Class: Stripe::PaymentIntent::CreateParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



4367
4368
4369
4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
# File 'lib/stripe/resources/payment_intent.rb', line 4367

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



4353
4354
4355
# File 'lib/stripe/resources/payment_intent.rb', line 4353

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



4355
4356
4357
# File 'lib/stripe/resources/payment_intent.rb', line 4355

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



4357
4358
4359
# File 'lib/stripe/resources/payment_intent.rb', line 4357

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



4359
4360
4361
# File 'lib/stripe/resources/payment_intent.rb', line 4359

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



4361
4362
4363
# File 'lib/stripe/resources/payment_intent.rb', line 4361

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



4363
4364
4365
# File 'lib/stripe/resources/payment_intent.rb', line 4363

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



4365
4366
4367
# File 'lib/stripe/resources/payment_intent.rb', line 4365

def subscription
  @subscription
end