Class: Stripe::PaymentIntent::CreateParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
# File 'lib/stripe/resources/payment_intent.rb', line 2964

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



2950
2951
2952
# File 'lib/stripe/resources/payment_intent.rb', line 2950

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



2952
2953
2954
# File 'lib/stripe/resources/payment_intent.rb', line 2952

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



2954
2955
2956
# File 'lib/stripe/resources/payment_intent.rb', line 2954

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



2956
2957
2958
# File 'lib/stripe/resources/payment_intent.rb', line 2956

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



2958
2959
2960
# File 'lib/stripe/resources/payment_intent.rb', line 2958

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



2960
2961
2962
# File 'lib/stripe/resources/payment_intent.rb', line 2960

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



2962
2963
2964
# File 'lib/stripe/resources/payment_intent.rb', line 2962

def subscription
  @subscription
end