Class: Stripe::PaymentIntent::CreateParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
# File 'lib/stripe/resources/payment_intent.rb', line 2798

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



2784
2785
2786
# File 'lib/stripe/resources/payment_intent.rb', line 2784

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



2786
2787
2788
# File 'lib/stripe/resources/payment_intent.rb', line 2786

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



2788
2789
2790
# File 'lib/stripe/resources/payment_intent.rb', line 2788

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



2790
2791
2792
# File 'lib/stripe/resources/payment_intent.rb', line 2790

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



2792
2793
2794
# File 'lib/stripe/resources/payment_intent.rb', line 2792

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



2794
2795
2796
# File 'lib/stripe/resources/payment_intent.rb', line 2794

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



2796
2797
2798
# File 'lib/stripe/resources/payment_intent.rb', line 2796

def subscription
  @subscription
end