Class: Stripe::PaymentIntent::CreateParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



2736
2737
2738
2739
2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
# File 'lib/stripe/resources/payment_intent.rb', line 2736

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



2722
2723
2724
# File 'lib/stripe/resources/payment_intent.rb', line 2722

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



2724
2725
2726
# File 'lib/stripe/resources/payment_intent.rb', line 2724

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



2726
2727
2728
# File 'lib/stripe/resources/payment_intent.rb', line 2726

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



2728
2729
2730
# File 'lib/stripe/resources/payment_intent.rb', line 2728

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



2730
2731
2732
# File 'lib/stripe/resources/payment_intent.rb', line 2730

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



2732
2733
2734
# File 'lib/stripe/resources/payment_intent.rb', line 2732

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



2734
2735
2736
# File 'lib/stripe/resources/payment_intent.rb', line 2734

def subscription
  @subscription
end