Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#distance ⇒ Object
The details of the distance traveled during the rental period.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#pickup_location_name ⇒ Object
Name of the pickup location.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#return_location_name ⇒ Object
Name of the return location.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
The vehicle identification number.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental
Returns a new instance of CarRental.
3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 3874 3875 3876 3877 3878 3879 3880 3881 3882 3883 3884 3885 3886 3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 3905 |
# File 'lib/stripe/resources/payment_intent.rb', line 3855 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @distance = distance @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @pickup_location_name = pickup_location_name @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @return_location_name = return_location_name @tax_exempt = tax_exempt @vehicle_identification_number = vehicle_identification_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
3807 3808 3809 |
# File 'lib/stripe/resources/payment_intent.rb', line 3807 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
3809 3810 3811 |
# File 'lib/stripe/resources/payment_intent.rb', line 3809 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
3811 3812 3813 |
# File 'lib/stripe/resources/payment_intent.rb', line 3811 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
3813 3814 3815 |
# File 'lib/stripe/resources/payment_intent.rb', line 3813 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
3815 3816 3817 |
# File 'lib/stripe/resources/payment_intent.rb', line 3815 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
3817 3818 3819 |
# File 'lib/stripe/resources/payment_intent.rb', line 3817 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
3819 3820 3821 |
# File 'lib/stripe/resources/payment_intent.rb', line 3819 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
3821 3822 3823 |
# File 'lib/stripe/resources/payment_intent.rb', line 3821 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
3823 3824 3825 |
# File 'lib/stripe/resources/payment_intent.rb', line 3823 def delivery @delivery end |
#distance ⇒ Object
The details of the distance traveled during the rental period.
3825 3826 3827 |
# File 'lib/stripe/resources/payment_intent.rb', line 3825 def distance @distance end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
3827 3828 3829 |
# File 'lib/stripe/resources/payment_intent.rb', line 3827 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
3829 3830 3831 |
# File 'lib/stripe/resources/payment_intent.rb', line 3829 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
3831 3832 3833 |
# File 'lib/stripe/resources/payment_intent.rb', line 3831 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
3833 3834 3835 |
# File 'lib/stripe/resources/payment_intent.rb', line 3833 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
3835 3836 3837 |
# File 'lib/stripe/resources/payment_intent.rb', line 3835 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object
Name of the pickup location.
3837 3838 3839 |
# File 'lib/stripe/resources/payment_intent.rb', line 3837 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object
Rental rate.
3839 3840 3841 |
# File 'lib/stripe/resources/payment_intent.rb', line 3839 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
3841 3842 3843 |
# File 'lib/stripe/resources/payment_intent.rb', line 3841 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
3843 3844 3845 |
# File 'lib/stripe/resources/payment_intent.rb', line 3843 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
3845 3846 3847 |
# File 'lib/stripe/resources/payment_intent.rb', line 3845 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
3847 3848 3849 |
# File 'lib/stripe/resources/payment_intent.rb', line 3847 def return_at @return_at end |
#return_location_name ⇒ Object
Name of the return location.
3849 3850 3851 |
# File 'lib/stripe/resources/payment_intent.rb', line 3849 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
3851 3852 3853 |
# File 'lib/stripe/resources/payment_intent.rb', line 3851 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object
The vehicle identification number.
3853 3854 3855 |
# File 'lib/stripe/resources/payment_intent.rb', line 3853 def vehicle_identification_number @vehicle_identification_number end |