Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#distance ⇒ Object
The details of the distance traveled during the rental period.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#pickup_location_name ⇒ Object
Name of the pickup location.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#return_location_name ⇒ Object
Name of the return location.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
The vehicle identification number.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental
Returns a new instance of CarRental.
2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 2479 2480 2481 2482 2483 2484 2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 2496 2497 2498 2499 2500 2501 2502 |
# File 'lib/stripe/resources/payment_intent.rb', line 2452 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @distance = distance @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @pickup_location_name = pickup_location_name @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @return_location_name = return_location_name @tax_exempt = tax_exempt @vehicle_identification_number = vehicle_identification_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
2404 2405 2406 |
# File 'lib/stripe/resources/payment_intent.rb', line 2404 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
2406 2407 2408 |
# File 'lib/stripe/resources/payment_intent.rb', line 2406 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
2408 2409 2410 |
# File 'lib/stripe/resources/payment_intent.rb', line 2408 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
2410 2411 2412 |
# File 'lib/stripe/resources/payment_intent.rb', line 2410 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
2412 2413 2414 |
# File 'lib/stripe/resources/payment_intent.rb', line 2412 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
2414 2415 2416 |
# File 'lib/stripe/resources/payment_intent.rb', line 2414 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
2416 2417 2418 |
# File 'lib/stripe/resources/payment_intent.rb', line 2416 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
2418 2419 2420 |
# File 'lib/stripe/resources/payment_intent.rb', line 2418 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
2420 2421 2422 |
# File 'lib/stripe/resources/payment_intent.rb', line 2420 def delivery @delivery end |
#distance ⇒ Object
The details of the distance traveled during the rental period.
2422 2423 2424 |
# File 'lib/stripe/resources/payment_intent.rb', line 2422 def distance @distance end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
2424 2425 2426 |
# File 'lib/stripe/resources/payment_intent.rb', line 2424 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
2426 2427 2428 |
# File 'lib/stripe/resources/payment_intent.rb', line 2426 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
2428 2429 2430 |
# File 'lib/stripe/resources/payment_intent.rb', line 2428 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
2430 2431 2432 |
# File 'lib/stripe/resources/payment_intent.rb', line 2430 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
2432 2433 2434 |
# File 'lib/stripe/resources/payment_intent.rb', line 2432 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object
Name of the pickup location.
2434 2435 2436 |
# File 'lib/stripe/resources/payment_intent.rb', line 2434 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object
Rental rate.
2436 2437 2438 |
# File 'lib/stripe/resources/payment_intent.rb', line 2436 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
2438 2439 2440 |
# File 'lib/stripe/resources/payment_intent.rb', line 2438 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
2440 2441 2442 |
# File 'lib/stripe/resources/payment_intent.rb', line 2440 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
2442 2443 2444 |
# File 'lib/stripe/resources/payment_intent.rb', line 2442 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
2444 2445 2446 |
# File 'lib/stripe/resources/payment_intent.rb', line 2444 def return_at @return_at end |
#return_location_name ⇒ Object
Name of the return location.
2446 2447 2448 |
# File 'lib/stripe/resources/payment_intent.rb', line 2446 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
2448 2449 2450 |
# File 'lib/stripe/resources/payment_intent.rb', line 2448 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object
The vehicle identification number.
2450 2451 2452 |
# File 'lib/stripe/resources/payment_intent.rb', line 2450 def vehicle_identification_number @vehicle_identification_number end |