Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental

Returns a new instance of CarRental.



2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
# File 'lib/stripe/resources/payment_intent.rb', line 2286

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  distance: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  pickup_location_name: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  return_location_name: nil,
  tax_exempt: nil,
  vehicle_identification_number: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @distance = distance
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @pickup_location_name = pickup_location_name
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @return_location_name = return_location_name
  @tax_exempt = tax_exempt
  @vehicle_identification_number = vehicle_identification_number
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



2238
2239
2240
# File 'lib/stripe/resources/payment_intent.rb', line 2238

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



2240
2241
2242
# File 'lib/stripe/resources/payment_intent.rb', line 2240

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



2242
2243
2244
# File 'lib/stripe/resources/payment_intent.rb', line 2242

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



2244
2245
2246
# File 'lib/stripe/resources/payment_intent.rb', line 2244

def car_make
  @car_make
end

#car_modelObject

Model of the car.



2246
2247
2248
# File 'lib/stripe/resources/payment_intent.rb', line 2246

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



2248
2249
2250
# File 'lib/stripe/resources/payment_intent.rb', line 2248

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



2250
2251
2252
# File 'lib/stripe/resources/payment_intent.rb', line 2250

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



2252
2253
2254
# File 'lib/stripe/resources/payment_intent.rb', line 2252

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



2254
2255
2256
# File 'lib/stripe/resources/payment_intent.rb', line 2254

def delivery
  @delivery
end

#distanceObject

The details of the distance traveled during the rental period.



2256
2257
2258
# File 'lib/stripe/resources/payment_intent.rb', line 2256

def distance
  @distance
end

#driversObject

The details of the passengers in the travel reservation



2258
2259
2260
# File 'lib/stripe/resources/payment_intent.rb', line 2258

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



2260
2261
2262
# File 'lib/stripe/resources/payment_intent.rb', line 2260

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



2262
2263
2264
# File 'lib/stripe/resources/payment_intent.rb', line 2262

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



2264
2265
2266
# File 'lib/stripe/resources/payment_intent.rb', line 2264

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



2266
2267
2268
# File 'lib/stripe/resources/payment_intent.rb', line 2266

def pickup_at
  @pickup_at
end

#pickup_location_nameObject

Name of the pickup location.



2268
2269
2270
# File 'lib/stripe/resources/payment_intent.rb', line 2268

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject

Rental rate.



2270
2271
2272
# File 'lib/stripe/resources/payment_intent.rb', line 2270

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



2272
2273
2274
# File 'lib/stripe/resources/payment_intent.rb', line 2272

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



2274
2275
2276
# File 'lib/stripe/resources/payment_intent.rb', line 2274

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



2276
2277
2278
# File 'lib/stripe/resources/payment_intent.rb', line 2276

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



2278
2279
2280
# File 'lib/stripe/resources/payment_intent.rb', line 2278

def return_at
  @return_at
end

#return_location_nameObject

Name of the return location.



2280
2281
2282
# File 'lib/stripe/resources/payment_intent.rb', line 2280

def return_location_name
  @return_location_name
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



2282
2283
2284
# File 'lib/stripe/resources/payment_intent.rb', line 2282

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject

The vehicle identification number.



2284
2285
2286
# File 'lib/stripe/resources/payment_intent.rb', line 2284

def vehicle_identification_number
  @vehicle_identification_number
end