Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/stripe/resources/payment_intent.rb', line 2232 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
2192 2193 2194 |
# File 'lib/stripe/resources/payment_intent.rb', line 2192 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
2194 2195 2196 |
# File 'lib/stripe/resources/payment_intent.rb', line 2194 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
2196 2197 2198 |
# File 'lib/stripe/resources/payment_intent.rb', line 2196 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
2198 2199 2200 |
# File 'lib/stripe/resources/payment_intent.rb', line 2198 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
2200 2201 2202 |
# File 'lib/stripe/resources/payment_intent.rb', line 2200 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
2202 2203 2204 |
# File 'lib/stripe/resources/payment_intent.rb', line 2202 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
2204 2205 2206 |
# File 'lib/stripe/resources/payment_intent.rb', line 2204 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
2206 2207 2208 |
# File 'lib/stripe/resources/payment_intent.rb', line 2206 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
2208 2209 2210 |
# File 'lib/stripe/resources/payment_intent.rb', line 2208 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
2210 2211 2212 |
# File 'lib/stripe/resources/payment_intent.rb', line 2210 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
2212 2213 2214 |
# File 'lib/stripe/resources/payment_intent.rb', line 2212 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
2214 2215 2216 |
# File 'lib/stripe/resources/payment_intent.rb', line 2214 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
2216 2217 2218 |
# File 'lib/stripe/resources/payment_intent.rb', line 2216 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
2218 2219 2220 |
# File 'lib/stripe/resources/payment_intent.rb', line 2218 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
2220 2221 2222 |
# File 'lib/stripe/resources/payment_intent.rb', line 2220 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
2222 2223 2224 |
# File 'lib/stripe/resources/payment_intent.rb', line 2222 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
2224 2225 2226 |
# File 'lib/stripe/resources/payment_intent.rb', line 2224 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
2226 2227 2228 |
# File 'lib/stripe/resources/payment_intent.rb', line 2226 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
2228 2229 2230 |
# File 'lib/stripe/resources/payment_intent.rb', line 2228 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
2230 2231 2232 |
# File 'lib/stripe/resources/payment_intent.rb', line 2230 def tax_exempt @tax_exempt end |