Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental

Returns a new instance of CarRental.



2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
2244
2245
# File 'lib/stripe/resources/payment_intent.rb', line 2203

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  tax_exempt: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @tax_exempt = tax_exempt
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



2163
2164
2165
# File 'lib/stripe/resources/payment_intent.rb', line 2163

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



2165
2166
2167
# File 'lib/stripe/resources/payment_intent.rb', line 2165

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



2167
2168
2169
# File 'lib/stripe/resources/payment_intent.rb', line 2167

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



2169
2170
2171
# File 'lib/stripe/resources/payment_intent.rb', line 2169

def car_make
  @car_make
end

#car_modelObject

Model of the car.



2171
2172
2173
# File 'lib/stripe/resources/payment_intent.rb', line 2171

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



2173
2174
2175
# File 'lib/stripe/resources/payment_intent.rb', line 2173

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



2175
2176
2177
# File 'lib/stripe/resources/payment_intent.rb', line 2175

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



2177
2178
2179
# File 'lib/stripe/resources/payment_intent.rb', line 2177

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



2179
2180
2181
# File 'lib/stripe/resources/payment_intent.rb', line 2179

def delivery
  @delivery
end

#driversObject

The details of the passengers in the travel reservation



2181
2182
2183
# File 'lib/stripe/resources/payment_intent.rb', line 2181

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



2183
2184
2185
# File 'lib/stripe/resources/payment_intent.rb', line 2183

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



2185
2186
2187
# File 'lib/stripe/resources/payment_intent.rb', line 2185

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



2187
2188
2189
# File 'lib/stripe/resources/payment_intent.rb', line 2187

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



2189
2190
2191
# File 'lib/stripe/resources/payment_intent.rb', line 2189

def pickup_at
  @pickup_at
end

#rate_amountObject

Rental rate.



2191
2192
2193
# File 'lib/stripe/resources/payment_intent.rb', line 2191

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



2193
2194
2195
# File 'lib/stripe/resources/payment_intent.rb', line 2193

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



2195
2196
2197
# File 'lib/stripe/resources/payment_intent.rb', line 2195

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



2197
2198
2199
# File 'lib/stripe/resources/payment_intent.rb', line 2197

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



2199
2200
2201
# File 'lib/stripe/resources/payment_intent.rb', line 2199

def return_at
  @return_at
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



2201
2202
2203
# File 'lib/stripe/resources/payment_intent.rb', line 2201

def tax_exempt
  @tax_exempt
end