Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental

Returns a new instance of CarRental.



2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
# File 'lib/stripe/resources/payment_intent.rb', line 2152

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  tax_exempt: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @tax_exempt = tax_exempt
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



2112
2113
2114
# File 'lib/stripe/resources/payment_intent.rb', line 2112

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



2114
2115
2116
# File 'lib/stripe/resources/payment_intent.rb', line 2114

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



2116
2117
2118
# File 'lib/stripe/resources/payment_intent.rb', line 2116

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



2118
2119
2120
# File 'lib/stripe/resources/payment_intent.rb', line 2118

def car_make
  @car_make
end

#car_modelObject

Model of the car.



2120
2121
2122
# File 'lib/stripe/resources/payment_intent.rb', line 2120

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



2122
2123
2124
# File 'lib/stripe/resources/payment_intent.rb', line 2122

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



2124
2125
2126
# File 'lib/stripe/resources/payment_intent.rb', line 2124

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



2126
2127
2128
# File 'lib/stripe/resources/payment_intent.rb', line 2126

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



2128
2129
2130
# File 'lib/stripe/resources/payment_intent.rb', line 2128

def delivery
  @delivery
end

#driversObject

The details of the passengers in the travel reservation



2130
2131
2132
# File 'lib/stripe/resources/payment_intent.rb', line 2130

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



2132
2133
2134
# File 'lib/stripe/resources/payment_intent.rb', line 2132

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



2134
2135
2136
# File 'lib/stripe/resources/payment_intent.rb', line 2134

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



2136
2137
2138
# File 'lib/stripe/resources/payment_intent.rb', line 2136

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



2138
2139
2140
# File 'lib/stripe/resources/payment_intent.rb', line 2138

def pickup_at
  @pickup_at
end

#rate_amountObject

Rental rate.



2140
2141
2142
# File 'lib/stripe/resources/payment_intent.rb', line 2140

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



2142
2143
2144
# File 'lib/stripe/resources/payment_intent.rb', line 2142

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



2144
2145
2146
# File 'lib/stripe/resources/payment_intent.rb', line 2144

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



2146
2147
2148
# File 'lib/stripe/resources/payment_intent.rb', line 2146

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



2148
2149
2150
# File 'lib/stripe/resources/payment_intent.rb', line 2148

def return_at
  @return_at
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



2150
2151
2152
# File 'lib/stripe/resources/payment_intent.rb', line 2150

def tax_exempt
  @tax_exempt
end