Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental

Returns a new instance of CarRental.



2598
2599
2600
2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
# File 'lib/stripe/resources/payment_intent.rb', line 2598

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  tax_exempt: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @tax_exempt = tax_exempt
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



2539
2540
2541
# File 'lib/stripe/resources/payment_intent.rb', line 2539

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



2542
2543
2544
# File 'lib/stripe/resources/payment_intent.rb', line 2542

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



2545
2546
2547
# File 'lib/stripe/resources/payment_intent.rb', line 2545

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



2548
2549
2550
# File 'lib/stripe/resources/payment_intent.rb', line 2548

def car_make
  @car_make
end

#car_modelObject

Model of the car.



2551
2552
2553
# File 'lib/stripe/resources/payment_intent.rb', line 2551

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



2554
2555
2556
# File 'lib/stripe/resources/payment_intent.rb', line 2554

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



2557
2558
2559
# File 'lib/stripe/resources/payment_intent.rb', line 2557

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



2560
2561
2562
# File 'lib/stripe/resources/payment_intent.rb', line 2560

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



2563
2564
2565
# File 'lib/stripe/resources/payment_intent.rb', line 2563

def delivery
  @delivery
end

#driversObject

The details of the passengers in the travel reservation



2566
2567
2568
# File 'lib/stripe/resources/payment_intent.rb', line 2566

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



2569
2570
2571
# File 'lib/stripe/resources/payment_intent.rb', line 2569

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



2572
2573
2574
# File 'lib/stripe/resources/payment_intent.rb', line 2572

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



2575
2576
2577
# File 'lib/stripe/resources/payment_intent.rb', line 2575

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



2578
2579
2580
# File 'lib/stripe/resources/payment_intent.rb', line 2578

def pickup_at
  @pickup_at
end

#rate_amountObject

Rental rate.



2581
2582
2583
# File 'lib/stripe/resources/payment_intent.rb', line 2581

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



2584
2585
2586
# File 'lib/stripe/resources/payment_intent.rb', line 2584

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



2587
2588
2589
# File 'lib/stripe/resources/payment_intent.rb', line 2587

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



2590
2591
2592
# File 'lib/stripe/resources/payment_intent.rb', line 2590

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



2593
2594
2595
# File 'lib/stripe/resources/payment_intent.rb', line 2593

def return_at
  @return_at
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



2596
2597
2598
# File 'lib/stripe/resources/payment_intent.rb', line 2596

def tax_exempt
  @tax_exempt
end