Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 |
# File 'lib/stripe/resources/payment_intent.rb', line 2138 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
2098 2099 2100 |
# File 'lib/stripe/resources/payment_intent.rb', line 2098 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
2100 2101 2102 |
# File 'lib/stripe/resources/payment_intent.rb', line 2100 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
2102 2103 2104 |
# File 'lib/stripe/resources/payment_intent.rb', line 2102 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
2104 2105 2106 |
# File 'lib/stripe/resources/payment_intent.rb', line 2104 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
2106 2107 2108 |
# File 'lib/stripe/resources/payment_intent.rb', line 2106 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
2108 2109 2110 |
# File 'lib/stripe/resources/payment_intent.rb', line 2108 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
2110 2111 2112 |
# File 'lib/stripe/resources/payment_intent.rb', line 2110 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
2112 2113 2114 |
# File 'lib/stripe/resources/payment_intent.rb', line 2112 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
2114 2115 2116 |
# File 'lib/stripe/resources/payment_intent.rb', line 2114 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
2116 2117 2118 |
# File 'lib/stripe/resources/payment_intent.rb', line 2116 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
2118 2119 2120 |
# File 'lib/stripe/resources/payment_intent.rb', line 2118 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
2120 2121 2122 |
# File 'lib/stripe/resources/payment_intent.rb', line 2120 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
2122 2123 2124 |
# File 'lib/stripe/resources/payment_intent.rb', line 2122 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
2124 2125 2126 |
# File 'lib/stripe/resources/payment_intent.rb', line 2124 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
2126 2127 2128 |
# File 'lib/stripe/resources/payment_intent.rb', line 2126 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
2128 2129 2130 |
# File 'lib/stripe/resources/payment_intent.rb', line 2128 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
2130 2131 2132 |
# File 'lib/stripe/resources/payment_intent.rb', line 2130 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
2132 2133 2134 |
# File 'lib/stripe/resources/payment_intent.rb', line 2132 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
2134 2135 2136 |
# File 'lib/stripe/resources/payment_intent.rb', line 2134 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
2136 2137 2138 |
# File 'lib/stripe/resources/payment_intent.rb', line 2136 def tax_exempt @tax_exempt end |