Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2132
2133
2134
2135
2136
# File 'lib/stripe/resources/payment_intent.rb', line 2132

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2126
2127
2128
# File 'lib/stripe/resources/payment_intent.rb', line 2126

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2128
2129
2130
# File 'lib/stripe/resources/payment_intent.rb', line 2128

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2130
2131
2132
# File 'lib/stripe/resources/payment_intent.rb', line 2130

def phone
  @phone
end