Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2075
2076
2077
2078
2079
# File 'lib/stripe/resources/payment_intent.rb', line 2075

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2069
2070
2071
# File 'lib/stripe/resources/payment_intent.rb', line 2069

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2071
2072
2073
# File 'lib/stripe/resources/payment_intent.rb', line 2071

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2073
2074
2075
# File 'lib/stripe/resources/payment_intent.rb', line 2073

def phone
  @phone
end