Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
2104 2105 2106 2107 2108 |
# File 'lib/stripe/resources/payment_intent.rb', line 2104 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
2098 2099 2100 |
# File 'lib/stripe/resources/payment_intent.rb', line 2098 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
2100 2101 2102 |
# File 'lib/stripe/resources/payment_intent.rb', line 2100 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
2102 2103 2104 |
# File 'lib/stripe/resources/payment_intent.rb', line 2102 def phone @phone end |