Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2024
2025
2026
2027
2028
# File 'lib/stripe/resources/payment_intent.rb', line 2024

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2018
2019
2020
# File 'lib/stripe/resources/payment_intent.rb', line 2018

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2020
2021
2022
# File 'lib/stripe/resources/payment_intent.rb', line 2020

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2022
2023
2024
# File 'lib/stripe/resources/payment_intent.rb', line 2022

def phone
  @phone
end