Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
2014 2015 2016 2017 2018 |
# File 'lib/stripe/resources/payment_intent.rb', line 2014 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
2008 2009 2010 |
# File 'lib/stripe/resources/payment_intent.rb', line 2008 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
2010 2011 2012 |
# File 'lib/stripe/resources/payment_intent.rb', line 2010 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
2012 2013 2014 |
# File 'lib/stripe/resources/payment_intent.rb', line 2012 def phone @phone end |