Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2010
2011
2012
2013
2014
# File 'lib/stripe/resources/payment_intent.rb', line 2010

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2004
2005
2006
# File 'lib/stripe/resources/payment_intent.rb', line 2004

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2006
2007
2008
# File 'lib/stripe/resources/payment_intent.rb', line 2006

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2008
2009
2010
# File 'lib/stripe/resources/payment_intent.rb', line 2008

def phone
  @phone
end