Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 2606 2607 2608 2609 2610 |
# File 'lib/stripe/resources/payment_intent.rb', line 2590 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
2572 2573 2574 |
# File 'lib/stripe/resources/payment_intent.rb', line 2572 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
2574 2575 2576 |
# File 'lib/stripe/resources/payment_intent.rb', line 2574 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
2576 2577 2578 |
# File 'lib/stripe/resources/payment_intent.rb', line 2576 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
2578 2579 2580 |
# File 'lib/stripe/resources/payment_intent.rb', line 2578 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
2580 2581 2582 |
# File 'lib/stripe/resources/payment_intent.rb', line 2580 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
2582 2583 2584 |
# File 'lib/stripe/resources/payment_intent.rb', line 2582 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
2584 2585 2586 |
# File 'lib/stripe/resources/payment_intent.rb', line 2584 def genre @genre end |
#name ⇒ Object
The name of the event.
2586 2587 2588 |
# File 'lib/stripe/resources/payment_intent.rb', line 2586 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
2588 2589 2590 |
# File 'lib/stripe/resources/payment_intent.rb', line 2588 def starts_at @starts_at end |