Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 |
# File 'lib/stripe/resources/payment_intent.rb', line 2437 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
2419 2420 2421 |
# File 'lib/stripe/resources/payment_intent.rb', line 2419 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
2421 2422 2423 |
# File 'lib/stripe/resources/payment_intent.rb', line 2421 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
2423 2424 2425 |
# File 'lib/stripe/resources/payment_intent.rb', line 2423 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
2425 2426 2427 |
# File 'lib/stripe/resources/payment_intent.rb', line 2425 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
2427 2428 2429 |
# File 'lib/stripe/resources/payment_intent.rb', line 2427 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
2429 2430 2431 |
# File 'lib/stripe/resources/payment_intent.rb', line 2429 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
2431 2432 2433 |
# File 'lib/stripe/resources/payment_intent.rb', line 2431 def genre @genre end |
#name ⇒ Object
The name of the event.
2433 2434 2435 |
# File 'lib/stripe/resources/payment_intent.rb', line 2433 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
2435 2436 2437 |
# File 'lib/stripe/resources/payment_intent.rb', line 2435 def starts_at @starts_at end |