Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 |
# File 'lib/stripe/resources/payment_intent.rb', line 2424 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
2406 2407 2408 |
# File 'lib/stripe/resources/payment_intent.rb', line 2406 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
2408 2409 2410 |
# File 'lib/stripe/resources/payment_intent.rb', line 2408 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
2410 2411 2412 |
# File 'lib/stripe/resources/payment_intent.rb', line 2410 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
2412 2413 2414 |
# File 'lib/stripe/resources/payment_intent.rb', line 2412 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
2414 2415 2416 |
# File 'lib/stripe/resources/payment_intent.rb', line 2414 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
2416 2417 2418 |
# File 'lib/stripe/resources/payment_intent.rb', line 2416 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
2418 2419 2420 |
# File 'lib/stripe/resources/payment_intent.rb', line 2418 def genre @genre end |
#name ⇒ Object
The name of the event.
2420 2421 2422 |
# File 'lib/stripe/resources/payment_intent.rb', line 2420 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
2422 2423 2424 |
# File 'lib/stripe/resources/payment_intent.rb', line 2422 def starts_at @starts_at end |