Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
2744 2745 2746 2747 2748 2749 2750 2751 2752 2753 2754 2755 2756 2757 2758 2759 2760 2761 2762 2763 2764 |
# File 'lib/stripe/resources/payment_intent.rb', line 2744 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
2718 2719 2720 |
# File 'lib/stripe/resources/payment_intent.rb', line 2718 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
2721 2722 2723 |
# File 'lib/stripe/resources/payment_intent.rb', line 2721 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
2724 2725 2726 |
# File 'lib/stripe/resources/payment_intent.rb', line 2724 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
2727 2728 2729 |
# File 'lib/stripe/resources/payment_intent.rb', line 2727 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
2730 2731 2732 |
# File 'lib/stripe/resources/payment_intent.rb', line 2730 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
2733 2734 2735 |
# File 'lib/stripe/resources/payment_intent.rb', line 2733 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
2736 2737 2738 |
# File 'lib/stripe/resources/payment_intent.rb', line 2736 def genre @genre end |
#name ⇒ Object
The name of the event.
2739 2740 2741 |
# File 'lib/stripe/resources/payment_intent.rb', line 2739 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
2742 2743 2744 |
# File 'lib/stripe/resources/payment_intent.rb', line 2742 def starts_at @starts_at end |