Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
2298 2299 2300 2301 2302 |
# File 'lib/stripe/resources/payment_intent.rb', line 2298 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
2292 2293 2294 |
# File 'lib/stripe/resources/payment_intent.rb', line 2292 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
2294 2295 2296 |
# File 'lib/stripe/resources/payment_intent.rb', line 2294 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
2296 2297 2298 |
# File 'lib/stripe/resources/payment_intent.rb', line 2296 def phone @phone end |