Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2247
2248
2249
2250
2251
# File 'lib/stripe/resources/payment_intent.rb', line 2247

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2241
2242
2243
# File 'lib/stripe/resources/payment_intent.rb', line 2241

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2243
2244
2245
# File 'lib/stripe/resources/payment_intent.rb', line 2243

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2245
2246
2247
# File 'lib/stripe/resources/payment_intent.rb', line 2245

def phone
  @phone
end