Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2237
2238
2239
2240
2241
# File 'lib/stripe/resources/payment_intent.rb', line 2237

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2231
2232
2233
# File 'lib/stripe/resources/payment_intent.rb', line 2231

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2233
2234
2235
# File 'lib/stripe/resources/payment_intent.rb', line 2233

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2235
2236
2237
# File 'lib/stripe/resources/payment_intent.rb', line 2235

def phone
  @phone
end