Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
2632 2633 2634 2635 2636 |
# File 'lib/stripe/resources/payment_intent.rb', line 2632 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
2626 2627 2628 |
# File 'lib/stripe/resources/payment_intent.rb', line 2626 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
2628 2629 2630 |
# File 'lib/stripe/resources/payment_intent.rb', line 2628 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
2630 2631 2632 |
# File 'lib/stripe/resources/payment_intent.rb', line 2630 def phone @phone end |