Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2404
2405
2406
2407
2408
# File 'lib/stripe/resources/payment_intent.rb', line 2404

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2398
2399
2400
# File 'lib/stripe/resources/payment_intent.rb', line 2398

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2400
2401
2402
# File 'lib/stripe/resources/payment_intent.rb', line 2400

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2402
2403
2404
# File 'lib/stripe/resources/payment_intent.rb', line 2402

def phone
  @phone
end