Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2375
2376
2377
2378
2379
# File 'lib/stripe/resources/payment_intent.rb', line 2375

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2369
2370
2371
# File 'lib/stripe/resources/payment_intent.rb', line 2369

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2371
2372
2373
# File 'lib/stripe/resources/payment_intent.rb', line 2371

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2373
2374
2375
# File 'lib/stripe/resources/payment_intent.rb', line 2373

def phone
  @phone
end