Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
2375 2376 2377 2378 2379 |
# File 'lib/stripe/resources/payment_intent.rb', line 2375 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
2369 2370 2371 |
# File 'lib/stripe/resources/payment_intent.rb', line 2369 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
2371 2372 2373 |
# File 'lib/stripe/resources/payment_intent.rb', line 2371 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
2373 2374 2375 |
# File 'lib/stripe/resources/payment_intent.rb', line 2373 def phone @phone end |