Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
2324 2325 2326 2327 2328 |
# File 'lib/stripe/resources/payment_intent.rb', line 2324 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
2318 2319 2320 |
# File 'lib/stripe/resources/payment_intent.rb', line 2318 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
2320 2321 2322 |
# File 'lib/stripe/resources/payment_intent.rb', line 2320 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
2322 2323 2324 |
# File 'lib/stripe/resources/payment_intent.rb', line 2322 def phone @phone end |