Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2788
2789
2790
2791
2792
# File 'lib/stripe/resources/payment_intent.rb', line 2788

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2780
2781
2782
# File 'lib/stripe/resources/payment_intent.rb', line 2780

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2783
2784
2785
# File 'lib/stripe/resources/payment_intent.rb', line 2783

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2786
2787
2788
# File 'lib/stripe/resources/payment_intent.rb', line 2786

def phone
  @phone
end