Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
2314 2315 2316 2317 2318 |
# File 'lib/stripe/resources/payment_intent.rb', line 2314 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
2308 2309 2310 |
# File 'lib/stripe/resources/payment_intent.rb', line 2308 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
2310 2311 2312 |
# File 'lib/stripe/resources/payment_intent.rb', line 2310 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
2312 2313 2314 |
# File 'lib/stripe/resources/payment_intent.rb', line 2312 def phone @phone end |