Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Flight::Segment
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::Flight::Segment
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The flight segment amount.
-
#arrival_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the arrival airport.
-
#arrives_at ⇒ Object
The arrival time for the flight segment.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier operating the flight segment.
-
#departs_at ⇒ Object
The departure time for the flight segment.
-
#departure_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the departure airport.
-
#flight_number ⇒ Object
The flight number associated with the segment.
-
#service_class ⇒ Object
The fare class for the segment.
Instance Method Summary collapse
-
#initialize(amount: nil, arrival_airport: nil, arrives_at: nil, carrier: nil, departs_at: nil, departure_airport: nil, flight_number: nil, service_class: nil) ⇒ Segment
constructor
A new instance of Segment.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, arrival_airport: nil, arrives_at: nil, carrier: nil, departs_at: nil, departure_airport: nil, flight_number: nil, service_class: nil) ⇒ Segment
Returns a new instance of Segment.
2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 |
# File 'lib/stripe/resources/payment_intent.rb', line 2510 def initialize( amount: nil, arrival_airport: nil, arrives_at: nil, carrier: nil, departs_at: nil, departure_airport: nil, flight_number: nil, service_class: nil ) @amount = amount @arrival_airport = arrival_airport @arrives_at = arrives_at @carrier = carrier @departs_at = departs_at @departure_airport = departure_airport @flight_number = flight_number @service_class = service_class end |
Instance Attribute Details
#amount ⇒ Object
The flight segment amount.
2494 2495 2496 |
# File 'lib/stripe/resources/payment_intent.rb', line 2494 def amount @amount end |
#arrival_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the arrival airport.
2496 2497 2498 |
# File 'lib/stripe/resources/payment_intent.rb', line 2496 def arrival_airport @arrival_airport end |
#arrives_at ⇒ Object
The arrival time for the flight segment. Measured in seconds since the Unix epoch.
2498 2499 2500 |
# File 'lib/stripe/resources/payment_intent.rb', line 2498 def arrives_at @arrives_at end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier operating the flight segment.
2500 2501 2502 |
# File 'lib/stripe/resources/payment_intent.rb', line 2500 def carrier @carrier end |
#departs_at ⇒ Object
The departure time for the flight segment. Measured in seconds since the Unix epoch.
2502 2503 2504 |
# File 'lib/stripe/resources/payment_intent.rb', line 2502 def departs_at @departs_at end |
#departure_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the departure airport.
2504 2505 2506 |
# File 'lib/stripe/resources/payment_intent.rb', line 2504 def departure_airport @departure_airport end |
#flight_number ⇒ Object
The flight number associated with the segment
2506 2507 2508 |
# File 'lib/stripe/resources/payment_intent.rb', line 2506 def flight_number @flight_number end |
#service_class ⇒ Object
The fare class for the segment.
2508 2509 2510 |
# File 'lib/stripe/resources/payment_intent.rb', line 2508 def service_class @service_class end |