Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
2852 2853 2854 2855 2856 2857 2858 2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 |
# File 'lib/stripe/resources/payment_intent.rb', line 2852 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
2810 2811 2812 |
# File 'lib/stripe/resources/payment_intent.rb', line 2810 def address @address end |
#adults ⇒ Object
The number of adults on the booking
2812 2813 2814 |
# File 'lib/stripe/resources/payment_intent.rb', line 2812 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
2814 2815 2816 |
# File 'lib/stripe/resources/payment_intent.rb', line 2814 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
2816 2817 2818 |
# File 'lib/stripe/resources/payment_intent.rb', line 2816 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
2818 2819 2820 |
# File 'lib/stripe/resources/payment_intent.rb', line 2818 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
2820 2821 2822 |
# File 'lib/stripe/resources/payment_intent.rb', line 2820 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
2822 2823 2824 |
# File 'lib/stripe/resources/payment_intent.rb', line 2822 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
2824 2825 2826 |
# File 'lib/stripe/resources/payment_intent.rb', line 2824 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
2826 2827 2828 |
# File 'lib/stripe/resources/payment_intent.rb', line 2826 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
2828 2829 2830 |
# File 'lib/stripe/resources/payment_intent.rb', line 2828 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
2830 2831 2832 |
# File 'lib/stripe/resources/payment_intent.rb', line 2830 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
2832 2833 2834 |
# File 'lib/stripe/resources/payment_intent.rb', line 2832 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
2834 2835 2836 |
# File 'lib/stripe/resources/payment_intent.rb', line 2834 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
2836 2837 2838 |
# File 'lib/stripe/resources/payment_intent.rb', line 2836 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
2838 2839 2840 |
# File 'lib/stripe/resources/payment_intent.rb', line 2838 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
2840 2841 2842 |
# File 'lib/stripe/resources/payment_intent.rb', line 2840 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
2842 2843 2844 |
# File 'lib/stripe/resources/payment_intent.rb', line 2842 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
2844 2845 2846 |
# File 'lib/stripe/resources/payment_intent.rb', line 2844 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
2846 2847 2848 |
# File 'lib/stripe/resources/payment_intent.rb', line 2846 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
2848 2849 2850 |
# File 'lib/stripe/resources/payment_intent.rb', line 2848 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
2850 2851 2852 |
# File 'lib/stripe/resources/payment_intent.rb', line 2850 def total_tax_amount @total_tax_amount end |