Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 2742 2743 |
# File 'lib/stripe/resources/payment_intent.rb', line 2699 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
2657 2658 2659 |
# File 'lib/stripe/resources/payment_intent.rb', line 2657 def address @address end |
#adults ⇒ Object
The number of adults on the booking
2659 2660 2661 |
# File 'lib/stripe/resources/payment_intent.rb', line 2659 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
2661 2662 2663 |
# File 'lib/stripe/resources/payment_intent.rb', line 2661 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
2663 2664 2665 |
# File 'lib/stripe/resources/payment_intent.rb', line 2663 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
2665 2666 2667 |
# File 'lib/stripe/resources/payment_intent.rb', line 2665 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
2667 2668 2669 |
# File 'lib/stripe/resources/payment_intent.rb', line 2667 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
2669 2670 2671 |
# File 'lib/stripe/resources/payment_intent.rb', line 2669 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
2671 2672 2673 |
# File 'lib/stripe/resources/payment_intent.rb', line 2671 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
2673 2674 2675 |
# File 'lib/stripe/resources/payment_intent.rb', line 2673 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
2675 2676 2677 |
# File 'lib/stripe/resources/payment_intent.rb', line 2675 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
2677 2678 2679 |
# File 'lib/stripe/resources/payment_intent.rb', line 2677 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
2679 2680 2681 |
# File 'lib/stripe/resources/payment_intent.rb', line 2679 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
2681 2682 2683 |
# File 'lib/stripe/resources/payment_intent.rb', line 2681 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
2683 2684 2685 |
# File 'lib/stripe/resources/payment_intent.rb', line 2683 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
2685 2686 2687 |
# File 'lib/stripe/resources/payment_intent.rb', line 2685 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
2687 2688 2689 |
# File 'lib/stripe/resources/payment_intent.rb', line 2687 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
2689 2690 2691 |
# File 'lib/stripe/resources/payment_intent.rb', line 2689 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
2691 2692 2693 |
# File 'lib/stripe/resources/payment_intent.rb', line 2691 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
2693 2694 2695 |
# File 'lib/stripe/resources/payment_intent.rb', line 2693 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
2695 2696 2697 |
# File 'lib/stripe/resources/payment_intent.rb', line 2695 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
2697 2698 2699 |
# File 'lib/stripe/resources/payment_intent.rb', line 2697 def total_tax_amount @total_tax_amount end |