Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
2704
2705
2706
2707
2708
2709
2710
2711
2712
2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
# File 'lib/stripe/resources/payment_intent.rb', line 2686

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



2644
2645
2646
# File 'lib/stripe/resources/payment_intent.rb', line 2644

def address
  @address
end

#adultsObject

The number of adults on the booking



2646
2647
2648
# File 'lib/stripe/resources/payment_intent.rb', line 2646

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



2648
2649
2650
# File 'lib/stripe/resources/payment_intent.rb', line 2648

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



2650
2651
2652
# File 'lib/stripe/resources/payment_intent.rb', line 2650

def booking_number
  @booking_number
end

#categoryObject

The lodging category



2652
2653
2654
# File 'lib/stripe/resources/payment_intent.rb', line 2652

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



2654
2655
2656
# File 'lib/stripe/resources/payment_intent.rb', line 2654

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



2656
2657
2658
# File 'lib/stripe/resources/payment_intent.rb', line 2656

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



2658
2659
2660
# File 'lib/stripe/resources/payment_intent.rb', line 2658

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



2660
2661
2662
# File 'lib/stripe/resources/payment_intent.rb', line 2660

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



2662
2663
2664
# File 'lib/stripe/resources/payment_intent.rb', line 2662

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



2664
2665
2666
# File 'lib/stripe/resources/payment_intent.rb', line 2664

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



2666
2667
2668
# File 'lib/stripe/resources/payment_intent.rb', line 2666

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



2668
2669
2670
# File 'lib/stripe/resources/payment_intent.rb', line 2668

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



2670
2671
2672
# File 'lib/stripe/resources/payment_intent.rb', line 2670

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



2672
2673
2674
# File 'lib/stripe/resources/payment_intent.rb', line 2672

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



2674
2675
2676
# File 'lib/stripe/resources/payment_intent.rb', line 2674

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



2676
2677
2678
# File 'lib/stripe/resources/payment_intent.rb', line 2676

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



2678
2679
2680
# File 'lib/stripe/resources/payment_intent.rb', line 2678

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



2680
2681
2682
# File 'lib/stripe/resources/payment_intent.rb', line 2680

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



2682
2683
2684
# File 'lib/stripe/resources/payment_intent.rb', line 2682

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



2684
2685
2686
# File 'lib/stripe/resources/payment_intent.rb', line 2684

def total_tax_amount
  @total_tax_amount
end