Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
2624 2625 2626 2627 2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 2656 2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 |
# File 'lib/stripe/resources/payment_intent.rb', line 2624 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
2582 2583 2584 |
# File 'lib/stripe/resources/payment_intent.rb', line 2582 def address @address end |
#adults ⇒ Object
The number of adults on the booking
2584 2585 2586 |
# File 'lib/stripe/resources/payment_intent.rb', line 2584 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
2586 2587 2588 |
# File 'lib/stripe/resources/payment_intent.rb', line 2586 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
2588 2589 2590 |
# File 'lib/stripe/resources/payment_intent.rb', line 2588 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
2590 2591 2592 |
# File 'lib/stripe/resources/payment_intent.rb', line 2590 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
2592 2593 2594 |
# File 'lib/stripe/resources/payment_intent.rb', line 2592 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
2594 2595 2596 |
# File 'lib/stripe/resources/payment_intent.rb', line 2594 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
2596 2597 2598 |
# File 'lib/stripe/resources/payment_intent.rb', line 2596 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
2598 2599 2600 |
# File 'lib/stripe/resources/payment_intent.rb', line 2598 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
2600 2601 2602 |
# File 'lib/stripe/resources/payment_intent.rb', line 2600 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
2602 2603 2604 |
# File 'lib/stripe/resources/payment_intent.rb', line 2602 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
2604 2605 2606 |
# File 'lib/stripe/resources/payment_intent.rb', line 2604 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
2606 2607 2608 |
# File 'lib/stripe/resources/payment_intent.rb', line 2606 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
2608 2609 2610 |
# File 'lib/stripe/resources/payment_intent.rb', line 2608 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
2610 2611 2612 |
# File 'lib/stripe/resources/payment_intent.rb', line 2610 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
2612 2613 2614 |
# File 'lib/stripe/resources/payment_intent.rb', line 2612 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
2614 2615 2616 |
# File 'lib/stripe/resources/payment_intent.rb', line 2614 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
2616 2617 2618 |
# File 'lib/stripe/resources/payment_intent.rb', line 2616 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
2618 2619 2620 |
# File 'lib/stripe/resources/payment_intent.rb', line 2618 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
2620 2621 2622 |
# File 'lib/stripe/resources/payment_intent.rb', line 2620 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
2622 2623 2624 |
# File 'lib/stripe/resources/payment_intent.rb', line 2622 def total_tax_amount @total_tax_amount end |