Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



2595
2596
2597
2598
2599
2600
2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
# File 'lib/stripe/resources/payment_intent.rb', line 2595

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



2553
2554
2555
# File 'lib/stripe/resources/payment_intent.rb', line 2553

def address
  @address
end

#adultsObject

The number of adults on the booking



2555
2556
2557
# File 'lib/stripe/resources/payment_intent.rb', line 2555

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



2557
2558
2559
# File 'lib/stripe/resources/payment_intent.rb', line 2557

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



2559
2560
2561
# File 'lib/stripe/resources/payment_intent.rb', line 2559

def booking_number
  @booking_number
end

#categoryObject

The lodging category



2561
2562
2563
# File 'lib/stripe/resources/payment_intent.rb', line 2561

def category
  @category
end

#checkin_atObject

Loding check-in time. Measured in seconds since the Unix epoch.



2563
2564
2565
# File 'lib/stripe/resources/payment_intent.rb', line 2563

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



2565
2566
2567
# File 'lib/stripe/resources/payment_intent.rb', line 2565

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



2567
2568
2569
# File 'lib/stripe/resources/payment_intent.rb', line 2567

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



2569
2570
2571
# File 'lib/stripe/resources/payment_intent.rb', line 2569

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



2571
2572
2573
# File 'lib/stripe/resources/payment_intent.rb', line 2571

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



2573
2574
2575
# File 'lib/stripe/resources/payment_intent.rb', line 2573

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



2575
2576
2577
# File 'lib/stripe/resources/payment_intent.rb', line 2575

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



2577
2578
2579
# File 'lib/stripe/resources/payment_intent.rb', line 2577

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



2579
2580
2581
# File 'lib/stripe/resources/payment_intent.rb', line 2579

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



2581
2582
2583
# File 'lib/stripe/resources/payment_intent.rb', line 2581

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



2583
2584
2585
# File 'lib/stripe/resources/payment_intent.rb', line 2583

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



2585
2586
2587
# File 'lib/stripe/resources/payment_intent.rb', line 2585

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



2587
2588
2589
# File 'lib/stripe/resources/payment_intent.rb', line 2587

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



2589
2590
2591
# File 'lib/stripe/resources/payment_intent.rb', line 2589

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



2591
2592
2593
# File 'lib/stripe/resources/payment_intent.rb', line 2591

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



2593
2594
2595
# File 'lib/stripe/resources/payment_intent.rb', line 2593

def total_tax_amount
  @total_tax_amount
end