Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Loding check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
3051 3052 3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 3066 3067 3068 3069 3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 3090 3091 3092 3093 3094 3095 |
# File 'lib/stripe/resources/payment_intent.rb', line 3051 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
2989 2990 2991 |
# File 'lib/stripe/resources/payment_intent.rb', line 2989 def address @address end |
#adults ⇒ Object
The number of adults on the booking
2992 2993 2994 |
# File 'lib/stripe/resources/payment_intent.rb', line 2992 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
2995 2996 2997 |
# File 'lib/stripe/resources/payment_intent.rb', line 2995 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
2998 2999 3000 |
# File 'lib/stripe/resources/payment_intent.rb', line 2998 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
3001 3002 3003 |
# File 'lib/stripe/resources/payment_intent.rb', line 3001 def category @category end |
#checkin_at ⇒ Object
Loding check-in time. Measured in seconds since the Unix epoch.
3004 3005 3006 |
# File 'lib/stripe/resources/payment_intent.rb', line 3004 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
3007 3008 3009 |
# File 'lib/stripe/resources/payment_intent.rb', line 3007 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
3010 3011 3012 |
# File 'lib/stripe/resources/payment_intent.rb', line 3010 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
3013 3014 3015 |
# File 'lib/stripe/resources/payment_intent.rb', line 3013 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
3016 3017 3018 |
# File 'lib/stripe/resources/payment_intent.rb', line 3016 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
3019 3020 3021 |
# File 'lib/stripe/resources/payment_intent.rb', line 3019 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
3022 3023 3024 |
# File 'lib/stripe/resources/payment_intent.rb', line 3022 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
3025 3026 3027 |
# File 'lib/stripe/resources/payment_intent.rb', line 3025 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
3028 3029 3030 |
# File 'lib/stripe/resources/payment_intent.rb', line 3028 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
3031 3032 3033 |
# File 'lib/stripe/resources/payment_intent.rb', line 3031 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
3034 3035 3036 |
# File 'lib/stripe/resources/payment_intent.rb', line 3034 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
3037 3038 3039 |
# File 'lib/stripe/resources/payment_intent.rb', line 3037 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
3040 3041 3042 |
# File 'lib/stripe/resources/payment_intent.rb', line 3040 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
3043 3044 3045 |
# File 'lib/stripe/resources/payment_intent.rb', line 3043 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
3046 3047 3048 |
# File 'lib/stripe/resources/payment_intent.rb', line 3046 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
3049 3050 3051 |
# File 'lib/stripe/resources/payment_intent.rb', line 3049 def total_tax_amount @total_tax_amount end |