Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Loding check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 2570 2571 2572 2573 2574 |
# File 'lib/stripe/resources/payment_intent.rb', line 2530 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
2488 2489 2490 |
# File 'lib/stripe/resources/payment_intent.rb', line 2488 def address @address end |
#adults ⇒ Object
The number of adults on the booking
2490 2491 2492 |
# File 'lib/stripe/resources/payment_intent.rb', line 2490 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
2492 2493 2494 |
# File 'lib/stripe/resources/payment_intent.rb', line 2492 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
2494 2495 2496 |
# File 'lib/stripe/resources/payment_intent.rb', line 2494 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
2496 2497 2498 |
# File 'lib/stripe/resources/payment_intent.rb', line 2496 def category @category end |
#checkin_at ⇒ Object
Loding check-in time. Measured in seconds since the Unix epoch.
2498 2499 2500 |
# File 'lib/stripe/resources/payment_intent.rb', line 2498 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
2500 2501 2502 |
# File 'lib/stripe/resources/payment_intent.rb', line 2500 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
2502 2503 2504 |
# File 'lib/stripe/resources/payment_intent.rb', line 2502 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
2504 2505 2506 |
# File 'lib/stripe/resources/payment_intent.rb', line 2504 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
2506 2507 2508 |
# File 'lib/stripe/resources/payment_intent.rb', line 2506 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
2508 2509 2510 |
# File 'lib/stripe/resources/payment_intent.rb', line 2508 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
2510 2511 2512 |
# File 'lib/stripe/resources/payment_intent.rb', line 2510 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
2512 2513 2514 |
# File 'lib/stripe/resources/payment_intent.rb', line 2512 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
2514 2515 2516 |
# File 'lib/stripe/resources/payment_intent.rb', line 2514 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
2516 2517 2518 |
# File 'lib/stripe/resources/payment_intent.rb', line 2516 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
2518 2519 2520 |
# File 'lib/stripe/resources/payment_intent.rb', line 2518 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
2520 2521 2522 |
# File 'lib/stripe/resources/payment_intent.rb', line 2520 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
2522 2523 2524 |
# File 'lib/stripe/resources/payment_intent.rb', line 2522 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
2524 2525 2526 |
# File 'lib/stripe/resources/payment_intent.rb', line 2524 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
2526 2527 2528 |
# File 'lib/stripe/resources/payment_intent.rb', line 2526 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
2528 2529 2530 |
# File 'lib/stripe/resources/payment_intent.rb', line 2528 def total_tax_amount @total_tax_amount end |