Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
2806 2807 2808 2809 2810 |
# File 'lib/stripe/resources/payment_intent.rb', line 2806 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
2800 2801 2802 |
# File 'lib/stripe/resources/payment_intent.rb', line 2800 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
2802 2803 2804 |
# File 'lib/stripe/resources/payment_intent.rb', line 2802 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
2804 2805 2806 |
# File 'lib/stripe/resources/payment_intent.rb', line 2804 def phone @phone end |