Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2618
2619
2620
2621
2622
# File 'lib/stripe/resources/payment_intent.rb', line 2618

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2612
2613
2614
# File 'lib/stripe/resources/payment_intent.rb', line 2612

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2614
2615
2616
# File 'lib/stripe/resources/payment_intent.rb', line 2614

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2616
2617
2618
# File 'lib/stripe/resources/payment_intent.rb', line 2616

def phone
  @phone
end