Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2527
2528
2529
2530
2531
# File 'lib/stripe/resources/payment_intent.rb', line 2527

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2521
2522
2523
# File 'lib/stripe/resources/payment_intent.rb', line 2521

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2523
2524
2525
# File 'lib/stripe/resources/payment_intent.rb', line 2523

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2525
2526
2527
# File 'lib/stripe/resources/payment_intent.rb', line 2525

def phone
  @phone
end