Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
2962 2963 2964 2965 2966 |
# File 'lib/stripe/resources/payment_intent.rb', line 2962 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
2954 2955 2956 |
# File 'lib/stripe/resources/payment_intent.rb', line 2954 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
2957 2958 2959 |
# File 'lib/stripe/resources/payment_intent.rb', line 2957 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
2960 2961 2962 |
# File 'lib/stripe/resources/payment_intent.rb', line 2960 def phone @phone end |