Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2466
2467
2468
2469
2470
# File 'lib/stripe/resources/payment_intent.rb', line 2466

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2460
2461
2462
# File 'lib/stripe/resources/payment_intent.rb', line 2460

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2462
2463
2464
# File 'lib/stripe/resources/payment_intent.rb', line 2462

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2464
2465
2466
# File 'lib/stripe/resources/payment_intent.rb', line 2464

def phone
  @phone
end