Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
2466 2467 2468 2469 2470 |
# File 'lib/stripe/resources/payment_intent.rb', line 2466 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
2460 2461 2462 |
# File 'lib/stripe/resources/payment_intent.rb', line 2460 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
2462 2463 2464 |
# File 'lib/stripe/resources/payment_intent.rb', line 2462 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
2464 2465 2466 |
# File 'lib/stripe/resources/payment_intent.rb', line 2464 def phone @phone end |