Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



2658
2659
2660
2661
# File 'lib/stripe/resources/payment_intent.rb', line 2658

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



2654
2655
2656
# File 'lib/stripe/resources/payment_intent.rb', line 2654

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



2656
2657
2658
# File 'lib/stripe/resources/payment_intent.rb', line 2656

def interval
  @interval
end