Class: Stripe::PaymentIntent::CreateParams::PaymentDetails::Subscription::BillingInterval
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentDetails::Subscription::BillingInterval
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#count ⇒ Object
The number of intervals, as an whole number greater than 0.
-
#interval ⇒ Object
Specifies a type of interval unit.
Instance Method Summary collapse
-
#initialize(count: nil, interval: nil) ⇒ BillingInterval
constructor
A new instance of BillingInterval.
Methods inherited from RequestParams
Constructor Details
#initialize(count: nil, interval: nil) ⇒ BillingInterval
Returns a new instance of BillingInterval.
2607 2608 2609 2610 |
# File 'lib/stripe/resources/payment_intent.rb', line 2607 def initialize(count: nil, interval: nil) @count = count @interval = interval end |
Instance Attribute Details
#count ⇒ Object
The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.
2603 2604 2605 |
# File 'lib/stripe/resources/payment_intent.rb', line 2603 def count @count end |
#interval ⇒ Object
Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.
2605 2606 2607 |
# File 'lib/stripe/resources/payment_intent.rb', line 2605 def interval @interval end |