Class: Stripe::PaymentIntent::CreateParams::PaymentMethodData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, RadarOptions, Rechnung, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, StripeBalance, Swish, Twint, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, billing_details: nil, blik: nil, boleto: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, radar_options: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, swish: nil, twint: nil, type: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodData

Returns a new instance of PaymentMethodData.



3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
3527
3528
3529
3530
3531
3532
3533
3534
3535
3536
3537
3538
3539
3540
3541
3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
3581
3582
3583
3584
3585
3586
3587
3588
3589
3590
3591
3592
3593
3594
3595
3596
3597
3598
3599
3600
3601
3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
3613
3614
3615
3616
3617
3618
# File 'lib/stripe/resources/payment_intent.rb', line 3494

def initialize(
  acss_debit: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  allow_redisplay: nil,
  alma: nil,
  amazon_pay: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  billie: nil,
  billing_details: nil,
  blik: nil,
  boleto: nil,
  cashapp: nil,
  crypto: nil,
  customer_balance: nil,
  eps: nil,
  fpx: nil,
  giropay: nil,
  gopay: nil,
  grabpay: nil,
  id_bank_transfer: nil,
  ideal: nil,
  interac_present: nil,
  kakao_pay: nil,
  klarna: nil,
  konbini: nil,
  kr_card: nil,
  link: nil,
  mb_way: nil,
  metadata: nil,
  mobilepay: nil,
  multibanco: nil,
  naver_pay: nil,
  nz_bank_account: nil,
  oxxo: nil,
  p24: nil,
  pay_by_bank: nil,
  payco: nil,
  paynow: nil,
  paypal: nil,
  payto: nil,
  pix: nil,
  promptpay: nil,
  qris: nil,
  radar_options: nil,
  rechnung: nil,
  revolut_pay: nil,
  samsung_pay: nil,
  satispay: nil,
  sepa_debit: nil,
  shopeepay: nil,
  sofort: nil,
  stripe_balance: nil,
  swish: nil,
  twint: nil,
  type: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @allow_redisplay = allow_redisplay
  @alma = alma
  @amazon_pay = amazon_pay
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @billie = billie
  @billing_details = billing_details
  @blik = blik
  @boleto = boleto
  @cashapp = cashapp
  @crypto = crypto
  @customer_balance = customer_balance
  @eps = eps
  @fpx = fpx
  @giropay = giropay
  @gopay = gopay
  @grabpay = grabpay
  @id_bank_transfer = id_bank_transfer
  @ideal = ideal
  @interac_present = interac_present
  @kakao_pay = kakao_pay
  @klarna = klarna
  @konbini = konbini
  @kr_card = kr_card
  @link = link
  @mb_way = mb_way
  @metadata = 
  @mobilepay = mobilepay
  @multibanco = multibanco
  @naver_pay = naver_pay
  @nz_bank_account = 
  @oxxo = oxxo
  @p24 = p24
  @pay_by_bank = pay_by_bank
  @payco = payco
  @paynow = paynow
  @paypal = paypal
  @payto = payto
  @pix = pix
  @promptpay = promptpay
  @qris = qris
  @radar_options = radar_options
  @rechnung = rechnung
  @revolut_pay = revolut_pay
  @samsung_pay = samsung_pay
  @satispay = satispay
  @sepa_debit = sepa_debit
  @shopeepay = shopeepay
  @sofort = sofort
  @stripe_balance = stripe_balance
  @swish = swish
  @twint = twint
  @type = type
  @us_bank_account = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

If this is an ‘acss_debit` PaymentMethod, this hash contains details about the ACSS Debit payment method.



3372
3373
3374
# File 'lib/stripe/resources/payment_intent.rb', line 3372

def acss_debit
  @acss_debit
end

#affirmObject

If this is an ‘affirm` PaymentMethod, this hash contains details about the Affirm payment method.



3374
3375
3376
# File 'lib/stripe/resources/payment_intent.rb', line 3374

def affirm
  @affirm
end

#afterpay_clearpayObject

If this is an ‘AfterpayClearpay` PaymentMethod, this hash contains details about the AfterpayClearpay payment method.



3376
3377
3378
# File 'lib/stripe/resources/payment_intent.rb', line 3376

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If this is an ‘Alipay` PaymentMethod, this hash contains details about the Alipay payment method.



3378
3379
3380
# File 'lib/stripe/resources/payment_intent.rb', line 3378

def alipay
  @alipay
end

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.



3380
3381
3382
# File 'lib/stripe/resources/payment_intent.rb', line 3380

def allow_redisplay
  @allow_redisplay
end

#almaObject

If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.



3382
3383
3384
# File 'lib/stripe/resources/payment_intent.rb', line 3382

def alma
  @alma
end

#amazon_payObject

If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.



3384
3385
3386
# File 'lib/stripe/resources/payment_intent.rb', line 3384

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject

If this is an ‘au_becs_debit` PaymentMethod, this hash contains details about the bank account.



3386
3387
3388
# File 'lib/stripe/resources/payment_intent.rb', line 3386

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

If this is a ‘bacs_debit` PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.



3388
3389
3390
# File 'lib/stripe/resources/payment_intent.rb', line 3388

def bacs_debit
  @bacs_debit
end

#bancontactObject

If this is a ‘bancontact` PaymentMethod, this hash contains details about the Bancontact payment method.



3390
3391
3392
# File 'lib/stripe/resources/payment_intent.rb', line 3390

def bancontact
  @bancontact
end

#billieObject

If this is a ‘billie` PaymentMethod, this hash contains details about the Billie payment method.



3392
3393
3394
# File 'lib/stripe/resources/payment_intent.rb', line 3392

def billie
  @billie
end

#billing_detailsObject

Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.



3394
3395
3396
# File 'lib/stripe/resources/payment_intent.rb', line 3394

def billing_details
  @billing_details
end

#blikObject

If this is a ‘blik` PaymentMethod, this hash contains details about the BLIK payment method.



3396
3397
3398
# File 'lib/stripe/resources/payment_intent.rb', line 3396

def blik
  @blik
end

#boletoObject

If this is a ‘boleto` PaymentMethod, this hash contains details about the Boleto payment method.



3398
3399
3400
# File 'lib/stripe/resources/payment_intent.rb', line 3398

def boleto
  @boleto
end

#cashappObject

If this is a ‘cashapp` PaymentMethod, this hash contains details about the Cash App Pay payment method.



3400
3401
3402
# File 'lib/stripe/resources/payment_intent.rb', line 3400

def cashapp
  @cashapp
end

#cryptoObject

If this is a Crypto PaymentMethod, this hash contains details about the Crypto payment method.



3402
3403
3404
# File 'lib/stripe/resources/payment_intent.rb', line 3402

def crypto
  @crypto
end

#customer_balanceObject

If this is a ‘customer_balance` PaymentMethod, this hash contains details about the CustomerBalance payment method.



3404
3405
3406
# File 'lib/stripe/resources/payment_intent.rb', line 3404

def customer_balance
  @customer_balance
end

#epsObject

If this is an ‘eps` PaymentMethod, this hash contains details about the EPS payment method.



3406
3407
3408
# File 'lib/stripe/resources/payment_intent.rb', line 3406

def eps
  @eps
end

#fpxObject

If this is an ‘fpx` PaymentMethod, this hash contains details about the FPX payment method.



3408
3409
3410
# File 'lib/stripe/resources/payment_intent.rb', line 3408

def fpx
  @fpx
end

#giropayObject

If this is a ‘giropay` PaymentMethod, this hash contains details about the Giropay payment method.



3410
3411
3412
# File 'lib/stripe/resources/payment_intent.rb', line 3410

def giropay
  @giropay
end

#gopayObject

If this is a Gopay PaymentMethod, this hash contains details about the Gopay payment method.



3412
3413
3414
# File 'lib/stripe/resources/payment_intent.rb', line 3412

def gopay
  @gopay
end

#grabpayObject

If this is a ‘grabpay` PaymentMethod, this hash contains details about the GrabPay payment method.



3414
3415
3416
# File 'lib/stripe/resources/payment_intent.rb', line 3414

def grabpay
  @grabpay
end

#id_bank_transferObject

If this is an ‘IdBankTransfer` PaymentMethod, this hash contains details about the IdBankTransfer payment method.



3416
3417
3418
# File 'lib/stripe/resources/payment_intent.rb', line 3416

def id_bank_transfer
  @id_bank_transfer
end

#idealObject

If this is an ‘ideal` PaymentMethod, this hash contains details about the iDEAL payment method.



3418
3419
3420
# File 'lib/stripe/resources/payment_intent.rb', line 3418

def ideal
  @ideal
end

#interac_presentObject

If this is an ‘interac_present` PaymentMethod, this hash contains details about the Interac Present payment method.



3420
3421
3422
# File 'lib/stripe/resources/payment_intent.rb', line 3420

def interac_present
  @interac_present
end

#kakao_payObject

If this is a ‘kakao_pay` PaymentMethod, this hash contains details about the Kakao Pay payment method.



3422
3423
3424
# File 'lib/stripe/resources/payment_intent.rb', line 3422

def kakao_pay
  @kakao_pay
end

#klarnaObject

If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method.



3424
3425
3426
# File 'lib/stripe/resources/payment_intent.rb', line 3424

def klarna
  @klarna
end

#konbiniObject

If this is a ‘konbini` PaymentMethod, this hash contains details about the Konbini payment method.



3426
3427
3428
# File 'lib/stripe/resources/payment_intent.rb', line 3426

def konbini
  @konbini
end

#kr_cardObject

If this is a ‘kr_card` PaymentMethod, this hash contains details about the Korean Card payment method.



3428
3429
3430
# File 'lib/stripe/resources/payment_intent.rb', line 3428

def kr_card
  @kr_card
end

If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.



3430
3431
3432
# File 'lib/stripe/resources/payment_intent.rb', line 3430

def link
  @link
end

#mb_wayObject

If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.



3432
3433
3434
# File 'lib/stripe/resources/payment_intent.rb', line 3432

def mb_way
  @mb_way
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3434
3435
3436
# File 'lib/stripe/resources/payment_intent.rb', line 3434

def 
  @metadata
end

#mobilepayObject

If this is a ‘mobilepay` PaymentMethod, this hash contains details about the MobilePay payment method.



3436
3437
3438
# File 'lib/stripe/resources/payment_intent.rb', line 3436

def mobilepay
  @mobilepay
end

#multibancoObject

If this is a ‘multibanco` PaymentMethod, this hash contains details about the Multibanco payment method.



3438
3439
3440
# File 'lib/stripe/resources/payment_intent.rb', line 3438

def multibanco
  @multibanco
end

If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.



3440
3441
3442
# File 'lib/stripe/resources/payment_intent.rb', line 3440

def naver_pay
  @naver_pay
end

#nz_bank_accountObject

If this is an nz_bank_account PaymentMethod, this hash contains details about the nz_bank_account payment method.



3442
3443
3444
# File 'lib/stripe/resources/payment_intent.rb', line 3442

def 
  @nz_bank_account
end

#oxxoObject

If this is an ‘oxxo` PaymentMethod, this hash contains details about the OXXO payment method.



3444
3445
3446
# File 'lib/stripe/resources/payment_intent.rb', line 3444

def oxxo
  @oxxo
end

#p24Object

If this is a ‘p24` PaymentMethod, this hash contains details about the P24 payment method.



3446
3447
3448
# File 'lib/stripe/resources/payment_intent.rb', line 3446

def p24
  @p24
end

#pay_by_bankObject

If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.



3448
3449
3450
# File 'lib/stripe/resources/payment_intent.rb', line 3448

def pay_by_bank
  @pay_by_bank
end

#paycoObject

If this is a ‘payco` PaymentMethod, this hash contains details about the PAYCO payment method.



3450
3451
3452
# File 'lib/stripe/resources/payment_intent.rb', line 3450

def payco
  @payco
end

#paynowObject

If this is a ‘paynow` PaymentMethod, this hash contains details about the PayNow payment method.



3452
3453
3454
# File 'lib/stripe/resources/payment_intent.rb', line 3452

def paynow
  @paynow
end

#paypalObject

If this is a ‘paypal` PaymentMethod, this hash contains details about the PayPal payment method.



3454
3455
3456
# File 'lib/stripe/resources/payment_intent.rb', line 3454

def paypal
  @paypal
end

#paytoObject

If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.



3456
3457
3458
# File 'lib/stripe/resources/payment_intent.rb', line 3456

def payto
  @payto
end

#pixObject

If this is a ‘pix` PaymentMethod, this hash contains details about the Pix payment method.



3458
3459
3460
# File 'lib/stripe/resources/payment_intent.rb', line 3458

def pix
  @pix
end

#promptpayObject

If this is a ‘promptpay` PaymentMethod, this hash contains details about the PromptPay payment method.



3460
3461
3462
# File 'lib/stripe/resources/payment_intent.rb', line 3460

def promptpay
  @promptpay
end

#qrisObject

If this is a ‘qris` PaymentMethod, this hash contains details about the QRIS payment method.



3462
3463
3464
# File 'lib/stripe/resources/payment_intent.rb', line 3462

def qris
  @qris
end

#radar_optionsObject

Options to configure Radar. See [Radar Session](stripe.com/docs/radar/radar-session) for more information.



3464
3465
3466
# File 'lib/stripe/resources/payment_intent.rb', line 3464

def radar_options
  @radar_options
end

#rechnungObject

If this is a ‘rechnung` PaymentMethod, this hash contains details about the Rechnung payment method.



3466
3467
3468
# File 'lib/stripe/resources/payment_intent.rb', line 3466

def rechnung
  @rechnung
end

#revolut_payObject

If this is a ‘revolut_pay` PaymentMethod, this hash contains details about the Revolut Pay payment method.



3468
3469
3470
# File 'lib/stripe/resources/payment_intent.rb', line 3468

def revolut_pay
  @revolut_pay
end

#samsung_payObject

If this is a ‘samsung_pay` PaymentMethod, this hash contains details about the SamsungPay payment method.



3470
3471
3472
# File 'lib/stripe/resources/payment_intent.rb', line 3470

def samsung_pay
  @samsung_pay
end

#satispayObject

If this is a ‘satispay` PaymentMethod, this hash contains details about the Satispay payment method.



3472
3473
3474
# File 'lib/stripe/resources/payment_intent.rb', line 3472

def satispay
  @satispay
end

#sepa_debitObject

If this is a ‘sepa_debit` PaymentMethod, this hash contains details about the SEPA debit bank account.



3474
3475
3476
# File 'lib/stripe/resources/payment_intent.rb', line 3474

def sepa_debit
  @sepa_debit
end

#shopeepayObject

If this is a Shopeepay PaymentMethod, this hash contains details about the Shopeepay payment method.



3476
3477
3478
# File 'lib/stripe/resources/payment_intent.rb', line 3476

def shopeepay
  @shopeepay
end

#sofortObject

If this is a ‘sofort` PaymentMethod, this hash contains details about the SOFORT payment method.



3478
3479
3480
# File 'lib/stripe/resources/payment_intent.rb', line 3478

def sofort
  @sofort
end

#stripe_balanceObject

This hash contains details about the Stripe balance payment method.



3480
3481
3482
# File 'lib/stripe/resources/payment_intent.rb', line 3480

def stripe_balance
  @stripe_balance
end

#swishObject

If this is a ‘swish` PaymentMethod, this hash contains details about the Swish payment method.



3482
3483
3484
# File 'lib/stripe/resources/payment_intent.rb', line 3482

def swish
  @swish
end

#twintObject

If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.



3484
3485
3486
# File 'lib/stripe/resources/payment_intent.rb', line 3484

def twint
  @twint
end

#typeObject

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



3486
3487
3488
# File 'lib/stripe/resources/payment_intent.rb', line 3486

def type
  @type
end

#us_bank_accountObject

If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.



3488
3489
3490
# File 'lib/stripe/resources/payment_intent.rb', line 3488

def 
  @us_bank_account
end

#wechat_payObject

If this is an ‘wechat_pay` PaymentMethod, this hash contains details about the wechat_pay payment method.



3490
3491
3492
# File 'lib/stripe/resources/payment_intent.rb', line 3490

def wechat_pay
  @wechat_pay
end

#zipObject

If this is a ‘zip` PaymentMethod, this hash contains details about the Zip payment method.



3492
3493
3494
# File 'lib/stripe/resources/payment_intent.rb', line 3492

def zip
  @zip
end