Class: Stripe::PaymentIntent::CreateParams::PaymentMethodData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, BillingDetails, Blik, Boleto, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, Oxxo, P24, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, RadarOptions, Rechnung, RevolutPay, SamsungPay, SepaDebit, Shopeepay, Sofort, Swish, Twint, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billing_details: nil, blik: nil, boleto: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, oxxo: nil, p24: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, radar_options: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, swish: nil, twint: nil, type: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodData

Returns a new instance of PaymentMethodData.



3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
3812
3813
3814
3815
3816
3817
3818
3819
3820
3821
3822
3823
3824
3825
3826
3827
3828
3829
3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/stripe/resources/payment_intent.rb', line 3742

def initialize(
  acss_debit: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  allow_redisplay: nil,
  alma: nil,
  amazon_pay: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  billing_details: nil,
  blik: nil,
  boleto: nil,
  cashapp: nil,
  customer_balance: nil,
  eps: nil,
  fpx: nil,
  giropay: nil,
  gopay: nil,
  grabpay: nil,
  id_bank_transfer: nil,
  ideal: nil,
  interac_present: nil,
  kakao_pay: nil,
  klarna: nil,
  konbini: nil,
  kr_card: nil,
  link: nil,
  mb_way: nil,
  metadata: nil,
  mobilepay: nil,
  multibanco: nil,
  naver_pay: nil,
  oxxo: nil,
  p24: nil,
  payco: nil,
  paynow: nil,
  paypal: nil,
  payto: nil,
  pix: nil,
  promptpay: nil,
  qris: nil,
  radar_options: nil,
  rechnung: nil,
  revolut_pay: nil,
  samsung_pay: nil,
  sepa_debit: nil,
  shopeepay: nil,
  sofort: nil,
  swish: nil,
  twint: nil,
  type: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @allow_redisplay = allow_redisplay
  @alma = alma
  @amazon_pay = amazon_pay
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @billing_details = billing_details
  @blik = blik
  @boleto = boleto
  @cashapp = cashapp
  @customer_balance = customer_balance
  @eps = eps
  @fpx = fpx
  @giropay = giropay
  @gopay = gopay
  @grabpay = grabpay
  @id_bank_transfer = id_bank_transfer
  @ideal = ideal
  @interac_present = interac_present
  @kakao_pay = kakao_pay
  @klarna = klarna
  @konbini = konbini
  @kr_card = kr_card
  @link = link
  @mb_way = mb_way
  @metadata = 
  @mobilepay = mobilepay
  @multibanco = multibanco
  @naver_pay = naver_pay
  @oxxo = oxxo
  @p24 = p24
  @payco = payco
  @paynow = paynow
  @paypal = paypal
  @payto = payto
  @pix = pix
  @promptpay = promptpay
  @qris = qris
  @radar_options = radar_options
  @rechnung = rechnung
  @revolut_pay = revolut_pay
  @samsung_pay = samsung_pay
  @sepa_debit = sepa_debit
  @shopeepay = shopeepay
  @sofort = sofort
  @swish = swish
  @twint = twint
  @type = type
  @us_bank_account = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

If this is an ‘acss_debit` PaymentMethod, this hash contains details about the ACSS Debit payment method.



3578
3579
3580
# File 'lib/stripe/resources/payment_intent.rb', line 3578

def acss_debit
  @acss_debit
end

#affirmObject

If this is an ‘affirm` PaymentMethod, this hash contains details about the Affirm payment method.



3581
3582
3583
# File 'lib/stripe/resources/payment_intent.rb', line 3581

def affirm
  @affirm
end

#afterpay_clearpayObject

If this is an ‘AfterpayClearpay` PaymentMethod, this hash contains details about the AfterpayClearpay payment method.



3584
3585
3586
# File 'lib/stripe/resources/payment_intent.rb', line 3584

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If this is an ‘Alipay` PaymentMethod, this hash contains details about the Alipay payment method.



3587
3588
3589
# File 'lib/stripe/resources/payment_intent.rb', line 3587

def alipay
  @alipay
end

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.



3590
3591
3592
# File 'lib/stripe/resources/payment_intent.rb', line 3590

def allow_redisplay
  @allow_redisplay
end

#almaObject

If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.



3593
3594
3595
# File 'lib/stripe/resources/payment_intent.rb', line 3593

def alma
  @alma
end

#amazon_payObject

If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.



3596
3597
3598
# File 'lib/stripe/resources/payment_intent.rb', line 3596

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject

If this is an ‘au_becs_debit` PaymentMethod, this hash contains details about the bank account.



3599
3600
3601
# File 'lib/stripe/resources/payment_intent.rb', line 3599

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

If this is a ‘bacs_debit` PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.



3602
3603
3604
# File 'lib/stripe/resources/payment_intent.rb', line 3602

def bacs_debit
  @bacs_debit
end

#bancontactObject

If this is a ‘bancontact` PaymentMethod, this hash contains details about the Bancontact payment method.



3605
3606
3607
# File 'lib/stripe/resources/payment_intent.rb', line 3605

def bancontact
  @bancontact
end

#billing_detailsObject

Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.



3608
3609
3610
# File 'lib/stripe/resources/payment_intent.rb', line 3608

def billing_details
  @billing_details
end

#blikObject

If this is a ‘blik` PaymentMethod, this hash contains details about the BLIK payment method.



3611
3612
3613
# File 'lib/stripe/resources/payment_intent.rb', line 3611

def blik
  @blik
end

#boletoObject

If this is a ‘boleto` PaymentMethod, this hash contains details about the Boleto payment method.



3614
3615
3616
# File 'lib/stripe/resources/payment_intent.rb', line 3614

def boleto
  @boleto
end

#cashappObject

If this is a ‘cashapp` PaymentMethod, this hash contains details about the Cash App Pay payment method.



3617
3618
3619
# File 'lib/stripe/resources/payment_intent.rb', line 3617

def cashapp
  @cashapp
end

#customer_balanceObject

If this is a ‘customer_balance` PaymentMethod, this hash contains details about the CustomerBalance payment method.



3620
3621
3622
# File 'lib/stripe/resources/payment_intent.rb', line 3620

def customer_balance
  @customer_balance
end

#epsObject

If this is an ‘eps` PaymentMethod, this hash contains details about the EPS payment method.



3623
3624
3625
# File 'lib/stripe/resources/payment_intent.rb', line 3623

def eps
  @eps
end

#fpxObject

If this is an ‘fpx` PaymentMethod, this hash contains details about the FPX payment method.



3626
3627
3628
# File 'lib/stripe/resources/payment_intent.rb', line 3626

def fpx
  @fpx
end

#giropayObject

If this is a ‘giropay` PaymentMethod, this hash contains details about the Giropay payment method.



3629
3630
3631
# File 'lib/stripe/resources/payment_intent.rb', line 3629

def giropay
  @giropay
end

#gopayObject

If this is a Gopay PaymentMethod, this hash contains details about the Gopay payment method.



3632
3633
3634
# File 'lib/stripe/resources/payment_intent.rb', line 3632

def gopay
  @gopay
end

#grabpayObject

If this is a ‘grabpay` PaymentMethod, this hash contains details about the GrabPay payment method.



3635
3636
3637
# File 'lib/stripe/resources/payment_intent.rb', line 3635

def grabpay
  @grabpay
end

#id_bank_transferObject

If this is an ‘IdBankTransfer` PaymentMethod, this hash contains details about the IdBankTransfer payment method.



3638
3639
3640
# File 'lib/stripe/resources/payment_intent.rb', line 3638

def id_bank_transfer
  @id_bank_transfer
end

#idealObject

If this is an ‘ideal` PaymentMethod, this hash contains details about the iDEAL payment method.



3641
3642
3643
# File 'lib/stripe/resources/payment_intent.rb', line 3641

def ideal
  @ideal
end

#interac_presentObject

If this is an ‘interac_present` PaymentMethod, this hash contains details about the Interac Present payment method.



3644
3645
3646
# File 'lib/stripe/resources/payment_intent.rb', line 3644

def interac_present
  @interac_present
end

#kakao_payObject

If this is a ‘kakao_pay` PaymentMethod, this hash contains details about the Kakao Pay payment method.



3647
3648
3649
# File 'lib/stripe/resources/payment_intent.rb', line 3647

def kakao_pay
  @kakao_pay
end

#klarnaObject

If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method.



3650
3651
3652
# File 'lib/stripe/resources/payment_intent.rb', line 3650

def klarna
  @klarna
end

#konbiniObject

If this is a ‘konbini` PaymentMethod, this hash contains details about the Konbini payment method.



3653
3654
3655
# File 'lib/stripe/resources/payment_intent.rb', line 3653

def konbini
  @konbini
end

#kr_cardObject

If this is a ‘kr_card` PaymentMethod, this hash contains details about the Korean Card payment method.



3656
3657
3658
# File 'lib/stripe/resources/payment_intent.rb', line 3656

def kr_card
  @kr_card
end

If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.



3659
3660
3661
# File 'lib/stripe/resources/payment_intent.rb', line 3659

def link
  @link
end

#mb_wayObject

If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.



3662
3663
3664
# File 'lib/stripe/resources/payment_intent.rb', line 3662

def mb_way
  @mb_way
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3665
3666
3667
# File 'lib/stripe/resources/payment_intent.rb', line 3665

def 
  @metadata
end

#mobilepayObject

If this is a ‘mobilepay` PaymentMethod, this hash contains details about the MobilePay payment method.



3668
3669
3670
# File 'lib/stripe/resources/payment_intent.rb', line 3668

def mobilepay
  @mobilepay
end

#multibancoObject

If this is a ‘multibanco` PaymentMethod, this hash contains details about the Multibanco payment method.



3671
3672
3673
# File 'lib/stripe/resources/payment_intent.rb', line 3671

def multibanco
  @multibanco
end

If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.



3674
3675
3676
# File 'lib/stripe/resources/payment_intent.rb', line 3674

def naver_pay
  @naver_pay
end

#oxxoObject

If this is an ‘oxxo` PaymentMethod, this hash contains details about the OXXO payment method.



3677
3678
3679
# File 'lib/stripe/resources/payment_intent.rb', line 3677

def oxxo
  @oxxo
end

#p24Object

If this is a ‘p24` PaymentMethod, this hash contains details about the P24 payment method.



3680
3681
3682
# File 'lib/stripe/resources/payment_intent.rb', line 3680

def p24
  @p24
end

#paycoObject

If this is a ‘payco` PaymentMethod, this hash contains details about the PAYCO payment method.



3683
3684
3685
# File 'lib/stripe/resources/payment_intent.rb', line 3683

def payco
  @payco
end

#paynowObject

If this is a ‘paynow` PaymentMethod, this hash contains details about the PayNow payment method.



3686
3687
3688
# File 'lib/stripe/resources/payment_intent.rb', line 3686

def paynow
  @paynow
end

#paypalObject

If this is a ‘paypal` PaymentMethod, this hash contains details about the PayPal payment method.



3689
3690
3691
# File 'lib/stripe/resources/payment_intent.rb', line 3689

def paypal
  @paypal
end

#paytoObject

If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.



3692
3693
3694
# File 'lib/stripe/resources/payment_intent.rb', line 3692

def payto
  @payto
end

#pixObject

If this is a ‘pix` PaymentMethod, this hash contains details about the Pix payment method.



3695
3696
3697
# File 'lib/stripe/resources/payment_intent.rb', line 3695

def pix
  @pix
end

#promptpayObject

If this is a ‘promptpay` PaymentMethod, this hash contains details about the PromptPay payment method.



3698
3699
3700
# File 'lib/stripe/resources/payment_intent.rb', line 3698

def promptpay
  @promptpay
end

#qrisObject

If this is a ‘qris` PaymentMethod, this hash contains details about the QRIS payment method.



3701
3702
3703
# File 'lib/stripe/resources/payment_intent.rb', line 3701

def qris
  @qris
end

#radar_optionsObject

Options to configure Radar. See [Radar Session](stripe.com/docs/radar/radar-session) for more information.



3704
3705
3706
# File 'lib/stripe/resources/payment_intent.rb', line 3704

def radar_options
  @radar_options
end

#rechnungObject

If this is a ‘rechnung` PaymentMethod, this hash contains details about the Rechnung payment method.



3707
3708
3709
# File 'lib/stripe/resources/payment_intent.rb', line 3707

def rechnung
  @rechnung
end

#revolut_payObject

If this is a ‘Revolut Pay` PaymentMethod, this hash contains details about the Revolut Pay payment method.



3710
3711
3712
# File 'lib/stripe/resources/payment_intent.rb', line 3710

def revolut_pay
  @revolut_pay
end

#samsung_payObject

If this is a ‘samsung_pay` PaymentMethod, this hash contains details about the SamsungPay payment method.



3713
3714
3715
# File 'lib/stripe/resources/payment_intent.rb', line 3713

def samsung_pay
  @samsung_pay
end

#sepa_debitObject

If this is a ‘sepa_debit` PaymentMethod, this hash contains details about the SEPA debit bank account.



3716
3717
3718
# File 'lib/stripe/resources/payment_intent.rb', line 3716

def sepa_debit
  @sepa_debit
end

#shopeepayObject

If this is a Shopeepay PaymentMethod, this hash contains details about the Shopeepay payment method.



3719
3720
3721
# File 'lib/stripe/resources/payment_intent.rb', line 3719

def shopeepay
  @shopeepay
end

#sofortObject

If this is a ‘sofort` PaymentMethod, this hash contains details about the SOFORT payment method.



3722
3723
3724
# File 'lib/stripe/resources/payment_intent.rb', line 3722

def sofort
  @sofort
end

#swishObject

If this is a ‘swish` PaymentMethod, this hash contains details about the Swish payment method.



3725
3726
3727
# File 'lib/stripe/resources/payment_intent.rb', line 3725

def swish
  @swish
end

#twintObject

If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.



3728
3729
3730
# File 'lib/stripe/resources/payment_intent.rb', line 3728

def twint
  @twint
end

#typeObject

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



3731
3732
3733
# File 'lib/stripe/resources/payment_intent.rb', line 3731

def type
  @type
end

#us_bank_accountObject

If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.



3734
3735
3736
# File 'lib/stripe/resources/payment_intent.rb', line 3734

def 
  @us_bank_account
end

#wechat_payObject

If this is an ‘wechat_pay` PaymentMethod, this hash contains details about the wechat_pay payment method.



3737
3738
3739
# File 'lib/stripe/resources/payment_intent.rb', line 3737

def wechat_pay
  @wechat_pay
end

#zipObject

If this is a ‘zip` PaymentMethod, this hash contains details about the Zip payment method.



3740
3741
3742
# File 'lib/stripe/resources/payment_intent.rb', line 3740

def zip
  @zip
end