Class: Stripe::PaymentIntent::CreateParams::PaymentMethodData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodData
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, BillingDetails, Blik, Boleto, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, Oxxo, P24, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, RadarOptions, Rechnung, RevolutPay, SamsungPay, SepaDebit, Shopeepay, Sofort, Swish, Twint, UsBankAccount, WechatPay, Zip
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If this is an ‘acss_debit` PaymentMethod, this hash contains details about the ACSS Debit payment method.
-
#affirm ⇒ Object
If this is an ‘affirm` PaymentMethod, this hash contains details about the Affirm payment method.
-
#afterpay_clearpay ⇒ Object
If this is an ‘AfterpayClearpay` PaymentMethod, this hash contains details about the AfterpayClearpay payment method.
-
#alipay ⇒ Object
If this is an ‘Alipay` PaymentMethod, this hash contains details about the Alipay payment method.
-
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#alma ⇒ Object
If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.
-
#amazon_pay ⇒ Object
If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.
-
#au_becs_debit ⇒ Object
If this is an ‘au_becs_debit` PaymentMethod, this hash contains details about the bank account.
-
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.
-
#bancontact ⇒ Object
If this is a ‘bancontact` PaymentMethod, this hash contains details about the Bancontact payment method.
-
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
-
#blik ⇒ Object
If this is a ‘blik` PaymentMethod, this hash contains details about the BLIK payment method.
-
#boleto ⇒ Object
If this is a ‘boleto` PaymentMethod, this hash contains details about the Boleto payment method.
-
#cashapp ⇒ Object
If this is a ‘cashapp` PaymentMethod, this hash contains details about the Cash App Pay payment method.
-
#customer_balance ⇒ Object
If this is a ‘customer_balance` PaymentMethod, this hash contains details about the CustomerBalance payment method.
-
#eps ⇒ Object
If this is an ‘eps` PaymentMethod, this hash contains details about the EPS payment method.
-
#fpx ⇒ Object
If this is an ‘fpx` PaymentMethod, this hash contains details about the FPX payment method.
-
#giropay ⇒ Object
If this is a ‘giropay` PaymentMethod, this hash contains details about the Giropay payment method.
-
#gopay ⇒ Object
If this is a Gopay PaymentMethod, this hash contains details about the Gopay payment method.
-
#grabpay ⇒ Object
If this is a ‘grabpay` PaymentMethod, this hash contains details about the GrabPay payment method.
-
#id_bank_transfer ⇒ Object
If this is an ‘IdBankTransfer` PaymentMethod, this hash contains details about the IdBankTransfer payment method.
-
#ideal ⇒ Object
If this is an ‘ideal` PaymentMethod, this hash contains details about the iDEAL payment method.
-
#interac_present ⇒ Object
If this is an ‘interac_present` PaymentMethod, this hash contains details about the Interac Present payment method.
-
#kakao_pay ⇒ Object
If this is a ‘kakao_pay` PaymentMethod, this hash contains details about the Kakao Pay payment method.
-
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method.
-
#konbini ⇒ Object
If this is a ‘konbini` PaymentMethod, this hash contains details about the Konbini payment method.
-
#kr_card ⇒ Object
If this is a ‘kr_card` PaymentMethod, this hash contains details about the Korean Card payment method.
-
#link ⇒ Object
If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.
-
#mb_way ⇒ Object
If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#mobilepay ⇒ Object
If this is a ‘mobilepay` PaymentMethod, this hash contains details about the MobilePay payment method.
-
#multibanco ⇒ Object
If this is a ‘multibanco` PaymentMethod, this hash contains details about the Multibanco payment method.
-
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.
-
#oxxo ⇒ Object
If this is an ‘oxxo` PaymentMethod, this hash contains details about the OXXO payment method.
-
#p24 ⇒ Object
If this is a ‘p24` PaymentMethod, this hash contains details about the P24 payment method.
-
#payco ⇒ Object
If this is a ‘payco` PaymentMethod, this hash contains details about the PAYCO payment method.
-
#paynow ⇒ Object
If this is a ‘paynow` PaymentMethod, this hash contains details about the PayNow payment method.
-
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this hash contains details about the PayPal payment method.
-
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.
-
#pix ⇒ Object
If this is a ‘pix` PaymentMethod, this hash contains details about the Pix payment method.
-
#promptpay ⇒ Object
If this is a ‘promptpay` PaymentMethod, this hash contains details about the PromptPay payment method.
-
#qris ⇒ Object
If this is a ‘qris` PaymentMethod, this hash contains details about the QRIS payment method.
-
#radar_options ⇒ Object
Options to configure Radar.
-
#rechnung ⇒ Object
If this is a ‘rechnung` PaymentMethod, this hash contains details about the Rechnung payment method.
-
#revolut_pay ⇒ Object
If this is a ‘Revolut Pay` PaymentMethod, this hash contains details about the Revolut Pay payment method.
-
#samsung_pay ⇒ Object
If this is a ‘samsung_pay` PaymentMethod, this hash contains details about the SamsungPay payment method.
-
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` PaymentMethod, this hash contains details about the SEPA debit bank account.
-
#shopeepay ⇒ Object
If this is a Shopeepay PaymentMethod, this hash contains details about the Shopeepay payment method.
-
#sofort ⇒ Object
If this is a ‘sofort` PaymentMethod, this hash contains details about the SOFORT payment method.
-
#swish ⇒ Object
If this is a ‘swish` PaymentMethod, this hash contains details about the Swish payment method.
-
#twint ⇒ Object
If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.
-
#type ⇒ Object
The type of the PaymentMethod.
-
#us_bank_account ⇒ Object
If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.
-
#wechat_pay ⇒ Object
If this is an ‘wechat_pay` PaymentMethod, this hash contains details about the wechat_pay payment method.
-
#zip ⇒ Object
If this is a ‘zip` PaymentMethod, this hash contains details about the Zip payment method.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billing_details: nil, blik: nil, boleto: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, oxxo: nil, p24: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, radar_options: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, swish: nil, twint: nil, type: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodData
Returns a new instance of PaymentMethodData.
3134 3135 3136 3137 3138 3139 3140 3141 3142 3143 3144 3145 3146 3147 3148 3149 3150 3151 3152 3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 3165 3166 3167 3168 3169 3170 3171 3172 3173 3174 3175 3176 3177 3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 3196 3197 3198 3199 3200 3201 3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 3213 3214 3215 3216 3217 3218 3219 3220 3221 3222 3223 3224 3225 3226 3227 3228 3229 3230 3231 3232 3233 3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 |
# File 'lib/stripe/resources/payment_intent.rb', line 3134 def initialize( acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billing_details: nil, blik: nil, boleto: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, oxxo: nil, p24: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, radar_options: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, swish: nil, twint: nil, type: nil, us_bank_account: nil, wechat_pay: nil, zip: nil ) @acss_debit = acss_debit @affirm = affirm @afterpay_clearpay = afterpay_clearpay @alipay = alipay @allow_redisplay = allow_redisplay @alma = alma @amazon_pay = amazon_pay @au_becs_debit = au_becs_debit @bacs_debit = bacs_debit @bancontact = bancontact @billing_details = billing_details @blik = blik @boleto = boleto @cashapp = cashapp @customer_balance = customer_balance @eps = eps @fpx = fpx @giropay = giropay @gopay = gopay @grabpay = grabpay @id_bank_transfer = id_bank_transfer @ideal = ideal @interac_present = interac_present @kakao_pay = kakao_pay @klarna = klarna @konbini = konbini @kr_card = kr_card @link = link @mb_way = mb_way @metadata = @mobilepay = mobilepay @multibanco = multibanco @naver_pay = naver_pay @oxxo = oxxo @p24 = p24 @payco = payco @paynow = paynow @paypal = paypal @payto = payto @pix = pix @promptpay = promptpay @qris = qris @radar_options = @rechnung = rechnung @revolut_pay = revolut_pay @samsung_pay = samsung_pay @sepa_debit = sepa_debit @shopeepay = shopeepay @sofort = sofort @swish = swish @twint = twint @type = type @us_bank_account = us_bank_account @wechat_pay = wechat_pay @zip = zip end |
Instance Attribute Details
#acss_debit ⇒ Object
If this is an ‘acss_debit` PaymentMethod, this hash contains details about the ACSS Debit payment method.
3024 3025 3026 |
# File 'lib/stripe/resources/payment_intent.rb', line 3024 def acss_debit @acss_debit end |
#affirm ⇒ Object
If this is an ‘affirm` PaymentMethod, this hash contains details about the Affirm payment method.
3026 3027 3028 |
# File 'lib/stripe/resources/payment_intent.rb', line 3026 def affirm @affirm end |
#afterpay_clearpay ⇒ Object
If this is an ‘AfterpayClearpay` PaymentMethod, this hash contains details about the AfterpayClearpay payment method.
3028 3029 3030 |
# File 'lib/stripe/resources/payment_intent.rb', line 3028 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
If this is an ‘Alipay` PaymentMethod, this hash contains details about the Alipay payment method.
3030 3031 3032 |
# File 'lib/stripe/resources/payment_intent.rb', line 3030 def alipay @alipay end |
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.
3032 3033 3034 |
# File 'lib/stripe/resources/payment_intent.rb', line 3032 def allow_redisplay @allow_redisplay end |
#alma ⇒ Object
If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.
3034 3035 3036 |
# File 'lib/stripe/resources/payment_intent.rb', line 3034 def alma @alma end |
#amazon_pay ⇒ Object
If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.
3036 3037 3038 |
# File 'lib/stripe/resources/payment_intent.rb', line 3036 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object
If this is an ‘au_becs_debit` PaymentMethod, this hash contains details about the bank account.
3038 3039 3040 |
# File 'lib/stripe/resources/payment_intent.rb', line 3038 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.
3040 3041 3042 |
# File 'lib/stripe/resources/payment_intent.rb', line 3040 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object
If this is a ‘bancontact` PaymentMethod, this hash contains details about the Bancontact payment method.
3042 3043 3044 |
# File 'lib/stripe/resources/payment_intent.rb', line 3042 def bancontact @bancontact end |
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
3044 3045 3046 |
# File 'lib/stripe/resources/payment_intent.rb', line 3044 def billing_details @billing_details end |
#blik ⇒ Object
If this is a ‘blik` PaymentMethod, this hash contains details about the BLIK payment method.
3046 3047 3048 |
# File 'lib/stripe/resources/payment_intent.rb', line 3046 def blik @blik end |
#boleto ⇒ Object
If this is a ‘boleto` PaymentMethod, this hash contains details about the Boleto payment method.
3048 3049 3050 |
# File 'lib/stripe/resources/payment_intent.rb', line 3048 def boleto @boleto end |
#cashapp ⇒ Object
If this is a ‘cashapp` PaymentMethod, this hash contains details about the Cash App Pay payment method.
3050 3051 3052 |
# File 'lib/stripe/resources/payment_intent.rb', line 3050 def cashapp @cashapp end |
#customer_balance ⇒ Object
If this is a ‘customer_balance` PaymentMethod, this hash contains details about the CustomerBalance payment method.
3052 3053 3054 |
# File 'lib/stripe/resources/payment_intent.rb', line 3052 def customer_balance @customer_balance end |
#eps ⇒ Object
If this is an ‘eps` PaymentMethod, this hash contains details about the EPS payment method.
3054 3055 3056 |
# File 'lib/stripe/resources/payment_intent.rb', line 3054 def eps @eps end |
#fpx ⇒ Object
If this is an ‘fpx` PaymentMethod, this hash contains details about the FPX payment method.
3056 3057 3058 |
# File 'lib/stripe/resources/payment_intent.rb', line 3056 def fpx @fpx end |
#giropay ⇒ Object
If this is a ‘giropay` PaymentMethod, this hash contains details about the Giropay payment method.
3058 3059 3060 |
# File 'lib/stripe/resources/payment_intent.rb', line 3058 def giropay @giropay end |
#gopay ⇒ Object
If this is a Gopay PaymentMethod, this hash contains details about the Gopay payment method.
3060 3061 3062 |
# File 'lib/stripe/resources/payment_intent.rb', line 3060 def gopay @gopay end |
#grabpay ⇒ Object
If this is a ‘grabpay` PaymentMethod, this hash contains details about the GrabPay payment method.
3062 3063 3064 |
# File 'lib/stripe/resources/payment_intent.rb', line 3062 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object
If this is an ‘IdBankTransfer` PaymentMethod, this hash contains details about the IdBankTransfer payment method.
3064 3065 3066 |
# File 'lib/stripe/resources/payment_intent.rb', line 3064 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object
If this is an ‘ideal` PaymentMethod, this hash contains details about the iDEAL payment method.
3066 3067 3068 |
# File 'lib/stripe/resources/payment_intent.rb', line 3066 def ideal @ideal end |
#interac_present ⇒ Object
If this is an ‘interac_present` PaymentMethod, this hash contains details about the Interac Present payment method.
3068 3069 3070 |
# File 'lib/stripe/resources/payment_intent.rb', line 3068 def interac_present @interac_present end |
#kakao_pay ⇒ Object
If this is a ‘kakao_pay` PaymentMethod, this hash contains details about the Kakao Pay payment method.
3070 3071 3072 |
# File 'lib/stripe/resources/payment_intent.rb', line 3070 def kakao_pay @kakao_pay end |
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method.
3072 3073 3074 |
# File 'lib/stripe/resources/payment_intent.rb', line 3072 def klarna @klarna end |
#konbini ⇒ Object
If this is a ‘konbini` PaymentMethod, this hash contains details about the Konbini payment method.
3074 3075 3076 |
# File 'lib/stripe/resources/payment_intent.rb', line 3074 def konbini @konbini end |
#kr_card ⇒ Object
If this is a ‘kr_card` PaymentMethod, this hash contains details about the Korean Card payment method.
3076 3077 3078 |
# File 'lib/stripe/resources/payment_intent.rb', line 3076 def kr_card @kr_card end |
#link ⇒ Object
If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.
3078 3079 3080 |
# File 'lib/stripe/resources/payment_intent.rb', line 3078 def link @link end |
#mb_way ⇒ Object
If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.
3080 3081 3082 |
# File 'lib/stripe/resources/payment_intent.rb', line 3080 def mb_way @mb_way end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
3082 3083 3084 |
# File 'lib/stripe/resources/payment_intent.rb', line 3082 def @metadata end |
#mobilepay ⇒ Object
If this is a ‘mobilepay` PaymentMethod, this hash contains details about the MobilePay payment method.
3084 3085 3086 |
# File 'lib/stripe/resources/payment_intent.rb', line 3084 def mobilepay @mobilepay end |
#multibanco ⇒ Object
If this is a ‘multibanco` PaymentMethod, this hash contains details about the Multibanco payment method.
3086 3087 3088 |
# File 'lib/stripe/resources/payment_intent.rb', line 3086 def multibanco @multibanco end |
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.
3088 3089 3090 |
# File 'lib/stripe/resources/payment_intent.rb', line 3088 def naver_pay @naver_pay end |
#oxxo ⇒ Object
If this is an ‘oxxo` PaymentMethod, this hash contains details about the OXXO payment method.
3090 3091 3092 |
# File 'lib/stripe/resources/payment_intent.rb', line 3090 def oxxo @oxxo end |
#p24 ⇒ Object
If this is a ‘p24` PaymentMethod, this hash contains details about the P24 payment method.
3092 3093 3094 |
# File 'lib/stripe/resources/payment_intent.rb', line 3092 def p24 @p24 end |
#payco ⇒ Object
If this is a ‘payco` PaymentMethod, this hash contains details about the PAYCO payment method.
3094 3095 3096 |
# File 'lib/stripe/resources/payment_intent.rb', line 3094 def payco @payco end |
#paynow ⇒ Object
If this is a ‘paynow` PaymentMethod, this hash contains details about the PayNow payment method.
3096 3097 3098 |
# File 'lib/stripe/resources/payment_intent.rb', line 3096 def paynow @paynow end |
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this hash contains details about the PayPal payment method.
3098 3099 3100 |
# File 'lib/stripe/resources/payment_intent.rb', line 3098 def paypal @paypal end |
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.
3100 3101 3102 |
# File 'lib/stripe/resources/payment_intent.rb', line 3100 def payto @payto end |
#pix ⇒ Object
If this is a ‘pix` PaymentMethod, this hash contains details about the Pix payment method.
3102 3103 3104 |
# File 'lib/stripe/resources/payment_intent.rb', line 3102 def pix @pix end |
#promptpay ⇒ Object
If this is a ‘promptpay` PaymentMethod, this hash contains details about the PromptPay payment method.
3104 3105 3106 |
# File 'lib/stripe/resources/payment_intent.rb', line 3104 def promptpay @promptpay end |
#qris ⇒ Object
If this is a ‘qris` PaymentMethod, this hash contains details about the QRIS payment method.
3106 3107 3108 |
# File 'lib/stripe/resources/payment_intent.rb', line 3106 def qris @qris end |
#radar_options ⇒ Object
Options to configure Radar. See [Radar Session](stripe.com/docs/radar/radar-session) for more information.
3108 3109 3110 |
# File 'lib/stripe/resources/payment_intent.rb', line 3108 def @radar_options end |
#rechnung ⇒ Object
If this is a ‘rechnung` PaymentMethod, this hash contains details about the Rechnung payment method.
3110 3111 3112 |
# File 'lib/stripe/resources/payment_intent.rb', line 3110 def rechnung @rechnung end |
#revolut_pay ⇒ Object
If this is a ‘Revolut Pay` PaymentMethod, this hash contains details about the Revolut Pay payment method.
3112 3113 3114 |
# File 'lib/stripe/resources/payment_intent.rb', line 3112 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object
If this is a ‘samsung_pay` PaymentMethod, this hash contains details about the SamsungPay payment method.
3114 3115 3116 |
# File 'lib/stripe/resources/payment_intent.rb', line 3114 def samsung_pay @samsung_pay end |
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` PaymentMethod, this hash contains details about the SEPA debit bank account.
3116 3117 3118 |
# File 'lib/stripe/resources/payment_intent.rb', line 3116 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object
If this is a Shopeepay PaymentMethod, this hash contains details about the Shopeepay payment method.
3118 3119 3120 |
# File 'lib/stripe/resources/payment_intent.rb', line 3118 def shopeepay @shopeepay end |
#sofort ⇒ Object
If this is a ‘sofort` PaymentMethod, this hash contains details about the SOFORT payment method.
3120 3121 3122 |
# File 'lib/stripe/resources/payment_intent.rb', line 3120 def sofort @sofort end |
#swish ⇒ Object
If this is a ‘swish` PaymentMethod, this hash contains details about the Swish payment method.
3122 3123 3124 |
# File 'lib/stripe/resources/payment_intent.rb', line 3122 def swish @swish end |
#twint ⇒ Object
If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.
3124 3125 3126 |
# File 'lib/stripe/resources/payment_intent.rb', line 3124 def twint @twint end |
#type ⇒ Object
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
3126 3127 3128 |
# File 'lib/stripe/resources/payment_intent.rb', line 3126 def type @type end |
#us_bank_account ⇒ Object
If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.
3128 3129 3130 |
# File 'lib/stripe/resources/payment_intent.rb', line 3128 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
If this is an ‘wechat_pay` PaymentMethod, this hash contains details about the wechat_pay payment method.
3130 3131 3132 |
# File 'lib/stripe/resources/payment_intent.rb', line 3130 def wechat_pay @wechat_pay end |
#zip ⇒ Object
If this is a ‘zip` PaymentMethod, this hash contains details about the Zip payment method.
3132 3133 3134 |
# File 'lib/stripe/resources/payment_intent.rb', line 3132 def zip @zip end |