Class: Stripe::PaymentIntent::CreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



3219
3220
3221
3222
3223
3224
3225
3226
3227
3228
3229
3230
3231
3232
3233
# File 'lib/stripe/resources/payment_intent.rb', line 3219

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



3207
3208
3209
# File 'lib/stripe/resources/payment_intent.rb', line 3207

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



3209
3210
3211
# File 'lib/stripe/resources/payment_intent.rb', line 3209

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



3211
3212
3213
# File 'lib/stripe/resources/payment_intent.rb', line 3211

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



3213
3214
3215
# File 'lib/stripe/resources/payment_intent.rb', line 3213

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



3215
3216
3217
# File 'lib/stripe/resources/payment_intent.rb', line 3215

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



3217
3218
3219
# File 'lib/stripe/resources/payment_intent.rb', line 3217

def suffix
  @suffix
end