Class: Stripe::PaymentIntent::CreateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 4613 4614 |
# File 'lib/stripe/resources/payment_intent.rb', line 4600 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
4588 4589 4590 |
# File 'lib/stripe/resources/payment_intent.rb', line 4588 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
4590 4591 4592 |
# File 'lib/stripe/resources/payment_intent.rb', line 4590 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
4592 4593 4594 |
# File 'lib/stripe/resources/payment_intent.rb', line 4592 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
4594 4595 4596 |
# File 'lib/stripe/resources/payment_intent.rb', line 4594 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
4596 4597 4598 |
# File 'lib/stripe/resources/payment_intent.rb', line 4596 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
4598 4599 4600 |
# File 'lib/stripe/resources/payment_intent.rb', line 4598 def suffix @suffix end |