Class: Stripe::PaymentIntent::CreateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
3197 3198 3199 3200 3201 3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 |
# File 'lib/stripe/resources/payment_intent.rb', line 3197 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
3185 3186 3187 |
# File 'lib/stripe/resources/payment_intent.rb', line 3185 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
3187 3188 3189 |
# File 'lib/stripe/resources/payment_intent.rb', line 3187 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
3189 3190 3191 |
# File 'lib/stripe/resources/payment_intent.rb', line 3189 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
3191 3192 3193 |
# File 'lib/stripe/resources/payment_intent.rb', line 3191 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
3193 3194 3195 |
# File 'lib/stripe/resources/payment_intent.rb', line 3193 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
3195 3196 3197 |
# File 'lib/stripe/resources/payment_intent.rb', line 3195 def suffix @suffix end |