Class: Stripe::PaymentIntent::CreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
# File 'lib/stripe/resources/payment_intent.rb', line 3044

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



3032
3033
3034
# File 'lib/stripe/resources/payment_intent.rb', line 3032

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



3034
3035
3036
# File 'lib/stripe/resources/payment_intent.rb', line 3034

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



3036
3037
3038
# File 'lib/stripe/resources/payment_intent.rb', line 3036

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



3038
3039
3040
# File 'lib/stripe/resources/payment_intent.rb', line 3038

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



3040
3041
3042
# File 'lib/stripe/resources/payment_intent.rb', line 3040

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



3042
3043
3044
# File 'lib/stripe/resources/payment_intent.rb', line 3042

def suffix
  @suffix
end