Class: Stripe::PaymentIntent::CreateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/stripe/resources/payment_intent.rb', line 3030 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
3018 3019 3020 |
# File 'lib/stripe/resources/payment_intent.rb', line 3018 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
3020 3021 3022 |
# File 'lib/stripe/resources/payment_intent.rb', line 3020 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
3022 3023 3024 |
# File 'lib/stripe/resources/payment_intent.rb', line 3022 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
3024 3025 3026 |
# File 'lib/stripe/resources/payment_intent.rb', line 3024 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
3026 3027 3028 |
# File 'lib/stripe/resources/payment_intent.rb', line 3026 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
3028 3029 3030 |
# File 'lib/stripe/resources/payment_intent.rb', line 3028 def suffix @suffix end |