Class: Stripe::PaymentIntent::CreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
# File 'lib/stripe/resources/payment_intent.rb', line 1857

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1845
1846
1847
# File 'lib/stripe/resources/payment_intent.rb', line 1845

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



1847
1848
1849
# File 'lib/stripe/resources/payment_intent.rb', line 1847

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



1849
1850
1851
# File 'lib/stripe/resources/payment_intent.rb', line 1849

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



1851
1852
1853
# File 'lib/stripe/resources/payment_intent.rb', line 1851

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



1853
1854
1855
# File 'lib/stripe/resources/payment_intent.rb', line 1853

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



1855
1856
1857
# File 'lib/stripe/resources/payment_intent.rb', line 1855

def suffix
  @suffix
end