Class: Stripe::PaymentIntent::CreateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 |
# File 'lib/stripe/resources/payment_intent.rb', line 3003 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
2991 2992 2993 |
# File 'lib/stripe/resources/payment_intent.rb', line 2991 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
2993 2994 2995 |
# File 'lib/stripe/resources/payment_intent.rb', line 2993 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
2995 2996 2997 |
# File 'lib/stripe/resources/payment_intent.rb', line 2995 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
2997 2998 2999 |
# File 'lib/stripe/resources/payment_intent.rb', line 2997 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
2999 3000 3001 |
# File 'lib/stripe/resources/payment_intent.rb', line 2999 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
3001 3002 3003 |
# File 'lib/stripe/resources/payment_intent.rb', line 3001 def suffix @suffix end |