Class: Stripe::PaymentIntent::CreateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 |
# File 'lib/stripe/resources/payment_intent.rb', line 1879 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1867 1868 1869 |
# File 'lib/stripe/resources/payment_intent.rb', line 1867 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
1869 1870 1871 |
# File 'lib/stripe/resources/payment_intent.rb', line 1869 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
1871 1872 1873 |
# File 'lib/stripe/resources/payment_intent.rb', line 1871 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
1873 1874 1875 |
# File 'lib/stripe/resources/payment_intent.rb', line 1873 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
1875 1876 1877 |
# File 'lib/stripe/resources/payment_intent.rb', line 1875 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
1877 1878 1879 |
# File 'lib/stripe/resources/payment_intent.rb', line 1877 def suffix @suffix end |