Class: Stripe::PaymentIntent::CreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
# File 'lib/stripe/resources/payment_intent.rb', line 2963

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



2951
2952
2953
# File 'lib/stripe/resources/payment_intent.rb', line 2951

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



2953
2954
2955
# File 'lib/stripe/resources/payment_intent.rb', line 2953

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



2955
2956
2957
# File 'lib/stripe/resources/payment_intent.rb', line 2955

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



2957
2958
2959
# File 'lib/stripe/resources/payment_intent.rb', line 2957

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



2959
2960
2961
# File 'lib/stripe/resources/payment_intent.rb', line 2959

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



2961
2962
2963
# File 'lib/stripe/resources/payment_intent.rb', line 2961

def suffix
  @suffix
end