Class: Stripe::PaymentIntent::CreateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
3120 3121 3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 |
# File 'lib/stripe/resources/payment_intent.rb', line 3120 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
3110 3111 3112 |
# File 'lib/stripe/resources/payment_intent.rb', line 3110 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
3112 3113 3114 |
# File 'lib/stripe/resources/payment_intent.rb', line 3112 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
3114 3115 3116 |
# File 'lib/stripe/resources/payment_intent.rb', line 3114 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
3116 3117 3118 |
# File 'lib/stripe/resources/payment_intent.rb', line 3116 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
3118 3119 3120 |
# File 'lib/stripe/resources/payment_intent.rb', line 3118 def routing_number @routing_number end |