Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CardPresent, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, StripeBalance, Swish, Twint, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, blik: nil, boleto: nil, card: nil, card_present: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
5186
5187
5188
5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
5205
5206
5207
5208
5209
5210
5211
5212
5213
5214
5215
5216
5217
5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
5246
5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
5267
5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
5278
5279
5280
5281
5282
5283
5284
5285
5286
# File 'lib/stripe/resources/payment_intent.rb', line 5170

def initialize(
  acss_debit: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  alma: nil,
  amazon_pay: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  billie: nil,
  blik: nil,
  boleto: nil,
  card: nil,
  card_present: nil,
  cashapp: nil,
  customer_balance: nil,
  eps: nil,
  fpx: nil,
  giropay: nil,
  gopay: nil,
  grabpay: nil,
  id_bank_transfer: nil,
  ideal: nil,
  interac_present: nil,
  kakao_pay: nil,
  klarna: nil,
  konbini: nil,
  kr_card: nil,
  link: nil,
  mb_way: nil,
  mobilepay: nil,
  multibanco: nil,
  naver_pay: nil,
  nz_bank_account: nil,
  oxxo: nil,
  p24: nil,
  pay_by_bank: nil,
  payco: nil,
  paynow: nil,
  paypal: nil,
  payto: nil,
  pix: nil,
  promptpay: nil,
  qris: nil,
  rechnung: nil,
  revolut_pay: nil,
  samsung_pay: nil,
  satispay: nil,
  sepa_debit: nil,
  shopeepay: nil,
  sofort: nil,
  stripe_balance: nil,
  swish: nil,
  twint: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @alma = alma
  @amazon_pay = amazon_pay
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @billie = billie
  @blik = blik
  @boleto = boleto
  @card = card
  @card_present = card_present
  @cashapp = cashapp
  @customer_balance = customer_balance
  @eps = eps
  @fpx = fpx
  @giropay = giropay
  @gopay = gopay
  @grabpay = grabpay
  @id_bank_transfer = id_bank_transfer
  @ideal = ideal
  @interac_present = interac_present
  @kakao_pay = kakao_pay
  @klarna = klarna
  @konbini = konbini
  @kr_card = kr_card
  @link = link
  @mb_way = mb_way
  @mobilepay = mobilepay
  @multibanco = multibanco
  @naver_pay = naver_pay
  @nz_bank_account = 
  @oxxo = oxxo
  @p24 = p24
  @pay_by_bank = pay_by_bank
  @payco = payco
  @paynow = paynow
  @paypal = paypal
  @payto = payto
  @pix = pix
  @promptpay = promptpay
  @qris = qris
  @rechnung = rechnung
  @revolut_pay = revolut_pay
  @samsung_pay = samsung_pay
  @satispay = satispay
  @sepa_debit = sepa_debit
  @shopeepay = shopeepay
  @sofort = sofort
  @stripe_balance = stripe_balance
  @swish = swish
  @twint = twint
  @us_bank_account = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

If this is a ‘acss_debit` PaymentMethod, this sub-hash contains details about the ACSS Debit payment method options.



5056
5057
5058
# File 'lib/stripe/resources/payment_intent.rb', line 5056

def acss_debit
  @acss_debit
end

#affirmObject

If this is an ‘affirm` PaymentMethod, this sub-hash contains details about the Affirm payment method options.



5058
5059
5060
# File 'lib/stripe/resources/payment_intent.rb', line 5058

def affirm
  @affirm
end

#afterpay_clearpayObject

If this is a ‘afterpay_clearpay` PaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options.



5060
5061
5062
# File 'lib/stripe/resources/payment_intent.rb', line 5060

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If this is a ‘alipay` PaymentMethod, this sub-hash contains details about the Alipay payment method options.



5062
5063
5064
# File 'lib/stripe/resources/payment_intent.rb', line 5062

def alipay
  @alipay
end

#almaObject

If this is a ‘alma` PaymentMethod, this sub-hash contains details about the Alma payment method options.



5064
5065
5066
# File 'lib/stripe/resources/payment_intent.rb', line 5064

def alma
  @alma
end

#amazon_payObject

If this is a ‘amazon_pay` PaymentMethod, this sub-hash contains details about the Amazon Pay payment method options.



5066
5067
5068
# File 'lib/stripe/resources/payment_intent.rb', line 5066

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject

If this is a ‘au_becs_debit` PaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options.



5068
5069
5070
# File 'lib/stripe/resources/payment_intent.rb', line 5068

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

If this is a ‘bacs_debit` PaymentMethod, this sub-hash contains details about the BACS Debit payment method options.



5070
5071
5072
# File 'lib/stripe/resources/payment_intent.rb', line 5070

def bacs_debit
  @bacs_debit
end

#bancontactObject

If this is a ‘bancontact` PaymentMethod, this sub-hash contains details about the Bancontact payment method options.



5072
5073
5074
# File 'lib/stripe/resources/payment_intent.rb', line 5072

def bancontact
  @bancontact
end

#billieObject

If this is a ‘billie` PaymentMethod, this sub-hash contains details about the Billie payment method options.



5074
5075
5076
# File 'lib/stripe/resources/payment_intent.rb', line 5074

def billie
  @billie
end

#blikObject

If this is a ‘blik` PaymentMethod, this sub-hash contains details about the BLIK payment method options.



5076
5077
5078
# File 'lib/stripe/resources/payment_intent.rb', line 5076

def blik
  @blik
end

#boletoObject

If this is a ‘boleto` PaymentMethod, this sub-hash contains details about the Boleto payment method options.



5078
5079
5080
# File 'lib/stripe/resources/payment_intent.rb', line 5078

def boleto
  @boleto
end

#cardObject

Configuration for any card payments attempted on this PaymentIntent.



5080
5081
5082
# File 'lib/stripe/resources/payment_intent.rb', line 5080

def card
  @card
end

#card_presentObject

If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.



5082
5083
5084
# File 'lib/stripe/resources/payment_intent.rb', line 5082

def card_present
  @card_present
end

#cashappObject

If this is a ‘cashapp` PaymentMethod, this sub-hash contains details about the Cash App Pay payment method options.



5084
5085
5086
# File 'lib/stripe/resources/payment_intent.rb', line 5084

def cashapp
  @cashapp
end

#customer_balanceObject

If this is a ‘customer balance` PaymentMethod, this sub-hash contains details about the customer balance payment method options.



5086
5087
5088
# File 'lib/stripe/resources/payment_intent.rb', line 5086

def customer_balance
  @customer_balance
end

#epsObject

If this is a ‘eps` PaymentMethod, this sub-hash contains details about the EPS payment method options.



5088
5089
5090
# File 'lib/stripe/resources/payment_intent.rb', line 5088

def eps
  @eps
end

#fpxObject

If this is a ‘fpx` PaymentMethod, this sub-hash contains details about the FPX payment method options.



5090
5091
5092
# File 'lib/stripe/resources/payment_intent.rb', line 5090

def fpx
  @fpx
end

#giropayObject

If this is a ‘giropay` PaymentMethod, this sub-hash contains details about the Giropay payment method options.



5092
5093
5094
# File 'lib/stripe/resources/payment_intent.rb', line 5092

def giropay
  @giropay
end

#gopayObject

If this is a ‘gopay` PaymentMethod, this sub-hash contains details about the Gopay payment method options.



5094
5095
5096
# File 'lib/stripe/resources/payment_intent.rb', line 5094

def gopay
  @gopay
end

#grabpayObject

If this is a ‘grabpay` PaymentMethod, this sub-hash contains details about the Grabpay payment method options.



5096
5097
5098
# File 'lib/stripe/resources/payment_intent.rb', line 5096

def grabpay
  @grabpay
end

#id_bank_transferObject

If this is a ‘id_bank_transfer` PaymentMethod, this sub-hash contains details about the Indonesia Bank Transfer payment method options.



5098
5099
5100
# File 'lib/stripe/resources/payment_intent.rb', line 5098

def id_bank_transfer
  @id_bank_transfer
end

#idealObject

If this is a ‘ideal` PaymentMethod, this sub-hash contains details about the Ideal payment method options.



5100
5101
5102
# File 'lib/stripe/resources/payment_intent.rb', line 5100

def ideal
  @ideal
end

#interac_presentObject

If this is a ‘interac_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.



5102
5103
5104
# File 'lib/stripe/resources/payment_intent.rb', line 5102

def interac_present
  @interac_present
end

#kakao_payObject

If this is a ‘kakao_pay` PaymentMethod, this sub-hash contains details about the Kakao Pay payment method options.



5104
5105
5106
# File 'lib/stripe/resources/payment_intent.rb', line 5104

def kakao_pay
  @kakao_pay
end

#klarnaObject

If this is a ‘klarna` PaymentMethod, this sub-hash contains details about the Klarna payment method options.



5106
5107
5108
# File 'lib/stripe/resources/payment_intent.rb', line 5106

def klarna
  @klarna
end

#konbiniObject

If this is a ‘konbini` PaymentMethod, this sub-hash contains details about the Konbini payment method options.



5108
5109
5110
# File 'lib/stripe/resources/payment_intent.rb', line 5108

def konbini
  @konbini
end

#kr_cardObject

If this is a ‘kr_card` PaymentMethod, this sub-hash contains details about the KR Card payment method options.



5110
5111
5112
# File 'lib/stripe/resources/payment_intent.rb', line 5110

def kr_card
  @kr_card
end

If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options.



5112
5113
5114
# File 'lib/stripe/resources/payment_intent.rb', line 5112

def link
  @link
end

#mb_wayObject

If this is a ‘mb_way` PaymentMethod, this sub-hash contains details about the MB WAY payment method options.



5114
5115
5116
# File 'lib/stripe/resources/payment_intent.rb', line 5114

def mb_way
  @mb_way
end

#mobilepayObject

If this is a ‘MobilePay` PaymentMethod, this sub-hash contains details about the MobilePay payment method options.



5116
5117
5118
# File 'lib/stripe/resources/payment_intent.rb', line 5116

def mobilepay
  @mobilepay
end

#multibancoObject

If this is a ‘multibanco` PaymentMethod, this sub-hash contains details about the Multibanco payment method options.



5118
5119
5120
# File 'lib/stripe/resources/payment_intent.rb', line 5118

def multibanco
  @multibanco
end

If this is a ‘naver_pay` PaymentMethod, this sub-hash contains details about the Naver Pay payment method options.



5120
5121
5122
# File 'lib/stripe/resources/payment_intent.rb', line 5120

def naver_pay
  @naver_pay
end

#nz_bank_accountObject

If this is a ‘nz_bank_account` PaymentMethod, this sub-hash contains details about the NZ BECS Direct Debit payment method options.



5122
5123
5124
# File 'lib/stripe/resources/payment_intent.rb', line 5122

def 
  @nz_bank_account
end

#oxxoObject

If this is a ‘oxxo` PaymentMethod, this sub-hash contains details about the OXXO payment method options.



5124
5125
5126
# File 'lib/stripe/resources/payment_intent.rb', line 5124

def oxxo
  @oxxo
end

#p24Object

If this is a ‘p24` PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options.



5126
5127
5128
# File 'lib/stripe/resources/payment_intent.rb', line 5126

def p24
  @p24
end

#pay_by_bankObject

If this is a ‘pay_by_bank` PaymentMethod, this sub-hash contains details about the PayByBank payment method options.



5128
5129
5130
# File 'lib/stripe/resources/payment_intent.rb', line 5128

def pay_by_bank
  @pay_by_bank
end

#paycoObject

If this is a ‘payco` PaymentMethod, this sub-hash contains details about the PAYCO payment method options.



5130
5131
5132
# File 'lib/stripe/resources/payment_intent.rb', line 5130

def payco
  @payco
end

#paynowObject

If this is a ‘paynow` PaymentMethod, this sub-hash contains details about the PayNow payment method options.



5132
5133
5134
# File 'lib/stripe/resources/payment_intent.rb', line 5132

def paynow
  @paynow
end

#paypalObject

If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.



5134
5135
5136
# File 'lib/stripe/resources/payment_intent.rb', line 5134

def paypal
  @paypal
end

#paytoObject

If this is a ‘payto` PaymentMethod, this sub-hash contains details about the PayTo payment method options.



5136
5137
5138
# File 'lib/stripe/resources/payment_intent.rb', line 5136

def payto
  @payto
end

#pixObject

If this is a ‘pix` PaymentMethod, this sub-hash contains details about the Pix payment method options.



5138
5139
5140
# File 'lib/stripe/resources/payment_intent.rb', line 5138

def pix
  @pix
end

#promptpayObject

If this is a ‘promptpay` PaymentMethod, this sub-hash contains details about the PromptPay payment method options.



5140
5141
5142
# File 'lib/stripe/resources/payment_intent.rb', line 5140

def promptpay
  @promptpay
end

#qrisObject

If this is a ‘qris` PaymentMethod, this sub-hash contains details about the QRIS payment method options.



5142
5143
5144
# File 'lib/stripe/resources/payment_intent.rb', line 5142

def qris
  @qris
end

#rechnungObject

If this is a ‘rechnung` PaymentMethod, this sub-hash contains details about the Rechnung payment method options.



5144
5145
5146
# File 'lib/stripe/resources/payment_intent.rb', line 5144

def rechnung
  @rechnung
end

#revolut_payObject

If this is a ‘revolut_pay` PaymentMethod, this sub-hash contains details about the Revolut Pay payment method options.



5146
5147
5148
# File 'lib/stripe/resources/payment_intent.rb', line 5146

def revolut_pay
  @revolut_pay
end

#samsung_payObject

If this is a ‘samsung_pay` PaymentMethod, this sub-hash contains details about the Samsung Pay payment method options.



5148
5149
5150
# File 'lib/stripe/resources/payment_intent.rb', line 5148

def samsung_pay
  @samsung_pay
end

#satispayObject

If this is a ‘satispay` PaymentMethod, this sub-hash contains details about the Satispay payment method options.



5150
5151
5152
# File 'lib/stripe/resources/payment_intent.rb', line 5150

def satispay
  @satispay
end

#sepa_debitObject

If this is a ‘sepa_debit` PaymentIntent, this sub-hash contains details about the SEPA Debit payment method options.



5152
5153
5154
# File 'lib/stripe/resources/payment_intent.rb', line 5152

def sepa_debit
  @sepa_debit
end

#shopeepayObject

If this is a ‘shopeepay` PaymentMethod, this sub-hash contains details about the ShopeePay payment method options.



5154
5155
5156
# File 'lib/stripe/resources/payment_intent.rb', line 5154

def shopeepay
  @shopeepay
end

#sofortObject

If this is a ‘sofort` PaymentMethod, this sub-hash contains details about the SOFORT payment method options.



5156
5157
5158
# File 'lib/stripe/resources/payment_intent.rb', line 5156

def sofort
  @sofort
end

#stripe_balanceObject

If this is a ‘stripe_balance` PaymentMethod, this sub-hash contains details about the Stripe Balance payment method options.



5158
5159
5160
# File 'lib/stripe/resources/payment_intent.rb', line 5158

def stripe_balance
  @stripe_balance
end

#swishObject

If this is a ‘Swish` PaymentMethod, this sub-hash contains details about the Swish payment method options.



5160
5161
5162
# File 'lib/stripe/resources/payment_intent.rb', line 5160

def swish
  @swish
end

#twintObject

If this is a ‘twint` PaymentMethod, this sub-hash contains details about the TWINT payment method options.



5162
5163
5164
# File 'lib/stripe/resources/payment_intent.rb', line 5162

def twint
  @twint
end

#us_bank_accountObject

If this is a ‘us_bank_account` PaymentMethod, this sub-hash contains details about the US bank account payment method options.



5164
5165
5166
# File 'lib/stripe/resources/payment_intent.rb', line 5164

def 
  @us_bank_account
end

#wechat_payObject

If this is a ‘wechat_pay` PaymentMethod, this sub-hash contains details about the WeChat Pay payment method options.



5166
5167
5168
# File 'lib/stripe/resources/payment_intent.rb', line 5166

def wechat_pay
  @wechat_pay
end

#zipObject

If this is a ‘zip` PaymentMethod, this sub-hash contains details about the Zip payment method options.



5168
5169
5170
# File 'lib/stripe/resources/payment_intent.rb', line 5168

def zip
  @zip
end