Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step.
-
#interval_description ⇒ Object
Description of the mandate interval.
-
#payment_schedule ⇒ Object
Payment schedule for the mandate.
-
#transaction_type ⇒ Object
Transaction type of the mandate.
Instance Method Summary collapse
-
#initialize(custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 |
# File 'lib/stripe/resources/payment_intent.rb', line 3460 def initialize( custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil ) @custom_mandate_url = custom_mandate_url @interval_description = interval_description @payment_schedule = payment_schedule @transaction_type = transaction_type end |
Instance Attribute Details
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.
3452 3453 3454 |
# File 'lib/stripe/resources/payment_intent.rb', line 3452 def custom_mandate_url @custom_mandate_url end |
#interval_description ⇒ Object
Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.
3454 3455 3456 |
# File 'lib/stripe/resources/payment_intent.rb', line 3454 def interval_description @interval_description end |
#payment_schedule ⇒ Object
Payment schedule for the mandate.
3456 3457 3458 |
# File 'lib/stripe/resources/payment_intent.rb', line 3456 def payment_schedule @payment_schedule end |
#transaction_type ⇒ Object
Transaction type of the mandate.
3458 3459 3460 |
# File 'lib/stripe/resources/payment_intent.rb', line 3458 def transaction_type @transaction_type end |