Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step.
-
#interval_description ⇒ Object
Description of the mandate interval.
-
#payment_schedule ⇒ Object
Payment schedule for the mandate.
-
#transaction_type ⇒ Object
Transaction type of the mandate.
Instance Method Summary collapse
-
#initialize(custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 |
# File 'lib/stripe/resources/payment_intent.rb', line 3400 def initialize( custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil ) @custom_mandate_url = custom_mandate_url @interval_description = interval_description @payment_schedule = payment_schedule @transaction_type = transaction_type end |
Instance Attribute Details
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.
3392 3393 3394 |
# File 'lib/stripe/resources/payment_intent.rb', line 3392 def custom_mandate_url @custom_mandate_url end |
#interval_description ⇒ Object
Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.
3394 3395 3396 |
# File 'lib/stripe/resources/payment_intent.rb', line 3394 def interval_description @interval_description end |
#payment_schedule ⇒ Object
Payment schedule for the mandate.
3396 3397 3398 |
# File 'lib/stripe/resources/payment_intent.rb', line 3396 def payment_schedule @payment_schedule end |
#transaction_type ⇒ Object
Transaction type of the mandate.
3398 3399 3400 |
# File 'lib/stripe/resources/payment_intent.rb', line 3398 def transaction_type @transaction_type end |