Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Card::Installments::Plan
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Card::Installments::Plan
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#count ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.
Instance Method Summary collapse
-
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
constructor
A new instance of Plan.
Methods inherited from RequestParams
Constructor Details
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
Returns a new instance of Plan.
5300 5301 5302 5303 5304 |
# File 'lib/stripe/resources/payment_intent.rb', line 5300 def initialize(count: nil, interval: nil, type: nil) @count = count @interval = interval @type = type end |
Instance Attribute Details
#count ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.
5293 5294 5295 |
# File 'lib/stripe/resources/payment_intent.rb', line 5293 def count @count end |
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.
5296 5297 5298 |
# File 'lib/stripe/resources/payment_intent.rb', line 5296 def interval @interval end |
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.
5298 5299 5300 |
# File 'lib/stripe/resources/payment_intent.rb', line 5298 def type @type end |