Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



2512
2513
2514
2515
2516
# File 'lib/stripe/resources/payment_intent.rb', line 2512

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



2505
2506
2507
# File 'lib/stripe/resources/payment_intent.rb', line 2505

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



2508
2509
2510
# File 'lib/stripe/resources/payment_intent.rb', line 2508

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`.



2510
2511
2512
# File 'lib/stripe/resources/payment_intent.rb', line 2510

def type
  @type
end