Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



3531
3532
3533
3534
3535
# File 'lib/stripe/resources/payment_intent.rb', line 3531

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



3524
3525
3526
# File 'lib/stripe/resources/payment_intent.rb', line 3524

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



3527
3528
3529
# File 'lib/stripe/resources/payment_intent.rb', line 3527

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`.



3529
3530
3531
# File 'lib/stripe/resources/payment_intent.rb', line 3529

def type
  @type
end