Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Card::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Card::MandateOptions
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments.
-
#amount_type ⇒ Object
One of ‘fixed` or `maximum`.
-
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
-
#end_date ⇒ Object
End date of the mandate or subscription.
-
#interval ⇒ Object
Specifies payment frequency.
-
#interval_count ⇒ Object
The number of intervals between payments.
-
#reference ⇒ Object
Unique identifier for the mandate or subscription.
-
#start_date ⇒ Object
Start date of the mandate or subscription.
-
#supported_types ⇒ Object
Specifies the type of mandates supported.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 |
# File 'lib/stripe/resources/payment_intent.rb', line 3766 def initialize( amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil ) @amount = amount @amount_type = amount_type @description = description @end_date = end_date @interval = interval @interval_count = interval_count @reference = reference @start_date = start_date @supported_types = supported_types end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments.
3748 3749 3750 |
# File 'lib/stripe/resources/payment_intent.rb', line 3748 def amount @amount end |
#amount_type ⇒ Object
One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.
3750 3751 3752 |
# File 'lib/stripe/resources/payment_intent.rb', line 3750 def amount_type @amount_type end |
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
3752 3753 3754 |
# File 'lib/stripe/resources/payment_intent.rb', line 3752 def description @description end |
#end_date ⇒ Object
End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.
3754 3755 3756 |
# File 'lib/stripe/resources/payment_intent.rb', line 3754 def end_date @end_date end |
#interval ⇒ Object
Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.
3756 3757 3758 |
# File 'lib/stripe/resources/payment_intent.rb', line 3756 def interval @interval end |
#interval_count ⇒ Object
The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.
3758 3759 3760 |
# File 'lib/stripe/resources/payment_intent.rb', line 3758 def interval_count @interval_count end |
#reference ⇒ Object
Unique identifier for the mandate or subscription.
3760 3761 3762 |
# File 'lib/stripe/resources/payment_intent.rb', line 3760 def reference @reference end |
#start_date ⇒ Object
Start date of the mandate or subscription. Start date should not be lesser than yesterday.
3762 3763 3764 |
# File 'lib/stripe/resources/payment_intent.rb', line 3762 def start_date @start_date end |
#supported_types ⇒ Object
Specifies the type of mandates supported. Possible values are ‘india`.
3764 3765 3766 |
# File 'lib/stripe/resources/payment_intent.rb', line 3764 def supported_types @supported_types end |