Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2507
2508
2509
2510
2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
# File 'lib/stripe/resources/payment_intent.rb', line 2507

def initialize(
  amount: nil,
  amount_type: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



2489
2490
2491
# File 'lib/stripe/resources/payment_intent.rb', line 2489

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



2491
2492
2493
# File 'lib/stripe/resources/payment_intent.rb', line 2491

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



2493
2494
2495
# File 'lib/stripe/resources/payment_intent.rb', line 2493

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



2495
2496
2497
# File 'lib/stripe/resources/payment_intent.rb', line 2495

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



2497
2498
2499
# File 'lib/stripe/resources/payment_intent.rb', line 2497

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



2499
2500
2501
# File 'lib/stripe/resources/payment_intent.rb', line 2499

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



2501
2502
2503
# File 'lib/stripe/resources/payment_intent.rb', line 2501

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



2503
2504
2505
# File 'lib/stripe/resources/payment_intent.rb', line 2503

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are ‘india`.



2505
2506
2507
# File 'lib/stripe/resources/payment_intent.rb', line 2505

def supported_types
  @supported_types
end