Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



4193
4194
4195
4196
4197
4198
4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
4211
4212
4213
# File 'lib/stripe/resources/payment_intent.rb', line 4193

def initialize(
  amount: nil,
  amount_type: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



4167
4168
4169
# File 'lib/stripe/resources/payment_intent.rb', line 4167

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



4170
4171
4172
# File 'lib/stripe/resources/payment_intent.rb', line 4170

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



4173
4174
4175
# File 'lib/stripe/resources/payment_intent.rb', line 4173

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



4176
4177
4178
# File 'lib/stripe/resources/payment_intent.rb', line 4176

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



4179
4180
4181
# File 'lib/stripe/resources/payment_intent.rb', line 4179

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



4182
4183
4184
# File 'lib/stripe/resources/payment_intent.rb', line 4182

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



4185
4186
4187
# File 'lib/stripe/resources/payment_intent.rb', line 4185

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



4188
4189
4190
# File 'lib/stripe/resources/payment_intent.rb', line 4188

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are ‘india`.



4191
4192
4193
# File 'lib/stripe/resources/payment_intent.rb', line 4191

def supported_types
  @supported_types
end