Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Card::ThreeDSecure::NetworkOptions::CartesBancaires
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Card::ThreeDSecure::NetworkOptions::CartesBancaires
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#cb_avalgo ⇒ Object
The cryptogram calculation algorithm used by the card Issuer’s ACS to calculate the Authentication cryptogram.
-
#cb_exemption ⇒ Object
The exemption indicator returned from Cartes Bancaires in the ARes.
-
#cb_score ⇒ Object
The risk score returned from Cartes Bancaires in the ARes.
Instance Method Summary collapse
-
#initialize(cb_avalgo: nil, cb_exemption: nil, cb_score: nil) ⇒ CartesBancaires
constructor
A new instance of CartesBancaires.
Methods inherited from RequestParams
Constructor Details
#initialize(cb_avalgo: nil, cb_exemption: nil, cb_score: nil) ⇒ CartesBancaires
Returns a new instance of CartesBancaires.
2546 2547 2548 2549 2550 |
# File 'lib/stripe/resources/payment_intent.rb', line 2546 def initialize(cb_avalgo: nil, cb_exemption: nil, cb_score: nil) @cb_avalgo = cb_avalgo @cb_exemption = cb_exemption @cb_score = cb_score end |
Instance Attribute Details
#cb_avalgo ⇒ Object
The cryptogram calculation algorithm used by the card Issuer’s ACS to calculate the Authentication cryptogram. Also known as ‘cavvAlgorithm`. messageExtension: CB-AVALGO
2536 2537 2538 |
# File 'lib/stripe/resources/payment_intent.rb', line 2536 def cb_avalgo @cb_avalgo end |
#cb_exemption ⇒ Object
The exemption indicator returned from Cartes Bancaires in the ARes. message extension: CB-EXEMPTION; string (4 characters) This is a 3 byte bitmap (low significant byte first and most significant bit first) that has been Base64 encoded
2541 2542 2543 |
# File 'lib/stripe/resources/payment_intent.rb', line 2541 def cb_exemption @cb_exemption end |
#cb_score ⇒ Object
The risk score returned from Cartes Bancaires in the ARes. message extension: CB-SCORE; numeric value 0-99
2544 2545 2546 |
# File 'lib/stripe/resources/payment_intent.rb', line 2544 def cb_score @cb_score end |