Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::CardPresent
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::CardPresent
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Routing
Instance Attribute Summary collapse
-
#request_extended_authorization ⇒ Object
Request ability to capture this payment beyond the standard [authorization validity window](stripe.com/docs/terminal/features/extended-authorizations#authorization-validity).
-
#request_incremental_authorization_support ⇒ Object
Request ability to [increment](stripe.com/docs/terminal/features/incremental-authorizations) this PaymentIntent if the combination of MCC and card brand is eligible.
-
#routing ⇒ Object
Network routing priority on co-branded EMV cards supporting domestic debit and international card schemes.
Instance Method Summary collapse
-
#initialize(request_extended_authorization: nil, request_incremental_authorization_support: nil, routing: nil) ⇒ CardPresent
constructor
A new instance of CardPresent.
Methods inherited from RequestParams
Constructor Details
#initialize(request_extended_authorization: nil, request_incremental_authorization_support: nil, routing: nil) ⇒ CardPresent
Returns a new instance of CardPresent.
2707 2708 2709 2710 2711 2712 2713 2714 2715 |
# File 'lib/stripe/resources/payment_intent.rb', line 2707 def initialize( request_extended_authorization: nil, request_incremental_authorization_support: nil, routing: nil ) @request_extended_authorization = @request_incremental_authorization_support = @routing = routing end |
Instance Attribute Details
#request_extended_authorization ⇒ Object
Request ability to capture this payment beyond the standard [authorization validity window](stripe.com/docs/terminal/features/extended-authorizations#authorization-validity)
2701 2702 2703 |
# File 'lib/stripe/resources/payment_intent.rb', line 2701 def @request_extended_authorization end |
#request_incremental_authorization_support ⇒ Object
Request ability to [increment](stripe.com/docs/terminal/features/incremental-authorizations) this PaymentIntent if the combination of MCC and card brand is eligible. Check [incremental_authorization_supported](stripe.com/docs/api/charges/object#charge_object-payment_method_details-card_present-incremental_authorization_supported) in the [Confirm](stripe.com/docs/api/payment_intents/confirm) response to verify support.
2703 2704 2705 |
# File 'lib/stripe/resources/payment_intent.rb', line 2703 def @request_incremental_authorization_support end |
#routing ⇒ Object
Network routing priority on co-branded EMV cards supporting domestic debit and international card schemes.
2705 2706 2707 |
# File 'lib/stripe/resources/payment_intent.rb', line 2705 def routing @routing end |