Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount of the next charge for the subscription.
-
#date ⇒ Object
The date of the next charge for the subscription in YYYY-MM-DD format.
Instance Method Summary collapse
-
#initialize(amount: nil, date: nil) ⇒ NextBilling
constructor
A new instance of NextBilling.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, date: nil) ⇒ NextBilling
Returns a new instance of NextBilling.
2968 2969 2970 2971 |
# File 'lib/stripe/resources/payment_intent.rb', line 2968 def initialize(amount: nil, date: nil) @amount = amount @date = date end |
Instance Attribute Details
#amount ⇒ Object
The amount of the next charge for the subscription.
2964 2965 2966 |
# File 'lib/stripe/resources/payment_intent.rb', line 2964 def amount @amount end |
#date ⇒ Object
The date of the next charge for the subscription in YYYY-MM-DD format.
2966 2967 2968 |
# File 'lib/stripe/resources/payment_intent.rb', line 2966 def date @date end |