Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
4828 4829 4830 4831 4832 4833 4834 4835 4836 4837 4838 4839 4840 4841 4842 4843 4844 4845 4846 |
# File 'lib/stripe/resources/payment_intent.rb', line 4828 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
4812 4813 4814 |
# File 'lib/stripe/resources/payment_intent.rb', line 4812 def category @category end |
#description ⇒ Object
Description of the line item.
4814 4815 4816 |
# File 'lib/stripe/resources/payment_intent.rb', line 4814 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
4816 4817 4818 |
# File 'lib/stripe/resources/payment_intent.rb', line 4816 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
4818 4819 4820 |
# File 'lib/stripe/resources/payment_intent.rb', line 4818 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
4820 4821 4822 |
# File 'lib/stripe/resources/payment_intent.rb', line 4820 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
4822 4823 4824 |
# File 'lib/stripe/resources/payment_intent.rb', line 4822 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
4824 4825 4826 |
# File 'lib/stripe/resources/payment_intent.rb', line 4824 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
4826 4827 4828 |
# File 'lib/stripe/resources/payment_intent.rb', line 4826 def unit_amount @unit_amount end |