Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
4675 4676 4677 4678 4679 4680 4681 4682 4683 4684 4685 4686 4687 4688 4689 4690 4691 4692 4693 |
# File 'lib/stripe/resources/payment_intent.rb', line 4675 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
4659 4660 4661 |
# File 'lib/stripe/resources/payment_intent.rb', line 4659 def category @category end |
#description ⇒ Object
Description of the line item.
4661 4662 4663 |
# File 'lib/stripe/resources/payment_intent.rb', line 4661 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
4663 4664 4665 |
# File 'lib/stripe/resources/payment_intent.rb', line 4663 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
4665 4666 4667 |
# File 'lib/stripe/resources/payment_intent.rb', line 4665 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
4667 4668 4669 |
# File 'lib/stripe/resources/payment_intent.rb', line 4667 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
4669 4670 4671 |
# File 'lib/stripe/resources/payment_intent.rb', line 4669 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
4671 4672 4673 |
# File 'lib/stripe/resources/payment_intent.rb', line 4671 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
4673 4674 4675 |
# File 'lib/stripe/resources/payment_intent.rb', line 4673 def unit_amount @unit_amount end |