Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



4524
4525
4526
4527
4528
4529
4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
# File 'lib/stripe/resources/payment_intent.rb', line 4524

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



4508
4509
4510
# File 'lib/stripe/resources/payment_intent.rb', line 4508

def category
  @category
end

#descriptionObject

Description of the line item.



4510
4511
4512
# File 'lib/stripe/resources/payment_intent.rb', line 4510

def description
  @description
end

#nameObject

Descriptive name of the line item.



4512
4513
4514
# File 'lib/stripe/resources/payment_intent.rb', line 4512

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



4514
4515
4516
# File 'lib/stripe/resources/payment_intent.rb', line 4514

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



4516
4517
4518
# File 'lib/stripe/resources/payment_intent.rb', line 4516

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



4518
4519
4520
# File 'lib/stripe/resources/payment_intent.rb', line 4518

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



4520
4521
4522
# File 'lib/stripe/resources/payment_intent.rb', line 4520

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



4522
4523
4524
# File 'lib/stripe/resources/payment_intent.rb', line 4522

def unit_amount
  @unit_amount
end