Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 4578 4579 4580 4581 4582 |
# File 'lib/stripe/resources/payment_intent.rb', line 4564 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
4548 4549 4550 |
# File 'lib/stripe/resources/payment_intent.rb', line 4548 def category @category end |
#description ⇒ Object
Description of the line item.
4550 4551 4552 |
# File 'lib/stripe/resources/payment_intent.rb', line 4550 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
4552 4553 4554 |
# File 'lib/stripe/resources/payment_intent.rb', line 4552 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
4554 4555 4556 |
# File 'lib/stripe/resources/payment_intent.rb', line 4554 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
4556 4557 4558 |
# File 'lib/stripe/resources/payment_intent.rb', line 4556 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
4558 4559 4560 |
# File 'lib/stripe/resources/payment_intent.rb', line 4558 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
4560 4561 4562 |
# File 'lib/stripe/resources/payment_intent.rb', line 4560 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
4562 4563 4564 |
# File 'lib/stripe/resources/payment_intent.rb', line 4562 def unit_amount @unit_amount end |