Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



4366
4367
4368
4369
4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
# File 'lib/stripe/resources/payment_intent.rb', line 4366

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



4350
4351
4352
# File 'lib/stripe/resources/payment_intent.rb', line 4350

def category
  @category
end

#descriptionObject

Description of the line item.



4352
4353
4354
# File 'lib/stripe/resources/payment_intent.rb', line 4352

def description
  @description
end

#nameObject

Descriptive name of the line item.



4354
4355
4356
# File 'lib/stripe/resources/payment_intent.rb', line 4354

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



4356
4357
4358
# File 'lib/stripe/resources/payment_intent.rb', line 4356

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



4358
4359
4360
# File 'lib/stripe/resources/payment_intent.rb', line 4358

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



4360
4361
4362
# File 'lib/stripe/resources/payment_intent.rb', line 4360

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



4362
4363
4364
# File 'lib/stripe/resources/payment_intent.rb', line 4362

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



4364
4365
4366
# File 'lib/stripe/resources/payment_intent.rb', line 4364

def unit_amount
  @unit_amount
end