Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
4342 4343 4344 4345 4346 4347 4348 4349 4350 4351 4352 4353 4354 4355 4356 4357 4358 4359 4360 |
# File 'lib/stripe/resources/payment_intent.rb', line 4342 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
4326 4327 4328 |
# File 'lib/stripe/resources/payment_intent.rb', line 4326 def category @category end |
#description ⇒ Object
Description of the line item.
4328 4329 4330 |
# File 'lib/stripe/resources/payment_intent.rb', line 4328 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
4330 4331 4332 |
# File 'lib/stripe/resources/payment_intent.rb', line 4330 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
4332 4333 4334 |
# File 'lib/stripe/resources/payment_intent.rb', line 4332 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
4334 4335 4336 |
# File 'lib/stripe/resources/payment_intent.rb', line 4334 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
4336 4337 4338 |
# File 'lib/stripe/resources/payment_intent.rb', line 4336 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
4338 4339 4340 |
# File 'lib/stripe/resources/payment_intent.rb', line 4338 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
4340 4341 4342 |
# File 'lib/stripe/resources/payment_intent.rb', line 4340 def unit_amount @unit_amount end |