Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 5037 5038 5039 5040 5041 5042 |
# File 'lib/stripe/resources/payment_intent.rb', line 5024 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
5001 5002 5003 |
# File 'lib/stripe/resources/payment_intent.rb', line 5001 def category @category end |
#description ⇒ Object
Description of the line item.
5004 5005 5006 |
# File 'lib/stripe/resources/payment_intent.rb', line 5004 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
5007 5008 5009 |
# File 'lib/stripe/resources/payment_intent.rb', line 5007 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
5010 5011 5012 |
# File 'lib/stripe/resources/payment_intent.rb', line 5010 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
5013 5014 5015 |
# File 'lib/stripe/resources/payment_intent.rb', line 5013 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
5016 5017 5018 |
# File 'lib/stripe/resources/payment_intent.rb', line 5016 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
5019 5020 5021 |
# File 'lib/stripe/resources/payment_intent.rb', line 5019 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
5022 5023 5024 |
# File 'lib/stripe/resources/payment_intent.rb', line 5022 def unit_amount @unit_amount end |