Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::UsBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: FinancialConnections, MandateOptions, Networks

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(financial_connections: nil, mandate_options: nil, networks: nil, preferred_settlement_speed: nil, setup_future_usage: nil, verification_method: nil) ⇒ UsBankAccount

Returns a new instance of UsBankAccount.



4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
# File 'lib/stripe/resources/payment_intent.rb', line 4727

def initialize(
  financial_connections: nil,
  mandate_options: nil,
  networks: nil,
  preferred_settlement_speed: nil,
  setup_future_usage: nil,
  verification_method: nil
)
  @financial_connections = financial_connections
  @mandate_options = mandate_options
  @networks = networks
  @preferred_settlement_speed = preferred_settlement_speed
  @setup_future_usage = setup_future_usage
  @verification_method = verification_method
end

Instance Attribute Details

#financial_connectionsObject

Additional fields for Financial Connections Session creation



4707
4708
4709
# File 'lib/stripe/resources/payment_intent.rb', line 4707

def financial_connections
  @financial_connections
end

#mandate_optionsObject

Additional fields for Mandate creation



4709
4710
4711
# File 'lib/stripe/resources/payment_intent.rb', line 4709

def mandate_options
  @mandate_options
end

#networksObject

Additional fields for network related functions



4711
4712
4713
# File 'lib/stripe/resources/payment_intent.rb', line 4711

def networks
  @networks
end

#preferred_settlement_speedObject

Preferred transaction settlement speed



4713
4714
4715
# File 'lib/stripe/resources/payment_intent.rb', line 4713

def preferred_settlement_speed
  @preferred_settlement_speed
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



4723
4724
4725
# File 'lib/stripe/resources/payment_intent.rb', line 4723

def setup_future_usage
  @setup_future_usage
end

#verification_methodObject

Bank account verification method.



4725
4726
4727
# File 'lib/stripe/resources/payment_intent.rb', line 4725

def verification_method
  @verification_method
end