Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



5053
5054
5055
5056
5057
5058
5059
5060
5061
5062
5063
5064
5065
# File 'lib/stripe/resources/payment_intent.rb', line 5053

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



5043
5044
5045
# File 'lib/stripe/resources/payment_intent.rb', line 5043

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



5045
5046
5047
# File 'lib/stripe/resources/payment_intent.rb', line 5045

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



5047
5048
5049
# File 'lib/stripe/resources/payment_intent.rb', line 5047

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



5049
5050
5051
# File 'lib/stripe/resources/payment_intent.rb', line 5049

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



5051
5052
5053
# File 'lib/stripe/resources/payment_intent.rb', line 5051

def return_url
  @return_url
end