Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
# File 'lib/stripe/resources/payment_intent.rb', line 4890

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



4880
4881
4882
# File 'lib/stripe/resources/payment_intent.rb', line 4880

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



4882
4883
4884
# File 'lib/stripe/resources/payment_intent.rb', line 4882

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



4884
4885
4886
# File 'lib/stripe/resources/payment_intent.rb', line 4884

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



4886
4887
4888
# File 'lib/stripe/resources/payment_intent.rb', line 4886

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



4888
4889
4890
# File 'lib/stripe/resources/payment_intent.rb', line 4888

def return_url
  @return_url
end