Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Filters, ManualEntry
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#manual_entry ⇒ Object
Customize manual entry behavior.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
4715 4716 4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 |
# File 'lib/stripe/resources/payment_intent.rb', line 4715 def initialize( filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil ) @filters = filters @manual_entry = manual_entry @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
4705 4706 4707 |
# File 'lib/stripe/resources/payment_intent.rb', line 4705 def filters @filters end |
#manual_entry ⇒ Object
Customize manual entry behavior
4707 4708 4709 |
# File 'lib/stripe/resources/payment_intent.rb', line 4707 def manual_entry @manual_entry end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
4709 4710 4711 |
# File 'lib/stripe/resources/payment_intent.rb', line 4709 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
4711 4712 4713 |
# File 'lib/stripe/resources/payment_intent.rb', line 4711 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
4713 4714 4715 |
# File 'lib/stripe/resources/payment_intent.rb', line 4713 def return_url @return_url end |