Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
# File 'lib/stripe/resources/payment_intent.rb', line 4688

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method



4678
4679
4680
# File 'lib/stripe/resources/payment_intent.rb', line 4678

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



4680
4681
4682
# File 'lib/stripe/resources/payment_intent.rb', line 4680

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



4682
4683
4684
# File 'lib/stripe/resources/payment_intent.rb', line 4682

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



4684
4685
4686
# File 'lib/stripe/resources/payment_intent.rb', line 4684

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



4686
4687
4688
# File 'lib/stripe/resources/payment_intent.rb', line 4686

def return_url
  @return_url
end