Class: Stripe::PaymentIntent::CreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



5394
5395
5396
5397
5398
5399
5400
5401
5402
5403
5404
5405
5406
# File 'lib/stripe/resources/payment_intent.rb', line 5394

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method



5380
5381
5382
# File 'lib/stripe/resources/payment_intent.rb', line 5380

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



5383
5384
5385
# File 'lib/stripe/resources/payment_intent.rb', line 5383

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



5386
5387
5388
# File 'lib/stripe/resources/payment_intent.rb', line 5386

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



5389
5390
5391
# File 'lib/stripe/resources/payment_intent.rb', line 5389

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



5392
5393
5394
# File 'lib/stripe/resources/payment_intent.rb', line 5392

def return_url
  @return_url
end