Class: Stripe::PaymentIntent::CreateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



3878
3879
3880
3881
3882
3883
3884
# File 'lib/stripe/resources/payment_intent.rb', line 3878

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



3868
3869
3870
# File 'lib/stripe/resources/payment_intent.rb', line 3868

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



3870
3871
3872
# File 'lib/stripe/resources/payment_intent.rb', line 3870

def carrier
  @carrier
end

#nameObject

Recipient name.



3872
3873
3874
# File 'lib/stripe/resources/payment_intent.rb', line 3872

def name
  @name
end

#phoneObject

Recipient phone (including extension).



3874
3875
3876
# File 'lib/stripe/resources/payment_intent.rb', line 3874

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



3876
3877
3878
# File 'lib/stripe/resources/payment_intent.rb', line 3876

def tracking_number
  @tracking_number
end