Class: Stripe::PaymentIntent::CreateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



5455
5456
5457
5458
5459
5460
5461
# File 'lib/stripe/resources/payment_intent.rb', line 5455

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



5445
5446
5447
# File 'lib/stripe/resources/payment_intent.rb', line 5445

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



5447
5448
5449
# File 'lib/stripe/resources/payment_intent.rb', line 5447

def carrier
  @carrier
end

#nameObject

Recipient name.



5449
5450
5451
# File 'lib/stripe/resources/payment_intent.rb', line 5449

def name
  @name
end

#phoneObject

Recipient phone (including extension).



5451
5452
5453
# File 'lib/stripe/resources/payment_intent.rb', line 5451

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



5453
5454
5455
# File 'lib/stripe/resources/payment_intent.rb', line 5453

def tracking_number
  @tracking_number
end