Class: Stripe::PaymentIntent::CreateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



3868
3869
3870
3871
3872
3873
3874
# File 'lib/stripe/resources/payment_intent.rb', line 3868

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



3858
3859
3860
# File 'lib/stripe/resources/payment_intent.rb', line 3858

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



3860
3861
3862
# File 'lib/stripe/resources/payment_intent.rb', line 3860

def carrier
  @carrier
end

#nameObject

Recipient name.



3862
3863
3864
# File 'lib/stripe/resources/payment_intent.rb', line 3862

def name
  @name
end

#phoneObject

Recipient phone (including extension).



3864
3865
3866
# File 'lib/stripe/resources/payment_intent.rb', line 3864

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



3866
3867
3868
# File 'lib/stripe/resources/payment_intent.rb', line 3866

def tracking_number
  @tracking_number
end