Class: Stripe::PaymentIntent::CreateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::Shipping
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
5340 5341 5342 5343 5344 5345 5346 |
# File 'lib/stripe/resources/payment_intent.rb', line 5340 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
5330 5331 5332 |
# File 'lib/stripe/resources/payment_intent.rb', line 5330 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
5332 5333 5334 |
# File 'lib/stripe/resources/payment_intent.rb', line 5332 def carrier @carrier end |
#name ⇒ Object
Recipient name.
5334 5335 5336 |
# File 'lib/stripe/resources/payment_intent.rb', line 5334 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
5336 5337 5338 |
# File 'lib/stripe/resources/payment_intent.rb', line 5336 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
5338 5339 5340 |
# File 'lib/stripe/resources/payment_intent.rb', line 5338 def tracking_number @tracking_number end |