Class: Stripe::PaymentIntent::CreateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::Shipping
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
3753 3754 3755 3756 3757 3758 3759 |
# File 'lib/stripe/resources/payment_intent.rb', line 3753 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
3743 3744 3745 |
# File 'lib/stripe/resources/payment_intent.rb', line 3743 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
3745 3746 3747 |
# File 'lib/stripe/resources/payment_intent.rb', line 3745 def carrier @carrier end |
#name ⇒ Object
Recipient name.
3747 3748 3749 |
# File 'lib/stripe/resources/payment_intent.rb', line 3747 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
3749 3750 3751 |
# File 'lib/stripe/resources/payment_intent.rb', line 3749 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
3751 3752 3753 |
# File 'lib/stripe/resources/payment_intent.rb', line 3751 def tracking_number @tracking_number end |