Class: Stripe::PaymentIntent::CreateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::Shipping
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
5324 5325 5326 5327 5328 5329 5330 |
# File 'lib/stripe/resources/payment_intent.rb', line 5324 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
5314 5315 5316 |
# File 'lib/stripe/resources/payment_intent.rb', line 5314 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
5316 5317 5318 |
# File 'lib/stripe/resources/payment_intent.rb', line 5316 def carrier @carrier end |
#name ⇒ Object
Recipient name.
5318 5319 5320 |
# File 'lib/stripe/resources/payment_intent.rb', line 5318 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
5320 5321 5322 |
# File 'lib/stripe/resources/payment_intent.rb', line 5320 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
5322 5323 5324 |
# File 'lib/stripe/resources/payment_intent.rb', line 5322 def tracking_number @tracking_number end |