Class: Stripe::PaymentIntent::CreateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



3783
3784
3785
3786
3787
3788
3789
# File 'lib/stripe/resources/payment_intent.rb', line 3783

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



3773
3774
3775
# File 'lib/stripe/resources/payment_intent.rb', line 3773

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



3775
3776
3777
# File 'lib/stripe/resources/payment_intent.rb', line 3775

def carrier
  @carrier
end

#nameObject

Recipient name.



3777
3778
3779
# File 'lib/stripe/resources/payment_intent.rb', line 3777

def name
  @name
end

#phoneObject

Recipient phone (including extension).



3779
3780
3781
# File 'lib/stripe/resources/payment_intent.rb', line 3779

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



3781
3782
3783
# File 'lib/stripe/resources/payment_intent.rb', line 3781

def tracking_number
  @tracking_number
end