Class: Stripe::PaymentIntent::CreateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



5066
5067
5068
5069
5070
5071
5072
# File 'lib/stripe/resources/payment_intent.rb', line 5066

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



5056
5057
5058
# File 'lib/stripe/resources/payment_intent.rb', line 5056

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



5058
5059
5060
# File 'lib/stripe/resources/payment_intent.rb', line 5058

def carrier
  @carrier
end

#nameObject

Recipient name.



5060
5061
5062
# File 'lib/stripe/resources/payment_intent.rb', line 5060

def name
  @name
end

#phoneObject

Recipient phone (including extension).



5062
5063
5064
# File 'lib/stripe/resources/payment_intent.rb', line 5062

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



5064
5065
5066
# File 'lib/stripe/resources/payment_intent.rb', line 5064

def tracking_number
  @tracking_number
end