Class: Stripe::PaymentIntent::CreateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::Shipping
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
5835 5836 5837 5838 5839 5840 5841 |
# File 'lib/stripe/resources/payment_intent.rb', line 5835 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
5821 5822 5823 |
# File 'lib/stripe/resources/payment_intent.rb', line 5821 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
5824 5825 5826 |
# File 'lib/stripe/resources/payment_intent.rb', line 5824 def carrier @carrier end |
#name ⇒ Object
Recipient name.
5827 5828 5829 |
# File 'lib/stripe/resources/payment_intent.rb', line 5827 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
5830 5831 5832 |
# File 'lib/stripe/resources/payment_intent.rb', line 5830 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
5833 5834 5835 |
# File 'lib/stripe/resources/payment_intent.rb', line 5833 def tracking_number @tracking_number end |