Class: Stripe::PaymentIntent::DecrementAuthorizationParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Hooks, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, transfer_data: nil) ⇒ DecrementAuthorizationParams

Returns a new instance of DecrementAuthorizationParams.



14207
14208
14209
14210
14211
14212
14213
14214
14215
14216
14217
14218
14219
14220
14221
14222
14223
# File 'lib/stripe/resources/payment_intent.rb', line 14207

def initialize(
  amount: nil,
  application_fee_amount: nil,
  description: nil,
  expand: nil,
  hooks: nil,
  metadata: nil,
  transfer_data: nil
)
  @amount = amount
  @application_fee_amount = application_fee_amount
  @description = description
  @expand = expand
  @hooks = hooks
  @metadata = 
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The updated total amount that you intend to collect from the cardholder. This amount must be smaller than the currently authorized amount and greater than the already captured amount.



14192
14193
14194
# File 'lib/stripe/resources/payment_intent.rb', line 14192

def amount
  @amount
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



14194
14195
14196
# File 'lib/stripe/resources/payment_intent.rb', line 14194

def application_fee_amount
  @application_fee_amount
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



14196
14197
14198
# File 'lib/stripe/resources/payment_intent.rb', line 14196

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



14198
14199
14200
# File 'lib/stripe/resources/payment_intent.rb', line 14198

def expand
  @expand
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



14200
14201
14202
# File 'lib/stripe/resources/payment_intent.rb', line 14200

def hooks
  @hooks
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



14202
14203
14204
# File 'lib/stripe/resources/payment_intent.rb', line 14202

def 
  @metadata
end

#transfer_dataObject

The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



14205
14206
14207
# File 'lib/stripe/resources/payment_intent.rb', line 14205

def transfer_data
  @transfer_data
end