Class: Stripe::PaymentIntent::DecrementAuthorizationParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::DecrementAuthorizationParams
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Hooks, TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured.
Instance Method Summary collapse
-
#initialize(amount: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, transfer_data: nil) ⇒ DecrementAuthorizationParams
constructor
A new instance of DecrementAuthorizationParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, transfer_data: nil) ⇒ DecrementAuthorizationParams
Returns a new instance of DecrementAuthorizationParams.
13579 13580 13581 13582 13583 13584 13585 13586 13587 13588 13589 13590 13591 13592 13593 13594 13595 |
# File 'lib/stripe/resources/payment_intent.rb', line 13579 def initialize( amount: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, transfer_data: nil ) @amount = amount @application_fee_amount = application_fee_amount @description = description @expand = @hooks = hooks @metadata = @transfer_data = transfer_data end |
Instance Attribute Details
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder. This amount must be smaller than the currently authorized amount and greater than the already captured amount.
13564 13565 13566 |
# File 'lib/stripe/resources/payment_intent.rb', line 13564 def amount @amount end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
13566 13567 13568 |
# File 'lib/stripe/resources/payment_intent.rb', line 13566 def application_fee_amount @application_fee_amount end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
13568 13569 13570 |
# File 'lib/stripe/resources/payment_intent.rb', line 13568 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
13570 13571 13572 |
# File 'lib/stripe/resources/payment_intent.rb', line 13570 def @expand end |
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle
13572 13573 13574 |
# File 'lib/stripe/resources/payment_intent.rb', line 13572 def hooks @hooks end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
13574 13575 13576 |
# File 'lib/stripe/resources/payment_intent.rb', line 13574 def @metadata end |
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
13577 13578 13579 |
# File 'lib/stripe/resources/payment_intent.rb', line 13577 def transfer_data @transfer_data end |