Class: Stripe::PaymentIntent::DecrementAuthorizationParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::DecrementAuthorizationParams
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AsyncWorkflows, TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#async_workflows ⇒ Object
Automations to be run during the PaymentIntent lifecycle.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured.
Instance Method Summary collapse
-
#initialize(amount: nil, application_fee_amount: nil, async_workflows: nil, description: nil, expand: nil, metadata: nil, transfer_data: nil) ⇒ DecrementAuthorizationParams
constructor
A new instance of DecrementAuthorizationParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, application_fee_amount: nil, async_workflows: nil, description: nil, expand: nil, metadata: nil, transfer_data: nil) ⇒ DecrementAuthorizationParams
Returns a new instance of DecrementAuthorizationParams.
13150 13151 13152 13153 13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 13166 |
# File 'lib/stripe/resources/payment_intent.rb', line 13150 def initialize( amount: nil, application_fee_amount: nil, async_workflows: nil, description: nil, expand: nil, metadata: nil, transfer_data: nil ) @amount = amount @application_fee_amount = application_fee_amount @async_workflows = async_workflows @description = description @expand = @metadata = @transfer_data = transfer_data end |
Instance Attribute Details
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder. This amount must be smaller than the currently authorized amount and greater than the already captured amount.
13135 13136 13137 |
# File 'lib/stripe/resources/payment_intent.rb', line 13135 def amount @amount end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
13137 13138 13139 |
# File 'lib/stripe/resources/payment_intent.rb', line 13137 def application_fee_amount @application_fee_amount end |
#async_workflows ⇒ Object
Automations to be run during the PaymentIntent lifecycle
13139 13140 13141 |
# File 'lib/stripe/resources/payment_intent.rb', line 13139 def async_workflows @async_workflows end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
13141 13142 13143 |
# File 'lib/stripe/resources/payment_intent.rb', line 13141 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
13143 13144 13145 |
# File 'lib/stripe/resources/payment_intent.rb', line 13143 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
13145 13146 13147 |
# File 'lib/stripe/resources/payment_intent.rb', line 13145 def @metadata end |
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
13148 13149 13150 |
# File 'lib/stripe/resources/payment_intent.rb', line 13148 def transfer_data @transfer_data end |