Class: Stripe::PaymentIntent::DecrementAuthorizationParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: AsyncWorkflows, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, application_fee_amount: nil, async_workflows: nil, description: nil, expand: nil, metadata: nil, transfer_data: nil) ⇒ DecrementAuthorizationParams

Returns a new instance of DecrementAuthorizationParams.



12687
12688
12689
12690
12691
12692
12693
12694
12695
12696
12697
12698
12699
12700
12701
12702
12703
# File 'lib/stripe/resources/payment_intent.rb', line 12687

def initialize(
  amount: nil,
  application_fee_amount: nil,
  async_workflows: nil,
  description: nil,
  expand: nil,
  metadata: nil,
  transfer_data: nil
)
  @amount = amount
  @application_fee_amount = application_fee_amount
  @async_workflows = async_workflows
  @description = description
  @expand = expand
  @metadata = 
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The updated total amount that you intend to collect from the cardholder. This amount must be smaller than the currently authorized amount and greater than the already captured amount.



12672
12673
12674
# File 'lib/stripe/resources/payment_intent.rb', line 12672

def amount
  @amount
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total payment amount. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



12674
12675
12676
# File 'lib/stripe/resources/payment_intent.rb', line 12674

def application_fee_amount
  @application_fee_amount
end

#async_workflowsObject

Automations to be run during the PaymentIntent lifecycle



12676
12677
12678
# File 'lib/stripe/resources/payment_intent.rb', line 12676

def async_workflows
  @async_workflows
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



12678
12679
12680
# File 'lib/stripe/resources/payment_intent.rb', line 12678

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



12680
12681
12682
# File 'lib/stripe/resources/payment_intent.rb', line 12680

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



12682
12683
12684
# File 'lib/stripe/resources/payment_intent.rb', line 12682

def 
  @metadata
end

#transfer_dataObject

The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



12685
12686
12687
# File 'lib/stripe/resources/payment_intent.rb', line 12685

def transfer_data
  @transfer_data
end