Class: Stripe::PaymentIntent::DecrementAuthorizationParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::DecrementAuthorizationParams
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AsyncWorkflows, TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#async_workflows ⇒ Object
Automations to be run during the PaymentIntent lifecycle.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured.
Instance Method Summary collapse
-
#initialize(amount: nil, application_fee_amount: nil, async_workflows: nil, description: nil, expand: nil, metadata: nil, transfer_data: nil) ⇒ DecrementAuthorizationParams
constructor
A new instance of DecrementAuthorizationParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, application_fee_amount: nil, async_workflows: nil, description: nil, expand: nil, metadata: nil, transfer_data: nil) ⇒ DecrementAuthorizationParams
Returns a new instance of DecrementAuthorizationParams.
12568 12569 12570 12571 12572 12573 12574 12575 12576 12577 12578 12579 12580 12581 12582 12583 12584 |
# File 'lib/stripe/resources/payment_intent.rb', line 12568 def initialize( amount: nil, application_fee_amount: nil, async_workflows: nil, description: nil, expand: nil, metadata: nil, transfer_data: nil ) @amount = amount @application_fee_amount = application_fee_amount @async_workflows = async_workflows @description = description @expand = @metadata = @transfer_data = transfer_data end |
Instance Attribute Details
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder. This amount must be smaller than the currently authorized amount and greater than the already captured amount.
12553 12554 12555 |
# File 'lib/stripe/resources/payment_intent.rb', line 12553 def amount @amount end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total payment amount. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
12555 12556 12557 |
# File 'lib/stripe/resources/payment_intent.rb', line 12555 def application_fee_amount @application_fee_amount end |
#async_workflows ⇒ Object
Automations to be run during the PaymentIntent lifecycle
12557 12558 12559 |
# File 'lib/stripe/resources/payment_intent.rb', line 12557 def async_workflows @async_workflows end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
12559 12560 12561 |
# File 'lib/stripe/resources/payment_intent.rb', line 12559 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
12561 12562 12563 |
# File 'lib/stripe/resources/payment_intent.rb', line 12561 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
12563 12564 12565 |
# File 'lib/stripe/resources/payment_intent.rb', line 12563 def @metadata end |
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
12566 12567 12568 |
# File 'lib/stripe/resources/payment_intent.rb', line 12566 def transfer_data @transfer_data end |