Class: Stripe::PaymentIntent::IncrementAuthorizationParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: AmountDetails, Hooks, PaymentDetails, PaymentMethodOptions, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_details: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, payment_details: nil, payment_method_options: nil, statement_descriptor: nil, transfer_data: nil) ⇒ IncrementAuthorizationParams

Returns a new instance of IncrementAuthorizationParams.



14642
14643
14644
14645
14646
14647
14648
14649
14650
14651
14652
14653
14654
14655
14656
14657
14658
14659
14660
14661
14662
14663
14664
14665
14666
# File 'lib/stripe/resources/payment_intent.rb', line 14642

def initialize(
  amount: nil,
  amount_details: nil,
  application_fee_amount: nil,
  description: nil,
  expand: nil,
  hooks: nil,
  metadata: nil,
  payment_details: nil,
  payment_method_options: nil,
  statement_descriptor: nil,
  transfer_data: nil
)
  @amount = amount
  @amount_details = amount_details
  @application_fee_amount = application_fee_amount
  @description = description
  @expand = expand
  @hooks = hooks
  @metadata = 
  @payment_details = payment_details
  @payment_method_options = payment_method_options
  @statement_descriptor = statement_descriptor
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The updated total amount that you intend to collect from the cardholder. This amount must be greater than the currently authorized amount.



14619
14620
14621
# File 'lib/stripe/resources/payment_intent.rb', line 14619

def amount
  @amount
end

#amount_detailsObject

Provides industry-specific information about the amount.



14621
14622
14623
# File 'lib/stripe/resources/payment_intent.rb', line 14621

def amount_details
  @amount_details
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



14623
14624
14625
# File 'lib/stripe/resources/payment_intent.rb', line 14623

def application_fee_amount
  @application_fee_amount
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



14625
14626
14627
# File 'lib/stripe/resources/payment_intent.rb', line 14625

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



14627
14628
14629
# File 'lib/stripe/resources/payment_intent.rb', line 14627

def expand
  @expand
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



14629
14630
14631
# File 'lib/stripe/resources/payment_intent.rb', line 14629

def hooks
  @hooks
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



14631
14632
14633
# File 'lib/stripe/resources/payment_intent.rb', line 14631

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



14633
14634
14635
# File 'lib/stripe/resources/payment_intent.rb', line 14633

def payment_details
  @payment_details
end

#payment_method_optionsObject

Payment method-specific configuration for this PaymentIntent.



14635
14636
14637
# File 'lib/stripe/resources/payment_intent.rb', line 14635

def payment_method_options
  @payment_method_options
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card or card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).



14637
14638
14639
# File 'lib/stripe/resources/payment_intent.rb', line 14637

def statement_descriptor
  @statement_descriptor
end

#transfer_dataObject

The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



14640
14641
14642
# File 'lib/stripe/resources/payment_intent.rb', line 14640

def transfer_data
  @transfer_data
end