Class: Stripe::PaymentIntent::IncrementAuthorizationParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, application_fee_amount: nil, description: nil, expand: nil, metadata: nil, statement_descriptor: nil, transfer_data: nil) ⇒ IncrementAuthorizationParams

Returns a new instance of IncrementAuthorizationParams.



8854
8855
8856
8857
8858
8859
8860
8861
8862
8863
8864
8865
8866
8867
8868
8869
8870
# File 'lib/stripe/resources/payment_intent.rb', line 8854

def initialize(
  amount: nil,
  application_fee_amount: nil,
  description: nil,
  expand: nil,
  metadata: nil,
  statement_descriptor: nil,
  transfer_data: nil
)
  @amount = amount
  @application_fee_amount = application_fee_amount
  @description = description
  @expand = expand
  @metadata = 
  @statement_descriptor = statement_descriptor
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The updated total amount that you intend to collect from the cardholder. This amount must be greater than the currently authorized amount.



8839
8840
8841
# File 'lib/stripe/resources/payment_intent.rb', line 8839

def amount
  @amount
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



8841
8842
8843
# File 'lib/stripe/resources/payment_intent.rb', line 8841

def application_fee_amount
  @application_fee_amount
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



8843
8844
8845
# File 'lib/stripe/resources/payment_intent.rb', line 8843

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



8845
8846
8847
# File 'lib/stripe/resources/payment_intent.rb', line 8845

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



8847
8848
8849
# File 'lib/stripe/resources/payment_intent.rb', line 8847

def 
  @metadata
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card or card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).



8849
8850
8851
# File 'lib/stripe/resources/payment_intent.rb', line 8849

def statement_descriptor
  @statement_descriptor
end

#transfer_dataObject

The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



8852
8853
8854
# File 'lib/stripe/resources/payment_intent.rb', line 8852

def transfer_data
  @transfer_data
end