Class: Stripe::PaymentIntent::IncrementAuthorizationParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: AmountDetails, Hooks, PaymentDetails, PaymentMethodOptions, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_details: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, payment_details: nil, payment_method_options: nil, statement_descriptor: nil, transfer_data: nil) ⇒ IncrementAuthorizationParams

Returns a new instance of IncrementAuthorizationParams.



14466
14467
14468
14469
14470
14471
14472
14473
14474
14475
14476
14477
14478
14479
14480
14481
14482
14483
14484
14485
14486
14487
14488
14489
14490
# File 'lib/stripe/resources/payment_intent.rb', line 14466

def initialize(
  amount: nil,
  amount_details: nil,
  application_fee_amount: nil,
  description: nil,
  expand: nil,
  hooks: nil,
  metadata: nil,
  payment_details: nil,
  payment_method_options: nil,
  statement_descriptor: nil,
  transfer_data: nil
)
  @amount = amount
  @amount_details = amount_details
  @application_fee_amount = application_fee_amount
  @description = description
  @expand = expand
  @hooks = hooks
  @metadata = 
  @payment_details = payment_details
  @payment_method_options = payment_method_options
  @statement_descriptor = statement_descriptor
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The updated total amount that you intend to collect from the cardholder. This amount must be greater than the currently authorized amount.



14443
14444
14445
# File 'lib/stripe/resources/payment_intent.rb', line 14443

def amount
  @amount
end

#amount_detailsObject

Provides industry-specific information about the amount.



14445
14446
14447
# File 'lib/stripe/resources/payment_intent.rb', line 14445

def amount_details
  @amount_details
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



14447
14448
14449
# File 'lib/stripe/resources/payment_intent.rb', line 14447

def application_fee_amount
  @application_fee_amount
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



14449
14450
14451
# File 'lib/stripe/resources/payment_intent.rb', line 14449

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



14451
14452
14453
# File 'lib/stripe/resources/payment_intent.rb', line 14451

def expand
  @expand
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



14453
14454
14455
# File 'lib/stripe/resources/payment_intent.rb', line 14453

def hooks
  @hooks
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



14455
14456
14457
# File 'lib/stripe/resources/payment_intent.rb', line 14455

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



14457
14458
14459
# File 'lib/stripe/resources/payment_intent.rb', line 14457

def payment_details
  @payment_details
end

#payment_method_optionsObject

Payment method-specific configuration for this PaymentIntent.



14459
14460
14461
# File 'lib/stripe/resources/payment_intent.rb', line 14459

def payment_method_options
  @payment_method_options
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card or card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).



14461
14462
14463
# File 'lib/stripe/resources/payment_intent.rb', line 14461

def statement_descriptor
  @statement_descriptor
end

#transfer_dataObject

The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



14464
14465
14466
# File 'lib/stripe/resources/payment_intent.rb', line 14464

def transfer_data
  @transfer_data
end