Class: Stripe::PaymentIntent::IncrementAuthorizationParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, application_fee_amount: nil, description: nil, expand: nil, metadata: nil, statement_descriptor: nil, transfer_data: nil) ⇒ IncrementAuthorizationParams

Returns a new instance of IncrementAuthorizationParams.



8824
8825
8826
8827
8828
8829
8830
8831
8832
8833
8834
8835
8836
8837
8838
8839
8840
# File 'lib/stripe/resources/payment_intent.rb', line 8824

def initialize(
  amount: nil,
  application_fee_amount: nil,
  description: nil,
  expand: nil,
  metadata: nil,
  statement_descriptor: nil,
  transfer_data: nil
)
  @amount = amount
  @application_fee_amount = application_fee_amount
  @description = description
  @expand = expand
  @metadata = 
  @statement_descriptor = statement_descriptor
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The updated total amount that you intend to collect from the cardholder. This amount must be greater than the currently authorized amount.



8809
8810
8811
# File 'lib/stripe/resources/payment_intent.rb', line 8809

def amount
  @amount
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



8811
8812
8813
# File 'lib/stripe/resources/payment_intent.rb', line 8811

def application_fee_amount
  @application_fee_amount
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



8813
8814
8815
# File 'lib/stripe/resources/payment_intent.rb', line 8813

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



8815
8816
8817
# File 'lib/stripe/resources/payment_intent.rb', line 8815

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



8817
8818
8819
# File 'lib/stripe/resources/payment_intent.rb', line 8817

def 
  @metadata
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card or card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).



8819
8820
8821
# File 'lib/stripe/resources/payment_intent.rb', line 8819

def statement_descriptor
  @statement_descriptor
end

#transfer_dataObject

The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



8822
8823
8824
# File 'lib/stripe/resources/payment_intent.rb', line 8822

def transfer_data
  @transfer_data
end