Class: Stripe::PaymentIntent::IncrementAuthorizationParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Hooks, PaymentMethodOptions, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, payment_method_options: nil, statement_descriptor: nil, transfer_data: nil) ⇒ IncrementAuthorizationParams

Returns a new instance of IncrementAuthorizationParams.



13350
13351
13352
13353
13354
13355
13356
13357
13358
13359
13360
13361
13362
13363
13364
13365
13366
13367
13368
13369
13370
# File 'lib/stripe/resources/payment_intent.rb', line 13350

def initialize(
  amount: nil,
  application_fee_amount: nil,
  description: nil,
  expand: nil,
  hooks: nil,
  metadata: nil,
  payment_method_options: nil,
  statement_descriptor: nil,
  transfer_data: nil
)
  @amount = amount
  @application_fee_amount = application_fee_amount
  @description = description
  @expand = expand
  @hooks = hooks
  @metadata = 
  @payment_method_options = payment_method_options
  @statement_descriptor = statement_descriptor
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The updated total amount that you intend to collect from the cardholder. This amount must be greater than the currently authorized amount.



13331
13332
13333
# File 'lib/stripe/resources/payment_intent.rb', line 13331

def amount
  @amount
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



13333
13334
13335
# File 'lib/stripe/resources/payment_intent.rb', line 13333

def application_fee_amount
  @application_fee_amount
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



13335
13336
13337
# File 'lib/stripe/resources/payment_intent.rb', line 13335

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



13337
13338
13339
# File 'lib/stripe/resources/payment_intent.rb', line 13337

def expand
  @expand
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



13339
13340
13341
# File 'lib/stripe/resources/payment_intent.rb', line 13339

def hooks
  @hooks
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



13341
13342
13343
# File 'lib/stripe/resources/payment_intent.rb', line 13341

def 
  @metadata
end

#payment_method_optionsObject

Payment method-specific configuration for this PaymentIntent.



13343
13344
13345
# File 'lib/stripe/resources/payment_intent.rb', line 13343

def payment_method_options
  @payment_method_options
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card or card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).



13345
13346
13347
# File 'lib/stripe/resources/payment_intent.rb', line 13345

def statement_descriptor
  @statement_descriptor
end

#transfer_dataObject

The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



13348
13349
13350
# File 'lib/stripe/resources/payment_intent.rb', line 13348

def transfer_data
  @transfer_data
end