Class: Stripe::PaymentIntent::IncrementAuthorizationParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::IncrementAuthorizationParams
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card or card charge.
-
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured.
Instance Method Summary collapse
-
#initialize(amount: nil, application_fee_amount: nil, description: nil, expand: nil, metadata: nil, statement_descriptor: nil, transfer_data: nil) ⇒ IncrementAuthorizationParams
constructor
A new instance of IncrementAuthorizationParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, application_fee_amount: nil, description: nil, expand: nil, metadata: nil, statement_descriptor: nil, transfer_data: nil) ⇒ IncrementAuthorizationParams
Returns a new instance of IncrementAuthorizationParams.
8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 8515 8516 8517 8518 8519 8520 8521 |
# File 'lib/stripe/resources/payment_intent.rb', line 8505 def initialize( amount: nil, application_fee_amount: nil, description: nil, expand: nil, metadata: nil, statement_descriptor: nil, transfer_data: nil ) @amount = amount @application_fee_amount = application_fee_amount @description = description @expand = @metadata = @statement_descriptor = statement_descriptor @transfer_data = transfer_data end |
Instance Attribute Details
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder. This amount must be greater than the currently authorized amount.
8490 8491 8492 |
# File 'lib/stripe/resources/payment_intent.rb', line 8490 def amount @amount end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
8492 8493 8494 |
# File 'lib/stripe/resources/payment_intent.rb', line 8492 def application_fee_amount @application_fee_amount end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
8494 8495 8496 |
# File 'lib/stripe/resources/payment_intent.rb', line 8494 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
8496 8497 8498 |
# File 'lib/stripe/resources/payment_intent.rb', line 8496 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
8498 8499 8500 |
# File 'lib/stripe/resources/payment_intent.rb', line 8498 def @metadata end |
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card or card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
8500 8501 8502 |
# File 'lib/stripe/resources/payment_intent.rb', line 8500 def statement_descriptor @statement_descriptor end |
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
8503 8504 8505 |
# File 'lib/stripe/resources/payment_intent.rb', line 8503 def transfer_data @transfer_data end |