Class: Stripe::PaymentIntent::IncrementAuthorizationParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: AsyncWorkflows, PaymentMethodOptions, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, application_fee_amount: nil, async_workflows: nil, description: nil, expand: nil, metadata: nil, payment_method_options: nil, statement_descriptor: nil, transfer_data: nil) ⇒ IncrementAuthorizationParams

Returns a new instance of IncrementAuthorizationParams.



12704
12705
12706
12707
12708
12709
12710
12711
12712
12713
12714
12715
12716
12717
12718
12719
12720
12721
12722
12723
12724
# File 'lib/stripe/resources/payment_intent.rb', line 12704

def initialize(
  amount: nil,
  application_fee_amount: nil,
  async_workflows: nil,
  description: nil,
  expand: nil,
  metadata: nil,
  payment_method_options: nil,
  statement_descriptor: nil,
  transfer_data: nil
)
  @amount = amount
  @application_fee_amount = application_fee_amount
  @async_workflows = async_workflows
  @description = description
  @expand = expand
  @metadata = 
  @payment_method_options = payment_method_options
  @statement_descriptor = statement_descriptor
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The updated total amount that you intend to collect from the cardholder. This amount must be greater than the currently authorized amount.



12685
12686
12687
# File 'lib/stripe/resources/payment_intent.rb', line 12685

def amount
  @amount
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total payment amount. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



12687
12688
12689
# File 'lib/stripe/resources/payment_intent.rb', line 12687

def application_fee_amount
  @application_fee_amount
end

#async_workflowsObject

Automations to be run during the PaymentIntent lifecycle



12689
12690
12691
# File 'lib/stripe/resources/payment_intent.rb', line 12689

def async_workflows
  @async_workflows
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



12691
12692
12693
# File 'lib/stripe/resources/payment_intent.rb', line 12691

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



12693
12694
12695
# File 'lib/stripe/resources/payment_intent.rb', line 12693

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



12695
12696
12697
# File 'lib/stripe/resources/payment_intent.rb', line 12695

def 
  @metadata
end

#payment_method_optionsObject

Payment method-specific configuration for this PaymentIntent.



12697
12698
12699
# File 'lib/stripe/resources/payment_intent.rb', line 12697

def payment_method_options
  @payment_method_options
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card or card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).



12699
12700
12701
# File 'lib/stripe/resources/payment_intent.rb', line 12699

def statement_descriptor
  @statement_descriptor
end

#transfer_dataObject

The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



12702
12703
12704
# File 'lib/stripe/resources/payment_intent.rb', line 12702

def transfer_data
  @transfer_data
end