Class: Stripe::PaymentIntent::IncrementAuthorizationParams::AmountDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: LineItem, Shipping, Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails

Returns a new instance of AmountDetails.



15929
15930
15931
15932
15933
15934
# File 'lib/stripe/resources/payment_intent.rb', line 15929

def initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil)
  @discount_amount = discount_amount
  @line_items = line_items
  @shipping = shipping
  @tax = tax
end

Instance Attribute Details

#discount_amountObject

The amount an item was discounted for.



15921
15922
15923
# File 'lib/stripe/resources/payment_intent.rb', line 15921

def discount_amount
  @discount_amount
end

#line_itemsObject

A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.



15923
15924
15925
# File 'lib/stripe/resources/payment_intent.rb', line 15923

def line_items
  @line_items
end

#shippingObject

Contains information about the shipping portion of the amount.



15925
15926
15927
# File 'lib/stripe/resources/payment_intent.rb', line 15925

def shipping
  @shipping
end

#taxObject

Contains information about the tax portion of the amount.



15927
15928
15929
# File 'lib/stripe/resources/payment_intent.rb', line 15927

def tax
  @tax
end