Class: Stripe::PaymentIntent::IncrementAuthorizationParams::AmountDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::IncrementAuthorizationParams::AmountDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: LineItem, Shipping, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The amount an item was discounted for.
-
#line_items ⇒ Object
A list of line items, each containing information about a product in the PaymentIntent.
-
#shipping ⇒ Object
Contains information about the shipping portion of the amount.
-
#tax ⇒ Object
Contains information about the tax portion of the amount.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails
constructor
A new instance of AmountDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails
Returns a new instance of AmountDetails.
14372 14373 14374 14375 14376 14377 |
# File 'lib/stripe/resources/payment_intent.rb', line 14372 def initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) @discount_amount = discount_amount @line_items = line_items @shipping = shipping @tax = tax end |
Instance Attribute Details
#discount_amount ⇒ Object
The amount an item was discounted for.
14364 14365 14366 |
# File 'lib/stripe/resources/payment_intent.rb', line 14364 def discount_amount @discount_amount end |
#line_items ⇒ Object
A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.
14366 14367 14368 |
# File 'lib/stripe/resources/payment_intent.rb', line 14366 def line_items @line_items end |
#shipping ⇒ Object
Contains information about the shipping portion of the amount.
14368 14369 14370 |
# File 'lib/stripe/resources/payment_intent.rb', line 14368 def shipping @shipping end |
#tax ⇒ Object
Contains information about the tax portion of the amount.
14370 14371 14372 |
# File 'lib/stripe/resources/payment_intent.rb', line 14370 def tax @tax end |