Class: Stripe::PaymentIntent::IncrementAuthorizationParams::AmountDetails::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::IncrementAuthorizationParams::AmountDetails::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The amount an item was discounted for.
-
#payment_method_options ⇒ Object
Payment method-specific information for line items.
-
#product_code ⇒ Object
Unique identifier of the product.
-
#product_name ⇒ Object
Name of the product.
-
#quantity ⇒ Object
Number of items of the product.
-
#tax ⇒ Object
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
Cost of the product.
-
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
Returns a new instance of LineItem.
14495 14496 14497 14498 14499 14500 14501 14502 14503 14504 14505 14506 14507 14508 14509 14510 14511 14512 14513 |
# File 'lib/stripe/resources/payment_intent.rb', line 14495 def initialize( discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil ) @discount_amount = discount_amount @payment_method_options = @product_code = product_code @product_name = product_name @quantity = quantity @tax = tax @unit_cost = unit_cost @unit_of_measure = unit_of_measure end |
Instance Attribute Details
#discount_amount ⇒ Object
The amount an item was discounted for. Positive integer.
14479 14480 14481 |
# File 'lib/stripe/resources/payment_intent.rb', line 14479 def discount_amount @discount_amount end |
#payment_method_options ⇒ Object
Payment method-specific information for line items.
14481 14482 14483 |
# File 'lib/stripe/resources/payment_intent.rb', line 14481 def @payment_method_options end |
#product_code ⇒ Object
Unique identifier of the product. At most 12 characters long.
14483 14484 14485 |
# File 'lib/stripe/resources/payment_intent.rb', line 14483 def product_code @product_code end |
#product_name ⇒ Object
Name of the product. At most 100 characters long.
14485 14486 14487 |
# File 'lib/stripe/resources/payment_intent.rb', line 14485 def product_name @product_name end |
#quantity ⇒ Object
Number of items of the product. Positive integer.
14487 14488 14489 |
# File 'lib/stripe/resources/payment_intent.rb', line 14487 def quantity @quantity end |
#tax ⇒ Object
Contains information about the tax on the item.
14489 14490 14491 |
# File 'lib/stripe/resources/payment_intent.rb', line 14489 def tax @tax end |
#unit_cost ⇒ Object
Cost of the product. Non-negative integer.
14491 14492 14493 |
# File 'lib/stripe/resources/payment_intent.rb', line 14491 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
14493 14494 14495 |
# File 'lib/stripe/resources/payment_intent.rb', line 14493 def unit_of_measure @unit_of_measure end |