Class: Stripe::PaymentIntent::IncrementAuthorizationParams::AmountDetails::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::IncrementAuthorizationParams::AmountDetails::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The amount an item was discounted for.
-
#payment_method_options ⇒ Object
Payment method-specific information for line items.
-
#product_code ⇒ Object
Unique identifier of the product.
-
#product_name ⇒ Object
Name of the product.
-
#quantity ⇒ Object
Number of items of the product.
-
#tax ⇒ Object
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
Cost of the product.
-
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
Returns a new instance of LineItem.
14319 14320 14321 14322 14323 14324 14325 14326 14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 14337 |
# File 'lib/stripe/resources/payment_intent.rb', line 14319 def initialize( discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil ) @discount_amount = discount_amount @payment_method_options = @product_code = product_code @product_name = product_name @quantity = quantity @tax = tax @unit_cost = unit_cost @unit_of_measure = unit_of_measure end |
Instance Attribute Details
#discount_amount ⇒ Object
The amount an item was discounted for. Positive integer.
14303 14304 14305 |
# File 'lib/stripe/resources/payment_intent.rb', line 14303 def discount_amount @discount_amount end |
#payment_method_options ⇒ Object
Payment method-specific information for line items.
14305 14306 14307 |
# File 'lib/stripe/resources/payment_intent.rb', line 14305 def @payment_method_options end |
#product_code ⇒ Object
Unique identifier of the product. At most 12 characters long.
14307 14308 14309 |
# File 'lib/stripe/resources/payment_intent.rb', line 14307 def product_code @product_code end |
#product_name ⇒ Object
Name of the product. At most 100 characters long.
14309 14310 14311 |
# File 'lib/stripe/resources/payment_intent.rb', line 14309 def product_name @product_name end |
#quantity ⇒ Object
Number of items of the product. Positive integer.
14311 14312 14313 |
# File 'lib/stripe/resources/payment_intent.rb', line 14311 def quantity @quantity end |
#tax ⇒ Object
Contains information about the tax on the item.
14313 14314 14315 |
# File 'lib/stripe/resources/payment_intent.rb', line 14313 def tax @tax end |
#unit_cost ⇒ Object
Cost of the product. Non-negative integer.
14315 14316 14317 |
# File 'lib/stripe/resources/payment_intent.rb', line 14315 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
14317 14318 14319 |
# File 'lib/stripe/resources/payment_intent.rb', line 14317 def unit_of_measure @unit_of_measure end |