Class: Stripe::PaymentIntent::IncrementAuthorizationParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer_reference: nil, order_reference: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



14587
14588
14589
14590
# File 'lib/stripe/resources/payment_intent.rb', line 14587

def initialize(customer_reference: nil, order_reference: nil)
  @customer_reference = customer_reference
  @order_reference = order_reference
end

Instance Attribute Details

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



14583
14584
14585
# File 'lib/stripe/resources/payment_intent.rb', line 14583

def customer_reference
  @customer_reference
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



14585
14586
14587
# File 'lib/stripe/resources/payment_intent.rb', line 14585

def order_reference
  @order_reference
end