Class: Stripe::PaymentIntent::IncrementAuthorizationParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::IncrementAuthorizationParams::PaymentDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
Instance Method Summary collapse
-
#initialize(customer_reference: nil, order_reference: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(customer_reference: nil, order_reference: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
14411 14412 14413 14414 |
# File 'lib/stripe/resources/payment_intent.rb', line 14411 def initialize(customer_reference: nil, order_reference: nil) @customer_reference = customer_reference @order_reference = order_reference end |
Instance Attribute Details
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
14407 14408 14409 |
# File 'lib/stripe/resources/payment_intent.rb', line 14407 def customer_reference @customer_reference end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
14409 14410 14411 |
# File 'lib/stripe/resources/payment_intent.rb', line 14409 def order_reference @order_reference end |