Class: Stripe::PaymentIntent::IncrementAuthorizationParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::IncrementAuthorizationParams::PaymentMethodOptions
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Card
Instance Attribute Summary collapse
-
#card ⇒ Object
Configuration for any card payments attempted on this PaymentIntent.
Instance Method Summary collapse
-
#initialize(card: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(card: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
12671 12672 12673 |
# File 'lib/stripe/resources/payment_intent.rb', line 12671 def initialize(card: nil) @card = card end |
Instance Attribute Details
#card ⇒ Object
Configuration for any card payments attempted on this PaymentIntent.
12669 12670 12671 |
# File 'lib/stripe/resources/payment_intent.rb', line 12669 def card @card end |