Class: Stripe::PaymentIntent::IncrementAuthorizationParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::IncrementAuthorizationParams::TransferData
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds.
Instance Method Summary collapse
-
#initialize(amount: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil) ⇒ TransferData
Returns a new instance of TransferData.
13298 13299 13300 |
# File 'lib/stripe/resources/payment_intent.rb', line 13298 def initialize(amount: nil) @amount = amount end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds.
13296 13297 13298 |
# File 'lib/stripe/resources/payment_intent.rb', line 13296 def amount @amount end |