Class: Stripe::PaymentIntent::LastPaymentError

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#advice_codeObject (readonly)

For card errors resulting from a card issuer decline, a short string indicating [how to proceed with an error](docs.stripe.com/declines#retrying-issuer-declines) if they provide one.



359
360
361
# File 'lib/stripe/resources/payment_intent.rb', line 359

def advice_code
  @advice_code
end

#chargeObject (readonly)

For card errors, the ID of the failed charge.



361
362
363
# File 'lib/stripe/resources/payment_intent.rb', line 361

def charge
  @charge
end

#codeObject (readonly)

For some errors that could be handled programmatically, a short string indicating the [error code](docs.stripe.com/error-codes) reported.



363
364
365
# File 'lib/stripe/resources/payment_intent.rb', line 363

def code
  @code
end

#decline_codeObject (readonly)

For card errors resulting from a card issuer decline, a short string indicating the [card issuer’s reason for the decline](docs.stripe.com/declines#issuer-declines) if they provide one.



365
366
367
# File 'lib/stripe/resources/payment_intent.rb', line 365

def decline_code
  @decline_code
end

#doc_urlObject (readonly)

A URL to more information about the [error code](docs.stripe.com/error-codes) reported.



367
368
369
# File 'lib/stripe/resources/payment_intent.rb', line 367

def doc_url
  @doc_url
end

#messageObject (readonly)

A human-readable message providing more details about the error. For card errors, these messages can be shown to your users.



369
370
371
# File 'lib/stripe/resources/payment_intent.rb', line 369

def message
  @message
end

#network_advice_codeObject (readonly)

For card errors resulting from a card issuer decline, a 2 digit code which indicates the advice given to merchant by the card network on how to proceed with an error.



371
372
373
# File 'lib/stripe/resources/payment_intent.rb', line 371

def network_advice_code
  @network_advice_code
end

#network_decline_codeObject (readonly)

For payments declined by the network, an alphanumeric code which indicates the reason the payment failed.



373
374
375
# File 'lib/stripe/resources/payment_intent.rb', line 373

def network_decline_code
  @network_decline_code
end

#paramObject (readonly)

If the error is parameter-specific, the parameter related to the error. For example, you can use this to display a message near the correct form field.



375
376
377
# File 'lib/stripe/resources/payment_intent.rb', line 375

def param
  @param
end

#payment_intentObject (readonly)

A PaymentIntent guides you through the process of collecting a payment from your customer. We recommend that you create exactly one PaymentIntent for each order or customer session in your system. You can reference the PaymentIntent later to see the history of payment attempts for a particular session.

A PaymentIntent transitions through [multiple statuses](/payments/paymentintents/lifecycle) throughout its lifetime as it interfaces with Stripe.js to perform authentication flows and ultimately creates at most one successful charge.

Related guide: [Payment Intents API](docs.stripe.com/payments/payment-intents)



387
388
389
# File 'lib/stripe/resources/payment_intent.rb', line 387

def payment_intent
  @payment_intent
end

#payment_methodObject (readonly)

PaymentMethod objects represent your customer’s payment instruments. You can use them with [PaymentIntents](docs.stripe.com/payments/payment-intents) to collect payments or save them to Customer objects to store instrument details for future payments.

Related guides: [Payment Methods](docs.stripe.com/payments/payment-methods) and [More Payment Scenarios](docs.stripe.com/payments/more-payment-scenarios).



393
394
395
# File 'lib/stripe/resources/payment_intent.rb', line 393

def payment_method
  @payment_method
end

#payment_method_typeObject (readonly)

If the error is specific to the type of payment method, the payment method type that had a problem. This field is only populated for invoice-related errors.



395
396
397
# File 'lib/stripe/resources/payment_intent.rb', line 395

def payment_method_type
  @payment_method_type
end

#request_log_urlObject (readonly)

A URL to the request log entry in your dashboard.



397
398
399
# File 'lib/stripe/resources/payment_intent.rb', line 397

def request_log_url
  @request_log_url
end

#setup_intentObject (readonly)

A SetupIntent guides you through the process of setting up and saving a customer’s payment credentials for future payments. For example, you can use a SetupIntent to set up and save your customer’s card without immediately collecting a payment. Later, you can use [PaymentIntents](api.stripe.com#payment_intents) to drive the payment flow.

Create a SetupIntent when you’re ready to collect your customer’s payment credentials. Don’t maintain long-lived, unconfirmed SetupIntents because they might not be valid. The SetupIntent transitions through multiple [statuses](docs.stripe.com/payments/intents#intent-statuses) as it guides you through the setup process.

Successful SetupIntents result in payment credentials that are optimized for future payments. For example, cardholders in [certain regions](stripe.com/guides/strong-customer-authentication) might need to be run through [Strong Customer Authentication](docs.stripe.com/strong-customer-authentication) during payment method collection to streamline later [off-session payments](docs.stripe.com/payments/setup-intents). If you use the SetupIntent with a [Customer](api.stripe.com#setup_intent_object-customer), it automatically attaches the resulting payment method to that Customer after successful setup. We recommend using SetupIntents or [setup_future_usage](api.stripe.com#payment_intent_object-setup_future_usage) on PaymentIntents to save payment methods to prevent saving invalid or unoptimized payment methods.

By using SetupIntents, you can reduce friction for your customers, even as regulations change over time.

Related guide: [Setup Intents API](docs.stripe.com/payments/setup-intents)



419
420
421
# File 'lib/stripe/resources/payment_intent.rb', line 419

def setup_intent
  @setup_intent
end

#sourceObject (readonly)

Attribute for field source



421
422
423
# File 'lib/stripe/resources/payment_intent.rb', line 421

def source
  @source
end

#typeObject (readonly)

The type of error returned. One of ‘api_error`, `card_error`, `idempotency_error`, or `invalid_request_error`



423
424
425
# File 'lib/stripe/resources/payment_intent.rb', line 423

def type
  @type
end

Class Method Details

.field_remappingsObject



429
430
431
# File 'lib/stripe/resources/payment_intent.rb', line 429

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



425
426
427
# File 'lib/stripe/resources/payment_intent.rb', line 425

def self.inner_class_types
  @inner_class_types = {}
end