Class: Stripe::PaymentIntent::LastPaymentError
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::LastPaymentError
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#advice_code ⇒ Object
readonly
For card errors resulting from a card issuer decline, a short string indicating [how to proceed with an error](stripe.com/docs/declines#retrying-issuer-declines) if they provide one.
-
#charge ⇒ Object
readonly
For card errors, the ID of the failed charge.
-
#code ⇒ Object
readonly
For some errors that could be handled programmatically, a short string indicating the [error code](stripe.com/docs/error-codes) reported.
-
#decline_code ⇒ Object
readonly
For card errors resulting from a card issuer decline, a short string indicating the [card issuer’s reason for the decline](stripe.com/docs/declines#issuer-declines) if they provide one.
-
#doc_url ⇒ Object
readonly
A URL to more information about the [error code](stripe.com/docs/error-codes) reported.
-
#message ⇒ Object
readonly
A human-readable message providing more details about the error.
-
#network_advice_code ⇒ Object
readonly
For card errors resulting from a card issuer decline, a 2 digit code which indicates the advice given to merchant by the card network on how to proceed with an error.
-
#network_decline_code ⇒ Object
readonly
For payments declined by the network, an alphanumeric code which indicates the reason the payment failed.
-
#param ⇒ Object
readonly
If the error is parameter-specific, the parameter related to the error.
-
#payment_intent ⇒ Object
readonly
A PaymentIntent guides you through the process of collecting a payment from your customer.
-
#payment_method ⇒ Object
readonly
PaymentMethod objects represent your customer’s payment instruments.
-
#payment_method_type ⇒ Object
readonly
If the error is specific to the type of payment method, the payment method type that had a problem.
-
#request_log_url ⇒ Object
readonly
A URL to the request log entry in your dashboard.
-
#setup_intent ⇒ Object
readonly
A SetupIntent guides you through the process of setting up and saving a customer’s payment credentials for future payments.
-
#source ⇒ Object
readonly
Attribute for field source.
-
#type ⇒ Object
readonly
The type of error returned.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#advice_code ⇒ Object (readonly)
For card errors resulting from a card issuer decline, a short string indicating [how to proceed with an error](stripe.com/docs/declines#retrying-issuer-declines) if they provide one.
116 117 118 |
# File 'lib/stripe/resources/payment_intent.rb', line 116 def advice_code @advice_code end |
#charge ⇒ Object (readonly)
For card errors, the ID of the failed charge.
118 119 120 |
# File 'lib/stripe/resources/payment_intent.rb', line 118 def charge @charge end |
#code ⇒ Object (readonly)
For some errors that could be handled programmatically, a short string indicating the [error code](stripe.com/docs/error-codes) reported.
120 121 122 |
# File 'lib/stripe/resources/payment_intent.rb', line 120 def code @code end |
#decline_code ⇒ Object (readonly)
For card errors resulting from a card issuer decline, a short string indicating the [card issuer’s reason for the decline](stripe.com/docs/declines#issuer-declines) if they provide one.
122 123 124 |
# File 'lib/stripe/resources/payment_intent.rb', line 122 def decline_code @decline_code end |
#doc_url ⇒ Object (readonly)
A URL to more information about the [error code](stripe.com/docs/error-codes) reported.
124 125 126 |
# File 'lib/stripe/resources/payment_intent.rb', line 124 def doc_url @doc_url end |
#message ⇒ Object (readonly)
A human-readable message providing more details about the error. For card errors, these messages can be shown to your users.
126 127 128 |
# File 'lib/stripe/resources/payment_intent.rb', line 126 def @message end |
#network_advice_code ⇒ Object (readonly)
For card errors resulting from a card issuer decline, a 2 digit code which indicates the advice given to merchant by the card network on how to proceed with an error.
128 129 130 |
# File 'lib/stripe/resources/payment_intent.rb', line 128 def network_advice_code @network_advice_code end |
#network_decline_code ⇒ Object (readonly)
For payments declined by the network, an alphanumeric code which indicates the reason the payment failed.
130 131 132 |
# File 'lib/stripe/resources/payment_intent.rb', line 130 def network_decline_code @network_decline_code end |
#param ⇒ Object (readonly)
If the error is parameter-specific, the parameter related to the error. For example, you can use this to display a message near the correct form field.
132 133 134 |
# File 'lib/stripe/resources/payment_intent.rb', line 132 def param @param end |
#payment_intent ⇒ Object (readonly)
A PaymentIntent guides you through the process of collecting a payment from your customer. We recommend that you create exactly one PaymentIntent for each order or customer session in your system. You can reference the PaymentIntent later to see the history of payment attempts for a particular session.
A PaymentIntent transitions through [multiple statuses](stripe.com/docs/payments/intents#intent-statuses) throughout its lifetime as it interfaces with Stripe.js to perform authentication flows and ultimately creates at most one successful charge.
Related guide: [Payment Intents API](stripe.com/docs/payments/payment-intents)
144 145 146 |
# File 'lib/stripe/resources/payment_intent.rb', line 144 def payment_intent @payment_intent end |
#payment_method ⇒ Object (readonly)
PaymentMethod objects represent your customer’s payment instruments. You can use them with [PaymentIntents](stripe.com/docs/payments/payment-intents) to collect payments or save them to Customer objects to store instrument details for future payments.
Related guides: [Payment Methods](stripe.com/docs/payments/payment-methods) and [More Payment Scenarios](stripe.com/docs/payments/more-payment-scenarios).
150 151 152 |
# File 'lib/stripe/resources/payment_intent.rb', line 150 def payment_method @payment_method end |
#payment_method_type ⇒ Object (readonly)
If the error is specific to the type of payment method, the payment method type that had a problem. This field is only populated for invoice-related errors.
152 153 154 |
# File 'lib/stripe/resources/payment_intent.rb', line 152 def payment_method_type @payment_method_type end |
#request_log_url ⇒ Object (readonly)
A URL to the request log entry in your dashboard.
154 155 156 |
# File 'lib/stripe/resources/payment_intent.rb', line 154 def request_log_url @request_log_url end |
#setup_intent ⇒ Object (readonly)
A SetupIntent guides you through the process of setting up and saving a customer’s payment credentials for future payments. For example, you can use a SetupIntent to set up and save your customer’s card without immediately collecting a payment. Later, you can use [PaymentIntents](stripe.com/docs/api#payment_intents) to drive the payment flow.
Create a SetupIntent when you’re ready to collect your customer’s payment credentials. Don’t maintain long-lived, unconfirmed SetupIntents because they might not be valid. The SetupIntent transitions through multiple [statuses](docs.stripe.com/payments/intents#intent-statuses) as it guides you through the setup process.
Successful SetupIntents result in payment credentials that are optimized for future payments. For example, cardholders in [certain regions](stripe.com/guides/strong-customer-authentication) might need to be run through [Strong Customer Authentication](docs.stripe.com/strong-customer-authentication) during payment method collection to streamline later [off-session payments](docs.stripe.com/payments/setup-intents). If you use the SetupIntent with a [Customer](stripe.com/docs/api#setup_intent_object-customer), it automatically attaches the resulting payment method to that Customer after successful setup. We recommend using SetupIntents or [setup_future_usage](stripe.com/docs/api#payment_intent_object-setup_future_usage) on PaymentIntents to save payment methods to prevent saving invalid or unoptimized payment methods.
By using SetupIntents, you can reduce friction for your customers, even as regulations change over time.
Related guide: [Setup Intents API](docs.stripe.com/payments/setup-intents)
176 177 178 |
# File 'lib/stripe/resources/payment_intent.rb', line 176 def setup_intent @setup_intent end |
#source ⇒ Object (readonly)
Attribute for field source
178 179 180 |
# File 'lib/stripe/resources/payment_intent.rb', line 178 def source @source end |
#type ⇒ Object (readonly)
The type of error returned. One of ‘api_error`, `card_error`, `idempotency_error`, or `invalid_request_error`
180 181 182 |
# File 'lib/stripe/resources/payment_intent.rb', line 180 def type @type end |
Class Method Details
.field_remappings ⇒ Object
186 187 188 |
# File 'lib/stripe/resources/payment_intent.rb', line 186 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
182 183 184 |
# File 'lib/stripe/resources/payment_intent.rb', line 182 def self.inner_class_types @inner_class_types = {} end |