Class: Stripe::PaymentIntent::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



2049
2050
2051
2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
2062
2063
2064
2065
# File 'lib/stripe/resources/payment_intent.rb', line 2049

def initialize(
  created: nil,
  customer: nil,
  customer_account: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil
)
  @created = created
  @customer = customer
  @customer_account = 
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp or a dictionary with a number of different query options.



2035
2036
2037
# File 'lib/stripe/resources/payment_intent.rb', line 2035

def created
  @created
end

#customerObject

Only return PaymentIntents for the customer that this customer ID specifies.



2037
2038
2039
# File 'lib/stripe/resources/payment_intent.rb', line 2037

def customer
  @customer
end

#customer_accountObject

Only return PaymentIntents for the account that this ID specifies.



2039
2040
2041
# File 'lib/stripe/resources/payment_intent.rb', line 2039

def 
  @customer_account
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



2041
2042
2043
# File 'lib/stripe/resources/payment_intent.rb', line 2041

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



2043
2044
2045
# File 'lib/stripe/resources/payment_intent.rb', line 2043

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



2045
2046
2047
# File 'lib/stripe/resources/payment_intent.rb', line 2045

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



2047
2048
2049
# File 'lib/stripe/resources/payment_intent.rb', line 2047

def starting_after
  @starting_after
end