Class: Stripe::PaymentIntent::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
# File 'lib/stripe/resources/payment_intent.rb', line 2027

def initialize(
  created: nil,
  customer: nil,
  customer_account: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil
)
  @created = created
  @customer = customer
  @customer_account = 
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp or a dictionary with a number of different query options.



2013
2014
2015
# File 'lib/stripe/resources/payment_intent.rb', line 2013

def created
  @created
end

#customerObject

Only return PaymentIntents for the customer that this customer ID specifies.



2015
2016
2017
# File 'lib/stripe/resources/payment_intent.rb', line 2015

def customer
  @customer
end

#customer_accountObject

Only return PaymentIntents for the account that this ID specifies.



2017
2018
2019
# File 'lib/stripe/resources/payment_intent.rb', line 2017

def 
  @customer_account
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



2019
2020
2021
# File 'lib/stripe/resources/payment_intent.rb', line 2019

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



2021
2022
2023
# File 'lib/stripe/resources/payment_intent.rb', line 2021

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



2023
2024
2025
# File 'lib/stripe/resources/payment_intent.rb', line 2023

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



2025
2026
2027
# File 'lib/stripe/resources/payment_intent.rb', line 2025

def starting_after
  @starting_after
end