Class: Stripe::PaymentIntent::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ListParams
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
A filter on the list, based on the object ‘created` field.
-
#customer ⇒ Object
Only return PaymentIntents for the customer that this customer ID specifies.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 |
# File 'lib/stripe/resources/payment_intent.rb', line 1584 def initialize( created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil ) @created = created @customer = customer @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#created ⇒ Object
A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp or a dictionary with a number of different query options.
1572 1573 1574 |
# File 'lib/stripe/resources/payment_intent.rb', line 1572 def created @created end |
#customer ⇒ Object
Only return PaymentIntents for the customer that this customer ID specifies.
1574 1575 1576 |
# File 'lib/stripe/resources/payment_intent.rb', line 1574 def customer @customer end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
1576 1577 1578 |
# File 'lib/stripe/resources/payment_intent.rb', line 1576 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1578 1579 1580 |
# File 'lib/stripe/resources/payment_intent.rb', line 1578 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1580 1581 1582 |
# File 'lib/stripe/resources/payment_intent.rb', line 1580 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
1582 1583 1584 |
# File 'lib/stripe/resources/payment_intent.rb', line 1582 def starting_after @starting_after end |