Class: Stripe::PaymentIntent::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
# File 'lib/stripe/resources/payment_intent.rb', line 1985

def initialize(
  created: nil,
  customer: nil,
  customer_account: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil
)
  @created = created
  @customer = customer
  @customer_account = 
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp or a dictionary with a number of different query options.



1971
1972
1973
# File 'lib/stripe/resources/payment_intent.rb', line 1971

def created
  @created
end

#customerObject

Only return PaymentIntents for the customer that this customer ID specifies.



1973
1974
1975
# File 'lib/stripe/resources/payment_intent.rb', line 1973

def customer
  @customer
end

#customer_accountObject

Only return PaymentIntents for the account that this ID specifies.



1975
1976
1977
# File 'lib/stripe/resources/payment_intent.rb', line 1975

def 
  @customer_account
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



1977
1978
1979
# File 'lib/stripe/resources/payment_intent.rb', line 1977

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



1979
1980
1981
# File 'lib/stripe/resources/payment_intent.rb', line 1979

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1981
1982
1983
# File 'lib/stripe/resources/payment_intent.rb', line 1981

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



1983
1984
1985
# File 'lib/stripe/resources/payment_intent.rb', line 1983

def starting_after
  @starting_after
end