Class: Stripe::PaymentIntent::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
# File 'lib/stripe/resources/payment_intent.rb', line 1570

def initialize(
  created: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil
)
  @created = created
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp or a dictionary with a number of different query options.



1558
1559
1560
# File 'lib/stripe/resources/payment_intent.rb', line 1558

def created
  @created
end

#customerObject

Only return PaymentIntents for the customer that this customer ID specifies.



1560
1561
1562
# File 'lib/stripe/resources/payment_intent.rb', line 1560

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



1562
1563
1564
# File 'lib/stripe/resources/payment_intent.rb', line 1562

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



1564
1565
1566
# File 'lib/stripe/resources/payment_intent.rb', line 1564

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1566
1567
1568
# File 'lib/stripe/resources/payment_intent.rb', line 1566

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



1568
1569
1570
# File 'lib/stripe/resources/payment_intent.rb', line 1568

def starting_after
  @starting_after
end