Class: Stripe::PaymentIntent::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ListParams
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
A filter on the list, based on the object ‘created` field.
-
#customer ⇒ Object
Only return PaymentIntents for the customer that this customer ID specifies.
-
#customer_account ⇒ Object
Only return PaymentIntents for the account that this ID specifies.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 |
# File 'lib/stripe/resources/payment_intent.rb', line 1956 def initialize( created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil ) @created = created @customer = customer @customer_account = customer_account @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#created ⇒ Object
A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp or a dictionary with a number of different query options.
1942 1943 1944 |
# File 'lib/stripe/resources/payment_intent.rb', line 1942 def created @created end |
#customer ⇒ Object
Only return PaymentIntents for the customer that this customer ID specifies.
1944 1945 1946 |
# File 'lib/stripe/resources/payment_intent.rb', line 1944 def customer @customer end |
#customer_account ⇒ Object
Only return PaymentIntents for the account that this ID specifies.
1946 1947 1948 |
# File 'lib/stripe/resources/payment_intent.rb', line 1946 def customer_account @customer_account end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
1948 1949 1950 |
# File 'lib/stripe/resources/payment_intent.rb', line 1948 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1950 1951 1952 |
# File 'lib/stripe/resources/payment_intent.rb', line 1950 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1952 1953 1954 |
# File 'lib/stripe/resources/payment_intent.rb', line 1952 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
1954 1955 1956 |
# File 'lib/stripe/resources/payment_intent.rb', line 1954 def starting_after @starting_after end |