Class: Stripe::PaymentIntent::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ListParams
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
A filter on the list, based on the object ‘created` field.
-
#customer ⇒ Object
Only return PaymentIntents for the customer that this customer ID specifies.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 |
# File 'lib/stripe/resources/payment_intent.rb', line 2316 def initialize( created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil ) @created = created @customer = customer @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#created ⇒ Object
A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp or a dictionary with a number of different query options.
2299 2300 2301 |
# File 'lib/stripe/resources/payment_intent.rb', line 2299 def created @created end |
#customer ⇒ Object
Only return PaymentIntents for the customer that this customer ID specifies.
2302 2303 2304 |
# File 'lib/stripe/resources/payment_intent.rb', line 2302 def customer @customer end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
2305 2306 2307 |
# File 'lib/stripe/resources/payment_intent.rb', line 2305 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2308 2309 2310 |
# File 'lib/stripe/resources/payment_intent.rb', line 2308 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
2311 2312 2313 |
# File 'lib/stripe/resources/payment_intent.rb', line 2311 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
2314 2315 2316 |
# File 'lib/stripe/resources/payment_intent.rb', line 2314 def starting_after @starting_after end |