Class: Stripe::PaymentIntent::NextAction
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AlipayHandleRedirect, BoletoDisplayDetails, CardAwaitNotification, CashappHandleRedirectOrDisplayQrCode, CryptoDisplayDetails, DisplayBankTransferInstructions, KonbiniDisplayDetails, MultibancoDisplayDetails, OxxoDisplayDetails, PaynowDisplayQrCode, PixDisplayQrCode, PromptpayDisplayQrCode, RedirectToUrl, SwishHandleRedirectOrDisplayQrCode, UpiHandleRedirectOrDisplayQrCode, VerifyWithMicrodeposits, WechatPayDisplayQrCode, WechatPayRedirectToAndroidApp, WechatPayRedirectToIosApp
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#alipay_handle_redirect ⇒ Object
readonly
Attribute for field alipay_handle_redirect.
-
#boleto_display_details ⇒ Object
readonly
Attribute for field boleto_display_details.
-
#card_await_notification ⇒ Object
readonly
Attribute for field card_await_notification.
-
#cashapp_handle_redirect_or_display_qr_code ⇒ Object
readonly
Attribute for field cashapp_handle_redirect_or_display_qr_code.
-
#crypto_display_details ⇒ Object
readonly
Attribute for field crypto_display_details.
-
#display_bank_transfer_instructions ⇒ Object
readonly
Attribute for field display_bank_transfer_instructions.
-
#konbini_display_details ⇒ Object
readonly
Attribute for field konbini_display_details.
-
#multibanco_display_details ⇒ Object
readonly
Attribute for field multibanco_display_details.
-
#oxxo_display_details ⇒ Object
readonly
Attribute for field oxxo_display_details.
-
#paynow_display_qr_code ⇒ Object
readonly
Attribute for field paynow_display_qr_code.
-
#pix_display_qr_code ⇒ Object
readonly
Attribute for field pix_display_qr_code.
-
#promptpay_display_qr_code ⇒ Object
readonly
Attribute for field promptpay_display_qr_code.
-
#redirect_to_url ⇒ Object
readonly
Attribute for field redirect_to_url.
-
#swish_handle_redirect_or_display_qr_code ⇒ Object
readonly
Attribute for field swish_handle_redirect_or_display_qr_code.
-
#type ⇒ Object
readonly
Type of the next action to perform.
-
#upi_handle_redirect_or_display_qr_code ⇒ Object
readonly
Attribute for field upi_handle_redirect_or_display_qr_code.
-
#use_stripe_sdk ⇒ Object
readonly
When confirming a PaymentIntent with Stripe.js, Stripe.js depends on the contents of this dictionary to invoke authentication flows.
-
#verify_with_microdeposits ⇒ Object
readonly
Attribute for field verify_with_microdeposits.
-
#wechat_pay_display_qr_code ⇒ Object
readonly
Attribute for field wechat_pay_display_qr_code.
-
#wechat_pay_redirect_to_android_app ⇒ Object
readonly
Attribute for field wechat_pay_redirect_to_android_app.
-
#wechat_pay_redirect_to_ios_app ⇒ Object
readonly
Attribute for field wechat_pay_redirect_to_ios_app.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#alipay_handle_redirect ⇒ Object (readonly)
Attribute for field alipay_handle_redirect
1390 1391 1392 |
# File 'lib/stripe/resources/payment_intent.rb', line 1390 def alipay_handle_redirect @alipay_handle_redirect end |
#boleto_display_details ⇒ Object (readonly)
Attribute for field boleto_display_details
1392 1393 1394 |
# File 'lib/stripe/resources/payment_intent.rb', line 1392 def boleto_display_details @boleto_display_details end |
#card_await_notification ⇒ Object (readonly)
Attribute for field card_await_notification
1394 1395 1396 |
# File 'lib/stripe/resources/payment_intent.rb', line 1394 def card_await_notification @card_await_notification end |
#cashapp_handle_redirect_or_display_qr_code ⇒ Object (readonly)
Attribute for field cashapp_handle_redirect_or_display_qr_code
1396 1397 1398 |
# File 'lib/stripe/resources/payment_intent.rb', line 1396 def cashapp_handle_redirect_or_display_qr_code @cashapp_handle_redirect_or_display_qr_code end |
#crypto_display_details ⇒ Object (readonly)
Attribute for field crypto_display_details
1398 1399 1400 |
# File 'lib/stripe/resources/payment_intent.rb', line 1398 def crypto_display_details @crypto_display_details end |
#display_bank_transfer_instructions ⇒ Object (readonly)
Attribute for field display_bank_transfer_instructions
1400 1401 1402 |
# File 'lib/stripe/resources/payment_intent.rb', line 1400 def display_bank_transfer_instructions @display_bank_transfer_instructions end |
#konbini_display_details ⇒ Object (readonly)
Attribute for field konbini_display_details
1402 1403 1404 |
# File 'lib/stripe/resources/payment_intent.rb', line 1402 def konbini_display_details @konbini_display_details end |
#multibanco_display_details ⇒ Object (readonly)
Attribute for field multibanco_display_details
1404 1405 1406 |
# File 'lib/stripe/resources/payment_intent.rb', line 1404 def multibanco_display_details @multibanco_display_details end |
#oxxo_display_details ⇒ Object (readonly)
Attribute for field oxxo_display_details
1406 1407 1408 |
# File 'lib/stripe/resources/payment_intent.rb', line 1406 def oxxo_display_details @oxxo_display_details end |
#paynow_display_qr_code ⇒ Object (readonly)
Attribute for field paynow_display_qr_code
1408 1409 1410 |
# File 'lib/stripe/resources/payment_intent.rb', line 1408 def paynow_display_qr_code @paynow_display_qr_code end |
#pix_display_qr_code ⇒ Object (readonly)
Attribute for field pix_display_qr_code
1410 1411 1412 |
# File 'lib/stripe/resources/payment_intent.rb', line 1410 def pix_display_qr_code @pix_display_qr_code end |
#promptpay_display_qr_code ⇒ Object (readonly)
Attribute for field promptpay_display_qr_code
1412 1413 1414 |
# File 'lib/stripe/resources/payment_intent.rb', line 1412 def promptpay_display_qr_code @promptpay_display_qr_code end |
#redirect_to_url ⇒ Object (readonly)
Attribute for field redirect_to_url
1414 1415 1416 |
# File 'lib/stripe/resources/payment_intent.rb', line 1414 def redirect_to_url @redirect_to_url end |
#swish_handle_redirect_or_display_qr_code ⇒ Object (readonly)
Attribute for field swish_handle_redirect_or_display_qr_code
1416 1417 1418 |
# File 'lib/stripe/resources/payment_intent.rb', line 1416 def swish_handle_redirect_or_display_qr_code @swish_handle_redirect_or_display_qr_code end |
#type ⇒ Object (readonly)
Type of the next action to perform. Refer to the other child attributes under ‘next_action` for available values. Examples include: `redirect_to_url`, `use_stripe_sdk`, `alipay_handle_redirect`, `oxxo_display_details`, or `verify_with_microdeposits`.
1418 1419 1420 |
# File 'lib/stripe/resources/payment_intent.rb', line 1418 def type @type end |
#upi_handle_redirect_or_display_qr_code ⇒ Object (readonly)
Attribute for field upi_handle_redirect_or_display_qr_code
1420 1421 1422 |
# File 'lib/stripe/resources/payment_intent.rb', line 1420 def upi_handle_redirect_or_display_qr_code @upi_handle_redirect_or_display_qr_code end |
#use_stripe_sdk ⇒ Object (readonly)
When confirming a PaymentIntent with Stripe.js, Stripe.js depends on the contents of this dictionary to invoke authentication flows. The shape of the contents is subject to change and is only intended to be used by Stripe.js.
1422 1423 1424 |
# File 'lib/stripe/resources/payment_intent.rb', line 1422 def use_stripe_sdk @use_stripe_sdk end |
#verify_with_microdeposits ⇒ Object (readonly)
Attribute for field verify_with_microdeposits
1424 1425 1426 |
# File 'lib/stripe/resources/payment_intent.rb', line 1424 def verify_with_microdeposits @verify_with_microdeposits end |
#wechat_pay_display_qr_code ⇒ Object (readonly)
Attribute for field wechat_pay_display_qr_code
1426 1427 1428 |
# File 'lib/stripe/resources/payment_intent.rb', line 1426 def wechat_pay_display_qr_code @wechat_pay_display_qr_code end |
#wechat_pay_redirect_to_android_app ⇒ Object (readonly)
Attribute for field wechat_pay_redirect_to_android_app
1428 1429 1430 |
# File 'lib/stripe/resources/payment_intent.rb', line 1428 def wechat_pay_redirect_to_android_app @wechat_pay_redirect_to_android_app end |
#wechat_pay_redirect_to_ios_app ⇒ Object (readonly)
Attribute for field wechat_pay_redirect_to_ios_app
1430 1431 1432 |
# File 'lib/stripe/resources/payment_intent.rb', line 1430 def wechat_pay_redirect_to_ios_app @wechat_pay_redirect_to_ios_app end |
Class Method Details
.field_remappings ⇒ Object
1456 1457 1458 |
# File 'lib/stripe/resources/payment_intent.rb', line 1456 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 |
# File 'lib/stripe/resources/payment_intent.rb', line 1432 def self.inner_class_types @inner_class_types = { alipay_handle_redirect: AlipayHandleRedirect, boleto_display_details: BoletoDisplayDetails, card_await_notification: CardAwaitNotification, cashapp_handle_redirect_or_display_qr_code: CashappHandleRedirectOrDisplayQrCode, crypto_display_details: CryptoDisplayDetails, display_bank_transfer_instructions: DisplayBankTransferInstructions, konbini_display_details: KonbiniDisplayDetails, multibanco_display_details: MultibancoDisplayDetails, oxxo_display_details: OxxoDisplayDetails, paynow_display_qr_code: PaynowDisplayQrCode, pix_display_qr_code: PixDisplayQrCode, promptpay_display_qr_code: PromptpayDisplayQrCode, redirect_to_url: RedirectToUrl, swish_handle_redirect_or_display_qr_code: SwishHandleRedirectOrDisplayQrCode, upi_handle_redirect_or_display_qr_code: UpiHandleRedirectOrDisplayQrCode, verify_with_microdeposits: VerifyWithMicrodeposits, wechat_pay_display_qr_code: WechatPayDisplayQrCode, wechat_pay_redirect_to_android_app: WechatPayRedirectToAndroidApp, wechat_pay_redirect_to_ios_app: WechatPayRedirectToIosApp, } end |