Class: Stripe::PaymentIntent::NextAction
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AlipayHandleRedirect, BoletoDisplayDetails, CardAwaitNotification, CashappHandleRedirectOrDisplayQrCode, DisplayBankTransferInstructions, KlarnaDisplayQrCode, KonbiniDisplayDetails, MultibancoDisplayDetails, OxxoDisplayDetails, PaynowDisplayQrCode, PixDisplayQrCode, PromptpayDisplayQrCode, RedirectToUrl, SwishHandleRedirectOrDisplayQrCode, UpiHandleRedirectOrDisplayQrCode, VerifyWithMicrodeposits, WechatPayDisplayQrCode, WechatPayRedirectToAndroidApp, WechatPayRedirectToIosApp
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#alipay_handle_redirect ⇒ Object
readonly
Attribute for field alipay_handle_redirect.
-
#boleto_display_details ⇒ Object
readonly
Attribute for field boleto_display_details.
-
#card_await_notification ⇒ Object
readonly
Attribute for field card_await_notification.
-
#cashapp_handle_redirect_or_display_qr_code ⇒ Object
readonly
Attribute for field cashapp_handle_redirect_or_display_qr_code.
-
#display_bank_transfer_instructions ⇒ Object
readonly
Attribute for field display_bank_transfer_instructions.
-
#klarna_display_qr_code ⇒ Object
readonly
Attribute for field klarna_display_qr_code.
-
#konbini_display_details ⇒ Object
readonly
Attribute for field konbini_display_details.
-
#multibanco_display_details ⇒ Object
readonly
Attribute for field multibanco_display_details.
-
#oxxo_display_details ⇒ Object
readonly
Attribute for field oxxo_display_details.
-
#paynow_display_qr_code ⇒ Object
readonly
Attribute for field paynow_display_qr_code.
-
#pix_display_qr_code ⇒ Object
readonly
Attribute for field pix_display_qr_code.
-
#promptpay_display_qr_code ⇒ Object
readonly
Attribute for field promptpay_display_qr_code.
-
#redirect_to_url ⇒ Object
readonly
Attribute for field redirect_to_url.
-
#swish_handle_redirect_or_display_qr_code ⇒ Object
readonly
Attribute for field swish_handle_redirect_or_display_qr_code.
-
#type ⇒ Object
readonly
Type of the next action to perform.
-
#upi_handle_redirect_or_display_qr_code ⇒ Object
readonly
Attribute for field upi_handle_redirect_or_display_qr_code.
-
#use_stripe_sdk ⇒ Object
readonly
When confirming a PaymentIntent with Stripe.js, Stripe.js depends on the contents of this dictionary to invoke authentication flows.
-
#verify_with_microdeposits ⇒ Object
readonly
Attribute for field verify_with_microdeposits.
-
#wechat_pay_display_qr_code ⇒ Object
readonly
Attribute for field wechat_pay_display_qr_code.
-
#wechat_pay_redirect_to_android_app ⇒ Object
readonly
Attribute for field wechat_pay_redirect_to_android_app.
-
#wechat_pay_redirect_to_ios_app ⇒ Object
readonly
Attribute for field wechat_pay_redirect_to_ios_app.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#alipay_handle_redirect ⇒ Object (readonly)
Attribute for field alipay_handle_redirect
1266 1267 1268 |
# File 'lib/stripe/resources/payment_intent.rb', line 1266 def alipay_handle_redirect @alipay_handle_redirect end |
#boleto_display_details ⇒ Object (readonly)
Attribute for field boleto_display_details
1268 1269 1270 |
# File 'lib/stripe/resources/payment_intent.rb', line 1268 def boleto_display_details @boleto_display_details end |
#card_await_notification ⇒ Object (readonly)
Attribute for field card_await_notification
1270 1271 1272 |
# File 'lib/stripe/resources/payment_intent.rb', line 1270 def card_await_notification @card_await_notification end |
#cashapp_handle_redirect_or_display_qr_code ⇒ Object (readonly)
Attribute for field cashapp_handle_redirect_or_display_qr_code
1272 1273 1274 |
# File 'lib/stripe/resources/payment_intent.rb', line 1272 def cashapp_handle_redirect_or_display_qr_code @cashapp_handle_redirect_or_display_qr_code end |
#display_bank_transfer_instructions ⇒ Object (readonly)
Attribute for field display_bank_transfer_instructions
1274 1275 1276 |
# File 'lib/stripe/resources/payment_intent.rb', line 1274 def display_bank_transfer_instructions @display_bank_transfer_instructions end |
#klarna_display_qr_code ⇒ Object (readonly)
Attribute for field klarna_display_qr_code
1276 1277 1278 |
# File 'lib/stripe/resources/payment_intent.rb', line 1276 def klarna_display_qr_code @klarna_display_qr_code end |
#konbini_display_details ⇒ Object (readonly)
Attribute for field konbini_display_details
1278 1279 1280 |
# File 'lib/stripe/resources/payment_intent.rb', line 1278 def konbini_display_details @konbini_display_details end |
#multibanco_display_details ⇒ Object (readonly)
Attribute for field multibanco_display_details
1280 1281 1282 |
# File 'lib/stripe/resources/payment_intent.rb', line 1280 def multibanco_display_details @multibanco_display_details end |
#oxxo_display_details ⇒ Object (readonly)
Attribute for field oxxo_display_details
1282 1283 1284 |
# File 'lib/stripe/resources/payment_intent.rb', line 1282 def oxxo_display_details @oxxo_display_details end |
#paynow_display_qr_code ⇒ Object (readonly)
Attribute for field paynow_display_qr_code
1284 1285 1286 |
# File 'lib/stripe/resources/payment_intent.rb', line 1284 def paynow_display_qr_code @paynow_display_qr_code end |
#pix_display_qr_code ⇒ Object (readonly)
Attribute for field pix_display_qr_code
1286 1287 1288 |
# File 'lib/stripe/resources/payment_intent.rb', line 1286 def pix_display_qr_code @pix_display_qr_code end |
#promptpay_display_qr_code ⇒ Object (readonly)
Attribute for field promptpay_display_qr_code
1288 1289 1290 |
# File 'lib/stripe/resources/payment_intent.rb', line 1288 def promptpay_display_qr_code @promptpay_display_qr_code end |
#redirect_to_url ⇒ Object (readonly)
Attribute for field redirect_to_url
1290 1291 1292 |
# File 'lib/stripe/resources/payment_intent.rb', line 1290 def redirect_to_url @redirect_to_url end |
#swish_handle_redirect_or_display_qr_code ⇒ Object (readonly)
Attribute for field swish_handle_redirect_or_display_qr_code
1292 1293 1294 |
# File 'lib/stripe/resources/payment_intent.rb', line 1292 def swish_handle_redirect_or_display_qr_code @swish_handle_redirect_or_display_qr_code end |
#type ⇒ Object (readonly)
Type of the next action to perform. Refer to the other child attributes under ‘next_action` for available values. Examples include: `redirect_to_url`, `use_stripe_sdk`, `alipay_handle_redirect`, `oxxo_display_details`, or `verify_with_microdeposits`.
1294 1295 1296 |
# File 'lib/stripe/resources/payment_intent.rb', line 1294 def type @type end |
#upi_handle_redirect_or_display_qr_code ⇒ Object (readonly)
Attribute for field upi_handle_redirect_or_display_qr_code
1296 1297 1298 |
# File 'lib/stripe/resources/payment_intent.rb', line 1296 def upi_handle_redirect_or_display_qr_code @upi_handle_redirect_or_display_qr_code end |
#use_stripe_sdk ⇒ Object (readonly)
When confirming a PaymentIntent with Stripe.js, Stripe.js depends on the contents of this dictionary to invoke authentication flows. The shape of the contents is subject to change and is only intended to be used by Stripe.js.
1298 1299 1300 |
# File 'lib/stripe/resources/payment_intent.rb', line 1298 def use_stripe_sdk @use_stripe_sdk end |
#verify_with_microdeposits ⇒ Object (readonly)
Attribute for field verify_with_microdeposits
1300 1301 1302 |
# File 'lib/stripe/resources/payment_intent.rb', line 1300 def verify_with_microdeposits @verify_with_microdeposits end |
#wechat_pay_display_qr_code ⇒ Object (readonly)
Attribute for field wechat_pay_display_qr_code
1302 1303 1304 |
# File 'lib/stripe/resources/payment_intent.rb', line 1302 def wechat_pay_display_qr_code @wechat_pay_display_qr_code end |
#wechat_pay_redirect_to_android_app ⇒ Object (readonly)
Attribute for field wechat_pay_redirect_to_android_app
1304 1305 1306 |
# File 'lib/stripe/resources/payment_intent.rb', line 1304 def wechat_pay_redirect_to_android_app @wechat_pay_redirect_to_android_app end |
#wechat_pay_redirect_to_ios_app ⇒ Object (readonly)
Attribute for field wechat_pay_redirect_to_ios_app
1306 1307 1308 |
# File 'lib/stripe/resources/payment_intent.rb', line 1306 def wechat_pay_redirect_to_ios_app @wechat_pay_redirect_to_ios_app end |
Class Method Details
.field_remappings ⇒ Object
1332 1333 1334 |
# File 'lib/stripe/resources/payment_intent.rb', line 1332 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 |
# File 'lib/stripe/resources/payment_intent.rb', line 1308 def self.inner_class_types @inner_class_types = { alipay_handle_redirect: AlipayHandleRedirect, boleto_display_details: BoletoDisplayDetails, card_await_notification: CardAwaitNotification, cashapp_handle_redirect_or_display_qr_code: CashappHandleRedirectOrDisplayQrCode, display_bank_transfer_instructions: DisplayBankTransferInstructions, klarna_display_qr_code: KlarnaDisplayQrCode, konbini_display_details: KonbiniDisplayDetails, multibanco_display_details: MultibancoDisplayDetails, oxxo_display_details: OxxoDisplayDetails, paynow_display_qr_code: PaynowDisplayQrCode, pix_display_qr_code: PixDisplayQrCode, promptpay_display_qr_code: PromptpayDisplayQrCode, redirect_to_url: RedirectToUrl, swish_handle_redirect_or_display_qr_code: SwishHandleRedirectOrDisplayQrCode, upi_handle_redirect_or_display_qr_code: UpiHandleRedirectOrDisplayQrCode, verify_with_microdeposits: VerifyWithMicrodeposits, wechat_pay_display_qr_code: WechatPayDisplayQrCode, wechat_pay_redirect_to_android_app: WechatPayRedirectToAndroidApp, wechat_pay_redirect_to_ios_app: WechatPayRedirectToIosApp, } end |