Class: Stripe::PaymentIntent::NextAction
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AlipayHandleRedirect, BoletoDisplayDetails, CardAwaitNotification, CashappHandleRedirectOrDisplayQrCode, CryptoDisplayDetails, DisplayBankTransferInstructions, KonbiniDisplayDetails, MultibancoDisplayDetails, OxxoDisplayDetails, PaynowDisplayQrCode, PixDisplayQrCode, PromptpayDisplayQrCode, RedirectToUrl, SwishHandleRedirectOrDisplayQrCode, VerifyWithMicrodeposits, WechatPayDisplayQrCode, WechatPayRedirectToAndroidApp, WechatPayRedirectToIosApp
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#alipay_handle_redirect ⇒ Object
readonly
Attribute for field alipay_handle_redirect.
-
#boleto_display_details ⇒ Object
readonly
Attribute for field boleto_display_details.
-
#card_await_notification ⇒ Object
readonly
Attribute for field card_await_notification.
-
#cashapp_handle_redirect_or_display_qr_code ⇒ Object
readonly
Attribute for field cashapp_handle_redirect_or_display_qr_code.
-
#crypto_display_details ⇒ Object
readonly
Attribute for field crypto_display_details.
-
#display_bank_transfer_instructions ⇒ Object
readonly
Attribute for field display_bank_transfer_instructions.
-
#konbini_display_details ⇒ Object
readonly
Attribute for field konbini_display_details.
-
#multibanco_display_details ⇒ Object
readonly
Attribute for field multibanco_display_details.
-
#oxxo_display_details ⇒ Object
readonly
Attribute for field oxxo_display_details.
-
#paynow_display_qr_code ⇒ Object
readonly
Attribute for field paynow_display_qr_code.
-
#pix_display_qr_code ⇒ Object
readonly
Attribute for field pix_display_qr_code.
-
#promptpay_display_qr_code ⇒ Object
readonly
Attribute for field promptpay_display_qr_code.
-
#redirect_to_url ⇒ Object
readonly
Attribute for field redirect_to_url.
-
#swish_handle_redirect_or_display_qr_code ⇒ Object
readonly
Attribute for field swish_handle_redirect_or_display_qr_code.
-
#type ⇒ Object
readonly
Type of the next action to perform.
-
#use_stripe_sdk ⇒ Object
readonly
When confirming a PaymentIntent with Stripe.js, Stripe.js depends on the contents of this dictionary to invoke authentication flows.
-
#verify_with_microdeposits ⇒ Object
readonly
Attribute for field verify_with_microdeposits.
-
#wechat_pay_display_qr_code ⇒ Object
readonly
Attribute for field wechat_pay_display_qr_code.
-
#wechat_pay_redirect_to_android_app ⇒ Object
readonly
Attribute for field wechat_pay_redirect_to_android_app.
-
#wechat_pay_redirect_to_ios_app ⇒ Object
readonly
Attribute for field wechat_pay_redirect_to_ios_app.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#alipay_handle_redirect ⇒ Object (readonly)
Attribute for field alipay_handle_redirect
1317 1318 1319 |
# File 'lib/stripe/resources/payment_intent.rb', line 1317 def alipay_handle_redirect @alipay_handle_redirect end |
#boleto_display_details ⇒ Object (readonly)
Attribute for field boleto_display_details
1319 1320 1321 |
# File 'lib/stripe/resources/payment_intent.rb', line 1319 def boleto_display_details @boleto_display_details end |
#card_await_notification ⇒ Object (readonly)
Attribute for field card_await_notification
1321 1322 1323 |
# File 'lib/stripe/resources/payment_intent.rb', line 1321 def card_await_notification @card_await_notification end |
#cashapp_handle_redirect_or_display_qr_code ⇒ Object (readonly)
Attribute for field cashapp_handle_redirect_or_display_qr_code
1323 1324 1325 |
# File 'lib/stripe/resources/payment_intent.rb', line 1323 def cashapp_handle_redirect_or_display_qr_code @cashapp_handle_redirect_or_display_qr_code end |
#crypto_display_details ⇒ Object (readonly)
Attribute for field crypto_display_details
1355 1356 1357 |
# File 'lib/stripe/resources/payment_intent.rb', line 1355 def crypto_display_details @crypto_display_details end |
#display_bank_transfer_instructions ⇒ Object (readonly)
Attribute for field display_bank_transfer_instructions
1325 1326 1327 |
# File 'lib/stripe/resources/payment_intent.rb', line 1325 def display_bank_transfer_instructions @display_bank_transfer_instructions end |
#konbini_display_details ⇒ Object (readonly)
Attribute for field konbini_display_details
1327 1328 1329 |
# File 'lib/stripe/resources/payment_intent.rb', line 1327 def konbini_display_details @konbini_display_details end |
#multibanco_display_details ⇒ Object (readonly)
Attribute for field multibanco_display_details
1329 1330 1331 |
# File 'lib/stripe/resources/payment_intent.rb', line 1329 def multibanco_display_details @multibanco_display_details end |
#oxxo_display_details ⇒ Object (readonly)
Attribute for field oxxo_display_details
1331 1332 1333 |
# File 'lib/stripe/resources/payment_intent.rb', line 1331 def oxxo_display_details @oxxo_display_details end |
#paynow_display_qr_code ⇒ Object (readonly)
Attribute for field paynow_display_qr_code
1333 1334 1335 |
# File 'lib/stripe/resources/payment_intent.rb', line 1333 def paynow_display_qr_code @paynow_display_qr_code end |
#pix_display_qr_code ⇒ Object (readonly)
Attribute for field pix_display_qr_code
1335 1336 1337 |
# File 'lib/stripe/resources/payment_intent.rb', line 1335 def pix_display_qr_code @pix_display_qr_code end |
#promptpay_display_qr_code ⇒ Object (readonly)
Attribute for field promptpay_display_qr_code
1337 1338 1339 |
# File 'lib/stripe/resources/payment_intent.rb', line 1337 def promptpay_display_qr_code @promptpay_display_qr_code end |
#redirect_to_url ⇒ Object (readonly)
Attribute for field redirect_to_url
1339 1340 1341 |
# File 'lib/stripe/resources/payment_intent.rb', line 1339 def redirect_to_url @redirect_to_url end |
#swish_handle_redirect_or_display_qr_code ⇒ Object (readonly)
Attribute for field swish_handle_redirect_or_display_qr_code
1341 1342 1343 |
# File 'lib/stripe/resources/payment_intent.rb', line 1341 def swish_handle_redirect_or_display_qr_code @swish_handle_redirect_or_display_qr_code end |
#type ⇒ Object (readonly)
Type of the next action to perform. Refer to the other child attributes under ‘next_action` for available values. Examples include: `redirect_to_url`, `use_stripe_sdk`, `alipay_handle_redirect`, `oxxo_display_details`, or `verify_with_microdeposits`.
1343 1344 1345 |
# File 'lib/stripe/resources/payment_intent.rb', line 1343 def type @type end |
#use_stripe_sdk ⇒ Object (readonly)
When confirming a PaymentIntent with Stripe.js, Stripe.js depends on the contents of this dictionary to invoke authentication flows. The shape of the contents is subject to change and is only intended to be used by Stripe.js.
1345 1346 1347 |
# File 'lib/stripe/resources/payment_intent.rb', line 1345 def use_stripe_sdk @use_stripe_sdk end |
#verify_with_microdeposits ⇒ Object (readonly)
Attribute for field verify_with_microdeposits
1347 1348 1349 |
# File 'lib/stripe/resources/payment_intent.rb', line 1347 def verify_with_microdeposits @verify_with_microdeposits end |
#wechat_pay_display_qr_code ⇒ Object (readonly)
Attribute for field wechat_pay_display_qr_code
1349 1350 1351 |
# File 'lib/stripe/resources/payment_intent.rb', line 1349 def wechat_pay_display_qr_code @wechat_pay_display_qr_code end |
#wechat_pay_redirect_to_android_app ⇒ Object (readonly)
Attribute for field wechat_pay_redirect_to_android_app
1351 1352 1353 |
# File 'lib/stripe/resources/payment_intent.rb', line 1351 def wechat_pay_redirect_to_android_app @wechat_pay_redirect_to_android_app end |
#wechat_pay_redirect_to_ios_app ⇒ Object (readonly)
Attribute for field wechat_pay_redirect_to_ios_app
1353 1354 1355 |
# File 'lib/stripe/resources/payment_intent.rb', line 1353 def wechat_pay_redirect_to_ios_app @wechat_pay_redirect_to_ios_app end |
Class Method Details
.field_remappings ⇒ Object
1380 1381 1382 |
# File 'lib/stripe/resources/payment_intent.rb', line 1380 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 |
# File 'lib/stripe/resources/payment_intent.rb', line 1357 def self.inner_class_types @inner_class_types = { alipay_handle_redirect: AlipayHandleRedirect, boleto_display_details: BoletoDisplayDetails, card_await_notification: CardAwaitNotification, cashapp_handle_redirect_or_display_qr_code: CashappHandleRedirectOrDisplayQrCode, display_bank_transfer_instructions: DisplayBankTransferInstructions, konbini_display_details: KonbiniDisplayDetails, multibanco_display_details: MultibancoDisplayDetails, oxxo_display_details: OxxoDisplayDetails, paynow_display_qr_code: PaynowDisplayQrCode, pix_display_qr_code: PixDisplayQrCode, promptpay_display_qr_code: PromptpayDisplayQrCode, redirect_to_url: RedirectToUrl, swish_handle_redirect_or_display_qr_code: SwishHandleRedirectOrDisplayQrCode, verify_with_microdeposits: VerifyWithMicrodeposits, wechat_pay_display_qr_code: WechatPayDisplayQrCode, wechat_pay_redirect_to_android_app: WechatPayRedirectToAndroidApp, wechat_pay_redirect_to_ios_app: WechatPayRedirectToIosApp, crypto_display_details: CryptoDisplayDetails, } end |