Class: Stripe::PaymentIntent::NextAction
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AlipayHandleRedirect, BoletoDisplayDetails, CardAwaitNotification, CashappHandleRedirectOrDisplayQrCode, DisplayBankTransferInstructions, KonbiniDisplayDetails, MultibancoDisplayDetails, OxxoDisplayDetails, PaynowDisplayQrCode, PixDisplayQrCode, PromptpayDisplayQrCode, RedirectToUrl, SwishHandleRedirectOrDisplayQrCode, VerifyWithMicrodeposits, WechatPayDisplayQrCode, WechatPayRedirectToAndroidApp, WechatPayRedirectToIosApp
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#alipay_handle_redirect ⇒ Object
readonly
Attribute for field alipay_handle_redirect.
-
#boleto_display_details ⇒ Object
readonly
Attribute for field boleto_display_details.
-
#card_await_notification ⇒ Object
readonly
Attribute for field card_await_notification.
-
#cashapp_handle_redirect_or_display_qr_code ⇒ Object
readonly
Attribute for field cashapp_handle_redirect_or_display_qr_code.
-
#display_bank_transfer_instructions ⇒ Object
readonly
Attribute for field display_bank_transfer_instructions.
-
#konbini_display_details ⇒ Object
readonly
Attribute for field konbini_display_details.
-
#multibanco_display_details ⇒ Object
readonly
Attribute for field multibanco_display_details.
-
#oxxo_display_details ⇒ Object
readonly
Attribute for field oxxo_display_details.
-
#paynow_display_qr_code ⇒ Object
readonly
Attribute for field paynow_display_qr_code.
-
#pix_display_qr_code ⇒ Object
readonly
Attribute for field pix_display_qr_code.
-
#promptpay_display_qr_code ⇒ Object
readonly
Attribute for field promptpay_display_qr_code.
-
#redirect_to_url ⇒ Object
readonly
Attribute for field redirect_to_url.
-
#swish_handle_redirect_or_display_qr_code ⇒ Object
readonly
Attribute for field swish_handle_redirect_or_display_qr_code.
-
#type ⇒ Object
readonly
Type of the next action to perform.
-
#use_stripe_sdk ⇒ Object
readonly
When confirming a PaymentIntent with Stripe.js, Stripe.js depends on the contents of this dictionary to invoke authentication flows.
-
#verify_with_microdeposits ⇒ Object
readonly
Attribute for field verify_with_microdeposits.
-
#wechat_pay_display_qr_code ⇒ Object
readonly
Attribute for field wechat_pay_display_qr_code.
-
#wechat_pay_redirect_to_android_app ⇒ Object
readonly
Attribute for field wechat_pay_redirect_to_android_app.
-
#wechat_pay_redirect_to_ios_app ⇒ Object
readonly
Attribute for field wechat_pay_redirect_to_ios_app.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#alipay_handle_redirect ⇒ Object (readonly)
Attribute for field alipay_handle_redirect
1176 1177 1178 |
# File 'lib/stripe/resources/payment_intent.rb', line 1176 def alipay_handle_redirect @alipay_handle_redirect end |
#boleto_display_details ⇒ Object (readonly)
Attribute for field boleto_display_details
1178 1179 1180 |
# File 'lib/stripe/resources/payment_intent.rb', line 1178 def boleto_display_details @boleto_display_details end |
#card_await_notification ⇒ Object (readonly)
Attribute for field card_await_notification
1180 1181 1182 |
# File 'lib/stripe/resources/payment_intent.rb', line 1180 def card_await_notification @card_await_notification end |
#cashapp_handle_redirect_or_display_qr_code ⇒ Object (readonly)
Attribute for field cashapp_handle_redirect_or_display_qr_code
1182 1183 1184 |
# File 'lib/stripe/resources/payment_intent.rb', line 1182 def cashapp_handle_redirect_or_display_qr_code @cashapp_handle_redirect_or_display_qr_code end |
#display_bank_transfer_instructions ⇒ Object (readonly)
Attribute for field display_bank_transfer_instructions
1184 1185 1186 |
# File 'lib/stripe/resources/payment_intent.rb', line 1184 def display_bank_transfer_instructions @display_bank_transfer_instructions end |
#konbini_display_details ⇒ Object (readonly)
Attribute for field konbini_display_details
1186 1187 1188 |
# File 'lib/stripe/resources/payment_intent.rb', line 1186 def konbini_display_details @konbini_display_details end |
#multibanco_display_details ⇒ Object (readonly)
Attribute for field multibanco_display_details
1188 1189 1190 |
# File 'lib/stripe/resources/payment_intent.rb', line 1188 def multibanco_display_details @multibanco_display_details end |
#oxxo_display_details ⇒ Object (readonly)
Attribute for field oxxo_display_details
1190 1191 1192 |
# File 'lib/stripe/resources/payment_intent.rb', line 1190 def oxxo_display_details @oxxo_display_details end |
#paynow_display_qr_code ⇒ Object (readonly)
Attribute for field paynow_display_qr_code
1192 1193 1194 |
# File 'lib/stripe/resources/payment_intent.rb', line 1192 def paynow_display_qr_code @paynow_display_qr_code end |
#pix_display_qr_code ⇒ Object (readonly)
Attribute for field pix_display_qr_code
1194 1195 1196 |
# File 'lib/stripe/resources/payment_intent.rb', line 1194 def pix_display_qr_code @pix_display_qr_code end |
#promptpay_display_qr_code ⇒ Object (readonly)
Attribute for field promptpay_display_qr_code
1196 1197 1198 |
# File 'lib/stripe/resources/payment_intent.rb', line 1196 def promptpay_display_qr_code @promptpay_display_qr_code end |
#redirect_to_url ⇒ Object (readonly)
Attribute for field redirect_to_url
1198 1199 1200 |
# File 'lib/stripe/resources/payment_intent.rb', line 1198 def redirect_to_url @redirect_to_url end |
#swish_handle_redirect_or_display_qr_code ⇒ Object (readonly)
Attribute for field swish_handle_redirect_or_display_qr_code
1200 1201 1202 |
# File 'lib/stripe/resources/payment_intent.rb', line 1200 def swish_handle_redirect_or_display_qr_code @swish_handle_redirect_or_display_qr_code end |
#type ⇒ Object (readonly)
Type of the next action to perform. Refer to the other child attributes under ‘next_action` for available values. Examples include: `redirect_to_url`, `use_stripe_sdk`, `alipay_handle_redirect`, `oxxo_display_details`, or `verify_with_microdeposits`.
1202 1203 1204 |
# File 'lib/stripe/resources/payment_intent.rb', line 1202 def type @type end |
#use_stripe_sdk ⇒ Object (readonly)
When confirming a PaymentIntent with Stripe.js, Stripe.js depends on the contents of this dictionary to invoke authentication flows. The shape of the contents is subject to change and is only intended to be used by Stripe.js.
1204 1205 1206 |
# File 'lib/stripe/resources/payment_intent.rb', line 1204 def use_stripe_sdk @use_stripe_sdk end |
#verify_with_microdeposits ⇒ Object (readonly)
Attribute for field verify_with_microdeposits
1206 1207 1208 |
# File 'lib/stripe/resources/payment_intent.rb', line 1206 def verify_with_microdeposits @verify_with_microdeposits end |
#wechat_pay_display_qr_code ⇒ Object (readonly)
Attribute for field wechat_pay_display_qr_code
1208 1209 1210 |
# File 'lib/stripe/resources/payment_intent.rb', line 1208 def wechat_pay_display_qr_code @wechat_pay_display_qr_code end |
#wechat_pay_redirect_to_android_app ⇒ Object (readonly)
Attribute for field wechat_pay_redirect_to_android_app
1210 1211 1212 |
# File 'lib/stripe/resources/payment_intent.rb', line 1210 def wechat_pay_redirect_to_android_app @wechat_pay_redirect_to_android_app end |
#wechat_pay_redirect_to_ios_app ⇒ Object (readonly)
Attribute for field wechat_pay_redirect_to_ios_app
1212 1213 1214 |
# File 'lib/stripe/resources/payment_intent.rb', line 1212 def wechat_pay_redirect_to_ios_app @wechat_pay_redirect_to_ios_app end |
Class Method Details
.field_remappings ⇒ Object
1236 1237 1238 |
# File 'lib/stripe/resources/payment_intent.rb', line 1236 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 |
# File 'lib/stripe/resources/payment_intent.rb', line 1214 def self.inner_class_types @inner_class_types = { alipay_handle_redirect: AlipayHandleRedirect, boleto_display_details: BoletoDisplayDetails, card_await_notification: CardAwaitNotification, cashapp_handle_redirect_or_display_qr_code: CashappHandleRedirectOrDisplayQrCode, display_bank_transfer_instructions: DisplayBankTransferInstructions, konbini_display_details: KonbiniDisplayDetails, multibanco_display_details: MultibancoDisplayDetails, oxxo_display_details: OxxoDisplayDetails, paynow_display_qr_code: PaynowDisplayQrCode, pix_display_qr_code: PixDisplayQrCode, promptpay_display_qr_code: PromptpayDisplayQrCode, redirect_to_url: RedirectToUrl, swish_handle_redirect_or_display_qr_code: SwishHandleRedirectOrDisplayQrCode, verify_with_microdeposits: VerifyWithMicrodeposits, wechat_pay_display_qr_code: WechatPayDisplayQrCode, wechat_pay_redirect_to_android_app: WechatPayRedirectToAndroidApp, wechat_pay_redirect_to_ios_app: WechatPayRedirectToIosApp, } end |