Class: Stripe::PaymentIntent::NextAction
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AlipayHandleRedirect, BoletoDisplayDetails, CardAwaitNotification, CashappHandleRedirectOrDisplayQrCode, DisplayBankTransferInstructions, KonbiniDisplayDetails, MultibancoDisplayDetails, OxxoDisplayDetails, PaynowDisplayQrCode, PixDisplayQrCode, PromptpayDisplayQrCode, RedirectToUrl, SwishHandleRedirectOrDisplayQrCode, VerifyWithMicrodeposits, WechatPayDisplayQrCode, WechatPayRedirectToAndroidApp, WechatPayRedirectToIosApp
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#alipay_handle_redirect ⇒ Object
readonly
Attribute for field alipay_handle_redirect.
-
#boleto_display_details ⇒ Object
readonly
Attribute for field boleto_display_details.
-
#card_await_notification ⇒ Object
readonly
Attribute for field card_await_notification.
-
#cashapp_handle_redirect_or_display_qr_code ⇒ Object
readonly
Attribute for field cashapp_handle_redirect_or_display_qr_code.
-
#display_bank_transfer_instructions ⇒ Object
readonly
Attribute for field display_bank_transfer_instructions.
-
#konbini_display_details ⇒ Object
readonly
Attribute for field konbini_display_details.
-
#multibanco_display_details ⇒ Object
readonly
Attribute for field multibanco_display_details.
-
#oxxo_display_details ⇒ Object
readonly
Attribute for field oxxo_display_details.
-
#paynow_display_qr_code ⇒ Object
readonly
Attribute for field paynow_display_qr_code.
-
#pix_display_qr_code ⇒ Object
readonly
Attribute for field pix_display_qr_code.
-
#promptpay_display_qr_code ⇒ Object
readonly
Attribute for field promptpay_display_qr_code.
-
#redirect_to_url ⇒ Object
readonly
Attribute for field redirect_to_url.
-
#swish_handle_redirect_or_display_qr_code ⇒ Object
readonly
Attribute for field swish_handle_redirect_or_display_qr_code.
-
#type ⇒ Object
readonly
Type of the next action to perform.
-
#use_stripe_sdk ⇒ Object
readonly
When confirming a PaymentIntent with Stripe.js, Stripe.js depends on the contents of this dictionary to invoke authentication flows.
-
#verify_with_microdeposits ⇒ Object
readonly
Attribute for field verify_with_microdeposits.
-
#wechat_pay_display_qr_code ⇒ Object
readonly
Attribute for field wechat_pay_display_qr_code.
-
#wechat_pay_redirect_to_android_app ⇒ Object
readonly
Attribute for field wechat_pay_redirect_to_android_app.
-
#wechat_pay_redirect_to_ios_app ⇒ Object
readonly
Attribute for field wechat_pay_redirect_to_ios_app.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#alipay_handle_redirect ⇒ Object (readonly)
Attribute for field alipay_handle_redirect
1085 1086 1087 |
# File 'lib/stripe/resources/payment_intent.rb', line 1085 def alipay_handle_redirect @alipay_handle_redirect end |
#boleto_display_details ⇒ Object (readonly)
Attribute for field boleto_display_details
1087 1088 1089 |
# File 'lib/stripe/resources/payment_intent.rb', line 1087 def boleto_display_details @boleto_display_details end |
#card_await_notification ⇒ Object (readonly)
Attribute for field card_await_notification
1089 1090 1091 |
# File 'lib/stripe/resources/payment_intent.rb', line 1089 def card_await_notification @card_await_notification end |
#cashapp_handle_redirect_or_display_qr_code ⇒ Object (readonly)
Attribute for field cashapp_handle_redirect_or_display_qr_code
1091 1092 1093 |
# File 'lib/stripe/resources/payment_intent.rb', line 1091 def cashapp_handle_redirect_or_display_qr_code @cashapp_handle_redirect_or_display_qr_code end |
#display_bank_transfer_instructions ⇒ Object (readonly)
Attribute for field display_bank_transfer_instructions
1093 1094 1095 |
# File 'lib/stripe/resources/payment_intent.rb', line 1093 def display_bank_transfer_instructions @display_bank_transfer_instructions end |
#konbini_display_details ⇒ Object (readonly)
Attribute for field konbini_display_details
1095 1096 1097 |
# File 'lib/stripe/resources/payment_intent.rb', line 1095 def konbini_display_details @konbini_display_details end |
#multibanco_display_details ⇒ Object (readonly)
Attribute for field multibanco_display_details
1097 1098 1099 |
# File 'lib/stripe/resources/payment_intent.rb', line 1097 def multibanco_display_details @multibanco_display_details end |
#oxxo_display_details ⇒ Object (readonly)
Attribute for field oxxo_display_details
1099 1100 1101 |
# File 'lib/stripe/resources/payment_intent.rb', line 1099 def oxxo_display_details @oxxo_display_details end |
#paynow_display_qr_code ⇒ Object (readonly)
Attribute for field paynow_display_qr_code
1101 1102 1103 |
# File 'lib/stripe/resources/payment_intent.rb', line 1101 def paynow_display_qr_code @paynow_display_qr_code end |
#pix_display_qr_code ⇒ Object (readonly)
Attribute for field pix_display_qr_code
1103 1104 1105 |
# File 'lib/stripe/resources/payment_intent.rb', line 1103 def pix_display_qr_code @pix_display_qr_code end |
#promptpay_display_qr_code ⇒ Object (readonly)
Attribute for field promptpay_display_qr_code
1105 1106 1107 |
# File 'lib/stripe/resources/payment_intent.rb', line 1105 def promptpay_display_qr_code @promptpay_display_qr_code end |
#redirect_to_url ⇒ Object (readonly)
Attribute for field redirect_to_url
1107 1108 1109 |
# File 'lib/stripe/resources/payment_intent.rb', line 1107 def redirect_to_url @redirect_to_url end |
#swish_handle_redirect_or_display_qr_code ⇒ Object (readonly)
Attribute for field swish_handle_redirect_or_display_qr_code
1109 1110 1111 |
# File 'lib/stripe/resources/payment_intent.rb', line 1109 def swish_handle_redirect_or_display_qr_code @swish_handle_redirect_or_display_qr_code end |
#type ⇒ Object (readonly)
Type of the next action to perform. Refer to the other child attributes under ‘next_action` for available values. Examples include: `redirect_to_url`, `use_stripe_sdk`, `alipay_handle_redirect`, `oxxo_display_details`, or `verify_with_microdeposits`.
1111 1112 1113 |
# File 'lib/stripe/resources/payment_intent.rb', line 1111 def type @type end |
#use_stripe_sdk ⇒ Object (readonly)
When confirming a PaymentIntent with Stripe.js, Stripe.js depends on the contents of this dictionary to invoke authentication flows. The shape of the contents is subject to change and is only intended to be used by Stripe.js.
1113 1114 1115 |
# File 'lib/stripe/resources/payment_intent.rb', line 1113 def use_stripe_sdk @use_stripe_sdk end |
#verify_with_microdeposits ⇒ Object (readonly)
Attribute for field verify_with_microdeposits
1115 1116 1117 |
# File 'lib/stripe/resources/payment_intent.rb', line 1115 def verify_with_microdeposits @verify_with_microdeposits end |
#wechat_pay_display_qr_code ⇒ Object (readonly)
Attribute for field wechat_pay_display_qr_code
1117 1118 1119 |
# File 'lib/stripe/resources/payment_intent.rb', line 1117 def wechat_pay_display_qr_code @wechat_pay_display_qr_code end |
#wechat_pay_redirect_to_android_app ⇒ Object (readonly)
Attribute for field wechat_pay_redirect_to_android_app
1119 1120 1121 |
# File 'lib/stripe/resources/payment_intent.rb', line 1119 def wechat_pay_redirect_to_android_app @wechat_pay_redirect_to_android_app end |
#wechat_pay_redirect_to_ios_app ⇒ Object (readonly)
Attribute for field wechat_pay_redirect_to_ios_app
1121 1122 1123 |
# File 'lib/stripe/resources/payment_intent.rb', line 1121 def wechat_pay_redirect_to_ios_app @wechat_pay_redirect_to_ios_app end |
Class Method Details
.field_remappings ⇒ Object
1145 1146 1147 |
# File 'lib/stripe/resources/payment_intent.rb', line 1145 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 |
# File 'lib/stripe/resources/payment_intent.rb', line 1123 def self.inner_class_types @inner_class_types = { alipay_handle_redirect: AlipayHandleRedirect, boleto_display_details: BoletoDisplayDetails, card_await_notification: CardAwaitNotification, cashapp_handle_redirect_or_display_qr_code: CashappHandleRedirectOrDisplayQrCode, display_bank_transfer_instructions: DisplayBankTransferInstructions, konbini_display_details: KonbiniDisplayDetails, multibanco_display_details: MultibancoDisplayDetails, oxxo_display_details: OxxoDisplayDetails, paynow_display_qr_code: PaynowDisplayQrCode, pix_display_qr_code: PixDisplayQrCode, promptpay_display_qr_code: PromptpayDisplayQrCode, redirect_to_url: RedirectToUrl, swish_handle_redirect_or_display_qr_code: SwishHandleRedirectOrDisplayQrCode, verify_with_microdeposits: VerifyWithMicrodeposits, wechat_pay_display_qr_code: WechatPayDisplayQrCode, wechat_pay_redirect_to_android_app: WechatPayRedirectToAndroidApp, wechat_pay_redirect_to_ios_app: WechatPayRedirectToIosApp, } end |