Class: Stripe::PaymentIntent::NextAction
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AlipayHandleRedirect, BoletoDisplayDetails, CardAwaitNotification, CashappHandleRedirectOrDisplayQrCode, DisplayBankTransferInstructions, KonbiniDisplayDetails, MultibancoDisplayDetails, OxxoDisplayDetails, PaynowDisplayQrCode, PixDisplayQrCode, PromptpayDisplayQrCode, RedirectToUrl, SwishHandleRedirectOrDisplayQrCode, VerifyWithMicrodeposits, WechatPayDisplayQrCode, WechatPayRedirectToAndroidApp, WechatPayRedirectToIosApp
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#alipay_handle_redirect ⇒ Object
readonly
Attribute for field alipay_handle_redirect.
-
#boleto_display_details ⇒ Object
readonly
Attribute for field boleto_display_details.
-
#card_await_notification ⇒ Object
readonly
Attribute for field card_await_notification.
-
#cashapp_handle_redirect_or_display_qr_code ⇒ Object
readonly
Attribute for field cashapp_handle_redirect_or_display_qr_code.
-
#display_bank_transfer_instructions ⇒ Object
readonly
Attribute for field display_bank_transfer_instructions.
-
#konbini_display_details ⇒ Object
readonly
Attribute for field konbini_display_details.
-
#multibanco_display_details ⇒ Object
readonly
Attribute for field multibanco_display_details.
-
#oxxo_display_details ⇒ Object
readonly
Attribute for field oxxo_display_details.
-
#paynow_display_qr_code ⇒ Object
readonly
Attribute for field paynow_display_qr_code.
-
#pix_display_qr_code ⇒ Object
readonly
Attribute for field pix_display_qr_code.
-
#promptpay_display_qr_code ⇒ Object
readonly
Attribute for field promptpay_display_qr_code.
-
#redirect_to_url ⇒ Object
readonly
Attribute for field redirect_to_url.
-
#swish_handle_redirect_or_display_qr_code ⇒ Object
readonly
Attribute for field swish_handle_redirect_or_display_qr_code.
-
#type ⇒ Object
readonly
Type of the next action to perform.
-
#use_stripe_sdk ⇒ Object
readonly
When confirming a PaymentIntent with Stripe.js, Stripe.js depends on the contents of this dictionary to invoke authentication flows.
-
#verify_with_microdeposits ⇒ Object
readonly
Attribute for field verify_with_microdeposits.
-
#wechat_pay_display_qr_code ⇒ Object
readonly
Attribute for field wechat_pay_display_qr_code.
-
#wechat_pay_redirect_to_android_app ⇒ Object
readonly
Attribute for field wechat_pay_redirect_to_android_app.
-
#wechat_pay_redirect_to_ios_app ⇒ Object
readonly
Attribute for field wechat_pay_redirect_to_ios_app.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#alipay_handle_redirect ⇒ Object (readonly)
Attribute for field alipay_handle_redirect
672 673 674 |
# File 'lib/stripe/resources/payment_intent.rb', line 672 def alipay_handle_redirect @alipay_handle_redirect end |
#boleto_display_details ⇒ Object (readonly)
Attribute for field boleto_display_details
674 675 676 |
# File 'lib/stripe/resources/payment_intent.rb', line 674 def boleto_display_details @boleto_display_details end |
#card_await_notification ⇒ Object (readonly)
Attribute for field card_await_notification
676 677 678 |
# File 'lib/stripe/resources/payment_intent.rb', line 676 def card_await_notification @card_await_notification end |
#cashapp_handle_redirect_or_display_qr_code ⇒ Object (readonly)
Attribute for field cashapp_handle_redirect_or_display_qr_code
678 679 680 |
# File 'lib/stripe/resources/payment_intent.rb', line 678 def cashapp_handle_redirect_or_display_qr_code @cashapp_handle_redirect_or_display_qr_code end |
#display_bank_transfer_instructions ⇒ Object (readonly)
Attribute for field display_bank_transfer_instructions
680 681 682 |
# File 'lib/stripe/resources/payment_intent.rb', line 680 def display_bank_transfer_instructions @display_bank_transfer_instructions end |
#konbini_display_details ⇒ Object (readonly)
Attribute for field konbini_display_details
682 683 684 |
# File 'lib/stripe/resources/payment_intent.rb', line 682 def konbini_display_details @konbini_display_details end |
#multibanco_display_details ⇒ Object (readonly)
Attribute for field multibanco_display_details
684 685 686 |
# File 'lib/stripe/resources/payment_intent.rb', line 684 def multibanco_display_details @multibanco_display_details end |
#oxxo_display_details ⇒ Object (readonly)
Attribute for field oxxo_display_details
686 687 688 |
# File 'lib/stripe/resources/payment_intent.rb', line 686 def oxxo_display_details @oxxo_display_details end |
#paynow_display_qr_code ⇒ Object (readonly)
Attribute for field paynow_display_qr_code
688 689 690 |
# File 'lib/stripe/resources/payment_intent.rb', line 688 def paynow_display_qr_code @paynow_display_qr_code end |
#pix_display_qr_code ⇒ Object (readonly)
Attribute for field pix_display_qr_code
690 691 692 |
# File 'lib/stripe/resources/payment_intent.rb', line 690 def pix_display_qr_code @pix_display_qr_code end |
#promptpay_display_qr_code ⇒ Object (readonly)
Attribute for field promptpay_display_qr_code
692 693 694 |
# File 'lib/stripe/resources/payment_intent.rb', line 692 def promptpay_display_qr_code @promptpay_display_qr_code end |
#redirect_to_url ⇒ Object (readonly)
Attribute for field redirect_to_url
694 695 696 |
# File 'lib/stripe/resources/payment_intent.rb', line 694 def redirect_to_url @redirect_to_url end |
#swish_handle_redirect_or_display_qr_code ⇒ Object (readonly)
Attribute for field swish_handle_redirect_or_display_qr_code
696 697 698 |
# File 'lib/stripe/resources/payment_intent.rb', line 696 def swish_handle_redirect_or_display_qr_code @swish_handle_redirect_or_display_qr_code end |
#type ⇒ Object (readonly)
Type of the next action to perform. Refer to the other child attributes under ‘next_action` for available values. Examples include: `redirect_to_url`, `use_stripe_sdk`, `alipay_handle_redirect`, `oxxo_display_details`, or `verify_with_microdeposits`.
698 699 700 |
# File 'lib/stripe/resources/payment_intent.rb', line 698 def type @type end |
#use_stripe_sdk ⇒ Object (readonly)
When confirming a PaymentIntent with Stripe.js, Stripe.js depends on the contents of this dictionary to invoke authentication flows. The shape of the contents is subject to change and is only intended to be used by Stripe.js.
700 701 702 |
# File 'lib/stripe/resources/payment_intent.rb', line 700 def use_stripe_sdk @use_stripe_sdk end |
#verify_with_microdeposits ⇒ Object (readonly)
Attribute for field verify_with_microdeposits
702 703 704 |
# File 'lib/stripe/resources/payment_intent.rb', line 702 def verify_with_microdeposits @verify_with_microdeposits end |
#wechat_pay_display_qr_code ⇒ Object (readonly)
Attribute for field wechat_pay_display_qr_code
704 705 706 |
# File 'lib/stripe/resources/payment_intent.rb', line 704 def wechat_pay_display_qr_code @wechat_pay_display_qr_code end |
#wechat_pay_redirect_to_android_app ⇒ Object (readonly)
Attribute for field wechat_pay_redirect_to_android_app
706 707 708 |
# File 'lib/stripe/resources/payment_intent.rb', line 706 def wechat_pay_redirect_to_android_app @wechat_pay_redirect_to_android_app end |
#wechat_pay_redirect_to_ios_app ⇒ Object (readonly)
Attribute for field wechat_pay_redirect_to_ios_app
708 709 710 |
# File 'lib/stripe/resources/payment_intent.rb', line 708 def wechat_pay_redirect_to_ios_app @wechat_pay_redirect_to_ios_app end |