Class: Stripe::PaymentIntent::NextAction
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AlipayHandleRedirect, BoletoDisplayDetails, CardAwaitNotification, CashappHandleRedirectOrDisplayQrCode, DisplayBankTransferInstructions, KonbiniDisplayDetails, MultibancoDisplayDetails, OxxoDisplayDetails, PaynowDisplayQrCode, PixDisplayQrCode, PromptpayDisplayQrCode, RedirectToUrl, SwishHandleRedirectOrDisplayQrCode, VerifyWithMicrodeposits, WechatPayDisplayQrCode, WechatPayRedirectToAndroidApp, WechatPayRedirectToIosApp
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#alipay_handle_redirect ⇒ Object
readonly
Attribute for field alipay_handle_redirect.
-
#boleto_display_details ⇒ Object
readonly
Attribute for field boleto_display_details.
-
#card_await_notification ⇒ Object
readonly
Attribute for field card_await_notification.
-
#cashapp_handle_redirect_or_display_qr_code ⇒ Object
readonly
Attribute for field cashapp_handle_redirect_or_display_qr_code.
-
#display_bank_transfer_instructions ⇒ Object
readonly
Attribute for field display_bank_transfer_instructions.
-
#konbini_display_details ⇒ Object
readonly
Attribute for field konbini_display_details.
-
#multibanco_display_details ⇒ Object
readonly
Attribute for field multibanco_display_details.
-
#oxxo_display_details ⇒ Object
readonly
Attribute for field oxxo_display_details.
-
#paynow_display_qr_code ⇒ Object
readonly
Attribute for field paynow_display_qr_code.
-
#pix_display_qr_code ⇒ Object
readonly
Attribute for field pix_display_qr_code.
-
#promptpay_display_qr_code ⇒ Object
readonly
Attribute for field promptpay_display_qr_code.
-
#redirect_to_url ⇒ Object
readonly
Attribute for field redirect_to_url.
-
#swish_handle_redirect_or_display_qr_code ⇒ Object
readonly
Attribute for field swish_handle_redirect_or_display_qr_code.
-
#type ⇒ Object
readonly
Type of the next action to perform, one of ‘redirect_to_url`, `use_stripe_sdk`, `alipay_handle_redirect`, `oxxo_display_details`, or `verify_with_microdeposits`.
-
#use_stripe_sdk ⇒ Object
readonly
When confirming a PaymentIntent with Stripe.js, Stripe.js depends on the contents of this dictionary to invoke authentication flows.
-
#verify_with_microdeposits ⇒ Object
readonly
Attribute for field verify_with_microdeposits.
-
#wechat_pay_display_qr_code ⇒ Object
readonly
Attribute for field wechat_pay_display_qr_code.
-
#wechat_pay_redirect_to_android_app ⇒ Object
readonly
Attribute for field wechat_pay_redirect_to_android_app.
-
#wechat_pay_redirect_to_ios_app ⇒ Object
readonly
Attribute for field wechat_pay_redirect_to_ios_app.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#alipay_handle_redirect ⇒ Object (readonly)
Attribute for field alipay_handle_redirect
647 648 649 |
# File 'lib/stripe/resources/payment_intent.rb', line 647 def alipay_handle_redirect @alipay_handle_redirect end |
#boleto_display_details ⇒ Object (readonly)
Attribute for field boleto_display_details
649 650 651 |
# File 'lib/stripe/resources/payment_intent.rb', line 649 def boleto_display_details @boleto_display_details end |
#card_await_notification ⇒ Object (readonly)
Attribute for field card_await_notification
651 652 653 |
# File 'lib/stripe/resources/payment_intent.rb', line 651 def card_await_notification @card_await_notification end |
#cashapp_handle_redirect_or_display_qr_code ⇒ Object (readonly)
Attribute for field cashapp_handle_redirect_or_display_qr_code
653 654 655 |
# File 'lib/stripe/resources/payment_intent.rb', line 653 def cashapp_handle_redirect_or_display_qr_code @cashapp_handle_redirect_or_display_qr_code end |
#display_bank_transfer_instructions ⇒ Object (readonly)
Attribute for field display_bank_transfer_instructions
655 656 657 |
# File 'lib/stripe/resources/payment_intent.rb', line 655 def display_bank_transfer_instructions @display_bank_transfer_instructions end |
#konbini_display_details ⇒ Object (readonly)
Attribute for field konbini_display_details
657 658 659 |
# File 'lib/stripe/resources/payment_intent.rb', line 657 def konbini_display_details @konbini_display_details end |
#multibanco_display_details ⇒ Object (readonly)
Attribute for field multibanco_display_details
659 660 661 |
# File 'lib/stripe/resources/payment_intent.rb', line 659 def multibanco_display_details @multibanco_display_details end |
#oxxo_display_details ⇒ Object (readonly)
Attribute for field oxxo_display_details
661 662 663 |
# File 'lib/stripe/resources/payment_intent.rb', line 661 def oxxo_display_details @oxxo_display_details end |
#paynow_display_qr_code ⇒ Object (readonly)
Attribute for field paynow_display_qr_code
663 664 665 |
# File 'lib/stripe/resources/payment_intent.rb', line 663 def paynow_display_qr_code @paynow_display_qr_code end |
#pix_display_qr_code ⇒ Object (readonly)
Attribute for field pix_display_qr_code
665 666 667 |
# File 'lib/stripe/resources/payment_intent.rb', line 665 def pix_display_qr_code @pix_display_qr_code end |
#promptpay_display_qr_code ⇒ Object (readonly)
Attribute for field promptpay_display_qr_code
667 668 669 |
# File 'lib/stripe/resources/payment_intent.rb', line 667 def promptpay_display_qr_code @promptpay_display_qr_code end |
#redirect_to_url ⇒ Object (readonly)
Attribute for field redirect_to_url
669 670 671 |
# File 'lib/stripe/resources/payment_intent.rb', line 669 def redirect_to_url @redirect_to_url end |
#swish_handle_redirect_or_display_qr_code ⇒ Object (readonly)
Attribute for field swish_handle_redirect_or_display_qr_code
671 672 673 |
# File 'lib/stripe/resources/payment_intent.rb', line 671 def swish_handle_redirect_or_display_qr_code @swish_handle_redirect_or_display_qr_code end |
#type ⇒ Object (readonly)
Type of the next action to perform, one of ‘redirect_to_url`, `use_stripe_sdk`, `alipay_handle_redirect`, `oxxo_display_details`, or `verify_with_microdeposits`.
673 674 675 |
# File 'lib/stripe/resources/payment_intent.rb', line 673 def type @type end |
#use_stripe_sdk ⇒ Object (readonly)
When confirming a PaymentIntent with Stripe.js, Stripe.js depends on the contents of this dictionary to invoke authentication flows. The shape of the contents is subject to change and is only intended to be used by Stripe.js.
675 676 677 |
# File 'lib/stripe/resources/payment_intent.rb', line 675 def use_stripe_sdk @use_stripe_sdk end |
#verify_with_microdeposits ⇒ Object (readonly)
Attribute for field verify_with_microdeposits
677 678 679 |
# File 'lib/stripe/resources/payment_intent.rb', line 677 def verify_with_microdeposits @verify_with_microdeposits end |
#wechat_pay_display_qr_code ⇒ Object (readonly)
Attribute for field wechat_pay_display_qr_code
679 680 681 |
# File 'lib/stripe/resources/payment_intent.rb', line 679 def wechat_pay_display_qr_code @wechat_pay_display_qr_code end |
#wechat_pay_redirect_to_android_app ⇒ Object (readonly)
Attribute for field wechat_pay_redirect_to_android_app
681 682 683 |
# File 'lib/stripe/resources/payment_intent.rb', line 681 def wechat_pay_redirect_to_android_app @wechat_pay_redirect_to_android_app end |
#wechat_pay_redirect_to_ios_app ⇒ Object (readonly)
Attribute for field wechat_pay_redirect_to_ios_app
683 684 685 |
# File 'lib/stripe/resources/payment_intent.rb', line 683 def wechat_pay_redirect_to_ios_app @wechat_pay_redirect_to_ios_app end |