Class: Stripe::PaymentIntent::NextAction::CardAwaitNotification
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::CardAwaitNotification
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#charge_attempt_at ⇒ Object
readonly
The time that payment will be attempted.
-
#customer_approval_required ⇒ Object
readonly
For payments greater than INR 15000, the customer must provide explicit approval of the payment with their bank.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#charge_attempt_at ⇒ Object (readonly)
The time that payment will be attempted. If customer approval is required, they need to provide approval before this time.
498 499 500 |
# File 'lib/stripe/resources/payment_intent.rb', line 498 def charge_attempt_at @charge_attempt_at end |
#customer_approval_required ⇒ Object (readonly)
For payments greater than INR 15000, the customer must provide explicit approval of the payment with their bank. For payments of lower amount, no customer action is required.
500 501 502 |
# File 'lib/stripe/resources/payment_intent.rb', line 500 def customer_approval_required @customer_approval_required end |
Class Method Details
.field_remappings ⇒ Object
506 507 508 |
# File 'lib/stripe/resources/payment_intent.rb', line 506 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
502 503 504 |
# File 'lib/stripe/resources/payment_intent.rb', line 502 def self.inner_class_types @inner_class_types = {} end |