Class: Stripe::PaymentIntent::NextAction::CardAwaitNotification

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#charge_attempt_atObject (readonly)

The time that payment will be attempted. If customer approval is required, they need to provide approval before this time.



177
178
179
# File 'lib/stripe/resources/payment_intent.rb', line 177

def charge_attempt_at
  @charge_attempt_at
end

#customer_approval_requiredObject (readonly)

For payments greater than INR 15000, the customer must provide explicit approval of the payment with their bank. For payments of lower amount, no customer action is required.



179
180
181
# File 'lib/stripe/resources/payment_intent.rb', line 179

def customer_approval_required
  @customer_approval_required
end