Class: Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: FinancialAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_remainingObject (readonly)

The remaining amount that needs to be transferred to complete the payment.



1005
1006
1007
# File 'lib/stripe/resources/payment_intent.rb', line 1005

def amount_remaining
  @amount_remaining
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



1007
1008
1009
# File 'lib/stripe/resources/payment_intent.rb', line 1007

def currency
  @currency
end

#financial_addressesObject (readonly)

A list of financial addresses that can be used to fund the customer balance



1009
1010
1011
# File 'lib/stripe/resources/payment_intent.rb', line 1009

def financial_addresses
  @financial_addresses
end

#hosted_instructions_urlObject (readonly)

A link to a hosted page that guides your customer through completing the transfer.



1011
1012
1013
# File 'lib/stripe/resources/payment_intent.rb', line 1011

def hosted_instructions_url
  @hosted_instructions_url
end

#referenceObject (readonly)

A string identifying this payment. Instruct your customer to include this code in the reference or memo field of their bank transfer.



1013
1014
1015
# File 'lib/stripe/resources/payment_intent.rb', line 1013

def reference
  @reference
end

#typeObject (readonly)

Type of bank transfer



1015
1016
1017
# File 'lib/stripe/resources/payment_intent.rb', line 1015

def type
  @type
end

Class Method Details

.field_remappingsObject



1021
1022
1023
# File 'lib/stripe/resources/payment_intent.rb', line 1021

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1017
1018
1019
# File 'lib/stripe/resources/payment_intent.rb', line 1017

def self.inner_class_types
  @inner_class_types = { financial_addresses: FinancialAddress }
end