Class: Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: FinancialAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_remainingObject (readonly)

The remaining amount that needs to be transferred to complete the payment.



701
702
703
# File 'lib/stripe/resources/payment_intent.rb', line 701

def amount_remaining
  @amount_remaining
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



703
704
705
# File 'lib/stripe/resources/payment_intent.rb', line 703

def currency
  @currency
end

#financial_addressesObject (readonly)

A list of financial addresses that can be used to fund the customer balance



705
706
707
# File 'lib/stripe/resources/payment_intent.rb', line 705

def financial_addresses
  @financial_addresses
end

#hosted_instructions_urlObject (readonly)

A link to a hosted page that guides your customer through completing the transfer.



707
708
709
# File 'lib/stripe/resources/payment_intent.rb', line 707

def hosted_instructions_url
  @hosted_instructions_url
end

#referenceObject (readonly)

A string identifying this payment. Instruct your customer to include this code in the reference or memo field of their bank transfer.



709
710
711
# File 'lib/stripe/resources/payment_intent.rb', line 709

def reference
  @reference
end

#typeObject (readonly)

Type of bank transfer



711
712
713
# File 'lib/stripe/resources/payment_intent.rb', line 711

def type
  @type
end

Class Method Details

.field_remappingsObject



717
718
719
# File 'lib/stripe/resources/payment_intent.rb', line 717

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



713
714
715
# File 'lib/stripe/resources/payment_intent.rb', line 713

def self.inner_class_types
  @inner_class_types = { financial_addresses: FinancialAddress }
end