Class: Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: FinancialAddress
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_remaining ⇒ Object
readonly
The remaining amount that needs to be transferred to complete the payment.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#financial_addresses ⇒ Object
readonly
A list of financial addresses that can be used to fund the customer balance.
-
#hosted_instructions_url ⇒ Object
readonly
A link to a hosted page that guides your customer through completing the transfer.
-
#reference ⇒ Object
readonly
A string identifying this payment.
-
#type ⇒ Object
readonly
Type of bank transfer.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_remaining ⇒ Object (readonly)
The remaining amount that needs to be transferred to complete the payment.
490 491 492 |
# File 'lib/stripe/resources/payment_intent.rb', line 490 def amount_remaining @amount_remaining end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
492 493 494 |
# File 'lib/stripe/resources/payment_intent.rb', line 492 def currency @currency end |
#financial_addresses ⇒ Object (readonly)
A list of financial addresses that can be used to fund the customer balance
494 495 496 |
# File 'lib/stripe/resources/payment_intent.rb', line 494 def financial_addresses @financial_addresses end |
#hosted_instructions_url ⇒ Object (readonly)
A link to a hosted page that guides your customer through completing the transfer.
496 497 498 |
# File 'lib/stripe/resources/payment_intent.rb', line 496 def hosted_instructions_url @hosted_instructions_url end |
#reference ⇒ Object (readonly)
A string identifying this payment. Instruct your customer to include this code in the reference or memo field of their bank transfer.
498 499 500 |
# File 'lib/stripe/resources/payment_intent.rb', line 498 def reference @reference end |
#type ⇒ Object (readonly)
Type of bank transfer
500 501 502 |
# File 'lib/stripe/resources/payment_intent.rb', line 500 def type @type end |