Class: Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: FinancialAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_remainingObject (readonly)

The remaining amount that needs to be transferred to complete the payment.



465
466
467
# File 'lib/stripe/resources/payment_intent.rb', line 465

def amount_remaining
  @amount_remaining
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



467
468
469
# File 'lib/stripe/resources/payment_intent.rb', line 467

def currency
  @currency
end

#financial_addressesObject (readonly)

A list of financial addresses that can be used to fund the customer balance



469
470
471
# File 'lib/stripe/resources/payment_intent.rb', line 469

def financial_addresses
  @financial_addresses
end

#hosted_instructions_urlObject (readonly)

A link to a hosted page that guides your customer through completing the transfer.



471
472
473
# File 'lib/stripe/resources/payment_intent.rb', line 471

def hosted_instructions_url
  @hosted_instructions_url
end

#referenceObject (readonly)

A string identifying this payment. Instruct your customer to include this code in the reference or memo field of their bank transfer.



473
474
475
# File 'lib/stripe/resources/payment_intent.rb', line 473

def reference
  @reference
end

#typeObject (readonly)

Type of bank transfer



475
476
477
# File 'lib/stripe/resources/payment_intent.rb', line 475

def type
  @type
end