Class: Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Aba, Iban, SortCode, Spei, Swift, Zengin

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#abaObject (readonly)

ABA Records contain U.S. bank account details per the ABA format.



1095
1096
1097
# File 'lib/stripe/resources/payment_intent.rb', line 1095

def aba
  @aba
end

#ibanObject (readonly)

Iban Records contain E.U. bank account details per the SEPA format.



1097
1098
1099
# File 'lib/stripe/resources/payment_intent.rb', line 1097

def iban
  @iban
end

#sort_codeObject (readonly)

Sort Code Records contain U.K. bank account details per the sort code format.



1099
1100
1101
# File 'lib/stripe/resources/payment_intent.rb', line 1099

def sort_code
  @sort_code
end

#speiObject (readonly)

SPEI Records contain Mexico bank account details per the SPEI format.



1101
1102
1103
# File 'lib/stripe/resources/payment_intent.rb', line 1101

def spei
  @spei
end

#supported_networksObject (readonly)

The payment networks supported by this FinancialAddress



1103
1104
1105
# File 'lib/stripe/resources/payment_intent.rb', line 1103

def supported_networks
  @supported_networks
end

#swiftObject (readonly)

SWIFT Records contain U.S. bank account details per the SWIFT format.



1105
1106
1107
# File 'lib/stripe/resources/payment_intent.rb', line 1105

def swift
  @swift
end

#typeObject (readonly)

The type of financial address



1107
1108
1109
# File 'lib/stripe/resources/payment_intent.rb', line 1107

def type
  @type
end

#zenginObject (readonly)

Zengin Records contain Japan bank account details per the Zengin format.



1109
1110
1111
# File 'lib/stripe/resources/payment_intent.rb', line 1109

def zengin
  @zengin
end

Class Method Details

.field_remappingsObject



1122
1123
1124
# File 'lib/stripe/resources/payment_intent.rb', line 1122

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
# File 'lib/stripe/resources/payment_intent.rb', line 1111

def self.inner_class_types
  @inner_class_types = {
    aba: Aba,
    iban: Iban,
    sort_code: SortCode,
    spei: Spei,
    swift: Swift,
    zengin: Zengin,
  }
end