Class: Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Aba, Iban, SortCode, Spei, Swift, Zengin
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#aba ⇒ Object
readonly
ABA Records contain U.S.
-
#iban ⇒ Object
readonly
Iban Records contain E.U.
-
#sort_code ⇒ Object
readonly
Sort Code Records contain U.K.
-
#spei ⇒ Object
readonly
SPEI Records contain Mexico bank account details per the SPEI format.
-
#supported_networks ⇒ Object
readonly
The payment networks supported by this FinancialAddress.
-
#swift ⇒ Object
readonly
SWIFT Records contain U.S.
-
#type ⇒ Object
readonly
The type of financial address.
-
#zengin ⇒ Object
readonly
Zengin Records contain Japan bank account details per the Zengin format.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#aba ⇒ Object (readonly)
ABA Records contain U.S. bank account details per the ABA format.
1085 1086 1087 |
# File 'lib/stripe/resources/payment_intent.rb', line 1085 def aba @aba end |
#iban ⇒ Object (readonly)
Iban Records contain E.U. bank account details per the SEPA format.
1087 1088 1089 |
# File 'lib/stripe/resources/payment_intent.rb', line 1087 def iban @iban end |
#sort_code ⇒ Object (readonly)
Sort Code Records contain U.K. bank account details per the sort code format.
1089 1090 1091 |
# File 'lib/stripe/resources/payment_intent.rb', line 1089 def sort_code @sort_code end |
#spei ⇒ Object (readonly)
SPEI Records contain Mexico bank account details per the SPEI format.
1091 1092 1093 |
# File 'lib/stripe/resources/payment_intent.rb', line 1091 def spei @spei end |
#supported_networks ⇒ Object (readonly)
The payment networks supported by this FinancialAddress
1093 1094 1095 |
# File 'lib/stripe/resources/payment_intent.rb', line 1093 def supported_networks @supported_networks end |
#swift ⇒ Object (readonly)
SWIFT Records contain U.S. bank account details per the SWIFT format.
1095 1096 1097 |
# File 'lib/stripe/resources/payment_intent.rb', line 1095 def swift @swift end |
#type ⇒ Object (readonly)
The type of financial address
1097 1098 1099 |
# File 'lib/stripe/resources/payment_intent.rb', line 1097 def type @type end |
#zengin ⇒ Object (readonly)
Zengin Records contain Japan bank account details per the Zengin format.
1099 1100 1101 |
# File 'lib/stripe/resources/payment_intent.rb', line 1099 def zengin @zengin end |
Class Method Details
.field_remappings ⇒ Object
1112 1113 1114 |
# File 'lib/stripe/resources/payment_intent.rb', line 1112 def self.field_remappings @field_remappings = {} end |