Class: Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Aba, Iban, SortCode, Spei, Swift, Zengin
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#aba ⇒ Object
readonly
ABA Records contain U.S.
-
#iban ⇒ Object
readonly
Iban Records contain E.U.
-
#sort_code ⇒ Object
readonly
Sort Code Records contain U.K.
-
#spei ⇒ Object
readonly
SPEI Records contain Mexico bank account details per the SPEI format.
-
#supported_networks ⇒ Object
readonly
The payment networks supported by this FinancialAddress.
-
#swift ⇒ Object
readonly
SWIFT Records contain U.S.
-
#type ⇒ Object
readonly
The type of financial address.
-
#zengin ⇒ Object
readonly
Zengin Records contain Japan bank account details per the Zengin format.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#aba ⇒ Object (readonly)
ABA Records contain U.S. bank account details per the ABA format.
845 846 847 |
# File 'lib/stripe/resources/payment_intent.rb', line 845 def aba @aba end |
#iban ⇒ Object (readonly)
Iban Records contain E.U. bank account details per the SEPA format.
847 848 849 |
# File 'lib/stripe/resources/payment_intent.rb', line 847 def iban @iban end |
#sort_code ⇒ Object (readonly)
Sort Code Records contain U.K. bank account details per the sort code format.
849 850 851 |
# File 'lib/stripe/resources/payment_intent.rb', line 849 def sort_code @sort_code end |
#spei ⇒ Object (readonly)
SPEI Records contain Mexico bank account details per the SPEI format.
851 852 853 |
# File 'lib/stripe/resources/payment_intent.rb', line 851 def spei @spei end |
#supported_networks ⇒ Object (readonly)
The payment networks supported by this FinancialAddress
853 854 855 |
# File 'lib/stripe/resources/payment_intent.rb', line 853 def supported_networks @supported_networks end |
#swift ⇒ Object (readonly)
SWIFT Records contain U.S. bank account details per the SWIFT format.
855 856 857 |
# File 'lib/stripe/resources/payment_intent.rb', line 855 def swift @swift end |
#type ⇒ Object (readonly)
The type of financial address
857 858 859 |
# File 'lib/stripe/resources/payment_intent.rb', line 857 def type @type end |
#zengin ⇒ Object (readonly)
Zengin Records contain Japan bank account details per the Zengin format.
859 860 861 |
# File 'lib/stripe/resources/payment_intent.rb', line 859 def zengin @zengin end |
Class Method Details
.field_remappings ⇒ Object
872 873 874 |
# File 'lib/stripe/resources/payment_intent.rb', line 872 def self.field_remappings @field_remappings = {} end |