Class: Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Aba, Iban, SortCode, Spei, Swift, Zengin
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#aba ⇒ Object
readonly
ABA Records contain U.S.
-
#iban ⇒ Object
readonly
Iban Records contain E.U.
-
#sort_code ⇒ Object
readonly
Sort Code Records contain U.K.
-
#spei ⇒ Object
readonly
SPEI Records contain Mexico bank account details per the SPEI format.
-
#supported_networks ⇒ Object
readonly
The payment networks supported by this FinancialAddress.
-
#swift ⇒ Object
readonly
SWIFT Records contain U.S.
-
#type ⇒ Object
readonly
The type of financial address.
-
#zengin ⇒ Object
readonly
Zengin Records contain Japan bank account details per the Zengin format.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#aba ⇒ Object (readonly)
ABA Records contain U.S. bank account details per the ABA format.
473 474 475 |
# File 'lib/stripe/resources/payment_intent.rb', line 473 def aba @aba end |
#iban ⇒ Object (readonly)
Iban Records contain E.U. bank account details per the SEPA format.
475 476 477 |
# File 'lib/stripe/resources/payment_intent.rb', line 475 def iban @iban end |
#sort_code ⇒ Object (readonly)
Sort Code Records contain U.K. bank account details per the sort code format.
477 478 479 |
# File 'lib/stripe/resources/payment_intent.rb', line 477 def sort_code @sort_code end |
#spei ⇒ Object (readonly)
SPEI Records contain Mexico bank account details per the SPEI format.
479 480 481 |
# File 'lib/stripe/resources/payment_intent.rb', line 479 def spei @spei end |
#supported_networks ⇒ Object (readonly)
The payment networks supported by this FinancialAddress
481 482 483 |
# File 'lib/stripe/resources/payment_intent.rb', line 481 def supported_networks @supported_networks end |
#swift ⇒ Object (readonly)
SWIFT Records contain U.S. bank account details per the SWIFT format.
483 484 485 |
# File 'lib/stripe/resources/payment_intent.rb', line 483 def swift @swift end |
#type ⇒ Object (readonly)
The type of financial address
485 486 487 |
# File 'lib/stripe/resources/payment_intent.rb', line 485 def type @type end |
#zengin ⇒ Object (readonly)
Zengin Records contain Japan bank account details per the Zengin format.
487 488 489 |
# File 'lib/stripe/resources/payment_intent.rb', line 487 def zengin @zengin end |