Class: Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Aba, Iban, SortCode, Spei, Swift, Zengin
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#aba ⇒ Object
readonly
ABA Records contain U.S.
-
#iban ⇒ Object
readonly
Iban Records contain E.U.
-
#sort_code ⇒ Object
readonly
Sort Code Records contain U.K.
-
#spei ⇒ Object
readonly
SPEI Records contain Mexico bank account details per the SPEI format.
-
#supported_networks ⇒ Object
readonly
The payment networks supported by this FinancialAddress.
-
#swift ⇒ Object
readonly
SWIFT Records contain U.S.
-
#type ⇒ Object
readonly
The type of financial address.
-
#zengin ⇒ Object
readonly
Zengin Records contain Japan bank account details per the Zengin format.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#aba ⇒ Object (readonly)
ABA Records contain U.S. bank account details per the ABA format.
448 449 450 |
# File 'lib/stripe/resources/payment_intent.rb', line 448 def aba @aba end |
#iban ⇒ Object (readonly)
Iban Records contain E.U. bank account details per the SEPA format.
450 451 452 |
# File 'lib/stripe/resources/payment_intent.rb', line 450 def iban @iban end |
#sort_code ⇒ Object (readonly)
Sort Code Records contain U.K. bank account details per the sort code format.
452 453 454 |
# File 'lib/stripe/resources/payment_intent.rb', line 452 def sort_code @sort_code end |
#spei ⇒ Object (readonly)
SPEI Records contain Mexico bank account details per the SPEI format.
454 455 456 |
# File 'lib/stripe/resources/payment_intent.rb', line 454 def spei @spei end |
#supported_networks ⇒ Object (readonly)
The payment networks supported by this FinancialAddress
456 457 458 |
# File 'lib/stripe/resources/payment_intent.rb', line 456 def supported_networks @supported_networks end |
#swift ⇒ Object (readonly)
SWIFT Records contain U.S. bank account details per the SWIFT format.
458 459 460 |
# File 'lib/stripe/resources/payment_intent.rb', line 458 def swift @swift end |
#type ⇒ Object (readonly)
The type of financial address
460 461 462 |
# File 'lib/stripe/resources/payment_intent.rb', line 460 def type @type end |
#zengin ⇒ Object (readonly)
Zengin Records contain Japan bank account details per the Zengin format.
462 463 464 |
# File 'lib/stripe/resources/payment_intent.rb', line 462 def zengin @zengin end |