Class: Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress::Iban
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress::Iban
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AccountHolderAddress, BankAddress
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_address ⇒ Object
readonly
Attribute for field account_holder_address.
-
#account_holder_name ⇒ Object
readonly
The name of the person or business that owns the bank account.
-
#bank_address ⇒ Object
readonly
Attribute for field bank_address.
-
#bic ⇒ Object
readonly
The BIC/SWIFT code of the account.
-
#country ⇒ Object
readonly
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
-
#iban ⇒ Object
readonly
The IBAN of the account.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_address ⇒ Object (readonly)
Attribute for field account_holder_address
531 532 533 |
# File 'lib/stripe/resources/payment_intent.rb', line 531 def account_holder_address @account_holder_address end |
#account_holder_name ⇒ Object (readonly)
The name of the person or business that owns the bank account
533 534 535 |
# File 'lib/stripe/resources/payment_intent.rb', line 533 def account_holder_name @account_holder_name end |
#bank_address ⇒ Object (readonly)
Attribute for field bank_address
535 536 537 |
# File 'lib/stripe/resources/payment_intent.rb', line 535 def bank_address @bank_address end |
#bic ⇒ Object (readonly)
The BIC/SWIFT code of the account.
537 538 539 |
# File 'lib/stripe/resources/payment_intent.rb', line 537 def bic @bic end |
#country ⇒ Object (readonly)
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
539 540 541 |
# File 'lib/stripe/resources/payment_intent.rb', line 539 def country @country end |
#iban ⇒ Object (readonly)
The IBAN of the account.
541 542 543 |
# File 'lib/stripe/resources/payment_intent.rb', line 541 def iban @iban end |
Class Method Details
.field_remappings ⇒ Object
550 551 552 |
# File 'lib/stripe/resources/payment_intent.rb', line 550 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
543 544 545 546 547 548 |
# File 'lib/stripe/resources/payment_intent.rb', line 543 def self.inner_class_types @inner_class_types = { account_holder_address: AccountHolderAddress, bank_address: BankAddress, } end |