Class: Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress::Iban
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress::Iban
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AccountHolderAddress, BankAddress
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_address ⇒ Object
readonly
Attribute for field account_holder_address.
-
#account_holder_name ⇒ Object
readonly
The name of the person or business that owns the bank account.
-
#bank_address ⇒ Object
readonly
Attribute for field bank_address.
-
#bic ⇒ Object
readonly
The BIC/SWIFT code of the account.
-
#country ⇒ Object
readonly
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
-
#iban ⇒ Object
readonly
The IBAN of the account.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_address ⇒ Object (readonly)
Attribute for field account_holder_address
278 279 280 |
# File 'lib/stripe/resources/payment_intent.rb', line 278 def account_holder_address @account_holder_address end |
#account_holder_name ⇒ Object (readonly)
The name of the person or business that owns the bank account
280 281 282 |
# File 'lib/stripe/resources/payment_intent.rb', line 280 def account_holder_name @account_holder_name end |
#bank_address ⇒ Object (readonly)
Attribute for field bank_address
282 283 284 |
# File 'lib/stripe/resources/payment_intent.rb', line 282 def bank_address @bank_address end |
#bic ⇒ Object (readonly)
The BIC/SWIFT code of the account.
284 285 286 |
# File 'lib/stripe/resources/payment_intent.rb', line 284 def bic @bic end |
#country ⇒ Object (readonly)
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
286 287 288 |
# File 'lib/stripe/resources/payment_intent.rb', line 286 def country @country end |
#iban ⇒ Object (readonly)
The IBAN of the account.
288 289 290 |
# File 'lib/stripe/resources/payment_intent.rb', line 288 def iban @iban end |