Class: Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress::SortCode
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress::SortCode
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AccountHolderAddress, BankAddress
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_address ⇒ Object
readonly
Attribute for field account_holder_address.
-
#account_holder_name ⇒ Object
readonly
The name of the person or business that owns the bank account.
-
#account_number ⇒ Object
readonly
The account number.
-
#bank_address ⇒ Object
readonly
Attribute for field bank_address.
-
#sort_code ⇒ Object
readonly
The six-digit sort code.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_address ⇒ Object (readonly)
Attribute for field account_holder_address
548 549 550 |
# File 'lib/stripe/resources/payment_intent.rb', line 548 def account_holder_address @account_holder_address end |
#account_holder_name ⇒ Object (readonly)
The name of the person or business that owns the bank account
550 551 552 |
# File 'lib/stripe/resources/payment_intent.rb', line 550 def account_holder_name @account_holder_name end |
#account_number ⇒ Object (readonly)
The account number
552 553 554 |
# File 'lib/stripe/resources/payment_intent.rb', line 552 def account_number @account_number end |
#bank_address ⇒ Object (readonly)
Attribute for field bank_address
554 555 556 |
# File 'lib/stripe/resources/payment_intent.rb', line 554 def bank_address @bank_address end |
#sort_code ⇒ Object (readonly)
The six-digit sort code
556 557 558 |
# File 'lib/stripe/resources/payment_intent.rb', line 556 def sort_code @sort_code end |
Class Method Details
.field_remappings ⇒ Object
565 566 567 |
# File 'lib/stripe/resources/payment_intent.rb', line 565 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
558 559 560 561 562 563 |
# File 'lib/stripe/resources/payment_intent.rb', line 558 def self.inner_class_types @inner_class_types = { account_holder_address: AccountHolderAddress, bank_address: BankAddress, } end |