Class: Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress::SortCode
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress::SortCode
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AccountHolderAddress, BankAddress
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_address ⇒ Object
readonly
Attribute for field account_holder_address.
-
#account_holder_name ⇒ Object
readonly
The name of the person or business that owns the bank account.
-
#account_number ⇒ Object
readonly
The account number.
-
#bank_address ⇒ Object
readonly
Attribute for field bank_address.
-
#sort_code ⇒ Object
readonly
The six-digit sort code.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_address ⇒ Object (readonly)
Attribute for field account_holder_address
730 731 732 |
# File 'lib/stripe/resources/payment_intent.rb', line 730 def account_holder_address @account_holder_address end |
#account_holder_name ⇒ Object (readonly)
The name of the person or business that owns the bank account
732 733 734 |
# File 'lib/stripe/resources/payment_intent.rb', line 732 def account_holder_name @account_holder_name end |
#account_number ⇒ Object (readonly)
The account number
734 735 736 |
# File 'lib/stripe/resources/payment_intent.rb', line 734 def account_number @account_number end |
#bank_address ⇒ Object (readonly)
Attribute for field bank_address
736 737 738 |
# File 'lib/stripe/resources/payment_intent.rb', line 736 def bank_address @bank_address end |
#sort_code ⇒ Object (readonly)
The six-digit sort code
738 739 740 |
# File 'lib/stripe/resources/payment_intent.rb', line 738 def sort_code @sort_code end |
Class Method Details
.field_remappings ⇒ Object
747 748 749 |
# File 'lib/stripe/resources/payment_intent.rb', line 747 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
740 741 742 743 744 745 |
# File 'lib/stripe/resources/payment_intent.rb', line 740 def self.inner_class_types @inner_class_types = { account_holder_address: AccountHolderAddress, bank_address: BankAddress, } end |