Class: Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress::SortCode
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::DisplayBankTransferInstructions::FinancialAddress::SortCode
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AccountHolderAddress, BankAddress
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_address ⇒ Object
readonly
Attribute for field account_holder_address.
-
#account_holder_name ⇒ Object
readonly
The name of the person or business that owns the bank account.
-
#account_number ⇒ Object
readonly
The account number.
-
#bank_address ⇒ Object
readonly
Attribute for field bank_address.
-
#sort_code ⇒ Object
readonly
The six-digit sort code.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_address ⇒ Object (readonly)
Attribute for field account_holder_address
284 285 286 |
# File 'lib/stripe/resources/payment_intent.rb', line 284 def account_holder_address @account_holder_address end |
#account_holder_name ⇒ Object (readonly)
The name of the person or business that owns the bank account
286 287 288 |
# File 'lib/stripe/resources/payment_intent.rb', line 286 def account_holder_name @account_holder_name end |
#account_number ⇒ Object (readonly)
The account number
288 289 290 |
# File 'lib/stripe/resources/payment_intent.rb', line 288 def account_number @account_number end |
#bank_address ⇒ Object (readonly)
Attribute for field bank_address
290 291 292 |
# File 'lib/stripe/resources/payment_intent.rb', line 290 def bank_address @bank_address end |
#sort_code ⇒ Object (readonly)
The six-digit sort code
292 293 294 |
# File 'lib/stripe/resources/payment_intent.rb', line 292 def sort_code @sort_code end |