Class: Stripe::PaymentIntent::NextAction::KonbiniDisplayDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Stores

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#expires_atObject (readonly)

The timestamp at which the pending Konbini payment expires.



1110
1111
1112
# File 'lib/stripe/resources/payment_intent.rb', line 1110

def expires_at
  @expires_at
end

#hosted_voucher_urlObject (readonly)

The URL for the Konbini payment instructions page, which allows customers to view and print a Konbini voucher.



1112
1113
1114
# File 'lib/stripe/resources/payment_intent.rb', line 1112

def hosted_voucher_url
  @hosted_voucher_url
end

#storesObject (readonly)

Attribute for field stores



1114
1115
1116
# File 'lib/stripe/resources/payment_intent.rb', line 1114

def stores
  @stores
end

Class Method Details

.field_remappingsObject



1120
1121
1122
# File 'lib/stripe/resources/payment_intent.rb', line 1120

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1116
1117
1118
# File 'lib/stripe/resources/payment_intent.rb', line 1116

def self.inner_class_types
  @inner_class_types = { stores: Stores }
end