Class: Stripe::PaymentIntent::NextAction::KonbiniDisplayDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::KonbiniDisplayDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Stores
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#expires_at ⇒ Object
readonly
The timestamp at which the pending Konbini payment expires.
-
#hosted_voucher_url ⇒ Object
readonly
The URL for the Konbini payment instructions page, which allows customers to view and print a Konbini voucher.
-
#stores ⇒ Object
readonly
Attribute for field stores.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#expires_at ⇒ Object (readonly)
The timestamp at which the pending Konbini payment expires.
1083 1084 1085 |
# File 'lib/stripe/resources/payment_intent.rb', line 1083 def expires_at @expires_at end |
#hosted_voucher_url ⇒ Object (readonly)
The URL for the Konbini payment instructions page, which allows customers to view and print a Konbini voucher.
1085 1086 1087 |
# File 'lib/stripe/resources/payment_intent.rb', line 1085 def hosted_voucher_url @hosted_voucher_url end |
#stores ⇒ Object (readonly)
Attribute for field stores
1087 1088 1089 |
# File 'lib/stripe/resources/payment_intent.rb', line 1087 def stores @stores end |
Class Method Details
.field_remappings ⇒ Object
1093 1094 1095 |
# File 'lib/stripe/resources/payment_intent.rb', line 1093 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1089 1090 1091 |
# File 'lib/stripe/resources/payment_intent.rb', line 1089 def self.inner_class_types @inner_class_types = { stores: Stores } end |