Class: Stripe::PaymentIntent::NextAction::KonbiniDisplayDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Stores

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#expires_atObject (readonly)

The timestamp at which the pending Konbini payment expires.



542
543
544
# File 'lib/stripe/resources/payment_intent.rb', line 542

def expires_at
  @expires_at
end

#hosted_voucher_urlObject (readonly)

The URL for the Konbini payment instructions page, which allows customers to view and print a Konbini voucher.



544
545
546
# File 'lib/stripe/resources/payment_intent.rb', line 544

def hosted_voucher_url
  @hosted_voucher_url
end

#storesObject (readonly)

Attribute for field stores



546
547
548
# File 'lib/stripe/resources/payment_intent.rb', line 546

def stores
  @stores
end