Class: Stripe::PaymentIntent::NextAction::MultibancoDisplayDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::MultibancoDisplayDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#entity ⇒ Object
readonly
Entity number associated with this Multibanco payment.
-
#expires_at ⇒ Object
readonly
The timestamp at which the Multibanco voucher expires.
-
#hosted_voucher_url ⇒ Object
readonly
The URL for the hosted Multibanco voucher page, which allows customers to view a Multibanco voucher.
-
#reference ⇒ Object
readonly
Reference number associated with this Multibanco payment.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#entity ⇒ Object (readonly)
Entity number associated with this Multibanco payment.
1018 1019 1020 |
# File 'lib/stripe/resources/payment_intent.rb', line 1018 def entity @entity end |
#expires_at ⇒ Object (readonly)
The timestamp at which the Multibanco voucher expires.
1020 1021 1022 |
# File 'lib/stripe/resources/payment_intent.rb', line 1020 def expires_at @expires_at end |
#hosted_voucher_url ⇒ Object (readonly)
The URL for the hosted Multibanco voucher page, which allows customers to view a Multibanco voucher.
1022 1023 1024 |
# File 'lib/stripe/resources/payment_intent.rb', line 1022 def hosted_voucher_url @hosted_voucher_url end |
#reference ⇒ Object (readonly)
Reference number associated with this Multibanco payment.
1024 1025 1026 |
# File 'lib/stripe/resources/payment_intent.rb', line 1024 def reference @reference end |
Class Method Details
.field_remappings ⇒ Object
1030 1031 1032 |
# File 'lib/stripe/resources/payment_intent.rb', line 1030 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1026 1027 1028 |
# File 'lib/stripe/resources/payment_intent.rb', line 1026 def self.inner_class_types @inner_class_types = {} end |