Class: Stripe::PaymentIntent::NextAction::OxxoDisplayDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::OxxoDisplayDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#expires_after ⇒ Object
readonly
The timestamp after which the OXXO voucher expires.
-
#hosted_voucher_url ⇒ Object
readonly
The URL for the hosted OXXO voucher page, which allows customers to view and print an OXXO voucher.
-
#number ⇒ Object
readonly
OXXO reference number.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#expires_after ⇒ Object (readonly)
The timestamp after which the OXXO voucher expires.
679 680 681 |
# File 'lib/stripe/resources/payment_intent.rb', line 679 def expires_after @expires_after end |
#hosted_voucher_url ⇒ Object (readonly)
The URL for the hosted OXXO voucher page, which allows customers to view and print an OXXO voucher.
682 683 684 |
# File 'lib/stripe/resources/payment_intent.rb', line 682 def hosted_voucher_url @hosted_voucher_url end |
#number ⇒ Object (readonly)
OXXO reference number.
685 686 687 |
# File 'lib/stripe/resources/payment_intent.rb', line 685 def number @number end |