Class: Stripe::PaymentIntent::NextAction::PixDisplayQrCode
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::PixDisplayQrCode
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#data ⇒ Object
readonly
The raw data string used to generate QR code, it should be used together with QR code library.
-
#expires_at ⇒ Object
readonly
The date (unix timestamp) when the PIX expires.
-
#hosted_instructions_url ⇒ Object
readonly
The URL to the hosted pix instructions page, which allows customers to view the pix QR code.
-
#image_url_png ⇒ Object
readonly
The image_url_png string used to render png QR code.
-
#image_url_svg ⇒ Object
readonly
The image_url_svg string used to render svg QR code.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#data ⇒ Object (readonly)
The raw data string used to generate QR code, it should be used together with QR code library.
1073 1074 1075 |
# File 'lib/stripe/resources/payment_intent.rb', line 1073 def data @data end |
#expires_at ⇒ Object (readonly)
The date (unix timestamp) when the PIX expires.
1075 1076 1077 |
# File 'lib/stripe/resources/payment_intent.rb', line 1075 def expires_at @expires_at end |
#hosted_instructions_url ⇒ Object (readonly)
The URL to the hosted pix instructions page, which allows customers to view the pix QR code.
1077 1078 1079 |
# File 'lib/stripe/resources/payment_intent.rb', line 1077 def hosted_instructions_url @hosted_instructions_url end |
#image_url_png ⇒ Object (readonly)
The image_url_png string used to render png QR code
1079 1080 1081 |
# File 'lib/stripe/resources/payment_intent.rb', line 1079 def image_url_png @image_url_png end |
#image_url_svg ⇒ Object (readonly)
The image_url_svg string used to render svg QR code
1081 1082 1083 |
# File 'lib/stripe/resources/payment_intent.rb', line 1081 def image_url_svg @image_url_svg end |
Class Method Details
.field_remappings ⇒ Object
1087 1088 1089 |
# File 'lib/stripe/resources/payment_intent.rb', line 1087 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1083 1084 1085 |
# File 'lib/stripe/resources/payment_intent.rb', line 1083 def self.inner_class_types @inner_class_types = {} end |