Class: Stripe::PaymentIntent::NextAction::PixDisplayQrCode
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::PixDisplayQrCode
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#data ⇒ Object
readonly
The raw data string used to generate QR code, it should be used together with QR code library.
-
#expires_at ⇒ Object
readonly
The date (unix timestamp) when the PIX expires.
-
#hosted_instructions_url ⇒ Object
readonly
The URL to the hosted pix instructions page, which allows customers to view the pix QR code.
-
#image_url_png ⇒ Object
readonly
The image_url_png string used to render png QR code.
-
#image_url_svg ⇒ Object
readonly
The image_url_svg string used to render svg QR code.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#data ⇒ Object (readonly)
The raw data string used to generate QR code, it should be used together with QR code library.
544 545 546 |
# File 'lib/stripe/resources/payment_intent.rb', line 544 def data @data end |
#expires_at ⇒ Object (readonly)
The date (unix timestamp) when the PIX expires.
546 547 548 |
# File 'lib/stripe/resources/payment_intent.rb', line 546 def expires_at @expires_at end |
#hosted_instructions_url ⇒ Object (readonly)
The URL to the hosted pix instructions page, which allows customers to view the pix QR code.
548 549 550 |
# File 'lib/stripe/resources/payment_intent.rb', line 548 def hosted_instructions_url @hosted_instructions_url end |
#image_url_png ⇒ Object (readonly)
The image_url_png string used to render png QR code
550 551 552 |
# File 'lib/stripe/resources/payment_intent.rb', line 550 def image_url_png @image_url_png end |
#image_url_svg ⇒ Object (readonly)
The image_url_svg string used to render svg QR code
552 553 554 |
# File 'lib/stripe/resources/payment_intent.rb', line 552 def image_url_svg @image_url_svg end |