Class: Stripe::PaymentIntent::NextAction::PromptpayDisplayQrCode
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::PromptpayDisplayQrCode
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#data ⇒ Object
readonly
The raw data string used to generate QR code, it should be used together with QR code library.
-
#hosted_instructions_url ⇒ Object
readonly
The URL to the hosted PromptPay instructions page, which allows customers to view the PromptPay QR code.
-
#image_url_png ⇒ Object
readonly
The PNG path used to render the QR code, can be used as the source in an HTML img tag.
-
#image_url_svg ⇒ Object
readonly
The SVG path used to render the QR code, can be used as the source in an HTML img tag.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#data ⇒ Object (readonly)
The raw data string used to generate QR code, it should be used together with QR code library.
1203 1204 1205 |
# File 'lib/stripe/resources/payment_intent.rb', line 1203 def data @data end |
#hosted_instructions_url ⇒ Object (readonly)
The URL to the hosted PromptPay instructions page, which allows customers to view the PromptPay QR code.
1205 1206 1207 |
# File 'lib/stripe/resources/payment_intent.rb', line 1205 def hosted_instructions_url @hosted_instructions_url end |
#image_url_png ⇒ Object (readonly)
The PNG path used to render the QR code, can be used as the source in an HTML img tag
1207 1208 1209 |
# File 'lib/stripe/resources/payment_intent.rb', line 1207 def image_url_png @image_url_png end |
#image_url_svg ⇒ Object (readonly)
The SVG path used to render the QR code, can be used as the source in an HTML img tag
1209 1210 1211 |
# File 'lib/stripe/resources/payment_intent.rb', line 1209 def image_url_svg @image_url_svg end |
Class Method Details
.field_remappings ⇒ Object
1215 1216 1217 |
# File 'lib/stripe/resources/payment_intent.rb', line 1215 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1211 1212 1213 |
# File 'lib/stripe/resources/payment_intent.rb', line 1211 def self.inner_class_types @inner_class_types = {} end |