Class: Stripe::PaymentIntent::NextAction::PromptpayDisplayQrCode
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::PromptpayDisplayQrCode
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#data ⇒ Object
readonly
The raw data string used to generate QR code, it should be used together with QR code library.
-
#hosted_instructions_url ⇒ Object
readonly
The URL to the hosted PromptPay instructions page, which allows customers to view the PromptPay QR code.
-
#image_url_png ⇒ Object
readonly
The PNG path used to render the QR code, can be used as the source in an HTML img tag.
-
#image_url_svg ⇒ Object
readonly
The SVG path used to render the QR code, can be used as the source in an HTML img tag.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#data ⇒ Object (readonly)
The raw data string used to generate QR code, it should be used together with QR code library.
1176 1177 1178 |
# File 'lib/stripe/resources/payment_intent.rb', line 1176 def data @data end |
#hosted_instructions_url ⇒ Object (readonly)
The URL to the hosted PromptPay instructions page, which allows customers to view the PromptPay QR code.
1178 1179 1180 |
# File 'lib/stripe/resources/payment_intent.rb', line 1178 def hosted_instructions_url @hosted_instructions_url end |
#image_url_png ⇒ Object (readonly)
The PNG path used to render the QR code, can be used as the source in an HTML img tag
1180 1181 1182 |
# File 'lib/stripe/resources/payment_intent.rb', line 1180 def image_url_png @image_url_png end |
#image_url_svg ⇒ Object (readonly)
The SVG path used to render the QR code, can be used as the source in an HTML img tag
1182 1183 1184 |
# File 'lib/stripe/resources/payment_intent.rb', line 1182 def image_url_svg @image_url_svg end |
Class Method Details
.field_remappings ⇒ Object
1188 1189 1190 |
# File 'lib/stripe/resources/payment_intent.rb', line 1188 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1184 1185 1186 |
# File 'lib/stripe/resources/payment_intent.rb', line 1184 def self.inner_class_types @inner_class_types = {} end |