Class: Stripe::PaymentIntent::NextAction::RedirectToUrl
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::NextAction::RedirectToUrl
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#return_url ⇒ Object
readonly
If the customer does not exit their browser while authenticating, they will be redirected to this specified URL after completion.
-
#url ⇒ Object
readonly
The URL you must redirect your customer to in order to authenticate the payment.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#return_url ⇒ Object (readonly)
If the customer does not exit their browser while authenticating, they will be redirected to this specified URL after completion.
1113 1114 1115 |
# File 'lib/stripe/resources/payment_intent.rb', line 1113 def return_url @return_url end |
#url ⇒ Object (readonly)
The URL you must redirect your customer to in order to authenticate the payment.
1115 1116 1117 |
# File 'lib/stripe/resources/payment_intent.rb', line 1115 def url @url end |
Class Method Details
.field_remappings ⇒ Object
1121 1122 1123 |
# File 'lib/stripe/resources/payment_intent.rb', line 1121 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1117 1118 1119 |
# File 'lib/stripe/resources/payment_intent.rb', line 1117 def self.inner_class_types @inner_class_types = {} end |