Class: Stripe::PaymentIntent::PaymentDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Benefit, CarRental, CarRentalDatum, EventDetails, FleetDatum, FlightDatum, LodgingDatum, MoneyServices, Subscription
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#benefit ⇒ Object
readonly
Attribute for field benefit.
-
#car_rental ⇒ Object
readonly
Attribute for field car_rental.
-
#car_rental_data ⇒ Object
readonly
Attribute for field car_rental_data.
-
#customer_reference ⇒ Object
readonly
A unique value to identify the customer.
-
#event_details ⇒ Object
readonly
Attribute for field event_details.
-
#fleet_data ⇒ Object
readonly
Fleet data for this PaymentIntent.
-
#flight_data ⇒ Object
readonly
Attribute for field flight_data.
-
#lodging_data ⇒ Object
readonly
Attribute for field lodging_data.
-
#money_services ⇒ Object
readonly
Attribute for field money_services.
-
#order_reference ⇒ Object
readonly
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
readonly
Attribute for field subscription.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#benefit ⇒ Object (readonly)
Attribute for field benefit
3007 3008 3009 |
# File 'lib/stripe/resources/payment_intent.rb', line 3007 def benefit @benefit end |
#car_rental ⇒ Object (readonly)
Attribute for field car_rental
3009 3010 3011 |
# File 'lib/stripe/resources/payment_intent.rb', line 3009 def car_rental @car_rental end |
#car_rental_data ⇒ Object (readonly)
Attribute for field car_rental_data
3011 3012 3013 |
# File 'lib/stripe/resources/payment_intent.rb', line 3011 def car_rental_data @car_rental_data end |
#customer_reference ⇒ Object (readonly)
A unique value to identify the customer. This field is available only for card payments.
This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.
3015 3016 3017 |
# File 'lib/stripe/resources/payment_intent.rb', line 3015 def customer_reference @customer_reference end |
#event_details ⇒ Object (readonly)
Attribute for field event_details
3017 3018 3019 |
# File 'lib/stripe/resources/payment_intent.rb', line 3017 def event_details @event_details end |
#fleet_data ⇒ Object (readonly)
Fleet data for this PaymentIntent.
3019 3020 3021 |
# File 'lib/stripe/resources/payment_intent.rb', line 3019 def fleet_data @fleet_data end |
#flight_data ⇒ Object (readonly)
Attribute for field flight_data
3021 3022 3023 |
# File 'lib/stripe/resources/payment_intent.rb', line 3021 def flight_data @flight_data end |
#lodging_data ⇒ Object (readonly)
Attribute for field lodging_data
3023 3024 3025 |
# File 'lib/stripe/resources/payment_intent.rb', line 3023 def lodging_data @lodging_data end |
#money_services ⇒ Object (readonly)
Attribute for field money_services
3025 3026 3027 |
# File 'lib/stripe/resources/payment_intent.rb', line 3025 def money_services @money_services end |
#order_reference ⇒ Object (readonly)
A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.
For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.
3029 3030 3031 |
# File 'lib/stripe/resources/payment_intent.rb', line 3029 def order_reference @order_reference end |
#subscription ⇒ Object (readonly)
Attribute for field subscription
3031 3032 3033 |
# File 'lib/stripe/resources/payment_intent.rb', line 3031 def subscription @subscription end |
Class Method Details
.field_remappings ⇒ Object
3047 3048 3049 |
# File 'lib/stripe/resources/payment_intent.rb', line 3047 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 |
# File 'lib/stripe/resources/payment_intent.rb', line 3033 def self.inner_class_types @inner_class_types = { benefit: Benefit, car_rental: CarRental, car_rental_data: CarRentalDatum, event_details: EventDetails, fleet_data: FleetDatum, flight_data: FlightDatum, lodging_data: LodgingDatum, money_services: MoneyServices, subscription: Subscription, } end |