Class: Stripe::PaymentIntent::PaymentDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: CarRental, CarRentalDatum, EventDetails, FlightDatum, LodgingDatum, Subscription
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
readonly
Attribute for field car_rental.
-
#car_rental_data ⇒ Object
readonly
Attribute for field car_rental_data.
-
#customer_reference ⇒ Object
readonly
A unique value to identify the customer.
-
#event_details ⇒ Object
readonly
Attribute for field event_details.
-
#flight_data ⇒ Object
readonly
Attribute for field flight_data.
-
#lodging_data ⇒ Object
readonly
Attribute for field lodging_data.
-
#order_reference ⇒ Object
readonly
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
readonly
Attribute for field subscription.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#car_rental ⇒ Object (readonly)
Attribute for field car_rental
2495 2496 2497 |
# File 'lib/stripe/resources/payment_intent.rb', line 2495 def car_rental @car_rental end |
#car_rental_data ⇒ Object (readonly)
Attribute for field car_rental_data
2497 2498 2499 |
# File 'lib/stripe/resources/payment_intent.rb', line 2497 def car_rental_data @car_rental_data end |
#customer_reference ⇒ Object (readonly)
A unique value to identify the customer. This field is available only for card payments.
This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.
2501 2502 2503 |
# File 'lib/stripe/resources/payment_intent.rb', line 2501 def customer_reference @customer_reference end |
#event_details ⇒ Object (readonly)
Attribute for field event_details
2503 2504 2505 |
# File 'lib/stripe/resources/payment_intent.rb', line 2503 def event_details @event_details end |
#flight_data ⇒ Object (readonly)
Attribute for field flight_data
2505 2506 2507 |
# File 'lib/stripe/resources/payment_intent.rb', line 2505 def flight_data @flight_data end |
#lodging_data ⇒ Object (readonly)
Attribute for field lodging_data
2507 2508 2509 |
# File 'lib/stripe/resources/payment_intent.rb', line 2507 def lodging_data @lodging_data end |
#order_reference ⇒ Object (readonly)
A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.
For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.
2511 2512 2513 |
# File 'lib/stripe/resources/payment_intent.rb', line 2511 def order_reference @order_reference end |
#subscription ⇒ Object (readonly)
Attribute for field subscription
2513 2514 2515 |
# File 'lib/stripe/resources/payment_intent.rb', line 2513 def subscription @subscription end |
Class Method Details
.field_remappings ⇒ Object
2526 2527 2528 |
# File 'lib/stripe/resources/payment_intent.rb', line 2526 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 |
# File 'lib/stripe/resources/payment_intent.rb', line 2515 def self.inner_class_types @inner_class_types = { car_rental: CarRental, car_rental_data: CarRentalDatum, event_details: EventDetails, flight_data: FlightDatum, lodging_data: LodgingDatum, subscription: Subscription, } end |