Class: Stripe::PaymentIntent::PaymentDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Benefit, CarRental, CarRentalDatum, EventDetails, FleetDatum, FlightDatum, LodgingDatum, MoneyServices, Subscription

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#benefitObject (readonly)

Attribute for field benefit



2873
2874
2875
# File 'lib/stripe/resources/payment_intent.rb', line 2873

def benefit
  @benefit
end

#car_rentalObject (readonly)

Attribute for field car_rental



2875
2876
2877
# File 'lib/stripe/resources/payment_intent.rb', line 2875

def car_rental
  @car_rental
end

#car_rental_dataObject (readonly)

Attribute for field car_rental_data



2877
2878
2879
# File 'lib/stripe/resources/payment_intent.rb', line 2877

def car_rental_data
  @car_rental_data
end

#customer_referenceObject (readonly)

A unique value to identify the customer. This field is available only for card payments.

This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.



2881
2882
2883
# File 'lib/stripe/resources/payment_intent.rb', line 2881

def customer_reference
  @customer_reference
end

#event_detailsObject (readonly)

Attribute for field event_details



2883
2884
2885
# File 'lib/stripe/resources/payment_intent.rb', line 2883

def event_details
  @event_details
end

#fleet_dataObject (readonly)

Fleet data for this PaymentIntent.



2885
2886
2887
# File 'lib/stripe/resources/payment_intent.rb', line 2885

def fleet_data
  @fleet_data
end

#flight_dataObject (readonly)

Attribute for field flight_data



2887
2888
2889
# File 'lib/stripe/resources/payment_intent.rb', line 2887

def flight_data
  @flight_data
end

#lodging_dataObject (readonly)

Attribute for field lodging_data



2889
2890
2891
# File 'lib/stripe/resources/payment_intent.rb', line 2889

def lodging_data
  @lodging_data
end

#money_servicesObject (readonly)

Attribute for field money_services



2891
2892
2893
# File 'lib/stripe/resources/payment_intent.rb', line 2891

def money_services
  @money_services
end

#order_referenceObject (readonly)

A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.

For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.



2895
2896
2897
# File 'lib/stripe/resources/payment_intent.rb', line 2895

def order_reference
  @order_reference
end

#subscriptionObject (readonly)

Attribute for field subscription



2897
2898
2899
# File 'lib/stripe/resources/payment_intent.rb', line 2897

def subscription
  @subscription
end

Class Method Details

.field_remappingsObject



2913
2914
2915
# File 'lib/stripe/resources/payment_intent.rb', line 2913

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
# File 'lib/stripe/resources/payment_intent.rb', line 2899

def self.inner_class_types
  @inner_class_types = {
    benefit: Benefit,
    car_rental: CarRental,
    car_rental_data: CarRentalDatum,
    event_details: EventDetails,
    fleet_data: FleetDatum,
    flight_data: FlightDatum,
    lodging_data: LodgingDatum,
    money_services: MoneyServices,
    subscription: Subscription,
  }
end