Class: Stripe::PaymentIntent::PaymentDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Benefit, CarRental, CarRentalDatum, EventDetails, FleetDatum, FlightDatum, LodgingDatum, MoneyServices, Subscription

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#benefitObject (readonly)

Attribute for field benefit



2992
2993
2994
# File 'lib/stripe/resources/payment_intent.rb', line 2992

def benefit
  @benefit
end

#car_rentalObject (readonly)

Attribute for field car_rental



2994
2995
2996
# File 'lib/stripe/resources/payment_intent.rb', line 2994

def car_rental
  @car_rental
end

#car_rental_dataObject (readonly)

Attribute for field car_rental_data



2996
2997
2998
# File 'lib/stripe/resources/payment_intent.rb', line 2996

def car_rental_data
  @car_rental_data
end

#customer_referenceObject (readonly)

A unique value to identify the customer. This field is available only for card payments.

This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.



3000
3001
3002
# File 'lib/stripe/resources/payment_intent.rb', line 3000

def customer_reference
  @customer_reference
end

#event_detailsObject (readonly)

Attribute for field event_details



3002
3003
3004
# File 'lib/stripe/resources/payment_intent.rb', line 3002

def event_details
  @event_details
end

#fleet_dataObject (readonly)

Fleet data for this PaymentIntent.



3004
3005
3006
# File 'lib/stripe/resources/payment_intent.rb', line 3004

def fleet_data
  @fleet_data
end

#flight_dataObject (readonly)

Attribute for field flight_data



3006
3007
3008
# File 'lib/stripe/resources/payment_intent.rb', line 3006

def flight_data
  @flight_data
end

#lodging_dataObject (readonly)

Attribute for field lodging_data



3008
3009
3010
# File 'lib/stripe/resources/payment_intent.rb', line 3008

def lodging_data
  @lodging_data
end

#money_servicesObject (readonly)

Attribute for field money_services



3010
3011
3012
# File 'lib/stripe/resources/payment_intent.rb', line 3010

def money_services
  @money_services
end

#order_referenceObject (readonly)

A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.

For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.



3014
3015
3016
# File 'lib/stripe/resources/payment_intent.rb', line 3014

def order_reference
  @order_reference
end

#subscriptionObject (readonly)

Attribute for field subscription



3016
3017
3018
# File 'lib/stripe/resources/payment_intent.rb', line 3016

def subscription
  @subscription
end

Class Method Details

.field_remappingsObject



3032
3033
3034
# File 'lib/stripe/resources/payment_intent.rb', line 3032

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3018
3019
3020
3021
3022
3023
3024
3025
3026
3027
3028
3029
3030
# File 'lib/stripe/resources/payment_intent.rb', line 3018

def self.inner_class_types
  @inner_class_types = {
    benefit: Benefit,
    car_rental: CarRental,
    car_rental_data: CarRentalDatum,
    event_details: EventDetails,
    fleet_data: FleetDatum,
    flight_data: FlightDatum,
    lodging_data: LodgingDatum,
    money_services: MoneyServices,
    subscription: Subscription,
  }
end