Class: Stripe::PaymentIntent::PaymentDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: CarRental, CarRentalDatum, EventDetails, FlightDatum, LodgingDatum, Subscription

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#car_rentalObject (readonly)

Attribute for field car_rental



2482
2483
2484
# File 'lib/stripe/resources/payment_intent.rb', line 2482

def car_rental
  @car_rental
end

#car_rental_dataObject (readonly)

Attribute for field car_rental_data



2484
2485
2486
# File 'lib/stripe/resources/payment_intent.rb', line 2484

def car_rental_data
  @car_rental_data
end

#customer_referenceObject (readonly)

A unique value to identify the customer. This field is available only for card payments.

This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.



2488
2489
2490
# File 'lib/stripe/resources/payment_intent.rb', line 2488

def customer_reference
  @customer_reference
end

#event_detailsObject (readonly)

Attribute for field event_details



2490
2491
2492
# File 'lib/stripe/resources/payment_intent.rb', line 2490

def event_details
  @event_details
end

#flight_dataObject (readonly)

Attribute for field flight_data



2492
2493
2494
# File 'lib/stripe/resources/payment_intent.rb', line 2492

def flight_data
  @flight_data
end

#lodging_dataObject (readonly)

Attribute for field lodging_data



2494
2495
2496
# File 'lib/stripe/resources/payment_intent.rb', line 2494

def lodging_data
  @lodging_data
end

#order_referenceObject (readonly)

A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.

For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.



2498
2499
2500
# File 'lib/stripe/resources/payment_intent.rb', line 2498

def order_reference
  @order_reference
end

#subscriptionObject (readonly)

Attribute for field subscription



2500
2501
2502
# File 'lib/stripe/resources/payment_intent.rb', line 2500

def subscription
  @subscription
end

Class Method Details

.field_remappingsObject



2513
2514
2515
# File 'lib/stripe/resources/payment_intent.rb', line 2513

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
# File 'lib/stripe/resources/payment_intent.rb', line 2502

def self.inner_class_types
  @inner_class_types = {
    car_rental: CarRental,
    car_rental_data: CarRentalDatum,
    event_details: EventDetails,
    flight_data: FlightDatum,
    lodging_data: LodgingDatum,
    subscription: Subscription,
  }
end