Class: Stripe::PaymentIntent::PaymentDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Benefit, CarRental, CarRentalDatum, EventDetails, FleetDatum, FlightDatum, LodgingDatum, MoneyServices, Subscription
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#benefit ⇒ Object
readonly
Attribute for field benefit.
-
#car_rental ⇒ Object
readonly
Attribute for field car_rental.
-
#car_rental_data ⇒ Object
readonly
Attribute for field car_rental_data.
-
#customer_reference ⇒ Object
readonly
A unique value to identify the customer.
-
#event_details ⇒ Object
readonly
Attribute for field event_details.
-
#fleet_data ⇒ Object
readonly
Fleet data for this PaymentIntent.
-
#flight_data ⇒ Object
readonly
Attribute for field flight_data.
-
#lodging_data ⇒ Object
readonly
Attribute for field lodging_data.
-
#money_services ⇒ Object
readonly
Attribute for field money_services.
-
#order_reference ⇒ Object
readonly
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
readonly
Attribute for field subscription.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#benefit ⇒ Object (readonly)
Attribute for field benefit
2858 2859 2860 |
# File 'lib/stripe/resources/payment_intent.rb', line 2858 def benefit @benefit end |
#car_rental ⇒ Object (readonly)
Attribute for field car_rental
2860 2861 2862 |
# File 'lib/stripe/resources/payment_intent.rb', line 2860 def car_rental @car_rental end |
#car_rental_data ⇒ Object (readonly)
Attribute for field car_rental_data
2862 2863 2864 |
# File 'lib/stripe/resources/payment_intent.rb', line 2862 def car_rental_data @car_rental_data end |
#customer_reference ⇒ Object (readonly)
A unique value to identify the customer. This field is available only for card payments.
This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.
2866 2867 2868 |
# File 'lib/stripe/resources/payment_intent.rb', line 2866 def customer_reference @customer_reference end |
#event_details ⇒ Object (readonly)
Attribute for field event_details
2868 2869 2870 |
# File 'lib/stripe/resources/payment_intent.rb', line 2868 def event_details @event_details end |
#fleet_data ⇒ Object (readonly)
Fleet data for this PaymentIntent.
2870 2871 2872 |
# File 'lib/stripe/resources/payment_intent.rb', line 2870 def fleet_data @fleet_data end |
#flight_data ⇒ Object (readonly)
Attribute for field flight_data
2872 2873 2874 |
# File 'lib/stripe/resources/payment_intent.rb', line 2872 def flight_data @flight_data end |
#lodging_data ⇒ Object (readonly)
Attribute for field lodging_data
2874 2875 2876 |
# File 'lib/stripe/resources/payment_intent.rb', line 2874 def lodging_data @lodging_data end |
#money_services ⇒ Object (readonly)
Attribute for field money_services
2876 2877 2878 |
# File 'lib/stripe/resources/payment_intent.rb', line 2876 def money_services @money_services end |
#order_reference ⇒ Object (readonly)
A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.
For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.
2880 2881 2882 |
# File 'lib/stripe/resources/payment_intent.rb', line 2880 def order_reference @order_reference end |
#subscription ⇒ Object (readonly)
Attribute for field subscription
2882 2883 2884 |
# File 'lib/stripe/resources/payment_intent.rb', line 2882 def subscription @subscription end |
Class Method Details
.field_remappings ⇒ Object
2898 2899 2900 |
# File 'lib/stripe/resources/payment_intent.rb', line 2898 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 |
# File 'lib/stripe/resources/payment_intent.rb', line 2884 def self.inner_class_types @inner_class_types = { benefit: Benefit, car_rental: CarRental, car_rental_data: CarRentalDatum, event_details: EventDetails, fleet_data: FleetDatum, flight_data: FlightDatum, lodging_data: LodgingDatum, money_services: MoneyServices, subscription: Subscription, } end |