Class: Stripe::PaymentIntent::PaymentDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Benefit, CarRental, CarRentalDatum, EventDetails, FlightDatum, LodgingDatum, Subscription

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#benefitObject (readonly)

Attribute for field benefit



2616
2617
2618
# File 'lib/stripe/resources/payment_intent.rb', line 2616

def benefit
  @benefit
end

#car_rentalObject (readonly)

Attribute for field car_rental



2618
2619
2620
# File 'lib/stripe/resources/payment_intent.rb', line 2618

def car_rental
  @car_rental
end

#car_rental_dataObject (readonly)

Attribute for field car_rental_data



2620
2621
2622
# File 'lib/stripe/resources/payment_intent.rb', line 2620

def car_rental_data
  @car_rental_data
end

#customer_referenceObject (readonly)

A unique value to identify the customer. This field is available only for card payments.

This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.



2624
2625
2626
# File 'lib/stripe/resources/payment_intent.rb', line 2624

def customer_reference
  @customer_reference
end

#event_detailsObject (readonly)

Attribute for field event_details



2626
2627
2628
# File 'lib/stripe/resources/payment_intent.rb', line 2626

def event_details
  @event_details
end

#flight_dataObject (readonly)

Attribute for field flight_data



2628
2629
2630
# File 'lib/stripe/resources/payment_intent.rb', line 2628

def flight_data
  @flight_data
end

#lodging_dataObject (readonly)

Attribute for field lodging_data



2630
2631
2632
# File 'lib/stripe/resources/payment_intent.rb', line 2630

def lodging_data
  @lodging_data
end

#order_referenceObject (readonly)

A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.

For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.



2634
2635
2636
# File 'lib/stripe/resources/payment_intent.rb', line 2634

def order_reference
  @order_reference
end

#subscriptionObject (readonly)

Attribute for field subscription



2636
2637
2638
# File 'lib/stripe/resources/payment_intent.rb', line 2636

def subscription
  @subscription
end

Class Method Details

.field_remappingsObject



2650
2651
2652
# File 'lib/stripe/resources/payment_intent.rb', line 2650

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
# File 'lib/stripe/resources/payment_intent.rb', line 2638

def self.inner_class_types
  @inner_class_types = {
    benefit: Benefit,
    car_rental: CarRental,
    car_rental_data: CarRentalDatum,
    event_details: EventDetails,
    flight_data: FlightDatum,
    lodging_data: LodgingDatum,
    subscription: Subscription,
  }
end