Class: Stripe::PaymentIntent::PaymentDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Benefit, CarRental, CarRentalDatum, EventDetails, FleetDatum, FlightDatum, LodgingDatum, Subscription
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#benefit ⇒ Object
readonly
Attribute for field benefit.
-
#car_rental ⇒ Object
readonly
Attribute for field car_rental.
-
#car_rental_data ⇒ Object
readonly
Attribute for field car_rental_data.
-
#customer_reference ⇒ Object
readonly
A unique value to identify the customer.
-
#event_details ⇒ Object
readonly
Attribute for field event_details.
-
#fleet_data ⇒ Object
readonly
Fleet data for this PaymentIntent.
-
#flight_data ⇒ Object
readonly
Attribute for field flight_data.
-
#lodging_data ⇒ Object
readonly
Attribute for field lodging_data.
-
#order_reference ⇒ Object
readonly
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
readonly
Attribute for field subscription.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#benefit ⇒ Object (readonly)
Attribute for field benefit
2703 2704 2705 |
# File 'lib/stripe/resources/payment_intent.rb', line 2703 def benefit @benefit end |
#car_rental ⇒ Object (readonly)
Attribute for field car_rental
2705 2706 2707 |
# File 'lib/stripe/resources/payment_intent.rb', line 2705 def car_rental @car_rental end |
#car_rental_data ⇒ Object (readonly)
Attribute for field car_rental_data
2707 2708 2709 |
# File 'lib/stripe/resources/payment_intent.rb', line 2707 def car_rental_data @car_rental_data end |
#customer_reference ⇒ Object (readonly)
A unique value to identify the customer. This field is available only for card payments.
This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.
2711 2712 2713 |
# File 'lib/stripe/resources/payment_intent.rb', line 2711 def customer_reference @customer_reference end |
#event_details ⇒ Object (readonly)
Attribute for field event_details
2713 2714 2715 |
# File 'lib/stripe/resources/payment_intent.rb', line 2713 def event_details @event_details end |
#fleet_data ⇒ Object (readonly)
Fleet data for this PaymentIntent.
2725 2726 2727 |
# File 'lib/stripe/resources/payment_intent.rb', line 2725 def fleet_data @fleet_data end |
#flight_data ⇒ Object (readonly)
Attribute for field flight_data
2715 2716 2717 |
# File 'lib/stripe/resources/payment_intent.rb', line 2715 def flight_data @flight_data end |
#lodging_data ⇒ Object (readonly)
Attribute for field lodging_data
2717 2718 2719 |
# File 'lib/stripe/resources/payment_intent.rb', line 2717 def lodging_data @lodging_data end |
#order_reference ⇒ Object (readonly)
A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.
For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.
2721 2722 2723 |
# File 'lib/stripe/resources/payment_intent.rb', line 2721 def order_reference @order_reference end |
#subscription ⇒ Object (readonly)
Attribute for field subscription
2723 2724 2725 |
# File 'lib/stripe/resources/payment_intent.rb', line 2723 def subscription @subscription end |
Class Method Details
.field_remappings ⇒ Object
2740 2741 2742 |
# File 'lib/stripe/resources/payment_intent.rb', line 2740 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 |
# File 'lib/stripe/resources/payment_intent.rb', line 2727 def self.inner_class_types @inner_class_types = { benefit: Benefit, car_rental: CarRental, car_rental_data: CarRentalDatum, event_details: EventDetails, flight_data: FlightDatum, lodging_data: LodgingDatum, subscription: Subscription, fleet_data: FleetDatum, } end |