Class: Stripe::PaymentIntent::PaymentDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Benefit, CarRental, CarRentalDatum, EventDetails, FlightDatum, LodgingDatum, Subscription

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#benefitObject (readonly)

Attribute for field benefit



2437
2438
2439
# File 'lib/stripe/resources/payment_intent.rb', line 2437

def benefit
  @benefit
end

#car_rentalObject (readonly)

Attribute for field car_rental



2439
2440
2441
# File 'lib/stripe/resources/payment_intent.rb', line 2439

def car_rental
  @car_rental
end

#car_rental_dataObject (readonly)

Attribute for field car_rental_data



2441
2442
2443
# File 'lib/stripe/resources/payment_intent.rb', line 2441

def car_rental_data
  @car_rental_data
end

#customer_referenceObject (readonly)

A unique value to identify the customer. This field is available only for card payments.

This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.



2445
2446
2447
# File 'lib/stripe/resources/payment_intent.rb', line 2445

def customer_reference
  @customer_reference
end

#event_detailsObject (readonly)

Attribute for field event_details



2447
2448
2449
# File 'lib/stripe/resources/payment_intent.rb', line 2447

def event_details
  @event_details
end

#flight_dataObject (readonly)

Attribute for field flight_data



2449
2450
2451
# File 'lib/stripe/resources/payment_intent.rb', line 2449

def flight_data
  @flight_data
end

#lodging_dataObject (readonly)

Attribute for field lodging_data



2451
2452
2453
# File 'lib/stripe/resources/payment_intent.rb', line 2451

def lodging_data
  @lodging_data
end

#order_referenceObject (readonly)

A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.

Required when the Payment Method Types array contains ‘card`, including when [automatic_payment_methods.enabled](/api/payment_intents/create#create_payment_intent-automatic_payment_methods-enabled) is set to `true`.

For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.



2457
2458
2459
# File 'lib/stripe/resources/payment_intent.rb', line 2457

def order_reference
  @order_reference
end

#subscriptionObject (readonly)

Attribute for field subscription



2459
2460
2461
# File 'lib/stripe/resources/payment_intent.rb', line 2459

def subscription
  @subscription
end

Class Method Details

.field_remappingsObject



2473
2474
2475
# File 'lib/stripe/resources/payment_intent.rb', line 2473

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
# File 'lib/stripe/resources/payment_intent.rb', line 2461

def self.inner_class_types
  @inner_class_types = {
    benefit: Benefit,
    car_rental: CarRental,
    car_rental_data: CarRentalDatum,
    event_details: EventDetails,
    flight_data: FlightDatum,
    lodging_data: LodgingDatum,
    subscription: Subscription,
  }
end