Class: Stripe::PaymentIntent::PaymentDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: CarRental, CarRentalDatum, EventDetails, FlightDatum, LodgingDatum, Subscription

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#car_rentalObject (readonly)

Attribute for field car_rental



2386
2387
2388
# File 'lib/stripe/resources/payment_intent.rb', line 2386

def car_rental
  @car_rental
end

#car_rental_dataObject (readonly)

Attribute for field car_rental_data



2388
2389
2390
# File 'lib/stripe/resources/payment_intent.rb', line 2388

def car_rental_data
  @car_rental_data
end

#customer_referenceObject (readonly)

A unique value to identify the customer. This field is available only for card payments.

This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.



2392
2393
2394
# File 'lib/stripe/resources/payment_intent.rb', line 2392

def customer_reference
  @customer_reference
end

#event_detailsObject (readonly)

Attribute for field event_details



2394
2395
2396
# File 'lib/stripe/resources/payment_intent.rb', line 2394

def event_details
  @event_details
end

#flight_dataObject (readonly)

Attribute for field flight_data



2396
2397
2398
# File 'lib/stripe/resources/payment_intent.rb', line 2396

def flight_data
  @flight_data
end

#lodging_dataObject (readonly)

Attribute for field lodging_data



2398
2399
2400
# File 'lib/stripe/resources/payment_intent.rb', line 2398

def lodging_data
  @lodging_data
end

#order_referenceObject (readonly)

A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.

Required when the Payment Method Types array contains ‘card`, including when [automatic_payment_methods.enabled](/api/payment_intents/create#create_payment_intent-automatic_payment_methods-enabled) is set to `true`.

For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.



2404
2405
2406
# File 'lib/stripe/resources/payment_intent.rb', line 2404

def order_reference
  @order_reference
end

#subscriptionObject (readonly)

Attribute for field subscription



2406
2407
2408
# File 'lib/stripe/resources/payment_intent.rb', line 2406

def subscription
  @subscription
end

Class Method Details

.field_remappingsObject



2419
2420
2421
# File 'lib/stripe/resources/payment_intent.rb', line 2419

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
# File 'lib/stripe/resources/payment_intent.rb', line 2408

def self.inner_class_types
  @inner_class_types = {
    car_rental: CarRental,
    car_rental_data: CarRentalDatum,
    event_details: EventDetails,
    flight_data: FlightDatum,
    lodging_data: LodgingDatum,
    subscription: Subscription,
  }
end