Class: Stripe::PaymentIntent::PaymentDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Benefit, CarRental, EventDetails, Subscription
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#benefit ⇒ Object
readonly
Attribute for field benefit.
-
#car_rental ⇒ Object
readonly
Attribute for field car_rental.
-
#customer_reference ⇒ Object
readonly
A unique value to identify the customer.
-
#event_details ⇒ Object
readonly
Attribute for field event_details.
-
#order_reference ⇒ Object
readonly
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
readonly
Attribute for field subscription.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#benefit ⇒ Object (readonly)
Attribute for field benefit
1595 1596 1597 |
# File 'lib/stripe/resources/payment_intent.rb', line 1595 def benefit @benefit end |
#car_rental ⇒ Object (readonly)
Attribute for field car_rental
1597 1598 1599 |
# File 'lib/stripe/resources/payment_intent.rb', line 1597 def car_rental @car_rental end |
#customer_reference ⇒ Object (readonly)
A unique value to identify the customer. This field is available only for card payments.
This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.
1601 1602 1603 |
# File 'lib/stripe/resources/payment_intent.rb', line 1601 def customer_reference @customer_reference end |
#event_details ⇒ Object (readonly)
Attribute for field event_details
1603 1604 1605 |
# File 'lib/stripe/resources/payment_intent.rb', line 1603 def event_details @event_details end |
#order_reference ⇒ Object (readonly)
A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.
Required when the Payment Method Types array contains ‘card`, including when [automatic_payment_methods.enabled](/api/payment_intents/create#create_payment_intent-automatic_payment_methods-enabled) is set to `true`.
For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.
1609 1610 1611 |
# File 'lib/stripe/resources/payment_intent.rb', line 1609 def order_reference @order_reference end |
#subscription ⇒ Object (readonly)
Attribute for field subscription
1611 1612 1613 |
# File 'lib/stripe/resources/payment_intent.rb', line 1611 def subscription @subscription end |
Class Method Details
.field_remappings ⇒ Object
1622 1623 1624 |
# File 'lib/stripe/resources/payment_intent.rb', line 1622 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1613 1614 1615 1616 1617 1618 1619 1620 |
# File 'lib/stripe/resources/payment_intent.rb', line 1613 def self.inner_class_types @inner_class_types = { benefit: Benefit, car_rental: CarRental, event_details: EventDetails, subscription: Subscription, } end |