Class: Stripe::PaymentIntent::PaymentDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Benefit, CarRental, EventDetails, Subscription

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#benefitObject (readonly)

Attribute for field benefit



1558
1559
1560
# File 'lib/stripe/resources/payment_intent.rb', line 1558

def benefit
  @benefit
end

#car_rentalObject (readonly)

Attribute for field car_rental



1560
1561
1562
# File 'lib/stripe/resources/payment_intent.rb', line 1560

def car_rental
  @car_rental
end

#customer_referenceObject (readonly)

A unique value to identify the customer. This field is available only for card payments.

This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.



1564
1565
1566
# File 'lib/stripe/resources/payment_intent.rb', line 1564

def customer_reference
  @customer_reference
end

#event_detailsObject (readonly)

Attribute for field event_details



1566
1567
1568
# File 'lib/stripe/resources/payment_intent.rb', line 1566

def event_details
  @event_details
end

#order_referenceObject (readonly)

A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.

Required when the Payment Method Types array contains ‘card`, including when [automatic_payment_methods.enabled](/api/payment_intents/create#create_payment_intent-automatic_payment_methods-enabled) is set to `true`.

For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.



1572
1573
1574
# File 'lib/stripe/resources/payment_intent.rb', line 1572

def order_reference
  @order_reference
end

#subscriptionObject (readonly)

Attribute for field subscription



1574
1575
1576
# File 'lib/stripe/resources/payment_intent.rb', line 1574

def subscription
  @subscription
end

Class Method Details

.field_remappingsObject



1585
1586
1587
# File 'lib/stripe/resources/payment_intent.rb', line 1585

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1576
1577
1578
1579
1580
1581
1582
1583
# File 'lib/stripe/resources/payment_intent.rb', line 1576

def self.inner_class_types
  @inner_class_types = {
    benefit: Benefit,
    car_rental: CarRental,
    event_details: EventDetails,
    subscription: Subscription,
  }
end