Class: Stripe::PaymentIntent::PaymentDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Benefit, CarRental, EventDetails, Subscription

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#benefitObject (readonly)

Attribute for field benefit



1541
1542
1543
# File 'lib/stripe/resources/payment_intent.rb', line 1541

def benefit
  @benefit
end

#car_rentalObject (readonly)

Attribute for field car_rental



1543
1544
1545
# File 'lib/stripe/resources/payment_intent.rb', line 1543

def car_rental
  @car_rental
end

#customer_referenceObject (readonly)

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



1545
1546
1547
# File 'lib/stripe/resources/payment_intent.rb', line 1545

def customer_reference
  @customer_reference
end

#event_detailsObject (readonly)

Attribute for field event_details



1547
1548
1549
# File 'lib/stripe/resources/payment_intent.rb', line 1547

def event_details
  @event_details
end

#order_referenceObject (readonly)

A unique value assigned by the business to identify the transaction.



1549
1550
1551
# File 'lib/stripe/resources/payment_intent.rb', line 1549

def order_reference
  @order_reference
end

#subscriptionObject (readonly)

Attribute for field subscription



1551
1552
1553
# File 'lib/stripe/resources/payment_intent.rb', line 1551

def subscription
  @subscription
end

Class Method Details

.field_remappingsObject



1562
1563
1564
# File 'lib/stripe/resources/payment_intent.rb', line 1562

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1553
1554
1555
1556
1557
1558
1559
1560
# File 'lib/stripe/resources/payment_intent.rb', line 1553

def self.inner_class_types
  @inner_class_types = {
    benefit: Benefit,
    car_rental: CarRental,
    event_details: EventDetails,
    subscription: Subscription,
  }
end