Class: Stripe::PaymentIntent::PaymentDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#customer_reference ⇒ Object
readonly
A unique value to identify the customer.
-
#order_reference ⇒ Object
readonly
A unique value assigned by the business to identify the transaction.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#customer_reference ⇒ Object (readonly)
A unique value to identify the customer. This field is available only for card payments.
This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.
1154 1155 1156 |
# File 'lib/stripe/resources/payment_intent.rb', line 1154 def customer_reference @customer_reference end |
#order_reference ⇒ Object (readonly)
A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.
Required when the Payment Method Types array contains ‘card`, including when [automatic_payment_methods.enabled](/api/payment_intents/create#create_payment_intent-automatic_payment_methods-enabled) is set to `true`.
For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.
1160 1161 1162 |
# File 'lib/stripe/resources/payment_intent.rb', line 1160 def order_reference @order_reference end |
Class Method Details
.field_remappings ⇒ Object
1166 1167 1168 |
# File 'lib/stripe/resources/payment_intent.rb', line 1166 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1162 1163 1164 |
# File 'lib/stripe/resources/payment_intent.rb', line 1162 def self.inner_class_types @inner_class_types = {} end |