Class: Stripe::PaymentIntent::PaymentDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Subscription

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#car_rentalObject (readonly)

Attribute for field car_rental



1516
1517
1518
# File 'lib/stripe/resources/payment_intent.rb', line 1516

def car_rental
  @car_rental
end

#customer_referenceObject (readonly)

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



1518
1519
1520
# File 'lib/stripe/resources/payment_intent.rb', line 1518

def customer_reference
  @customer_reference
end

#event_detailsObject (readonly)

Attribute for field event_details



1520
1521
1522
# File 'lib/stripe/resources/payment_intent.rb', line 1520

def event_details
  @event_details
end

#order_referenceObject (readonly)

A unique value assigned by the business to identify the transaction.



1522
1523
1524
# File 'lib/stripe/resources/payment_intent.rb', line 1522

def order_reference
  @order_reference
end

#subscriptionObject (readonly)

Attribute for field subscription



1524
1525
1526
# File 'lib/stripe/resources/payment_intent.rb', line 1524

def subscription
  @subscription
end

Class Method Details

.field_remappingsObject



1534
1535
1536
# File 'lib/stripe/resources/payment_intent.rb', line 1534

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1526
1527
1528
1529
1530
1531
1532
# File 'lib/stripe/resources/payment_intent.rb', line 1526

def self.inner_class_types
  @inner_class_types = {
    car_rental: CarRental,
    event_details: EventDetails,
    subscription: Subscription,
  }
end