Class: Stripe::PaymentIntent::PaymentDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Subscription

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#car_rentalObject (readonly)

Attribute for field car_rental



909
910
911
# File 'lib/stripe/resources/payment_intent.rb', line 909

def car_rental
  @car_rental
end

#customer_referenceObject (readonly)

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



911
912
913
# File 'lib/stripe/resources/payment_intent.rb', line 911

def customer_reference
  @customer_reference
end

#event_detailsObject (readonly)

Attribute for field event_details



913
914
915
# File 'lib/stripe/resources/payment_intent.rb', line 913

def event_details
  @event_details
end

#order_referenceObject (readonly)

A unique value assigned by the business to identify the transaction.



915
916
917
# File 'lib/stripe/resources/payment_intent.rb', line 915

def order_reference
  @order_reference
end

#subscriptionObject (readonly)

Attribute for field subscription



917
918
919
# File 'lib/stripe/resources/payment_intent.rb', line 917

def subscription
  @subscription
end