Class: Stripe::PaymentIntent::PaymentDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Subscription

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#car_rentalObject (readonly)

Attribute for field car_rental



890
891
892
# File 'lib/stripe/resources/payment_intent.rb', line 890

def car_rental
  @car_rental
end

#customer_referenceObject (readonly)

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



892
893
894
# File 'lib/stripe/resources/payment_intent.rb', line 892

def customer_reference
  @customer_reference
end

#event_detailsObject (readonly)

Attribute for field event_details



894
895
896
# File 'lib/stripe/resources/payment_intent.rb', line 894

def event_details
  @event_details
end

#order_referenceObject (readonly)

A unique value assigned by the business to identify the transaction.



896
897
898
# File 'lib/stripe/resources/payment_intent.rb', line 896

def order_reference
  @order_reference
end

#subscriptionObject (readonly)

Attribute for field subscription



898
899
900
# File 'lib/stripe/resources/payment_intent.rb', line 898

def subscription
  @subscription
end