Class: Stripe::PaymentIntent::PaymentDetails::CarRental
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
readonly
Class code of the car.
-
#car_make ⇒ Object
readonly
Make of the car.
-
#car_model ⇒ Object
readonly
Model of the car.
-
#company ⇒ Object
readonly
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
readonly
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
readonly
Number of days the car is being rented.
-
#delivery ⇒ Object
readonly
Attribute for field delivery.
-
#distance ⇒ Object
readonly
Attribute for field distance.
-
#drivers ⇒ Object
readonly
The details of the drivers associated with the trip.
-
#extra_charges ⇒ Object
readonly
List of additional charges being billed.
-
#no_show ⇒ Object
readonly
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
readonly
Attribute for field pickup_address.
-
#pickup_at ⇒ Object
readonly
Car pick-up time.
-
#pickup_location_name ⇒ Object
readonly
Name of the pickup location.
-
#rate_amount ⇒ Object
readonly
Rental rate.
-
#rate_interval ⇒ Object
readonly
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
readonly
The full name of the person or entity renting the car.
-
#return_address ⇒ Object
readonly
Attribute for field return_address.
-
#return_at ⇒ Object
readonly
Car return time.
-
#return_location_name ⇒ Object
readonly
Name of the return location.
-
#tax_exempt ⇒ Object
readonly
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
readonly
The vehicle identification number of the car.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
1744 1745 1746 |
# File 'lib/stripe/resources/payment_intent.rb', line 1744 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
The booking number associated with the car rental.
1746 1747 1748 |
# File 'lib/stripe/resources/payment_intent.rb', line 1746 def booking_number @booking_number end |
#car_class_code ⇒ Object (readonly)
Class code of the car.
1748 1749 1750 |
# File 'lib/stripe/resources/payment_intent.rb', line 1748 def car_class_code @car_class_code end |
#car_make ⇒ Object (readonly)
Make of the car.
1750 1751 1752 |
# File 'lib/stripe/resources/payment_intent.rb', line 1750 def car_make @car_make end |
#car_model ⇒ Object (readonly)
Model of the car.
1752 1753 1754 |
# File 'lib/stripe/resources/payment_intent.rb', line 1752 def car_model @car_model end |
#company ⇒ Object (readonly)
The name of the rental car company.
1754 1755 1756 |
# File 'lib/stripe/resources/payment_intent.rb', line 1754 def company @company end |
#customer_service_phone_number ⇒ Object (readonly)
The customer service phone number of the car rental company.
1756 1757 1758 |
# File 'lib/stripe/resources/payment_intent.rb', line 1756 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object (readonly)
Number of days the car is being rented.
1758 1759 1760 |
# File 'lib/stripe/resources/payment_intent.rb', line 1758 def days_rented @days_rented end |
#delivery ⇒ Object (readonly)
Attribute for field delivery
1760 1761 1762 |
# File 'lib/stripe/resources/payment_intent.rb', line 1760 def delivery @delivery end |
#distance ⇒ Object (readonly)
Attribute for field distance
1762 1763 1764 |
# File 'lib/stripe/resources/payment_intent.rb', line 1762 def distance @distance end |
#drivers ⇒ Object (readonly)
The details of the drivers associated with the trip.
1764 1765 1766 |
# File 'lib/stripe/resources/payment_intent.rb', line 1764 def drivers @drivers end |
#extra_charges ⇒ Object (readonly)
List of additional charges being billed.
1766 1767 1768 |
# File 'lib/stripe/resources/payment_intent.rb', line 1766 def extra_charges @extra_charges end |
#no_show ⇒ Object (readonly)
Indicates if the customer did not keep nor cancel their booking.
1768 1769 1770 |
# File 'lib/stripe/resources/payment_intent.rb', line 1768 def no_show @no_show end |
#pickup_address ⇒ Object (readonly)
Attribute for field pickup_address
1770 1771 1772 |
# File 'lib/stripe/resources/payment_intent.rb', line 1770 def pickup_address @pickup_address end |
#pickup_at ⇒ Object (readonly)
Car pick-up time. Measured in seconds since the Unix epoch.
1772 1773 1774 |
# File 'lib/stripe/resources/payment_intent.rb', line 1772 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object (readonly)
Name of the pickup location.
1774 1775 1776 |
# File 'lib/stripe/resources/payment_intent.rb', line 1774 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object (readonly)
Rental rate.
1776 1777 1778 |
# File 'lib/stripe/resources/payment_intent.rb', line 1776 def rate_amount @rate_amount end |
#rate_interval ⇒ Object (readonly)
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
1778 1779 1780 |
# File 'lib/stripe/resources/payment_intent.rb', line 1778 def rate_interval @rate_interval end |
#renter_name ⇒ Object (readonly)
The full name of the person or entity renting the car.
1780 1781 1782 |
# File 'lib/stripe/resources/payment_intent.rb', line 1780 def renter_name @renter_name end |
#return_address ⇒ Object (readonly)
Attribute for field return_address
1782 1783 1784 |
# File 'lib/stripe/resources/payment_intent.rb', line 1782 def return_address @return_address end |
#return_at ⇒ Object (readonly)
Car return time. Measured in seconds since the Unix epoch.
1784 1785 1786 |
# File 'lib/stripe/resources/payment_intent.rb', line 1784 def return_at @return_at end |
#return_location_name ⇒ Object (readonly)
Name of the return location.
1786 1787 1788 |
# File 'lib/stripe/resources/payment_intent.rb', line 1786 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object (readonly)
Indicates whether the goods or services are tax-exempt or tax is not collected.
1788 1789 1790 |
# File 'lib/stripe/resources/payment_intent.rb', line 1788 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object (readonly)
The vehicle identification number of the car.
1790 1791 1792 |
# File 'lib/stripe/resources/payment_intent.rb', line 1790 def vehicle_identification_number @vehicle_identification_number end |
Class Method Details
.field_remappings ⇒ Object
1803 1804 1805 |
# File 'lib/stripe/resources/payment_intent.rb', line 1803 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 |
# File 'lib/stripe/resources/payment_intent.rb', line 1792 def self.inner_class_types @inner_class_types = { affiliate: Affiliate, delivery: Delivery, distance: Distance, drivers: Driver, pickup_address: PickupAddress, return_address: ReturnAddress, } end |