Class: Stripe::PaymentIntent::PaymentDetails::CarRental

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#affiliateObject (readonly)

Attribute for field affiliate



1474
1475
1476
# File 'lib/stripe/resources/payment_intent.rb', line 1474

def affiliate
  @affiliate
end

#booking_numberObject (readonly)

The booking number associated with the car rental.



1476
1477
1478
# File 'lib/stripe/resources/payment_intent.rb', line 1476

def booking_number
  @booking_number
end

#car_class_codeObject (readonly)

Class code of the car.



1478
1479
1480
# File 'lib/stripe/resources/payment_intent.rb', line 1478

def car_class_code
  @car_class_code
end

#car_makeObject (readonly)

Make of the car.



1480
1481
1482
# File 'lib/stripe/resources/payment_intent.rb', line 1480

def car_make
  @car_make
end

#car_modelObject (readonly)

Model of the car.



1482
1483
1484
# File 'lib/stripe/resources/payment_intent.rb', line 1482

def car_model
  @car_model
end

#companyObject (readonly)

The name of the rental car company.



1484
1485
1486
# File 'lib/stripe/resources/payment_intent.rb', line 1484

def company
  @company
end

#customer_service_phone_numberObject (readonly)

The customer service phone number of the car rental company.



1486
1487
1488
# File 'lib/stripe/resources/payment_intent.rb', line 1486

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject (readonly)

Number of days the car is being rented.



1488
1489
1490
# File 'lib/stripe/resources/payment_intent.rb', line 1488

def days_rented
  @days_rented
end

#deliveryObject (readonly)

Attribute for field delivery



1490
1491
1492
# File 'lib/stripe/resources/payment_intent.rb', line 1490

def delivery
  @delivery
end

#distanceObject (readonly)

Attribute for field distance



1492
1493
1494
# File 'lib/stripe/resources/payment_intent.rb', line 1492

def distance
  @distance
end

#driversObject (readonly)

The details of the drivers associated with the trip.



1494
1495
1496
# File 'lib/stripe/resources/payment_intent.rb', line 1494

def drivers
  @drivers
end

#extra_chargesObject (readonly)

List of additional charges being billed.



1496
1497
1498
# File 'lib/stripe/resources/payment_intent.rb', line 1496

def extra_charges
  @extra_charges
end

#no_showObject (readonly)

Indicates if the customer did not keep nor cancel their booking.



1498
1499
1500
# File 'lib/stripe/resources/payment_intent.rb', line 1498

def no_show
  @no_show
end

#pickup_addressObject (readonly)

Attribute for field pickup_address



1500
1501
1502
# File 'lib/stripe/resources/payment_intent.rb', line 1500

def pickup_address
  @pickup_address
end

#pickup_atObject (readonly)

Car pick-up time. Measured in seconds since the Unix epoch.



1502
1503
1504
# File 'lib/stripe/resources/payment_intent.rb', line 1502

def pickup_at
  @pickup_at
end

#pickup_location_nameObject (readonly)

Name of the pickup location.



1504
1505
1506
# File 'lib/stripe/resources/payment_intent.rb', line 1504

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject (readonly)

Rental rate.



1506
1507
1508
# File 'lib/stripe/resources/payment_intent.rb', line 1506

def rate_amount
  @rate_amount
end

#rate_intervalObject (readonly)

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



1508
1509
1510
# File 'lib/stripe/resources/payment_intent.rb', line 1508

def rate_interval
  @rate_interval
end

#renter_nameObject (readonly)

The full name of the person or entity renting the car.



1510
1511
1512
# File 'lib/stripe/resources/payment_intent.rb', line 1510

def renter_name
  @renter_name
end

#return_addressObject (readonly)

Attribute for field return_address



1512
1513
1514
# File 'lib/stripe/resources/payment_intent.rb', line 1512

def return_address
  @return_address
end

#return_atObject (readonly)

Car return time. Measured in seconds since the Unix epoch.



1514
1515
1516
# File 'lib/stripe/resources/payment_intent.rb', line 1514

def return_at
  @return_at
end

#return_location_nameObject (readonly)

Name of the return location.



1516
1517
1518
# File 'lib/stripe/resources/payment_intent.rb', line 1516

def return_location_name
  @return_location_name
end

#tax_exemptObject (readonly)

Indicates whether the goods or services are tax-exempt or tax is not collected.



1518
1519
1520
# File 'lib/stripe/resources/payment_intent.rb', line 1518

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject (readonly)

The vehicle identification number of the car.



1520
1521
1522
# File 'lib/stripe/resources/payment_intent.rb', line 1520

def vehicle_identification_number
  @vehicle_identification_number
end

Class Method Details

.field_remappingsObject



1533
1534
1535
# File 'lib/stripe/resources/payment_intent.rb', line 1533

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
# File 'lib/stripe/resources/payment_intent.rb', line 1522

def self.inner_class_types
  @inner_class_types = {
    affiliate: Affiliate,
    delivery: Delivery,
    distance: Distance,
    drivers: Driver,
    pickup_address: PickupAddress,
    return_address: ReturnAddress,
  }
end