Class: Stripe::PaymentIntent::PaymentDetails::CarRental

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#affiliateObject (readonly)

Attribute for field affiliate



1610
1611
1612
# File 'lib/stripe/resources/payment_intent.rb', line 1610

def affiliate
  @affiliate
end

#booking_numberObject (readonly)

The booking number associated with the car rental.



1612
1613
1614
# File 'lib/stripe/resources/payment_intent.rb', line 1612

def booking_number
  @booking_number
end

#car_class_codeObject (readonly)

Class code of the car.



1614
1615
1616
# File 'lib/stripe/resources/payment_intent.rb', line 1614

def car_class_code
  @car_class_code
end

#car_makeObject (readonly)

Make of the car.



1616
1617
1618
# File 'lib/stripe/resources/payment_intent.rb', line 1616

def car_make
  @car_make
end

#car_modelObject (readonly)

Model of the car.



1618
1619
1620
# File 'lib/stripe/resources/payment_intent.rb', line 1618

def car_model
  @car_model
end

#companyObject (readonly)

The name of the rental car company.



1620
1621
1622
# File 'lib/stripe/resources/payment_intent.rb', line 1620

def company
  @company
end

#customer_service_phone_numberObject (readonly)

The customer service phone number of the car rental company.



1622
1623
1624
# File 'lib/stripe/resources/payment_intent.rb', line 1622

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject (readonly)

Number of days the car is being rented.



1624
1625
1626
# File 'lib/stripe/resources/payment_intent.rb', line 1624

def days_rented
  @days_rented
end

#deliveryObject (readonly)

Attribute for field delivery



1626
1627
1628
# File 'lib/stripe/resources/payment_intent.rb', line 1626

def delivery
  @delivery
end

#distanceObject (readonly)

Attribute for field distance



1628
1629
1630
# File 'lib/stripe/resources/payment_intent.rb', line 1628

def distance
  @distance
end

#driversObject (readonly)

The details of the drivers associated with the trip.



1630
1631
1632
# File 'lib/stripe/resources/payment_intent.rb', line 1630

def drivers
  @drivers
end

#extra_chargesObject (readonly)

List of additional charges being billed.



1632
1633
1634
# File 'lib/stripe/resources/payment_intent.rb', line 1632

def extra_charges
  @extra_charges
end

#no_showObject (readonly)

Indicates if the customer did not keep nor cancel their booking.



1634
1635
1636
# File 'lib/stripe/resources/payment_intent.rb', line 1634

def no_show
  @no_show
end

#pickup_addressObject (readonly)

Attribute for field pickup_address



1636
1637
1638
# File 'lib/stripe/resources/payment_intent.rb', line 1636

def pickup_address
  @pickup_address
end

#pickup_atObject (readonly)

Car pick-up time. Measured in seconds since the Unix epoch.



1638
1639
1640
# File 'lib/stripe/resources/payment_intent.rb', line 1638

def pickup_at
  @pickup_at
end

#pickup_location_nameObject (readonly)

Name of the pickup location.



1640
1641
1642
# File 'lib/stripe/resources/payment_intent.rb', line 1640

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject (readonly)

Rental rate.



1642
1643
1644
# File 'lib/stripe/resources/payment_intent.rb', line 1642

def rate_amount
  @rate_amount
end

#rate_intervalObject (readonly)

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



1644
1645
1646
# File 'lib/stripe/resources/payment_intent.rb', line 1644

def rate_interval
  @rate_interval
end

#renter_nameObject (readonly)

The full name of the person or entity renting the car.



1646
1647
1648
# File 'lib/stripe/resources/payment_intent.rb', line 1646

def renter_name
  @renter_name
end

#return_addressObject (readonly)

Attribute for field return_address



1648
1649
1650
# File 'lib/stripe/resources/payment_intent.rb', line 1648

def return_address
  @return_address
end

#return_atObject (readonly)

Car return time. Measured in seconds since the Unix epoch.



1650
1651
1652
# File 'lib/stripe/resources/payment_intent.rb', line 1650

def return_at
  @return_at
end

#return_location_nameObject (readonly)

Name of the return location.



1652
1653
1654
# File 'lib/stripe/resources/payment_intent.rb', line 1652

def return_location_name
  @return_location_name
end

#tax_exemptObject (readonly)

Indicates whether the goods or services are tax-exempt or tax is not collected.



1654
1655
1656
# File 'lib/stripe/resources/payment_intent.rb', line 1654

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject (readonly)

The vehicle identification number of the car.



1656
1657
1658
# File 'lib/stripe/resources/payment_intent.rb', line 1656

def vehicle_identification_number
  @vehicle_identification_number
end

Class Method Details

.field_remappingsObject



1669
1670
1671
# File 'lib/stripe/resources/payment_intent.rb', line 1669

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
# File 'lib/stripe/resources/payment_intent.rb', line 1658

def self.inner_class_types
  @inner_class_types = {
    affiliate: Affiliate,
    delivery: Delivery,
    distance: Distance,
    drivers: Driver,
    pickup_address: PickupAddress,
    return_address: ReturnAddress,
  }
end