Class: Stripe::PaymentIntent::PaymentDetails::CarRental
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
readonly
Class code of the car.
-
#car_make ⇒ Object
readonly
Make of the car.
-
#car_model ⇒ Object
readonly
Model of the car.
-
#company ⇒ Object
readonly
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
readonly
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
readonly
Number of days the car is being rented.
-
#delivery ⇒ Object
readonly
Attribute for field delivery.
-
#distance ⇒ Object
readonly
Attribute for field distance.
-
#drivers ⇒ Object
readonly
The details of the drivers associated with the trip.
-
#extra_charges ⇒ Object
readonly
List of additional charges being billed.
-
#no_show ⇒ Object
readonly
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
readonly
Attribute for field pickup_address.
-
#pickup_at ⇒ Object
readonly
Car pick-up time.
-
#pickup_location_name ⇒ Object
readonly
Name of the pickup location.
-
#rate_amount ⇒ Object
readonly
Rental rate.
-
#rate_interval ⇒ Object
readonly
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
readonly
The full name of the person or entity renting the car.
-
#return_address ⇒ Object
readonly
Attribute for field return_address.
-
#return_at ⇒ Object
readonly
Car return time.
-
#return_location_name ⇒ Object
readonly
Name of the return location.
-
#tax_exempt ⇒ Object
readonly
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
readonly
The vehicle identification number of the car.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
1632 1633 1634 |
# File 'lib/stripe/resources/payment_intent.rb', line 1632 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
The booking number associated with the car rental.
1634 1635 1636 |
# File 'lib/stripe/resources/payment_intent.rb', line 1634 def booking_number @booking_number end |
#car_class_code ⇒ Object (readonly)
Class code of the car.
1636 1637 1638 |
# File 'lib/stripe/resources/payment_intent.rb', line 1636 def car_class_code @car_class_code end |
#car_make ⇒ Object (readonly)
Make of the car.
1638 1639 1640 |
# File 'lib/stripe/resources/payment_intent.rb', line 1638 def car_make @car_make end |
#car_model ⇒ Object (readonly)
Model of the car.
1640 1641 1642 |
# File 'lib/stripe/resources/payment_intent.rb', line 1640 def car_model @car_model end |
#company ⇒ Object (readonly)
The name of the rental car company.
1642 1643 1644 |
# File 'lib/stripe/resources/payment_intent.rb', line 1642 def company @company end |
#customer_service_phone_number ⇒ Object (readonly)
The customer service phone number of the car rental company.
1644 1645 1646 |
# File 'lib/stripe/resources/payment_intent.rb', line 1644 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object (readonly)
Number of days the car is being rented.
1646 1647 1648 |
# File 'lib/stripe/resources/payment_intent.rb', line 1646 def days_rented @days_rented end |
#delivery ⇒ Object (readonly)
Attribute for field delivery
1648 1649 1650 |
# File 'lib/stripe/resources/payment_intent.rb', line 1648 def delivery @delivery end |
#distance ⇒ Object (readonly)
Attribute for field distance
1650 1651 1652 |
# File 'lib/stripe/resources/payment_intent.rb', line 1650 def distance @distance end |
#drivers ⇒ Object (readonly)
The details of the drivers associated with the trip.
1652 1653 1654 |
# File 'lib/stripe/resources/payment_intent.rb', line 1652 def drivers @drivers end |
#extra_charges ⇒ Object (readonly)
List of additional charges being billed.
1654 1655 1656 |
# File 'lib/stripe/resources/payment_intent.rb', line 1654 def extra_charges @extra_charges end |
#no_show ⇒ Object (readonly)
Indicates if the customer did not keep nor cancel their booking.
1656 1657 1658 |
# File 'lib/stripe/resources/payment_intent.rb', line 1656 def no_show @no_show end |
#pickup_address ⇒ Object (readonly)
Attribute for field pickup_address
1658 1659 1660 |
# File 'lib/stripe/resources/payment_intent.rb', line 1658 def pickup_address @pickup_address end |
#pickup_at ⇒ Object (readonly)
Car pick-up time. Measured in seconds since the Unix epoch.
1660 1661 1662 |
# File 'lib/stripe/resources/payment_intent.rb', line 1660 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object (readonly)
Name of the pickup location.
1662 1663 1664 |
# File 'lib/stripe/resources/payment_intent.rb', line 1662 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object (readonly)
Rental rate.
1664 1665 1666 |
# File 'lib/stripe/resources/payment_intent.rb', line 1664 def rate_amount @rate_amount end |
#rate_interval ⇒ Object (readonly)
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
1666 1667 1668 |
# File 'lib/stripe/resources/payment_intent.rb', line 1666 def rate_interval @rate_interval end |
#renter_name ⇒ Object (readonly)
The full name of the person or entity renting the car.
1668 1669 1670 |
# File 'lib/stripe/resources/payment_intent.rb', line 1668 def renter_name @renter_name end |
#return_address ⇒ Object (readonly)
Attribute for field return_address
1670 1671 1672 |
# File 'lib/stripe/resources/payment_intent.rb', line 1670 def return_address @return_address end |
#return_at ⇒ Object (readonly)
Car return time. Measured in seconds since the Unix epoch.
1672 1673 1674 |
# File 'lib/stripe/resources/payment_intent.rb', line 1672 def return_at @return_at end |
#return_location_name ⇒ Object (readonly)
Name of the return location.
1674 1675 1676 |
# File 'lib/stripe/resources/payment_intent.rb', line 1674 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object (readonly)
Indicates whether the goods or services are tax-exempt or tax is not collected.
1676 1677 1678 |
# File 'lib/stripe/resources/payment_intent.rb', line 1676 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object (readonly)
The vehicle identification number of the car.
1678 1679 1680 |
# File 'lib/stripe/resources/payment_intent.rb', line 1678 def vehicle_identification_number @vehicle_identification_number end |
Class Method Details
.field_remappings ⇒ Object
1691 1692 1693 |
# File 'lib/stripe/resources/payment_intent.rb', line 1691 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 |
# File 'lib/stripe/resources/payment_intent.rb', line 1680 def self.inner_class_types @inner_class_types = { affiliate: Affiliate, delivery: Delivery, distance: Distance, drivers: Driver, pickup_address: PickupAddress, return_address: ReturnAddress, } end |