Class: Stripe::PaymentIntent::PaymentDetails::CarRental
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
readonly
Class code of the car.
-
#car_make ⇒ Object
readonly
Make of the car.
-
#car_model ⇒ Object
readonly
Model of the car.
-
#company ⇒ Object
readonly
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
readonly
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
readonly
Number of days the car is being rented.
-
#delivery ⇒ Object
readonly
Attribute for field delivery.
-
#distance ⇒ Object
readonly
Attribute for field distance.
-
#drivers ⇒ Object
readonly
The details of the drivers associated with the trip.
-
#extra_charges ⇒ Object
readonly
List of additional charges being billed.
-
#no_show ⇒ Object
readonly
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
readonly
Attribute for field pickup_address.
-
#pickup_at ⇒ Object
readonly
Car pick-up time.
-
#pickup_location_name ⇒ Object
readonly
Name of the pickup location.
-
#rate_amount ⇒ Object
readonly
Rental rate.
-
#rate_interval ⇒ Object
readonly
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
readonly
The full name of the person or entity renting the car.
-
#return_address ⇒ Object
readonly
Attribute for field return_address.
-
#return_at ⇒ Object
readonly
Car return time.
-
#return_location_name ⇒ Object
readonly
Name of the return location.
-
#tax_exempt ⇒ Object
readonly
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
readonly
The vehicle identification number of the car.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
1461 1462 1463 |
# File 'lib/stripe/resources/payment_intent.rb', line 1461 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
The booking number associated with the car rental.
1463 1464 1465 |
# File 'lib/stripe/resources/payment_intent.rb', line 1463 def booking_number @booking_number end |
#car_class_code ⇒ Object (readonly)
Class code of the car.
1465 1466 1467 |
# File 'lib/stripe/resources/payment_intent.rb', line 1465 def car_class_code @car_class_code end |
#car_make ⇒ Object (readonly)
Make of the car.
1467 1468 1469 |
# File 'lib/stripe/resources/payment_intent.rb', line 1467 def car_make @car_make end |
#car_model ⇒ Object (readonly)
Model of the car.
1469 1470 1471 |
# File 'lib/stripe/resources/payment_intent.rb', line 1469 def car_model @car_model end |
#company ⇒ Object (readonly)
The name of the rental car company.
1471 1472 1473 |
# File 'lib/stripe/resources/payment_intent.rb', line 1471 def company @company end |
#customer_service_phone_number ⇒ Object (readonly)
The customer service phone number of the car rental company.
1473 1474 1475 |
# File 'lib/stripe/resources/payment_intent.rb', line 1473 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object (readonly)
Number of days the car is being rented.
1475 1476 1477 |
# File 'lib/stripe/resources/payment_intent.rb', line 1475 def days_rented @days_rented end |
#delivery ⇒ Object (readonly)
Attribute for field delivery
1477 1478 1479 |
# File 'lib/stripe/resources/payment_intent.rb', line 1477 def delivery @delivery end |
#distance ⇒ Object (readonly)
Attribute for field distance
1479 1480 1481 |
# File 'lib/stripe/resources/payment_intent.rb', line 1479 def distance @distance end |
#drivers ⇒ Object (readonly)
The details of the drivers associated with the trip.
1481 1482 1483 |
# File 'lib/stripe/resources/payment_intent.rb', line 1481 def drivers @drivers end |
#extra_charges ⇒ Object (readonly)
List of additional charges being billed.
1483 1484 1485 |
# File 'lib/stripe/resources/payment_intent.rb', line 1483 def extra_charges @extra_charges end |
#no_show ⇒ Object (readonly)
Indicates if the customer did not keep nor cancel their booking.
1485 1486 1487 |
# File 'lib/stripe/resources/payment_intent.rb', line 1485 def no_show @no_show end |
#pickup_address ⇒ Object (readonly)
Attribute for field pickup_address
1487 1488 1489 |
# File 'lib/stripe/resources/payment_intent.rb', line 1487 def pickup_address @pickup_address end |
#pickup_at ⇒ Object (readonly)
Car pick-up time. Measured in seconds since the Unix epoch.
1489 1490 1491 |
# File 'lib/stripe/resources/payment_intent.rb', line 1489 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object (readonly)
Name of the pickup location.
1491 1492 1493 |
# File 'lib/stripe/resources/payment_intent.rb', line 1491 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object (readonly)
Rental rate.
1493 1494 1495 |
# File 'lib/stripe/resources/payment_intent.rb', line 1493 def rate_amount @rate_amount end |
#rate_interval ⇒ Object (readonly)
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
1495 1496 1497 |
# File 'lib/stripe/resources/payment_intent.rb', line 1495 def rate_interval @rate_interval end |
#renter_name ⇒ Object (readonly)
The full name of the person or entity renting the car.
1497 1498 1499 |
# File 'lib/stripe/resources/payment_intent.rb', line 1497 def renter_name @renter_name end |
#return_address ⇒ Object (readonly)
Attribute for field return_address
1499 1500 1501 |
# File 'lib/stripe/resources/payment_intent.rb', line 1499 def return_address @return_address end |
#return_at ⇒ Object (readonly)
Car return time. Measured in seconds since the Unix epoch.
1501 1502 1503 |
# File 'lib/stripe/resources/payment_intent.rb', line 1501 def return_at @return_at end |
#return_location_name ⇒ Object (readonly)
Name of the return location.
1503 1504 1505 |
# File 'lib/stripe/resources/payment_intent.rb', line 1503 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object (readonly)
Indicates whether the goods or services are tax-exempt or tax is not collected.
1505 1506 1507 |
# File 'lib/stripe/resources/payment_intent.rb', line 1505 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object (readonly)
The vehicle identification number of the car.
1507 1508 1509 |
# File 'lib/stripe/resources/payment_intent.rb', line 1507 def vehicle_identification_number @vehicle_identification_number end |
Class Method Details
.field_remappings ⇒ Object
1520 1521 1522 |
# File 'lib/stripe/resources/payment_intent.rb', line 1520 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 |
# File 'lib/stripe/resources/payment_intent.rb', line 1509 def self.inner_class_types @inner_class_types = { affiliate: Affiliate, delivery: Delivery, distance: Distance, drivers: Driver, pickup_address: PickupAddress, return_address: ReturnAddress, } end |