Class: Stripe::PaymentIntent::PaymentDetails::CarRental

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#affiliateObject (readonly)

Attribute for field affiliate



1534
1535
1536
# File 'lib/stripe/resources/payment_intent.rb', line 1534

def affiliate
  @affiliate
end

#booking_numberObject (readonly)

The booking number associated with the car rental.



1536
1537
1538
# File 'lib/stripe/resources/payment_intent.rb', line 1536

def booking_number
  @booking_number
end

#car_class_codeObject (readonly)

Class code of the car.



1538
1539
1540
# File 'lib/stripe/resources/payment_intent.rb', line 1538

def car_class_code
  @car_class_code
end

#car_makeObject (readonly)

Make of the car.



1540
1541
1542
# File 'lib/stripe/resources/payment_intent.rb', line 1540

def car_make
  @car_make
end

#car_modelObject (readonly)

Model of the car.



1542
1543
1544
# File 'lib/stripe/resources/payment_intent.rb', line 1542

def car_model
  @car_model
end

#companyObject (readonly)

The name of the rental car company.



1544
1545
1546
# File 'lib/stripe/resources/payment_intent.rb', line 1544

def company
  @company
end

#customer_service_phone_numberObject (readonly)

The customer service phone number of the car rental company.



1546
1547
1548
# File 'lib/stripe/resources/payment_intent.rb', line 1546

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject (readonly)

Number of days the car is being rented.



1548
1549
1550
# File 'lib/stripe/resources/payment_intent.rb', line 1548

def days_rented
  @days_rented
end

#deliveryObject (readonly)

Attribute for field delivery



1550
1551
1552
# File 'lib/stripe/resources/payment_intent.rb', line 1550

def delivery
  @delivery
end

#distanceObject (readonly)

Attribute for field distance



1552
1553
1554
# File 'lib/stripe/resources/payment_intent.rb', line 1552

def distance
  @distance
end

#driversObject (readonly)

The details of the drivers associated with the trip.



1554
1555
1556
# File 'lib/stripe/resources/payment_intent.rb', line 1554

def drivers
  @drivers
end

#extra_chargesObject (readonly)

List of additional charges being billed.



1556
1557
1558
# File 'lib/stripe/resources/payment_intent.rb', line 1556

def extra_charges
  @extra_charges
end

#no_showObject (readonly)

Indicates if the customer did not keep nor cancel their booking.



1558
1559
1560
# File 'lib/stripe/resources/payment_intent.rb', line 1558

def no_show
  @no_show
end

#pickup_addressObject (readonly)

Attribute for field pickup_address



1560
1561
1562
# File 'lib/stripe/resources/payment_intent.rb', line 1560

def pickup_address
  @pickup_address
end

#pickup_atObject (readonly)

Car pick-up time. Measured in seconds since the Unix epoch.



1562
1563
1564
# File 'lib/stripe/resources/payment_intent.rb', line 1562

def pickup_at
  @pickup_at
end

#pickup_location_nameObject (readonly)

Name of the pickup location.



1564
1565
1566
# File 'lib/stripe/resources/payment_intent.rb', line 1564

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject (readonly)

Rental rate.



1566
1567
1568
# File 'lib/stripe/resources/payment_intent.rb', line 1566

def rate_amount
  @rate_amount
end

#rate_intervalObject (readonly)

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



1568
1569
1570
# File 'lib/stripe/resources/payment_intent.rb', line 1568

def rate_interval
  @rate_interval
end

#renter_nameObject (readonly)

The full name of the person or entity renting the car.



1570
1571
1572
# File 'lib/stripe/resources/payment_intent.rb', line 1570

def renter_name
  @renter_name
end

#return_addressObject (readonly)

Attribute for field return_address



1572
1573
1574
# File 'lib/stripe/resources/payment_intent.rb', line 1572

def return_address
  @return_address
end

#return_atObject (readonly)

Car return time. Measured in seconds since the Unix epoch.



1574
1575
1576
# File 'lib/stripe/resources/payment_intent.rb', line 1574

def return_at
  @return_at
end

#return_location_nameObject (readonly)

Name of the return location.



1576
1577
1578
# File 'lib/stripe/resources/payment_intent.rb', line 1576

def return_location_name
  @return_location_name
end

#tax_exemptObject (readonly)

Indicates whether the goods or services are tax-exempt or tax is not collected.



1578
1579
1580
# File 'lib/stripe/resources/payment_intent.rb', line 1578

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject (readonly)

The vehicle identification number of the car.



1580
1581
1582
# File 'lib/stripe/resources/payment_intent.rb', line 1580

def vehicle_identification_number
  @vehicle_identification_number
end

Class Method Details

.field_remappingsObject



1593
1594
1595
# File 'lib/stripe/resources/payment_intent.rb', line 1593

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
# File 'lib/stripe/resources/payment_intent.rb', line 1582

def self.inner_class_types
  @inner_class_types = {
    affiliate: Affiliate,
    delivery: Delivery,
    distance: Distance,
    drivers: Driver,
    pickup_address: PickupAddress,
    return_address: ReturnAddress,
  }
end