Class: Stripe::PaymentIntent::PaymentDetails::CarRental

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#affiliateObject (readonly)

Attribute for field affiliate



1403
1404
1405
# File 'lib/stripe/resources/payment_intent.rb', line 1403

def affiliate
  @affiliate
end

#booking_numberObject (readonly)

The booking number associated with the car rental.



1405
1406
1407
# File 'lib/stripe/resources/payment_intent.rb', line 1405

def booking_number
  @booking_number
end

#car_class_codeObject (readonly)

Class code of the car.



1407
1408
1409
# File 'lib/stripe/resources/payment_intent.rb', line 1407

def car_class_code
  @car_class_code
end

#car_makeObject (readonly)

Make of the car.



1409
1410
1411
# File 'lib/stripe/resources/payment_intent.rb', line 1409

def car_make
  @car_make
end

#car_modelObject (readonly)

Model of the car.



1411
1412
1413
# File 'lib/stripe/resources/payment_intent.rb', line 1411

def car_model
  @car_model
end

#companyObject (readonly)

The name of the rental car company.



1413
1414
1415
# File 'lib/stripe/resources/payment_intent.rb', line 1413

def company
  @company
end

#customer_service_phone_numberObject (readonly)

The customer service phone number of the car rental company.



1415
1416
1417
# File 'lib/stripe/resources/payment_intent.rb', line 1415

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject (readonly)

Number of days the car is being rented.



1417
1418
1419
# File 'lib/stripe/resources/payment_intent.rb', line 1417

def days_rented
  @days_rented
end

#deliveryObject (readonly)

Attribute for field delivery



1419
1420
1421
# File 'lib/stripe/resources/payment_intent.rb', line 1419

def delivery
  @delivery
end

#distanceObject (readonly)

Attribute for field distance



1421
1422
1423
# File 'lib/stripe/resources/payment_intent.rb', line 1421

def distance
  @distance
end

#driversObject (readonly)

The details of the drivers associated with the trip.



1423
1424
1425
# File 'lib/stripe/resources/payment_intent.rb', line 1423

def drivers
  @drivers
end

#extra_chargesObject (readonly)

List of additional charges being billed.



1425
1426
1427
# File 'lib/stripe/resources/payment_intent.rb', line 1425

def extra_charges
  @extra_charges
end

#no_showObject (readonly)

Indicates if the customer did not keep nor cancel their booking.



1427
1428
1429
# File 'lib/stripe/resources/payment_intent.rb', line 1427

def no_show
  @no_show
end

#pickup_addressObject (readonly)

Attribute for field pickup_address



1429
1430
1431
# File 'lib/stripe/resources/payment_intent.rb', line 1429

def pickup_address
  @pickup_address
end

#pickup_atObject (readonly)

Car pick-up time. Measured in seconds since the Unix epoch.



1431
1432
1433
# File 'lib/stripe/resources/payment_intent.rb', line 1431

def pickup_at
  @pickup_at
end

#pickup_location_nameObject (readonly)

Name of the pickup location.



1433
1434
1435
# File 'lib/stripe/resources/payment_intent.rb', line 1433

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject (readonly)

Rental rate.



1435
1436
1437
# File 'lib/stripe/resources/payment_intent.rb', line 1435

def rate_amount
  @rate_amount
end

#rate_intervalObject (readonly)

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



1437
1438
1439
# File 'lib/stripe/resources/payment_intent.rb', line 1437

def rate_interval
  @rate_interval
end

#renter_nameObject (readonly)

The full name of the person or entity renting the car.



1439
1440
1441
# File 'lib/stripe/resources/payment_intent.rb', line 1439

def renter_name
  @renter_name
end

#return_addressObject (readonly)

Attribute for field return_address



1441
1442
1443
# File 'lib/stripe/resources/payment_intent.rb', line 1441

def return_address
  @return_address
end

#return_atObject (readonly)

Car return time. Measured in seconds since the Unix epoch.



1443
1444
1445
# File 'lib/stripe/resources/payment_intent.rb', line 1443

def return_at
  @return_at
end

#return_location_nameObject (readonly)

Name of the return location.



1445
1446
1447
# File 'lib/stripe/resources/payment_intent.rb', line 1445

def return_location_name
  @return_location_name
end

#tax_exemptObject (readonly)

Indicates whether the goods or services are tax-exempt or tax is not collected.



1447
1448
1449
# File 'lib/stripe/resources/payment_intent.rb', line 1447

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject (readonly)

The vehicle identification number of the car.



1449
1450
1451
# File 'lib/stripe/resources/payment_intent.rb', line 1449

def vehicle_identification_number
  @vehicle_identification_number
end

Class Method Details

.field_remappingsObject



1462
1463
1464
# File 'lib/stripe/resources/payment_intent.rb', line 1462

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
# File 'lib/stripe/resources/payment_intent.rb', line 1451

def self.inner_class_types
  @inner_class_types = {
    affiliate: Affiliate,
    delivery: Delivery,
    distance: Distance,
    drivers: Driver,
    pickup_address: PickupAddress,
    return_address: ReturnAddress,
  }
end