Class: Stripe::PaymentIntent::PaymentDetails::CarRental
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
readonly
Class code of the car.
-
#car_make ⇒ Object
readonly
Make of the car.
-
#car_model ⇒ Object
readonly
Model of the car.
-
#company ⇒ Object
readonly
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
readonly
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
readonly
Number of days the car is being rented.
-
#delivery ⇒ Object
readonly
Attribute for field delivery.
-
#distance ⇒ Object
readonly
Attribute for field distance.
-
#drivers ⇒ Object
readonly
The details of the drivers associated with the trip.
-
#extra_charges ⇒ Object
readonly
List of additional charges being billed.
-
#no_show ⇒ Object
readonly
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
readonly
Attribute for field pickup_address.
-
#pickup_at ⇒ Object
readonly
Car pick-up time.
-
#pickup_location_name ⇒ Object
readonly
Name of the pickup location.
-
#rate_amount ⇒ Object
readonly
Rental rate.
-
#rate_interval ⇒ Object
readonly
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
readonly
The full name of the person or entity renting the car.
-
#return_address ⇒ Object
readonly
Attribute for field return_address.
-
#return_at ⇒ Object
readonly
Car return time.
-
#return_location_name ⇒ Object
readonly
Name of the return location.
-
#tax_exempt ⇒ Object
readonly
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
readonly
The vehicle identification number of the car.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
1365 1366 1367 |
# File 'lib/stripe/resources/payment_intent.rb', line 1365 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
The booking number associated with the car rental.
1367 1368 1369 |
# File 'lib/stripe/resources/payment_intent.rb', line 1367 def booking_number @booking_number end |
#car_class_code ⇒ Object (readonly)
Class code of the car.
1369 1370 1371 |
# File 'lib/stripe/resources/payment_intent.rb', line 1369 def car_class_code @car_class_code end |
#car_make ⇒ Object (readonly)
Make of the car.
1371 1372 1373 |
# File 'lib/stripe/resources/payment_intent.rb', line 1371 def car_make @car_make end |
#car_model ⇒ Object (readonly)
Model of the car.
1373 1374 1375 |
# File 'lib/stripe/resources/payment_intent.rb', line 1373 def car_model @car_model end |
#company ⇒ Object (readonly)
The name of the rental car company.
1375 1376 1377 |
# File 'lib/stripe/resources/payment_intent.rb', line 1375 def company @company end |
#customer_service_phone_number ⇒ Object (readonly)
The customer service phone number of the car rental company.
1377 1378 1379 |
# File 'lib/stripe/resources/payment_intent.rb', line 1377 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object (readonly)
Number of days the car is being rented.
1379 1380 1381 |
# File 'lib/stripe/resources/payment_intent.rb', line 1379 def days_rented @days_rented end |
#delivery ⇒ Object (readonly)
Attribute for field delivery
1381 1382 1383 |
# File 'lib/stripe/resources/payment_intent.rb', line 1381 def delivery @delivery end |
#distance ⇒ Object (readonly)
Attribute for field distance
1383 1384 1385 |
# File 'lib/stripe/resources/payment_intent.rb', line 1383 def distance @distance end |
#drivers ⇒ Object (readonly)
The details of the drivers associated with the trip.
1385 1386 1387 |
# File 'lib/stripe/resources/payment_intent.rb', line 1385 def drivers @drivers end |
#extra_charges ⇒ Object (readonly)
List of additional charges being billed.
1387 1388 1389 |
# File 'lib/stripe/resources/payment_intent.rb', line 1387 def extra_charges @extra_charges end |
#no_show ⇒ Object (readonly)
Indicates if the customer did not keep nor cancel their booking.
1389 1390 1391 |
# File 'lib/stripe/resources/payment_intent.rb', line 1389 def no_show @no_show end |
#pickup_address ⇒ Object (readonly)
Attribute for field pickup_address
1391 1392 1393 |
# File 'lib/stripe/resources/payment_intent.rb', line 1391 def pickup_address @pickup_address end |
#pickup_at ⇒ Object (readonly)
Car pick-up time. Measured in seconds since the Unix epoch.
1393 1394 1395 |
# File 'lib/stripe/resources/payment_intent.rb', line 1393 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object (readonly)
Name of the pickup location.
1395 1396 1397 |
# File 'lib/stripe/resources/payment_intent.rb', line 1395 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object (readonly)
Rental rate.
1397 1398 1399 |
# File 'lib/stripe/resources/payment_intent.rb', line 1397 def rate_amount @rate_amount end |
#rate_interval ⇒ Object (readonly)
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
1399 1400 1401 |
# File 'lib/stripe/resources/payment_intent.rb', line 1399 def rate_interval @rate_interval end |
#renter_name ⇒ Object (readonly)
The full name of the person or entity renting the car.
1401 1402 1403 |
# File 'lib/stripe/resources/payment_intent.rb', line 1401 def renter_name @renter_name end |
#return_address ⇒ Object (readonly)
Attribute for field return_address
1403 1404 1405 |
# File 'lib/stripe/resources/payment_intent.rb', line 1403 def return_address @return_address end |
#return_at ⇒ Object (readonly)
Car return time. Measured in seconds since the Unix epoch.
1405 1406 1407 |
# File 'lib/stripe/resources/payment_intent.rb', line 1405 def return_at @return_at end |
#return_location_name ⇒ Object (readonly)
Name of the return location.
1407 1408 1409 |
# File 'lib/stripe/resources/payment_intent.rb', line 1407 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object (readonly)
Indicates whether the goods or services are tax-exempt or tax is not collected.
1409 1410 1411 |
# File 'lib/stripe/resources/payment_intent.rb', line 1409 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object (readonly)
The vehicle identification number of the car.
1411 1412 1413 |
# File 'lib/stripe/resources/payment_intent.rb', line 1411 def vehicle_identification_number @vehicle_identification_number end |
Class Method Details
.field_remappings ⇒ Object
1424 1425 1426 |
# File 'lib/stripe/resources/payment_intent.rb', line 1424 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 |
# File 'lib/stripe/resources/payment_intent.rb', line 1413 def self.inner_class_types @inner_class_types = { affiliate: Affiliate, delivery: Delivery, distance: Distance, drivers: Driver, pickup_address: PickupAddress, return_address: ReturnAddress, } end |