Class: Stripe::PaymentIntent::PaymentDetails::CarRental

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#affiliateObject (readonly)

Attribute for field affiliate



1349
1350
1351
# File 'lib/stripe/resources/payment_intent.rb', line 1349

def affiliate
  @affiliate
end

#booking_numberObject (readonly)

The booking number associated with the car rental.



1351
1352
1353
# File 'lib/stripe/resources/payment_intent.rb', line 1351

def booking_number
  @booking_number
end

#car_class_codeObject (readonly)

Class code of the car.



1353
1354
1355
# File 'lib/stripe/resources/payment_intent.rb', line 1353

def car_class_code
  @car_class_code
end

#car_makeObject (readonly)

Make of the car.



1355
1356
1357
# File 'lib/stripe/resources/payment_intent.rb', line 1355

def car_make
  @car_make
end

#car_modelObject (readonly)

Model of the car.



1357
1358
1359
# File 'lib/stripe/resources/payment_intent.rb', line 1357

def car_model
  @car_model
end

#companyObject (readonly)

The name of the rental car company.



1359
1360
1361
# File 'lib/stripe/resources/payment_intent.rb', line 1359

def company
  @company
end

#customer_service_phone_numberObject (readonly)

The customer service phone number of the car rental company.



1361
1362
1363
# File 'lib/stripe/resources/payment_intent.rb', line 1361

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject (readonly)

Number of days the car is being rented.



1363
1364
1365
# File 'lib/stripe/resources/payment_intent.rb', line 1363

def days_rented
  @days_rented
end

#deliveryObject (readonly)

Attribute for field delivery



1365
1366
1367
# File 'lib/stripe/resources/payment_intent.rb', line 1365

def delivery
  @delivery
end

#distanceObject (readonly)

Attribute for field distance



1367
1368
1369
# File 'lib/stripe/resources/payment_intent.rb', line 1367

def distance
  @distance
end

#driversObject (readonly)

The details of the drivers associated with the trip.



1369
1370
1371
# File 'lib/stripe/resources/payment_intent.rb', line 1369

def drivers
  @drivers
end

#extra_chargesObject (readonly)

List of additional charges being billed.



1371
1372
1373
# File 'lib/stripe/resources/payment_intent.rb', line 1371

def extra_charges
  @extra_charges
end

#no_showObject (readonly)

Indicates if the customer did not keep nor cancel their booking.



1373
1374
1375
# File 'lib/stripe/resources/payment_intent.rb', line 1373

def no_show
  @no_show
end

#pickup_addressObject (readonly)

Attribute for field pickup_address



1375
1376
1377
# File 'lib/stripe/resources/payment_intent.rb', line 1375

def pickup_address
  @pickup_address
end

#pickup_atObject (readonly)

Car pick-up time. Measured in seconds since the Unix epoch.



1377
1378
1379
# File 'lib/stripe/resources/payment_intent.rb', line 1377

def pickup_at
  @pickup_at
end

#pickup_location_nameObject (readonly)

Name of the pickup location.



1379
1380
1381
# File 'lib/stripe/resources/payment_intent.rb', line 1379

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject (readonly)

Rental rate.



1381
1382
1383
# File 'lib/stripe/resources/payment_intent.rb', line 1381

def rate_amount
  @rate_amount
end

#rate_intervalObject (readonly)

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



1383
1384
1385
# File 'lib/stripe/resources/payment_intent.rb', line 1383

def rate_interval
  @rate_interval
end

#renter_nameObject (readonly)

The full name of the person or entity renting the car.



1385
1386
1387
# File 'lib/stripe/resources/payment_intent.rb', line 1385

def renter_name
  @renter_name
end

#return_addressObject (readonly)

Attribute for field return_address



1387
1388
1389
# File 'lib/stripe/resources/payment_intent.rb', line 1387

def return_address
  @return_address
end

#return_atObject (readonly)

Car return time. Measured in seconds since the Unix epoch.



1389
1390
1391
# File 'lib/stripe/resources/payment_intent.rb', line 1389

def return_at
  @return_at
end

#return_location_nameObject (readonly)

Name of the return location.



1391
1392
1393
# File 'lib/stripe/resources/payment_intent.rb', line 1391

def return_location_name
  @return_location_name
end

#tax_exemptObject (readonly)

Indicates whether the goods or services are tax-exempt or tax is not collected.



1393
1394
1395
# File 'lib/stripe/resources/payment_intent.rb', line 1393

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject (readonly)

The vehicle identification number of the car.



1395
1396
1397
# File 'lib/stripe/resources/payment_intent.rb', line 1395

def vehicle_identification_number
  @vehicle_identification_number
end

Class Method Details

.field_remappingsObject



1408
1409
1410
# File 'lib/stripe/resources/payment_intent.rb', line 1408

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
# File 'lib/stripe/resources/payment_intent.rb', line 1397

def self.inner_class_types
  @inner_class_types = {
    affiliate: Affiliate,
    delivery: Delivery,
    distance: Distance,
    drivers: Driver,
    pickup_address: PickupAddress,
    return_address: ReturnAddress,
  }
end