Class: Stripe::PaymentIntent::PaymentDetails::CarRental
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
readonly
Class code of the car.
-
#car_make ⇒ Object
readonly
Make of the car.
-
#car_model ⇒ Object
readonly
Model of the car.
-
#company ⇒ Object
readonly
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
readonly
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
readonly
Number of days the car is being rented.
-
#delivery ⇒ Object
readonly
Attribute for field delivery.
-
#distance ⇒ Object
readonly
Attribute for field distance.
-
#drivers ⇒ Object
readonly
The details of the drivers associated with the trip.
-
#extra_charges ⇒ Object
readonly
List of additional charges being billed.
-
#no_show ⇒ Object
readonly
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
readonly
Attribute for field pickup_address.
-
#pickup_at ⇒ Object
readonly
Car pick-up time.
-
#pickup_location_name ⇒ Object
readonly
Name of the pickup location.
-
#rate_amount ⇒ Object
readonly
Rental rate.
-
#rate_interval ⇒ Object
readonly
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
readonly
The full name of the person or entity renting the car.
-
#return_address ⇒ Object
readonly
Attribute for field return_address.
-
#return_at ⇒ Object
readonly
Car return time.
-
#return_location_name ⇒ Object
readonly
Name of the return location.
-
#tax_exempt ⇒ Object
readonly
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
readonly
The vehicle identification number of the car.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
1332 1333 1334 |
# File 'lib/stripe/resources/payment_intent.rb', line 1332 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
The booking number associated with the car rental.
1334 1335 1336 |
# File 'lib/stripe/resources/payment_intent.rb', line 1334 def booking_number @booking_number end |
#car_class_code ⇒ Object (readonly)
Class code of the car.
1336 1337 1338 |
# File 'lib/stripe/resources/payment_intent.rb', line 1336 def car_class_code @car_class_code end |
#car_make ⇒ Object (readonly)
Make of the car.
1338 1339 1340 |
# File 'lib/stripe/resources/payment_intent.rb', line 1338 def car_make @car_make end |
#car_model ⇒ Object (readonly)
Model of the car.
1340 1341 1342 |
# File 'lib/stripe/resources/payment_intent.rb', line 1340 def car_model @car_model end |
#company ⇒ Object (readonly)
The name of the rental car company.
1342 1343 1344 |
# File 'lib/stripe/resources/payment_intent.rb', line 1342 def company @company end |
#customer_service_phone_number ⇒ Object (readonly)
The customer service phone number of the car rental company.
1344 1345 1346 |
# File 'lib/stripe/resources/payment_intent.rb', line 1344 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object (readonly)
Number of days the car is being rented.
1346 1347 1348 |
# File 'lib/stripe/resources/payment_intent.rb', line 1346 def days_rented @days_rented end |
#delivery ⇒ Object (readonly)
Attribute for field delivery
1348 1349 1350 |
# File 'lib/stripe/resources/payment_intent.rb', line 1348 def delivery @delivery end |
#distance ⇒ Object (readonly)
Attribute for field distance
1350 1351 1352 |
# File 'lib/stripe/resources/payment_intent.rb', line 1350 def distance @distance end |
#drivers ⇒ Object (readonly)
The details of the drivers associated with the trip.
1352 1353 1354 |
# File 'lib/stripe/resources/payment_intent.rb', line 1352 def drivers @drivers end |
#extra_charges ⇒ Object (readonly)
List of additional charges being billed.
1354 1355 1356 |
# File 'lib/stripe/resources/payment_intent.rb', line 1354 def extra_charges @extra_charges end |
#no_show ⇒ Object (readonly)
Indicates if the customer did not keep nor cancel their booking.
1356 1357 1358 |
# File 'lib/stripe/resources/payment_intent.rb', line 1356 def no_show @no_show end |
#pickup_address ⇒ Object (readonly)
Attribute for field pickup_address
1358 1359 1360 |
# File 'lib/stripe/resources/payment_intent.rb', line 1358 def pickup_address @pickup_address end |
#pickup_at ⇒ Object (readonly)
Car pick-up time. Measured in seconds since the Unix epoch.
1360 1361 1362 |
# File 'lib/stripe/resources/payment_intent.rb', line 1360 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object (readonly)
Name of the pickup location.
1362 1363 1364 |
# File 'lib/stripe/resources/payment_intent.rb', line 1362 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object (readonly)
Rental rate.
1364 1365 1366 |
# File 'lib/stripe/resources/payment_intent.rb', line 1364 def rate_amount @rate_amount end |
#rate_interval ⇒ Object (readonly)
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
1366 1367 1368 |
# File 'lib/stripe/resources/payment_intent.rb', line 1366 def rate_interval @rate_interval end |
#renter_name ⇒ Object (readonly)
The full name of the person or entity renting the car.
1368 1369 1370 |
# File 'lib/stripe/resources/payment_intent.rb', line 1368 def renter_name @renter_name end |
#return_address ⇒ Object (readonly)
Attribute for field return_address
1370 1371 1372 |
# File 'lib/stripe/resources/payment_intent.rb', line 1370 def return_address @return_address end |
#return_at ⇒ Object (readonly)
Car return time. Measured in seconds since the Unix epoch.
1372 1373 1374 |
# File 'lib/stripe/resources/payment_intent.rb', line 1372 def return_at @return_at end |
#return_location_name ⇒ Object (readonly)
Name of the return location.
1374 1375 1376 |
# File 'lib/stripe/resources/payment_intent.rb', line 1374 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object (readonly)
Indicates whether the goods or services are tax-exempt or tax is not collected.
1376 1377 1378 |
# File 'lib/stripe/resources/payment_intent.rb', line 1376 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object (readonly)
The vehicle identification number of the car.
1378 1379 1380 |
# File 'lib/stripe/resources/payment_intent.rb', line 1378 def vehicle_identification_number @vehicle_identification_number end |
Class Method Details
.field_remappings ⇒ Object
1391 1392 1393 |
# File 'lib/stripe/resources/payment_intent.rb', line 1391 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 |
# File 'lib/stripe/resources/payment_intent.rb', line 1380 def self.inner_class_types @inner_class_types = { affiliate: Affiliate, delivery: Delivery, distance: Distance, drivers: Driver, pickup_address: PickupAddress, return_address: ReturnAddress, } end |