Class: Stripe::PaymentIntent::PaymentDetails::CarRental

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#affiliateObject (readonly)

Attribute for field affiliate



779
780
781
# File 'lib/stripe/resources/payment_intent.rb', line 779

def affiliate
  @affiliate
end

#booking_numberObject (readonly)

The booking number associated with the car rental.



781
782
783
# File 'lib/stripe/resources/payment_intent.rb', line 781

def booking_number
  @booking_number
end

#car_class_codeObject (readonly)

Class code of the car.



783
784
785
# File 'lib/stripe/resources/payment_intent.rb', line 783

def car_class_code
  @car_class_code
end

#car_makeObject (readonly)

Make of the car.



785
786
787
# File 'lib/stripe/resources/payment_intent.rb', line 785

def car_make
  @car_make
end

#car_modelObject (readonly)

Model of the car.



787
788
789
# File 'lib/stripe/resources/payment_intent.rb', line 787

def car_model
  @car_model
end

#companyObject (readonly)

The name of the rental car company.



789
790
791
# File 'lib/stripe/resources/payment_intent.rb', line 789

def company
  @company
end

#customer_service_phone_numberObject (readonly)

The customer service phone number of the car rental company.



791
792
793
# File 'lib/stripe/resources/payment_intent.rb', line 791

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject (readonly)

Number of days the car is being rented.



793
794
795
# File 'lib/stripe/resources/payment_intent.rb', line 793

def days_rented
  @days_rented
end

#deliveryObject (readonly)

Attribute for field delivery



795
796
797
# File 'lib/stripe/resources/payment_intent.rb', line 795

def delivery
  @delivery
end

#distanceObject (readonly)

Attribute for field distance



797
798
799
# File 'lib/stripe/resources/payment_intent.rb', line 797

def distance
  @distance
end

#driversObject (readonly)

The details of the drivers associated with the trip.



799
800
801
# File 'lib/stripe/resources/payment_intent.rb', line 799

def drivers
  @drivers
end

#extra_chargesObject (readonly)

List of additional charges being billed.



801
802
803
# File 'lib/stripe/resources/payment_intent.rb', line 801

def extra_charges
  @extra_charges
end

#no_showObject (readonly)

Indicates if the customer did not keep nor cancel their booking.



803
804
805
# File 'lib/stripe/resources/payment_intent.rb', line 803

def no_show
  @no_show
end

#pickup_addressObject (readonly)

Attribute for field pickup_address



805
806
807
# File 'lib/stripe/resources/payment_intent.rb', line 805

def pickup_address
  @pickup_address
end

#pickup_atObject (readonly)

Car pick-up time. Measured in seconds since the Unix epoch.



807
808
809
# File 'lib/stripe/resources/payment_intent.rb', line 807

def pickup_at
  @pickup_at
end

#pickup_location_nameObject (readonly)

Name of the pickup location.



809
810
811
# File 'lib/stripe/resources/payment_intent.rb', line 809

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject (readonly)

Rental rate.



811
812
813
# File 'lib/stripe/resources/payment_intent.rb', line 811

def rate_amount
  @rate_amount
end

#rate_intervalObject (readonly)

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



813
814
815
# File 'lib/stripe/resources/payment_intent.rb', line 813

def rate_interval
  @rate_interval
end

#renter_nameObject (readonly)

The full name of the person or entity renting the car.



815
816
817
# File 'lib/stripe/resources/payment_intent.rb', line 815

def renter_name
  @renter_name
end

#return_addressObject (readonly)

Attribute for field return_address



817
818
819
# File 'lib/stripe/resources/payment_intent.rb', line 817

def return_address
  @return_address
end

#return_atObject (readonly)

Car return time. Measured in seconds since the Unix epoch.



819
820
821
# File 'lib/stripe/resources/payment_intent.rb', line 819

def return_at
  @return_at
end

#return_location_nameObject (readonly)

Name of the return location.



821
822
823
# File 'lib/stripe/resources/payment_intent.rb', line 821

def return_location_name
  @return_location_name
end

#tax_exemptObject (readonly)

Indicates whether the goods or services are tax-exempt or tax is not collected.



823
824
825
# File 'lib/stripe/resources/payment_intent.rb', line 823

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject (readonly)

The vehicle identification number of the car.



825
826
827
# File 'lib/stripe/resources/payment_intent.rb', line 825

def vehicle_identification_number
  @vehicle_identification_number
end