Class: Stripe::PaymentIntent::PaymentDetails::CarRental

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#affiliateObject (readonly)

Attribute for field affiliate



768
769
770
# File 'lib/stripe/resources/payment_intent.rb', line 768

def affiliate
  @affiliate
end

#booking_numberObject (readonly)

The booking number associated with the car rental.



770
771
772
# File 'lib/stripe/resources/payment_intent.rb', line 770

def booking_number
  @booking_number
end

#car_class_codeObject (readonly)

Class code of the car.



772
773
774
# File 'lib/stripe/resources/payment_intent.rb', line 772

def car_class_code
  @car_class_code
end

#car_makeObject (readonly)

Make of the car.



774
775
776
# File 'lib/stripe/resources/payment_intent.rb', line 774

def car_make
  @car_make
end

#car_modelObject (readonly)

Model of the car.



776
777
778
# File 'lib/stripe/resources/payment_intent.rb', line 776

def car_model
  @car_model
end

#companyObject (readonly)

The name of the rental car company.



778
779
780
# File 'lib/stripe/resources/payment_intent.rb', line 778

def company
  @company
end

#customer_service_phone_numberObject (readonly)

The customer service phone number of the car rental company.



780
781
782
# File 'lib/stripe/resources/payment_intent.rb', line 780

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject (readonly)

Number of days the car is being rented.



782
783
784
# File 'lib/stripe/resources/payment_intent.rb', line 782

def days_rented
  @days_rented
end

#deliveryObject (readonly)

Attribute for field delivery



784
785
786
# File 'lib/stripe/resources/payment_intent.rb', line 784

def delivery
  @delivery
end

#driversObject (readonly)

The details of the drivers associated with the trip.



786
787
788
# File 'lib/stripe/resources/payment_intent.rb', line 786

def drivers
  @drivers
end

#extra_chargesObject (readonly)

List of additional charges being billed.



788
789
790
# File 'lib/stripe/resources/payment_intent.rb', line 788

def extra_charges
  @extra_charges
end

#no_showObject (readonly)

Indicates if the customer did not keep nor cancel their booking.



790
791
792
# File 'lib/stripe/resources/payment_intent.rb', line 790

def no_show
  @no_show
end

#pickup_addressObject (readonly)

Attribute for field pickup_address



792
793
794
# File 'lib/stripe/resources/payment_intent.rb', line 792

def pickup_address
  @pickup_address
end

#pickup_atObject (readonly)

Car pick-up time. Measured in seconds since the Unix epoch.



794
795
796
# File 'lib/stripe/resources/payment_intent.rb', line 794

def pickup_at
  @pickup_at
end

#rate_amountObject (readonly)

Rental rate.



796
797
798
# File 'lib/stripe/resources/payment_intent.rb', line 796

def rate_amount
  @rate_amount
end

#rate_intervalObject (readonly)

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



798
799
800
# File 'lib/stripe/resources/payment_intent.rb', line 798

def rate_interval
  @rate_interval
end

#renter_nameObject (readonly)

The full name of the person or entity renting the car.



800
801
802
# File 'lib/stripe/resources/payment_intent.rb', line 800

def renter_name
  @renter_name
end

#return_addressObject (readonly)

Attribute for field return_address



802
803
804
# File 'lib/stripe/resources/payment_intent.rb', line 802

def return_address
  @return_address
end

#return_atObject (readonly)

Car return time. Measured in seconds since the Unix epoch.



804
805
806
# File 'lib/stripe/resources/payment_intent.rb', line 804

def return_at
  @return_at
end

#tax_exemptObject (readonly)

Indicates whether the goods or services are tax-exempt or tax is not collected.



806
807
808
# File 'lib/stripe/resources/payment_intent.rb', line 806

def tax_exempt
  @tax_exempt
end