Class: Stripe::PaymentIntent::PaymentDetails::CarRental
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
readonly
Class code of the car.
-
#car_make ⇒ Object
readonly
Make of the car.
-
#car_model ⇒ Object
readonly
Model of the car.
-
#company ⇒ Object
readonly
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
readonly
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
readonly
Number of days the car is being rented.
-
#delivery ⇒ Object
readonly
Attribute for field delivery.
-
#drivers ⇒ Object
readonly
The details of the drivers associated with the trip.
-
#extra_charges ⇒ Object
readonly
List of additional charges being billed.
-
#no_show ⇒ Object
readonly
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
readonly
Attribute for field pickup_address.
-
#pickup_at ⇒ Object
readonly
Car pick-up time.
-
#rate_amount ⇒ Object
readonly
Rental rate.
-
#rate_interval ⇒ Object
readonly
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
readonly
The full name of the person or entity renting the car.
-
#return_address ⇒ Object
readonly
Attribute for field return_address.
-
#return_at ⇒ Object
readonly
Car return time.
-
#tax_exempt ⇒ Object
readonly
Indicates whether the goods or services are tax-exempt or tax is not collected.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
743 744 745 |
# File 'lib/stripe/resources/payment_intent.rb', line 743 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
The booking number associated with the car rental.
745 746 747 |
# File 'lib/stripe/resources/payment_intent.rb', line 745 def booking_number @booking_number end |
#car_class_code ⇒ Object (readonly)
Class code of the car.
747 748 749 |
# File 'lib/stripe/resources/payment_intent.rb', line 747 def car_class_code @car_class_code end |
#car_make ⇒ Object (readonly)
Make of the car.
749 750 751 |
# File 'lib/stripe/resources/payment_intent.rb', line 749 def car_make @car_make end |
#car_model ⇒ Object (readonly)
Model of the car.
751 752 753 |
# File 'lib/stripe/resources/payment_intent.rb', line 751 def car_model @car_model end |
#company ⇒ Object (readonly)
The name of the rental car company.
753 754 755 |
# File 'lib/stripe/resources/payment_intent.rb', line 753 def company @company end |
#customer_service_phone_number ⇒ Object (readonly)
The customer service phone number of the car rental company.
755 756 757 |
# File 'lib/stripe/resources/payment_intent.rb', line 755 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object (readonly)
Number of days the car is being rented.
757 758 759 |
# File 'lib/stripe/resources/payment_intent.rb', line 757 def days_rented @days_rented end |
#delivery ⇒ Object (readonly)
Attribute for field delivery
759 760 761 |
# File 'lib/stripe/resources/payment_intent.rb', line 759 def delivery @delivery end |
#drivers ⇒ Object (readonly)
The details of the drivers associated with the trip.
761 762 763 |
# File 'lib/stripe/resources/payment_intent.rb', line 761 def drivers @drivers end |
#extra_charges ⇒ Object (readonly)
List of additional charges being billed.
763 764 765 |
# File 'lib/stripe/resources/payment_intent.rb', line 763 def extra_charges @extra_charges end |
#no_show ⇒ Object (readonly)
Indicates if the customer did not keep nor cancel their booking.
765 766 767 |
# File 'lib/stripe/resources/payment_intent.rb', line 765 def no_show @no_show end |
#pickup_address ⇒ Object (readonly)
Attribute for field pickup_address
767 768 769 |
# File 'lib/stripe/resources/payment_intent.rb', line 767 def pickup_address @pickup_address end |
#pickup_at ⇒ Object (readonly)
Car pick-up time. Measured in seconds since the Unix epoch.
769 770 771 |
# File 'lib/stripe/resources/payment_intent.rb', line 769 def pickup_at @pickup_at end |
#rate_amount ⇒ Object (readonly)
Rental rate.
771 772 773 |
# File 'lib/stripe/resources/payment_intent.rb', line 771 def rate_amount @rate_amount end |
#rate_interval ⇒ Object (readonly)
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
773 774 775 |
# File 'lib/stripe/resources/payment_intent.rb', line 773 def rate_interval @rate_interval end |
#renter_name ⇒ Object (readonly)
The full name of the person or entity renting the car.
775 776 777 |
# File 'lib/stripe/resources/payment_intent.rb', line 775 def renter_name @renter_name end |
#return_address ⇒ Object (readonly)
Attribute for field return_address
777 778 779 |
# File 'lib/stripe/resources/payment_intent.rb', line 777 def return_address @return_address end |
#return_at ⇒ Object (readonly)
Car return time. Measured in seconds since the Unix epoch.
779 780 781 |
# File 'lib/stripe/resources/payment_intent.rb', line 779 def return_at @return_at end |
#tax_exempt ⇒ Object (readonly)
Indicates whether the goods or services are tax-exempt or tax is not collected.
781 782 783 |
# File 'lib/stripe/resources/payment_intent.rb', line 781 def tax_exempt @tax_exempt end |