Class: Stripe::PaymentIntent::PaymentDetails::CarRental
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
readonly
Class code of the car.
-
#car_make ⇒ Object
readonly
Make of the car.
-
#car_model ⇒ Object
readonly
Model of the car.
-
#company ⇒ Object
readonly
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
readonly
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
readonly
Number of days the car is being rented.
-
#delivery ⇒ Object
readonly
Attribute for field delivery.
-
#drivers ⇒ Object
readonly
The details of the drivers associated with the trip.
-
#extra_charges ⇒ Object
readonly
List of additional charges being billed.
-
#no_show ⇒ Object
readonly
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
readonly
Attribute for field pickup_address.
-
#pickup_at ⇒ Object
readonly
Car pick-up time.
-
#rate_amount ⇒ Object
readonly
Rental rate.
-
#rate_interval ⇒ Object
readonly
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
readonly
The full name of the person or entity renting the car.
-
#return_address ⇒ Object
readonly
Attribute for field return_address.
-
#return_at ⇒ Object
readonly
Car return time.
-
#tax_exempt ⇒ Object
readonly
Indicates whether the goods or services are tax-exempt or tax is not collected.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
945 946 947 |
# File 'lib/stripe/resources/payment_intent.rb', line 945 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
The booking number associated with the car rental.
948 949 950 |
# File 'lib/stripe/resources/payment_intent.rb', line 948 def booking_number @booking_number end |
#car_class_code ⇒ Object (readonly)
Class code of the car.
951 952 953 |
# File 'lib/stripe/resources/payment_intent.rb', line 951 def car_class_code @car_class_code end |
#car_make ⇒ Object (readonly)
Make of the car.
954 955 956 |
# File 'lib/stripe/resources/payment_intent.rb', line 954 def car_make @car_make end |
#car_model ⇒ Object (readonly)
Model of the car.
957 958 959 |
# File 'lib/stripe/resources/payment_intent.rb', line 957 def car_model @car_model end |
#company ⇒ Object (readonly)
The name of the rental car company.
960 961 962 |
# File 'lib/stripe/resources/payment_intent.rb', line 960 def company @company end |
#customer_service_phone_number ⇒ Object (readonly)
The customer service phone number of the car rental company.
963 964 965 |
# File 'lib/stripe/resources/payment_intent.rb', line 963 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object (readonly)
Number of days the car is being rented.
966 967 968 |
# File 'lib/stripe/resources/payment_intent.rb', line 966 def days_rented @days_rented end |
#delivery ⇒ Object (readonly)
Attribute for field delivery
969 970 971 |
# File 'lib/stripe/resources/payment_intent.rb', line 969 def delivery @delivery end |
#drivers ⇒ Object (readonly)
The details of the drivers associated with the trip.
972 973 974 |
# File 'lib/stripe/resources/payment_intent.rb', line 972 def drivers @drivers end |
#extra_charges ⇒ Object (readonly)
List of additional charges being billed.
975 976 977 |
# File 'lib/stripe/resources/payment_intent.rb', line 975 def extra_charges @extra_charges end |
#no_show ⇒ Object (readonly)
Indicates if the customer did not keep nor cancel their booking.
978 979 980 |
# File 'lib/stripe/resources/payment_intent.rb', line 978 def no_show @no_show end |
#pickup_address ⇒ Object (readonly)
Attribute for field pickup_address
981 982 983 |
# File 'lib/stripe/resources/payment_intent.rb', line 981 def pickup_address @pickup_address end |
#pickup_at ⇒ Object (readonly)
Car pick-up time. Measured in seconds since the Unix epoch.
984 985 986 |
# File 'lib/stripe/resources/payment_intent.rb', line 984 def pickup_at @pickup_at end |
#rate_amount ⇒ Object (readonly)
Rental rate.
987 988 989 |
# File 'lib/stripe/resources/payment_intent.rb', line 987 def rate_amount @rate_amount end |
#rate_interval ⇒ Object (readonly)
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
990 991 992 |
# File 'lib/stripe/resources/payment_intent.rb', line 990 def rate_interval @rate_interval end |
#renter_name ⇒ Object (readonly)
The full name of the person or entity renting the car.
993 994 995 |
# File 'lib/stripe/resources/payment_intent.rb', line 993 def renter_name @renter_name end |
#return_address ⇒ Object (readonly)
Attribute for field return_address
996 997 998 |
# File 'lib/stripe/resources/payment_intent.rb', line 996 def return_address @return_address end |
#return_at ⇒ Object (readonly)
Car return time. Measured in seconds since the Unix epoch.
999 1000 1001 |
# File 'lib/stripe/resources/payment_intent.rb', line 999 def return_at @return_at end |
#tax_exempt ⇒ Object (readonly)
Indicates whether the goods or services are tax-exempt or tax is not collected.
1002 1003 1004 |
# File 'lib/stripe/resources/payment_intent.rb', line 1002 def tax_exempt @tax_exempt end |