Class: Stripe::PaymentIntent::PaymentDetails::CarRentalDatum
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::CarRentalDatum
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Distance, Driver, DropOff, Insurance, Pickup, Total, Vehicle
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
The booking number associated with the car rental.
-
#carrier_name ⇒ Object
readonly
The name of the car rental company.
-
#customer_service_phone_number ⇒ Object
readonly
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
readonly
Number of days the car is being rented.
-
#distance ⇒ Object
readonly
Attribute for field distance.
-
#drivers ⇒ Object
readonly
The details of the drivers associated with the rental.
-
#drop_off ⇒ Object
readonly
Attribute for field drop_off.
-
#insurances ⇒ Object
readonly
Insurance details for the car rental.
-
#no_show_indicator ⇒ Object
readonly
Indicates if the customer did not keep nor cancel their booking.
-
#pickup ⇒ Object
readonly
Attribute for field pickup.
-
#renter_name ⇒ Object
readonly
Name of the person renting the vehicle.
-
#total ⇒ Object
readonly
Attribute for field total.
-
#vehicle ⇒ Object
readonly
Attribute for field vehicle.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
2178 2179 2180 |
# File 'lib/stripe/resources/payment_intent.rb', line 2178 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
The booking number associated with the car rental.
2180 2181 2182 |
# File 'lib/stripe/resources/payment_intent.rb', line 2180 def booking_number @booking_number end |
#carrier_name ⇒ Object (readonly)
The name of the car rental company.
2182 2183 2184 |
# File 'lib/stripe/resources/payment_intent.rb', line 2182 def carrier_name @carrier_name end |
#customer_service_phone_number ⇒ Object (readonly)
The customer service phone number of the car rental company.
2184 2185 2186 |
# File 'lib/stripe/resources/payment_intent.rb', line 2184 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object (readonly)
Number of days the car is being rented.
2186 2187 2188 |
# File 'lib/stripe/resources/payment_intent.rb', line 2186 def days_rented @days_rented end |
#distance ⇒ Object (readonly)
Attribute for field distance
2188 2189 2190 |
# File 'lib/stripe/resources/payment_intent.rb', line 2188 def distance @distance end |
#drivers ⇒ Object (readonly)
The details of the drivers associated with the rental.
2190 2191 2192 |
# File 'lib/stripe/resources/payment_intent.rb', line 2190 def drivers @drivers end |
#drop_off ⇒ Object (readonly)
Attribute for field drop_off
2192 2193 2194 |
# File 'lib/stripe/resources/payment_intent.rb', line 2192 def drop_off @drop_off end |
#insurances ⇒ Object (readonly)
Insurance details for the car rental.
2194 2195 2196 |
# File 'lib/stripe/resources/payment_intent.rb', line 2194 def insurances @insurances end |
#no_show_indicator ⇒ Object (readonly)
Indicates if the customer did not keep nor cancel their booking.
2196 2197 2198 |
# File 'lib/stripe/resources/payment_intent.rb', line 2196 def no_show_indicator @no_show_indicator end |
#pickup ⇒ Object (readonly)
Attribute for field pickup
2198 2199 2200 |
# File 'lib/stripe/resources/payment_intent.rb', line 2198 def pickup @pickup end |
#renter_name ⇒ Object (readonly)
Name of the person renting the vehicle.
2200 2201 2202 |
# File 'lib/stripe/resources/payment_intent.rb', line 2200 def renter_name @renter_name end |
#total ⇒ Object (readonly)
Attribute for field total
2202 2203 2204 |
# File 'lib/stripe/resources/payment_intent.rb', line 2202 def total @total end |
#vehicle ⇒ Object (readonly)
Attribute for field vehicle
2204 2205 2206 |
# File 'lib/stripe/resources/payment_intent.rb', line 2204 def vehicle @vehicle end |
Class Method Details
.field_remappings ⇒ Object
2219 2220 2221 |
# File 'lib/stripe/resources/payment_intent.rb', line 2219 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 |
# File 'lib/stripe/resources/payment_intent.rb', line 2206 def self.inner_class_types @inner_class_types = { affiliate: Affiliate, distance: Distance, drivers: Driver, drop_off: DropOff, insurances: Insurance, pickup: Pickup, total: Total, vehicle: Vehicle, } end |