Class: Stripe::PaymentIntent::PaymentDetails::CarRentalDatum
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::CarRentalDatum
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Distance, Driver, DropOff, Insurance, Pickup, Total, Vehicle
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
The booking number associated with the car rental.
-
#carrier_name ⇒ Object
readonly
The name of the car rental company.
-
#customer_service_phone_number ⇒ Object
readonly
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
readonly
Number of days the car is being rented.
-
#distance ⇒ Object
readonly
Attribute for field distance.
-
#drivers ⇒ Object
readonly
The details of the drivers associated with the rental.
-
#drop_off ⇒ Object
readonly
Attribute for field drop_off.
-
#insurances ⇒ Object
readonly
Insurance details for the car rental.
-
#no_show_indicator ⇒ Object
readonly
Indicates if the customer did not keep nor cancel their booking.
-
#pickup ⇒ Object
readonly
Attribute for field pickup.
-
#renter_name ⇒ Object
readonly
Name of the person renting the vehicle.
-
#total ⇒ Object
readonly
Attribute for field total.
-
#vehicle ⇒ Object
readonly
Attribute for field vehicle.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
2081 2082 2083 |
# File 'lib/stripe/resources/payment_intent.rb', line 2081 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
The booking number associated with the car rental.
2083 2084 2085 |
# File 'lib/stripe/resources/payment_intent.rb', line 2083 def booking_number @booking_number end |
#carrier_name ⇒ Object (readonly)
The name of the car rental company.
2085 2086 2087 |
# File 'lib/stripe/resources/payment_intent.rb', line 2085 def carrier_name @carrier_name end |
#customer_service_phone_number ⇒ Object (readonly)
The customer service phone number of the car rental company.
2087 2088 2089 |
# File 'lib/stripe/resources/payment_intent.rb', line 2087 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object (readonly)
Number of days the car is being rented.
2089 2090 2091 |
# File 'lib/stripe/resources/payment_intent.rb', line 2089 def days_rented @days_rented end |
#distance ⇒ Object (readonly)
Attribute for field distance
2091 2092 2093 |
# File 'lib/stripe/resources/payment_intent.rb', line 2091 def distance @distance end |
#drivers ⇒ Object (readonly)
The details of the drivers associated with the rental.
2093 2094 2095 |
# File 'lib/stripe/resources/payment_intent.rb', line 2093 def drivers @drivers end |
#drop_off ⇒ Object (readonly)
Attribute for field drop_off
2095 2096 2097 |
# File 'lib/stripe/resources/payment_intent.rb', line 2095 def drop_off @drop_off end |
#insurances ⇒ Object (readonly)
Insurance details for the car rental.
2097 2098 2099 |
# File 'lib/stripe/resources/payment_intent.rb', line 2097 def insurances @insurances end |
#no_show_indicator ⇒ Object (readonly)
Indicates if the customer did not keep nor cancel their booking.
2099 2100 2101 |
# File 'lib/stripe/resources/payment_intent.rb', line 2099 def no_show_indicator @no_show_indicator end |
#pickup ⇒ Object (readonly)
Attribute for field pickup
2101 2102 2103 |
# File 'lib/stripe/resources/payment_intent.rb', line 2101 def pickup @pickup end |
#renter_name ⇒ Object (readonly)
Name of the person renting the vehicle.
2103 2104 2105 |
# File 'lib/stripe/resources/payment_intent.rb', line 2103 def renter_name @renter_name end |
#total ⇒ Object (readonly)
Attribute for field total
2105 2106 2107 |
# File 'lib/stripe/resources/payment_intent.rb', line 2105 def total @total end |
#vehicle ⇒ Object (readonly)
Attribute for field vehicle
2107 2108 2109 |
# File 'lib/stripe/resources/payment_intent.rb', line 2107 def vehicle @vehicle end |
Class Method Details
.field_remappings ⇒ Object
2122 2123 2124 |
# File 'lib/stripe/resources/payment_intent.rb', line 2122 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 |
# File 'lib/stripe/resources/payment_intent.rb', line 2109 def self.inner_class_types @inner_class_types = { affiliate: Affiliate, distance: Distance, drivers: Driver, drop_off: DropOff, insurances: Insurance, pickup: Pickup, total: Total, vehicle: Vehicle, } end |