Class: Stripe::PaymentIntent::PaymentDetails::CarRentalDatum

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Distance, Driver, DropOff, Insurance, Pickup, Total, Vehicle

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#affiliateObject (readonly)

Attribute for field affiliate



1811
1812
1813
# File 'lib/stripe/resources/payment_intent.rb', line 1811

def affiliate
  @affiliate
end

#booking_numberObject (readonly)

The booking number associated with the car rental.



1813
1814
1815
# File 'lib/stripe/resources/payment_intent.rb', line 1813

def booking_number
  @booking_number
end

#carrier_nameObject (readonly)

The name of the car rental company.



1815
1816
1817
# File 'lib/stripe/resources/payment_intent.rb', line 1815

def carrier_name
  @carrier_name
end

#customer_service_phone_numberObject (readonly)

The customer service phone number of the car rental company.



1817
1818
1819
# File 'lib/stripe/resources/payment_intent.rb', line 1817

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject (readonly)

Number of days the car is being rented.



1819
1820
1821
# File 'lib/stripe/resources/payment_intent.rb', line 1819

def days_rented
  @days_rented
end

#distanceObject (readonly)

Attribute for field distance



1821
1822
1823
# File 'lib/stripe/resources/payment_intent.rb', line 1821

def distance
  @distance
end

#driversObject (readonly)

The details of the drivers associated with the rental.



1823
1824
1825
# File 'lib/stripe/resources/payment_intent.rb', line 1823

def drivers
  @drivers
end

#drop_offObject (readonly)

Attribute for field drop_off



1825
1826
1827
# File 'lib/stripe/resources/payment_intent.rb', line 1825

def drop_off
  @drop_off
end

#insurancesObject (readonly)

Insurance details for the car rental.



1827
1828
1829
# File 'lib/stripe/resources/payment_intent.rb', line 1827

def insurances
  @insurances
end

#no_show_indicatorObject (readonly)

Indicates if the customer did not keep nor cancel their booking.



1829
1830
1831
# File 'lib/stripe/resources/payment_intent.rb', line 1829

def no_show_indicator
  @no_show_indicator
end

#pickupObject (readonly)

Attribute for field pickup



1831
1832
1833
# File 'lib/stripe/resources/payment_intent.rb', line 1831

def pickup
  @pickup
end

#renter_nameObject (readonly)

Name of the person renting the vehicle.



1833
1834
1835
# File 'lib/stripe/resources/payment_intent.rb', line 1833

def renter_name
  @renter_name
end

#totalObject (readonly)

Attribute for field total



1835
1836
1837
# File 'lib/stripe/resources/payment_intent.rb', line 1835

def total
  @total
end

#vehicleObject (readonly)

Attribute for field vehicle



1837
1838
1839
# File 'lib/stripe/resources/payment_intent.rb', line 1837

def vehicle
  @vehicle
end

Class Method Details

.field_remappingsObject



1852
1853
1854
# File 'lib/stripe/resources/payment_intent.rb', line 1852

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
# File 'lib/stripe/resources/payment_intent.rb', line 1839

def self.inner_class_types
  @inner_class_types = {
    affiliate: Affiliate,
    distance: Distance,
    drivers: Driver,
    drop_off: DropOff,
    insurances: Insurance,
    pickup: Pickup,
    total: Total,
    vehicle: Vehicle,
  }
end