Class: Stripe::PaymentIntent::PaymentDetails::CarRentalDatum

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Distance, Driver, DropOff, Insurance, Pickup, Total, Vehicle

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#affiliateObject (readonly)

Attribute for field affiliate



2066
2067
2068
# File 'lib/stripe/resources/payment_intent.rb', line 2066

def affiliate
  @affiliate
end

#booking_numberObject (readonly)

The booking number associated with the car rental.



2068
2069
2070
# File 'lib/stripe/resources/payment_intent.rb', line 2068

def booking_number
  @booking_number
end

#carrier_nameObject (readonly)

The name of the car rental company.



2070
2071
2072
# File 'lib/stripe/resources/payment_intent.rb', line 2070

def carrier_name
  @carrier_name
end

#customer_service_phone_numberObject (readonly)

The customer service phone number of the car rental company.



2072
2073
2074
# File 'lib/stripe/resources/payment_intent.rb', line 2072

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject (readonly)

Number of days the car is being rented.



2074
2075
2076
# File 'lib/stripe/resources/payment_intent.rb', line 2074

def days_rented
  @days_rented
end

#distanceObject (readonly)

Attribute for field distance



2076
2077
2078
# File 'lib/stripe/resources/payment_intent.rb', line 2076

def distance
  @distance
end

#driversObject (readonly)

The details of the drivers associated with the rental.



2078
2079
2080
# File 'lib/stripe/resources/payment_intent.rb', line 2078

def drivers
  @drivers
end

#drop_offObject (readonly)

Attribute for field drop_off



2080
2081
2082
# File 'lib/stripe/resources/payment_intent.rb', line 2080

def drop_off
  @drop_off
end

#insurancesObject (readonly)

Insurance details for the car rental.



2082
2083
2084
# File 'lib/stripe/resources/payment_intent.rb', line 2082

def insurances
  @insurances
end

#no_show_indicatorObject (readonly)

Indicates if the customer did not keep nor cancel their booking.



2084
2085
2086
# File 'lib/stripe/resources/payment_intent.rb', line 2084

def no_show_indicator
  @no_show_indicator
end

#pickupObject (readonly)

Attribute for field pickup



2086
2087
2088
# File 'lib/stripe/resources/payment_intent.rb', line 2086

def pickup
  @pickup
end

#renter_nameObject (readonly)

Name of the person renting the vehicle.



2088
2089
2090
# File 'lib/stripe/resources/payment_intent.rb', line 2088

def renter_name
  @renter_name
end

#totalObject (readonly)

Attribute for field total



2090
2091
2092
# File 'lib/stripe/resources/payment_intent.rb', line 2090

def total
  @total
end

#vehicleObject (readonly)

Attribute for field vehicle



2092
2093
2094
# File 'lib/stripe/resources/payment_intent.rb', line 2092

def vehicle
  @vehicle
end

Class Method Details

.field_remappingsObject



2107
2108
2109
# File 'lib/stripe/resources/payment_intent.rb', line 2107

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
# File 'lib/stripe/resources/payment_intent.rb', line 2094

def self.inner_class_types
  @inner_class_types = {
    affiliate: Affiliate,
    distance: Distance,
    drivers: Driver,
    drop_off: DropOff,
    insurances: Insurance,
    pickup: Pickup,
    total: Total,
    vehicle: Vehicle,
  }
end