Class: Stripe::PaymentIntent::PaymentDetails::CarRentalDatum
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::CarRentalDatum
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Distance, Driver, DropOff, Insurance, Pickup, Total, Vehicle
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
The booking number associated with the car rental.
-
#carrier_name ⇒ Object
readonly
The name of the car rental company.
-
#customer_service_phone_number ⇒ Object
readonly
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
readonly
Number of days the car is being rented.
-
#distance ⇒ Object
readonly
Attribute for field distance.
-
#drivers ⇒ Object
readonly
The details of the drivers associated with the rental.
-
#drop_off ⇒ Object
readonly
Attribute for field drop_off.
-
#insurances ⇒ Object
readonly
Insurance details for the car rental.
-
#no_show_indicator ⇒ Object
readonly
Indicates if the customer did not keep nor cancel their booking.
-
#pickup ⇒ Object
readonly
Attribute for field pickup.
-
#renter_name ⇒ Object
readonly
Name of the person renting the vehicle.
-
#total ⇒ Object
readonly
Attribute for field total.
-
#vehicle ⇒ Object
readonly
Attribute for field vehicle.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
1947 1948 1949 |
# File 'lib/stripe/resources/payment_intent.rb', line 1947 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
The booking number associated with the car rental.
1949 1950 1951 |
# File 'lib/stripe/resources/payment_intent.rb', line 1949 def booking_number @booking_number end |
#carrier_name ⇒ Object (readonly)
The name of the car rental company.
1951 1952 1953 |
# File 'lib/stripe/resources/payment_intent.rb', line 1951 def carrier_name @carrier_name end |
#customer_service_phone_number ⇒ Object (readonly)
The customer service phone number of the car rental company.
1953 1954 1955 |
# File 'lib/stripe/resources/payment_intent.rb', line 1953 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object (readonly)
Number of days the car is being rented.
1955 1956 1957 |
# File 'lib/stripe/resources/payment_intent.rb', line 1955 def days_rented @days_rented end |
#distance ⇒ Object (readonly)
Attribute for field distance
1957 1958 1959 |
# File 'lib/stripe/resources/payment_intent.rb', line 1957 def distance @distance end |
#drivers ⇒ Object (readonly)
The details of the drivers associated with the rental.
1959 1960 1961 |
# File 'lib/stripe/resources/payment_intent.rb', line 1959 def drivers @drivers end |
#drop_off ⇒ Object (readonly)
Attribute for field drop_off
1961 1962 1963 |
# File 'lib/stripe/resources/payment_intent.rb', line 1961 def drop_off @drop_off end |
#insurances ⇒ Object (readonly)
Insurance details for the car rental.
1963 1964 1965 |
# File 'lib/stripe/resources/payment_intent.rb', line 1963 def insurances @insurances end |
#no_show_indicator ⇒ Object (readonly)
Indicates if the customer did not keep nor cancel their booking.
1965 1966 1967 |
# File 'lib/stripe/resources/payment_intent.rb', line 1965 def no_show_indicator @no_show_indicator end |
#pickup ⇒ Object (readonly)
Attribute for field pickup
1967 1968 1969 |
# File 'lib/stripe/resources/payment_intent.rb', line 1967 def pickup @pickup end |
#renter_name ⇒ Object (readonly)
Name of the person renting the vehicle.
1969 1970 1971 |
# File 'lib/stripe/resources/payment_intent.rb', line 1969 def renter_name @renter_name end |
#total ⇒ Object (readonly)
Attribute for field total
1971 1972 1973 |
# File 'lib/stripe/resources/payment_intent.rb', line 1971 def total @total end |
#vehicle ⇒ Object (readonly)
Attribute for field vehicle
1973 1974 1975 |
# File 'lib/stripe/resources/payment_intent.rb', line 1973 def vehicle @vehicle end |
Class Method Details
.field_remappings ⇒ Object
1988 1989 1990 |
# File 'lib/stripe/resources/payment_intent.rb', line 1988 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 |
# File 'lib/stripe/resources/payment_intent.rb', line 1975 def self.inner_class_types @inner_class_types = { affiliate: Affiliate, distance: Distance, drivers: Driver, drop_off: DropOff, insurances: Insurance, pickup: Pickup, total: Total, vehicle: Vehicle, } end |