Class: Stripe::PaymentIntent::PaymentDetails::CarRentalDatum

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Distance, Driver, DropOff, Insurance, Pickup, Total, Vehicle

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#affiliateObject (readonly)

Attribute for field affiliate



1798
1799
1800
# File 'lib/stripe/resources/payment_intent.rb', line 1798

def affiliate
  @affiliate
end

#booking_numberObject (readonly)

The booking number associated with the car rental.



1800
1801
1802
# File 'lib/stripe/resources/payment_intent.rb', line 1800

def booking_number
  @booking_number
end

#carrier_nameObject (readonly)

The name of the car rental company.



1802
1803
1804
# File 'lib/stripe/resources/payment_intent.rb', line 1802

def carrier_name
  @carrier_name
end

#customer_service_phone_numberObject (readonly)

The customer service phone number of the car rental company.



1804
1805
1806
# File 'lib/stripe/resources/payment_intent.rb', line 1804

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject (readonly)

Number of days the car is being rented.



1806
1807
1808
# File 'lib/stripe/resources/payment_intent.rb', line 1806

def days_rented
  @days_rented
end

#distanceObject (readonly)

Attribute for field distance



1808
1809
1810
# File 'lib/stripe/resources/payment_intent.rb', line 1808

def distance
  @distance
end

#driversObject (readonly)

The details of the drivers associated with the rental.



1810
1811
1812
# File 'lib/stripe/resources/payment_intent.rb', line 1810

def drivers
  @drivers
end

#drop_offObject (readonly)

Attribute for field drop_off



1812
1813
1814
# File 'lib/stripe/resources/payment_intent.rb', line 1812

def drop_off
  @drop_off
end

#insurancesObject (readonly)

Insurance details for the car rental.



1814
1815
1816
# File 'lib/stripe/resources/payment_intent.rb', line 1814

def insurances
  @insurances
end

#no_show_indicatorObject (readonly)

Indicates if the customer did not keep nor cancel their booking.



1816
1817
1818
# File 'lib/stripe/resources/payment_intent.rb', line 1816

def no_show_indicator
  @no_show_indicator
end

#pickupObject (readonly)

Attribute for field pickup



1818
1819
1820
# File 'lib/stripe/resources/payment_intent.rb', line 1818

def pickup
  @pickup
end

#renter_nameObject (readonly)

Name of the person renting the vehicle.



1820
1821
1822
# File 'lib/stripe/resources/payment_intent.rb', line 1820

def renter_name
  @renter_name
end

#totalObject (readonly)

Attribute for field total



1822
1823
1824
# File 'lib/stripe/resources/payment_intent.rb', line 1822

def total
  @total
end

#vehicleObject (readonly)

Attribute for field vehicle



1824
1825
1826
# File 'lib/stripe/resources/payment_intent.rb', line 1824

def vehicle
  @vehicle
end

Class Method Details

.field_remappingsObject



1839
1840
1841
# File 'lib/stripe/resources/payment_intent.rb', line 1839

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
1837
# File 'lib/stripe/resources/payment_intent.rb', line 1826

def self.inner_class_types
  @inner_class_types = {
    affiliate: Affiliate,
    distance: Distance,
    drivers: Driver,
    drop_off: DropOff,
    insurances: Insurance,
    pickup: Pickup,
    total: Total,
    vehicle: Vehicle,
  }
end