Class: Stripe::PaymentIntent::PaymentDetails::CarRentalDatum

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Distance, Driver, DropOff, Insurance, Pickup, Total, Vehicle

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#affiliateObject (readonly)

Attribute for field affiliate



1932
1933
1934
# File 'lib/stripe/resources/payment_intent.rb', line 1932

def affiliate
  @affiliate
end

#booking_numberObject (readonly)

The booking number associated with the car rental.



1934
1935
1936
# File 'lib/stripe/resources/payment_intent.rb', line 1934

def booking_number
  @booking_number
end

#carrier_nameObject (readonly)

The name of the car rental company.



1936
1937
1938
# File 'lib/stripe/resources/payment_intent.rb', line 1936

def carrier_name
  @carrier_name
end

#customer_service_phone_numberObject (readonly)

The customer service phone number of the car rental company.



1938
1939
1940
# File 'lib/stripe/resources/payment_intent.rb', line 1938

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject (readonly)

Number of days the car is being rented.



1940
1941
1942
# File 'lib/stripe/resources/payment_intent.rb', line 1940

def days_rented
  @days_rented
end

#distanceObject (readonly)

Attribute for field distance



1942
1943
1944
# File 'lib/stripe/resources/payment_intent.rb', line 1942

def distance
  @distance
end

#driversObject (readonly)

The details of the drivers associated with the rental.



1944
1945
1946
# File 'lib/stripe/resources/payment_intent.rb', line 1944

def drivers
  @drivers
end

#drop_offObject (readonly)

Attribute for field drop_off



1946
1947
1948
# File 'lib/stripe/resources/payment_intent.rb', line 1946

def drop_off
  @drop_off
end

#insurancesObject (readonly)

Insurance details for the car rental.



1948
1949
1950
# File 'lib/stripe/resources/payment_intent.rb', line 1948

def insurances
  @insurances
end

#no_show_indicatorObject (readonly)

Indicates if the customer did not keep nor cancel their booking.



1950
1951
1952
# File 'lib/stripe/resources/payment_intent.rb', line 1950

def no_show_indicator
  @no_show_indicator
end

#pickupObject (readonly)

Attribute for field pickup



1952
1953
1954
# File 'lib/stripe/resources/payment_intent.rb', line 1952

def pickup
  @pickup
end

#renter_nameObject (readonly)

Name of the person renting the vehicle.



1954
1955
1956
# File 'lib/stripe/resources/payment_intent.rb', line 1954

def renter_name
  @renter_name
end

#totalObject (readonly)

Attribute for field total



1956
1957
1958
# File 'lib/stripe/resources/payment_intent.rb', line 1956

def total
  @total
end

#vehicleObject (readonly)

Attribute for field vehicle



1958
1959
1960
# File 'lib/stripe/resources/payment_intent.rb', line 1958

def vehicle
  @vehicle
end

Class Method Details

.field_remappingsObject



1973
1974
1975
# File 'lib/stripe/resources/payment_intent.rb', line 1973

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
# File 'lib/stripe/resources/payment_intent.rb', line 1960

def self.inner_class_types
  @inner_class_types = {
    affiliate: Affiliate,
    distance: Distance,
    drivers: Driver,
    drop_off: DropOff,
    insurances: Insurance,
    pickup: Pickup,
    total: Total,
    vehicle: Vehicle,
  }
end