Class: Stripe::PaymentIntent::PaymentDetails::CarRentalDatum

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Distance, Driver, DropOff, Insurance, Pickup, Total, Vehicle

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#affiliateObject (readonly)

Attribute for field affiliate



1871
1872
1873
# File 'lib/stripe/resources/payment_intent.rb', line 1871

def affiliate
  @affiliate
end

#booking_numberObject (readonly)

The booking number associated with the car rental.



1873
1874
1875
# File 'lib/stripe/resources/payment_intent.rb', line 1873

def booking_number
  @booking_number
end

#carrier_nameObject (readonly)

The name of the car rental company.



1875
1876
1877
# File 'lib/stripe/resources/payment_intent.rb', line 1875

def carrier_name
  @carrier_name
end

#customer_service_phone_numberObject (readonly)

The customer service phone number of the car rental company.



1877
1878
1879
# File 'lib/stripe/resources/payment_intent.rb', line 1877

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject (readonly)

Number of days the car is being rented.



1879
1880
1881
# File 'lib/stripe/resources/payment_intent.rb', line 1879

def days_rented
  @days_rented
end

#distanceObject (readonly)

Attribute for field distance



1881
1882
1883
# File 'lib/stripe/resources/payment_intent.rb', line 1881

def distance
  @distance
end

#driversObject (readonly)

The details of the drivers associated with the rental.



1883
1884
1885
# File 'lib/stripe/resources/payment_intent.rb', line 1883

def drivers
  @drivers
end

#drop_offObject (readonly)

Attribute for field drop_off



1885
1886
1887
# File 'lib/stripe/resources/payment_intent.rb', line 1885

def drop_off
  @drop_off
end

#insurancesObject (readonly)

Insurance details for the car rental.



1887
1888
1889
# File 'lib/stripe/resources/payment_intent.rb', line 1887

def insurances
  @insurances
end

#no_show_indicatorObject (readonly)

Indicates if the customer did not keep nor cancel their booking.



1889
1890
1891
# File 'lib/stripe/resources/payment_intent.rb', line 1889

def no_show_indicator
  @no_show_indicator
end

#pickupObject (readonly)

Attribute for field pickup



1891
1892
1893
# File 'lib/stripe/resources/payment_intent.rb', line 1891

def pickup
  @pickup
end

#renter_nameObject (readonly)

Name of the person renting the vehicle.



1893
1894
1895
# File 'lib/stripe/resources/payment_intent.rb', line 1893

def renter_name
  @renter_name
end

#totalObject (readonly)

Attribute for field total



1895
1896
1897
# File 'lib/stripe/resources/payment_intent.rb', line 1895

def total
  @total
end

#vehicleObject (readonly)

Attribute for field vehicle



1897
1898
1899
# File 'lib/stripe/resources/payment_intent.rb', line 1897

def vehicle
  @vehicle
end

Class Method Details

.field_remappingsObject



1912
1913
1914
# File 'lib/stripe/resources/payment_intent.rb', line 1912

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
# File 'lib/stripe/resources/payment_intent.rb', line 1899

def self.inner_class_types
  @inner_class_types = {
    affiliate: Affiliate,
    distance: Distance,
    drivers: Driver,
    drop_off: DropOff,
    insurances: Insurance,
    pickup: Pickup,
    total: Total,
    vehicle: Vehicle,
  }
end