Class: Stripe::PaymentIntent::PaymentDetails::CarRentalDatum
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::CarRentalDatum
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Distance, Driver, DropOff, Insurance, Pickup, Total, Vehicle
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
The booking number associated with the car rental.
-
#carrier_name ⇒ Object
readonly
The name of the car rental company.
-
#customer_service_phone_number ⇒ Object
readonly
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
readonly
Number of days the car is being rented.
-
#distance ⇒ Object
readonly
Attribute for field distance.
-
#drivers ⇒ Object
readonly
The details of the drivers associated with the rental.
-
#drop_off ⇒ Object
readonly
Attribute for field drop_off.
-
#insurances ⇒ Object
readonly
Insurance details for the car rental.
-
#no_show_indicator ⇒ Object
readonly
Indicates if the customer did not keep nor cancel their booking.
-
#pickup ⇒ Object
readonly
Attribute for field pickup.
-
#renter_name ⇒ Object
readonly
Name of the person renting the vehicle.
-
#total ⇒ Object
readonly
Attribute for field total.
-
#vehicle ⇒ Object
readonly
Attribute for field vehicle.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
1753 1754 1755 |
# File 'lib/stripe/resources/payment_intent.rb', line 1753 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
The booking number associated with the car rental.
1755 1756 1757 |
# File 'lib/stripe/resources/payment_intent.rb', line 1755 def booking_number @booking_number end |
#carrier_name ⇒ Object (readonly)
The name of the car rental company.
1757 1758 1759 |
# File 'lib/stripe/resources/payment_intent.rb', line 1757 def carrier_name @carrier_name end |
#customer_service_phone_number ⇒ Object (readonly)
The customer service phone number of the car rental company.
1759 1760 1761 |
# File 'lib/stripe/resources/payment_intent.rb', line 1759 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object (readonly)
Number of days the car is being rented.
1761 1762 1763 |
# File 'lib/stripe/resources/payment_intent.rb', line 1761 def days_rented @days_rented end |
#distance ⇒ Object (readonly)
Attribute for field distance
1763 1764 1765 |
# File 'lib/stripe/resources/payment_intent.rb', line 1763 def distance @distance end |
#drivers ⇒ Object (readonly)
The details of the drivers associated with the rental.
1765 1766 1767 |
# File 'lib/stripe/resources/payment_intent.rb', line 1765 def drivers @drivers end |
#drop_off ⇒ Object (readonly)
Attribute for field drop_off
1767 1768 1769 |
# File 'lib/stripe/resources/payment_intent.rb', line 1767 def drop_off @drop_off end |
#insurances ⇒ Object (readonly)
Insurance details for the car rental.
1769 1770 1771 |
# File 'lib/stripe/resources/payment_intent.rb', line 1769 def insurances @insurances end |
#no_show_indicator ⇒ Object (readonly)
Indicates if the customer did not keep nor cancel their booking.
1771 1772 1773 |
# File 'lib/stripe/resources/payment_intent.rb', line 1771 def no_show_indicator @no_show_indicator end |
#pickup ⇒ Object (readonly)
Attribute for field pickup
1773 1774 1775 |
# File 'lib/stripe/resources/payment_intent.rb', line 1773 def pickup @pickup end |
#renter_name ⇒ Object (readonly)
Name of the person renting the vehicle.
1775 1776 1777 |
# File 'lib/stripe/resources/payment_intent.rb', line 1775 def renter_name @renter_name end |
#total ⇒ Object (readonly)
Attribute for field total
1777 1778 1779 |
# File 'lib/stripe/resources/payment_intent.rb', line 1777 def total @total end |
#vehicle ⇒ Object (readonly)
Attribute for field vehicle
1779 1780 1781 |
# File 'lib/stripe/resources/payment_intent.rb', line 1779 def vehicle @vehicle end |
Class Method Details
.field_remappings ⇒ Object
1794 1795 1796 |
# File 'lib/stripe/resources/payment_intent.rb', line 1794 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 |
# File 'lib/stripe/resources/payment_intent.rb', line 1781 def self.inner_class_types @inner_class_types = { affiliate: Affiliate, distance: Distance, drivers: Driver, drop_off: DropOff, insurances: Insurance, pickup: Pickup, total: Total, vehicle: Vehicle, } end |