Class: Stripe::PaymentIntent::PaymentDetails::CarRentalDatum

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Distance, Driver, DropOff, Insurance, Pickup, Total, Vehicle

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#affiliateObject (readonly)

Attribute for field affiliate



1740
1741
1742
# File 'lib/stripe/resources/payment_intent.rb', line 1740

def affiliate
  @affiliate
end

#booking_numberObject (readonly)

The booking number associated with the car rental.



1742
1743
1744
# File 'lib/stripe/resources/payment_intent.rb', line 1742

def booking_number
  @booking_number
end

#carrier_nameObject (readonly)

The name of the car rental company.



1744
1745
1746
# File 'lib/stripe/resources/payment_intent.rb', line 1744

def carrier_name
  @carrier_name
end

#customer_service_phone_numberObject (readonly)

The customer service phone number of the car rental company.



1746
1747
1748
# File 'lib/stripe/resources/payment_intent.rb', line 1746

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject (readonly)

Number of days the car is being rented.



1748
1749
1750
# File 'lib/stripe/resources/payment_intent.rb', line 1748

def days_rented
  @days_rented
end

#distanceObject (readonly)

Attribute for field distance



1750
1751
1752
# File 'lib/stripe/resources/payment_intent.rb', line 1750

def distance
  @distance
end

#driversObject (readonly)

The details of the drivers associated with the rental.



1752
1753
1754
# File 'lib/stripe/resources/payment_intent.rb', line 1752

def drivers
  @drivers
end

#drop_offObject (readonly)

Attribute for field drop_off



1754
1755
1756
# File 'lib/stripe/resources/payment_intent.rb', line 1754

def drop_off
  @drop_off
end

#insurancesObject (readonly)

Insurance details for the car rental.



1756
1757
1758
# File 'lib/stripe/resources/payment_intent.rb', line 1756

def insurances
  @insurances
end

#no_show_indicatorObject (readonly)

Indicates if the customer did not keep nor cancel their booking.



1758
1759
1760
# File 'lib/stripe/resources/payment_intent.rb', line 1758

def no_show_indicator
  @no_show_indicator
end

#pickupObject (readonly)

Attribute for field pickup



1760
1761
1762
# File 'lib/stripe/resources/payment_intent.rb', line 1760

def pickup
  @pickup
end

#renter_nameObject (readonly)

Name of the person renting the vehicle.



1762
1763
1764
# File 'lib/stripe/resources/payment_intent.rb', line 1762

def renter_name
  @renter_name
end

#totalObject (readonly)

Attribute for field total



1764
1765
1766
# File 'lib/stripe/resources/payment_intent.rb', line 1764

def total
  @total
end

#vehicleObject (readonly)

Attribute for field vehicle



1766
1767
1768
# File 'lib/stripe/resources/payment_intent.rb', line 1766

def vehicle
  @vehicle
end

Class Method Details

.field_remappingsObject



1781
1782
1783
# File 'lib/stripe/resources/payment_intent.rb', line 1781

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
# File 'lib/stripe/resources/payment_intent.rb', line 1768

def self.inner_class_types
  @inner_class_types = {
    affiliate: Affiliate,
    distance: Distance,
    drivers: Driver,
    drop_off: DropOff,
    insurances: Insurance,
    pickup: Pickup,
    total: Total,
    vehicle: Vehicle,
  }
end