Class: Stripe::PaymentIntent::PaymentDetails::CarRentalDatum
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::CarRentalDatum
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Distance, Driver, DropOff, Insurance, Pickup, Total, Vehicle
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
The booking number associated with the car rental.
-
#carrier_name ⇒ Object
readonly
The name of the car rental company.
-
#customer_service_phone_number ⇒ Object
readonly
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
readonly
Number of days the car is being rented.
-
#distance ⇒ Object
readonly
Attribute for field distance.
-
#drivers ⇒ Object
readonly
The details of the drivers associated with the rental.
-
#drop_off ⇒ Object
readonly
Attribute for field drop_off.
-
#insurances ⇒ Object
readonly
Insurance details for the car rental.
-
#no_show_indicator ⇒ Object
readonly
Indicates if the customer did not keep nor cancel their booking.
-
#pickup ⇒ Object
readonly
Attribute for field pickup.
-
#renter_name ⇒ Object
readonly
Name of the person renting the vehicle.
-
#total ⇒ Object
readonly
Attribute for field total.
-
#vehicle ⇒ Object
readonly
Attribute for field vehicle.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
1702 1703 1704 |
# File 'lib/stripe/resources/payment_intent.rb', line 1702 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
The booking number associated with the car rental.
1704 1705 1706 |
# File 'lib/stripe/resources/payment_intent.rb', line 1704 def booking_number @booking_number end |
#carrier_name ⇒ Object (readonly)
The name of the car rental company.
1706 1707 1708 |
# File 'lib/stripe/resources/payment_intent.rb', line 1706 def carrier_name @carrier_name end |
#customer_service_phone_number ⇒ Object (readonly)
The customer service phone number of the car rental company.
1708 1709 1710 |
# File 'lib/stripe/resources/payment_intent.rb', line 1708 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object (readonly)
Number of days the car is being rented.
1710 1711 1712 |
# File 'lib/stripe/resources/payment_intent.rb', line 1710 def days_rented @days_rented end |
#distance ⇒ Object (readonly)
Attribute for field distance
1712 1713 1714 |
# File 'lib/stripe/resources/payment_intent.rb', line 1712 def distance @distance end |
#drivers ⇒ Object (readonly)
The details of the drivers associated with the rental.
1714 1715 1716 |
# File 'lib/stripe/resources/payment_intent.rb', line 1714 def drivers @drivers end |
#drop_off ⇒ Object (readonly)
Attribute for field drop_off
1716 1717 1718 |
# File 'lib/stripe/resources/payment_intent.rb', line 1716 def drop_off @drop_off end |
#insurances ⇒ Object (readonly)
Insurance details for the car rental.
1718 1719 1720 |
# File 'lib/stripe/resources/payment_intent.rb', line 1718 def insurances @insurances end |
#no_show_indicator ⇒ Object (readonly)
Indicates if the customer did not keep nor cancel their booking.
1720 1721 1722 |
# File 'lib/stripe/resources/payment_intent.rb', line 1720 def no_show_indicator @no_show_indicator end |
#pickup ⇒ Object (readonly)
Attribute for field pickup
1722 1723 1724 |
# File 'lib/stripe/resources/payment_intent.rb', line 1722 def pickup @pickup end |
#renter_name ⇒ Object (readonly)
Name of the person renting the vehicle.
1724 1725 1726 |
# File 'lib/stripe/resources/payment_intent.rb', line 1724 def renter_name @renter_name end |
#total ⇒ Object (readonly)
Attribute for field total
1726 1727 1728 |
# File 'lib/stripe/resources/payment_intent.rb', line 1726 def total @total end |
#vehicle ⇒ Object (readonly)
Attribute for field vehicle
1728 1729 1730 |
# File 'lib/stripe/resources/payment_intent.rb', line 1728 def vehicle @vehicle end |
Class Method Details
.field_remappings ⇒ Object
1743 1744 1745 |
# File 'lib/stripe/resources/payment_intent.rb', line 1743 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 |
# File 'lib/stripe/resources/payment_intent.rb', line 1730 def self.inner_class_types @inner_class_types = { affiliate: Affiliate, distance: Distance, drivers: Driver, drop_off: DropOff, insurances: Insurance, pickup: Pickup, total: Total, vehicle: Vehicle, } end |