Class: Stripe::PaymentIntent::PaymentDetails::EventDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
readonly
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
readonly
Attribute for field address.
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#company ⇒ Object
readonly
The name of the company.
-
#delivery ⇒ Object
readonly
Attribute for field delivery.
-
#ends_at ⇒ Object
readonly
Event end time.
-
#genre ⇒ Object
readonly
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
readonly
The name of the event.
-
#starts_at ⇒ Object
readonly
Event start time.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#access_controlled_venue ⇒ Object (readonly)
Indicates if the tickets are digitally checked when entering the venue.
2195 2196 2197 |
# File 'lib/stripe/resources/payment_intent.rb', line 2195 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object (readonly)
Attribute for field address
2197 2198 2199 |
# File 'lib/stripe/resources/payment_intent.rb', line 2197 def address @address end |
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
2199 2200 2201 |
# File 'lib/stripe/resources/payment_intent.rb', line 2199 def affiliate @affiliate end |
#company ⇒ Object (readonly)
The name of the company
2201 2202 2203 |
# File 'lib/stripe/resources/payment_intent.rb', line 2201 def company @company end |
#delivery ⇒ Object (readonly)
Attribute for field delivery
2203 2204 2205 |
# File 'lib/stripe/resources/payment_intent.rb', line 2203 def delivery @delivery end |
#ends_at ⇒ Object (readonly)
Event end time. Measured in seconds since the Unix epoch.
2205 2206 2207 |
# File 'lib/stripe/resources/payment_intent.rb', line 2205 def ends_at @ends_at end |
#genre ⇒ Object (readonly)
Type of the event entertainment (concert, sports event etc)
2207 2208 2209 |
# File 'lib/stripe/resources/payment_intent.rb', line 2207 def genre @genre end |
#name ⇒ Object (readonly)
The name of the event.
2209 2210 2211 |
# File 'lib/stripe/resources/payment_intent.rb', line 2209 def name @name end |
#starts_at ⇒ Object (readonly)
Event start time. Measured in seconds since the Unix epoch.
2211 2212 2213 |
# File 'lib/stripe/resources/payment_intent.rb', line 2211 def starts_at @starts_at end |
Class Method Details
.field_remappings ⇒ Object
2217 2218 2219 |
# File 'lib/stripe/resources/payment_intent.rb', line 2217 def self.field_remappings @field_remappings = {} end |