Class: Stripe::PaymentIntent::PaymentDetails::EventDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
readonly
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
readonly
Attribute for field address.
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#company ⇒ Object
readonly
The name of the company.
-
#delivery ⇒ Object
readonly
Attribute for field delivery.
-
#ends_at ⇒ Object
readonly
Event end time.
-
#genre ⇒ Object
readonly
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
readonly
The name of the event.
-
#starts_at ⇒ Object
readonly
Event start time.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#access_controlled_venue ⇒ Object (readonly)
Indicates if the tickets are digitally checked when entering the venue.
1925 1926 1927 |
# File 'lib/stripe/resources/payment_intent.rb', line 1925 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object (readonly)
Attribute for field address
1927 1928 1929 |
# File 'lib/stripe/resources/payment_intent.rb', line 1927 def address @address end |
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
1929 1930 1931 |
# File 'lib/stripe/resources/payment_intent.rb', line 1929 def affiliate @affiliate end |
#company ⇒ Object (readonly)
The name of the company
1931 1932 1933 |
# File 'lib/stripe/resources/payment_intent.rb', line 1931 def company @company end |
#delivery ⇒ Object (readonly)
Attribute for field delivery
1933 1934 1935 |
# File 'lib/stripe/resources/payment_intent.rb', line 1933 def delivery @delivery end |
#ends_at ⇒ Object (readonly)
Event end time. Measured in seconds since the Unix epoch.
1935 1936 1937 |
# File 'lib/stripe/resources/payment_intent.rb', line 1935 def ends_at @ends_at end |
#genre ⇒ Object (readonly)
Type of the event entertainment (concert, sports event etc)
1937 1938 1939 |
# File 'lib/stripe/resources/payment_intent.rb', line 1937 def genre @genre end |
#name ⇒ Object (readonly)
The name of the event.
1939 1940 1941 |
# File 'lib/stripe/resources/payment_intent.rb', line 1939 def name @name end |
#starts_at ⇒ Object (readonly)
Event start time. Measured in seconds since the Unix epoch.
1941 1942 1943 |
# File 'lib/stripe/resources/payment_intent.rb', line 1941 def starts_at @starts_at end |
Class Method Details
.field_remappings ⇒ Object
1947 1948 1949 |
# File 'lib/stripe/resources/payment_intent.rb', line 1947 def self.field_remappings @field_remappings = {} end |