Class: Stripe::PaymentIntent::PaymentDetails::EventDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
readonly
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
readonly
Attribute for field address.
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#company ⇒ Object
readonly
The name of the company.
-
#delivery ⇒ Object
readonly
Attribute for field delivery.
-
#ends_at ⇒ Object
readonly
Event end time.
-
#genre ⇒ Object
readonly
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
readonly
The name of the event.
-
#starts_at ⇒ Object
readonly
Event start time.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#access_controlled_venue ⇒ Object (readonly)
Indicates if the tickets are digitally checked when entering the venue.
2083 2084 2085 |
# File 'lib/stripe/resources/payment_intent.rb', line 2083 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object (readonly)
Attribute for field address
2085 2086 2087 |
# File 'lib/stripe/resources/payment_intent.rb', line 2085 def address @address end |
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
2087 2088 2089 |
# File 'lib/stripe/resources/payment_intent.rb', line 2087 def affiliate @affiliate end |
#company ⇒ Object (readonly)
The name of the company
2089 2090 2091 |
# File 'lib/stripe/resources/payment_intent.rb', line 2089 def company @company end |
#delivery ⇒ Object (readonly)
Attribute for field delivery
2091 2092 2093 |
# File 'lib/stripe/resources/payment_intent.rb', line 2091 def delivery @delivery end |
#ends_at ⇒ Object (readonly)
Event end time. Measured in seconds since the Unix epoch.
2093 2094 2095 |
# File 'lib/stripe/resources/payment_intent.rb', line 2093 def ends_at @ends_at end |
#genre ⇒ Object (readonly)
Type of the event entertainment (concert, sports event etc)
2095 2096 2097 |
# File 'lib/stripe/resources/payment_intent.rb', line 2095 def genre @genre end |
#name ⇒ Object (readonly)
The name of the event.
2097 2098 2099 |
# File 'lib/stripe/resources/payment_intent.rb', line 2097 def name @name end |
#starts_at ⇒ Object (readonly)
Event start time. Measured in seconds since the Unix epoch.
2099 2100 2101 |
# File 'lib/stripe/resources/payment_intent.rb', line 2099 def starts_at @starts_at end |
Class Method Details
.field_remappings ⇒ Object
2105 2106 2107 |
# File 'lib/stripe/resources/payment_intent.rb', line 2105 def self.field_remappings @field_remappings = {} end |