Class: Stripe::PaymentIntent::PaymentDetails::EventDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
readonly
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
readonly
Attribute for field address.
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#company ⇒ Object
readonly
The name of the company.
-
#delivery ⇒ Object
readonly
Attribute for field delivery.
-
#ends_at ⇒ Object
readonly
Event end time.
-
#genre ⇒ Object
readonly
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
readonly
The name of the event.
-
#starts_at ⇒ Object
readonly
Event start time.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#access_controlled_venue ⇒ Object (readonly)
Indicates if the tickets are digitally checked when entering the venue.
2180 2181 2182 |
# File 'lib/stripe/resources/payment_intent.rb', line 2180 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object (readonly)
Attribute for field address
2182 2183 2184 |
# File 'lib/stripe/resources/payment_intent.rb', line 2182 def address @address end |
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
2184 2185 2186 |
# File 'lib/stripe/resources/payment_intent.rb', line 2184 def affiliate @affiliate end |
#company ⇒ Object (readonly)
The name of the company
2186 2187 2188 |
# File 'lib/stripe/resources/payment_intent.rb', line 2186 def company @company end |
#delivery ⇒ Object (readonly)
Attribute for field delivery
2188 2189 2190 |
# File 'lib/stripe/resources/payment_intent.rb', line 2188 def delivery @delivery end |
#ends_at ⇒ Object (readonly)
Event end time. Measured in seconds since the Unix epoch.
2190 2191 2192 |
# File 'lib/stripe/resources/payment_intent.rb', line 2190 def ends_at @ends_at end |
#genre ⇒ Object (readonly)
Type of the event entertainment (concert, sports event etc)
2192 2193 2194 |
# File 'lib/stripe/resources/payment_intent.rb', line 2192 def genre @genre end |
#name ⇒ Object (readonly)
The name of the event.
2194 2195 2196 |
# File 'lib/stripe/resources/payment_intent.rb', line 2194 def name @name end |
#starts_at ⇒ Object (readonly)
Event start time. Measured in seconds since the Unix epoch.
2196 2197 2198 |
# File 'lib/stripe/resources/payment_intent.rb', line 2196 def starts_at @starts_at end |
Class Method Details
.field_remappings ⇒ Object
2202 2203 2204 |
# File 'lib/stripe/resources/payment_intent.rb', line 2202 def self.field_remappings @field_remappings = {} end |