Class: Stripe::PaymentIntent::PaymentDetails::EventDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
readonly
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
readonly
Attribute for field address.
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#company ⇒ Object
readonly
The name of the company.
-
#delivery ⇒ Object
readonly
Attribute for field delivery.
-
#ends_at ⇒ Object
readonly
Event end time.
-
#genre ⇒ Object
readonly
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
readonly
The name of the event.
-
#starts_at ⇒ Object
readonly
Event start time.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#access_controlled_venue ⇒ Object (readonly)
Indicates if the tickets are digitally checked when entering the venue.
1912 1913 1914 |
# File 'lib/stripe/resources/payment_intent.rb', line 1912 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object (readonly)
Attribute for field address
1914 1915 1916 |
# File 'lib/stripe/resources/payment_intent.rb', line 1914 def address @address end |
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
1916 1917 1918 |
# File 'lib/stripe/resources/payment_intent.rb', line 1916 def affiliate @affiliate end |
#company ⇒ Object (readonly)
The name of the company
1918 1919 1920 |
# File 'lib/stripe/resources/payment_intent.rb', line 1918 def company @company end |
#delivery ⇒ Object (readonly)
Attribute for field delivery
1920 1921 1922 |
# File 'lib/stripe/resources/payment_intent.rb', line 1920 def delivery @delivery end |
#ends_at ⇒ Object (readonly)
Event end time. Measured in seconds since the Unix epoch.
1922 1923 1924 |
# File 'lib/stripe/resources/payment_intent.rb', line 1922 def ends_at @ends_at end |
#genre ⇒ Object (readonly)
Type of the event entertainment (concert, sports event etc)
1924 1925 1926 |
# File 'lib/stripe/resources/payment_intent.rb', line 1924 def genre @genre end |
#name ⇒ Object (readonly)
The name of the event.
1926 1927 1928 |
# File 'lib/stripe/resources/payment_intent.rb', line 1926 def name @name end |
#starts_at ⇒ Object (readonly)
Event start time. Measured in seconds since the Unix epoch.
1928 1929 1930 |
# File 'lib/stripe/resources/payment_intent.rb', line 1928 def starts_at @starts_at end |
Class Method Details
.field_remappings ⇒ Object
1934 1935 1936 |
# File 'lib/stripe/resources/payment_intent.rb', line 1934 def self.field_remappings @field_remappings = {} end |