Class: Stripe::PaymentIntent::PaymentDetails::EventDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
readonly
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
readonly
Attribute for field address.
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#company ⇒ Object
readonly
The name of the company.
-
#delivery ⇒ Object
readonly
Attribute for field delivery.
-
#ends_at ⇒ Object
readonly
Event end time.
-
#genre ⇒ Object
readonly
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
readonly
The name of the event.
-
#starts_at ⇒ Object
readonly
Event start time.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#access_controlled_venue ⇒ Object (readonly)
Indicates if the tickets are digitally checked when entering the venue.
1867 1868 1869 |
# File 'lib/stripe/resources/payment_intent.rb', line 1867 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object (readonly)
Attribute for field address
1869 1870 1871 |
# File 'lib/stripe/resources/payment_intent.rb', line 1869 def address @address end |
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
1871 1872 1873 |
# File 'lib/stripe/resources/payment_intent.rb', line 1871 def affiliate @affiliate end |
#company ⇒ Object (readonly)
The name of the company
1873 1874 1875 |
# File 'lib/stripe/resources/payment_intent.rb', line 1873 def company @company end |
#delivery ⇒ Object (readonly)
Attribute for field delivery
1875 1876 1877 |
# File 'lib/stripe/resources/payment_intent.rb', line 1875 def delivery @delivery end |
#ends_at ⇒ Object (readonly)
Event end time. Measured in seconds since the Unix epoch.
1877 1878 1879 |
# File 'lib/stripe/resources/payment_intent.rb', line 1877 def ends_at @ends_at end |
#genre ⇒ Object (readonly)
Type of the event entertainment (concert, sports event etc)
1879 1880 1881 |
# File 'lib/stripe/resources/payment_intent.rb', line 1879 def genre @genre end |
#name ⇒ Object (readonly)
The name of the event.
1881 1882 1883 |
# File 'lib/stripe/resources/payment_intent.rb', line 1881 def name @name end |
#starts_at ⇒ Object (readonly)
Event start time. Measured in seconds since the Unix epoch.
1883 1884 1885 |
# File 'lib/stripe/resources/payment_intent.rb', line 1883 def starts_at @starts_at end |
Class Method Details
.field_remappings ⇒ Object
1889 1890 1891 |
# File 'lib/stripe/resources/payment_intent.rb', line 1889 def self.field_remappings @field_remappings = {} end |