Class: Stripe::PaymentIntent::PaymentDetails::EventDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
readonly
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
readonly
Attribute for field address.
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#company ⇒ Object
readonly
The name of the company.
-
#delivery ⇒ Object
readonly
Attribute for field delivery.
-
#ends_at ⇒ Object
readonly
Event end time.
-
#genre ⇒ Object
readonly
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
readonly
The name of the event.
-
#starts_at ⇒ Object
readonly
Event start time.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#access_controlled_venue ⇒ Object (readonly)
Indicates if the tickets are digitally checked when entering the venue.
1985 1986 1987 |
# File 'lib/stripe/resources/payment_intent.rb', line 1985 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object (readonly)
Attribute for field address
1987 1988 1989 |
# File 'lib/stripe/resources/payment_intent.rb', line 1987 def address @address end |
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
1989 1990 1991 |
# File 'lib/stripe/resources/payment_intent.rb', line 1989 def affiliate @affiliate end |
#company ⇒ Object (readonly)
The name of the company
1991 1992 1993 |
# File 'lib/stripe/resources/payment_intent.rb', line 1991 def company @company end |
#delivery ⇒ Object (readonly)
Attribute for field delivery
1993 1994 1995 |
# File 'lib/stripe/resources/payment_intent.rb', line 1993 def delivery @delivery end |
#ends_at ⇒ Object (readonly)
Event end time. Measured in seconds since the Unix epoch.
1995 1996 1997 |
# File 'lib/stripe/resources/payment_intent.rb', line 1995 def ends_at @ends_at end |
#genre ⇒ Object (readonly)
Type of the event entertainment (concert, sports event etc)
1997 1998 1999 |
# File 'lib/stripe/resources/payment_intent.rb', line 1997 def genre @genre end |
#name ⇒ Object (readonly)
The name of the event.
1999 2000 2001 |
# File 'lib/stripe/resources/payment_intent.rb', line 1999 def name @name end |
#starts_at ⇒ Object (readonly)
Event start time. Measured in seconds since the Unix epoch.
2001 2002 2003 |
# File 'lib/stripe/resources/payment_intent.rb', line 2001 def starts_at @starts_at end |
Class Method Details
.field_remappings ⇒ Object
2007 2008 2009 |
# File 'lib/stripe/resources/payment_intent.rb', line 2007 def self.field_remappings @field_remappings = {} end |