Class: Stripe::PaymentIntent::PaymentDetails::EventDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
readonly
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
readonly
Attribute for field address.
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#company ⇒ Object
readonly
The name of the company.
-
#delivery ⇒ Object
readonly
Attribute for field delivery.
-
#ends_at ⇒ Object
readonly
Event end time.
-
#genre ⇒ Object
readonly
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
readonly
The name of the event.
-
#starts_at ⇒ Object
readonly
Event start time.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#access_controlled_venue ⇒ Object (readonly)
Indicates if the tickets are digitally checked when entering the venue.
1481 1482 1483 |
# File 'lib/stripe/resources/payment_intent.rb', line 1481 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object (readonly)
Attribute for field address
1483 1484 1485 |
# File 'lib/stripe/resources/payment_intent.rb', line 1483 def address @address end |
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
1485 1486 1487 |
# File 'lib/stripe/resources/payment_intent.rb', line 1485 def affiliate @affiliate end |
#company ⇒ Object (readonly)
The name of the company
1487 1488 1489 |
# File 'lib/stripe/resources/payment_intent.rb', line 1487 def company @company end |
#delivery ⇒ Object (readonly)
Attribute for field delivery
1489 1490 1491 |
# File 'lib/stripe/resources/payment_intent.rb', line 1489 def delivery @delivery end |
#ends_at ⇒ Object (readonly)
Event end time. Measured in seconds since the Unix epoch.
1491 1492 1493 |
# File 'lib/stripe/resources/payment_intent.rb', line 1491 def ends_at @ends_at end |
#genre ⇒ Object (readonly)
Type of the event entertainment (concert, sports event etc)
1493 1494 1495 |
# File 'lib/stripe/resources/payment_intent.rb', line 1493 def genre @genre end |
#name ⇒ Object (readonly)
The name of the event.
1495 1496 1497 |
# File 'lib/stripe/resources/payment_intent.rb', line 1495 def name @name end |
#starts_at ⇒ Object (readonly)
Event start time. Measured in seconds since the Unix epoch.
1497 1498 1499 |
# File 'lib/stripe/resources/payment_intent.rb', line 1497 def starts_at @starts_at end |
Class Method Details
.field_remappings ⇒ Object
1503 1504 1505 |
# File 'lib/stripe/resources/payment_intent.rb', line 1503 def self.field_remappings @field_remappings = {} end |