Class: Stripe::PaymentIntent::PaymentDetails::EventDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
readonly
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
readonly
Attribute for field address.
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#company ⇒ Object
readonly
The name of the company.
-
#delivery ⇒ Object
readonly
Attribute for field delivery.
-
#ends_at ⇒ Object
readonly
Event end time.
-
#genre ⇒ Object
readonly
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
readonly
The name of the event.
-
#starts_at ⇒ Object
readonly
Event start time.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#access_controlled_venue ⇒ Object (readonly)
Indicates if the tickets are digitally checked when entering the venue.
1464 1465 1466 |
# File 'lib/stripe/resources/payment_intent.rb', line 1464 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object (readonly)
Attribute for field address
1466 1467 1468 |
# File 'lib/stripe/resources/payment_intent.rb', line 1466 def address @address end |
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
1468 1469 1470 |
# File 'lib/stripe/resources/payment_intent.rb', line 1468 def affiliate @affiliate end |
#company ⇒ Object (readonly)
The name of the company
1470 1471 1472 |
# File 'lib/stripe/resources/payment_intent.rb', line 1470 def company @company end |
#delivery ⇒ Object (readonly)
Attribute for field delivery
1472 1473 1474 |
# File 'lib/stripe/resources/payment_intent.rb', line 1472 def delivery @delivery end |
#ends_at ⇒ Object (readonly)
Event end time. Measured in seconds since the Unix epoch.
1474 1475 1476 |
# File 'lib/stripe/resources/payment_intent.rb', line 1474 def ends_at @ends_at end |
#genre ⇒ Object (readonly)
Type of the event entertainment (concert, sports event etc)
1476 1477 1478 |
# File 'lib/stripe/resources/payment_intent.rb', line 1476 def genre @genre end |
#name ⇒ Object (readonly)
The name of the event.
1478 1479 1480 |
# File 'lib/stripe/resources/payment_intent.rb', line 1478 def name @name end |
#starts_at ⇒ Object (readonly)
Event start time. Measured in seconds since the Unix epoch.
1480 1481 1482 |
# File 'lib/stripe/resources/payment_intent.rb', line 1480 def starts_at @starts_at end |
Class Method Details
.field_remappings ⇒ Object
1486 1487 1488 |
# File 'lib/stripe/resources/payment_intent.rb', line 1486 def self.field_remappings @field_remappings = {} end |