Class: Stripe::PaymentIntent::PaymentDetails::EventDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
readonly
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
readonly
Attribute for field address.
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#company ⇒ Object
readonly
The name of the company.
-
#delivery ⇒ Object
readonly
Attribute for field delivery.
-
#ends_at ⇒ Object
readonly
Event end time.
-
#genre ⇒ Object
readonly
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
readonly
The name of the event.
-
#starts_at ⇒ Object
readonly
Event start time.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#access_controlled_venue ⇒ Object (readonly)
Indicates if the tickets are digitally checked when entering the venue.
864 865 866 |
# File 'lib/stripe/resources/payment_intent.rb', line 864 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object (readonly)
Attribute for field address
866 867 868 |
# File 'lib/stripe/resources/payment_intent.rb', line 866 def address @address end |
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
868 869 870 |
# File 'lib/stripe/resources/payment_intent.rb', line 868 def affiliate @affiliate end |
#company ⇒ Object (readonly)
The name of the company
870 871 872 |
# File 'lib/stripe/resources/payment_intent.rb', line 870 def company @company end |
#delivery ⇒ Object (readonly)
Attribute for field delivery
872 873 874 |
# File 'lib/stripe/resources/payment_intent.rb', line 872 def delivery @delivery end |
#ends_at ⇒ Object (readonly)
Event end time. Measured in seconds since the Unix epoch.
874 875 876 |
# File 'lib/stripe/resources/payment_intent.rb', line 874 def ends_at @ends_at end |
#genre ⇒ Object (readonly)
Type of the event entertainment (concert, sports event etc)
876 877 878 |
# File 'lib/stripe/resources/payment_intent.rb', line 876 def genre @genre end |
#name ⇒ Object (readonly)
The name of the event.
878 879 880 |
# File 'lib/stripe/resources/payment_intent.rb', line 878 def name @name end |
#starts_at ⇒ Object (readonly)
Event start time. Measured in seconds since the Unix epoch.
880 881 882 |
# File 'lib/stripe/resources/payment_intent.rb', line 880 def starts_at @starts_at end |