Class: Stripe::PaymentIntent::PaymentDetails::EventDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
readonly
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
readonly
Attribute for field address.
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#company ⇒ Object
readonly
The name of the company.
-
#delivery ⇒ Object
readonly
Attribute for field delivery.
-
#ends_at ⇒ Object
readonly
Event end time.
-
#genre ⇒ Object
readonly
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
readonly
The name of the event.
-
#starts_at ⇒ Object
readonly
Event start time.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#access_controlled_venue ⇒ Object (readonly)
Indicates if the tickets are digitally checked when entering the venue.
845 846 847 |
# File 'lib/stripe/resources/payment_intent.rb', line 845 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object (readonly)
Attribute for field address
847 848 849 |
# File 'lib/stripe/resources/payment_intent.rb', line 847 def address @address end |
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
849 850 851 |
# File 'lib/stripe/resources/payment_intent.rb', line 849 def affiliate @affiliate end |
#company ⇒ Object (readonly)
The name of the company
851 852 853 |
# File 'lib/stripe/resources/payment_intent.rb', line 851 def company @company end |
#delivery ⇒ Object (readonly)
Attribute for field delivery
853 854 855 |
# File 'lib/stripe/resources/payment_intent.rb', line 853 def delivery @delivery end |
#ends_at ⇒ Object (readonly)
Event end time. Measured in seconds since the Unix epoch.
855 856 857 |
# File 'lib/stripe/resources/payment_intent.rb', line 855 def ends_at @ends_at end |
#genre ⇒ Object (readonly)
Type of the event entertainment (concert, sports event etc)
857 858 859 |
# File 'lib/stripe/resources/payment_intent.rb', line 857 def genre @genre end |
#name ⇒ Object (readonly)
The name of the event.
859 860 861 |
# File 'lib/stripe/resources/payment_intent.rb', line 859 def name @name end |
#starts_at ⇒ Object (readonly)
Event start time. Measured in seconds since the Unix epoch.
861 862 863 |
# File 'lib/stripe/resources/payment_intent.rb', line 861 def starts_at @starts_at end |