Class: Stripe::PaymentIntent::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#email ⇒ Object
readonly
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
readonly
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
readonly
The phone number of the recipient the ticket is delivered to.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#email ⇒ Object (readonly)
The email of the recipient the ticket is delivered to.
833 834 835 |
# File 'lib/stripe/resources/payment_intent.rb', line 833 def email @email end |
#name ⇒ Object (readonly)
The name of the recipient the ticket is delivered to.
835 836 837 |
# File 'lib/stripe/resources/payment_intent.rb', line 835 def name @name end |
#phone ⇒ Object (readonly)
The phone number of the recipient the ticket is delivered to.
837 838 839 |
# File 'lib/stripe/resources/payment_intent.rb', line 837 def phone @phone end |