Class: Stripe::PaymentIntent::PaymentDetails::FlightDatum
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::FlightDatum
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Insurance, Passenger, Segment, Total
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
The booking number associated with the flight reservation.
-
#computerized_reservation_system ⇒ Object
readonly
The computerized reservation system used to make the reservation and purchase the ticket.
-
#endorsements_and_restrictions ⇒ Object
readonly
Ticket restrictions.
-
#insurances ⇒ Object
readonly
Insurance details for the flight.
-
#passengers ⇒ Object
readonly
The list of passengers for this flight.
-
#segments ⇒ Object
readonly
The list of flight segments for this reservation.
-
#ticket_electronically_issued_indicator ⇒ Object
readonly
Electronic ticket indicator.
-
#total ⇒ Object
readonly
Attribute for field total.
-
#transaction_type ⇒ Object
readonly
Type of flight transaction.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
2501 2502 2503 |
# File 'lib/stripe/resources/payment_intent.rb', line 2501 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
The booking number associated with the flight reservation.
2503 2504 2505 |
# File 'lib/stripe/resources/payment_intent.rb', line 2503 def booking_number @booking_number end |
#computerized_reservation_system ⇒ Object (readonly)
The computerized reservation system used to make the reservation and purchase the ticket.
2505 2506 2507 |
# File 'lib/stripe/resources/payment_intent.rb', line 2505 def computerized_reservation_system @computerized_reservation_system end |
#endorsements_and_restrictions ⇒ Object (readonly)
Ticket restrictions.
2507 2508 2509 |
# File 'lib/stripe/resources/payment_intent.rb', line 2507 def endorsements_and_restrictions @endorsements_and_restrictions end |
#insurances ⇒ Object (readonly)
Insurance details for the flight.
2509 2510 2511 |
# File 'lib/stripe/resources/payment_intent.rb', line 2509 def insurances @insurances end |
#passengers ⇒ Object (readonly)
The list of passengers for this flight.
2511 2512 2513 |
# File 'lib/stripe/resources/payment_intent.rb', line 2511 def passengers @passengers end |
#segments ⇒ Object (readonly)
The list of flight segments for this reservation.
2513 2514 2515 |
# File 'lib/stripe/resources/payment_intent.rb', line 2513 def segments @segments end |
#ticket_electronically_issued_indicator ⇒ Object (readonly)
Electronic ticket indicator.
2515 2516 2517 |
# File 'lib/stripe/resources/payment_intent.rb', line 2515 def ticket_electronically_issued_indicator @ticket_electronically_issued_indicator end |
#total ⇒ Object (readonly)
Attribute for field total
2517 2518 2519 |
# File 'lib/stripe/resources/payment_intent.rb', line 2517 def total @total end |
#transaction_type ⇒ Object (readonly)
Type of flight transaction.
2519 2520 2521 |
# File 'lib/stripe/resources/payment_intent.rb', line 2519 def transaction_type @transaction_type end |
Class Method Details
.field_remappings ⇒ Object
2531 2532 2533 |
# File 'lib/stripe/resources/payment_intent.rb', line 2531 def self.field_remappings @field_remappings = {} end |