Class: Stripe::PaymentIntent::PaymentDetails::FlightDatum
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::FlightDatum
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Insurance, Passenger, Segment, Total
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
The booking number associated with the flight reservation.
-
#computerized_reservation_system ⇒ Object
readonly
The computerized reservation system used to make the reservation and purchase the ticket.
-
#endorsements_and_restrictions ⇒ Object
readonly
Ticket restrictions.
-
#insurances ⇒ Object
readonly
Insurance details for the flight.
-
#passengers ⇒ Object
readonly
The list of passengers for this flight.
-
#segments ⇒ Object
readonly
The list of flight segments for this reservation.
-
#ticket_electronically_issued_indicator ⇒ Object
readonly
Electronic ticket indicator.
-
#total ⇒ Object
readonly
Attribute for field total.
-
#transaction_type ⇒ Object
readonly
Type of flight transaction.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
2088 2089 2090 |
# File 'lib/stripe/resources/payment_intent.rb', line 2088 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
The booking number associated with the flight reservation.
2090 2091 2092 |
# File 'lib/stripe/resources/payment_intent.rb', line 2090 def booking_number @booking_number end |
#computerized_reservation_system ⇒ Object (readonly)
The computerized reservation system used to make the reservation and purchase the ticket.
2092 2093 2094 |
# File 'lib/stripe/resources/payment_intent.rb', line 2092 def computerized_reservation_system @computerized_reservation_system end |
#endorsements_and_restrictions ⇒ Object (readonly)
Ticket restrictions.
2094 2095 2096 |
# File 'lib/stripe/resources/payment_intent.rb', line 2094 def endorsements_and_restrictions @endorsements_and_restrictions end |
#insurances ⇒ Object (readonly)
Insurance details for the flight.
2096 2097 2098 |
# File 'lib/stripe/resources/payment_intent.rb', line 2096 def insurances @insurances end |
#passengers ⇒ Object (readonly)
The list of passengers for this flight.
2098 2099 2100 |
# File 'lib/stripe/resources/payment_intent.rb', line 2098 def passengers @passengers end |
#segments ⇒ Object (readonly)
The list of flight segments for this reservation.
2100 2101 2102 |
# File 'lib/stripe/resources/payment_intent.rb', line 2100 def segments @segments end |
#ticket_electronically_issued_indicator ⇒ Object (readonly)
Electronic ticket indicator.
2102 2103 2104 |
# File 'lib/stripe/resources/payment_intent.rb', line 2102 def ticket_electronically_issued_indicator @ticket_electronically_issued_indicator end |
#total ⇒ Object (readonly)
Attribute for field total
2104 2105 2106 |
# File 'lib/stripe/resources/payment_intent.rb', line 2104 def total @total end |
#transaction_type ⇒ Object (readonly)
Type of flight transaction.
2106 2107 2108 |
# File 'lib/stripe/resources/payment_intent.rb', line 2106 def transaction_type @transaction_type end |
Class Method Details
.field_remappings ⇒ Object
2118 2119 2120 |
# File 'lib/stripe/resources/payment_intent.rb', line 2118 def self.field_remappings @field_remappings = {} end |