Class: Stripe::PaymentIntent::PaymentDetails::LodgingDatum
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::LodgingDatum
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Accommodation, Affiliate, Guest, Host, Insurance, Total
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#accommodation ⇒ Object
readonly
Attribute for field accommodation.
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
Booking confirmation number for the lodging.
-
#checkin_at ⇒ Object
readonly
Check-in date.
-
#checkout_at ⇒ Object
readonly
Check-out date.
-
#customer_service_phone_number ⇒ Object
readonly
Customer service phone number for the lodging company.
-
#fire_safety_act_compliance_indicator ⇒ Object
readonly
Whether the lodging is compliant with any hotel fire safety regulations.
-
#guests ⇒ Object
readonly
List of guests for the lodging.
-
#host ⇒ Object
readonly
Attribute for field host.
-
#insurances ⇒ Object
readonly
List of insurances for the lodging.
-
#no_show_indicator ⇒ Object
readonly
Whether the renter is a no-show.
-
#renter_id_number ⇒ Object
readonly
Renter ID number for the lodging.
-
#renter_name ⇒ Object
readonly
Renter name for the lodging.
-
#total ⇒ Object
readonly
Attribute for field total.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#accommodation ⇒ Object (readonly)
Attribute for field accommodation
2401 2402 2403 |
# File 'lib/stripe/resources/payment_intent.rb', line 2401 def accommodation @accommodation end |
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
2403 2404 2405 |
# File 'lib/stripe/resources/payment_intent.rb', line 2403 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
Booking confirmation number for the lodging.
2405 2406 2407 |
# File 'lib/stripe/resources/payment_intent.rb', line 2405 def booking_number @booking_number end |
#checkin_at ⇒ Object (readonly)
Check-in date.
2407 2408 2409 |
# File 'lib/stripe/resources/payment_intent.rb', line 2407 def checkin_at @checkin_at end |
#checkout_at ⇒ Object (readonly)
Check-out date.
2409 2410 2411 |
# File 'lib/stripe/resources/payment_intent.rb', line 2409 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object (readonly)
Customer service phone number for the lodging company.
2411 2412 2413 |
# File 'lib/stripe/resources/payment_intent.rb', line 2411 def customer_service_phone_number @customer_service_phone_number end |
#fire_safety_act_compliance_indicator ⇒ Object (readonly)
Whether the lodging is compliant with any hotel fire safety regulations.
2413 2414 2415 |
# File 'lib/stripe/resources/payment_intent.rb', line 2413 def fire_safety_act_compliance_indicator @fire_safety_act_compliance_indicator end |
#guests ⇒ Object (readonly)
List of guests for the lodging.
2415 2416 2417 |
# File 'lib/stripe/resources/payment_intent.rb', line 2415 def guests @guests end |
#host ⇒ Object (readonly)
Attribute for field host
2417 2418 2419 |
# File 'lib/stripe/resources/payment_intent.rb', line 2417 def host @host end |
#insurances ⇒ Object (readonly)
List of insurances for the lodging.
2419 2420 2421 |
# File 'lib/stripe/resources/payment_intent.rb', line 2419 def insurances @insurances end |
#no_show_indicator ⇒ Object (readonly)
Whether the renter is a no-show.
2421 2422 2423 |
# File 'lib/stripe/resources/payment_intent.rb', line 2421 def no_show_indicator @no_show_indicator end |
#renter_id_number ⇒ Object (readonly)
Renter ID number for the lodging.
2423 2424 2425 |
# File 'lib/stripe/resources/payment_intent.rb', line 2423 def renter_id_number @renter_id_number end |
#renter_name ⇒ Object (readonly)
Renter name for the lodging.
2425 2426 2427 |
# File 'lib/stripe/resources/payment_intent.rb', line 2425 def renter_name @renter_name end |
#total ⇒ Object (readonly)
Attribute for field total
2427 2428 2429 |
# File 'lib/stripe/resources/payment_intent.rb', line 2427 def total @total end |
Class Method Details
.field_remappings ⇒ Object
2440 2441 2442 |
# File 'lib/stripe/resources/payment_intent.rb', line 2440 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2429 2430 2431 2432 2433 2434 2435 2436 2437 2438 |
# File 'lib/stripe/resources/payment_intent.rb', line 2429 def self.inner_class_types @inner_class_types = { accommodation: Accommodation, affiliate: Affiliate, guests: Guest, host: Host, insurances: Insurance, total: Total, } end |