Class: Stripe::PaymentIntent::PaymentDetails::LodgingDatum
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::LodgingDatum
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Accommodation, Affiliate, Guest, Host, Insurance, Total
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#accommodation ⇒ Object
readonly
Attribute for field accommodation.
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
Booking confirmation number for the lodging.
-
#checkin_at ⇒ Object
readonly
Check-in date.
-
#checkout_at ⇒ Object
readonly
Check-out date.
-
#customer_service_phone_number ⇒ Object
readonly
Customer service phone number for the lodging company.
-
#fire_safety_act_compliance_indicator ⇒ Object
readonly
Whether the lodging is compliant with any hotel fire safety regulations.
-
#guests ⇒ Object
readonly
List of guests for the lodging.
-
#host ⇒ Object
readonly
Attribute for field host.
-
#insurances ⇒ Object
readonly
List of insurances for the lodging.
-
#no_show_indicator ⇒ Object
readonly
Whether the renter is a no-show.
-
#renter_id_number ⇒ Object
readonly
Renter ID number for the lodging.
-
#renter_name ⇒ Object
readonly
Renter name for the lodging.
-
#total ⇒ Object
readonly
Attribute for field total.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#accommodation ⇒ Object (readonly)
Attribute for field accommodation
2624 2625 2626 |
# File 'lib/stripe/resources/payment_intent.rb', line 2624 def accommodation @accommodation end |
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
2626 2627 2628 |
# File 'lib/stripe/resources/payment_intent.rb', line 2626 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
Booking confirmation number for the lodging.
2628 2629 2630 |
# File 'lib/stripe/resources/payment_intent.rb', line 2628 def booking_number @booking_number end |
#checkin_at ⇒ Object (readonly)
Check-in date.
2630 2631 2632 |
# File 'lib/stripe/resources/payment_intent.rb', line 2630 def checkin_at @checkin_at end |
#checkout_at ⇒ Object (readonly)
Check-out date.
2632 2633 2634 |
# File 'lib/stripe/resources/payment_intent.rb', line 2632 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object (readonly)
Customer service phone number for the lodging company.
2634 2635 2636 |
# File 'lib/stripe/resources/payment_intent.rb', line 2634 def customer_service_phone_number @customer_service_phone_number end |
#fire_safety_act_compliance_indicator ⇒ Object (readonly)
Whether the lodging is compliant with any hotel fire safety regulations.
2636 2637 2638 |
# File 'lib/stripe/resources/payment_intent.rb', line 2636 def fire_safety_act_compliance_indicator @fire_safety_act_compliance_indicator end |
#guests ⇒ Object (readonly)
List of guests for the lodging.
2638 2639 2640 |
# File 'lib/stripe/resources/payment_intent.rb', line 2638 def guests @guests end |
#host ⇒ Object (readonly)
Attribute for field host
2640 2641 2642 |
# File 'lib/stripe/resources/payment_intent.rb', line 2640 def host @host end |
#insurances ⇒ Object (readonly)
List of insurances for the lodging.
2642 2643 2644 |
# File 'lib/stripe/resources/payment_intent.rb', line 2642 def insurances @insurances end |
#no_show_indicator ⇒ Object (readonly)
Whether the renter is a no-show.
2644 2645 2646 |
# File 'lib/stripe/resources/payment_intent.rb', line 2644 def no_show_indicator @no_show_indicator end |
#renter_id_number ⇒ Object (readonly)
Renter ID number for the lodging.
2646 2647 2648 |
# File 'lib/stripe/resources/payment_intent.rb', line 2646 def renter_id_number @renter_id_number end |
#renter_name ⇒ Object (readonly)
Renter name for the lodging.
2648 2649 2650 |
# File 'lib/stripe/resources/payment_intent.rb', line 2648 def renter_name @renter_name end |
#total ⇒ Object (readonly)
Attribute for field total
2650 2651 2652 |
# File 'lib/stripe/resources/payment_intent.rb', line 2650 def total @total end |
Class Method Details
.field_remappings ⇒ Object
2663 2664 2665 |
# File 'lib/stripe/resources/payment_intent.rb', line 2663 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2652 2653 2654 2655 2656 2657 2658 2659 2660 2661 |
# File 'lib/stripe/resources/payment_intent.rb', line 2652 def self.inner_class_types @inner_class_types = { accommodation: Accommodation, affiliate: Affiliate, guests: Guest, host: Host, insurances: Insurance, total: Total, } end |