Class: Stripe::PaymentIntent::PaymentDetails::LodgingDatum
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::LodgingDatum
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Accommodation, Affiliate, Guest, Host, Insurance, Total
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#accommodation ⇒ Object
readonly
Attribute for field accommodation.
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
Booking confirmation number for the lodging.
-
#checkin_at ⇒ Object
readonly
Check-in date.
-
#checkout_at ⇒ Object
readonly
Check-out date.
-
#customer_service_phone_number ⇒ Object
readonly
Customer service phone number for the lodging company.
-
#fire_safety_act_compliance_indicator ⇒ Object
readonly
Whether the lodging is compliant with any hotel fire safety regulations.
-
#guests ⇒ Object
readonly
List of guests for the lodging.
-
#host ⇒ Object
readonly
Attribute for field host.
-
#insurances ⇒ Object
readonly
List of insurances for the lodging.
-
#no_show_indicator ⇒ Object
readonly
Whether the renter is a no-show.
-
#renter_id_number ⇒ Object
readonly
Renter ID number for the lodging.
-
#renter_name ⇒ Object
readonly
Renter name for the lodging.
-
#total ⇒ Object
readonly
Attribute for field total.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#accommodation ⇒ Object (readonly)
Attribute for field accommodation
2388 2389 2390 |
# File 'lib/stripe/resources/payment_intent.rb', line 2388 def accommodation @accommodation end |
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
2390 2391 2392 |
# File 'lib/stripe/resources/payment_intent.rb', line 2390 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
Booking confirmation number for the lodging.
2392 2393 2394 |
# File 'lib/stripe/resources/payment_intent.rb', line 2392 def booking_number @booking_number end |
#checkin_at ⇒ Object (readonly)
Check-in date.
2394 2395 2396 |
# File 'lib/stripe/resources/payment_intent.rb', line 2394 def checkin_at @checkin_at end |
#checkout_at ⇒ Object (readonly)
Check-out date.
2396 2397 2398 |
# File 'lib/stripe/resources/payment_intent.rb', line 2396 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object (readonly)
Customer service phone number for the lodging company.
2398 2399 2400 |
# File 'lib/stripe/resources/payment_intent.rb', line 2398 def customer_service_phone_number @customer_service_phone_number end |
#fire_safety_act_compliance_indicator ⇒ Object (readonly)
Whether the lodging is compliant with any hotel fire safety regulations.
2400 2401 2402 |
# File 'lib/stripe/resources/payment_intent.rb', line 2400 def fire_safety_act_compliance_indicator @fire_safety_act_compliance_indicator end |
#guests ⇒ Object (readonly)
List of guests for the lodging.
2402 2403 2404 |
# File 'lib/stripe/resources/payment_intent.rb', line 2402 def guests @guests end |
#host ⇒ Object (readonly)
Attribute for field host
2404 2405 2406 |
# File 'lib/stripe/resources/payment_intent.rb', line 2404 def host @host end |
#insurances ⇒ Object (readonly)
List of insurances for the lodging.
2406 2407 2408 |
# File 'lib/stripe/resources/payment_intent.rb', line 2406 def insurances @insurances end |
#no_show_indicator ⇒ Object (readonly)
Whether the renter is a no-show.
2408 2409 2410 |
# File 'lib/stripe/resources/payment_intent.rb', line 2408 def no_show_indicator @no_show_indicator end |
#renter_id_number ⇒ Object (readonly)
Renter ID number for the lodging.
2410 2411 2412 |
# File 'lib/stripe/resources/payment_intent.rb', line 2410 def renter_id_number @renter_id_number end |
#renter_name ⇒ Object (readonly)
Renter name for the lodging.
2412 2413 2414 |
# File 'lib/stripe/resources/payment_intent.rb', line 2412 def renter_name @renter_name end |
#total ⇒ Object (readonly)
Attribute for field total
2414 2415 2416 |
# File 'lib/stripe/resources/payment_intent.rb', line 2414 def total @total end |
Class Method Details
.field_remappings ⇒ Object
2427 2428 2429 |
# File 'lib/stripe/resources/payment_intent.rb', line 2427 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 |
# File 'lib/stripe/resources/payment_intent.rb', line 2416 def self.inner_class_types @inner_class_types = { accommodation: Accommodation, affiliate: Affiliate, guests: Guest, host: Host, insurances: Insurance, total: Total, } end |