Class: Stripe::PaymentIntent::PaymentDetails::LodgingDatum
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::LodgingDatum
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Accommodation, Affiliate, Guest, Host, Insurance, Total
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#accommodation ⇒ Object
readonly
Attribute for field accommodation.
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
Booking confirmation number for the lodging.
-
#checkin_at ⇒ Object
readonly
Check-in date.
-
#checkout_at ⇒ Object
readonly
Check-out date.
-
#customer_service_phone_number ⇒ Object
readonly
Customer service phone number for the lodging company.
-
#fire_safety_act_compliance_indicator ⇒ Object
readonly
Whether the lodging is compliant with any hotel fire safety regulations.
-
#guests ⇒ Object
readonly
List of guests for the lodging.
-
#host ⇒ Object
readonly
Attribute for field host.
-
#insurances ⇒ Object
readonly
List of insurances for the lodging.
-
#no_show_indicator ⇒ Object
readonly
Whether the renter is a no-show.
-
#renter_id_number ⇒ Object
readonly
Renter ID number for the lodging.
-
#renter_name ⇒ Object
readonly
Renter name for the lodging.
-
#total ⇒ Object
readonly
Attribute for field total.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#accommodation ⇒ Object (readonly)
Attribute for field accommodation
2609 2610 2611 |
# File 'lib/stripe/resources/payment_intent.rb', line 2609 def accommodation @accommodation end |
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
2611 2612 2613 |
# File 'lib/stripe/resources/payment_intent.rb', line 2611 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
Booking confirmation number for the lodging.
2613 2614 2615 |
# File 'lib/stripe/resources/payment_intent.rb', line 2613 def booking_number @booking_number end |
#checkin_at ⇒ Object (readonly)
Check-in date.
2615 2616 2617 |
# File 'lib/stripe/resources/payment_intent.rb', line 2615 def checkin_at @checkin_at end |
#checkout_at ⇒ Object (readonly)
Check-out date.
2617 2618 2619 |
# File 'lib/stripe/resources/payment_intent.rb', line 2617 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object (readonly)
Customer service phone number for the lodging company.
2619 2620 2621 |
# File 'lib/stripe/resources/payment_intent.rb', line 2619 def customer_service_phone_number @customer_service_phone_number end |
#fire_safety_act_compliance_indicator ⇒ Object (readonly)
Whether the lodging is compliant with any hotel fire safety regulations.
2621 2622 2623 |
# File 'lib/stripe/resources/payment_intent.rb', line 2621 def fire_safety_act_compliance_indicator @fire_safety_act_compliance_indicator end |
#guests ⇒ Object (readonly)
List of guests for the lodging.
2623 2624 2625 |
# File 'lib/stripe/resources/payment_intent.rb', line 2623 def guests @guests end |
#host ⇒ Object (readonly)
Attribute for field host
2625 2626 2627 |
# File 'lib/stripe/resources/payment_intent.rb', line 2625 def host @host end |
#insurances ⇒ Object (readonly)
List of insurances for the lodging.
2627 2628 2629 |
# File 'lib/stripe/resources/payment_intent.rb', line 2627 def insurances @insurances end |
#no_show_indicator ⇒ Object (readonly)
Whether the renter is a no-show.
2629 2630 2631 |
# File 'lib/stripe/resources/payment_intent.rb', line 2629 def no_show_indicator @no_show_indicator end |
#renter_id_number ⇒ Object (readonly)
Renter ID number for the lodging.
2631 2632 2633 |
# File 'lib/stripe/resources/payment_intent.rb', line 2631 def renter_id_number @renter_id_number end |
#renter_name ⇒ Object (readonly)
Renter name for the lodging.
2633 2634 2635 |
# File 'lib/stripe/resources/payment_intent.rb', line 2633 def renter_name @renter_name end |
#total ⇒ Object (readonly)
Attribute for field total
2635 2636 2637 |
# File 'lib/stripe/resources/payment_intent.rb', line 2635 def total @total end |
Class Method Details
.field_remappings ⇒ Object
2648 2649 2650 |
# File 'lib/stripe/resources/payment_intent.rb', line 2648 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 |
# File 'lib/stripe/resources/payment_intent.rb', line 2637 def self.inner_class_types @inner_class_types = { accommodation: Accommodation, affiliate: Affiliate, guests: Guest, host: Host, insurances: Insurance, total: Total, } end |