Class: Stripe::PaymentIntent::PaymentDetails::LodgingDatum
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::LodgingDatum
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Accommodation, Affiliate, Guest, Host, Insurance, Total
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#accommodation ⇒ Object
readonly
Attribute for field accommodation.
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
Booking confirmation number for the lodging.
-
#checkin_at ⇒ Object
readonly
Check-in date.
-
#checkout_at ⇒ Object
readonly
Check-out date.
-
#customer_service_phone_number ⇒ Object
readonly
Customer service phone number for the lodging company.
-
#fire_safety_act_compliance_indicator ⇒ Object
readonly
Whether the lodging is compliant with any hotel fire safety regulations.
-
#guests ⇒ Object
readonly
List of guests for the lodging.
-
#host ⇒ Object
readonly
Attribute for field host.
-
#insurances ⇒ Object
readonly
List of insurances for the lodging.
-
#no_show_indicator ⇒ Object
readonly
Whether the renter is a no-show.
-
#renter_id_number ⇒ Object
readonly
Renter ID number for the lodging.
-
#renter_name ⇒ Object
readonly
Renter name for the lodging.
-
#total ⇒ Object
readonly
Attribute for field total.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#accommodation ⇒ Object (readonly)
Attribute for field accommodation
2522 2523 2524 |
# File 'lib/stripe/resources/payment_intent.rb', line 2522 def accommodation @accommodation end |
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
2524 2525 2526 |
# File 'lib/stripe/resources/payment_intent.rb', line 2524 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
Booking confirmation number for the lodging.
2526 2527 2528 |
# File 'lib/stripe/resources/payment_intent.rb', line 2526 def booking_number @booking_number end |
#checkin_at ⇒ Object (readonly)
Check-in date.
2528 2529 2530 |
# File 'lib/stripe/resources/payment_intent.rb', line 2528 def checkin_at @checkin_at end |
#checkout_at ⇒ Object (readonly)
Check-out date.
2530 2531 2532 |
# File 'lib/stripe/resources/payment_intent.rb', line 2530 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object (readonly)
Customer service phone number for the lodging company.
2532 2533 2534 |
# File 'lib/stripe/resources/payment_intent.rb', line 2532 def customer_service_phone_number @customer_service_phone_number end |
#fire_safety_act_compliance_indicator ⇒ Object (readonly)
Whether the lodging is compliant with any hotel fire safety regulations.
2534 2535 2536 |
# File 'lib/stripe/resources/payment_intent.rb', line 2534 def fire_safety_act_compliance_indicator @fire_safety_act_compliance_indicator end |
#guests ⇒ Object (readonly)
List of guests for the lodging.
2536 2537 2538 |
# File 'lib/stripe/resources/payment_intent.rb', line 2536 def guests @guests end |
#host ⇒ Object (readonly)
Attribute for field host
2538 2539 2540 |
# File 'lib/stripe/resources/payment_intent.rb', line 2538 def host @host end |
#insurances ⇒ Object (readonly)
List of insurances for the lodging.
2540 2541 2542 |
# File 'lib/stripe/resources/payment_intent.rb', line 2540 def insurances @insurances end |
#no_show_indicator ⇒ Object (readonly)
Whether the renter is a no-show.
2542 2543 2544 |
# File 'lib/stripe/resources/payment_intent.rb', line 2542 def no_show_indicator @no_show_indicator end |
#renter_id_number ⇒ Object (readonly)
Renter ID number for the lodging.
2544 2545 2546 |
# File 'lib/stripe/resources/payment_intent.rb', line 2544 def renter_id_number @renter_id_number end |
#renter_name ⇒ Object (readonly)
Renter name for the lodging.
2546 2547 2548 |
# File 'lib/stripe/resources/payment_intent.rb', line 2546 def renter_name @renter_name end |
#total ⇒ Object (readonly)
Attribute for field total
2548 2549 2550 |
# File 'lib/stripe/resources/payment_intent.rb', line 2548 def total @total end |
Class Method Details
.field_remappings ⇒ Object
2561 2562 2563 |
# File 'lib/stripe/resources/payment_intent.rb', line 2561 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 |
# File 'lib/stripe/resources/payment_intent.rb', line 2550 def self.inner_class_types @inner_class_types = { accommodation: Accommodation, affiliate: Affiliate, guests: Guest, host: Host, insurances: Insurance, total: Total, } end |