Class: Stripe::PaymentIntent::PaymentDetails::LodgingDatum
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::LodgingDatum
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Accommodation, Affiliate, Guest, Host, Insurance, Total
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#accommodation ⇒ Object
readonly
Attribute for field accommodation.
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
Booking confirmation number for the lodging.
-
#checkin_at ⇒ Object
readonly
Check-in date.
-
#checkout_at ⇒ Object
readonly
Check-out date.
-
#customer_service_phone_number ⇒ Object
readonly
Customer service phone number for the lodging company.
-
#fire_safety_act_compliance_indicator ⇒ Object
readonly
Whether the lodging is compliant with any hotel fire safety regulations.
-
#guests ⇒ Object
readonly
List of guests for the lodging.
-
#host ⇒ Object
readonly
Attribute for field host.
-
#insurances ⇒ Object
readonly
List of insurances for the lodging.
-
#no_show_indicator ⇒ Object
readonly
Whether the renter is a no-show.
-
#renter_id_number ⇒ Object
readonly
Renter ID number for the lodging.
-
#renter_name ⇒ Object
readonly
Renter name for the lodging.
-
#total ⇒ Object
readonly
Attribute for field total.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#accommodation ⇒ Object (readonly)
Attribute for field accommodation
2343 2344 2345 |
# File 'lib/stripe/resources/payment_intent.rb', line 2343 def accommodation @accommodation end |
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
2345 2346 2347 |
# File 'lib/stripe/resources/payment_intent.rb', line 2345 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
Booking confirmation number for the lodging.
2347 2348 2349 |
# File 'lib/stripe/resources/payment_intent.rb', line 2347 def booking_number @booking_number end |
#checkin_at ⇒ Object (readonly)
Check-in date.
2349 2350 2351 |
# File 'lib/stripe/resources/payment_intent.rb', line 2349 def checkin_at @checkin_at end |
#checkout_at ⇒ Object (readonly)
Check-out date.
2351 2352 2353 |
# File 'lib/stripe/resources/payment_intent.rb', line 2351 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object (readonly)
Customer service phone number for the lodging company.
2353 2354 2355 |
# File 'lib/stripe/resources/payment_intent.rb', line 2353 def customer_service_phone_number @customer_service_phone_number end |
#fire_safety_act_compliance_indicator ⇒ Object (readonly)
Whether the lodging is compliant with any hotel fire safety regulations.
2355 2356 2357 |
# File 'lib/stripe/resources/payment_intent.rb', line 2355 def fire_safety_act_compliance_indicator @fire_safety_act_compliance_indicator end |
#guests ⇒ Object (readonly)
List of guests for the lodging.
2357 2358 2359 |
# File 'lib/stripe/resources/payment_intent.rb', line 2357 def guests @guests end |
#host ⇒ Object (readonly)
Attribute for field host
2359 2360 2361 |
# File 'lib/stripe/resources/payment_intent.rb', line 2359 def host @host end |
#insurances ⇒ Object (readonly)
List of insurances for the lodging.
2361 2362 2363 |
# File 'lib/stripe/resources/payment_intent.rb', line 2361 def insurances @insurances end |
#no_show_indicator ⇒ Object (readonly)
Whether the renter is a no-show.
2363 2364 2365 |
# File 'lib/stripe/resources/payment_intent.rb', line 2363 def no_show_indicator @no_show_indicator end |
#renter_id_number ⇒ Object (readonly)
Renter ID number for the lodging.
2365 2366 2367 |
# File 'lib/stripe/resources/payment_intent.rb', line 2365 def renter_id_number @renter_id_number end |
#renter_name ⇒ Object (readonly)
Renter name for the lodging.
2367 2368 2369 |
# File 'lib/stripe/resources/payment_intent.rb', line 2367 def renter_name @renter_name end |
#total ⇒ Object (readonly)
Attribute for field total
2369 2370 2371 |
# File 'lib/stripe/resources/payment_intent.rb', line 2369 def total @total end |
Class Method Details
.field_remappings ⇒ Object
2382 2383 2384 |
# File 'lib/stripe/resources/payment_intent.rb', line 2382 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 |
# File 'lib/stripe/resources/payment_intent.rb', line 2371 def self.inner_class_types @inner_class_types = { accommodation: Accommodation, affiliate: Affiliate, guests: Guest, host: Host, insurances: Insurance, total: Total, } end |