Class: Stripe::PaymentIntent::PaymentDetails::LodgingDatum
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::LodgingDatum
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Accommodation, Affiliate, Guest, Host, Insurance, Total
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#accommodation ⇒ Object
readonly
Attribute for field accommodation.
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
Booking confirmation number for the lodging.
-
#checkin_at ⇒ Object
readonly
Check-in date.
-
#checkout_at ⇒ Object
readonly
Check-out date.
-
#customer_service_phone_number ⇒ Object
readonly
Customer service phone number for the lodging company.
-
#fire_safety_act_compliance_indicator ⇒ Object
readonly
Whether the lodging is compliant with any hotel fire safety regulations.
-
#guests ⇒ Object
readonly
List of guests for the lodging.
-
#host ⇒ Object
readonly
Attribute for field host.
-
#insurances ⇒ Object
readonly
List of insurances for the lodging.
-
#no_show_indicator ⇒ Object
readonly
Whether the renter is a no-show.
-
#renter_id_number ⇒ Object
readonly
Renter ID number for the lodging.
-
#renter_name ⇒ Object
readonly
Renter name for the lodging.
-
#total ⇒ Object
readonly
Attribute for field total.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#accommodation ⇒ Object (readonly)
Attribute for field accommodation
2330 2331 2332 |
# File 'lib/stripe/resources/payment_intent.rb', line 2330 def accommodation @accommodation end |
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
2332 2333 2334 |
# File 'lib/stripe/resources/payment_intent.rb', line 2332 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
Booking confirmation number for the lodging.
2334 2335 2336 |
# File 'lib/stripe/resources/payment_intent.rb', line 2334 def booking_number @booking_number end |
#checkin_at ⇒ Object (readonly)
Check-in date.
2336 2337 2338 |
# File 'lib/stripe/resources/payment_intent.rb', line 2336 def checkin_at @checkin_at end |
#checkout_at ⇒ Object (readonly)
Check-out date.
2338 2339 2340 |
# File 'lib/stripe/resources/payment_intent.rb', line 2338 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object (readonly)
Customer service phone number for the lodging company.
2340 2341 2342 |
# File 'lib/stripe/resources/payment_intent.rb', line 2340 def customer_service_phone_number @customer_service_phone_number end |
#fire_safety_act_compliance_indicator ⇒ Object (readonly)
Whether the lodging is compliant with any hotel fire safety regulations.
2342 2343 2344 |
# File 'lib/stripe/resources/payment_intent.rb', line 2342 def fire_safety_act_compliance_indicator @fire_safety_act_compliance_indicator end |
#guests ⇒ Object (readonly)
List of guests for the lodging.
2344 2345 2346 |
# File 'lib/stripe/resources/payment_intent.rb', line 2344 def guests @guests end |
#host ⇒ Object (readonly)
Attribute for field host
2346 2347 2348 |
# File 'lib/stripe/resources/payment_intent.rb', line 2346 def host @host end |
#insurances ⇒ Object (readonly)
List of insurances for the lodging.
2348 2349 2350 |
# File 'lib/stripe/resources/payment_intent.rb', line 2348 def insurances @insurances end |
#no_show_indicator ⇒ Object (readonly)
Whether the renter is a no-show.
2350 2351 2352 |
# File 'lib/stripe/resources/payment_intent.rb', line 2350 def no_show_indicator @no_show_indicator end |
#renter_id_number ⇒ Object (readonly)
Renter ID number for the lodging.
2352 2353 2354 |
# File 'lib/stripe/resources/payment_intent.rb', line 2352 def renter_id_number @renter_id_number end |
#renter_name ⇒ Object (readonly)
Renter name for the lodging.
2354 2355 2356 |
# File 'lib/stripe/resources/payment_intent.rb', line 2354 def renter_name @renter_name end |
#total ⇒ Object (readonly)
Attribute for field total
2356 2357 2358 |
# File 'lib/stripe/resources/payment_intent.rb', line 2356 def total @total end |
Class Method Details
.field_remappings ⇒ Object
2369 2370 2371 |
# File 'lib/stripe/resources/payment_intent.rb', line 2369 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 |
# File 'lib/stripe/resources/payment_intent.rb', line 2358 def self.inner_class_types @inner_class_types = { accommodation: Accommodation, affiliate: Affiliate, guests: Guest, host: Host, insurances: Insurance, total: Total, } end |