Class: Stripe::PaymentIntent::PaymentDetails::LodgingDatum
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::LodgingDatum
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Accommodation, Affiliate, Guest, Host, Insurance, Total
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#accommodation ⇒ Object
readonly
Attribute for field accommodation.
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#booking_number ⇒ Object
readonly
Booking confirmation number for the lodging.
-
#checkin_at ⇒ Object
readonly
Check-in date.
-
#checkout_at ⇒ Object
readonly
Check-out date.
-
#customer_service_phone_number ⇒ Object
readonly
Customer service phone number for the lodging company.
-
#fire_safety_act_compliance_indicator ⇒ Object
readonly
Whether the lodging is compliant with any hotel fire safety regulations.
-
#guests ⇒ Object
readonly
List of guests for the lodging.
-
#host ⇒ Object
readonly
Attribute for field host.
-
#insurances ⇒ Object
readonly
List of insurances for the lodging.
-
#no_show_indicator ⇒ Object
readonly
Whether the renter is a no-show.
-
#renter_id_number ⇒ Object
readonly
Renter ID number for the lodging.
-
#renter_name ⇒ Object
readonly
Renter name for the lodging.
-
#total ⇒ Object
readonly
Attribute for field total.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#accommodation ⇒ Object (readonly)
Attribute for field accommodation
2292 2293 2294 |
# File 'lib/stripe/resources/payment_intent.rb', line 2292 def accommodation @accommodation end |
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
2294 2295 2296 |
# File 'lib/stripe/resources/payment_intent.rb', line 2294 def affiliate @affiliate end |
#booking_number ⇒ Object (readonly)
Booking confirmation number for the lodging.
2296 2297 2298 |
# File 'lib/stripe/resources/payment_intent.rb', line 2296 def booking_number @booking_number end |
#checkin_at ⇒ Object (readonly)
Check-in date.
2298 2299 2300 |
# File 'lib/stripe/resources/payment_intent.rb', line 2298 def checkin_at @checkin_at end |
#checkout_at ⇒ Object (readonly)
Check-out date.
2300 2301 2302 |
# File 'lib/stripe/resources/payment_intent.rb', line 2300 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object (readonly)
Customer service phone number for the lodging company.
2302 2303 2304 |
# File 'lib/stripe/resources/payment_intent.rb', line 2302 def customer_service_phone_number @customer_service_phone_number end |
#fire_safety_act_compliance_indicator ⇒ Object (readonly)
Whether the lodging is compliant with any hotel fire safety regulations.
2304 2305 2306 |
# File 'lib/stripe/resources/payment_intent.rb', line 2304 def fire_safety_act_compliance_indicator @fire_safety_act_compliance_indicator end |
#guests ⇒ Object (readonly)
List of guests for the lodging.
2306 2307 2308 |
# File 'lib/stripe/resources/payment_intent.rb', line 2306 def guests @guests end |
#host ⇒ Object (readonly)
Attribute for field host
2308 2309 2310 |
# File 'lib/stripe/resources/payment_intent.rb', line 2308 def host @host end |
#insurances ⇒ Object (readonly)
List of insurances for the lodging.
2310 2311 2312 |
# File 'lib/stripe/resources/payment_intent.rb', line 2310 def insurances @insurances end |
#no_show_indicator ⇒ Object (readonly)
Whether the renter is a no-show.
2312 2313 2314 |
# File 'lib/stripe/resources/payment_intent.rb', line 2312 def no_show_indicator @no_show_indicator end |
#renter_id_number ⇒ Object (readonly)
Renter ID number for the lodging.
2314 2315 2316 |
# File 'lib/stripe/resources/payment_intent.rb', line 2314 def renter_id_number @renter_id_number end |
#renter_name ⇒ Object (readonly)
Renter name for the lodging.
2316 2317 2318 |
# File 'lib/stripe/resources/payment_intent.rb', line 2316 def renter_name @renter_name end |
#total ⇒ Object (readonly)
Attribute for field total
2318 2319 2320 |
# File 'lib/stripe/resources/payment_intent.rb', line 2318 def total @total end |
Class Method Details
.field_remappings ⇒ Object
2331 2332 2333 |
# File 'lib/stripe/resources/payment_intent.rb', line 2331 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 |
# File 'lib/stripe/resources/payment_intent.rb', line 2320 def self.inner_class_types @inner_class_types = { accommodation: Accommodation, affiliate: Affiliate, guests: Guest, host: Host, insurances: Insurance, total: Total, } end |