Class: Stripe::PaymentIntent::PaymentDetails::MoneyServices::AccountFunding

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: BeneficiaryDetails, SenderDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#beneficiary_accountObject (readonly)

ID of the Account representing the beneficiary in this account funding transaction.



2812
2813
2814
# File 'lib/stripe/resources/payment_intent.rb', line 2812

def 
  @beneficiary_account
end

#beneficiary_detailsObject (readonly)

Attribute for field beneficiary_details



2814
2815
2816
# File 'lib/stripe/resources/payment_intent.rb', line 2814

def beneficiary_details
  @beneficiary_details
end

#sender_accountObject (readonly)

ID of the Account representing the sender in this account funding transaction.



2816
2817
2818
# File 'lib/stripe/resources/payment_intent.rb', line 2816

def 
  @sender_account
end

#sender_detailsObject (readonly)

Attribute for field sender_details



2818
2819
2820
# File 'lib/stripe/resources/payment_intent.rb', line 2818

def sender_details
  @sender_details
end

Class Method Details

.field_remappingsObject



2827
2828
2829
# File 'lib/stripe/resources/payment_intent.rb', line 2827

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2820
2821
2822
2823
2824
2825
# File 'lib/stripe/resources/payment_intent.rb', line 2820

def self.inner_class_types
  @inner_class_types = {
    beneficiary_details: BeneficiaryDetails,
    sender_details: SenderDetails,
  }
end