Class: Stripe::PaymentIntent::PaymentDetails::Subscription
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::Subscription
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, BillingInterval
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#auto_renewal ⇒ Object
readonly
Info whether the subscription will be auto renewed upon expiry.
-
#billing_interval ⇒ Object
readonly
Attribute for field billing_interval.
-
#ends_at ⇒ Object
readonly
Subscription end time.
-
#name ⇒ Object
readonly
Name of the product on subscription.
-
#starts_at ⇒ Object
readonly
Subscription start time.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
2461 2462 2463 |
# File 'lib/stripe/resources/payment_intent.rb', line 2461 def affiliate @affiliate end |
#auto_renewal ⇒ Object (readonly)
Info whether the subscription will be auto renewed upon expiry.
2463 2464 2465 |
# File 'lib/stripe/resources/payment_intent.rb', line 2463 def auto_renewal @auto_renewal end |
#billing_interval ⇒ Object (readonly)
Attribute for field billing_interval
2465 2466 2467 |
# File 'lib/stripe/resources/payment_intent.rb', line 2465 def billing_interval @billing_interval end |
#ends_at ⇒ Object (readonly)
Subscription end time. Measured in seconds since the Unix epoch.
2467 2468 2469 |
# File 'lib/stripe/resources/payment_intent.rb', line 2467 def ends_at @ends_at end |
#name ⇒ Object (readonly)
Name of the product on subscription. e.g. Apple Music Subscription.
2469 2470 2471 |
# File 'lib/stripe/resources/payment_intent.rb', line 2469 def name @name end |
#starts_at ⇒ Object (readonly)
Subscription start time. Measured in seconds since the Unix epoch.
2471 2472 2473 |
# File 'lib/stripe/resources/payment_intent.rb', line 2471 def starts_at @starts_at end |
Class Method Details
.field_remappings ⇒ Object
2477 2478 2479 |
# File 'lib/stripe/resources/payment_intent.rb', line 2477 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2473 2474 2475 |
# File 'lib/stripe/resources/payment_intent.rb', line 2473 def self.inner_class_types @inner_class_types = { affiliate: Affiliate, billing_interval: BillingInterval } end |