Class: Stripe::PaymentIntent::PaymentDetails::Subscription
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::Subscription
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, BillingInterval
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#auto_renewal ⇒ Object
readonly
Info whether the subscription will be auto renewed upon expiry.
-
#billing_interval ⇒ Object
readonly
Attribute for field billing_interval.
-
#ends_at ⇒ Object
readonly
Subscription end time.
-
#name ⇒ Object
readonly
Name of the product on subscription.
-
#starts_at ⇒ Object
readonly
Subscription start time.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
1520 1521 1522 |
# File 'lib/stripe/resources/payment_intent.rb', line 1520 def affiliate @affiliate end |
#auto_renewal ⇒ Object (readonly)
Info whether the subscription will be auto renewed upon expiry.
1522 1523 1524 |
# File 'lib/stripe/resources/payment_intent.rb', line 1522 def auto_renewal @auto_renewal end |
#billing_interval ⇒ Object (readonly)
Attribute for field billing_interval
1524 1525 1526 |
# File 'lib/stripe/resources/payment_intent.rb', line 1524 def billing_interval @billing_interval end |
#ends_at ⇒ Object (readonly)
Subscription end time. Measured in seconds since the Unix epoch.
1526 1527 1528 |
# File 'lib/stripe/resources/payment_intent.rb', line 1526 def ends_at @ends_at end |
#name ⇒ Object (readonly)
Name of the product on subscription. e.g. Apple Music Subscription.
1528 1529 1530 |
# File 'lib/stripe/resources/payment_intent.rb', line 1528 def name @name end |
#starts_at ⇒ Object (readonly)
Subscription start time. Measured in seconds since the Unix epoch.
1530 1531 1532 |
# File 'lib/stripe/resources/payment_intent.rb', line 1530 def starts_at @starts_at end |
Class Method Details
.field_remappings ⇒ Object
1536 1537 1538 |
# File 'lib/stripe/resources/payment_intent.rb', line 1536 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1532 1533 1534 |
# File 'lib/stripe/resources/payment_intent.rb', line 1532 def self.inner_class_types @inner_class_types = { affiliate: Affiliate, billing_interval: BillingInterval } end |