Class: Stripe::PaymentIntent::PaymentDetails::Subscription
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::Subscription
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, BillingInterval
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#auto_renewal ⇒ Object
readonly
Info whether the subscription will be auto renewed upon expiry.
-
#billing_interval ⇒ Object
readonly
Attribute for field billing_interval.
-
#ends_at ⇒ Object
readonly
Subscription end time.
-
#name ⇒ Object
readonly
Name of the product on subscription.
-
#starts_at ⇒ Object
readonly
Subscription start time.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
896 897 898 |
# File 'lib/stripe/resources/payment_intent.rb', line 896 def affiliate @affiliate end |
#auto_renewal ⇒ Object (readonly)
Info whether the subscription will be auto renewed upon expiry.
898 899 900 |
# File 'lib/stripe/resources/payment_intent.rb', line 898 def auto_renewal @auto_renewal end |
#billing_interval ⇒ Object (readonly)
Attribute for field billing_interval
900 901 902 |
# File 'lib/stripe/resources/payment_intent.rb', line 900 def billing_interval @billing_interval end |
#ends_at ⇒ Object (readonly)
Subscription end time. Measured in seconds since the Unix epoch.
902 903 904 |
# File 'lib/stripe/resources/payment_intent.rb', line 902 def ends_at @ends_at end |
#name ⇒ Object (readonly)
Name of the product on subscription. e.g. Apple Music Subscription.
904 905 906 |
# File 'lib/stripe/resources/payment_intent.rb', line 904 def name @name end |
#starts_at ⇒ Object (readonly)
Subscription start time. Measured in seconds since the Unix epoch.
906 907 908 |
# File 'lib/stripe/resources/payment_intent.rb', line 906 def starts_at @starts_at end |