Class: Stripe::PaymentIntent::PaymentDetails::Subscription
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::Subscription
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, BillingInterval
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
readonly
Attribute for field affiliate.
-
#auto_renewal ⇒ Object
readonly
Info whether the subscription will be auto renewed upon expiry.
-
#billing_interval ⇒ Object
readonly
Attribute for field billing_interval.
-
#ends_at ⇒ Object
readonly
Subscription end time.
-
#name ⇒ Object
readonly
Name of the product on subscription.
-
#starts_at ⇒ Object
readonly
Subscription start time.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affiliate ⇒ Object (readonly)
Attribute for field affiliate
877 878 879 |
# File 'lib/stripe/resources/payment_intent.rb', line 877 def affiliate @affiliate end |
#auto_renewal ⇒ Object (readonly)
Info whether the subscription will be auto renewed upon expiry.
879 880 881 |
# File 'lib/stripe/resources/payment_intent.rb', line 879 def auto_renewal @auto_renewal end |
#billing_interval ⇒ Object (readonly)
Attribute for field billing_interval
881 882 883 |
# File 'lib/stripe/resources/payment_intent.rb', line 881 def billing_interval @billing_interval end |
#ends_at ⇒ Object (readonly)
Subscription end time. Measured in seconds since the Unix epoch.
883 884 885 |
# File 'lib/stripe/resources/payment_intent.rb', line 883 def ends_at @ends_at end |
#name ⇒ Object (readonly)
Name of the product on subscription. e.g. Apple Music Subscription.
885 886 887 |
# File 'lib/stripe/resources/payment_intent.rb', line 885 def name @name end |
#starts_at ⇒ Object (readonly)
Subscription start time. Measured in seconds since the Unix epoch.
887 888 889 |
# File 'lib/stripe/resources/payment_intent.rb', line 887 def starts_at @starts_at end |