Class: Stripe::PaymentIntent::PaymentDetails::Subscription::BillingInterval
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentDetails::Subscription::BillingInterval
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#count ⇒ Object
readonly
The number of intervals, as an whole number greater than 0.
-
#interval ⇒ Object
readonly
Specifies a type of interval unit.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#count ⇒ Object (readonly)
The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.
872 873 874 |
# File 'lib/stripe/resources/payment_intent.rb', line 872 def count @count end |
#interval ⇒ Object (readonly)
Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.
874 875 876 |
# File 'lib/stripe/resources/payment_intent.rb', line 874 def interval @interval end |