Class: Stripe::PaymentIntent::PaymentMethodOptions::AcssDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: MandateOptions

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#mandate_optionsObject (readonly)

Attribute for field mandate_options



2567
2568
2569
# File 'lib/stripe/resources/payment_intent.rb', line 2567

def mandate_options
  @mandate_options
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.



2575
2576
2577
# File 'lib/stripe/resources/payment_intent.rb', line 2575

def setup_future_usage
  @setup_future_usage
end

#target_dateObject (readonly)

Controls when Stripe will attempt to debit the funds from the customer's account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.



2577
2578
2579
# File 'lib/stripe/resources/payment_intent.rb', line 2577

def target_date
  @target_date
end

#verification_methodObject (readonly)

Bank account verification method. The default value is automatic.



2579
2580
2581
# File 'lib/stripe/resources/payment_intent.rb', line 2579

def verification_method
  @verification_method
end

Class Method Details

.field_remappingsObject



2585
2586
2587
# File 'lib/stripe/resources/payment_intent.rb', line 2585

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2581
2582
2583
# File 'lib/stripe/resources/payment_intent.rb', line 2581

def self.inner_class_types
  @inner_class_types = { mandate_options: MandateOptions }
end