Class: Stripe::PaymentIntent::PaymentMethodOptions::AcssDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: MandateOptions

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#mandate_optionsObject (readonly)

Attribute for field mandate_options



2554
2555
2556
# File 'lib/stripe/resources/payment_intent.rb', line 2554

def mandate_options
  @mandate_options
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).



2562
2563
2564
# File 'lib/stripe/resources/payment_intent.rb', line 2562

def setup_future_usage
  @setup_future_usage
end

#target_dateObject (readonly)

Controls when Stripe will attempt to debit the funds from the customer’s account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.



2564
2565
2566
# File 'lib/stripe/resources/payment_intent.rb', line 2564

def target_date
  @target_date
end

#verification_methodObject (readonly)

Bank account verification method. The default value is ‘automatic`.



2566
2567
2568
# File 'lib/stripe/resources/payment_intent.rb', line 2566

def verification_method
  @verification_method
end

Class Method Details

.field_remappingsObject



2572
2573
2574
# File 'lib/stripe/resources/payment_intent.rb', line 2572

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2568
2569
2570
# File 'lib/stripe/resources/payment_intent.rb', line 2568

def self.inner_class_types
  @inner_class_types = { mandate_options: MandateOptions }
end