Class: Stripe::PaymentIntent::PaymentMethodOptions::Affirm
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Affirm
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
readonly
Controls when the funds will be captured from the customer's account.
-
#preferred_locale ⇒ Object
readonly
Preferred language of the Affirm authorization page that the customer is redirected to.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#capture_method ⇒ Object (readonly)
Controls when the funds will be captured from the customer's account.
2592 2593 2594 |
# File 'lib/stripe/resources/payment_intent.rb', line 2592 def capture_method @capture_method end |
#preferred_locale ⇒ Object (readonly)
Preferred language of the Affirm authorization page that the customer is redirected to.
2594 2595 2596 |
# File 'lib/stripe/resources/payment_intent.rb', line 2594 def preferred_locale @preferred_locale end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
2602 2603 2604 |
# File 'lib/stripe/resources/payment_intent.rb', line 2602 def setup_future_usage @setup_future_usage end |
Class Method Details
.field_remappings ⇒ Object
2608 2609 2610 |
# File 'lib/stripe/resources/payment_intent.rb', line 2608 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2604 2605 2606 |
# File 'lib/stripe/resources/payment_intent.rb', line 2604 def self.inner_class_types @inner_class_types = {} end |