Class: Stripe::PaymentIntent::PaymentMethodOptions::AfterpayClearpay

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#capture_methodObject (readonly)

Controls when the funds will be captured from the customer’s account.



3136
3137
3138
# File 'lib/stripe/resources/payment_intent.rb', line 3136

def capture_method
  @capture_method
end

#referenceObject (readonly)

An internal identifier or reference that this payment corresponds to. You must limit the identifier to 128 characters, and it can only contain letters, numbers, underscores, backslashes, and dashes. This field differs from the statement descriptor and item name.



3139
3140
3141
# File 'lib/stripe/resources/payment_intent.rb', line 3139

def reference
  @reference
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).



3147
3148
3149
# File 'lib/stripe/resources/payment_intent.rb', line 3147

def setup_future_usage
  @setup_future_usage
end

Class Method Details

.field_remappingsObject



3153
3154
3155
# File 'lib/stripe/resources/payment_intent.rb', line 3153

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3149
3150
3151
# File 'lib/stripe/resources/payment_intent.rb', line 3149

def self.inner_class_types
  @inner_class_types = {}
end