Class: Stripe::PaymentIntent::PaymentMethodOptions::AfterpayClearpay
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::AfterpayClearpay
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
readonly
Controls when the funds will be captured from the customer’s account.
-
#reference ⇒ Object
readonly
An internal identifier or reference that this payment corresponds to.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#capture_method ⇒ Object (readonly)
Controls when the funds will be captured from the customer’s account.
2680 2681 2682 |
# File 'lib/stripe/resources/payment_intent.rb', line 2680 def capture_method @capture_method end |
#reference ⇒ Object (readonly)
An internal identifier or reference that this payment corresponds to. You must limit the identifier to 128 characters, and it can only contain letters, numbers, underscores, backslashes, and dashes. This field differs from the statement descriptor and item name.
2683 2684 2685 |
# File 'lib/stripe/resources/payment_intent.rb', line 2683 def reference @reference end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
2691 2692 2693 |
# File 'lib/stripe/resources/payment_intent.rb', line 2691 def setup_future_usage @setup_future_usage end |
Class Method Details
.field_remappings ⇒ Object
2697 2698 2699 |
# File 'lib/stripe/resources/payment_intent.rb', line 2697 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2693 2694 2695 |
# File 'lib/stripe/resources/payment_intent.rb', line 2693 def self.inner_class_types @inner_class_types = {} end |