Class: Stripe::PaymentIntent::PaymentMethodOptions::Bancontact
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Bancontact
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#preferred_language ⇒ Object
readonly
Preferred language of the Bancontact authorization page that the customer is redirected to.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#preferred_language ⇒ Object (readonly)
Preferred language of the Bancontact authorization page that the customer is redirected to.
2748 2749 2750 |
# File 'lib/stripe/resources/payment_intent.rb', line 2748 def preferred_language @preferred_language end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
2756 2757 2758 |
# File 'lib/stripe/resources/payment_intent.rb', line 2756 def setup_future_usage @setup_future_usage end |
Class Method Details
.field_remappings ⇒ Object
2762 2763 2764 |
# File 'lib/stripe/resources/payment_intent.rb', line 2762 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2758 2759 2760 |
# File 'lib/stripe/resources/payment_intent.rb', line 2758 def self.inner_class_types @inner_class_types = {} end |