Class: Stripe::PaymentIntent::PaymentMethodOptions::Card
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: CaptureDelay, Installments, MandateOptions, StatementDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#capture_by ⇒ Object
readonly
Controls when funds are captured from the customer's account when
capture_methodisautomatic_delayed. -
#capture_delay ⇒ Object
readonly
Attribute for field capture_delay.
-
#capture_method ⇒ Object
readonly
Controls when the funds will be captured from the customer's account.
-
#installments ⇒ Object
readonly
Installment details for this payment.
-
#mandate_options ⇒ Object
readonly
Configuration options for setting up an eMandate for cards issued in India.
-
#network ⇒ Object
readonly
Selected network to process this payment intent on.
-
#request_decremental_authorization ⇒ Object
readonly
Request ability to decrement the authorization for this PaymentIntent.
-
#request_extended_authorization ⇒ Object
readonly
Request ability to capture beyond the standard authorization validity window for this PaymentIntent.
-
#request_incremental_authorization ⇒ Object
readonly
Request ability to increment the authorization for this PaymentIntent.
-
#request_multicapture ⇒ Object
readonly
Request ability to make multiple captures for this PaymentIntent.
-
#request_overcapture ⇒ Object
readonly
Request ability to overcapture for this PaymentIntent.
-
#request_partial_authorization ⇒ Object
readonly
Request partial authorization on this PaymentIntent.
-
#request_reauthorization ⇒ Object
readonly
Request ability to reauthorize for this PaymentIntent.
-
#request_three_d_secure ⇒ Object
readonly
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements.
-
#require_cvc_recollection ⇒ Object
readonly
When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent's payment method.
-
#statement_descriptor_suffix_kana ⇒ Object
readonly
Provides information about a card payment that customers see on their statements.
-
#statement_descriptor_suffix_kanji ⇒ Object
readonly
Provides information about a card payment that customers see on their statements.
-
#statement_details ⇒ Object
readonly
Attribute for field statement_details.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#capture_by ⇒ Object (readonly)
Controls when funds are captured from the customer's account when capture_method is automatic_delayed.
If omitted, funds are captured before the authorization expires.
3594 3595 3596 |
# File 'lib/stripe/resources/payment_intent.rb', line 3594 def capture_by @capture_by end |
#capture_delay ⇒ Object (readonly)
Attribute for field capture_delay
3596 3597 3598 |
# File 'lib/stripe/resources/payment_intent.rb', line 3596 def capture_delay @capture_delay end |
#capture_method ⇒ Object (readonly)
Controls when the funds will be captured from the customer's account.
3598 3599 3600 |
# File 'lib/stripe/resources/payment_intent.rb', line 3598 def capture_method @capture_method end |
#installments ⇒ Object (readonly)
Installment details for this payment.
For more information, see the installments integration guide.
3602 3603 3604 |
# File 'lib/stripe/resources/payment_intent.rb', line 3602 def installments @installments end |
#mandate_options ⇒ Object (readonly)
Configuration options for setting up an eMandate for cards issued in India.
3604 3605 3606 |
# File 'lib/stripe/resources/payment_intent.rb', line 3604 def @mandate_options end |
#network ⇒ Object (readonly)
Selected network to process this payment intent on. Depends on the available networks of the card attached to the payment intent. Can be only set confirm-time.
3606 3607 3608 |
# File 'lib/stripe/resources/payment_intent.rb', line 3606 def network @network end |
#request_decremental_authorization ⇒ Object (readonly)
Request ability to decrement the authorization for this PaymentIntent.
3608 3609 3610 |
# File 'lib/stripe/resources/payment_intent.rb', line 3608 def @request_decremental_authorization end |
#request_extended_authorization ⇒ Object (readonly)
Request ability to capture beyond the standard authorization validity window for this PaymentIntent.
3610 3611 3612 |
# File 'lib/stripe/resources/payment_intent.rb', line 3610 def @request_extended_authorization end |
#request_incremental_authorization ⇒ Object (readonly)
Request ability to increment the authorization for this PaymentIntent.
3612 3613 3614 |
# File 'lib/stripe/resources/payment_intent.rb', line 3612 def @request_incremental_authorization end |
#request_multicapture ⇒ Object (readonly)
Request ability to make multiple captures for this PaymentIntent.
3614 3615 3616 |
# File 'lib/stripe/resources/payment_intent.rb', line 3614 def request_multicapture @request_multicapture end |
#request_overcapture ⇒ Object (readonly)
Request ability to overcapture for this PaymentIntent.
3616 3617 3618 |
# File 'lib/stripe/resources/payment_intent.rb', line 3616 def request_overcapture @request_overcapture end |
#request_partial_authorization ⇒ Object (readonly)
Request partial authorization on this PaymentIntent.
3618 3619 3620 |
# File 'lib/stripe/resources/payment_intent.rb', line 3618 def @request_partial_authorization end |
#request_reauthorization ⇒ Object (readonly)
Request ability to reauthorize for this PaymentIntent.
3620 3621 3622 |
# File 'lib/stripe/resources/payment_intent.rb', line 3620 def @request_reauthorization end |
#request_three_d_secure ⇒ Object (readonly)
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements. However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to automatic. Read our guide on manually requesting 3D Secure for more information on how this configuration interacts with Radar and our SCA Engine.
3622 3623 3624 |
# File 'lib/stripe/resources/payment_intent.rb', line 3622 def request_three_d_secure @request_three_d_secure end |
#require_cvc_recollection ⇒ Object (readonly)
When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).
3624 3625 3626 |
# File 'lib/stripe/resources/payment_intent.rb', line 3624 def require_cvc_recollection @require_cvc_recollection end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
3632 3633 3634 |
# File 'lib/stripe/resources/payment_intent.rb', line 3632 def setup_future_usage @setup_future_usage end |
#statement_descriptor_suffix_kana ⇒ Object (readonly)
Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.
3634 3635 3636 |
# File 'lib/stripe/resources/payment_intent.rb', line 3634 def statement_descriptor_suffix_kana @statement_descriptor_suffix_kana end |
#statement_descriptor_suffix_kanji ⇒ Object (readonly)
Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.
3636 3637 3638 |
# File 'lib/stripe/resources/payment_intent.rb', line 3636 def statement_descriptor_suffix_kanji @statement_descriptor_suffix_kanji end |
#statement_details ⇒ Object (readonly)
Attribute for field statement_details
3638 3639 3640 |
# File 'lib/stripe/resources/payment_intent.rb', line 3638 def statement_details @statement_details end |
Class Method Details
.field_remappings ⇒ Object
3649 3650 3651 |
# File 'lib/stripe/resources/payment_intent.rb', line 3649 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3640 3641 3642 3643 3644 3645 3646 3647 |
# File 'lib/stripe/resources/payment_intent.rb', line 3640 def self.inner_class_types @inner_class_types = { capture_delay: CaptureDelay, installments: Installments, mandate_options: MandateOptions, statement_details: StatementDetails, } end |