Class: Stripe::PaymentIntent::PaymentMethodOptions::Card
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Installments, MandateOptions, StatementDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
readonly
Controls when the funds will be captured from the customer’s account.
-
#installments ⇒ Object
readonly
Installment details for this payment.
-
#mandate_options ⇒ Object
readonly
Configuration options for setting up an eMandate for cards issued in India.
-
#network ⇒ Object
readonly
Selected network to process this payment intent on.
-
#request_decremental_authorization ⇒ Object
readonly
Request ability to [decrement the authorization](docs.stripe.com/payments/decremental-authorization) for this PaymentIntent.
-
#request_extended_authorization ⇒ Object
readonly
Request ability to [capture beyond the standard authorization validity window](docs.stripe.com/payments/extended-authorization) for this PaymentIntent.
-
#request_incremental_authorization ⇒ Object
readonly
Request ability to [increment the authorization](docs.stripe.com/payments/incremental-authorization) for this PaymentIntent.
-
#request_multicapture ⇒ Object
readonly
Request ability to make [multiple captures](docs.stripe.com/payments/multicapture) for this PaymentIntent.
-
#request_overcapture ⇒ Object
readonly
Request ability to [overcapture](docs.stripe.com/payments/overcapture) for this PaymentIntent.
-
#request_partial_authorization ⇒ Object
readonly
Request partial authorization on this PaymentIntent.
-
#request_three_d_secure ⇒ Object
readonly
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](docs.stripe.com/strong-customer-authentication).
-
#require_cvc_recollection ⇒ Object
readonly
When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#statement_descriptor_suffix_kana ⇒ Object
readonly
Provides information about a card payment that customers see on their statements.
-
#statement_descriptor_suffix_kanji ⇒ Object
readonly
Provides information about a card payment that customers see on their statements.
-
#statement_details ⇒ Object
readonly
Attribute for field statement_details.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#capture_method ⇒ Object (readonly)
Controls when the funds will be captured from the customer’s account.
2832 2833 2834 |
# File 'lib/stripe/resources/payment_intent.rb', line 2832 def capture_method @capture_method end |
#installments ⇒ Object (readonly)
Installment details for this payment.
For more information, see the [installments integration guide](docs.stripe.com/payments/installments).
2836 2837 2838 |
# File 'lib/stripe/resources/payment_intent.rb', line 2836 def installments @installments end |
#mandate_options ⇒ Object (readonly)
Configuration options for setting up an eMandate for cards issued in India.
2838 2839 2840 |
# File 'lib/stripe/resources/payment_intent.rb', line 2838 def @mandate_options end |
#network ⇒ Object (readonly)
Selected network to process this payment intent on. Depends on the available networks of the card attached to the payment intent. Can be only set confirm-time.
2840 2841 2842 |
# File 'lib/stripe/resources/payment_intent.rb', line 2840 def network @network end |
#request_decremental_authorization ⇒ Object (readonly)
Request ability to [decrement the authorization](docs.stripe.com/payments/decremental-authorization) for this PaymentIntent.
2842 2843 2844 |
# File 'lib/stripe/resources/payment_intent.rb', line 2842 def @request_decremental_authorization end |
#request_extended_authorization ⇒ Object (readonly)
Request ability to [capture beyond the standard authorization validity window](docs.stripe.com/payments/extended-authorization) for this PaymentIntent.
2844 2845 2846 |
# File 'lib/stripe/resources/payment_intent.rb', line 2844 def @request_extended_authorization end |
#request_incremental_authorization ⇒ Object (readonly)
Request ability to [increment the authorization](docs.stripe.com/payments/incremental-authorization) for this PaymentIntent.
2846 2847 2848 |
# File 'lib/stripe/resources/payment_intent.rb', line 2846 def @request_incremental_authorization end |
#request_multicapture ⇒ Object (readonly)
Request ability to make [multiple captures](docs.stripe.com/payments/multicapture) for this PaymentIntent.
2848 2849 2850 |
# File 'lib/stripe/resources/payment_intent.rb', line 2848 def request_multicapture @request_multicapture end |
#request_overcapture ⇒ Object (readonly)
Request ability to [overcapture](docs.stripe.com/payments/overcapture) for this PaymentIntent.
2850 2851 2852 |
# File 'lib/stripe/resources/payment_intent.rb', line 2850 def request_overcapture @request_overcapture end |
#request_partial_authorization ⇒ Object (readonly)
Request partial authorization on this PaymentIntent.
2852 2853 2854 |
# File 'lib/stripe/resources/payment_intent.rb', line 2852 def @request_partial_authorization end |
#request_three_d_secure ⇒ Object (readonly)
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](docs.stripe.com/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](docs.stripe.com/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.
2854 2855 2856 |
# File 'lib/stripe/resources/payment_intent.rb', line 2854 def request_three_d_secure @request_three_d_secure end |
#require_cvc_recollection ⇒ Object (readonly)
When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).
2856 2857 2858 |
# File 'lib/stripe/resources/payment_intent.rb', line 2856 def require_cvc_recollection @require_cvc_recollection end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
2864 2865 2866 |
# File 'lib/stripe/resources/payment_intent.rb', line 2864 def setup_future_usage @setup_future_usage end |
#statement_descriptor_suffix_kana ⇒ Object (readonly)
Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.
2866 2867 2868 |
# File 'lib/stripe/resources/payment_intent.rb', line 2866 def statement_descriptor_suffix_kana @statement_descriptor_suffix_kana end |
#statement_descriptor_suffix_kanji ⇒ Object (readonly)
Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.
2868 2869 2870 |
# File 'lib/stripe/resources/payment_intent.rb', line 2868 def statement_descriptor_suffix_kanji @statement_descriptor_suffix_kanji end |
#statement_details ⇒ Object (readonly)
Attribute for field statement_details
2870 2871 2872 |
# File 'lib/stripe/resources/payment_intent.rb', line 2870 def statement_details @statement_details end |
Class Method Details
.field_remappings ⇒ Object
2880 2881 2882 |
# File 'lib/stripe/resources/payment_intent.rb', line 2880 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2872 2873 2874 2875 2876 2877 2878 |
# File 'lib/stripe/resources/payment_intent.rb', line 2872 def self.inner_class_types @inner_class_types = { installments: Installments, mandate_options: MandateOptions, statement_details: StatementDetails, } end |