Class: Stripe::PaymentIntent::PaymentMethodOptions::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Installments, MandateOptions, StatementDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#capture_methodObject (readonly)

Controls when the funds will be captured from the customer’s account.



1975
1976
1977
# File 'lib/stripe/resources/payment_intent.rb', line 1975

def capture_method
  @capture_method
end

#installmentsObject (readonly)

Installment details for this payment.

For more information, see the [installments integration guide](stripe.com/docs/payments/installments).



1979
1980
1981
# File 'lib/stripe/resources/payment_intent.rb', line 1979

def installments
  @installments
end

#mandate_optionsObject (readonly)

Configuration options for setting up an eMandate for cards issued in India.



1981
1982
1983
# File 'lib/stripe/resources/payment_intent.rb', line 1981

def mandate_options
  @mandate_options
end

#networkObject (readonly)

Selected network to process this payment intent on. Depends on the available networks of the card attached to the payment intent. Can be only set confirm-time.



1983
1984
1985
# File 'lib/stripe/resources/payment_intent.rb', line 1983

def network
  @network
end

#request_decremental_authorizationObject (readonly)

Request ability to [decrement the authorization](stripe.com/docs/payments/decremental-authorization) for this PaymentIntent.



1985
1986
1987
# File 'lib/stripe/resources/payment_intent.rb', line 1985

def request_decremental_authorization
  @request_decremental_authorization
end

#request_extended_authorizationObject (readonly)

Request ability to [capture beyond the standard authorization validity window](stripe.com/docs/payments/extended-authorization) for this PaymentIntent.



1987
1988
1989
# File 'lib/stripe/resources/payment_intent.rb', line 1987

def request_extended_authorization
  @request_extended_authorization
end

#request_incremental_authorizationObject (readonly)

Request ability to [increment the authorization](stripe.com/docs/payments/incremental-authorization) for this PaymentIntent.



1989
1990
1991
# File 'lib/stripe/resources/payment_intent.rb', line 1989

def request_incremental_authorization
  @request_incremental_authorization
end

#request_multicaptureObject (readonly)

Request ability to make [multiple captures](stripe.com/docs/payments/multicapture) for this PaymentIntent.



1991
1992
1993
# File 'lib/stripe/resources/payment_intent.rb', line 1991

def request_multicapture
  @request_multicapture
end

#request_overcaptureObject (readonly)

Request ability to [overcapture](stripe.com/docs/payments/overcapture) for this PaymentIntent.



1993
1994
1995
# File 'lib/stripe/resources/payment_intent.rb', line 1993

def request_overcapture
  @request_overcapture
end

#request_partial_authorizationObject (readonly)

Request partial authorization on this PaymentIntent.



1995
1996
1997
# File 'lib/stripe/resources/payment_intent.rb', line 1995

def request_partial_authorization
  @request_partial_authorization
end

#request_three_d_secureObject (readonly)

We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](stripe.com/docs/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.



1997
1998
1999
# File 'lib/stripe/resources/payment_intent.rb', line 1997

def request_three_d_secure
  @request_three_d_secure
end

#require_cvc_recollectionObject (readonly)

When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).



1999
2000
2001
# File 'lib/stripe/resources/payment_intent.rb', line 1999

def require_cvc_recollection
  @require_cvc_recollection
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).



2007
2008
2009
# File 'lib/stripe/resources/payment_intent.rb', line 2007

def setup_future_usage
  @setup_future_usage
end

#statement_descriptor_suffix_kanaObject (readonly)

Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.



2009
2010
2011
# File 'lib/stripe/resources/payment_intent.rb', line 2009

def statement_descriptor_suffix_kana
  @statement_descriptor_suffix_kana
end

#statement_descriptor_suffix_kanjiObject (readonly)

Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.



2011
2012
2013
# File 'lib/stripe/resources/payment_intent.rb', line 2011

def statement_descriptor_suffix_kanji
  @statement_descriptor_suffix_kanji
end

#statement_detailsObject (readonly)

Attribute for field statement_details



2013
2014
2015
# File 'lib/stripe/resources/payment_intent.rb', line 2013

def statement_details
  @statement_details
end

Class Method Details

.field_remappingsObject



2023
2024
2025
# File 'lib/stripe/resources/payment_intent.rb', line 2023

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2015
2016
2017
2018
2019
2020
2021
# File 'lib/stripe/resources/payment_intent.rb', line 2015

def self.inner_class_types
  @inner_class_types = {
    installments: Installments,
    mandate_options: MandateOptions,
    statement_details: StatementDetails,
  }
end