Class: Stripe::PaymentIntent::PaymentMethodOptions::Card
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Installments, MandateOptions, StatementDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
readonly
Controls when the funds will be captured from the customer’s account.
-
#installments ⇒ Object
readonly
Installment details for this payment.
-
#mandate_options ⇒ Object
readonly
Configuration options for setting up an eMandate for cards issued in India.
-
#network ⇒ Object
readonly
Selected network to process this payment intent on.
-
#request_decremental_authorization ⇒ Object
readonly
Request ability to [decrement the authorization](stripe.com/docs/payments/decremental-authorization) for this PaymentIntent.
-
#request_extended_authorization ⇒ Object
readonly
Request ability to [capture beyond the standard authorization validity window](stripe.com/docs/payments/extended-authorization) for this PaymentIntent.
-
#request_incremental_authorization ⇒ Object
readonly
Request ability to [increment the authorization](stripe.com/docs/payments/incremental-authorization) for this PaymentIntent.
-
#request_multicapture ⇒ Object
readonly
Request ability to make [multiple captures](stripe.com/docs/payments/multicapture) for this PaymentIntent.
-
#request_overcapture ⇒ Object
readonly
Request ability to [overcapture](stripe.com/docs/payments/overcapture) for this PaymentIntent.
-
#request_partial_authorization ⇒ Object
readonly
Request partial authorization on this PaymentIntent.
-
#request_three_d_secure ⇒ Object
readonly
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication).
-
#require_cvc_recollection ⇒ Object
readonly
When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#statement_descriptor_suffix_kana ⇒ Object
readonly
Provides information about a card payment that customers see on their statements.
-
#statement_descriptor_suffix_kanji ⇒ Object
readonly
Provides information about a card payment that customers see on their statements.
-
#statement_details ⇒ Object
readonly
Attribute for field statement_details.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#capture_method ⇒ Object (readonly)
Controls when the funds will be captured from the customer’s account.
1160 1161 1162 |
# File 'lib/stripe/resources/payment_intent.rb', line 1160 def capture_method @capture_method end |
#installments ⇒ Object (readonly)
Installment details for this payment.
For more information, see the [installments integration guide](stripe.com/docs/payments/installments).
1164 1165 1166 |
# File 'lib/stripe/resources/payment_intent.rb', line 1164 def installments @installments end |
#mandate_options ⇒ Object (readonly)
Configuration options for setting up an eMandate for cards issued in India.
1166 1167 1168 |
# File 'lib/stripe/resources/payment_intent.rb', line 1166 def @mandate_options end |
#network ⇒ Object (readonly)
Selected network to process this payment intent on. Depends on the available networks of the card attached to the payment intent. Can be only set confirm-time.
1168 1169 1170 |
# File 'lib/stripe/resources/payment_intent.rb', line 1168 def network @network end |
#request_decremental_authorization ⇒ Object (readonly)
Request ability to [decrement the authorization](stripe.com/docs/payments/decremental-authorization) for this PaymentIntent.
1170 1171 1172 |
# File 'lib/stripe/resources/payment_intent.rb', line 1170 def @request_decremental_authorization end |
#request_extended_authorization ⇒ Object (readonly)
Request ability to [capture beyond the standard authorization validity window](stripe.com/docs/payments/extended-authorization) for this PaymentIntent.
1172 1173 1174 |
# File 'lib/stripe/resources/payment_intent.rb', line 1172 def @request_extended_authorization end |
#request_incremental_authorization ⇒ Object (readonly)
Request ability to [increment the authorization](stripe.com/docs/payments/incremental-authorization) for this PaymentIntent.
1174 1175 1176 |
# File 'lib/stripe/resources/payment_intent.rb', line 1174 def @request_incremental_authorization end |
#request_multicapture ⇒ Object (readonly)
Request ability to make [multiple captures](stripe.com/docs/payments/multicapture) for this PaymentIntent.
1176 1177 1178 |
# File 'lib/stripe/resources/payment_intent.rb', line 1176 def request_multicapture @request_multicapture end |
#request_overcapture ⇒ Object (readonly)
Request ability to [overcapture](stripe.com/docs/payments/overcapture) for this PaymentIntent.
1178 1179 1180 |
# File 'lib/stripe/resources/payment_intent.rb', line 1178 def request_overcapture @request_overcapture end |
#request_partial_authorization ⇒ Object (readonly)
Request partial authorization on this PaymentIntent.
1180 1181 1182 |
# File 'lib/stripe/resources/payment_intent.rb', line 1180 def @request_partial_authorization end |
#request_three_d_secure ⇒ Object (readonly)
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](stripe.com/docs/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.
1182 1183 1184 |
# File 'lib/stripe/resources/payment_intent.rb', line 1182 def request_three_d_secure @request_three_d_secure end |
#require_cvc_recollection ⇒ Object (readonly)
When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).
1184 1185 1186 |
# File 'lib/stripe/resources/payment_intent.rb', line 1184 def require_cvc_recollection @require_cvc_recollection end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
1192 1193 1194 |
# File 'lib/stripe/resources/payment_intent.rb', line 1192 def setup_future_usage @setup_future_usage end |
#statement_descriptor_suffix_kana ⇒ Object (readonly)
Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.
1194 1195 1196 |
# File 'lib/stripe/resources/payment_intent.rb', line 1194 def statement_descriptor_suffix_kana @statement_descriptor_suffix_kana end |
#statement_descriptor_suffix_kanji ⇒ Object (readonly)
Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.
1196 1197 1198 |
# File 'lib/stripe/resources/payment_intent.rb', line 1196 def statement_descriptor_suffix_kanji @statement_descriptor_suffix_kanji end |
#statement_details ⇒ Object (readonly)
Attribute for field statement_details
1198 1199 1200 |
# File 'lib/stripe/resources/payment_intent.rb', line 1198 def statement_details @statement_details end |