Class: Stripe::PaymentIntent::PaymentMethodOptions::Card
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Installments, MandateOptions
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
readonly
Controls when the funds will be captured from the customer’s account.
-
#installments ⇒ Object
readonly
Installment details for this payment (Mexico only).
-
#mandate_options ⇒ Object
readonly
Configuration options for setting up an eMandate for cards issued in India.
-
#network ⇒ Object
readonly
Selected network to process this payment intent on.
-
#request_extended_authorization ⇒ Object
readonly
Request ability to [capture beyond the standard authorization validity window](stripe.com/docs/payments/extended-authorization) for this PaymentIntent.
-
#request_incremental_authorization ⇒ Object
readonly
Request ability to [increment the authorization](stripe.com/docs/payments/incremental-authorization) for this PaymentIntent.
-
#request_multicapture ⇒ Object
readonly
Request ability to make [multiple captures](stripe.com/docs/payments/multicapture) for this PaymentIntent.
-
#request_overcapture ⇒ Object
readonly
Request ability to [overcapture](stripe.com/docs/payments/overcapture) for this PaymentIntent.
-
#request_three_d_secure ⇒ Object
readonly
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication).
-
#require_cvc_recollection ⇒ Object
readonly
When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#statement_descriptor_suffix_kana ⇒ Object
readonly
Provides information about a card payment that customers see on their statements.
-
#statement_descriptor_suffix_kanji ⇒ Object
readonly
Provides information about a card payment that customers see on their statements.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#capture_method ⇒ Object (readonly)
Controls when the funds will be captured from the customer’s account.
892 893 894 |
# File 'lib/stripe/resources/payment_intent.rb', line 892 def capture_method @capture_method end |
#installments ⇒ Object (readonly)
Installment details for this payment (Mexico only).
For more information, see the [installments integration guide](stripe.com/docs/payments/installments).
896 897 898 |
# File 'lib/stripe/resources/payment_intent.rb', line 896 def installments @installments end |
#mandate_options ⇒ Object (readonly)
Configuration options for setting up an eMandate for cards issued in India.
898 899 900 |
# File 'lib/stripe/resources/payment_intent.rb', line 898 def @mandate_options end |
#network ⇒ Object (readonly)
Selected network to process this payment intent on. Depends on the available networks of the card attached to the payment intent. Can be only set confirm-time.
900 901 902 |
# File 'lib/stripe/resources/payment_intent.rb', line 900 def network @network end |
#request_extended_authorization ⇒ Object (readonly)
Request ability to [capture beyond the standard authorization validity window](stripe.com/docs/payments/extended-authorization) for this PaymentIntent.
902 903 904 |
# File 'lib/stripe/resources/payment_intent.rb', line 902 def @request_extended_authorization end |
#request_incremental_authorization ⇒ Object (readonly)
Request ability to [increment the authorization](stripe.com/docs/payments/incremental-authorization) for this PaymentIntent.
904 905 906 |
# File 'lib/stripe/resources/payment_intent.rb', line 904 def @request_incremental_authorization end |
#request_multicapture ⇒ Object (readonly)
Request ability to make [multiple captures](stripe.com/docs/payments/multicapture) for this PaymentIntent.
906 907 908 |
# File 'lib/stripe/resources/payment_intent.rb', line 906 def request_multicapture @request_multicapture end |
#request_overcapture ⇒ Object (readonly)
Request ability to [overcapture](stripe.com/docs/payments/overcapture) for this PaymentIntent.
908 909 910 |
# File 'lib/stripe/resources/payment_intent.rb', line 908 def request_overcapture @request_overcapture end |
#request_three_d_secure ⇒ Object (readonly)
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](stripe.com/docs/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.
910 911 912 |
# File 'lib/stripe/resources/payment_intent.rb', line 910 def request_three_d_secure @request_three_d_secure end |
#require_cvc_recollection ⇒ Object (readonly)
When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).
912 913 914 |
# File 'lib/stripe/resources/payment_intent.rb', line 912 def require_cvc_recollection @require_cvc_recollection end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
920 921 922 |
# File 'lib/stripe/resources/payment_intent.rb', line 920 def setup_future_usage @setup_future_usage end |
#statement_descriptor_suffix_kana ⇒ Object (readonly)
Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.
922 923 924 |
# File 'lib/stripe/resources/payment_intent.rb', line 922 def statement_descriptor_suffix_kana @statement_descriptor_suffix_kana end |
#statement_descriptor_suffix_kanji ⇒ Object (readonly)
Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.
924 925 926 |
# File 'lib/stripe/resources/payment_intent.rb', line 924 def statement_descriptor_suffix_kanji @statement_descriptor_suffix_kanji end |