Class: Stripe::PaymentIntent::PaymentMethodOptions::Card
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Installments, MandateOptions, StatementDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
readonly
Controls when the funds will be captured from the customer’s account.
-
#installments ⇒ Object
readonly
Installment details for this payment (Mexico only).
-
#mandate_options ⇒ Object
readonly
Configuration options for setting up an eMandate for cards issued in India.
-
#network ⇒ Object
readonly
Selected network to process this payment intent on.
-
#request_decremental_authorization ⇒ Object
readonly
Request ability to [decrement the authorization](stripe.com/docs/payments/decremental-authorization) for this PaymentIntent.
-
#request_extended_authorization ⇒ Object
readonly
Request ability to [capture beyond the standard authorization validity window](stripe.com/docs/payments/extended-authorization) for this PaymentIntent.
-
#request_incremental_authorization ⇒ Object
readonly
Request ability to [increment the authorization](stripe.com/docs/payments/incremental-authorization) for this PaymentIntent.
-
#request_multicapture ⇒ Object
readonly
Request ability to make [multiple captures](stripe.com/docs/payments/multicapture) for this PaymentIntent.
-
#request_overcapture ⇒ Object
readonly
Request ability to [overcapture](stripe.com/docs/payments/overcapture) for this PaymentIntent.
-
#request_partial_authorization ⇒ Object
readonly
Request partial authorization on this PaymentIntent.
-
#request_three_d_secure ⇒ Object
readonly
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication).
-
#require_cvc_recollection ⇒ Object
readonly
When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#statement_descriptor_suffix_kana ⇒ Object
readonly
Provides information about a card payment that customers see on their statements.
-
#statement_descriptor_suffix_kanji ⇒ Object
readonly
Provides information about a card payment that customers see on their statements.
-
#statement_details ⇒ Object
readonly
Attribute for field statement_details.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#capture_method ⇒ Object (readonly)
Controls when the funds will be captured from the customer’s account.
1101 1102 1103 |
# File 'lib/stripe/resources/payment_intent.rb', line 1101 def capture_method @capture_method end |
#installments ⇒ Object (readonly)
Installment details for this payment (Mexico only).
For more information, see the [installments integration guide](stripe.com/docs/payments/installments).
1105 1106 1107 |
# File 'lib/stripe/resources/payment_intent.rb', line 1105 def installments @installments end |
#mandate_options ⇒ Object (readonly)
Configuration options for setting up an eMandate for cards issued in India.
1107 1108 1109 |
# File 'lib/stripe/resources/payment_intent.rb', line 1107 def @mandate_options end |
#network ⇒ Object (readonly)
Selected network to process this payment intent on. Depends on the available networks of the card attached to the payment intent. Can be only set confirm-time.
1109 1110 1111 |
# File 'lib/stripe/resources/payment_intent.rb', line 1109 def network @network end |
#request_decremental_authorization ⇒ Object (readonly)
Request ability to [decrement the authorization](stripe.com/docs/payments/decremental-authorization) for this PaymentIntent.
1111 1112 1113 |
# File 'lib/stripe/resources/payment_intent.rb', line 1111 def @request_decremental_authorization end |
#request_extended_authorization ⇒ Object (readonly)
Request ability to [capture beyond the standard authorization validity window](stripe.com/docs/payments/extended-authorization) for this PaymentIntent.
1113 1114 1115 |
# File 'lib/stripe/resources/payment_intent.rb', line 1113 def @request_extended_authorization end |
#request_incremental_authorization ⇒ Object (readonly)
Request ability to [increment the authorization](stripe.com/docs/payments/incremental-authorization) for this PaymentIntent.
1115 1116 1117 |
# File 'lib/stripe/resources/payment_intent.rb', line 1115 def @request_incremental_authorization end |
#request_multicapture ⇒ Object (readonly)
Request ability to make [multiple captures](stripe.com/docs/payments/multicapture) for this PaymentIntent.
1117 1118 1119 |
# File 'lib/stripe/resources/payment_intent.rb', line 1117 def request_multicapture @request_multicapture end |
#request_overcapture ⇒ Object (readonly)
Request ability to [overcapture](stripe.com/docs/payments/overcapture) for this PaymentIntent.
1119 1120 1121 |
# File 'lib/stripe/resources/payment_intent.rb', line 1119 def request_overcapture @request_overcapture end |
#request_partial_authorization ⇒ Object (readonly)
Request partial authorization on this PaymentIntent.
1121 1122 1123 |
# File 'lib/stripe/resources/payment_intent.rb', line 1121 def @request_partial_authorization end |
#request_three_d_secure ⇒ Object (readonly)
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](stripe.com/docs/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.
1123 1124 1125 |
# File 'lib/stripe/resources/payment_intent.rb', line 1123 def request_three_d_secure @request_three_d_secure end |
#require_cvc_recollection ⇒ Object (readonly)
When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).
1125 1126 1127 |
# File 'lib/stripe/resources/payment_intent.rb', line 1125 def require_cvc_recollection @require_cvc_recollection end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
1133 1134 1135 |
# File 'lib/stripe/resources/payment_intent.rb', line 1133 def setup_future_usage @setup_future_usage end |
#statement_descriptor_suffix_kana ⇒ Object (readonly)
Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.
1135 1136 1137 |
# File 'lib/stripe/resources/payment_intent.rb', line 1135 def statement_descriptor_suffix_kana @statement_descriptor_suffix_kana end |
#statement_descriptor_suffix_kanji ⇒ Object (readonly)
Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.
1137 1138 1139 |
# File 'lib/stripe/resources/payment_intent.rb', line 1137 def statement_descriptor_suffix_kanji @statement_descriptor_suffix_kanji end |
#statement_details ⇒ Object (readonly)
Attribute for field statement_details
1139 1140 1141 |
# File 'lib/stripe/resources/payment_intent.rb', line 1139 def statement_details @statement_details end |