Class: Stripe::PaymentIntent::PaymentMethodOptions::Card::Installments
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Card::Installments
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AvailablePlan, Plan
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#available_plans ⇒ Object
readonly
Installment plans that may be selected for this PaymentIntent.
-
#enabled ⇒ Object
readonly
Whether Installments are enabled for this PaymentIntent.
-
#plan ⇒ Object
readonly
Installment plan selected for this PaymentIntent.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#available_plans ⇒ Object (readonly)
Installment plans that may be selected for this PaymentIntent.
1894 1895 1896 |
# File 'lib/stripe/resources/payment_intent.rb', line 1894 def available_plans @available_plans end |
#enabled ⇒ Object (readonly)
Whether Installments are enabled for this PaymentIntent.
1896 1897 1898 |
# File 'lib/stripe/resources/payment_intent.rb', line 1896 def enabled @enabled end |
#plan ⇒ Object (readonly)
Installment plan selected for this PaymentIntent.
1898 1899 1900 |
# File 'lib/stripe/resources/payment_intent.rb', line 1898 def plan @plan end |
Class Method Details
.field_remappings ⇒ Object
1904 1905 1906 |
# File 'lib/stripe/resources/payment_intent.rb', line 1904 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1900 1901 1902 |
# File 'lib/stripe/resources/payment_intent.rb', line 1900 def self.inner_class_types @inner_class_types = { available_plans: AvailablePlan, plan: Plan } end |