Class: Stripe::PaymentIntent::PaymentMethodOptions::Card::Installments::AvailablePlan

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#countObject (readonly)

For ‘fixed_count` installment plans, this is the number of installment payments your customer will make to their credit card.



1398
1399
1400
# File 'lib/stripe/resources/payment_intent.rb', line 1398

def count
  @count
end

#intervalObject (readonly)

For ‘fixed_count` installment plans, this is the interval between installment payments your customer will make to their credit card. One of `month`.



1401
1402
1403
# File 'lib/stripe/resources/payment_intent.rb', line 1401

def interval
  @interval
end

#typeObject (readonly)

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



1403
1404
1405
# File 'lib/stripe/resources/payment_intent.rb', line 1403

def type
  @type
end

Class Method Details

.field_remappingsObject



1409
1410
1411
# File 'lib/stripe/resources/payment_intent.rb', line 1409

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1405
1406
1407
# File 'lib/stripe/resources/payment_intent.rb', line 1405

def self.inner_class_types
  @inner_class_types = {}
end