Class: Stripe::PaymentIntent::PaymentMethodOptions::Card::Installments::AvailablePlan
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Card::Installments::AvailablePlan
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#count ⇒ Object
readonly
For ‘fixed_count` installment plans, this is the number of installment payments your customer will make to their credit card.
-
#interval ⇒ Object
readonly
For ‘fixed_count` installment plans, this is the interval between installment payments your customer will make to their credit card.
-
#type ⇒ Object
readonly
Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#count ⇒ Object (readonly)
For ‘fixed_count` installment plans, this is the number of installment payments your customer will make to their credit card.
1093 1094 1095 |
# File 'lib/stripe/resources/payment_intent.rb', line 1093 def count @count end |
#interval ⇒ Object (readonly)
For ‘fixed_count` installment plans, this is the interval between installment payments your customer will make to their credit card. One of `month`.
1096 1097 1098 |
# File 'lib/stripe/resources/payment_intent.rb', line 1096 def interval @interval end |
#type ⇒ Object (readonly)
Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.
1098 1099 1100 |
# File 'lib/stripe/resources/payment_intent.rb', line 1098 def type @type end |