Class: Stripe::PaymentIntent::PaymentMethodOptions::Card::Installments::Plan

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#countObject (readonly)

For ‘fixed_count` installment plans, this is the number of installment payments your customer will make to their credit card.



853
854
855
# File 'lib/stripe/resources/payment_intent.rb', line 853

def count
  @count
end

#intervalObject (readonly)

For ‘fixed_count` installment plans, this is the interval between installment payments your customer will make to their credit card. One of `month`.



856
857
858
# File 'lib/stripe/resources/payment_intent.rb', line 856

def interval
  @interval
end

#typeObject (readonly)

Type of installment plan, one of ‘fixed_count`.



858
859
860
# File 'lib/stripe/resources/payment_intent.rb', line 858

def type
  @type
end