Class: Stripe::PaymentIntent::PaymentMethodOptions::Card::MandateOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Card::MandateOptions
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount to be charged for future payments, specified in the presentment currency.
-
#amount_type ⇒ Object
readonly
One of ‘fixed` or `maximum`.
-
#description ⇒ Object
readonly
A description of the mandate or subscription that is meant to be displayed to the customer.
-
#end_date ⇒ Object
readonly
End date of the mandate or subscription.
-
#interval ⇒ Object
readonly
Specifies payment frequency.
-
#interval_count ⇒ Object
readonly
The number of intervals between payments.
-
#reference ⇒ Object
readonly
Unique identifier for the mandate or subscription.
-
#start_date ⇒ Object
readonly
Start date of the mandate or subscription.
-
#supported_types ⇒ Object
readonly
Specifies the type of mandates supported.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount to be charged for future payments, specified in the presentment currency.
3406 3407 3408 |
# File 'lib/stripe/resources/payment_intent.rb', line 3406 def amount @amount end |
#amount_type ⇒ Object (readonly)
One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.
3408 3409 3410 |
# File 'lib/stripe/resources/payment_intent.rb', line 3408 def amount_type @amount_type end |
#description ⇒ Object (readonly)
A description of the mandate or subscription that is meant to be displayed to the customer.
3410 3411 3412 |
# File 'lib/stripe/resources/payment_intent.rb', line 3410 def description @description end |
#end_date ⇒ Object (readonly)
End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.
3412 3413 3414 |
# File 'lib/stripe/resources/payment_intent.rb', line 3412 def end_date @end_date end |
#interval ⇒ Object (readonly)
Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.
3414 3415 3416 |
# File 'lib/stripe/resources/payment_intent.rb', line 3414 def interval @interval end |
#interval_count ⇒ Object (readonly)
The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.
3416 3417 3418 |
# File 'lib/stripe/resources/payment_intent.rb', line 3416 def interval_count @interval_count end |
#reference ⇒ Object (readonly)
Unique identifier for the mandate or subscription.
3418 3419 3420 |
# File 'lib/stripe/resources/payment_intent.rb', line 3418 def reference @reference end |
#start_date ⇒ Object (readonly)
Start date of the mandate or subscription. Start date should not be lesser than yesterday.
3420 3421 3422 |
# File 'lib/stripe/resources/payment_intent.rb', line 3420 def start_date @start_date end |
#supported_types ⇒ Object (readonly)
Specifies the type of mandates supported. Possible values are ‘india`.
3422 3423 3424 |
# File 'lib/stripe/resources/payment_intent.rb', line 3422 def supported_types @supported_types end |
Class Method Details
.field_remappings ⇒ Object
3428 3429 3430 |
# File 'lib/stripe/resources/payment_intent.rb', line 3428 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3424 3425 3426 |
# File 'lib/stripe/resources/payment_intent.rb', line 3424 def self.inner_class_types @inner_class_types = {} end |