Class: Stripe::PaymentIntent::PaymentMethodOptions::Card::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments, specified in the presentment currency.



2885
2886
2887
# File 'lib/stripe/resources/payment_intent.rb', line 2885

def amount
  @amount
end

#amount_typeObject (readonly)

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



2887
2888
2889
# File 'lib/stripe/resources/payment_intent.rb', line 2887

def amount_type
  @amount_type
end

#descriptionObject (readonly)

A description of the mandate or subscription that is meant to be displayed to the customer.



2889
2890
2891
# File 'lib/stripe/resources/payment_intent.rb', line 2889

def description
  @description
end

#end_dateObject (readonly)

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



2891
2892
2893
# File 'lib/stripe/resources/payment_intent.rb', line 2891

def end_date
  @end_date
end

#intervalObject (readonly)

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



2893
2894
2895
# File 'lib/stripe/resources/payment_intent.rb', line 2893

def interval
  @interval
end

#interval_countObject (readonly)

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



2895
2896
2897
# File 'lib/stripe/resources/payment_intent.rb', line 2895

def interval_count
  @interval_count
end

#referenceObject (readonly)

Unique identifier for the mandate or subscription.



2897
2898
2899
# File 'lib/stripe/resources/payment_intent.rb', line 2897

def reference
  @reference
end

#start_dateObject (readonly)

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



2899
2900
2901
# File 'lib/stripe/resources/payment_intent.rb', line 2899

def start_date
  @start_date
end

#supported_typesObject (readonly)

Specifies the type of mandates supported. Possible values are ‘india`.



2901
2902
2903
# File 'lib/stripe/resources/payment_intent.rb', line 2901

def supported_types
  @supported_types
end

Class Method Details

.field_remappingsObject



2907
2908
2909
# File 'lib/stripe/resources/payment_intent.rb', line 2907

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2903
2904
2905
# File 'lib/stripe/resources/payment_intent.rb', line 2903

def self.inner_class_types
  @inner_class_types = {}
end