Class: Stripe::PaymentIntent::PaymentMethodOptions::Card::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments, specified in the presentment currency.



1659
1660
1661
# File 'lib/stripe/resources/payment_intent.rb', line 1659

def amount
  @amount
end

#amount_typeObject (readonly)

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



1661
1662
1663
# File 'lib/stripe/resources/payment_intent.rb', line 1661

def amount_type
  @amount_type
end

#descriptionObject (readonly)

A description of the mandate or subscription that is meant to be displayed to the customer.



1663
1664
1665
# File 'lib/stripe/resources/payment_intent.rb', line 1663

def description
  @description
end

#end_dateObject (readonly)

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



1665
1666
1667
# File 'lib/stripe/resources/payment_intent.rb', line 1665

def end_date
  @end_date
end

#intervalObject (readonly)

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



1667
1668
1669
# File 'lib/stripe/resources/payment_intent.rb', line 1667

def interval
  @interval
end

#interval_countObject (readonly)

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



1669
1670
1671
# File 'lib/stripe/resources/payment_intent.rb', line 1669

def interval_count
  @interval_count
end

#referenceObject (readonly)

Unique identifier for the mandate or subscription.



1671
1672
1673
# File 'lib/stripe/resources/payment_intent.rb', line 1671

def reference
  @reference
end

#start_dateObject (readonly)

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



1673
1674
1675
# File 'lib/stripe/resources/payment_intent.rb', line 1673

def start_date
  @start_date
end

#supported_typesObject (readonly)

Specifies the type of mandates supported. Possible values are ‘india`.



1675
1676
1677
# File 'lib/stripe/resources/payment_intent.rb', line 1675

def supported_types
  @supported_types
end

Class Method Details

.field_remappingsObject



1681
1682
1683
# File 'lib/stripe/resources/payment_intent.rb', line 1681

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1677
1678
1679
# File 'lib/stripe/resources/payment_intent.rb', line 1677

def self.inner_class_types
  @inner_class_types = {}
end