Class: Stripe::PaymentIntent::PaymentMethodOptions::Card::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments, specified in the presentment currency.



3262
3263
3264
# File 'lib/stripe/resources/payment_intent.rb', line 3262

def amount
  @amount
end

#amount_typeObject (readonly)

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



3264
3265
3266
# File 'lib/stripe/resources/payment_intent.rb', line 3264

def amount_type
  @amount_type
end

#descriptionObject (readonly)

A description of the mandate or subscription that is meant to be displayed to the customer.



3266
3267
3268
# File 'lib/stripe/resources/payment_intent.rb', line 3266

def description
  @description
end

#end_dateObject (readonly)

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



3268
3269
3270
# File 'lib/stripe/resources/payment_intent.rb', line 3268

def end_date
  @end_date
end

#intervalObject (readonly)

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



3270
3271
3272
# File 'lib/stripe/resources/payment_intent.rb', line 3270

def interval
  @interval
end

#interval_countObject (readonly)

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



3272
3273
3274
# File 'lib/stripe/resources/payment_intent.rb', line 3272

def interval_count
  @interval_count
end

#referenceObject (readonly)

Unique identifier for the mandate or subscription.



3274
3275
3276
# File 'lib/stripe/resources/payment_intent.rb', line 3274

def reference
  @reference
end

#start_dateObject (readonly)

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



3276
3277
3278
# File 'lib/stripe/resources/payment_intent.rb', line 3276

def start_date
  @start_date
end

#supported_typesObject (readonly)

Specifies the type of mandates supported. Possible values are ‘india`.



3278
3279
3280
# File 'lib/stripe/resources/payment_intent.rb', line 3278

def supported_types
  @supported_types
end

Class Method Details

.field_remappingsObject



3284
3285
3286
# File 'lib/stripe/resources/payment_intent.rb', line 3284

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3280
3281
3282
# File 'lib/stripe/resources/payment_intent.rb', line 3280

def self.inner_class_types
  @inner_class_types = {}
end