Class: Stripe::PaymentIntent::PaymentMethodOptions::Card::MandateOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Card::MandateOptions
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount to be charged for future payments.
-
#amount_type ⇒ Object
readonly
One of ‘fixed` or `maximum`.
-
#description ⇒ Object
readonly
A description of the mandate or subscription that is meant to be displayed to the customer.
-
#end_date ⇒ Object
readonly
End date of the mandate or subscription.
-
#interval ⇒ Object
readonly
Specifies payment frequency.
-
#interval_count ⇒ Object
readonly
The number of intervals between payments.
-
#reference ⇒ Object
readonly
Unique identifier for the mandate or subscription.
-
#start_date ⇒ Object
readonly
Start date of the mandate or subscription.
-
#supported_types ⇒ Object
readonly
Specifies the type of mandates supported.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount to be charged for future payments.
2940 2941 2942 |
# File 'lib/stripe/resources/payment_intent.rb', line 2940 def amount @amount end |
#amount_type ⇒ Object (readonly)
One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.
2942 2943 2944 |
# File 'lib/stripe/resources/payment_intent.rb', line 2942 def amount_type @amount_type end |
#description ⇒ Object (readonly)
A description of the mandate or subscription that is meant to be displayed to the customer.
2944 2945 2946 |
# File 'lib/stripe/resources/payment_intent.rb', line 2944 def description @description end |
#end_date ⇒ Object (readonly)
End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.
2946 2947 2948 |
# File 'lib/stripe/resources/payment_intent.rb', line 2946 def end_date @end_date end |
#interval ⇒ Object (readonly)
Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.
2948 2949 2950 |
# File 'lib/stripe/resources/payment_intent.rb', line 2948 def interval @interval end |
#interval_count ⇒ Object (readonly)
The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.
2950 2951 2952 |
# File 'lib/stripe/resources/payment_intent.rb', line 2950 def interval_count @interval_count end |
#reference ⇒ Object (readonly)
Unique identifier for the mandate or subscription.
2952 2953 2954 |
# File 'lib/stripe/resources/payment_intent.rb', line 2952 def reference @reference end |
#start_date ⇒ Object (readonly)
Start date of the mandate or subscription. Start date should not be lesser than yesterday.
2954 2955 2956 |
# File 'lib/stripe/resources/payment_intent.rb', line 2954 def start_date @start_date end |
#supported_types ⇒ Object (readonly)
Specifies the type of mandates supported. Possible values are ‘india`.
2956 2957 2958 |
# File 'lib/stripe/resources/payment_intent.rb', line 2956 def supported_types @supported_types end |
Class Method Details
.field_remappings ⇒ Object
2962 2963 2964 |
# File 'lib/stripe/resources/payment_intent.rb', line 2962 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2958 2959 2960 |
# File 'lib/stripe/resources/payment_intent.rb', line 2958 def self.inner_class_types @inner_class_types = {} end |