Class: Stripe::PaymentIntent::PaymentMethodOptions::Card::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments.



1515
1516
1517
# File 'lib/stripe/resources/payment_intent.rb', line 1515

def amount
  @amount
end

#amount_typeObject (readonly)

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



1517
1518
1519
# File 'lib/stripe/resources/payment_intent.rb', line 1517

def amount_type
  @amount_type
end

#descriptionObject (readonly)

A description of the mandate or subscription that is meant to be displayed to the customer.



1519
1520
1521
# File 'lib/stripe/resources/payment_intent.rb', line 1519

def description
  @description
end

#end_dateObject (readonly)

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



1521
1522
1523
# File 'lib/stripe/resources/payment_intent.rb', line 1521

def end_date
  @end_date
end

#intervalObject (readonly)

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



1523
1524
1525
# File 'lib/stripe/resources/payment_intent.rb', line 1523

def interval
  @interval
end

#interval_countObject (readonly)

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



1525
1526
1527
# File 'lib/stripe/resources/payment_intent.rb', line 1525

def interval_count
  @interval_count
end

#referenceObject (readonly)

Unique identifier for the mandate or subscription.



1527
1528
1529
# File 'lib/stripe/resources/payment_intent.rb', line 1527

def reference
  @reference
end

#start_dateObject (readonly)

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



1529
1530
1531
# File 'lib/stripe/resources/payment_intent.rb', line 1529

def start_date
  @start_date
end

#supported_typesObject (readonly)

Specifies the type of mandates supported. Possible values are ‘india`.



1531
1532
1533
# File 'lib/stripe/resources/payment_intent.rb', line 1531

def supported_types
  @supported_types
end

Class Method Details

.field_remappingsObject



1537
1538
1539
# File 'lib/stripe/resources/payment_intent.rb', line 1537

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1533
1534
1535
# File 'lib/stripe/resources/payment_intent.rb', line 1533

def self.inner_class_types
  @inner_class_types = {}
end