Class: Stripe::PaymentIntent::PaymentMethodOptions::Card::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments.



1883
1884
1885
# File 'lib/stripe/resources/payment_intent.rb', line 1883

def amount
  @amount
end

#amount_typeObject (readonly)

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



1885
1886
1887
# File 'lib/stripe/resources/payment_intent.rb', line 1885

def amount_type
  @amount_type
end

#descriptionObject (readonly)

A description of the mandate or subscription that is meant to be displayed to the customer.



1887
1888
1889
# File 'lib/stripe/resources/payment_intent.rb', line 1887

def description
  @description
end

#end_dateObject (readonly)

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



1889
1890
1891
# File 'lib/stripe/resources/payment_intent.rb', line 1889

def end_date
  @end_date
end

#intervalObject (readonly)

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



1891
1892
1893
# File 'lib/stripe/resources/payment_intent.rb', line 1891

def interval
  @interval
end

#interval_countObject (readonly)

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



1893
1894
1895
# File 'lib/stripe/resources/payment_intent.rb', line 1893

def interval_count
  @interval_count
end

#referenceObject (readonly)

Unique identifier for the mandate or subscription.



1895
1896
1897
# File 'lib/stripe/resources/payment_intent.rb', line 1895

def reference
  @reference
end

#start_dateObject (readonly)

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



1897
1898
1899
# File 'lib/stripe/resources/payment_intent.rb', line 1897

def start_date
  @start_date
end

#supported_typesObject (readonly)

Specifies the type of mandates supported. Possible values are ‘india`.



1899
1900
1901
# File 'lib/stripe/resources/payment_intent.rb', line 1899

def supported_types
  @supported_types
end

Class Method Details

.field_remappingsObject



1905
1906
1907
# File 'lib/stripe/resources/payment_intent.rb', line 1905

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1901
1902
1903
# File 'lib/stripe/resources/payment_intent.rb', line 1901

def self.inner_class_types
  @inner_class_types = {}
end