Class: Stripe::PaymentIntent::PaymentMethodOptions::Card::MandateOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Card::MandateOptions
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount to be charged for future payments.
-
#amount_type ⇒ Object
readonly
One of ‘fixed` or `maximum`.
-
#description ⇒ Object
readonly
A description of the mandate or subscription that is meant to be displayed to the customer.
-
#end_date ⇒ Object
readonly
End date of the mandate or subscription.
-
#interval ⇒ Object
readonly
Specifies payment frequency.
-
#interval_count ⇒ Object
readonly
The number of intervals between payments.
-
#reference ⇒ Object
readonly
Unique identifier for the mandate or subscription.
-
#start_date ⇒ Object
readonly
Start date of the mandate or subscription.
-
#supported_types ⇒ Object
readonly
Specifies the type of mandates supported.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount to be charged for future payments.
873 874 875 |
# File 'lib/stripe/resources/payment_intent.rb', line 873 def amount @amount end |
#amount_type ⇒ Object (readonly)
One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.
875 876 877 |
# File 'lib/stripe/resources/payment_intent.rb', line 875 def amount_type @amount_type end |
#description ⇒ Object (readonly)
A description of the mandate or subscription that is meant to be displayed to the customer.
877 878 879 |
# File 'lib/stripe/resources/payment_intent.rb', line 877 def description @description end |
#end_date ⇒ Object (readonly)
End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.
879 880 881 |
# File 'lib/stripe/resources/payment_intent.rb', line 879 def end_date @end_date end |
#interval ⇒ Object (readonly)
Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.
881 882 883 |
# File 'lib/stripe/resources/payment_intent.rb', line 881 def interval @interval end |
#interval_count ⇒ Object (readonly)
The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.
883 884 885 |
# File 'lib/stripe/resources/payment_intent.rb', line 883 def interval_count @interval_count end |
#reference ⇒ Object (readonly)
Unique identifier for the mandate or subscription.
885 886 887 |
# File 'lib/stripe/resources/payment_intent.rb', line 885 def reference @reference end |
#start_date ⇒ Object (readonly)
Start date of the mandate or subscription. Start date should not be lesser than yesterday.
887 888 889 |
# File 'lib/stripe/resources/payment_intent.rb', line 887 def start_date @start_date end |
#supported_types ⇒ Object (readonly)
Specifies the type of mandates supported. Possible values are ‘india`.
889 890 891 |
# File 'lib/stripe/resources/payment_intent.rb', line 889 def supported_types @supported_types end |