Class: Stripe::PaymentIntent::PaymentMethodOptions::Card::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments.



1098
1099
1100
# File 'lib/stripe/resources/payment_intent.rb', line 1098

def amount
  @amount
end

#amount_typeObject (readonly)

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



1100
1101
1102
# File 'lib/stripe/resources/payment_intent.rb', line 1100

def amount_type
  @amount_type
end

#descriptionObject (readonly)

A description of the mandate or subscription that is meant to be displayed to the customer.



1102
1103
1104
# File 'lib/stripe/resources/payment_intent.rb', line 1102

def description
  @description
end

#end_dateObject (readonly)

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



1104
1105
1106
# File 'lib/stripe/resources/payment_intent.rb', line 1104

def end_date
  @end_date
end

#intervalObject (readonly)

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



1106
1107
1108
# File 'lib/stripe/resources/payment_intent.rb', line 1106

def interval
  @interval
end

#interval_countObject (readonly)

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



1108
1109
1110
# File 'lib/stripe/resources/payment_intent.rb', line 1108

def interval_count
  @interval_count
end

#referenceObject (readonly)

Unique identifier for the mandate or subscription.



1110
1111
1112
# File 'lib/stripe/resources/payment_intent.rb', line 1110

def reference
  @reference
end

#start_dateObject (readonly)

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



1112
1113
1114
# File 'lib/stripe/resources/payment_intent.rb', line 1112

def start_date
  @start_date
end

#supported_typesObject (readonly)

Specifies the type of mandates supported. Possible values are ‘india`.



1114
1115
1116
# File 'lib/stripe/resources/payment_intent.rb', line 1114

def supported_types
  @supported_types
end