Class: Stripe::PaymentIntent::PaymentMethodOptions::CardPresent

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: AadeData, CaptureDelay, Routing

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#aade_dataObject (readonly)

Attribute for field aade_data



3708
3709
3710
# File 'lib/stripe/resources/payment_intent.rb', line 3708

def aade_data
  @aade_data
end

#capture_byObject (readonly)

Controls when funds are captured from the customer's account when capture_method is automatic_delayed.

If omitted, funds are captured before the authorization expires.



3712
3713
3714
# File 'lib/stripe/resources/payment_intent.rb', line 3712

def capture_by
  @capture_by
end

#capture_delayObject (readonly)

Attribute for field capture_delay



3714
3715
3716
# File 'lib/stripe/resources/payment_intent.rb', line 3714

def capture_delay
  @capture_delay
end

#capture_methodObject (readonly)

Controls when the funds will be captured from the customer's account.



3716
3717
3718
# File 'lib/stripe/resources/payment_intent.rb', line 3716

def capture_method
  @capture_method
end

#request_extended_authorizationObject (readonly)

Request ability to capture this payment beyond the standard authorization validity window



3718
3719
3720
# File 'lib/stripe/resources/payment_intent.rb', line 3718

def request_extended_authorization
  @request_extended_authorization
end

#request_incremental_authorization_supportObject (readonly)

Request ability to increment this PaymentIntent if the combination of MCC and card brand is eligible. Check incremental_authorization_supported in the Confirm response to verify support.



3720
3721
3722
# File 'lib/stripe/resources/payment_intent.rb', line 3720

def request_incremental_authorization_support
  @request_incremental_authorization_support
end

#request_multicaptureObject (readonly)

Request ability to make multiple captures for this PaymentIntent.



3722
3723
3724
# File 'lib/stripe/resources/payment_intent.rb', line 3722

def request_multicapture
  @request_multicapture
end

#request_reauthorizationObject (readonly)

Request ability to reauthorize for this PaymentIntent.



3724
3725
3726
# File 'lib/stripe/resources/payment_intent.rb', line 3724

def request_reauthorization
  @request_reauthorization
end

#routingObject (readonly)

Attribute for field routing



3726
3727
3728
# File 'lib/stripe/resources/payment_intent.rb', line 3726

def routing
  @routing
end

Class Method Details

.field_remappingsObject



3732
3733
3734
# File 'lib/stripe/resources/payment_intent.rb', line 3732

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3728
3729
3730
# File 'lib/stripe/resources/payment_intent.rb', line 3728

def self.inner_class_types
  @inner_class_types = { aade_data: AadeData, capture_delay: CaptureDelay, routing: Routing }
end