Class: Stripe::PaymentIntent::PaymentMethodOptions::CardPresent
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::CardPresent
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Routing
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
readonly
Controls when the funds will be captured from the customer’s account.
-
#request_extended_authorization ⇒ Object
readonly
Request ability to capture this payment beyond the standard [authorization validity window](docs.stripe.com/terminal/features/extended-authorizations#authorization-validity).
-
#request_incremental_authorization_support ⇒ Object
readonly
Request ability to [increment](docs.stripe.com/terminal/features/incremental-authorizations) this PaymentIntent if the combination of MCC and card brand is eligible.
-
#request_reauthorization ⇒ Object
readonly
Request ability to [reauthorize](docs.stripe.com/payments/reauthorization) for this PaymentIntent.
-
#routing ⇒ Object
readonly
Attribute for field routing.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#capture_method ⇒ Object (readonly)
Controls when the funds will be captured from the customer’s account.
3539 3540 3541 |
# File 'lib/stripe/resources/payment_intent.rb', line 3539 def capture_method @capture_method end |
#request_extended_authorization ⇒ Object (readonly)
Request ability to capture this payment beyond the standard [authorization validity window](docs.stripe.com/terminal/features/extended-authorizations#authorization-validity)
3541 3542 3543 |
# File 'lib/stripe/resources/payment_intent.rb', line 3541 def @request_extended_authorization end |
#request_incremental_authorization_support ⇒ Object (readonly)
Request ability to [increment](docs.stripe.com/terminal/features/incremental-authorizations) this PaymentIntent if the combination of MCC and card brand is eligible. Check [incremental_authorization_supported](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-incremental_authorization_supported) in the [Confirm](docs.stripe.com/api/payment_intents/confirm) response to verify support.
3543 3544 3545 |
# File 'lib/stripe/resources/payment_intent.rb', line 3543 def @request_incremental_authorization_support end |
#request_reauthorization ⇒ Object (readonly)
Request ability to [reauthorize](docs.stripe.com/payments/reauthorization) for this PaymentIntent.
3545 3546 3547 |
# File 'lib/stripe/resources/payment_intent.rb', line 3545 def @request_reauthorization end |
#routing ⇒ Object (readonly)
Attribute for field routing
3547 3548 3549 |
# File 'lib/stripe/resources/payment_intent.rb', line 3547 def routing @routing end |
Class Method Details
.field_remappings ⇒ Object
3553 3554 3555 |
# File 'lib/stripe/resources/payment_intent.rb', line 3553 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3549 3550 3551 |
# File 'lib/stripe/resources/payment_intent.rb', line 3549 def self.inner_class_types @inner_class_types = { routing: Routing } end |