Class: Stripe::PaymentIntent::PaymentMethodOptions::CardPresent
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::CardPresent
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Routing
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
readonly
Controls when the funds will be captured from the customer’s account.
-
#request_extended_authorization ⇒ Object
readonly
Request ability to capture this payment beyond the standard [authorization validity window](docs.stripe.com/terminal/features/extended-authorizations#authorization-validity).
-
#request_incremental_authorization_support ⇒ Object
readonly
Request ability to [increment](docs.stripe.com/terminal/features/incremental-authorizations) this PaymentIntent if the combination of MCC and card brand is eligible.
-
#routing ⇒ Object
readonly
Attribute for field routing.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#capture_method ⇒ Object (readonly)
Controls when the funds will be captured from the customer’s account.
2993 2994 2995 |
# File 'lib/stripe/resources/payment_intent.rb', line 2993 def capture_method @capture_method end |
#request_extended_authorization ⇒ Object (readonly)
Request ability to capture this payment beyond the standard [authorization validity window](docs.stripe.com/terminal/features/extended-authorizations#authorization-validity)
2995 2996 2997 |
# File 'lib/stripe/resources/payment_intent.rb', line 2995 def @request_extended_authorization end |
#request_incremental_authorization_support ⇒ Object (readonly)
Request ability to [increment](docs.stripe.com/terminal/features/incremental-authorizations) this PaymentIntent if the combination of MCC and card brand is eligible. Check [incremental_authorization_supported](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-incremental_authorization_supported) in the [Confirm](docs.stripe.com/api/payment_intents/confirm) response to verify support.
2997 2998 2999 |
# File 'lib/stripe/resources/payment_intent.rb', line 2997 def @request_incremental_authorization_support end |
#routing ⇒ Object (readonly)
Attribute for field routing
2999 3000 3001 |
# File 'lib/stripe/resources/payment_intent.rb', line 2999 def routing @routing end |
Class Method Details
.field_remappings ⇒ Object
3005 3006 3007 |
# File 'lib/stripe/resources/payment_intent.rb', line 3005 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3001 3002 3003 |
# File 'lib/stripe/resources/payment_intent.rb', line 3001 def self.inner_class_types @inner_class_types = { routing: Routing } end |