Class: Stripe::PaymentIntent::PaymentMethodOptions::CardPresent

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Routing

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#capture_methodObject (readonly)

Controls when the funds will be captured from the customer’s account.



3222
3223
3224
# File 'lib/stripe/resources/payment_intent.rb', line 3222

def capture_method
  @capture_method
end

#request_extended_authorizationObject (readonly)

Request ability to capture this payment beyond the standard [authorization validity window](docs.stripe.com/terminal/features/extended-authorizations#authorization-validity)



3224
3225
3226
# File 'lib/stripe/resources/payment_intent.rb', line 3224

def request_extended_authorization
  @request_extended_authorization
end

#request_incremental_authorization_supportObject (readonly)

Request ability to [increment](docs.stripe.com/terminal/features/incremental-authorizations) this PaymentIntent if the combination of MCC and card brand is eligible. Check [incremental_authorization_supported](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-incremental_authorization_supported) in the [Confirm](docs.stripe.com/api/payment_intents/confirm) response to verify support.



3226
3227
3228
# File 'lib/stripe/resources/payment_intent.rb', line 3226

def request_incremental_authorization_support
  @request_incremental_authorization_support
end

#request_reauthorizationObject (readonly)

Request ability to [reauthorize](docs.stripe.com/payments/reauthorization) for this PaymentIntent.



3228
3229
3230
# File 'lib/stripe/resources/payment_intent.rb', line 3228

def request_reauthorization
  @request_reauthorization
end

#routingObject (readonly)

Attribute for field routing



3230
3231
3232
# File 'lib/stripe/resources/payment_intent.rb', line 3230

def routing
  @routing
end

Class Method Details

.field_remappingsObject



3236
3237
3238
# File 'lib/stripe/resources/payment_intent.rb', line 3236

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3232
3233
3234
# File 'lib/stripe/resources/payment_intent.rb', line 3232

def self.inner_class_types
  @inner_class_types = { routing: Routing }
end