Class: Stripe::PaymentIntent::PaymentMethodOptions::CardPresent::CaptureDelay
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::CardPresent::CaptureDelay
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#days ⇒ Object
readonly
The number of days to delay the capture of the funds.
-
#hours ⇒ Object
readonly
The number of hours to delay the capture of the funds.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#days ⇒ Object (readonly)
The number of days to delay the capture of the funds.
You can only set this if capture_method is automatic_delayed and capture_by is target_delay.
3680 3681 3682 |
# File 'lib/stripe/resources/payment_intent.rb', line 3680 def days @days end |
#hours ⇒ Object (readonly)
The number of hours to delay the capture of the funds.
You can only set this if capture_method is automatic_delayed and capture_by is target_delay.
3684 3685 3686 |
# File 'lib/stripe/resources/payment_intent.rb', line 3684 def hours @hours end |
Class Method Details
.field_remappings ⇒ Object
3690 3691 3692 |
# File 'lib/stripe/resources/payment_intent.rb', line 3690 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3686 3687 3688 |
# File 'lib/stripe/resources/payment_intent.rb', line 3686 def self.inner_class_types @inner_class_types = {} end |