Class: Stripe::PaymentIntent::PaymentMethodOptions::Crypto
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Crypto
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AmountReconciliation, DepositOptions, TransactionVerificationOptions
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_reconciliation ⇒ Object
readonly
Attribute for field amount_reconciliation.
-
#deposit_options ⇒ Object
readonly
Attribute for field deposit_options.
-
#mode ⇒ Object
readonly
The mode of the crypto payment.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent's payment method.
-
#transaction_verification_options ⇒ Object
readonly
Attribute for field transaction_verification_options.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_reconciliation ⇒ Object (readonly)
Attribute for field amount_reconciliation
3802 3803 3804 |
# File 'lib/stripe/resources/payment_intent.rb', line 3802 def amount_reconciliation @amount_reconciliation end |
#deposit_options ⇒ Object (readonly)
Attribute for field deposit_options
3804 3805 3806 |
# File 'lib/stripe/resources/payment_intent.rb', line 3804 def @deposit_options end |
#mode ⇒ Object (readonly)
The mode of the crypto payment.
3806 3807 3808 |
# File 'lib/stripe/resources/payment_intent.rb', line 3806 def mode @mode end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
3814 3815 3816 |
# File 'lib/stripe/resources/payment_intent.rb', line 3814 def setup_future_usage @setup_future_usage end |
#transaction_verification_options ⇒ Object (readonly)
Attribute for field transaction_verification_options
3816 3817 3818 |
# File 'lib/stripe/resources/payment_intent.rb', line 3816 def @transaction_verification_options end |
Class Method Details
.field_remappings ⇒ Object
3826 3827 3828 |
# File 'lib/stripe/resources/payment_intent.rb', line 3826 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3818 3819 3820 3821 3822 3823 3824 |
# File 'lib/stripe/resources/payment_intent.rb', line 3818 def self.inner_class_types @inner_class_types = { amount_reconciliation: AmountReconciliation, deposit_options: DepositOptions, transaction_verification_options: TransactionVerificationOptions, } end |