Class: Stripe::PaymentIntent::PaymentMethodOptions::Crypto

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: DepositOptions

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#deposit_optionsObject (readonly)

Attribute for field deposit_options



3471
3472
3473
# File 'lib/stripe/resources/payment_intent.rb', line 3471

def deposit_options
  @deposit_options
end

#modeObject (readonly)

The mode of the crypto payment.



3473
3474
3475
# File 'lib/stripe/resources/payment_intent.rb', line 3473

def mode
  @mode
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).



3481
3482
3483
# File 'lib/stripe/resources/payment_intent.rb', line 3481

def setup_future_usage
  @setup_future_usage
end

Class Method Details

.field_remappingsObject



3487
3488
3489
# File 'lib/stripe/resources/payment_intent.rb', line 3487

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3483
3484
3485
# File 'lib/stripe/resources/payment_intent.rb', line 3483

def self.inner_class_types
  @inner_class_types = { deposit_options: DepositOptions }
end