Class: Stripe::PaymentIntent::PaymentMethodOptions::Crypto
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Crypto
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: DepositOptions
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#deposit_options ⇒ Object
readonly
Attribute for field deposit_options.
-
#mode ⇒ Object
readonly
The mode of the crypto payment.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#deposit_options ⇒ Object (readonly)
Attribute for field deposit_options
3135 3136 3137 |
# File 'lib/stripe/resources/payment_intent.rb', line 3135 def @deposit_options end |
#mode ⇒ Object (readonly)
The mode of the crypto payment.
3137 3138 3139 |
# File 'lib/stripe/resources/payment_intent.rb', line 3137 def mode @mode end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
3133 3134 3135 |
# File 'lib/stripe/resources/payment_intent.rb', line 3133 def setup_future_usage @setup_future_usage end |
Class Method Details
.field_remappings ⇒ Object
3143 3144 3145 |
# File 'lib/stripe/resources/payment_intent.rb', line 3143 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3139 3140 3141 |
# File 'lib/stripe/resources/payment_intent.rb', line 3139 def self.inner_class_types @inner_class_types = { deposit_options: DepositOptions } end |