Class: Stripe::PaymentIntent::PaymentMethodOptions::CustomerBalance
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::CustomerBalance
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: BankTransfer
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_transfer ⇒ Object
readonly
Attribute for field bank_transfer.
-
#funding_type ⇒ Object
readonly
The funding method type to be used when there are not enough funds in the customer balance.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_transfer ⇒ Object (readonly)
Attribute for field bank_transfer
3105 3106 3107 |
# File 'lib/stripe/resources/payment_intent.rb', line 3105 def bank_transfer @bank_transfer end |
#funding_type ⇒ Object (readonly)
The funding method type to be used when there are not enough funds in the customer balance. Permitted values include: bank_transfer.
3107 3108 3109 |
# File 'lib/stripe/resources/payment_intent.rb', line 3107 def funding_type @funding_type end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
3115 3116 3117 |
# File 'lib/stripe/resources/payment_intent.rb', line 3115 def setup_future_usage @setup_future_usage end |
Class Method Details
.field_remappings ⇒ Object
3121 3122 3123 |
# File 'lib/stripe/resources/payment_intent.rb', line 3121 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3117 3118 3119 |
# File 'lib/stripe/resources/payment_intent.rb', line 3117 def self.inner_class_types @inner_class_types = { bank_transfer: BankTransfer } end |