Class: Stripe::PaymentIntent::PaymentMethodOptions::IdBankTransfer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::IdBankTransfer
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#expires_after ⇒ Object
readonly
The UNIX timestamp until which the virtual bank account is valid.
-
#expires_at ⇒ Object
readonly
The UNIX timestamp until which the virtual bank account is valid.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#expires_after ⇒ Object (readonly)
The UNIX timestamp until which the virtual bank account is valid. Permitted range is from now till 2678400 seconds (31 days) from now.
3223 3224 3225 |
# File 'lib/stripe/resources/payment_intent.rb', line 3223 def expires_after @expires_after end |
#expires_at ⇒ Object (readonly)
The UNIX timestamp until which the virtual bank account is valid. Permitted range is from now until 30 days from now. If unset, it defaults to 1 days from now.
3225 3226 3227 |
# File 'lib/stripe/resources/payment_intent.rb', line 3225 def expires_at @expires_at end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
3233 3234 3235 |
# File 'lib/stripe/resources/payment_intent.rb', line 3233 def setup_future_usage @setup_future_usage end |
Class Method Details
.field_remappings ⇒ Object
3239 3240 3241 |
# File 'lib/stripe/resources/payment_intent.rb', line 3239 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3235 3236 3237 |
# File 'lib/stripe/resources/payment_intent.rb', line 3235 def self.inner_class_types @inner_class_types = {} end |