Class: Stripe::PaymentIntent::PaymentMethodOptions::Klarna
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Klarna
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
readonly
Controls when the funds will be captured from the customer's account.
-
#preferred_locale ⇒ Object
readonly
Preferred locale of the Klarna checkout page that the customer is redirected to.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#capture_method ⇒ Object (readonly)
Controls when the funds will be captured from the customer's account.
1981 1982 1983 |
# File 'lib/stripe/resources/payment_intent.rb', line 1981 def capture_method @capture_method end |
#preferred_locale ⇒ Object (readonly)
Preferred locale of the Klarna checkout page that the customer is redirected to.
1983 1984 1985 |
# File 'lib/stripe/resources/payment_intent.rb', line 1983 def preferred_locale @preferred_locale end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
1991 1992 1993 |
# File 'lib/stripe/resources/payment_intent.rb', line 1991 def setup_future_usage @setup_future_usage end |
Class Method Details
.field_remappings ⇒ Object
1997 1998 1999 |
# File 'lib/stripe/resources/payment_intent.rb', line 1997 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1993 1994 1995 |
# File 'lib/stripe/resources/payment_intent.rb', line 1993 def self.inner_class_types @inner_class_types = {} end |