Class: Stripe::PaymentIntent::PaymentMethodOptions::Konbini

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#confirmation_numberObject (readonly)

An optional 10 to 11 digit numeric-only string determining the confirmation code at applicable convenience stores.



4094
4095
4096
# File 'lib/stripe/resources/payment_intent.rb', line 4094

def confirmation_number
  @confirmation_number
end

#expires_after_daysObject (readonly)

The number of calendar days (between 1 and 60) after which Konbini payment instructions will expire. For example, if a PaymentIntent is confirmed with Konbini and expires_after_days set to 2 on Monday JST, the instructions will expire on Wednesday 23:59:59 JST.



4096
4097
4098
# File 'lib/stripe/resources/payment_intent.rb', line 4096

def expires_after_days
  @expires_after_days
end

#expires_atObject (readonly)

The timestamp at which the Konbini payment instructions will expire. Only one of expires_after_days or expires_at may be set.



4098
4099
4100
# File 'lib/stripe/resources/payment_intent.rb', line 4098

def expires_at
  @expires_at
end

#product_descriptionObject (readonly)

A product descriptor of up to 22 characters, which will appear to customers at the convenience store.



4100
4101
4102
# File 'lib/stripe/resources/payment_intent.rb', line 4100

def product_description
  @product_description
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.



4108
4109
4110
# File 'lib/stripe/resources/payment_intent.rb', line 4108

def setup_future_usage
  @setup_future_usage
end

Class Method Details

.field_remappingsObject



4114
4115
4116
# File 'lib/stripe/resources/payment_intent.rb', line 4114

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4110
4111
4112
# File 'lib/stripe/resources/payment_intent.rb', line 4110

def self.inner_class_types
  @inner_class_types = {}
end