Class: Stripe::PaymentIntent::PaymentMethodOptions::Konbini
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Konbini
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#confirmation_number ⇒ Object
readonly
An optional 10 to 11 digit numeric-only string determining the confirmation code at applicable convenience stores.
-
#expires_after_days ⇒ Object
readonly
The number of calendar days (between 1 and 60) after which Konbini payment instructions will expire.
-
#expires_at ⇒ Object
readonly
The timestamp at which the Konbini payment instructions will expire.
-
#product_description ⇒ Object
readonly
A product descriptor of up to 22 characters, which will appear to customers at the convenience store.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#confirmation_number ⇒ Object (readonly)
An optional 10 to 11 digit numeric-only string determining the confirmation code at applicable convenience stores.
3319 3320 3321 |
# File 'lib/stripe/resources/payment_intent.rb', line 3319 def confirmation_number @confirmation_number end |
#expires_after_days ⇒ Object (readonly)
The number of calendar days (between 1 and 60) after which Konbini payment instructions will expire. For example, if a PaymentIntent is confirmed with Konbini and expires_after_days set to 2 on Monday JST, the instructions will expire on Wednesday 23:59:59 JST.
3321 3322 3323 |
# File 'lib/stripe/resources/payment_intent.rb', line 3321 def expires_after_days @expires_after_days end |
#expires_at ⇒ Object (readonly)
The timestamp at which the Konbini payment instructions will expire. Only one of expires_after_days or expires_at may be set.
3323 3324 3325 |
# File 'lib/stripe/resources/payment_intent.rb', line 3323 def expires_at @expires_at end |
#product_description ⇒ Object (readonly)
A product descriptor of up to 22 characters, which will appear to customers at the convenience store.
3325 3326 3327 |
# File 'lib/stripe/resources/payment_intent.rb', line 3325 def product_description @product_description end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
3333 3334 3335 |
# File 'lib/stripe/resources/payment_intent.rb', line 3333 def setup_future_usage @setup_future_usage end |
Class Method Details
.field_remappings ⇒ Object
3339 3340 3341 |
# File 'lib/stripe/resources/payment_intent.rb', line 3339 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3335 3336 3337 |
# File 'lib/stripe/resources/payment_intent.rb', line 3335 def self.inner_class_types @inner_class_types = {} end |