Class: Stripe::PaymentIntent::PaymentMethodOptions::Link

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#capture_methodObject (readonly)

Controls when the funds will be captured from the customer's account.



3367
3368
3369
# File 'lib/stripe/resources/payment_intent.rb', line 3367

def capture_method
  @capture_method
end

#persistent_tokenObject (readonly)

[Deprecated] This is a legacy parameter that no longer has any function.



3369
3370
3371
# File 'lib/stripe/resources/payment_intent.rb', line 3369

def persistent_token
  @persistent_token
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.



3377
3378
3379
# File 'lib/stripe/resources/payment_intent.rb', line 3377

def setup_future_usage
  @setup_future_usage
end

Class Method Details

.field_remappingsObject



3383
3384
3385
# File 'lib/stripe/resources/payment_intent.rb', line 3383

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3379
3380
3381
# File 'lib/stripe/resources/payment_intent.rb', line 3379

def self.inner_class_types
  @inner_class_types = {}
end