Class: Stripe::PaymentIntent::PaymentMethodOptions::Paypal

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: LineItem

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#capture_methodObject (readonly)

Controls when the funds will be captured from the customer’s account.



1469
1470
1471
# File 'lib/stripe/resources/payment_intent.rb', line 1469

def capture_method
  @capture_method
end

#line_itemsObject (readonly)

The line items purchased by the customer.



1471
1472
1473
# File 'lib/stripe/resources/payment_intent.rb', line 1471

def line_items
  @line_items
end

#preferred_localeObject (readonly)

Preferred locale of the PayPal checkout page that the customer is redirected to.



1473
1474
1475
# File 'lib/stripe/resources/payment_intent.rb', line 1473

def preferred_locale
  @preferred_locale
end

#referenceObject (readonly)

A reference of the PayPal transaction visible to customer which is mapped to PayPal’s invoice ID. This must be a globally unique ID if you have configured in your PayPal settings to block multiple payments per invoice ID.



1475
1476
1477
# File 'lib/stripe/resources/payment_intent.rb', line 1475

def reference
  @reference
end

#reference_idObject (readonly)

A reference of the PayPal transaction visible to customer which is mapped to PayPal’s invoice ID. This must be a globally unique ID if you have configured in your PayPal settings to block multiple payments per invoice ID.



1477
1478
1479
# File 'lib/stripe/resources/payment_intent.rb', line 1477

def reference_id
  @reference_id
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).



1485
1486
1487
# File 'lib/stripe/resources/payment_intent.rb', line 1485

def setup_future_usage
  @setup_future_usage
end

#subsellersObject (readonly)

The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when [separate charges and transfers](stripe.com/docs/connect/separate-charges-and-transfers) are used.



1487
1488
1489
# File 'lib/stripe/resources/payment_intent.rb', line 1487

def subsellers
  @subsellers
end