Class: Stripe::PaymentIntent::PaymentMethodOptions::Paypal::LineItem

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#categoryObject (readonly)

Type of the line item.



4148
4149
4150
# File 'lib/stripe/resources/payment_intent.rb', line 4148

def category
  @category
end

#descriptionObject (readonly)

Description of the line item.



4150
4151
4152
# File 'lib/stripe/resources/payment_intent.rb', line 4150

def description
  @description
end

#nameObject (readonly)

Descriptive name of the line item.



4152
4153
4154
# File 'lib/stripe/resources/payment_intent.rb', line 4152

def name
  @name
end

#quantityObject (readonly)

Quantity of the line item. Cannot be a negative number.



4154
4155
4156
# File 'lib/stripe/resources/payment_intent.rb', line 4154

def quantity
  @quantity
end

#skuObject (readonly)

Client facing stock keeping unit, article number or similar.



4156
4157
4158
# File 'lib/stripe/resources/payment_intent.rb', line 4156

def sku
  @sku
end

#sold_byObject (readonly)

The Stripe account ID of the connected account that sells the item. This is only needed when using [Separate Charges and Transfers](docs.stripe.com/connect/separate-charges-and-transfers).



4158
4159
4160
# File 'lib/stripe/resources/payment_intent.rb', line 4158

def sold_by
  @sold_by
end

#taxObject (readonly)

Attribute for field tax



4160
4161
4162
# File 'lib/stripe/resources/payment_intent.rb', line 4160

def tax
  @tax
end

#unit_amountObject (readonly)

Price for a single unit of the line item in minor units. Cannot be a negative number.



4162
4163
4164
# File 'lib/stripe/resources/payment_intent.rb', line 4162

def unit_amount
  @unit_amount
end

Class Method Details

.field_remappingsObject



4168
4169
4170
# File 'lib/stripe/resources/payment_intent.rb', line 4168

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4164
4165
4166
# File 'lib/stripe/resources/payment_intent.rb', line 4164

def self.inner_class_types
  @inner_class_types = { tax: Tax }
end