Class: Stripe::PaymentIntent::PaymentMethodOptions::Paypal::LineItem

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#categoryObject (readonly)

Type of the line item.



4007
4008
4009
# File 'lib/stripe/resources/payment_intent.rb', line 4007

def category
  @category
end

#descriptionObject (readonly)

Description of the line item.



4009
4010
4011
# File 'lib/stripe/resources/payment_intent.rb', line 4009

def description
  @description
end

#nameObject (readonly)

Descriptive name of the line item.



4011
4012
4013
# File 'lib/stripe/resources/payment_intent.rb', line 4011

def name
  @name
end

#quantityObject (readonly)

Quantity of the line item. Cannot be a negative number.



4013
4014
4015
# File 'lib/stripe/resources/payment_intent.rb', line 4013

def quantity
  @quantity
end

#skuObject (readonly)

Client facing stock keeping unit, article number or similar.



4015
4016
4017
# File 'lib/stripe/resources/payment_intent.rb', line 4015

def sku
  @sku
end

#sold_byObject (readonly)

The Stripe account ID of the connected account that sells the item. This is only needed when using [Separate Charges and Transfers](docs.stripe.com/connect/separate-charges-and-transfers).



4017
4018
4019
# File 'lib/stripe/resources/payment_intent.rb', line 4017

def sold_by
  @sold_by
end

#taxObject (readonly)

Attribute for field tax



4019
4020
4021
# File 'lib/stripe/resources/payment_intent.rb', line 4019

def tax
  @tax
end

#unit_amountObject (readonly)

Price for a single unit of the line item in minor units. Cannot be a negative number.



4021
4022
4023
# File 'lib/stripe/resources/payment_intent.rb', line 4021

def unit_amount
  @unit_amount
end

Class Method Details

.field_remappingsObject



4027
4028
4029
# File 'lib/stripe/resources/payment_intent.rb', line 4027

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4023
4024
4025
# File 'lib/stripe/resources/payment_intent.rb', line 4023

def self.inner_class_types
  @inner_class_types = { tax: Tax }
end