Class: Stripe::PaymentIntent::PaymentMethodOptions::Paypal::LineItem

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#categoryObject (readonly)

Type of the line item.



3565
3566
3567
# File 'lib/stripe/resources/payment_intent.rb', line 3565

def category
  @category
end

#descriptionObject (readonly)

Description of the line item.



3567
3568
3569
# File 'lib/stripe/resources/payment_intent.rb', line 3567

def description
  @description
end

#nameObject (readonly)

Descriptive name of the line item.



3569
3570
3571
# File 'lib/stripe/resources/payment_intent.rb', line 3569

def name
  @name
end

#quantityObject (readonly)

Quantity of the line item. Cannot be a negative number.



3571
3572
3573
# File 'lib/stripe/resources/payment_intent.rb', line 3571

def quantity
  @quantity
end

#skuObject (readonly)

Client facing stock keeping unit, article number or similar.



3573
3574
3575
# File 'lib/stripe/resources/payment_intent.rb', line 3573

def sku
  @sku
end

#sold_byObject (readonly)

The Stripe account ID of the connected account that sells the item. This is only needed when using [Separate Charges and Transfers](docs.stripe.com/connect/separate-charges-and-transfers).



3575
3576
3577
# File 'lib/stripe/resources/payment_intent.rb', line 3575

def sold_by
  @sold_by
end

#taxObject (readonly)

Attribute for field tax



3577
3578
3579
# File 'lib/stripe/resources/payment_intent.rb', line 3577

def tax
  @tax
end

#unit_amountObject (readonly)

Price for a single unit of the line item in minor units. Cannot be a negative number.



3579
3580
3581
# File 'lib/stripe/resources/payment_intent.rb', line 3579

def unit_amount
  @unit_amount
end

Class Method Details

.field_remappingsObject



3585
3586
3587
# File 'lib/stripe/resources/payment_intent.rb', line 3585

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3581
3582
3583
# File 'lib/stripe/resources/payment_intent.rb', line 3581

def self.inner_class_types
  @inner_class_types = { tax: Tax }
end