Class: Stripe::PaymentIntent::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Tax
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#category ⇒ Object
readonly
Type of the line item.
-
#description ⇒ Object
readonly
Description of the line item.
-
#name ⇒ Object
readonly
Descriptive name of the line item.
-
#quantity ⇒ Object
readonly
Quantity of the line item.
-
#sku ⇒ Object
readonly
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
readonly
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
readonly
Attribute for field tax.
-
#unit_amount ⇒ Object
readonly
Price for a single unit of the line item in minor units.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#category ⇒ Object (readonly)
Type of the line item.
3529 3530 3531 |
# File 'lib/stripe/resources/payment_intent.rb', line 3529 def category @category end |
#description ⇒ Object (readonly)
Description of the line item.
3531 3532 3533 |
# File 'lib/stripe/resources/payment_intent.rb', line 3531 def description @description end |
#name ⇒ Object (readonly)
Descriptive name of the line item.
3533 3534 3535 |
# File 'lib/stripe/resources/payment_intent.rb', line 3533 def name @name end |
#quantity ⇒ Object (readonly)
Quantity of the line item. Cannot be a negative number.
3535 3536 3537 |
# File 'lib/stripe/resources/payment_intent.rb', line 3535 def quantity @quantity end |
#sku ⇒ Object (readonly)
Client facing stock keeping unit, article number or similar.
3537 3538 3539 |
# File 'lib/stripe/resources/payment_intent.rb', line 3537 def sku @sku end |
#sold_by ⇒ Object (readonly)
The Stripe account ID of the connected account that sells the item. This is only needed when using [Separate Charges and Transfers](docs.stripe.com/connect/separate-charges-and-transfers).
3539 3540 3541 |
# File 'lib/stripe/resources/payment_intent.rb', line 3539 def sold_by @sold_by end |
#tax ⇒ Object (readonly)
Attribute for field tax
3541 3542 3543 |
# File 'lib/stripe/resources/payment_intent.rb', line 3541 def tax @tax end |
#unit_amount ⇒ Object (readonly)
Price for a single unit of the line item in minor units. Cannot be a negative number.
3543 3544 3545 |
# File 'lib/stripe/resources/payment_intent.rb', line 3543 def unit_amount @unit_amount end |
Class Method Details
.field_remappings ⇒ Object
3549 3550 3551 |
# File 'lib/stripe/resources/payment_intent.rb', line 3549 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3545 3546 3547 |
# File 'lib/stripe/resources/payment_intent.rb', line 3545 def self.inner_class_types @inner_class_types = { tax: Tax } end |