Class: Stripe::PaymentIntent::PaymentMethodOptions::Paypal::LineItem

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#categoryObject (readonly)

Type of the line item.



3512
3513
3514
# File 'lib/stripe/resources/payment_intent.rb', line 3512

def category
  @category
end

#descriptionObject (readonly)

Description of the line item.



3514
3515
3516
# File 'lib/stripe/resources/payment_intent.rb', line 3514

def description
  @description
end

#nameObject (readonly)

Descriptive name of the line item.



3516
3517
3518
# File 'lib/stripe/resources/payment_intent.rb', line 3516

def name
  @name
end

#quantityObject (readonly)

Quantity of the line item. Cannot be a negative number.



3518
3519
3520
# File 'lib/stripe/resources/payment_intent.rb', line 3518

def quantity
  @quantity
end

#skuObject (readonly)

Client facing stock keeping unit, article number or similar.



3520
3521
3522
# File 'lib/stripe/resources/payment_intent.rb', line 3520

def sku
  @sku
end

#sold_byObject (readonly)

The Stripe account ID of the connected account that sells the item. This is only needed when using [Separate Charges and Transfers](docs.stripe.com/connect/separate-charges-and-transfers).



3522
3523
3524
# File 'lib/stripe/resources/payment_intent.rb', line 3522

def sold_by
  @sold_by
end

#taxObject (readonly)

Attribute for field tax



3524
3525
3526
# File 'lib/stripe/resources/payment_intent.rb', line 3524

def tax
  @tax
end

#unit_amountObject (readonly)

Price for a single unit of the line item in minor units. Cannot be a negative number.



3526
3527
3528
# File 'lib/stripe/resources/payment_intent.rb', line 3526

def unit_amount
  @unit_amount
end

Class Method Details

.field_remappingsObject



3532
3533
3534
# File 'lib/stripe/resources/payment_intent.rb', line 3532

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3528
3529
3530
# File 'lib/stripe/resources/payment_intent.rb', line 3528

def self.inner_class_types
  @inner_class_types = { tax: Tax }
end