Class: Stripe::PaymentIntent::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Tax
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#category ⇒ Object
readonly
Type of the line item.
-
#description ⇒ Object
readonly
Description of the line item.
-
#name ⇒ Object
readonly
Descriptive name of the line item.
-
#quantity ⇒ Object
readonly
Quantity of the line item.
-
#sku ⇒ Object
readonly
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
readonly
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
readonly
Attribute for field tax.
-
#unit_amount ⇒ Object
readonly
Price for a single unit of the line item in minor units.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#category ⇒ Object (readonly)
Type of the line item.
3471 3472 3473 |
# File 'lib/stripe/resources/payment_intent.rb', line 3471 def category @category end |
#description ⇒ Object (readonly)
Description of the line item.
3473 3474 3475 |
# File 'lib/stripe/resources/payment_intent.rb', line 3473 def description @description end |
#name ⇒ Object (readonly)
Descriptive name of the line item.
3475 3476 3477 |
# File 'lib/stripe/resources/payment_intent.rb', line 3475 def name @name end |
#quantity ⇒ Object (readonly)
Quantity of the line item. Cannot be a negative number.
3477 3478 3479 |
# File 'lib/stripe/resources/payment_intent.rb', line 3477 def quantity @quantity end |
#sku ⇒ Object (readonly)
Client facing stock keeping unit, article number or similar.
3479 3480 3481 |
# File 'lib/stripe/resources/payment_intent.rb', line 3479 def sku @sku end |
#sold_by ⇒ Object (readonly)
The Stripe account ID of the connected account that sells the item. This is only needed when using [Separate Charges and Transfers](docs.stripe.com/connect/separate-charges-and-transfers).
3481 3482 3483 |
# File 'lib/stripe/resources/payment_intent.rb', line 3481 def sold_by @sold_by end |
#tax ⇒ Object (readonly)
Attribute for field tax
3483 3484 3485 |
# File 'lib/stripe/resources/payment_intent.rb', line 3483 def tax @tax end |
#unit_amount ⇒ Object (readonly)
Price for a single unit of the line item in minor units. Cannot be a negative number.
3485 3486 3487 |
# File 'lib/stripe/resources/payment_intent.rb', line 3485 def unit_amount @unit_amount end |
Class Method Details
.field_remappings ⇒ Object
3491 3492 3493 |
# File 'lib/stripe/resources/payment_intent.rb', line 3491 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3487 3488 3489 |
# File 'lib/stripe/resources/payment_intent.rb', line 3487 def self.inner_class_types @inner_class_types = { tax: Tax } end |