Class: Stripe::PaymentIntent::PaymentMethodOptions::Paypal::LineItem

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#categoryObject (readonly)

Type of the line item.



2637
2638
2639
# File 'lib/stripe/resources/payment_intent.rb', line 2637

def category
  @category
end

#descriptionObject (readonly)

Description of the line item.



2639
2640
2641
# File 'lib/stripe/resources/payment_intent.rb', line 2639

def description
  @description
end

#nameObject (readonly)

Descriptive name of the line item.



2641
2642
2643
# File 'lib/stripe/resources/payment_intent.rb', line 2641

def name
  @name
end

#quantityObject (readonly)

Quantity of the line item. Cannot be a negative number.



2643
2644
2645
# File 'lib/stripe/resources/payment_intent.rb', line 2643

def quantity
  @quantity
end

#skuObject (readonly)

Client facing stock keeping unit, article number or similar.



2645
2646
2647
# File 'lib/stripe/resources/payment_intent.rb', line 2645

def sku
  @sku
end

#sold_byObject (readonly)

The Stripe account ID of the connected account that sells the item. This is only needed when using [Separate Charges and Transfers](docs.stripe.com/connect/separate-charges-and-transfers).



2647
2648
2649
# File 'lib/stripe/resources/payment_intent.rb', line 2647

def sold_by
  @sold_by
end

#taxObject (readonly)

Attribute for field tax



2649
2650
2651
# File 'lib/stripe/resources/payment_intent.rb', line 2649

def tax
  @tax
end

#unit_amountObject (readonly)

Price for a single unit of the line item in minor units. Cannot be a negative number.



2651
2652
2653
# File 'lib/stripe/resources/payment_intent.rb', line 2651

def unit_amount
  @unit_amount
end

Class Method Details

.field_remappingsObject



2657
2658
2659
# File 'lib/stripe/resources/payment_intent.rb', line 2657

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2653
2654
2655
# File 'lib/stripe/resources/payment_intent.rb', line 2653

def self.inner_class_types
  @inner_class_types = { tax: Tax }
end