Class: Stripe::PaymentIntent::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Tax
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#category ⇒ Object
readonly
Type of the line item.
-
#description ⇒ Object
readonly
Description of the line item.
-
#name ⇒ Object
readonly
Descriptive name of the line item.
-
#quantity ⇒ Object
readonly
Quantity of the line item.
-
#sku ⇒ Object
readonly
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
readonly
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
readonly
Attribute for field tax.
-
#unit_amount ⇒ Object
readonly
Price for a single unit of the line item in minor units.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#category ⇒ Object (readonly)
Type of the line item.
2612 2613 2614 |
# File 'lib/stripe/resources/payment_intent.rb', line 2612 def category @category end |
#description ⇒ Object (readonly)
Description of the line item.
2614 2615 2616 |
# File 'lib/stripe/resources/payment_intent.rb', line 2614 def description @description end |
#name ⇒ Object (readonly)
Descriptive name of the line item.
2616 2617 2618 |
# File 'lib/stripe/resources/payment_intent.rb', line 2616 def name @name end |
#quantity ⇒ Object (readonly)
Quantity of the line item. Cannot be a negative number.
2618 2619 2620 |
# File 'lib/stripe/resources/payment_intent.rb', line 2618 def quantity @quantity end |
#sku ⇒ Object (readonly)
Client facing stock keeping unit, article number or similar.
2620 2621 2622 |
# File 'lib/stripe/resources/payment_intent.rb', line 2620 def sku @sku end |
#sold_by ⇒ Object (readonly)
The Stripe account ID of the connected account that sells the item. This is only needed when using [Separate Charges and Transfers](docs.stripe.com/connect/separate-charges-and-transfers).
2622 2623 2624 |
# File 'lib/stripe/resources/payment_intent.rb', line 2622 def sold_by @sold_by end |
#tax ⇒ Object (readonly)
Attribute for field tax
2624 2625 2626 |
# File 'lib/stripe/resources/payment_intent.rb', line 2624 def tax @tax end |
#unit_amount ⇒ Object (readonly)
Price for a single unit of the line item in minor units. Cannot be a negative number.
2626 2627 2628 |
# File 'lib/stripe/resources/payment_intent.rb', line 2626 def unit_amount @unit_amount end |
Class Method Details
.field_remappings ⇒ Object
2632 2633 2634 |
# File 'lib/stripe/resources/payment_intent.rb', line 2632 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2628 2629 2630 |
# File 'lib/stripe/resources/payment_intent.rb', line 2628 def self.inner_class_types @inner_class_types = { tax: Tax } end |