Class: Stripe::PaymentIntent::PaymentMethodOptions::Paypal::LineItem

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#categoryObject (readonly)

Type of the line item.



1537
1538
1539
# File 'lib/stripe/resources/payment_intent.rb', line 1537

def category
  @category
end

#descriptionObject (readonly)

Description of the line item.



1539
1540
1541
# File 'lib/stripe/resources/payment_intent.rb', line 1539

def description
  @description
end

#nameObject (readonly)

Descriptive name of the line item.



1541
1542
1543
# File 'lib/stripe/resources/payment_intent.rb', line 1541

def name
  @name
end

#quantityObject (readonly)

Quantity of the line item. Cannot be a negative number.



1543
1544
1545
# File 'lib/stripe/resources/payment_intent.rb', line 1543

def quantity
  @quantity
end

#skuObject (readonly)

Client facing stock keeping unit, article number or similar.



1545
1546
1547
# File 'lib/stripe/resources/payment_intent.rb', line 1545

def sku
  @sku
end

#sold_byObject (readonly)

The Stripe account ID of the connected account that sells the item. This is only needed when using [Separate Charges and Transfers](docs.stripe.com/connect/separate-charges-and-transfers).



1547
1548
1549
# File 'lib/stripe/resources/payment_intent.rb', line 1547

def sold_by
  @sold_by
end

#taxObject (readonly)

Attribute for field tax



1549
1550
1551
# File 'lib/stripe/resources/payment_intent.rb', line 1549

def tax
  @tax
end

#unit_amountObject (readonly)

Price for a single unit of the line item in minor units. Cannot be a negative number.



1551
1552
1553
# File 'lib/stripe/resources/payment_intent.rb', line 1551

def unit_amount
  @unit_amount
end