Class: Stripe::PaymentIntent::PaymentMethodOptions::Paypal::LineItem

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#categoryObject (readonly)

Type of the line item.



1526
1527
1528
# File 'lib/stripe/resources/payment_intent.rb', line 1526

def category
  @category
end

#descriptionObject (readonly)

Description of the line item.



1528
1529
1530
# File 'lib/stripe/resources/payment_intent.rb', line 1528

def description
  @description
end

#nameObject (readonly)

Descriptive name of the line item.



1530
1531
1532
# File 'lib/stripe/resources/payment_intent.rb', line 1530

def name
  @name
end

#quantityObject (readonly)

Quantity of the line item. Cannot be a negative number.



1532
1533
1534
# File 'lib/stripe/resources/payment_intent.rb', line 1532

def quantity
  @quantity
end

#skuObject (readonly)

Client facing stock keeping unit, article number or similar.



1534
1535
1536
# File 'lib/stripe/resources/payment_intent.rb', line 1534

def sku
  @sku
end

#sold_byObject (readonly)

The Stripe account ID of the connected account that sells the item. This is only needed when using [Separate Charges and Transfers](docs.stripe.com/connect/separate-charges-and-transfers).



1536
1537
1538
# File 'lib/stripe/resources/payment_intent.rb', line 1536

def sold_by
  @sold_by
end

#taxObject (readonly)

Attribute for field tax



1538
1539
1540
# File 'lib/stripe/resources/payment_intent.rb', line 1538

def tax
  @tax
end

#unit_amountObject (readonly)

Price for a single unit of the line item in minor units. Cannot be a negative number.



1540
1541
1542
# File 'lib/stripe/resources/payment_intent.rb', line 1540

def unit_amount
  @unit_amount
end