Class: Stripe::PaymentIntent::PaymentMethodOptions::Paypal::LineItem

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#categoryObject (readonly)

Type of the line item.



1504
1505
1506
# File 'lib/stripe/resources/payment_intent.rb', line 1504

def category
  @category
end

#descriptionObject (readonly)

Description of the line item.



1506
1507
1508
# File 'lib/stripe/resources/payment_intent.rb', line 1506

def description
  @description
end

#nameObject (readonly)

Descriptive name of the line item.



1508
1509
1510
# File 'lib/stripe/resources/payment_intent.rb', line 1508

def name
  @name
end

#quantityObject (readonly)

Quantity of the line item. Cannot be a negative number.



1510
1511
1512
# File 'lib/stripe/resources/payment_intent.rb', line 1510

def quantity
  @quantity
end

#skuObject (readonly)

Client facing stock keeping unit, article number or similar.



1512
1513
1514
# File 'lib/stripe/resources/payment_intent.rb', line 1512

def sku
  @sku
end

#sold_byObject (readonly)

The Stripe account ID of the connected account that sells the item. This is only needed when using [Separate Charges and Transfers](docs.stripe.com/connect/separate-charges-and-transfers).



1514
1515
1516
# File 'lib/stripe/resources/payment_intent.rb', line 1514

def sold_by
  @sold_by
end

#taxObject (readonly)

Attribute for field tax



1516
1517
1518
# File 'lib/stripe/resources/payment_intent.rb', line 1516

def tax
  @tax
end

#unit_amountObject (readonly)

Price for a single unit of the line item in minor units. Cannot be a negative number.



1518
1519
1520
# File 'lib/stripe/resources/payment_intent.rb', line 1518

def unit_amount
  @unit_amount
end