Class: Stripe::PaymentIntent::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Tax
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#category ⇒ Object
readonly
Type of the line item.
-
#description ⇒ Object
readonly
Description of the line item.
-
#name ⇒ Object
readonly
Descriptive name of the line item.
-
#quantity ⇒ Object
readonly
Quantity of the line item.
-
#sku ⇒ Object
readonly
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
readonly
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
readonly
Attribute for field tax.
-
#unit_amount ⇒ Object
readonly
Price for a single unit of the line item in minor units.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#category ⇒ Object (readonly)
Type of the line item.
1504 1505 1506 |
# File 'lib/stripe/resources/payment_intent.rb', line 1504 def category @category end |
#description ⇒ Object (readonly)
Description of the line item.
1506 1507 1508 |
# File 'lib/stripe/resources/payment_intent.rb', line 1506 def description @description end |
#name ⇒ Object (readonly)
Descriptive name of the line item.
1508 1509 1510 |
# File 'lib/stripe/resources/payment_intent.rb', line 1508 def name @name end |
#quantity ⇒ Object (readonly)
Quantity of the line item. Cannot be a negative number.
1510 1511 1512 |
# File 'lib/stripe/resources/payment_intent.rb', line 1510 def quantity @quantity end |
#sku ⇒ Object (readonly)
Client facing stock keeping unit, article number or similar.
1512 1513 1514 |
# File 'lib/stripe/resources/payment_intent.rb', line 1512 def sku @sku end |
#sold_by ⇒ Object (readonly)
The Stripe account ID of the connected account that sells the item. This is only needed when using [Separate Charges and Transfers](docs.stripe.com/connect/separate-charges-and-transfers).
1514 1515 1516 |
# File 'lib/stripe/resources/payment_intent.rb', line 1514 def sold_by @sold_by end |
#tax ⇒ Object (readonly)
Attribute for field tax
1516 1517 1518 |
# File 'lib/stripe/resources/payment_intent.rb', line 1516 def tax @tax end |
#unit_amount ⇒ Object (readonly)
Price for a single unit of the line item in minor units. Cannot be a negative number.
1518 1519 1520 |
# File 'lib/stripe/resources/payment_intent.rb', line 1518 def unit_amount @unit_amount end |