Class: Stripe::PaymentIntent::PaymentMethodOptions::Paypal::LineItem

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#categoryObject (readonly)

Type of the line item.



1475
1476
1477
# File 'lib/stripe/resources/payment_intent.rb', line 1475

def category
  @category
end

#descriptionObject (readonly)

Description of the line item.



1477
1478
1479
# File 'lib/stripe/resources/payment_intent.rb', line 1477

def description
  @description
end

#nameObject (readonly)

Descriptive name of the line item.



1479
1480
1481
# File 'lib/stripe/resources/payment_intent.rb', line 1479

def name
  @name
end

#quantityObject (readonly)

Quantity of the line item. Cannot be a negative number.



1481
1482
1483
# File 'lib/stripe/resources/payment_intent.rb', line 1481

def quantity
  @quantity
end

#skuObject (readonly)

Client facing stock keeping unit, article number or similar.



1483
1484
1485
# File 'lib/stripe/resources/payment_intent.rb', line 1483

def sku
  @sku
end

#sold_byObject (readonly)

The Stripe account ID of the connected account that sells the item. This is only needed when using [Separate Charges and Transfers](docs.stripe.com/connect/separate-charges-and-transfers).



1485
1486
1487
# File 'lib/stripe/resources/payment_intent.rb', line 1485

def sold_by
  @sold_by
end

#taxObject (readonly)

Attribute for field tax



1487
1488
1489
# File 'lib/stripe/resources/payment_intent.rb', line 1487

def tax
  @tax
end

#unit_amountObject (readonly)

Price for a single unit of the line item in minor units. Cannot be a negative number.



1489
1490
1491
# File 'lib/stripe/resources/payment_intent.rb', line 1489

def unit_amount
  @unit_amount
end