Class: Stripe::PaymentIntent::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Tax
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#category ⇒ Object
readonly
Type of the line item.
-
#description ⇒ Object
readonly
Description of the line item.
-
#name ⇒ Object
readonly
Descriptive name of the line item.
-
#quantity ⇒ Object
readonly
Quantity of the line item.
-
#sku ⇒ Object
readonly
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
readonly
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
readonly
Attribute for field tax.
-
#unit_amount ⇒ Object
readonly
Price for a single unit of the line item in minor units.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#category ⇒ Object (readonly)
Type of the line item.
1444 1445 1446 |
# File 'lib/stripe/resources/payment_intent.rb', line 1444 def category @category end |
#description ⇒ Object (readonly)
Description of the line item.
1446 1447 1448 |
# File 'lib/stripe/resources/payment_intent.rb', line 1446 def description @description end |
#name ⇒ Object (readonly)
Descriptive name of the line item.
1448 1449 1450 |
# File 'lib/stripe/resources/payment_intent.rb', line 1448 def name @name end |
#quantity ⇒ Object (readonly)
Quantity of the line item. Cannot be a negative number.
1450 1451 1452 |
# File 'lib/stripe/resources/payment_intent.rb', line 1450 def quantity @quantity end |
#sku ⇒ Object (readonly)
Client facing stock keeping unit, article number or similar.
1452 1453 1454 |
# File 'lib/stripe/resources/payment_intent.rb', line 1452 def sku @sku end |
#sold_by ⇒ Object (readonly)
The Stripe account ID of the connected account that sells the item. This is only needed when using [Separate Charges and Transfers](docs.stripe.com/connect/separate-charges-and-transfers).
1454 1455 1456 |
# File 'lib/stripe/resources/payment_intent.rb', line 1454 def sold_by @sold_by end |
#tax ⇒ Object (readonly)
Attribute for field tax
1456 1457 1458 |
# File 'lib/stripe/resources/payment_intent.rb', line 1456 def tax @tax end |
#unit_amount ⇒ Object (readonly)
Price for a single unit of the line item in minor units. Cannot be a negative number.
1458 1459 1460 |
# File 'lib/stripe/resources/payment_intent.rb', line 1458 def unit_amount @unit_amount end |