Class: Stripe::PaymentIntent::PaymentMethodOptions::Payto::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount that will be collected. It is required when amount_type is fixed.



3663
3664
3665
# File 'lib/stripe/resources/payment_intent.rb', line 3663

def amount
  @amount
end

#amount_typeObject (readonly)

The type of amount that will be collected. The amount charged must be exact or up to the value of amount param for fixed or maximum type respectively. Defaults to maximum.



3665
3666
3667
# File 'lib/stripe/resources/payment_intent.rb', line 3665

def amount_type
  @amount_type
end

#end_dateObject (readonly)

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



3667
3668
3669
# File 'lib/stripe/resources/payment_intent.rb', line 3667

def end_date
  @end_date
end

#payment_scheduleObject (readonly)

The periodicity at which payments will be collected. Defaults to adhoc.



3669
3670
3671
# File 'lib/stripe/resources/payment_intent.rb', line 3669

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject (readonly)

The number of payments that will be made during a payment period. Defaults to 1 except for when payment_schedule is adhoc. In that case, it defaults to no limit.



3671
3672
3673
# File 'lib/stripe/resources/payment_intent.rb', line 3671

def payments_per_period
  @payments_per_period
end

#purposeObject (readonly)

The purpose for which payments are made. Has a default value based on your merchant category code.



3673
3674
3675
# File 'lib/stripe/resources/payment_intent.rb', line 3673

def purpose
  @purpose
end

Class Method Details

.field_remappingsObject



3679
3680
3681
# File 'lib/stripe/resources/payment_intent.rb', line 3679

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3675
3676
3677
# File 'lib/stripe/resources/payment_intent.rb', line 3675

def self.inner_class_types
  @inner_class_types = {}
end