Class: Stripe::PaymentIntent::PaymentMethodOptions::Payto::MandateOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Payto::MandateOptions
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount that will be collected.
-
#amount_type ⇒ Object
readonly
The type of amount that will be collected.
-
#end_date ⇒ Object
readonly
Date, in YYYY-MM-DD format, after which payments will not be collected.
-
#payment_schedule ⇒ Object
readonly
The periodicity at which payments will be collected.
-
#payments_per_period ⇒ Object
readonly
The number of payments that will be made during a payment period.
-
#purpose ⇒ Object
readonly
The purpose for which payments are made.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount that will be collected. It is required when amount_type is fixed.
2366 2367 2368 |
# File 'lib/stripe/resources/payment_intent.rb', line 2366 def amount @amount end |
#amount_type ⇒ Object (readonly)
The type of amount that will be collected. The amount charged must be exact or up to the value of amount param for fixed or maximum type respectively. Defaults to maximum.
2368 2369 2370 |
# File 'lib/stripe/resources/payment_intent.rb', line 2368 def amount_type @amount_type end |
#end_date ⇒ Object (readonly)
Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.
2370 2371 2372 |
# File 'lib/stripe/resources/payment_intent.rb', line 2370 def end_date @end_date end |
#payment_schedule ⇒ Object (readonly)
The periodicity at which payments will be collected. Defaults to adhoc.
2372 2373 2374 |
# File 'lib/stripe/resources/payment_intent.rb', line 2372 def payment_schedule @payment_schedule end |
#payments_per_period ⇒ Object (readonly)
The number of payments that will be made during a payment period. Defaults to 1 except for when payment_schedule is adhoc. In that case, it defaults to no limit.
2374 2375 2376 |
# File 'lib/stripe/resources/payment_intent.rb', line 2374 def payments_per_period @payments_per_period end |
#purpose ⇒ Object (readonly)
The purpose for which payments are made. Has a default value based on your merchant category code.
2376 2377 2378 |
# File 'lib/stripe/resources/payment_intent.rb', line 2376 def purpose @purpose end |
Class Method Details
.field_remappings ⇒ Object
2382 2383 2384 |
# File 'lib/stripe/resources/payment_intent.rb', line 2382 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2378 2379 2380 |
# File 'lib/stripe/resources/payment_intent.rb', line 2378 def self.inner_class_types @inner_class_types = {} end |