Class: Stripe::PaymentIntent::PaymentMethodOptions::Pix
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Pix
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: MandateOptions
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_includes_iof ⇒ Object
readonly
Determines if the amount includes the IOF tax.
-
#expires_after_seconds ⇒ Object
readonly
The number of seconds (between 10 and 1209600) after which Pix payment will expire.
-
#expires_at ⇒ Object
readonly
The timestamp at which the Pix expires.
-
#mandate_options ⇒ Object
readonly
Attribute for field mandate_options.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_includes_iof ⇒ Object (readonly)
Determines if the amount includes the IOF tax.
3731 3732 3733 |
# File 'lib/stripe/resources/payment_intent.rb', line 3731 def amount_includes_iof @amount_includes_iof end |
#expires_after_seconds ⇒ Object (readonly)
The number of seconds (between 10 and 1209600) after which Pix payment will expire.
3733 3734 3735 |
# File 'lib/stripe/resources/payment_intent.rb', line 3733 def expires_after_seconds @expires_after_seconds end |
#expires_at ⇒ Object (readonly)
The timestamp at which the Pix expires.
3735 3736 3737 |
# File 'lib/stripe/resources/payment_intent.rb', line 3735 def expires_at @expires_at end |
#mandate_options ⇒ Object (readonly)
Attribute for field mandate_options
3737 3738 3739 |
# File 'lib/stripe/resources/payment_intent.rb', line 3737 def @mandate_options end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
3745 3746 3747 |
# File 'lib/stripe/resources/payment_intent.rb', line 3745 def setup_future_usage @setup_future_usage end |
Class Method Details
.field_remappings ⇒ Object
3751 3752 3753 |
# File 'lib/stripe/resources/payment_intent.rb', line 3751 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3747 3748 3749 |
# File 'lib/stripe/resources/payment_intent.rb', line 3747 def self.inner_class_types @inner_class_types = { mandate_options: MandateOptions } end |