Class: Stripe::PaymentIntent::PaymentMethodOptions::Pix

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_includes_iofObject (readonly)

Determines if the amount includes the IOF tax.



2268
2269
2270
# File 'lib/stripe/resources/payment_intent.rb', line 2268

def amount_includes_iof
  @amount_includes_iof
end

#expires_after_secondsObject (readonly)

The number of seconds (between 10 and 1209600) after which Pix payment will expire.



2270
2271
2272
# File 'lib/stripe/resources/payment_intent.rb', line 2270

def expires_after_seconds
  @expires_after_seconds
end

#expires_atObject (readonly)

The timestamp at which the Pix expires.



2272
2273
2274
# File 'lib/stripe/resources/payment_intent.rb', line 2272

def expires_at
  @expires_at
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).



2280
2281
2282
# File 'lib/stripe/resources/payment_intent.rb', line 2280

def setup_future_usage
  @setup_future_usage
end

Class Method Details

.field_remappingsObject



2286
2287
2288
# File 'lib/stripe/resources/payment_intent.rb', line 2286

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2282
2283
2284
# File 'lib/stripe/resources/payment_intent.rb', line 2282

def self.inner_class_types
  @inner_class_types = {}
end