Class: Stripe::PaymentIntent::PaymentMethodOptions::Pix
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Pix
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: MandateOptions
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_includes_iof ⇒ Object
readonly
Determines if the amount includes the IOF tax.
-
#expires_after_seconds ⇒ Object
readonly
The number of seconds (between 10 and 1209600) after which Pix payment will expire.
-
#expires_at ⇒ Object
readonly
The timestamp at which the Pix expires.
-
#mandate_options ⇒ Object
readonly
Attribute for field mandate_options.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_includes_iof ⇒ Object (readonly)
Determines if the amount includes the IOF tax.
1622 1623 1624 |
# File 'lib/stripe/resources/payment_intent.rb', line 1622 def amount_includes_iof @amount_includes_iof end |
#expires_after_seconds ⇒ Object (readonly)
The number of seconds (between 10 and 1209600) after which Pix payment will expire.
1624 1625 1626 |
# File 'lib/stripe/resources/payment_intent.rb', line 1624 def expires_after_seconds @expires_after_seconds end |
#expires_at ⇒ Object (readonly)
The timestamp at which the Pix expires.
1626 1627 1628 |
# File 'lib/stripe/resources/payment_intent.rb', line 1626 def expires_at @expires_at end |
#mandate_options ⇒ Object (readonly)
Attribute for field mandate_options
1628 1629 1630 |
# File 'lib/stripe/resources/payment_intent.rb', line 1628 def @mandate_options end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
1636 1637 1638 |
# File 'lib/stripe/resources/payment_intent.rb', line 1636 def setup_future_usage @setup_future_usage end |