Class: Stripe::PaymentIntent::PaymentMethodOptions::Pix::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments.



3698
3699
3700
# File 'lib/stripe/resources/payment_intent.rb', line 3698

def amount
  @amount
end

#amount_includes_iofObject (readonly)

Determines if the amount includes the IOF tax.



3700
3701
3702
# File 'lib/stripe/resources/payment_intent.rb', line 3700

def amount_includes_iof
  @amount_includes_iof
end

#amount_typeObject (readonly)

Type of amount.



3702
3703
3704
# File 'lib/stripe/resources/payment_intent.rb', line 3702

def amount_type
  @amount_type
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.



3704
3705
3706
# File 'lib/stripe/resources/payment_intent.rb', line 3704

def currency
  @currency
end

#end_dateObject (readonly)

Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.



3706
3707
3708
# File 'lib/stripe/resources/payment_intent.rb', line 3706

def end_date
  @end_date
end

#payment_scheduleObject (readonly)

Schedule at which the future payments will be charged.



3708
3709
3710
# File 'lib/stripe/resources/payment_intent.rb', line 3708

def payment_schedule
  @payment_schedule
end

#referenceObject (readonly)

Subscription name displayed to buyers in their bank app.



3710
3711
3712
# File 'lib/stripe/resources/payment_intent.rb', line 3710

def reference
  @reference
end

#start_dateObject (readonly)

Start date of the mandate, in ‘YYYY-MM-DD`.



3712
3713
3714
# File 'lib/stripe/resources/payment_intent.rb', line 3712

def start_date
  @start_date
end

Class Method Details

.field_remappingsObject



3718
3719
3720
# File 'lib/stripe/resources/payment_intent.rb', line 3718

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3714
3715
3716
# File 'lib/stripe/resources/payment_intent.rb', line 3714

def self.inner_class_types
  @inner_class_types = {}
end