Class: Stripe::PaymentIntent::PaymentMethodOptions::Pix::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments.



2327
2328
2329
# File 'lib/stripe/resources/payment_intent.rb', line 2327

def amount
  @amount
end

#amount_includes_iofObject (readonly)

Determines if the amount includes the IOF tax.



2329
2330
2331
# File 'lib/stripe/resources/payment_intent.rb', line 2329

def amount_includes_iof
  @amount_includes_iof
end

#amount_typeObject (readonly)

Type of amount.



2331
2332
2333
# File 'lib/stripe/resources/payment_intent.rb', line 2331

def amount_type
  @amount_type
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.



2333
2334
2335
# File 'lib/stripe/resources/payment_intent.rb', line 2333

def currency
  @currency
end

#end_dateObject (readonly)

Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.



2335
2336
2337
# File 'lib/stripe/resources/payment_intent.rb', line 2335

def end_date
  @end_date
end

#payment_scheduleObject (readonly)

Schedule at which the future payments will be charged.



2337
2338
2339
# File 'lib/stripe/resources/payment_intent.rb', line 2337

def payment_schedule
  @payment_schedule
end

#referenceObject (readonly)

Subscription name displayed to buyers in their bank app.



2339
2340
2341
# File 'lib/stripe/resources/payment_intent.rb', line 2339

def reference
  @reference
end

#start_dateObject (readonly)

Start date of the mandate, in ‘YYYY-MM-DD`.



2341
2342
2343
# File 'lib/stripe/resources/payment_intent.rb', line 2341

def start_date
  @start_date
end

Class Method Details

.field_remappingsObject



2347
2348
2349
# File 'lib/stripe/resources/payment_intent.rb', line 2347

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2343
2344
2345
# File 'lib/stripe/resources/payment_intent.rb', line 2343

def self.inner_class_types
  @inner_class_types = {}
end