Class: Stripe::PaymentIntent::PaymentMethodOptions::Pix::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments.



4117
4118
4119
# File 'lib/stripe/resources/payment_intent.rb', line 4117

def amount
  @amount
end

#amount_includes_iofObject (readonly)

Determines if the amount includes the IOF tax.



4119
4120
4121
# File 'lib/stripe/resources/payment_intent.rb', line 4119

def amount_includes_iof
  @amount_includes_iof
end

#amount_typeObject (readonly)

Type of amount.



4121
4122
4123
# File 'lib/stripe/resources/payment_intent.rb', line 4121

def amount_type
  @amount_type
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.



4123
4124
4125
# File 'lib/stripe/resources/payment_intent.rb', line 4123

def currency
  @currency
end

#end_dateObject (readonly)

Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.



4125
4126
4127
# File 'lib/stripe/resources/payment_intent.rb', line 4125

def end_date
  @end_date
end

#payment_scheduleObject (readonly)

Schedule at which the future payments will be charged.



4127
4128
4129
# File 'lib/stripe/resources/payment_intent.rb', line 4127

def payment_schedule
  @payment_schedule
end

#referenceObject (readonly)

Subscription name displayed to buyers in their bank app.



4129
4130
4131
# File 'lib/stripe/resources/payment_intent.rb', line 4129

def reference
  @reference
end

#start_dateObject (readonly)

Start date of the mandate, in ‘YYYY-MM-DD`.



4131
4132
4133
# File 'lib/stripe/resources/payment_intent.rb', line 4131

def start_date
  @start_date
end

Class Method Details

.field_remappingsObject



4137
4138
4139
# File 'lib/stripe/resources/payment_intent.rb', line 4137

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4133
4134
4135
# File 'lib/stripe/resources/payment_intent.rb', line 4133

def self.inner_class_types
  @inner_class_types = {}
end