Class: Stripe::PaymentIntent::PaymentMethodOptions::Pix::MandateOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Pix::MandateOptions
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount to be charged for future payments.
-
#amount_includes_iof ⇒ Object
readonly
Determines if the amount includes the IOF tax.
-
#amount_type ⇒ Object
readonly
Type of amount.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#end_date ⇒ Object
readonly
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.
-
#payment_schedule ⇒ Object
readonly
Schedule at which the future payments will be charged.
-
#reference ⇒ Object
readonly
Subscription name displayed to buyers in their bank app.
-
#start_date ⇒ Object
readonly
Start date of the mandate, in ‘YYYY-MM-DD`.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount to be charged for future payments.
4095 4096 4097 |
# File 'lib/stripe/resources/payment_intent.rb', line 4095 def amount @amount end |
#amount_includes_iof ⇒ Object (readonly)
Determines if the amount includes the IOF tax.
4097 4098 4099 |
# File 'lib/stripe/resources/payment_intent.rb', line 4097 def amount_includes_iof @amount_includes_iof end |
#amount_type ⇒ Object (readonly)
Type of amount.
4099 4100 4101 |
# File 'lib/stripe/resources/payment_intent.rb', line 4099 def amount_type @amount_type end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
4101 4102 4103 |
# File 'lib/stripe/resources/payment_intent.rb', line 4101 def currency @currency end |
#end_date ⇒ Object (readonly)
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.
4103 4104 4105 |
# File 'lib/stripe/resources/payment_intent.rb', line 4103 def end_date @end_date end |
#payment_schedule ⇒ Object (readonly)
Schedule at which the future payments will be charged.
4105 4106 4107 |
# File 'lib/stripe/resources/payment_intent.rb', line 4105 def payment_schedule @payment_schedule end |
#reference ⇒ Object (readonly)
Subscription name displayed to buyers in their bank app.
4107 4108 4109 |
# File 'lib/stripe/resources/payment_intent.rb', line 4107 def reference @reference end |
#start_date ⇒ Object (readonly)
Start date of the mandate, in ‘YYYY-MM-DD`.
4109 4110 4111 |
# File 'lib/stripe/resources/payment_intent.rb', line 4109 def start_date @start_date end |
Class Method Details
.field_remappings ⇒ Object
4115 4116 4117 |
# File 'lib/stripe/resources/payment_intent.rb', line 4115 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
4111 4112 4113 |
# File 'lib/stripe/resources/payment_intent.rb', line 4111 def self.inner_class_types @inner_class_types = {} end |