Class: Stripe::PaymentIntent::PaymentMethodOptions::Pix::MandateOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Pix::MandateOptions
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount to be charged for future payments.
-
#amount_includes_iof ⇒ Object
readonly
Determines if the amount includes the IOF tax.
-
#amount_type ⇒ Object
readonly
Type of amount.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#end_date ⇒ Object
readonly
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.
-
#payment_schedule ⇒ Object
readonly
Schedule at which the future payments will be charged.
-
#reference ⇒ Object
readonly
Subscription name displayed to buyers in their bank app.
-
#start_date ⇒ Object
readonly
Start date of the mandate, in ‘YYYY-MM-DD`.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount to be charged for future payments.
3675 3676 3677 |
# File 'lib/stripe/resources/payment_intent.rb', line 3675 def amount @amount end |
#amount_includes_iof ⇒ Object (readonly)
Determines if the amount includes the IOF tax.
3677 3678 3679 |
# File 'lib/stripe/resources/payment_intent.rb', line 3677 def amount_includes_iof @amount_includes_iof end |
#amount_type ⇒ Object (readonly)
Type of amount.
3679 3680 3681 |
# File 'lib/stripe/resources/payment_intent.rb', line 3679 def amount_type @amount_type end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
3681 3682 3683 |
# File 'lib/stripe/resources/payment_intent.rb', line 3681 def currency @currency end |
#end_date ⇒ Object (readonly)
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.
3683 3684 3685 |
# File 'lib/stripe/resources/payment_intent.rb', line 3683 def end_date @end_date end |
#payment_schedule ⇒ Object (readonly)
Schedule at which the future payments will be charged.
3685 3686 3687 |
# File 'lib/stripe/resources/payment_intent.rb', line 3685 def payment_schedule @payment_schedule end |
#reference ⇒ Object (readonly)
Subscription name displayed to buyers in their bank app.
3687 3688 3689 |
# File 'lib/stripe/resources/payment_intent.rb', line 3687 def reference @reference end |
#start_date ⇒ Object (readonly)
Start date of the mandate, in ‘YYYY-MM-DD`.
3689 3690 3691 |
# File 'lib/stripe/resources/payment_intent.rb', line 3689 def start_date @start_date end |
Class Method Details
.field_remappings ⇒ Object
3695 3696 3697 |
# File 'lib/stripe/resources/payment_intent.rb', line 3695 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3691 3692 3693 |
# File 'lib/stripe/resources/payment_intent.rb', line 3691 def self.inner_class_types @inner_class_types = {} end |