Class: Stripe::PaymentIntent::PaymentMethodOptions::Pix::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments.



3922
3923
3924
# File 'lib/stripe/resources/payment_intent.rb', line 3922

def amount
  @amount
end

#amount_includes_iofObject (readonly)

Determines if the amount includes the IOF tax.



3924
3925
3926
# File 'lib/stripe/resources/payment_intent.rb', line 3924

def amount_includes_iof
  @amount_includes_iof
end

#amount_typeObject (readonly)

Type of amount.



3926
3927
3928
# File 'lib/stripe/resources/payment_intent.rb', line 3926

def amount_type
  @amount_type
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.



3928
3929
3930
# File 'lib/stripe/resources/payment_intent.rb', line 3928

def currency
  @currency
end

#end_dateObject (readonly)

Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.



3930
3931
3932
# File 'lib/stripe/resources/payment_intent.rb', line 3930

def end_date
  @end_date
end

#payment_scheduleObject (readonly)

Schedule at which the future payments will be charged.



3932
3933
3934
# File 'lib/stripe/resources/payment_intent.rb', line 3932

def payment_schedule
  @payment_schedule
end

#referenceObject (readonly)

Subscription name displayed to buyers in their bank app.



3934
3935
3936
# File 'lib/stripe/resources/payment_intent.rb', line 3934

def reference
  @reference
end

#start_dateObject (readonly)

Start date of the mandate, in ‘YYYY-MM-DD`.



3936
3937
3938
# File 'lib/stripe/resources/payment_intent.rb', line 3936

def start_date
  @start_date
end

Class Method Details

.field_remappingsObject



3942
3943
3944
# File 'lib/stripe/resources/payment_intent.rb', line 3942

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3938
3939
3940
# File 'lib/stripe/resources/payment_intent.rb', line 3938

def self.inner_class_types
  @inner_class_types = {}
end