Class: Stripe::PaymentIntent::PaymentMethodOptions::Pix::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments.



4080
4081
4082
# File 'lib/stripe/resources/payment_intent.rb', line 4080

def amount
  @amount
end

#amount_includes_iofObject (readonly)

Determines if the amount includes the IOF tax.



4082
4083
4084
# File 'lib/stripe/resources/payment_intent.rb', line 4082

def amount_includes_iof
  @amount_includes_iof
end

#amount_typeObject (readonly)

Type of amount.



4084
4085
4086
# File 'lib/stripe/resources/payment_intent.rb', line 4084

def amount_type
  @amount_type
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.



4086
4087
4088
# File 'lib/stripe/resources/payment_intent.rb', line 4086

def currency
  @currency
end

#end_dateObject (readonly)

Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.



4088
4089
4090
# File 'lib/stripe/resources/payment_intent.rb', line 4088

def end_date
  @end_date
end

#payment_scheduleObject (readonly)

Schedule at which the future payments will be charged.



4090
4091
4092
# File 'lib/stripe/resources/payment_intent.rb', line 4090

def payment_schedule
  @payment_schedule
end

#referenceObject (readonly)

Subscription name displayed to buyers in their bank app.



4092
4093
4094
# File 'lib/stripe/resources/payment_intent.rb', line 4092

def reference
  @reference
end

#start_dateObject (readonly)

Start date of the mandate, in ‘YYYY-MM-DD`.



4094
4095
4096
# File 'lib/stripe/resources/payment_intent.rb', line 4094

def start_date
  @start_date
end

Class Method Details

.field_remappingsObject



4100
4101
4102
# File 'lib/stripe/resources/payment_intent.rb', line 4100

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4096
4097
4098
# File 'lib/stripe/resources/payment_intent.rb', line 4096

def self.inner_class_types
  @inner_class_types = {}
end