Class: Stripe::PaymentIntent::PaymentMethodOptions::Pix::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments.



3639
3640
3641
# File 'lib/stripe/resources/payment_intent.rb', line 3639

def amount
  @amount
end

#amount_includes_iofObject (readonly)

Determines if the amount includes the IOF tax.



3641
3642
3643
# File 'lib/stripe/resources/payment_intent.rb', line 3641

def amount_includes_iof
  @amount_includes_iof
end

#amount_typeObject (readonly)

Type of amount.



3643
3644
3645
# File 'lib/stripe/resources/payment_intent.rb', line 3643

def amount_type
  @amount_type
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.



3645
3646
3647
# File 'lib/stripe/resources/payment_intent.rb', line 3645

def currency
  @currency
end

#end_dateObject (readonly)

Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.



3647
3648
3649
# File 'lib/stripe/resources/payment_intent.rb', line 3647

def end_date
  @end_date
end

#payment_scheduleObject (readonly)

Schedule at which the future payments will be charged.



3649
3650
3651
# File 'lib/stripe/resources/payment_intent.rb', line 3649

def payment_schedule
  @payment_schedule
end

#referenceObject (readonly)

Subscription name displayed to buyers in their bank app.



3651
3652
3653
# File 'lib/stripe/resources/payment_intent.rb', line 3651

def reference
  @reference
end

#start_dateObject (readonly)

Start date of the mandate, in ‘YYYY-MM-DD`.



3653
3654
3655
# File 'lib/stripe/resources/payment_intent.rb', line 3653

def start_date
  @start_date
end

Class Method Details

.field_remappingsObject



3659
3660
3661
# File 'lib/stripe/resources/payment_intent.rb', line 3659

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3655
3656
3657
# File 'lib/stripe/resources/payment_intent.rb', line 3655

def self.inner_class_types
  @inner_class_types = {}
end