Class: Stripe::PaymentIntent::PaymentMethodOptions::Pix::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments.



3622
3623
3624
# File 'lib/stripe/resources/payment_intent.rb', line 3622

def amount
  @amount
end

#amount_includes_iofObject (readonly)

Determines if the amount includes the IOF tax.



3624
3625
3626
# File 'lib/stripe/resources/payment_intent.rb', line 3624

def amount_includes_iof
  @amount_includes_iof
end

#amount_typeObject (readonly)

Type of amount.



3626
3627
3628
# File 'lib/stripe/resources/payment_intent.rb', line 3626

def amount_type
  @amount_type
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.



3628
3629
3630
# File 'lib/stripe/resources/payment_intent.rb', line 3628

def currency
  @currency
end

#end_dateObject (readonly)

Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.



3630
3631
3632
# File 'lib/stripe/resources/payment_intent.rb', line 3630

def end_date
  @end_date
end

#payment_scheduleObject (readonly)

Schedule at which the future payments will be charged.



3632
3633
3634
# File 'lib/stripe/resources/payment_intent.rb', line 3632

def payment_schedule
  @payment_schedule
end

#referenceObject (readonly)

Subscription name displayed to buyers in their bank app.



3634
3635
3636
# File 'lib/stripe/resources/payment_intent.rb', line 3634

def reference
  @reference
end

#start_dateObject (readonly)

Start date of the mandate, in ‘YYYY-MM-DD`.



3636
3637
3638
# File 'lib/stripe/resources/payment_intent.rb', line 3636

def start_date
  @start_date
end

Class Method Details

.field_remappingsObject



3642
3643
3644
# File 'lib/stripe/resources/payment_intent.rb', line 3642

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3638
3639
3640
# File 'lib/stripe/resources/payment_intent.rb', line 3638

def self.inner_class_types
  @inner_class_types = {}
end