Class: Stripe::PaymentIntent::PaymentMethodOptions::Pix::MandateOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::Pix::MandateOptions
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount to be charged for future payments.
-
#amount_includes_iof ⇒ Object
readonly
Determines if the amount includes the IOF tax.
-
#amount_type ⇒ Object
readonly
Type of amount.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#end_date ⇒ Object
readonly
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.
-
#payment_schedule ⇒ Object
readonly
Schedule at which the future payments will be charged.
-
#reference ⇒ Object
readonly
Subscription name displayed to buyers in their bank app.
-
#start_date ⇒ Object
readonly
Start date of the mandate, in ‘YYYY-MM-DD`.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount to be charged for future payments.
2784 2785 2786 |
# File 'lib/stripe/resources/payment_intent.rb', line 2784 def amount @amount end |
#amount_includes_iof ⇒ Object (readonly)
Determines if the amount includes the IOF tax.
2786 2787 2788 |
# File 'lib/stripe/resources/payment_intent.rb', line 2786 def amount_includes_iof @amount_includes_iof end |
#amount_type ⇒ Object (readonly)
Type of amount.
2788 2789 2790 |
# File 'lib/stripe/resources/payment_intent.rb', line 2788 def amount_type @amount_type end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
2790 2791 2792 |
# File 'lib/stripe/resources/payment_intent.rb', line 2790 def currency @currency end |
#end_date ⇒ Object (readonly)
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.
2792 2793 2794 |
# File 'lib/stripe/resources/payment_intent.rb', line 2792 def end_date @end_date end |
#payment_schedule ⇒ Object (readonly)
Schedule at which the future payments will be charged.
2794 2795 2796 |
# File 'lib/stripe/resources/payment_intent.rb', line 2794 def payment_schedule @payment_schedule end |
#reference ⇒ Object (readonly)
Subscription name displayed to buyers in their bank app.
2796 2797 2798 |
# File 'lib/stripe/resources/payment_intent.rb', line 2796 def reference @reference end |
#start_date ⇒ Object (readonly)
Start date of the mandate, in ‘YYYY-MM-DD`.
2798 2799 2800 |
# File 'lib/stripe/resources/payment_intent.rb', line 2798 def start_date @start_date end |
Class Method Details
.field_remappings ⇒ Object
2804 2805 2806 |
# File 'lib/stripe/resources/payment_intent.rb', line 2804 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2800 2801 2802 |
# File 'lib/stripe/resources/payment_intent.rb', line 2800 def self.inner_class_types @inner_class_types = {} end |