Class: Stripe::PaymentIntent::PaymentMethodOptions::Pix::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments.



2747
2748
2749
# File 'lib/stripe/resources/payment_intent.rb', line 2747

def amount
  @amount
end

#amount_includes_iofObject (readonly)

Determines if the amount includes the IOF tax.



2749
2750
2751
# File 'lib/stripe/resources/payment_intent.rb', line 2749

def amount_includes_iof
  @amount_includes_iof
end

#amount_typeObject (readonly)

Type of amount.



2751
2752
2753
# File 'lib/stripe/resources/payment_intent.rb', line 2751

def amount_type
  @amount_type
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.



2753
2754
2755
# File 'lib/stripe/resources/payment_intent.rb', line 2753

def currency
  @currency
end

#end_dateObject (readonly)

Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.



2755
2756
2757
# File 'lib/stripe/resources/payment_intent.rb', line 2755

def end_date
  @end_date
end

#payment_scheduleObject (readonly)

Schedule at which the future payments will be charged.



2757
2758
2759
# File 'lib/stripe/resources/payment_intent.rb', line 2757

def payment_schedule
  @payment_schedule
end

#referenceObject (readonly)

Subscription name displayed to buyers in their bank app.



2759
2760
2761
# File 'lib/stripe/resources/payment_intent.rb', line 2759

def reference
  @reference
end

#start_dateObject (readonly)

Start date of the mandate, in ‘YYYY-MM-DD`.



2761
2762
2763
# File 'lib/stripe/resources/payment_intent.rb', line 2761

def start_date
  @start_date
end

Class Method Details

.field_remappingsObject



2767
2768
2769
# File 'lib/stripe/resources/payment_intent.rb', line 2767

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2763
2764
2765
# File 'lib/stripe/resources/payment_intent.rb', line 2763

def self.inner_class_types
  @inner_class_types = {}
end