Class: Stripe::PaymentIntent::PaymentMethodOptions::Pix::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments.



2722
2723
2724
# File 'lib/stripe/resources/payment_intent.rb', line 2722

def amount
  @amount
end

#amount_includes_iofObject (readonly)

Determines if the amount includes the IOF tax.



2724
2725
2726
# File 'lib/stripe/resources/payment_intent.rb', line 2724

def amount_includes_iof
  @amount_includes_iof
end

#amount_typeObject (readonly)

Type of amount.



2726
2727
2728
# File 'lib/stripe/resources/payment_intent.rb', line 2726

def amount_type
  @amount_type
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.



2728
2729
2730
# File 'lib/stripe/resources/payment_intent.rb', line 2728

def currency
  @currency
end

#end_dateObject (readonly)

Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.



2730
2731
2732
# File 'lib/stripe/resources/payment_intent.rb', line 2730

def end_date
  @end_date
end

#payment_scheduleObject (readonly)

Schedule at which the future payments will be charged.



2732
2733
2734
# File 'lib/stripe/resources/payment_intent.rb', line 2732

def payment_schedule
  @payment_schedule
end

#referenceObject (readonly)

Subscription name displayed to buyers in their bank app.



2734
2735
2736
# File 'lib/stripe/resources/payment_intent.rb', line 2734

def reference
  @reference
end

#start_dateObject (readonly)

Start date of the mandate, in ‘YYYY-MM-DD`.



2736
2737
2738
# File 'lib/stripe/resources/payment_intent.rb', line 2736

def start_date
  @start_date
end

Class Method Details

.field_remappingsObject



2742
2743
2744
# File 'lib/stripe/resources/payment_intent.rb', line 2742

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2738
2739
2740
# File 'lib/stripe/resources/payment_intent.rb', line 2738

def self.inner_class_types
  @inner_class_types = {}
end