Class: Stripe::PaymentIntent::PaymentMethodOptions::UsBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::UsBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: FinancialConnections, MandateOptions
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#financial_connections ⇒ Object
readonly
Attribute for field financial_connections.
-
#mandate_options ⇒ Object
readonly
Attribute for field mandate_options.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent's payment method.
-
#target_date ⇒ Object
readonly
Controls when Stripe will attempt to debit the funds from the customer's account.
-
#transaction_purpose ⇒ Object
readonly
The purpose of the transaction.
-
#verification_method ⇒ Object
readonly
Bank account verification method.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#financial_connections ⇒ Object (readonly)
Attribute for field financial_connections
4116 4117 4118 |
# File 'lib/stripe/resources/payment_intent.rb', line 4116 def financial_connections @financial_connections end |
#mandate_options ⇒ Object (readonly)
Attribute for field mandate_options
4118 4119 4120 |
# File 'lib/stripe/resources/payment_intent.rb', line 4118 def @mandate_options end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
4126 4127 4128 |
# File 'lib/stripe/resources/payment_intent.rb', line 4126 def setup_future_usage @setup_future_usage end |
#target_date ⇒ Object (readonly)
Controls when Stripe will attempt to debit the funds from the customer's account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.
4128 4129 4130 |
# File 'lib/stripe/resources/payment_intent.rb', line 4128 def target_date @target_date end |
#transaction_purpose ⇒ Object (readonly)
The purpose of the transaction.
4130 4131 4132 |
# File 'lib/stripe/resources/payment_intent.rb', line 4130 def transaction_purpose @transaction_purpose end |
#verification_method ⇒ Object (readonly)
Bank account verification method. The default value is automatic.
4132 4133 4134 |
# File 'lib/stripe/resources/payment_intent.rb', line 4132 def verification_method @verification_method end |
Class Method Details
.field_remappings ⇒ Object
4141 4142 4143 |
# File 'lib/stripe/resources/payment_intent.rb', line 4141 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
4134 4135 4136 4137 4138 4139 |
# File 'lib/stripe/resources/payment_intent.rb', line 4134 def self.inner_class_types @inner_class_types = { financial_connections: FinancialConnections, mandate_options: MandateOptions, } end |