Class: Stripe::PaymentIntent::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Filters, ManualEntry
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#filters ⇒ Object
readonly
Attribute for field filters.
-
#manual_entry ⇒ Object
readonly
Attribute for field manual_entry.
-
#permissions ⇒ Object
readonly
The list of permissions to request.
-
#prefetch ⇒ Object
readonly
Data features requested to be retrieved upon account creation.
-
#return_url ⇒ Object
readonly
For webview integrations only.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#filters ⇒ Object (readonly)
Attribute for field filters
4003 4004 4005 |
# File 'lib/stripe/resources/payment_intent.rb', line 4003 def filters @filters end |
#manual_entry ⇒ Object (readonly)
Attribute for field manual_entry
4005 4006 4007 |
# File 'lib/stripe/resources/payment_intent.rb', line 4005 def manual_entry @manual_entry end |
#permissions ⇒ Object (readonly)
The list of permissions to request. The ‘payment_method` permission must be included.
4007 4008 4009 |
# File 'lib/stripe/resources/payment_intent.rb', line 4007 def @permissions end |
#prefetch ⇒ Object (readonly)
Data features requested to be retrieved upon account creation.
4009 4010 4011 |
# File 'lib/stripe/resources/payment_intent.rb', line 4009 def prefetch @prefetch end |
#return_url ⇒ Object (readonly)
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
4011 4012 4013 |
# File 'lib/stripe/resources/payment_intent.rb', line 4011 def return_url @return_url end |
Class Method Details
.field_remappings ⇒ Object
4017 4018 4019 |
# File 'lib/stripe/resources/payment_intent.rb', line 4017 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
4013 4014 4015 |
# File 'lib/stripe/resources/payment_intent.rb', line 4013 def self.inner_class_types @inner_class_types = { filters: Filters, manual_entry: ManualEntry } end |