Class: Stripe::PaymentIntent::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Filters
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#filters ⇒ Object
readonly
Attribute for field filters.
-
#permissions ⇒ Object
readonly
The list of permissions to request.
-
#prefetch ⇒ Object
readonly
Data features requested to be retrieved upon account creation.
-
#return_url ⇒ Object
readonly
For webview integrations only.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#filters ⇒ Object (readonly)
Attribute for field filters
2419 2420 2421 |
# File 'lib/stripe/resources/payment_intent.rb', line 2419 def filters @filters end |
#permissions ⇒ Object (readonly)
The list of permissions to request. The ‘payment_method` permission must be included.
2421 2422 2423 |
# File 'lib/stripe/resources/payment_intent.rb', line 2421 def @permissions end |
#prefetch ⇒ Object (readonly)
Data features requested to be retrieved upon account creation.
2423 2424 2425 |
# File 'lib/stripe/resources/payment_intent.rb', line 2423 def prefetch @prefetch end |
#return_url ⇒ Object (readonly)
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
2425 2426 2427 |
# File 'lib/stripe/resources/payment_intent.rb', line 2425 def return_url @return_url end |
Class Method Details
.field_remappings ⇒ Object
2431 2432 2433 |
# File 'lib/stripe/resources/payment_intent.rb', line 2431 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2427 2428 2429 |
# File 'lib/stripe/resources/payment_intent.rb', line 2427 def self.inner_class_types @inner_class_types = { filters: Filters } end |