Class: Stripe::PaymentIntent::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#filtersObject (readonly)

Attribute for field filters



1718
1719
1720
# File 'lib/stripe/resources/payment_intent.rb', line 1718

def filters
  @filters
end

#manual_entryObject (readonly)

Attribute for field manual_entry



1720
1721
1722
# File 'lib/stripe/resources/payment_intent.rb', line 1720

def manual_entry
  @manual_entry
end

#permissionsObject (readonly)

The list of permissions to request. The ‘payment_method` permission must be included.



1722
1723
1724
# File 'lib/stripe/resources/payment_intent.rb', line 1722

def permissions
  @permissions
end

#prefetchObject (readonly)

Data features requested to be retrieved upon account creation.



1724
1725
1726
# File 'lib/stripe/resources/payment_intent.rb', line 1724

def prefetch
  @prefetch
end

#return_urlObject (readonly)

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



1726
1727
1728
# File 'lib/stripe/resources/payment_intent.rb', line 1726

def return_url
  @return_url
end