Class: Stripe::PaymentIntent::PaymentMethodOptions::WechatPay
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::PaymentMethodOptions::WechatPay
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#app_id ⇒ Object
readonly
The app ID registered with WeChat Pay.
-
#client ⇒ Object
readonly
The client type that the end customer will pay from.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#app_id ⇒ Object (readonly)
The app ID registered with WeChat Pay. Only required when client is ios, android, or mini_program.
2693 2694 2695 |
# File 'lib/stripe/resources/payment_intent.rb', line 2693 def app_id @app_id end |
#client ⇒ Object (readonly)
The client type that the end customer will pay from
2695 2696 2697 |
# File 'lib/stripe/resources/payment_intent.rb', line 2695 def client @client end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
2703 2704 2705 |
# File 'lib/stripe/resources/payment_intent.rb', line 2703 def setup_future_usage @setup_future_usage end |
Class Method Details
.field_remappings ⇒ Object
2709 2710 2711 |
# File 'lib/stripe/resources/payment_intent.rb', line 2709 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2705 2706 2707 |
# File 'lib/stripe/resources/payment_intent.rb', line 2705 def self.inner_class_types @inner_class_types = {} end |