Class: Stripe::PaymentIntent::Processing::Card::CustomerNotification

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#approval_requestedObject (readonly)

Whether customer approval has been requested for this payment. For payments greater than INR 15000 or mandate amount, the customer must provide explicit approval of the payment with their bank.



4390
4391
4392
# File 'lib/stripe/resources/payment_intent.rb', line 4390

def approval_requested
  @approval_requested
end

#completes_atObject (readonly)

If customer approval is required, they need to provide approval before this time.



4392
4393
4394
# File 'lib/stripe/resources/payment_intent.rb', line 4392

def completes_at
  @completes_at
end

Class Method Details

.field_remappingsObject



4398
4399
4400
# File 'lib/stripe/resources/payment_intent.rb', line 4398

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4394
4395
4396
# File 'lib/stripe/resources/payment_intent.rb', line 4394

def self.inner_class_types
  @inner_class_types = {}
end