Class: Stripe::PaymentIntent::Processing::Card::CustomerNotification

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#approval_requestedObject (readonly)

Whether customer approval has been requested for this payment. For payments greater than INR 15000 or mandate amount, the customer must provide explicit approval of the payment with their bank.



4785
4786
4787
# File 'lib/stripe/resources/payment_intent.rb', line 4785

def approval_requested
  @approval_requested
end

#completes_atObject (readonly)

If customer approval is required, they need to provide approval before this time.



4787
4788
4789
# File 'lib/stripe/resources/payment_intent.rb', line 4787

def completes_at
  @completes_at
end

Class Method Details

.field_remappingsObject



4793
4794
4795
# File 'lib/stripe/resources/payment_intent.rb', line 4793

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4789
4790
4791
# File 'lib/stripe/resources/payment_intent.rb', line 4789

def self.inner_class_types
  @inner_class_types = {}
end