Class: Stripe::PaymentIntent::Processing::Card::CustomerNotification

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#approval_requestedObject (readonly)

Whether customer approval has been requested for this payment. For payments greater than INR 15000 or mandate amount, the customer must provide explicit approval of the payment with their bank.



4316
4317
4318
# File 'lib/stripe/resources/payment_intent.rb', line 4316

def approval_requested
  @approval_requested
end

#completes_atObject (readonly)

If customer approval is required, they need to provide approval before this time.



4318
4319
4320
# File 'lib/stripe/resources/payment_intent.rb', line 4318

def completes_at
  @completes_at
end

Class Method Details

.field_remappingsObject



4324
4325
4326
# File 'lib/stripe/resources/payment_intent.rb', line 4324

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4320
4321
4322
# File 'lib/stripe/resources/payment_intent.rb', line 4320

def self.inner_class_types
  @inner_class_types = {}
end