Class: Stripe::PaymentIntent::Processing::Card::CustomerNotification

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#approval_requestedObject (readonly)

Whether customer approval has been requested for this payment. For payments greater than INR 15000 or mandate amount, the customer must provide explicit approval of the payment with their bank.



4254
4255
4256
# File 'lib/stripe/resources/payment_intent.rb', line 4254

def approval_requested
  @approval_requested
end

#completes_atObject (readonly)

If customer approval is required, they need to provide approval before this time.



4256
4257
4258
# File 'lib/stripe/resources/payment_intent.rb', line 4256

def completes_at
  @completes_at
end

Class Method Details

.field_remappingsObject



4262
4263
4264
# File 'lib/stripe/resources/payment_intent.rb', line 4262

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4258
4259
4260
# File 'lib/stripe/resources/payment_intent.rb', line 4258

def self.inner_class_types
  @inner_class_types = {}
end