Class: Stripe::PaymentIntent::Processing::Card::CustomerNotification
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::Processing::Card::CustomerNotification
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#approval_requested ⇒ Object
readonly
Whether customer approval has been requested for this payment.
-
#completes_at ⇒ Object
readonly
If customer approval is required, they need to provide approval before this time.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#approval_requested ⇒ Object (readonly)
Whether customer approval has been requested for this payment. For payments greater than INR 15000 or mandate amount, the customer must provide explicit approval of the payment with their bank.
3416 3417 3418 |
# File 'lib/stripe/resources/payment_intent.rb', line 3416 def approval_requested @approval_requested end |
#completes_at ⇒ Object (readonly)
If customer approval is required, they need to provide approval before this time.
3418 3419 3420 |
# File 'lib/stripe/resources/payment_intent.rb', line 3418 def completes_at @completes_at end |
Class Method Details
.field_remappings ⇒ Object
3424 3425 3426 |
# File 'lib/stripe/resources/payment_intent.rb', line 3424 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3420 3421 3422 |
# File 'lib/stripe/resources/payment_intent.rb', line 3420 def self.inner_class_types @inner_class_types = {} end |