Class: Stripe::PaymentIntent::Processing::Card::CustomerNotification
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::Processing::Card::CustomerNotification
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#approval_requested ⇒ Object
readonly
Whether customer approval has been requested for this payment.
-
#completes_at ⇒ Object
readonly
If customer approval is required, they need to provide approval before this time.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#approval_requested ⇒ Object (readonly)
Whether customer approval has been requested for this payment. For payments greater than INR 15000 or mandate amount, the customer must provide explicit approval of the payment with their bank.
1945 1946 1947 |
# File 'lib/stripe/resources/payment_intent.rb', line 1945 def approval_requested @approval_requested end |
#completes_at ⇒ Object (readonly)
If customer approval is required, they need to provide approval before this time.
1947 1948 1949 |
# File 'lib/stripe/resources/payment_intent.rb', line 1947 def completes_at @completes_at end |