Class: Stripe::PaymentIntent::Processing::Card::CustomerNotification

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#approval_requestedObject (readonly)

Whether customer approval has been requested for this payment. For payments greater than INR 15000 or mandate amount, the customer must provide explicit approval of the payment with their bank.



1504
1505
1506
# File 'lib/stripe/resources/payment_intent.rb', line 1504

def approval_requested
  @approval_requested
end

#completes_atObject (readonly)

If customer approval is required, they need to provide approval before this time.



1506
1507
1508
# File 'lib/stripe/resources/payment_intent.rb', line 1506

def completes_at
  @completes_at
end