Class: Stripe::PaymentIntent::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::RetrieveParams
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#client_secret ⇒ Object
The client secret of the PaymentIntent.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
5297 5298 5299 5300 |
# File 'lib/stripe/resources/payment_intent.rb', line 5297 def initialize(client_secret: nil, expand: nil) @client_secret = client_secret @expand = end |
Instance Attribute Details
#client_secret ⇒ Object
The client secret of the PaymentIntent. We require it if you use a publishable key to retrieve the source.
5293 5294 5295 |
# File 'lib/stripe/resources/payment_intent.rb', line 5293 def client_secret @client_secret end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
5295 5296 5297 |
# File 'lib/stripe/resources/payment_intent.rb', line 5295 def @expand end |