Class: Stripe::PaymentIntent::RetrieveParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams

Returns a new instance of RetrieveParams.



6071
6072
6073
6074
# File 'lib/stripe/resources/payment_intent.rb', line 6071

def initialize(client_secret: nil, expand: nil)
  @client_secret = client_secret
  @expand = expand
end

Instance Attribute Details

#client_secretObject

The client secret of the PaymentIntent. We require it if you use a publishable key to retrieve the source.



6066
6067
6068
# File 'lib/stripe/resources/payment_intent.rb', line 6066

def client_secret
  @client_secret
end

#expandObject

Specifies which fields in the response should be expanded.



6069
6070
6071
# File 'lib/stripe/resources/payment_intent.rb', line 6069

def expand
  @expand
end