Class: Stripe::PaymentIntent::RetrieveParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams

Returns a new instance of RetrieveParams.



5248
5249
5250
5251
# File 'lib/stripe/resources/payment_intent.rb', line 5248

def initialize(client_secret: nil, expand: nil)
  @client_secret = client_secret
  @expand = expand
end

Instance Attribute Details

#client_secretObject

The client secret of the PaymentIntent. We require it if you use a publishable key to retrieve the source.



5244
5245
5246
# File 'lib/stripe/resources/payment_intent.rb', line 5244

def client_secret
  @client_secret
end

#expandObject

Specifies which fields in the response should be expanded.



5246
5247
5248
# File 'lib/stripe/resources/payment_intent.rb', line 5246

def expand
  @expand
end