Class: Stripe::PaymentIntent::SearchParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams

Returns a new instance of SearchParams.



9508
9509
9510
9511
9512
9513
# File 'lib/stripe/resources/payment_intent.rb', line 9508

def initialize(expand: nil, limit: nil, page: nil, query: nil)
  @expand = expand
  @limit = limit
  @page = page
  @query = query
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



9500
9501
9502
# File 'lib/stripe/resources/payment_intent.rb', line 9500

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



9502
9503
9504
# File 'lib/stripe/resources/payment_intent.rb', line 9502

def limit
  @limit
end

#pageObject

A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.



9504
9505
9506
# File 'lib/stripe/resources/payment_intent.rb', line 9504

def page
  @page
end

#queryObject

The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for payment intents](stripe.com/docs/search#query-fields-for-payment-intents).



9506
9507
9508
# File 'lib/stripe/resources/payment_intent.rb', line 9506

def query
  @query
end