Class: Stripe::PaymentIntent::SearchParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams

Returns a new instance of SearchParams.



9194
9195
9196
9197
9198
9199
# File 'lib/stripe/resources/payment_intent.rb', line 9194

def initialize(expand: nil, limit: nil, page: nil, query: nil)
  @expand = expand
  @limit = limit
  @page = page
  @query = query
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



9186
9187
9188
# File 'lib/stripe/resources/payment_intent.rb', line 9186

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



9188
9189
9190
# File 'lib/stripe/resources/payment_intent.rb', line 9188

def limit
  @limit
end

#pageObject

A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.



9190
9191
9192
# File 'lib/stripe/resources/payment_intent.rb', line 9190

def page
  @page
end

#queryObject

The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for payment intents](stripe.com/docs/search#query-fields-for-payment-intents).



9192
9193
9194
# File 'lib/stripe/resources/payment_intent.rb', line 9192

def query
  @query
end