Class: Stripe::PaymentIntent::SearchParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams

Returns a new instance of SearchParams.



8501
8502
8503
8504
8505
8506
# File 'lib/stripe/resources/payment_intent.rb', line 8501

def initialize(expand: nil, limit: nil, page: nil, query: nil)
  @expand = expand
  @limit = limit
  @page = page
  @query = query
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



8493
8494
8495
# File 'lib/stripe/resources/payment_intent.rb', line 8493

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



8495
8496
8497
# File 'lib/stripe/resources/payment_intent.rb', line 8495

def limit
  @limit
end

#pageObject

A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.



8497
8498
8499
# File 'lib/stripe/resources/payment_intent.rb', line 8497

def page
  @page
end

#queryObject

The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for payment intents](stripe.com/docs/search#query-fields-for-payment-intents).



8499
8500
8501
# File 'lib/stripe/resources/payment_intent.rb', line 8499

def query
  @query
end