Class: Stripe::PaymentIntent::Shipping

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

Attribute for field address



5009
5010
5011
# File 'lib/stripe/resources/payment_intent.rb', line 5009

def address
  @address
end

#carrierObject (readonly)

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



5011
5012
5013
# File 'lib/stripe/resources/payment_intent.rb', line 5011

def carrier
  @carrier
end

#nameObject (readonly)

Recipient name.



5013
5014
5015
# File 'lib/stripe/resources/payment_intent.rb', line 5013

def name
  @name
end

#phoneObject (readonly)

Recipient phone (including extension).



5015
5016
5017
# File 'lib/stripe/resources/payment_intent.rb', line 5015

def phone
  @phone
end

#tracking_numberObject (readonly)

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



5017
5018
5019
# File 'lib/stripe/resources/payment_intent.rb', line 5017

def tracking_number
  @tracking_number
end

Class Method Details

.field_remappingsObject



5023
5024
5025
# File 'lib/stripe/resources/payment_intent.rb', line 5023

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



5019
5020
5021
# File 'lib/stripe/resources/payment_intent.rb', line 5019

def self.inner_class_types
  @inner_class_types = { address: Address }
end