Class: Stripe::PaymentIntent::Shipping

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

Attribute for field address



4561
4562
4563
# File 'lib/stripe/resources/payment_intent.rb', line 4561

def address
  @address
end

#carrierObject (readonly)

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



4563
4564
4565
# File 'lib/stripe/resources/payment_intent.rb', line 4563

def carrier
  @carrier
end

#nameObject (readonly)

Recipient name.



4565
4566
4567
# File 'lib/stripe/resources/payment_intent.rb', line 4565

def name
  @name
end

#phoneObject (readonly)

Recipient phone (including extension).



4567
4568
4569
# File 'lib/stripe/resources/payment_intent.rb', line 4567

def phone
  @phone
end

#tracking_numberObject (readonly)

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



4569
4570
4571
# File 'lib/stripe/resources/payment_intent.rb', line 4569

def tracking_number
  @tracking_number
end

Class Method Details

.field_remappingsObject



4575
4576
4577
# File 'lib/stripe/resources/payment_intent.rb', line 4575

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4571
4572
4573
# File 'lib/stripe/resources/payment_intent.rb', line 4571

def self.inner_class_types
  @inner_class_types = { address: Address }
end