Class: Stripe::PaymentIntent::Shipping
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::Shipping
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
Attribute for field address.
-
#carrier ⇒ Object
readonly
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
readonly
Recipient name.
-
#phone ⇒ Object
readonly
Recipient phone (including extension).
-
#tracking_number ⇒ Object
readonly
The tracking number for a physical product, obtained from the delivery service.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
Attribute for field address
3477 3478 3479 |
# File 'lib/stripe/resources/payment_intent.rb', line 3477 def address @address end |
#carrier ⇒ Object (readonly)
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
3479 3480 3481 |
# File 'lib/stripe/resources/payment_intent.rb', line 3479 def carrier @carrier end |
#name ⇒ Object (readonly)
Recipient name.
3481 3482 3483 |
# File 'lib/stripe/resources/payment_intent.rb', line 3481 def name @name end |
#phone ⇒ Object (readonly)
Recipient phone (including extension).
3483 3484 3485 |
# File 'lib/stripe/resources/payment_intent.rb', line 3483 def phone @phone end |
#tracking_number ⇒ Object (readonly)
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
3485 3486 3487 |
# File 'lib/stripe/resources/payment_intent.rb', line 3485 def tracking_number @tracking_number end |
Class Method Details
.field_remappings ⇒ Object
3491 3492 3493 |
# File 'lib/stripe/resources/payment_intent.rb', line 3491 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3487 3488 3489 |
# File 'lib/stripe/resources/payment_intent.rb', line 3487 def self.inner_class_types @inner_class_types = { address: Address } end |