Class: Stripe::PaymentIntent::Shipping
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::Shipping
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
Attribute for field address.
-
#carrier ⇒ Object
readonly
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
readonly
Recipient name.
-
#phone ⇒ Object
readonly
Recipient phone (including extension).
-
#tracking_number ⇒ Object
readonly
The tracking number for a physical product, obtained from the delivery service.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
Attribute for field address
2682 2683 2684 |
# File 'lib/stripe/resources/payment_intent.rb', line 2682 def address @address end |
#carrier ⇒ Object (readonly)
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
2684 2685 2686 |
# File 'lib/stripe/resources/payment_intent.rb', line 2684 def carrier @carrier end |
#name ⇒ Object (readonly)
Recipient name.
2686 2687 2688 |
# File 'lib/stripe/resources/payment_intent.rb', line 2686 def name @name end |
#phone ⇒ Object (readonly)
Recipient phone (including extension).
2688 2689 2690 |
# File 'lib/stripe/resources/payment_intent.rb', line 2688 def phone @phone end |
#tracking_number ⇒ Object (readonly)
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
2690 2691 2692 |
# File 'lib/stripe/resources/payment_intent.rb', line 2690 def tracking_number @tracking_number end |
Class Method Details
.field_remappings ⇒ Object
2696 2697 2698 |
# File 'lib/stripe/resources/payment_intent.rb', line 2696 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2692 2693 2694 |
# File 'lib/stripe/resources/payment_intent.rb', line 2692 def self.inner_class_types @inner_class_types = { address: Address } end |