Class: Stripe::PaymentIntent::Shipping

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

Attribute for field address



3402
3403
3404
# File 'lib/stripe/resources/payment_intent.rb', line 3402

def address
  @address
end

#carrierObject (readonly)

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



3404
3405
3406
# File 'lib/stripe/resources/payment_intent.rb', line 3404

def carrier
  @carrier
end

#nameObject (readonly)

Recipient name.



3406
3407
3408
# File 'lib/stripe/resources/payment_intent.rb', line 3406

def name
  @name
end

#phoneObject (readonly)

Recipient phone (including extension).



3408
3409
3410
# File 'lib/stripe/resources/payment_intent.rb', line 3408

def phone
  @phone
end

#tracking_numberObject (readonly)

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



3410
3411
3412
# File 'lib/stripe/resources/payment_intent.rb', line 3410

def tracking_number
  @tracking_number
end

Class Method Details

.field_remappingsObject



3416
3417
3418
# File 'lib/stripe/resources/payment_intent.rb', line 3416

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3412
3413
3414
# File 'lib/stripe/resources/payment_intent.rb', line 3412

def self.inner_class_types
  @inner_class_types = { address: Address }
end