Class: Stripe::PaymentIntent::TransferData

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: PaymentData

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount transferred to the destination account. This transfer will occur automatically after the payment succeeds. If no amount is specified, by default the entire payment amount is transferred to the destination account. The amount must be less than or equal to the amount, and must be a positive integer representing how much to transfer in the smallest currency unit (e.g., 100 cents to charge $1.00).



5419
5420
5421
# File 'lib/stripe/resources/payment_intent.rb', line 5419

def amount
  @amount
end

#descriptionObject (readonly)

An arbitrary string attached to the transfer. Often useful for displaying to users.



5421
5422
5423
# File 'lib/stripe/resources/payment_intent.rb', line 5421

def description
  @description
end

#destinationObject (readonly)

The account (if any) that the payment is attributed to for tax reporting, and where funds from the payment are transferred to after payment success.



5423
5424
5425
# File 'lib/stripe/resources/payment_intent.rb', line 5423

def destination
  @destination
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



5425
5426
5427
# File 'lib/stripe/resources/payment_intent.rb', line 5425

def 
  @metadata
end

#payment_dataObject (readonly)

Attribute for field payment_data



5427
5428
5429
# File 'lib/stripe/resources/payment_intent.rb', line 5427

def payment_data
  @payment_data
end

Class Method Details

.field_remappingsObject



5433
5434
5435
# File 'lib/stripe/resources/payment_intent.rb', line 5433

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



5429
5430
5431
# File 'lib/stripe/resources/payment_intent.rb', line 5429

def self.inner_class_types
  @inner_class_types = { payment_data: PaymentData }
end