Class: Stripe::PaymentIntent::TransferData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::TransferData
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: PaymentData
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount transferred to the destination account.
-
#description ⇒ Object
readonly
An arbitrary string attached to the transfer.
-
#destination ⇒ Object
readonly
The account (if any) that the payment is attributed to for tax reporting, and where funds from the payment are transferred to after payment success.
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#payment_data ⇒ Object
readonly
Attribute for field payment_data.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount transferred to the destination account. This transfer will occur automatically after the payment succeeds. If no amount is specified, by default the entire payment amount is transferred to the destination account. The amount must be less than or equal to the amount, and must be a positive integer representing how much to transfer in the smallest currency unit (e.g., 100 cents to charge $1.00).
3028 3029 3030 |
# File 'lib/stripe/resources/payment_intent.rb', line 3028 def amount @amount end |
#description ⇒ Object (readonly)
An arbitrary string attached to the transfer. Often useful for displaying to users.
3030 3031 3032 |
# File 'lib/stripe/resources/payment_intent.rb', line 3030 def description @description end |
#destination ⇒ Object (readonly)
The account (if any) that the payment is attributed to for tax reporting, and where funds from the payment are transferred to after payment success.
3032 3033 3034 |
# File 'lib/stripe/resources/payment_intent.rb', line 3032 def destination @destination end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
3034 3035 3036 |
# File 'lib/stripe/resources/payment_intent.rb', line 3034 def @metadata end |
#payment_data ⇒ Object (readonly)
Attribute for field payment_data
3036 3037 3038 |
# File 'lib/stripe/resources/payment_intent.rb', line 3036 def payment_data @payment_data end |
Class Method Details
.field_remappings ⇒ Object
3042 3043 3044 |
# File 'lib/stripe/resources/payment_intent.rb', line 3042 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3038 3039 3040 |
# File 'lib/stripe/resources/payment_intent.rb', line 3038 def self.inner_class_types @inner_class_types = { payment_data: PaymentData } end |