Class: Stripe::PaymentIntent::TransferData

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: PaymentData

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount transferred to the destination account. This transfer will occur automatically after the payment succeeds. If no amount is specified, by default the entire payment amount is transferred to the destination account.

The amount must be less than or equal to the [amount](https://docs.stripe.com/api/payment_intents/object#payment_intent_object-amount), and must be a positive integer
representing how much to transfer in the smallest currency unit (e.g., 100 cents to charge $1.00).


4456
4457
4458
# File 'lib/stripe/resources/payment_intent.rb', line 4456

def amount
  @amount
end

#descriptionObject (readonly)

An arbitrary string attached to the transfer. Often useful for displaying to users.



4458
4459
4460
# File 'lib/stripe/resources/payment_intent.rb', line 4458

def description
  @description
end

#destinationObject (readonly)

The account (if any) that the payment is attributed to for tax reporting, and where funds from the payment are transferred to after payment success.



4460
4461
4462
# File 'lib/stripe/resources/payment_intent.rb', line 4460

def destination
  @destination
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



4462
4463
4464
# File 'lib/stripe/resources/payment_intent.rb', line 4462

def 
  @metadata
end

#payment_dataObject (readonly)

Attribute for field payment_data



4464
4465
4466
# File 'lib/stripe/resources/payment_intent.rb', line 4464

def payment_data
  @payment_data
end

Class Method Details

.field_remappingsObject



4470
4471
4472
# File 'lib/stripe/resources/payment_intent.rb', line 4470

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4466
4467
4468
# File 'lib/stripe/resources/payment_intent.rb', line 4466

def self.inner_class_types
  @inner_class_types = { payment_data: PaymentData }
end