Class: Stripe::PaymentIntent::TransferData

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: PaymentData

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount transferred to the destination account. This transfer will occur automatically after the payment succeeds. If no amount is specified, by default the entire payment amount is transferred to the destination account.

The amount must be less than or equal to the [amount](https://docs.stripe.com/api/payment_intents/object#payment_intent_object-amount), and must be a positive integer
representing how much to transfer in the smallest currency unit (e.g., 100 cents to charge $1.00).


2980
2981
2982
# File 'lib/stripe/resources/payment_intent.rb', line 2980

def amount
  @amount
end

#descriptionObject (readonly)

An arbitrary string attached to the transfer. Often useful for displaying to users.



2982
2983
2984
# File 'lib/stripe/resources/payment_intent.rb', line 2982

def description
  @description
end

#destinationObject (readonly)

The account (if any) that the payment is attributed to for tax reporting, and where funds from the payment are transferred to after payment success.



2984
2985
2986
# File 'lib/stripe/resources/payment_intent.rb', line 2984

def destination
  @destination
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



2986
2987
2988
# File 'lib/stripe/resources/payment_intent.rb', line 2986

def 
  @metadata
end

#payment_dataObject (readonly)

Attribute for field payment_data



2988
2989
2990
# File 'lib/stripe/resources/payment_intent.rb', line 2988

def payment_data
  @payment_data
end

Class Method Details

.field_remappingsObject



2994
2995
2996
# File 'lib/stripe/resources/payment_intent.rb', line 2994

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2990
2991
2992
# File 'lib/stripe/resources/payment_intent.rb', line 2990

def self.inner_class_types
  @inner_class_types = { payment_data: PaymentData }
end