Class: Stripe::PaymentIntent::TransferData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::TransferData
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount transferred to the destination account.
-
#destination ⇒ Object
readonly
The account (if any) that the payment is attributed to for tax reporting, and where funds from the payment are transferred to after payment success.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount transferred to the destination account. This transfer will occur automatically after the payment succeeds. If no amount is specified, by default the entire payment amount is transferred to the destination account.
The amount must be less than or equal to the [amount](https://stripe.com/docs/api/payment_intents/object#payment_intent_object-amount), and must be a positive integer
representing how much to transfer in the smallest currency unit (e.g., 100 cents to charge $1.00).
3397 3398 3399 |
# File 'lib/stripe/resources/payment_intent.rb', line 3397 def amount @amount end |
#destination ⇒ Object (readonly)
The account (if any) that the payment is attributed to for tax reporting, and where funds from the payment are transferred to after payment success.
3399 3400 3401 |
# File 'lib/stripe/resources/payment_intent.rb', line 3399 def destination @destination end |
Class Method Details
.field_remappings ⇒ Object
3405 3406 3407 |
# File 'lib/stripe/resources/payment_intent.rb', line 3405 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3401 3402 3403 |
# File 'lib/stripe/resources/payment_intent.rb', line 3401 def self.inner_class_types @inner_class_types = {} end |