Class: Stripe::PaymentIntent::TransferData

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_intent.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount transferred to the destination account. This transfer will occur automatically after the payment succeeds. If no amount is specified, by default the entire payment amount is transferred to the destination account.

The amount must be less than or equal to the [amount](https://docs.stripe.com/api/payment_intents/object#payment_intent_object-amount), and must be a positive integer
representing how much to transfer in the smallest currency unit (e.g., 100 cents to charge $1.00).


2809
2810
2811
# File 'lib/stripe/resources/payment_intent.rb', line 2809

def amount
  @amount
end

#destinationObject (readonly)

The account (if any) that the payment is attributed to for tax reporting, and where funds from the payment are transferred to after payment success.



2811
2812
2813
# File 'lib/stripe/resources/payment_intent.rb', line 2811

def destination
  @destination
end

Class Method Details

.field_remappingsObject



2817
2818
2819
# File 'lib/stripe/resources/payment_intent.rb', line 2817

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2813
2814
2815
# File 'lib/stripe/resources/payment_intent.rb', line 2813

def self.inner_class_types
  @inner_class_types = {}
end