Class: Stripe::PaymentIntent::TriggerActionParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::TriggerActionParams
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: ScanQrCode
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
-
#type ⇒ Object
The type of action to be simulated.
Instance Method Summary collapse
-
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
constructor
A new instance of TriggerActionParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
Returns a new instance of TriggerActionParams.
14700 14701 14702 14703 14704 |
# File 'lib/stripe/resources/payment_intent.rb', line 14700 def initialize(expand: nil, scan_qr_code: nil, type: nil) @expand = @scan_qr_code = scan_qr_code @type = type end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
14694 14695 14696 |
# File 'lib/stripe/resources/payment_intent.rb', line 14694 def @expand end |
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
14696 14697 14698 |
# File 'lib/stripe/resources/payment_intent.rb', line 14696 def scan_qr_code @scan_qr_code end |
#type ⇒ Object
The type of action to be simulated.
14698 14699 14700 |
# File 'lib/stripe/resources/payment_intent.rb', line 14698 def type @type end |