Class: Stripe::PaymentIntent::TriggerActionParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::TriggerActionParams
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: ScanQrCode
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
-
#type ⇒ Object
The type of action to be simulated.
Instance Method Summary collapse
-
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
constructor
A new instance of TriggerActionParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
Returns a new instance of TriggerActionParams.
13723 13724 13725 13726 13727 |
# File 'lib/stripe/resources/payment_intent.rb', line 13723 def initialize(expand: nil, scan_qr_code: nil, type: nil) @expand = @scan_qr_code = scan_qr_code @type = type end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
13717 13718 13719 |
# File 'lib/stripe/resources/payment_intent.rb', line 13717 def @expand end |
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
13719 13720 13721 |
# File 'lib/stripe/resources/payment_intent.rb', line 13719 def scan_qr_code @scan_qr_code end |
#type ⇒ Object
The type of action to be simulated.
13721 13722 13723 |
# File 'lib/stripe/resources/payment_intent.rb', line 13721 def type @type end |