Class: Stripe::PaymentIntent::TriggerActionParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::TriggerActionParams
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: ScanQrCode
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
-
#type ⇒ Object
The type of action to be simulated.
Instance Method Summary collapse
-
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
constructor
A new instance of TriggerActionParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
Returns a new instance of TriggerActionParams.
13404 13405 13406 13407 13408 |
# File 'lib/stripe/resources/payment_intent.rb', line 13404 def initialize(expand: nil, scan_qr_code: nil, type: nil) @expand = @scan_qr_code = scan_qr_code @type = type end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
13398 13399 13400 |
# File 'lib/stripe/resources/payment_intent.rb', line 13398 def @expand end |
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
13400 13401 13402 |
# File 'lib/stripe/resources/payment_intent.rb', line 13400 def scan_qr_code @scan_qr_code end |
#type ⇒ Object
The type of action to be simulated.
13402 13403 13404 |
# File 'lib/stripe/resources/payment_intent.rb', line 13402 def type @type end |