Class: Stripe::PaymentIntent::TriggerActionParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::TriggerActionParams
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: ScanQrCode
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
-
#type ⇒ Object
The type of action to be simulated.
Instance Method Summary collapse
-
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
constructor
A new instance of TriggerActionParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
Returns a new instance of TriggerActionParams.
13376 13377 13378 13379 13380 |
# File 'lib/stripe/resources/payment_intent.rb', line 13376 def initialize(expand: nil, scan_qr_code: nil, type: nil) @expand = @scan_qr_code = scan_qr_code @type = type end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
13370 13371 13372 |
# File 'lib/stripe/resources/payment_intent.rb', line 13370 def @expand end |
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
13372 13373 13374 |
# File 'lib/stripe/resources/payment_intent.rb', line 13372 def scan_qr_code @scan_qr_code end |
#type ⇒ Object
The type of action to be simulated.
13374 13375 13376 |
# File 'lib/stripe/resources/payment_intent.rb', line 13374 def type @type end |