Class: Stripe::PaymentIntent::TriggerActionParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::TriggerActionParams
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: ScanQrCode
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
-
#type ⇒ Object
The type of action to be simulated.
Instance Method Summary collapse
-
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
constructor
A new instance of TriggerActionParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
Returns a new instance of TriggerActionParams.
13294 13295 13296 13297 13298 |
# File 'lib/stripe/resources/payment_intent.rb', line 13294 def initialize(expand: nil, scan_qr_code: nil, type: nil) @expand = @scan_qr_code = scan_qr_code @type = type end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
13288 13289 13290 |
# File 'lib/stripe/resources/payment_intent.rb', line 13288 def @expand end |
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
13290 13291 13292 |
# File 'lib/stripe/resources/payment_intent.rb', line 13290 def scan_qr_code @scan_qr_code end |
#type ⇒ Object
The type of action to be simulated.
13292 13293 13294 |
# File 'lib/stripe/resources/payment_intent.rb', line 13292 def type @type end |