Class: Stripe::PaymentIntent::TriggerActionParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::TriggerActionParams
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: ScanQrCode
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
-
#type ⇒ Object
The type of action to be simulated.
Instance Method Summary collapse
-
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
constructor
A new instance of TriggerActionParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
Returns a new instance of TriggerActionParams.
12831 12832 12833 12834 12835 |
# File 'lib/stripe/resources/payment_intent.rb', line 12831 def initialize(expand: nil, scan_qr_code: nil, type: nil) @expand = @scan_qr_code = scan_qr_code @type = type end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
12825 12826 12827 |
# File 'lib/stripe/resources/payment_intent.rb', line 12825 def @expand end |
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
12827 12828 12829 |
# File 'lib/stripe/resources/payment_intent.rb', line 12827 def scan_qr_code @scan_qr_code end |
#type ⇒ Object
The type of action to be simulated.
12829 12830 12831 |
# File 'lib/stripe/resources/payment_intent.rb', line 12829 def type @type end |