Class: Stripe::PaymentIntent::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Hooks, MandateData, PaymentDetails, PaymentMethodData, PaymentMethodOptions, Shipping, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, application_fee_amount: nil, capture_method: nil, currency: nil, customer: nil, customer_account: nil, description: nil, expand: nil, fx_quote: nil, hooks: nil, mandate_data: nil, metadata: nil, payment_details: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, receipt_email: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



8912
8913
8914
8915
8916
8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
8931
8932
8933
8934
8935
8936
8937
8938
8939
8940
8941
8942
8943
8944
8945
8946
8947
8948
8949
8950
8951
8952
8953
8954
8955
8956
8957
8958
8959
8960
8961
8962
8963
8964
# File 'lib/stripe/resources/payment_intent.rb', line 8912

def initialize(
  amount: nil,
  application_fee_amount: nil,
  capture_method: nil,
  currency: nil,
  customer: nil,
  customer_account: nil,
  description: nil,
  expand: nil,
  fx_quote: nil,
  hooks: nil,
  mandate_data: nil,
  metadata: nil,
  payment_details: nil,
  payment_method: nil,
  payment_method_configuration: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  receipt_email: nil,
  setup_future_usage: nil,
  shipping: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil,
  transfer_group: nil
)
  @amount = amount
  @application_fee_amount = application_fee_amount
  @capture_method = capture_method
  @currency = currency
  @customer = customer
  @customer_account = 
  @description = description
  @expand = expand
  @fx_quote = fx_quote
  @hooks = hooks
  @mandate_data = mandate_data
  @metadata = 
  @payment_details = payment_details
  @payment_method = payment_method
  @payment_method_configuration = payment_method_configuration
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @receipt_email = receipt_email
  @setup_future_usage = setup_future_usage
  @shipping = shipping
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
  @transfer_group = transfer_group
end

Instance Attribute Details

#amountObject

Amount intended to be collected by this PaymentIntent. A positive integer representing how much to charge in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge currency](stripe.com/docs/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).



8842
8843
8844
# File 'lib/stripe/resources/payment_intent.rb', line 8842

def amount
  @amount
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



8844
8845
8846
# File 'lib/stripe/resources/payment_intent.rb', line 8844

def application_fee_amount
  @application_fee_amount
end

#capture_methodObject

Controls when the funds will be captured from the customer’s account.



8846
8847
8848
# File 'lib/stripe/resources/payment_intent.rb', line 8846

def capture_method
  @capture_method
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



8848
8849
8850
# File 'lib/stripe/resources/payment_intent.rb', line 8848

def currency
  @currency
end

#customerObject

ID of the Customer this PaymentIntent belongs to, if one exists.

Payment methods attached to other Customers cannot be used with this PaymentIntent.

If [setup_future_usage](stripe.com/docs/api#payment_intent_object-setup_future_usage) is set and this PaymentIntent’s payment method is not ‘card_present`, then the payment method attaches to the Customer after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is `card_present` and isn’t a digital wallet, then a [generated_card](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Customer instead.



8854
8855
8856
# File 'lib/stripe/resources/payment_intent.rb', line 8854

def customer
  @customer
end

#customer_accountObject

ID of the Account this PaymentIntent belongs to, if one exists.

Payment methods attached to other Accounts cannot be used with this PaymentIntent.

If [setup_future_usage](stripe.com/docs/api#payment_intent_object-setup_future_usage) is set and this PaymentIntent’s payment method is not ‘card_present`, then the payment method attaches to the Account after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is `card_present` and isn’t a digital wallet, then a [generated_card](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Account instead.



8860
8861
8862
# File 'lib/stripe/resources/payment_intent.rb', line 8860

def 
  @customer_account
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



8862
8863
8864
# File 'lib/stripe/resources/payment_intent.rb', line 8862

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



8864
8865
8866
# File 'lib/stripe/resources/payment_intent.rb', line 8864

def expand
  @expand
end

#fx_quoteObject

The FX rate in the quote is validated and used to convert the presentment amount to the settlement amount.



8866
8867
8868
# File 'lib/stripe/resources/payment_intent.rb', line 8866

def fx_quote
  @fx_quote
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



8868
8869
8870
# File 'lib/stripe/resources/payment_intent.rb', line 8868

def hooks
  @hooks
end

#mandate_dataObject

This hash contains details about the Mandate to create.



8870
8871
8872
# File 'lib/stripe/resources/payment_intent.rb', line 8870

def mandate_data
  @mandate_data
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



8872
8873
8874
# File 'lib/stripe/resources/payment_intent.rb', line 8872

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



8874
8875
8876
# File 'lib/stripe/resources/payment_intent.rb', line 8874

def payment_details
  @payment_details
end

#payment_methodObject

Attribute for param field payment_method



8876
8877
8878
# File 'lib/stripe/resources/payment_intent.rb', line 8876

def payment_method
  @payment_method
end

#payment_method_configurationObject

The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this PaymentIntent.



8878
8879
8880
# File 'lib/stripe/resources/payment_intent.rb', line 8878

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the [payment_method](stripe.com/docs/api/payment_intents/object#payment_intent_object-payment_method) property on the PaymentIntent.



8882
8883
8884
# File 'lib/stripe/resources/payment_intent.rb', line 8882

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment-method-specific configuration for this PaymentIntent.



8884
8885
8886
# File 'lib/stripe/resources/payment_intent.rb', line 8884

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, card) that this PaymentIntent can use. Use ‘automatic_payment_methods` to manage payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods).



8886
8887
8888
# File 'lib/stripe/resources/payment_intent.rb', line 8886

def payment_method_types
  @payment_method_types
end

#receipt_emailObject

Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).



8888
8889
8890
# File 'lib/stripe/resources/payment_intent.rb', line 8888

def receipt_email
  @receipt_email
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



8898
8899
8900
# File 'lib/stripe/resources/payment_intent.rb', line 8898

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this PaymentIntent.



8900
8901
8902
# File 'lib/stripe/resources/payment_intent.rb', line 8900

def shipping
  @shipping
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).

Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.



8904
8905
8906
# File 'lib/stripe/resources/payment_intent.rb', line 8904

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



8906
8907
8908
# File 'lib/stripe/resources/payment_intent.rb', line 8906

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

Use this parameter to automatically create a Transfer when the payment succeeds. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



8908
8909
8910
# File 'lib/stripe/resources/payment_intent.rb', line 8908

def transfer_data
  @transfer_data
end

#transfer_groupObject

A string that identifies the resulting payment as part of a group. You can only provide ‘transfer_group` if it hasn’t been set. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



8910
8911
8912
# File 'lib/stripe/resources/payment_intent.rb', line 8910

def transfer_group
  @transfer_group
end