Class: Stripe::PaymentIntent::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AsyncWorkflows, MandateData, PaymentDetails, PaymentMethodData, PaymentMethodOptions, Shipping, TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount intended to be collected by this PaymentIntent.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#async_workflows ⇒ Object
Automations to be run during the PaymentIntent lifecycle.
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
ID of the Customer this PaymentIntent belongs to, if one exists.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#mandate_data ⇒ Object
This hash contains details about the Mandate to create.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment_details ⇒ Object
Provides industry-specific information about the charge.
-
#payment_method ⇒ Object
Attribute for param field payment_method.
-
#payment_method_configuration ⇒ Object
The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this PaymentIntent.
-
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod.
-
#payment_method_options ⇒ Object
Payment-method-specific configuration for this PaymentIntent.
-
#payment_method_types ⇒ Object
The list of payment method types (for example, card) that this PaymentIntent can use.
-
#receipt_email ⇒ Object
Email address that the receipt for the resulting payment will be sent to.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#shipping ⇒ Object
Shipping information for this PaymentIntent.
-
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card charge.
-
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge.
-
#transfer_data ⇒ Object
Use this parameter to automatically create a Transfer when the payment succeeds.
-
#transfer_group ⇒ Object
A string that identifies the resulting payment as part of a group.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, application_fee_amount: nil, async_workflows: nil, capture_method: nil, currency: nil, customer: nil, description: nil, expand: nil, mandate_data: nil, metadata: nil, payment_details: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, receipt_email: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 8470 8471 8472 8473 8474 8475 8476 8477 8478 8479 8480 8481 8482 8483 8484 8485 8486 8487 8488 |
# File 'lib/stripe/resources/payment_intent.rb', line 8440 def initialize( amount: nil, application_fee_amount: nil, async_workflows: nil, capture_method: nil, currency: nil, customer: nil, description: nil, expand: nil, mandate_data: nil, metadata: nil, payment_details: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, receipt_email: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil ) @amount = amount @application_fee_amount = application_fee_amount @async_workflows = async_workflows @capture_method = capture_method @currency = currency @customer = customer @description = description @expand = @mandate_data = mandate_data @metadata = @payment_details = payment_details @payment_method = payment_method @payment_method_configuration = payment_method_configuration @payment_method_data = payment_method_data @payment_method_options = @payment_method_types = payment_method_types @receipt_email = receipt_email @setup_future_usage = setup_future_usage @shipping = shipping @statement_descriptor = statement_descriptor @statement_descriptor_suffix = statement_descriptor_suffix @transfer_data = transfer_data @transfer_group = transfer_group end |
Instance Attribute Details
#amount ⇒ Object
Amount intended to be collected by this PaymentIntent. A positive integer representing how much to charge in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge currency](stripe.com/docs/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).
8378 8379 8380 |
# File 'lib/stripe/resources/payment_intent.rb', line 8378 def amount @amount end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total payment amount. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
8380 8381 8382 |
# File 'lib/stripe/resources/payment_intent.rb', line 8380 def application_fee_amount @application_fee_amount end |
#async_workflows ⇒ Object
Automations to be run during the PaymentIntent lifecycle
8382 8383 8384 |
# File 'lib/stripe/resources/payment_intent.rb', line 8382 def async_workflows @async_workflows end |
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
8384 8385 8386 |
# File 'lib/stripe/resources/payment_intent.rb', line 8384 def capture_method @capture_method end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
8386 8387 8388 |
# File 'lib/stripe/resources/payment_intent.rb', line 8386 def currency @currency end |
#customer ⇒ Object
ID of the Customer this PaymentIntent belongs to, if one exists.
Payment methods attached to other Customers cannot be used with this PaymentIntent.
If [setup_future_usage](stripe.com/docs/api#payment_intent_object-setup_future_usage) is set and this PaymentIntent’s payment method is not ‘card_present`, then the payment method attaches to the Customer after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is `card_present` and isn’t a digital wallet, then a [generated_card](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Customer instead.
8392 8393 8394 |
# File 'lib/stripe/resources/payment_intent.rb', line 8392 def customer @customer end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
8394 8395 8396 |
# File 'lib/stripe/resources/payment_intent.rb', line 8394 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
8396 8397 8398 |
# File 'lib/stripe/resources/payment_intent.rb', line 8396 def @expand end |
#mandate_data ⇒ Object
This hash contains details about the Mandate to create.
8398 8399 8400 |
# File 'lib/stripe/resources/payment_intent.rb', line 8398 def mandate_data @mandate_data end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
8400 8401 8402 |
# File 'lib/stripe/resources/payment_intent.rb', line 8400 def @metadata end |
#payment_details ⇒ Object
Provides industry-specific information about the charge.
8402 8403 8404 |
# File 'lib/stripe/resources/payment_intent.rb', line 8402 def payment_details @payment_details end |
#payment_method ⇒ Object
Attribute for param field payment_method
8404 8405 8406 |
# File 'lib/stripe/resources/payment_intent.rb', line 8404 def payment_method @payment_method end |
#payment_method_configuration ⇒ Object
The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this PaymentIntent.
8406 8407 8408 |
# File 'lib/stripe/resources/payment_intent.rb', line 8406 def payment_method_configuration @payment_method_configuration end |
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the [payment_method](stripe.com/docs/api/payment_intents/object#payment_intent_object-payment_method) property on the PaymentIntent.
8410 8411 8412 |
# File 'lib/stripe/resources/payment_intent.rb', line 8410 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment-method-specific configuration for this PaymentIntent.
8412 8413 8414 |
# File 'lib/stripe/resources/payment_intent.rb', line 8412 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types (for example, card) that this PaymentIntent can use. Use ‘automatic_payment_methods` to manage payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods).
8414 8415 8416 |
# File 'lib/stripe/resources/payment_intent.rb', line 8414 def payment_method_types @payment_method_types end |
#receipt_email ⇒ Object
Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).
8416 8417 8418 |
# File 'lib/stripe/resources/payment_intent.rb', line 8416 def receipt_email @receipt_email end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.
8426 8427 8428 |
# File 'lib/stripe/resources/payment_intent.rb', line 8426 def setup_future_usage @setup_future_usage end |
#shipping ⇒ Object
Shipping information for this PaymentIntent.
8428 8429 8430 |
# File 'lib/stripe/resources/payment_intent.rb', line 8428 def shipping @shipping end |
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.
8432 8433 8434 |
# File 'lib/stripe/resources/payment_intent.rb', line 8432 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.
8434 8435 8436 |
# File 'lib/stripe/resources/payment_intent.rb', line 8434 def statement_descriptor_suffix @statement_descriptor_suffix end |
#transfer_data ⇒ Object
Use this parameter to automatically create a Transfer when the payment succeeds. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
8436 8437 8438 |
# File 'lib/stripe/resources/payment_intent.rb', line 8436 def transfer_data @transfer_data end |
#transfer_group ⇒ Object
A string that identifies the resulting payment as part of a group. You can only provide ‘transfer_group` if it hasn’t been set. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
8438 8439 8440 |
# File 'lib/stripe/resources/payment_intent.rb', line 8438 def transfer_group @transfer_group end |