Class: Stripe::PaymentIntent::UpdateParams::AmountDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: LineItem, Shipping, Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails

Returns a new instance of AmountDetails.



5966
5967
5968
5969
5970
5971
# File 'lib/stripe/resources/payment_intent.rb', line 5966

def initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil)
  @discount_amount = discount_amount
  @line_items = line_items
  @shipping = shipping
  @tax = tax
end

Instance Attribute Details

#discount_amountObject

The amount an item was discounted for.



5958
5959
5960
# File 'lib/stripe/resources/payment_intent.rb', line 5958

def discount_amount
  @discount_amount
end

#line_itemsObject

A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.



5960
5961
5962
# File 'lib/stripe/resources/payment_intent.rb', line 5960

def line_items
  @line_items
end

#shippingObject

Contains information about the shipping portion of the amount.



5962
5963
5964
# File 'lib/stripe/resources/payment_intent.rb', line 5962

def shipping
  @shipping
end

#taxObject

Contains information about the tax portion of the amount.



5964
5965
5966
# File 'lib/stripe/resources/payment_intent.rb', line 5964

def tax
  @tax
end