Class: Stripe::PaymentIntent::UpdateParams::AmountDetails::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::AmountDetails::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The amount an item was discounted for.
-
#payment_method_options ⇒ Object
Payment method-specific information for line items.
-
#product_code ⇒ Object
Unique identifier of the product.
-
#product_name ⇒ Object
Name of the product.
-
#quantity ⇒ Object
Number of items of the product.
-
#tax ⇒ Object
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
Cost of the product.
-
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
Returns a new instance of LineItem.
5913 5914 5915 5916 5917 5918 5919 5920 5921 5922 5923 5924 5925 5926 5927 5928 5929 5930 5931 |
# File 'lib/stripe/resources/payment_intent.rb', line 5913 def initialize( discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil ) @discount_amount = discount_amount @payment_method_options = @product_code = product_code @product_name = product_name @quantity = quantity @tax = tax @unit_cost = unit_cost @unit_of_measure = unit_of_measure end |
Instance Attribute Details
#discount_amount ⇒ Object
The amount an item was discounted for. Positive integer.
5897 5898 5899 |
# File 'lib/stripe/resources/payment_intent.rb', line 5897 def discount_amount @discount_amount end |
#payment_method_options ⇒ Object
Payment method-specific information for line items.
5899 5900 5901 |
# File 'lib/stripe/resources/payment_intent.rb', line 5899 def @payment_method_options end |
#product_code ⇒ Object
Unique identifier of the product. At most 12 characters long.
5901 5902 5903 |
# File 'lib/stripe/resources/payment_intent.rb', line 5901 def product_code @product_code end |
#product_name ⇒ Object
Name of the product. At most 100 characters long.
5903 5904 5905 |
# File 'lib/stripe/resources/payment_intent.rb', line 5903 def product_name @product_name end |
#quantity ⇒ Object
Number of items of the product. Positive integer.
5905 5906 5907 |
# File 'lib/stripe/resources/payment_intent.rb', line 5905 def quantity @quantity end |
#tax ⇒ Object
Contains information about the tax on the item.
5907 5908 5909 |
# File 'lib/stripe/resources/payment_intent.rb', line 5907 def tax @tax end |
#unit_cost ⇒ Object
Cost of the product. Non-negative integer.
5909 5910 5911 |
# File 'lib/stripe/resources/payment_intent.rb', line 5909 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
5911 5912 5913 |
# File 'lib/stripe/resources/payment_intent.rb', line 5911 def unit_of_measure @unit_of_measure end |