Class: Stripe::PaymentIntent::UpdateParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



5592
5593
5594
5595
# File 'lib/stripe/resources/payment_intent.rb', line 5592

def initialize(online: nil, type: nil)
  @online = online
  @type = type
end

Instance Attribute Details

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



5588
5589
5590
# File 'lib/stripe/resources/payment_intent.rb', line 5588

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate.



5590
5591
5592
# File 'lib/stripe/resources/payment_intent.rb', line 5590

def type
  @type
end