Class: Stripe::PaymentIntent::UpdateParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



5530
5531
5532
5533
# File 'lib/stripe/resources/payment_intent.rb', line 5530

def initialize(online: nil, type: nil)
  @online = online
  @type = type
end

Instance Attribute Details

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



5526
5527
5528
# File 'lib/stripe/resources/payment_intent.rb', line 5526

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate.



5528
5529
5530
# File 'lib/stripe/resources/payment_intent.rb', line 5528

def type
  @type
end