Class: Stripe::PaymentIntent::UpdateParams::MandateData::CustomerAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::MandateData::CustomerAcceptance
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Online
Instance Attribute Summary collapse
-
#online ⇒ Object
If this is a Mandate accepted online, this hash contains details about the online acceptance.
-
#type ⇒ Object
The type of customer acceptance information included with the Mandate.
Instance Method Summary collapse
-
#initialize(online: nil, type: nil) ⇒ CustomerAcceptance
constructor
A new instance of CustomerAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(online: nil, type: nil) ⇒ CustomerAcceptance
Returns a new instance of CustomerAcceptance.
6123 6124 6125 6126 |
# File 'lib/stripe/resources/payment_intent.rb', line 6123 def initialize(online: nil, type: nil) @online = online @type = type end |
Instance Attribute Details
#online ⇒ Object
If this is a Mandate accepted online, this hash contains details about the online acceptance.
6118 6119 6120 |
# File 'lib/stripe/resources/payment_intent.rb', line 6118 def online @online end |
#type ⇒ Object
The type of customer acceptance information included with the Mandate.
6121 6122 6123 |
# File 'lib/stripe/resources/payment_intent.rb', line 6121 def type @type end |