Class: Stripe::PaymentIntent::UpdateParams::MandateData::CustomerAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::MandateData::CustomerAcceptance
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Online
Instance Attribute Summary collapse
-
#online ⇒ Object
If this is a Mandate accepted online, this hash contains details about the online acceptance.
-
#type ⇒ Object
The type of customer acceptance information included with the Mandate.
Instance Method Summary collapse
-
#initialize(online: nil, type: nil) ⇒ CustomerAcceptance
constructor
A new instance of CustomerAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(online: nil, type: nil) ⇒ CustomerAcceptance
Returns a new instance of CustomerAcceptance.
5316 5317 5318 5319 |
# File 'lib/stripe/resources/payment_intent.rb', line 5316 def initialize(online: nil, type: nil) @online = online @type = type end |
Instance Attribute Details
#online ⇒ Object
If this is a Mandate accepted online, this hash contains details about the online acceptance.
5312 5313 5314 |
# File 'lib/stripe/resources/payment_intent.rb', line 5312 def online @online end |
#type ⇒ Object
The type of customer acceptance information included with the Mandate.
5314 5315 5316 |
# File 'lib/stripe/resources/payment_intent.rb', line 5314 def type @type end |