Class: Stripe::PaymentIntent::UpdateParams::MandateData::CustomerAcceptance::Online
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::MandateData::CustomerAcceptance::Online
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#ip_address ⇒ Object
The IP address from which the Mandate was accepted by the customer.
-
#user_agent ⇒ Object
The user agent of the browser from which the Mandate was accepted by the customer.
Instance Method Summary collapse
-
#initialize(ip_address: nil, user_agent: nil) ⇒ Online
constructor
A new instance of Online.
Methods inherited from RequestParams
Constructor Details
#initialize(ip_address: nil, user_agent: nil) ⇒ Online
Returns a new instance of Online.
5564 5565 5566 5567 |
# File 'lib/stripe/resources/payment_intent.rb', line 5564 def initialize(ip_address: nil, user_agent: nil) @ip_address = ip_address @user_agent = user_agent end |
Instance Attribute Details
#ip_address ⇒ Object
The IP address from which the Mandate was accepted by the customer.
5560 5561 5562 |
# File 'lib/stripe/resources/payment_intent.rb', line 5560 def ip_address @ip_address end |
#user_agent ⇒ Object
The user agent of the browser from which the Mandate was accepted by the customer.
5562 5563 5564 |
# File 'lib/stripe/resources/payment_intent.rb', line 5562 def user_agent @user_agent end |