Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
8173 8174 8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 8185 8186 8187 8188 8189 |
# File 'lib/stripe/resources/payment_intent.rb', line 8173 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
8159 8160 8161 |
# File 'lib/stripe/resources/payment_intent.rb', line 8159 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
8161 8162 8163 |
# File 'lib/stripe/resources/payment_intent.rb', line 8161 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
8163 8164 8165 |
# File 'lib/stripe/resources/payment_intent.rb', line 8163 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
8165 8166 8167 |
# File 'lib/stripe/resources/payment_intent.rb', line 8165 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
8167 8168 8169 |
# File 'lib/stripe/resources/payment_intent.rb', line 8167 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
8169 8170 8171 |
# File 'lib/stripe/resources/payment_intent.rb', line 8169 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
8171 8172 8173 |
# File 'lib/stripe/resources/payment_intent.rb', line 8171 def subscription @subscription end |