Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/stripe/resources/payment_intent.rb', line 6716 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
6702 6703 6704 |
# File 'lib/stripe/resources/payment_intent.rb', line 6702 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
6704 6705 6706 |
# File 'lib/stripe/resources/payment_intent.rb', line 6704 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
6706 6707 6708 |
# File 'lib/stripe/resources/payment_intent.rb', line 6706 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
6708 6709 6710 |
# File 'lib/stripe/resources/payment_intent.rb', line 6708 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
6710 6711 6712 |
# File 'lib/stripe/resources/payment_intent.rb', line 6710 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
6712 6713 6714 |
# File 'lib/stripe/resources/payment_intent.rb', line 6712 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
6714 6715 6716 |
# File 'lib/stripe/resources/payment_intent.rb', line 6714 def subscription @subscription end |