Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



6406
6407
6408
6409
6410
6411
6412
6413
6414
6415
6416
6417
6418
6419
6420
6421
6422
# File 'lib/stripe/resources/payment_intent.rb', line 6406

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



6392
6393
6394
# File 'lib/stripe/resources/payment_intent.rb', line 6392

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



6394
6395
6396
# File 'lib/stripe/resources/payment_intent.rb', line 6394

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



6396
6397
6398
# File 'lib/stripe/resources/payment_intent.rb', line 6396

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



6398
6399
6400
# File 'lib/stripe/resources/payment_intent.rb', line 6398

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



6400
6401
6402
# File 'lib/stripe/resources/payment_intent.rb', line 6400

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



6402
6403
6404
# File 'lib/stripe/resources/payment_intent.rb', line 6402

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



6404
6405
6406
# File 'lib/stripe/resources/payment_intent.rb', line 6404

def subscription
  @subscription
end