Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
# File 'lib/stripe/resources/payment_intent.rb', line 6291

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



6277
6278
6279
# File 'lib/stripe/resources/payment_intent.rb', line 6277

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



6279
6280
6281
# File 'lib/stripe/resources/payment_intent.rb', line 6279

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



6281
6282
6283
# File 'lib/stripe/resources/payment_intent.rb', line 6281

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



6283
6284
6285
# File 'lib/stripe/resources/payment_intent.rb', line 6283

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



6285
6286
6287
# File 'lib/stripe/resources/payment_intent.rb', line 6285

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



6287
6288
6289
# File 'lib/stripe/resources/payment_intent.rb', line 6287

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



6289
6290
6291
# File 'lib/stripe/resources/payment_intent.rb', line 6289

def subscription
  @subscription
end