Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



6239
6240
6241
6242
6243
6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
# File 'lib/stripe/resources/payment_intent.rb', line 6239

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



6225
6226
6227
# File 'lib/stripe/resources/payment_intent.rb', line 6225

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



6227
6228
6229
# File 'lib/stripe/resources/payment_intent.rb', line 6227

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



6229
6230
6231
# File 'lib/stripe/resources/payment_intent.rb', line 6229

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



6231
6232
6233
# File 'lib/stripe/resources/payment_intent.rb', line 6231

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



6233
6234
6235
# File 'lib/stripe/resources/payment_intent.rb', line 6233

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



6235
6236
6237
# File 'lib/stripe/resources/payment_intent.rb', line 6235

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



6237
6238
6239
# File 'lib/stripe/resources/payment_intent.rb', line 6237

def subscription
  @subscription
end