Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental

Returns a new instance of CarRental.



6280
6281
6282
6283
6284
6285
6286
6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
6321
6322
6323
6324
6325
6326
6327
6328
6329
6330
# File 'lib/stripe/resources/payment_intent.rb', line 6280

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  distance: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  pickup_location_name: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  return_location_name: nil,
  tax_exempt: nil,
  vehicle_identification_number: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @distance = distance
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @pickup_location_name = pickup_location_name
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @return_location_name = return_location_name
  @tax_exempt = tax_exempt
  @vehicle_identification_number = vehicle_identification_number
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



6232
6233
6234
# File 'lib/stripe/resources/payment_intent.rb', line 6232

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



6234
6235
6236
# File 'lib/stripe/resources/payment_intent.rb', line 6234

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



6236
6237
6238
# File 'lib/stripe/resources/payment_intent.rb', line 6236

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



6238
6239
6240
# File 'lib/stripe/resources/payment_intent.rb', line 6238

def car_make
  @car_make
end

#car_modelObject

Model of the car.



6240
6241
6242
# File 'lib/stripe/resources/payment_intent.rb', line 6240

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



6242
6243
6244
# File 'lib/stripe/resources/payment_intent.rb', line 6242

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



6244
6245
6246
# File 'lib/stripe/resources/payment_intent.rb', line 6244

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



6246
6247
6248
# File 'lib/stripe/resources/payment_intent.rb', line 6246

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



6248
6249
6250
# File 'lib/stripe/resources/payment_intent.rb', line 6248

def delivery
  @delivery
end

#distanceObject

The details of the distance traveled during the rental period.



6250
6251
6252
# File 'lib/stripe/resources/payment_intent.rb', line 6250

def distance
  @distance
end

#driversObject

The details of the passengers in the travel reservation



6252
6253
6254
# File 'lib/stripe/resources/payment_intent.rb', line 6252

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



6254
6255
6256
# File 'lib/stripe/resources/payment_intent.rb', line 6254

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



6256
6257
6258
# File 'lib/stripe/resources/payment_intent.rb', line 6256

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



6258
6259
6260
# File 'lib/stripe/resources/payment_intent.rb', line 6258

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



6260
6261
6262
# File 'lib/stripe/resources/payment_intent.rb', line 6260

def pickup_at
  @pickup_at
end

#pickup_location_nameObject

Name of the pickup location.



6262
6263
6264
# File 'lib/stripe/resources/payment_intent.rb', line 6262

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject

Rental rate.



6264
6265
6266
# File 'lib/stripe/resources/payment_intent.rb', line 6264

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



6266
6267
6268
# File 'lib/stripe/resources/payment_intent.rb', line 6266

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



6268
6269
6270
# File 'lib/stripe/resources/payment_intent.rb', line 6268

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



6270
6271
6272
# File 'lib/stripe/resources/payment_intent.rb', line 6270

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



6272
6273
6274
# File 'lib/stripe/resources/payment_intent.rb', line 6272

def return_at
  @return_at
end

#return_location_nameObject

Name of the return location.



6274
6275
6276
# File 'lib/stripe/resources/payment_intent.rb', line 6274

def return_location_name
  @return_location_name
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



6276
6277
6278
# File 'lib/stripe/resources/payment_intent.rb', line 6276

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject

The vehicle identification number.



6278
6279
6280
# File 'lib/stripe/resources/payment_intent.rb', line 6278

def vehicle_identification_number
  @vehicle_identification_number
end