Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#distance ⇒ Object
The details of the distance traveled during the rental period.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#pickup_location_name ⇒ Object
Name of the pickup location.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#return_location_name ⇒ Object
Name of the return location.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
The vehicle identification number.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental
Returns a new instance of CarRental.
7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 |
# File 'lib/stripe/resources/payment_intent.rb', line 7661 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @distance = distance @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @pickup_location_name = pickup_location_name @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @return_location_name = return_location_name @tax_exempt = tax_exempt @vehicle_identification_number = vehicle_identification_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
7613 7614 7615 |
# File 'lib/stripe/resources/payment_intent.rb', line 7613 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
7615 7616 7617 |
# File 'lib/stripe/resources/payment_intent.rb', line 7615 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
7617 7618 7619 |
# File 'lib/stripe/resources/payment_intent.rb', line 7617 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
7619 7620 7621 |
# File 'lib/stripe/resources/payment_intent.rb', line 7619 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
7621 7622 7623 |
# File 'lib/stripe/resources/payment_intent.rb', line 7621 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
7623 7624 7625 |
# File 'lib/stripe/resources/payment_intent.rb', line 7623 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
7625 7626 7627 |
# File 'lib/stripe/resources/payment_intent.rb', line 7625 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
7627 7628 7629 |
# File 'lib/stripe/resources/payment_intent.rb', line 7627 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
7629 7630 7631 |
# File 'lib/stripe/resources/payment_intent.rb', line 7629 def delivery @delivery end |
#distance ⇒ Object
The details of the distance traveled during the rental period.
7631 7632 7633 |
# File 'lib/stripe/resources/payment_intent.rb', line 7631 def distance @distance end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
7633 7634 7635 |
# File 'lib/stripe/resources/payment_intent.rb', line 7633 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
7635 7636 7637 |
# File 'lib/stripe/resources/payment_intent.rb', line 7635 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
7637 7638 7639 |
# File 'lib/stripe/resources/payment_intent.rb', line 7637 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
7639 7640 7641 |
# File 'lib/stripe/resources/payment_intent.rb', line 7639 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
7641 7642 7643 |
# File 'lib/stripe/resources/payment_intent.rb', line 7641 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object
Name of the pickup location.
7643 7644 7645 |
# File 'lib/stripe/resources/payment_intent.rb', line 7643 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object
Rental rate.
7645 7646 7647 |
# File 'lib/stripe/resources/payment_intent.rb', line 7645 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
7647 7648 7649 |
# File 'lib/stripe/resources/payment_intent.rb', line 7647 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
7649 7650 7651 |
# File 'lib/stripe/resources/payment_intent.rb', line 7649 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
7651 7652 7653 |
# File 'lib/stripe/resources/payment_intent.rb', line 7651 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
7653 7654 7655 |
# File 'lib/stripe/resources/payment_intent.rb', line 7653 def return_at @return_at end |
#return_location_name ⇒ Object
Name of the return location.
7655 7656 7657 |
# File 'lib/stripe/resources/payment_intent.rb', line 7655 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
7657 7658 7659 |
# File 'lib/stripe/resources/payment_intent.rb', line 7657 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object
The vehicle identification number.
7659 7660 7661 |
# File 'lib/stripe/resources/payment_intent.rb', line 7659 def vehicle_identification_number @vehicle_identification_number end |