Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#distance ⇒ Object
The details of the distance traveled during the rental period.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#pickup_location_name ⇒ Object
Name of the pickup location.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#return_location_name ⇒ Object
Name of the return location.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
The vehicle identification number.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental
Returns a new instance of CarRental.
6204 6205 6206 6207 6208 6209 6210 6211 6212 6213 6214 6215 6216 6217 6218 6219 6220 6221 6222 6223 6224 6225 6226 6227 6228 6229 6230 6231 6232 6233 6234 6235 6236 6237 6238 6239 6240 6241 6242 6243 6244 6245 6246 6247 6248 6249 6250 6251 6252 6253 6254 |
# File 'lib/stripe/resources/payment_intent.rb', line 6204 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @distance = distance @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @pickup_location_name = pickup_location_name @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @return_location_name = return_location_name @tax_exempt = tax_exempt @vehicle_identification_number = vehicle_identification_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
6156 6157 6158 |
# File 'lib/stripe/resources/payment_intent.rb', line 6156 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
6158 6159 6160 |
# File 'lib/stripe/resources/payment_intent.rb', line 6158 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
6160 6161 6162 |
# File 'lib/stripe/resources/payment_intent.rb', line 6160 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
6162 6163 6164 |
# File 'lib/stripe/resources/payment_intent.rb', line 6162 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
6164 6165 6166 |
# File 'lib/stripe/resources/payment_intent.rb', line 6164 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
6166 6167 6168 |
# File 'lib/stripe/resources/payment_intent.rb', line 6166 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
6168 6169 6170 |
# File 'lib/stripe/resources/payment_intent.rb', line 6168 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
6170 6171 6172 |
# File 'lib/stripe/resources/payment_intent.rb', line 6170 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
6172 6173 6174 |
# File 'lib/stripe/resources/payment_intent.rb', line 6172 def delivery @delivery end |
#distance ⇒ Object
The details of the distance traveled during the rental period.
6174 6175 6176 |
# File 'lib/stripe/resources/payment_intent.rb', line 6174 def distance @distance end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
6176 6177 6178 |
# File 'lib/stripe/resources/payment_intent.rb', line 6176 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
6178 6179 6180 |
# File 'lib/stripe/resources/payment_intent.rb', line 6178 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
6180 6181 6182 |
# File 'lib/stripe/resources/payment_intent.rb', line 6180 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
6182 6183 6184 |
# File 'lib/stripe/resources/payment_intent.rb', line 6182 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
6184 6185 6186 |
# File 'lib/stripe/resources/payment_intent.rb', line 6184 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object
Name of the pickup location.
6186 6187 6188 |
# File 'lib/stripe/resources/payment_intent.rb', line 6186 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object
Rental rate.
6188 6189 6190 |
# File 'lib/stripe/resources/payment_intent.rb', line 6188 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
6190 6191 6192 |
# File 'lib/stripe/resources/payment_intent.rb', line 6190 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
6192 6193 6194 |
# File 'lib/stripe/resources/payment_intent.rb', line 6192 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
6194 6195 6196 |
# File 'lib/stripe/resources/payment_intent.rb', line 6194 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
6196 6197 6198 |
# File 'lib/stripe/resources/payment_intent.rb', line 6196 def return_at @return_at end |
#return_location_name ⇒ Object
Name of the return location.
6198 6199 6200 |
# File 'lib/stripe/resources/payment_intent.rb', line 6198 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
6200 6201 6202 |
# File 'lib/stripe/resources/payment_intent.rb', line 6200 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object
The vehicle identification number.
6202 6203 6204 |
# File 'lib/stripe/resources/payment_intent.rb', line 6202 def vehicle_identification_number @vehicle_identification_number end |