Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#distance ⇒ Object
The details of the distance traveled during the rental period.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#pickup_location_name ⇒ Object
Name of the pickup location.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#return_location_name ⇒ Object
Name of the return location.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
The vehicle identification number.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental
Returns a new instance of CarRental.
5894 5895 5896 5897 5898 5899 5900 5901 5902 5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 5919 5920 5921 5922 5923 5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 5936 5937 5938 5939 5940 5941 5942 5943 5944 |
# File 'lib/stripe/resources/payment_intent.rb', line 5894 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @distance = distance @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @pickup_location_name = pickup_location_name @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @return_location_name = return_location_name @tax_exempt = tax_exempt @vehicle_identification_number = vehicle_identification_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
5846 5847 5848 |
# File 'lib/stripe/resources/payment_intent.rb', line 5846 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
5848 5849 5850 |
# File 'lib/stripe/resources/payment_intent.rb', line 5848 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
5850 5851 5852 |
# File 'lib/stripe/resources/payment_intent.rb', line 5850 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
5852 5853 5854 |
# File 'lib/stripe/resources/payment_intent.rb', line 5852 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
5854 5855 5856 |
# File 'lib/stripe/resources/payment_intent.rb', line 5854 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
5856 5857 5858 |
# File 'lib/stripe/resources/payment_intent.rb', line 5856 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
5858 5859 5860 |
# File 'lib/stripe/resources/payment_intent.rb', line 5858 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
5860 5861 5862 |
# File 'lib/stripe/resources/payment_intent.rb', line 5860 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
5862 5863 5864 |
# File 'lib/stripe/resources/payment_intent.rb', line 5862 def delivery @delivery end |
#distance ⇒ Object
The details of the distance traveled during the rental period.
5864 5865 5866 |
# File 'lib/stripe/resources/payment_intent.rb', line 5864 def distance @distance end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
5866 5867 5868 |
# File 'lib/stripe/resources/payment_intent.rb', line 5866 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
5868 5869 5870 |
# File 'lib/stripe/resources/payment_intent.rb', line 5868 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
5870 5871 5872 |
# File 'lib/stripe/resources/payment_intent.rb', line 5870 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
5872 5873 5874 |
# File 'lib/stripe/resources/payment_intent.rb', line 5872 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
5874 5875 5876 |
# File 'lib/stripe/resources/payment_intent.rb', line 5874 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object
Name of the pickup location.
5876 5877 5878 |
# File 'lib/stripe/resources/payment_intent.rb', line 5876 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object
Rental rate.
5878 5879 5880 |
# File 'lib/stripe/resources/payment_intent.rb', line 5878 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
5880 5881 5882 |
# File 'lib/stripe/resources/payment_intent.rb', line 5880 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
5882 5883 5884 |
# File 'lib/stripe/resources/payment_intent.rb', line 5882 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
5884 5885 5886 |
# File 'lib/stripe/resources/payment_intent.rb', line 5884 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
5886 5887 5888 |
# File 'lib/stripe/resources/payment_intent.rb', line 5886 def return_at @return_at end |
#return_location_name ⇒ Object
Name of the return location.
5888 5889 5890 |
# File 'lib/stripe/resources/payment_intent.rb', line 5888 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
5890 5891 5892 |
# File 'lib/stripe/resources/payment_intent.rb', line 5890 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object
The vehicle identification number.
5892 5893 5894 |
# File 'lib/stripe/resources/payment_intent.rb', line 5892 def vehicle_identification_number @vehicle_identification_number end |