Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental

Returns a new instance of CarRental.



5779
5780
5781
5782
5783
5784
5785
5786
5787
5788
5789
5790
5791
5792
5793
5794
5795
5796
5797
5798
5799
5800
5801
5802
5803
5804
5805
5806
5807
5808
5809
5810
5811
5812
5813
5814
5815
5816
5817
5818
5819
5820
5821
5822
5823
5824
5825
5826
5827
5828
5829
# File 'lib/stripe/resources/payment_intent.rb', line 5779

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  distance: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  pickup_location_name: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  return_location_name: nil,
  tax_exempt: nil,
  vehicle_identification_number: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @distance = distance
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @pickup_location_name = pickup_location_name
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @return_location_name = return_location_name
  @tax_exempt = tax_exempt
  @vehicle_identification_number = vehicle_identification_number
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



5731
5732
5733
# File 'lib/stripe/resources/payment_intent.rb', line 5731

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



5733
5734
5735
# File 'lib/stripe/resources/payment_intent.rb', line 5733

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



5735
5736
5737
# File 'lib/stripe/resources/payment_intent.rb', line 5735

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



5737
5738
5739
# File 'lib/stripe/resources/payment_intent.rb', line 5737

def car_make
  @car_make
end

#car_modelObject

Model of the car.



5739
5740
5741
# File 'lib/stripe/resources/payment_intent.rb', line 5739

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



5741
5742
5743
# File 'lib/stripe/resources/payment_intent.rb', line 5741

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



5743
5744
5745
# File 'lib/stripe/resources/payment_intent.rb', line 5743

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



5745
5746
5747
# File 'lib/stripe/resources/payment_intent.rb', line 5745

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



5747
5748
5749
# File 'lib/stripe/resources/payment_intent.rb', line 5747

def delivery
  @delivery
end

#distanceObject

The details of the distance traveled during the rental period.



5749
5750
5751
# File 'lib/stripe/resources/payment_intent.rb', line 5749

def distance
  @distance
end

#driversObject

The details of the passengers in the travel reservation



5751
5752
5753
# File 'lib/stripe/resources/payment_intent.rb', line 5751

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



5753
5754
5755
# File 'lib/stripe/resources/payment_intent.rb', line 5753

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



5755
5756
5757
# File 'lib/stripe/resources/payment_intent.rb', line 5755

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



5757
5758
5759
# File 'lib/stripe/resources/payment_intent.rb', line 5757

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



5759
5760
5761
# File 'lib/stripe/resources/payment_intent.rb', line 5759

def pickup_at
  @pickup_at
end

#pickup_location_nameObject

Name of the pickup location.



5761
5762
5763
# File 'lib/stripe/resources/payment_intent.rb', line 5761

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject

Rental rate.



5763
5764
5765
# File 'lib/stripe/resources/payment_intent.rb', line 5763

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



5765
5766
5767
# File 'lib/stripe/resources/payment_intent.rb', line 5765

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



5767
5768
5769
# File 'lib/stripe/resources/payment_intent.rb', line 5767

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



5769
5770
5771
# File 'lib/stripe/resources/payment_intent.rb', line 5769

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



5771
5772
5773
# File 'lib/stripe/resources/payment_intent.rb', line 5771

def return_at
  @return_at
end

#return_location_nameObject

Name of the return location.



5773
5774
5775
# File 'lib/stripe/resources/payment_intent.rb', line 5773

def return_location_name
  @return_location_name
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



5775
5776
5777
# File 'lib/stripe/resources/payment_intent.rb', line 5775

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject

The vehicle identification number.



5777
5778
5779
# File 'lib/stripe/resources/payment_intent.rb', line 5777

def vehicle_identification_number
  @vehicle_identification_number
end