Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental

Returns a new instance of CarRental.



5735
5736
5737
5738
5739
5740
5741
5742
5743
5744
5745
5746
5747
5748
5749
5750
5751
5752
5753
5754
5755
5756
5757
5758
5759
5760
5761
5762
5763
5764
5765
5766
5767
5768
5769
5770
5771
5772
5773
5774
5775
5776
5777
# File 'lib/stripe/resources/payment_intent.rb', line 5735

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  tax_exempt: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @tax_exempt = tax_exempt
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



5695
5696
5697
# File 'lib/stripe/resources/payment_intent.rb', line 5695

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



5697
5698
5699
# File 'lib/stripe/resources/payment_intent.rb', line 5697

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



5699
5700
5701
# File 'lib/stripe/resources/payment_intent.rb', line 5699

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



5701
5702
5703
# File 'lib/stripe/resources/payment_intent.rb', line 5701

def car_make
  @car_make
end

#car_modelObject

Model of the car.



5703
5704
5705
# File 'lib/stripe/resources/payment_intent.rb', line 5703

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



5705
5706
5707
# File 'lib/stripe/resources/payment_intent.rb', line 5705

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



5707
5708
5709
# File 'lib/stripe/resources/payment_intent.rb', line 5707

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



5709
5710
5711
# File 'lib/stripe/resources/payment_intent.rb', line 5709

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



5711
5712
5713
# File 'lib/stripe/resources/payment_intent.rb', line 5711

def delivery
  @delivery
end

#driversObject

The details of the passengers in the travel reservation



5713
5714
5715
# File 'lib/stripe/resources/payment_intent.rb', line 5713

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



5715
5716
5717
# File 'lib/stripe/resources/payment_intent.rb', line 5715

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



5717
5718
5719
# File 'lib/stripe/resources/payment_intent.rb', line 5717

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



5719
5720
5721
# File 'lib/stripe/resources/payment_intent.rb', line 5719

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



5721
5722
5723
# File 'lib/stripe/resources/payment_intent.rb', line 5721

def pickup_at
  @pickup_at
end

#rate_amountObject

Rental rate.



5723
5724
5725
# File 'lib/stripe/resources/payment_intent.rb', line 5723

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



5725
5726
5727
# File 'lib/stripe/resources/payment_intent.rb', line 5725

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



5727
5728
5729
# File 'lib/stripe/resources/payment_intent.rb', line 5727

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



5729
5730
5731
# File 'lib/stripe/resources/payment_intent.rb', line 5729

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



5731
5732
5733
# File 'lib/stripe/resources/payment_intent.rb', line 5731

def return_at
  @return_at
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



5733
5734
5735
# File 'lib/stripe/resources/payment_intent.rb', line 5733

def tax_exempt
  @tax_exempt
end