Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
5691 5692 5693 5694 5695 5696 5697 5698 5699 5700 5701 5702 5703 5704 5705 5706 5707 5708 5709 5710 5711 5712 5713 5714 5715 5716 5717 5718 5719 5720 5721 5722 5723 5724 5725 5726 5727 5728 5729 5730 5731 5732 5733 |
# File 'lib/stripe/resources/payment_intent.rb', line 5691 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
5651 5652 5653 |
# File 'lib/stripe/resources/payment_intent.rb', line 5651 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
5653 5654 5655 |
# File 'lib/stripe/resources/payment_intent.rb', line 5653 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
5655 5656 5657 |
# File 'lib/stripe/resources/payment_intent.rb', line 5655 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
5657 5658 5659 |
# File 'lib/stripe/resources/payment_intent.rb', line 5657 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
5659 5660 5661 |
# File 'lib/stripe/resources/payment_intent.rb', line 5659 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
5661 5662 5663 |
# File 'lib/stripe/resources/payment_intent.rb', line 5661 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
5663 5664 5665 |
# File 'lib/stripe/resources/payment_intent.rb', line 5663 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
5665 5666 5667 |
# File 'lib/stripe/resources/payment_intent.rb', line 5665 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
5667 5668 5669 |
# File 'lib/stripe/resources/payment_intent.rb', line 5667 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
5669 5670 5671 |
# File 'lib/stripe/resources/payment_intent.rb', line 5669 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
5671 5672 5673 |
# File 'lib/stripe/resources/payment_intent.rb', line 5671 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
5673 5674 5675 |
# File 'lib/stripe/resources/payment_intent.rb', line 5673 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
5675 5676 5677 |
# File 'lib/stripe/resources/payment_intent.rb', line 5675 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
5677 5678 5679 |
# File 'lib/stripe/resources/payment_intent.rb', line 5677 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
5679 5680 5681 |
# File 'lib/stripe/resources/payment_intent.rb', line 5679 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
5681 5682 5683 |
# File 'lib/stripe/resources/payment_intent.rb', line 5681 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
5683 5684 5685 |
# File 'lib/stripe/resources/payment_intent.rb', line 5683 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
5685 5686 5687 |
# File 'lib/stripe/resources/payment_intent.rb', line 5685 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
5687 5688 5689 |
# File 'lib/stripe/resources/payment_intent.rb', line 5687 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
5689 5690 5691 |
# File 'lib/stripe/resources/payment_intent.rb', line 5689 def tax_exempt @tax_exempt end |