Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental

Returns a new instance of CarRental.



5477
5478
5479
5480
5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
5501
5502
5503
5504
5505
5506
5507
5508
5509
5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
# File 'lib/stripe/resources/payment_intent.rb', line 5477

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  tax_exempt: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @tax_exempt = tax_exempt
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



5437
5438
5439
# File 'lib/stripe/resources/payment_intent.rb', line 5437

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



5439
5440
5441
# File 'lib/stripe/resources/payment_intent.rb', line 5439

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



5441
5442
5443
# File 'lib/stripe/resources/payment_intent.rb', line 5441

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



5443
5444
5445
# File 'lib/stripe/resources/payment_intent.rb', line 5443

def car_make
  @car_make
end

#car_modelObject

Model of the car.



5445
5446
5447
# File 'lib/stripe/resources/payment_intent.rb', line 5445

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



5447
5448
5449
# File 'lib/stripe/resources/payment_intent.rb', line 5447

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



5449
5450
5451
# File 'lib/stripe/resources/payment_intent.rb', line 5449

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



5451
5452
5453
# File 'lib/stripe/resources/payment_intent.rb', line 5451

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



5453
5454
5455
# File 'lib/stripe/resources/payment_intent.rb', line 5453

def delivery
  @delivery
end

#driversObject

The details of the passengers in the travel reservation



5455
5456
5457
# File 'lib/stripe/resources/payment_intent.rb', line 5455

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



5457
5458
5459
# File 'lib/stripe/resources/payment_intent.rb', line 5457

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



5459
5460
5461
# File 'lib/stripe/resources/payment_intent.rb', line 5459

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



5461
5462
5463
# File 'lib/stripe/resources/payment_intent.rb', line 5461

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



5463
5464
5465
# File 'lib/stripe/resources/payment_intent.rb', line 5463

def pickup_at
  @pickup_at
end

#rate_amountObject

Rental rate.



5465
5466
5467
# File 'lib/stripe/resources/payment_intent.rb', line 5465

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



5467
5468
5469
# File 'lib/stripe/resources/payment_intent.rb', line 5467

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



5469
5470
5471
# File 'lib/stripe/resources/payment_intent.rb', line 5469

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



5471
5472
5473
# File 'lib/stripe/resources/payment_intent.rb', line 5471

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



5473
5474
5475
# File 'lib/stripe/resources/payment_intent.rb', line 5473

def return_at
  @return_at
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



5475
5476
5477
# File 'lib/stripe/resources/payment_intent.rb', line 5475

def tax_exempt
  @tax_exempt
end