Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental

Returns a new instance of CarRental.



6316
6317
6318
6319
6320
6321
6322
6323
6324
6325
6326
6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
6346
6347
6348
6349
6350
6351
6352
6353
6354
6355
6356
6357
6358
# File 'lib/stripe/resources/payment_intent.rb', line 6316

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  tax_exempt: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @tax_exempt = tax_exempt
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



6257
6258
6259
# File 'lib/stripe/resources/payment_intent.rb', line 6257

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



6260
6261
6262
# File 'lib/stripe/resources/payment_intent.rb', line 6260

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



6263
6264
6265
# File 'lib/stripe/resources/payment_intent.rb', line 6263

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



6266
6267
6268
# File 'lib/stripe/resources/payment_intent.rb', line 6266

def car_make
  @car_make
end

#car_modelObject

Model of the car.



6269
6270
6271
# File 'lib/stripe/resources/payment_intent.rb', line 6269

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



6272
6273
6274
# File 'lib/stripe/resources/payment_intent.rb', line 6272

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



6275
6276
6277
# File 'lib/stripe/resources/payment_intent.rb', line 6275

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



6278
6279
6280
# File 'lib/stripe/resources/payment_intent.rb', line 6278

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



6281
6282
6283
# File 'lib/stripe/resources/payment_intent.rb', line 6281

def delivery
  @delivery
end

#driversObject

The details of the passengers in the travel reservation



6284
6285
6286
# File 'lib/stripe/resources/payment_intent.rb', line 6284

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



6287
6288
6289
# File 'lib/stripe/resources/payment_intent.rb', line 6287

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



6290
6291
6292
# File 'lib/stripe/resources/payment_intent.rb', line 6290

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



6293
6294
6295
# File 'lib/stripe/resources/payment_intent.rb', line 6293

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



6296
6297
6298
# File 'lib/stripe/resources/payment_intent.rb', line 6296

def pickup_at
  @pickup_at
end

#rate_amountObject

Rental rate.



6299
6300
6301
# File 'lib/stripe/resources/payment_intent.rb', line 6299

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



6302
6303
6304
# File 'lib/stripe/resources/payment_intent.rb', line 6302

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



6305
6306
6307
# File 'lib/stripe/resources/payment_intent.rb', line 6305

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



6308
6309
6310
# File 'lib/stripe/resources/payment_intent.rb', line 6308

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



6311
6312
6313
# File 'lib/stripe/resources/payment_intent.rb', line 6311

def return_at
  @return_at
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



6314
6315
6316
# File 'lib/stripe/resources/payment_intent.rb', line 6314

def tax_exempt
  @tax_exempt
end