Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental::Affiliate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental::Affiliate
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
The name of the affiliate that originated the purchase.
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Affiliate
constructor
A new instance of Affiliate.
Methods inherited from RequestParams
Constructor Details
#initialize(name: nil) ⇒ Affiliate
Returns a new instance of Affiliate.
6142 6143 6144 |
# File 'lib/stripe/resources/payment_intent.rb', line 6142 def initialize(name: nil) @name = name end |
Instance Attribute Details
#name ⇒ Object
The name of the affiliate that originated the purchase.
6140 6141 6142 |
# File 'lib/stripe/resources/payment_intent.rb', line 6140 def name @name end |