Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



5740
5741
5742
5743
5744
# File 'lib/stripe/resources/payment_intent.rb', line 5740

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



5734
5735
5736
# File 'lib/stripe/resources/payment_intent.rb', line 5734

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



5736
5737
5738
# File 'lib/stripe/resources/payment_intent.rb', line 5736

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



5738
5739
5740
# File 'lib/stripe/resources/payment_intent.rb', line 5738

def phone
  @phone
end