Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
5625 5626 5627 5628 5629 |
# File 'lib/stripe/resources/payment_intent.rb', line 5625 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
5619 5620 5621 |
# File 'lib/stripe/resources/payment_intent.rb', line 5619 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
5621 5622 5623 |
# File 'lib/stripe/resources/payment_intent.rb', line 5621 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
5623 5624 5625 |
# File 'lib/stripe/resources/payment_intent.rb', line 5623 def phone @phone end |