Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
5563 5564 5565 5566 5567 |
# File 'lib/stripe/resources/payment_intent.rb', line 5563 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
5557 5558 5559 |
# File 'lib/stripe/resources/payment_intent.rb', line 5557 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
5559 5560 5561 |
# File 'lib/stripe/resources/payment_intent.rb', line 5559 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
5561 5562 5563 |
# File 'lib/stripe/resources/payment_intent.rb', line 5561 def phone @phone end |