Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



5380
5381
5382
5383
5384
# File 'lib/stripe/resources/payment_intent.rb', line 5380

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



5374
5375
5376
# File 'lib/stripe/resources/payment_intent.rb', line 5374

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



5376
5377
5378
# File 'lib/stripe/resources/payment_intent.rb', line 5376

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



5378
5379
5380
# File 'lib/stripe/resources/payment_intent.rb', line 5378

def phone
  @phone
end