Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



5349
5350
5351
5352
5353
# File 'lib/stripe/resources/payment_intent.rb', line 5349

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



5343
5344
5345
# File 'lib/stripe/resources/payment_intent.rb', line 5343

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



5345
5346
5347
# File 'lib/stripe/resources/payment_intent.rb', line 5345

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



5347
5348
5349
# File 'lib/stripe/resources/payment_intent.rb', line 5347

def phone
  @phone
end