Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



6158
6159
6160
6161
6162
# File 'lib/stripe/resources/payment_intent.rb', line 6158

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



6150
6151
6152
# File 'lib/stripe/resources/payment_intent.rb', line 6150

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



6153
6154
6155
# File 'lib/stripe/resources/payment_intent.rb', line 6153

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



6156
6157
6158
# File 'lib/stripe/resources/payment_intent.rb', line 6156

def phone
  @phone
end