Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
5331 5332 5333 5334 5335 |
# File 'lib/stripe/resources/payment_intent.rb', line 5331 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
5325 5326 5327 |
# File 'lib/stripe/resources/payment_intent.rb', line 5325 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
5327 5328 5329 |
# File 'lib/stripe/resources/payment_intent.rb', line 5327 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
5329 5330 5331 |
# File 'lib/stripe/resources/payment_intent.rb', line 5329 def phone @phone end |