Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
7799 7800 7801 7802 7803 7804 7805 7806 7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 7818 7819 |
# File 'lib/stripe/resources/payment_intent.rb', line 7799 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
7781 7782 7783 |
# File 'lib/stripe/resources/payment_intent.rb', line 7781 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
7783 7784 7785 |
# File 'lib/stripe/resources/payment_intent.rb', line 7783 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
7785 7786 7787 |
# File 'lib/stripe/resources/payment_intent.rb', line 7785 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
7787 7788 7789 |
# File 'lib/stripe/resources/payment_intent.rb', line 7787 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
7789 7790 7791 |
# File 'lib/stripe/resources/payment_intent.rb', line 7789 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
7791 7792 7793 |
# File 'lib/stripe/resources/payment_intent.rb', line 7791 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
7793 7794 7795 |
# File 'lib/stripe/resources/payment_intent.rb', line 7793 def genre @genre end |
#name ⇒ Object
The name of the event.
7795 7796 7797 |
# File 'lib/stripe/resources/payment_intent.rb', line 7795 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
7797 7798 7799 |
# File 'lib/stripe/resources/payment_intent.rb', line 7797 def starts_at @starts_at end |