Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
6342 6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 |
# File 'lib/stripe/resources/payment_intent.rb', line 6342 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
6324 6325 6326 |
# File 'lib/stripe/resources/payment_intent.rb', line 6324 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
6326 6327 6328 |
# File 'lib/stripe/resources/payment_intent.rb', line 6326 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
6328 6329 6330 |
# File 'lib/stripe/resources/payment_intent.rb', line 6328 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
6330 6331 6332 |
# File 'lib/stripe/resources/payment_intent.rb', line 6330 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
6332 6333 6334 |
# File 'lib/stripe/resources/payment_intent.rb', line 6332 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
6334 6335 6336 |
# File 'lib/stripe/resources/payment_intent.rb', line 6334 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
6336 6337 6338 |
# File 'lib/stripe/resources/payment_intent.rb', line 6336 def genre @genre end |
#name ⇒ Object
The name of the event.
6338 6339 6340 |
# File 'lib/stripe/resources/payment_intent.rb', line 6338 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
6340 6341 6342 |
# File 'lib/stripe/resources/payment_intent.rb', line 6340 def starts_at @starts_at end |