Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
6032 6033 6034 6035 6036 6037 6038 6039 6040 6041 6042 6043 6044 6045 6046 6047 6048 6049 6050 6051 6052 |
# File 'lib/stripe/resources/payment_intent.rb', line 6032 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
6014 6015 6016 |
# File 'lib/stripe/resources/payment_intent.rb', line 6014 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
6016 6017 6018 |
# File 'lib/stripe/resources/payment_intent.rb', line 6016 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
6018 6019 6020 |
# File 'lib/stripe/resources/payment_intent.rb', line 6018 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
6020 6021 6022 |
# File 'lib/stripe/resources/payment_intent.rb', line 6020 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
6022 6023 6024 |
# File 'lib/stripe/resources/payment_intent.rb', line 6022 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
6024 6025 6026 |
# File 'lib/stripe/resources/payment_intent.rb', line 6024 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
6026 6027 6028 |
# File 'lib/stripe/resources/payment_intent.rb', line 6026 def genre @genre end |
#name ⇒ Object
The name of the event.
6028 6029 6030 |
# File 'lib/stripe/resources/payment_intent.rb', line 6028 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
6030 6031 6032 |
# File 'lib/stripe/resources/payment_intent.rb', line 6030 def starts_at @starts_at end |