Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
5917 5918 5919 5920 5921 5922 5923 5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 5936 5937 |
# File 'lib/stripe/resources/payment_intent.rb', line 5917 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
5899 5900 5901 |
# File 'lib/stripe/resources/payment_intent.rb', line 5899 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
5901 5902 5903 |
# File 'lib/stripe/resources/payment_intent.rb', line 5901 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
5903 5904 5905 |
# File 'lib/stripe/resources/payment_intent.rb', line 5903 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
5905 5906 5907 |
# File 'lib/stripe/resources/payment_intent.rb', line 5905 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
5907 5908 5909 |
# File 'lib/stripe/resources/payment_intent.rb', line 5907 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
5909 5910 5911 |
# File 'lib/stripe/resources/payment_intent.rb', line 5909 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
5911 5912 5913 |
# File 'lib/stripe/resources/payment_intent.rb', line 5911 def genre @genre end |
#name ⇒ Object
The name of the event.
5913 5914 5915 |
# File 'lib/stripe/resources/payment_intent.rb', line 5913 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
5915 5916 5917 |
# File 'lib/stripe/resources/payment_intent.rb', line 5915 def starts_at @starts_at end |