Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
5865 5866 5867 5868 5869 5870 5871 5872 5873 5874 5875 5876 5877 5878 5879 5880 5881 5882 5883 5884 5885 |
# File 'lib/stripe/resources/payment_intent.rb', line 5865 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
5847 5848 5849 |
# File 'lib/stripe/resources/payment_intent.rb', line 5847 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
5849 5850 5851 |
# File 'lib/stripe/resources/payment_intent.rb', line 5849 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
5851 5852 5853 |
# File 'lib/stripe/resources/payment_intent.rb', line 5851 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
5853 5854 5855 |
# File 'lib/stripe/resources/payment_intent.rb', line 5853 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
5855 5856 5857 |
# File 'lib/stripe/resources/payment_intent.rb', line 5855 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
5857 5858 5859 |
# File 'lib/stripe/resources/payment_intent.rb', line 5857 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
5859 5860 5861 |
# File 'lib/stripe/resources/payment_intent.rb', line 5859 def genre @genre end |
#name ⇒ Object
The name of the event.
5861 5862 5863 |
# File 'lib/stripe/resources/payment_intent.rb', line 5861 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
5863 5864 5865 |
# File 'lib/stripe/resources/payment_intent.rb', line 5863 def starts_at @starts_at end |