Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
5821 5822 5823 5824 5825 5826 5827 5828 5829 5830 5831 5832 5833 5834 5835 5836 5837 5838 5839 5840 5841 |
# File 'lib/stripe/resources/payment_intent.rb', line 5821 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
5803 5804 5805 |
# File 'lib/stripe/resources/payment_intent.rb', line 5803 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
5805 5806 5807 |
# File 'lib/stripe/resources/payment_intent.rb', line 5805 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
5807 5808 5809 |
# File 'lib/stripe/resources/payment_intent.rb', line 5807 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
5809 5810 5811 |
# File 'lib/stripe/resources/payment_intent.rb', line 5809 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
5811 5812 5813 |
# File 'lib/stripe/resources/payment_intent.rb', line 5811 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
5813 5814 5815 |
# File 'lib/stripe/resources/payment_intent.rb', line 5813 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
5815 5816 5817 |
# File 'lib/stripe/resources/payment_intent.rb', line 5815 def genre @genre end |
#name ⇒ Object
The name of the event.
5817 5818 5819 |
# File 'lib/stripe/resources/payment_intent.rb', line 5817 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
5819 5820 5821 |
# File 'lib/stripe/resources/payment_intent.rb', line 5819 def starts_at @starts_at end |