Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
5607 5608 5609 5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 5625 5626 5627 |
# File 'lib/stripe/resources/payment_intent.rb', line 5607 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
5589 5590 5591 |
# File 'lib/stripe/resources/payment_intent.rb', line 5589 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
5591 5592 5593 |
# File 'lib/stripe/resources/payment_intent.rb', line 5591 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
5593 5594 5595 |
# File 'lib/stripe/resources/payment_intent.rb', line 5593 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
5595 5596 5597 |
# File 'lib/stripe/resources/payment_intent.rb', line 5595 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
5597 5598 5599 |
# File 'lib/stripe/resources/payment_intent.rb', line 5597 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
5599 5600 5601 |
# File 'lib/stripe/resources/payment_intent.rb', line 5599 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
5601 5602 5603 |
# File 'lib/stripe/resources/payment_intent.rb', line 5601 def genre @genre end |
#name ⇒ Object
The name of the event.
5603 5604 5605 |
# File 'lib/stripe/resources/payment_intent.rb', line 5603 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
5605 5606 5607 |
# File 'lib/stripe/resources/payment_intent.rb', line 5605 def starts_at @starts_at end |