Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 6474 6475 6476 6477 6478 6479 6480 6481 6482 |
# File 'lib/stripe/resources/payment_intent.rb', line 6462 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
6436 6437 6438 |
# File 'lib/stripe/resources/payment_intent.rb', line 6436 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
6439 6440 6441 |
# File 'lib/stripe/resources/payment_intent.rb', line 6439 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
6442 6443 6444 |
# File 'lib/stripe/resources/payment_intent.rb', line 6442 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
6445 6446 6447 |
# File 'lib/stripe/resources/payment_intent.rb', line 6445 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
6448 6449 6450 |
# File 'lib/stripe/resources/payment_intent.rb', line 6448 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
6451 6452 6453 |
# File 'lib/stripe/resources/payment_intent.rb', line 6451 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
6454 6455 6456 |
# File 'lib/stripe/resources/payment_intent.rb', line 6454 def genre @genre end |
#name ⇒ Object
The name of the event.
6457 6458 6459 |
# File 'lib/stripe/resources/payment_intent.rb', line 6457 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
6460 6461 6462 |
# File 'lib/stripe/resources/payment_intent.rb', line 6460 def starts_at @starts_at end |