Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
5589 5590 5591 5592 5593 5594 5595 5596 5597 5598 5599 5600 5601 5602 5603 5604 5605 5606 5607 5608 5609 |
# File 'lib/stripe/resources/payment_intent.rb', line 5589 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
5571 5572 5573 |
# File 'lib/stripe/resources/payment_intent.rb', line 5571 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
5573 5574 5575 |
# File 'lib/stripe/resources/payment_intent.rb', line 5573 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
5575 5576 5577 |
# File 'lib/stripe/resources/payment_intent.rb', line 5575 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
5577 5578 5579 |
# File 'lib/stripe/resources/payment_intent.rb', line 5577 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
5579 5580 5581 |
# File 'lib/stripe/resources/payment_intent.rb', line 5579 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
5581 5582 5583 |
# File 'lib/stripe/resources/payment_intent.rb', line 5581 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
5583 5584 5585 |
# File 'lib/stripe/resources/payment_intent.rb', line 5583 def genre @genre end |
#name ⇒ Object
The name of the event.
5585 5586 5587 |
# File 'lib/stripe/resources/payment_intent.rb', line 5585 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
5587 5588 5589 |
# File 'lib/stripe/resources/payment_intent.rb', line 5587 def starts_at @starts_at end |