Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
7764 7765 7766 7767 7768 |
# File 'lib/stripe/resources/payment_intent.rb', line 7764 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
7758 7759 7760 |
# File 'lib/stripe/resources/payment_intent.rb', line 7758 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
7760 7761 7762 |
# File 'lib/stripe/resources/payment_intent.rb', line 7760 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
7762 7763 7764 |
# File 'lib/stripe/resources/payment_intent.rb', line 7762 def phone @phone end |