Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



6307
6308
6309
6310
6311
# File 'lib/stripe/resources/payment_intent.rb', line 6307

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



6301
6302
6303
# File 'lib/stripe/resources/payment_intent.rb', line 6301

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



6303
6304
6305
# File 'lib/stripe/resources/payment_intent.rb', line 6303

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



6305
6306
6307
# File 'lib/stripe/resources/payment_intent.rb', line 6305

def phone
  @phone
end