Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



5997
5998
5999
6000
6001
# File 'lib/stripe/resources/payment_intent.rb', line 5997

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



5991
5992
5993
# File 'lib/stripe/resources/payment_intent.rb', line 5991

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



5993
5994
5995
# File 'lib/stripe/resources/payment_intent.rb', line 5993

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



5995
5996
5997
# File 'lib/stripe/resources/payment_intent.rb', line 5995

def phone
  @phone
end