Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



5882
5883
5884
5885
5886
# File 'lib/stripe/resources/payment_intent.rb', line 5882

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



5876
5877
5878
# File 'lib/stripe/resources/payment_intent.rb', line 5876

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



5878
5879
5880
# File 'lib/stripe/resources/payment_intent.rb', line 5878

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



5880
5881
5882
# File 'lib/stripe/resources/payment_intent.rb', line 5880

def phone
  @phone
end