Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
5830 5831 5832 5833 5834 |
# File 'lib/stripe/resources/payment_intent.rb', line 5830 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
5824 5825 5826 |
# File 'lib/stripe/resources/payment_intent.rb', line 5824 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
5826 5827 5828 |
# File 'lib/stripe/resources/payment_intent.rb', line 5826 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
5828 5829 5830 |
# File 'lib/stripe/resources/payment_intent.rb', line 5828 def phone @phone end |