Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
5786 5787 5788 5789 5790 |
# File 'lib/stripe/resources/payment_intent.rb', line 5786 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
5780 5781 5782 |
# File 'lib/stripe/resources/payment_intent.rb', line 5780 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
5782 5783 5784 |
# File 'lib/stripe/resources/payment_intent.rb', line 5782 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
5784 5785 5786 |
# File 'lib/stripe/resources/payment_intent.rb', line 5784 def phone @phone end |