Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
5603 5604 5605 5606 5607 |
# File 'lib/stripe/resources/payment_intent.rb', line 5603 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
5597 5598 5599 |
# File 'lib/stripe/resources/payment_intent.rb', line 5597 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
5599 5600 5601 |
# File 'lib/stripe/resources/payment_intent.rb', line 5599 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
5601 5602 5603 |
# File 'lib/stripe/resources/payment_intent.rb', line 5601 def phone @phone end |