Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 6167 6168 6169 6170 6171 6172 6173 |
# File 'lib/stripe/resources/payment_intent.rb', line 6155 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
6139 6140 6141 |
# File 'lib/stripe/resources/payment_intent.rb', line 6139 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
6141 6142 6143 |
# File 'lib/stripe/resources/payment_intent.rb', line 6141 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
6143 6144 6145 |
# File 'lib/stripe/resources/payment_intent.rb', line 6143 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
6145 6146 6147 |
# File 'lib/stripe/resources/payment_intent.rb', line 6145 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
6147 6148 6149 |
# File 'lib/stripe/resources/payment_intent.rb', line 6147 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
6149 6150 6151 |
# File 'lib/stripe/resources/payment_intent.rb', line 6149 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
6151 6152 6153 |
# File 'lib/stripe/resources/payment_intent.rb', line 6151 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
6153 6154 6155 |
# File 'lib/stripe/resources/payment_intent.rb', line 6153 def ticket_number @ticket_number end |