Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
6040 6041 6042 6043 6044 6045 6046 6047 6048 6049 6050 6051 6052 6053 6054 6055 6056 6057 6058 |
# File 'lib/stripe/resources/payment_intent.rb', line 6040 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
6024 6025 6026 |
# File 'lib/stripe/resources/payment_intent.rb', line 6024 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
6026 6027 6028 |
# File 'lib/stripe/resources/payment_intent.rb', line 6026 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
6028 6029 6030 |
# File 'lib/stripe/resources/payment_intent.rb', line 6028 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
6030 6031 6032 |
# File 'lib/stripe/resources/payment_intent.rb', line 6030 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
6032 6033 6034 |
# File 'lib/stripe/resources/payment_intent.rb', line 6032 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
6034 6035 6036 |
# File 'lib/stripe/resources/payment_intent.rb', line 6034 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
6036 6037 6038 |
# File 'lib/stripe/resources/payment_intent.rb', line 6036 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
6038 6039 6040 |
# File 'lib/stripe/resources/payment_intent.rb', line 6038 def ticket_number @ticket_number end |