Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 |
# File 'lib/stripe/resources/payment_intent.rb', line 5988 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
5972 5973 5974 |
# File 'lib/stripe/resources/payment_intent.rb', line 5972 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
5974 5975 5976 |
# File 'lib/stripe/resources/payment_intent.rb', line 5974 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
5976 5977 5978 |
# File 'lib/stripe/resources/payment_intent.rb', line 5976 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
5978 5979 5980 |
# File 'lib/stripe/resources/payment_intent.rb', line 5978 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
5980 5981 5982 |
# File 'lib/stripe/resources/payment_intent.rb', line 5980 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
5982 5983 5984 |
# File 'lib/stripe/resources/payment_intent.rb', line 5982 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
5984 5985 5986 |
# File 'lib/stripe/resources/payment_intent.rb', line 5984 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
5986 5987 5988 |
# File 'lib/stripe/resources/payment_intent.rb', line 5986 def ticket_number @ticket_number end |