Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
5712 5713 5714 5715 5716 5717 5718 5719 5720 5721 5722 5723 5724 5725 5726 5727 5728 5729 5730 |
# File 'lib/stripe/resources/payment_intent.rb', line 5712 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
5696 5697 5698 |
# File 'lib/stripe/resources/payment_intent.rb', line 5696 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
5698 5699 5700 |
# File 'lib/stripe/resources/payment_intent.rb', line 5698 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
5700 5701 5702 |
# File 'lib/stripe/resources/payment_intent.rb', line 5700 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
5702 5703 5704 |
# File 'lib/stripe/resources/payment_intent.rb', line 5702 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
5704 5705 5706 |
# File 'lib/stripe/resources/payment_intent.rb', line 5704 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
5706 5707 5708 |
# File 'lib/stripe/resources/payment_intent.rb', line 5706 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
5708 5709 5710 |
# File 'lib/stripe/resources/payment_intent.rb', line 5708 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
5710 5711 5712 |
# File 'lib/stripe/resources/payment_intent.rb', line 5710 def ticket_number @ticket_number end |