Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
6384 6385 6386 6387 6388 |
# File 'lib/stripe/resources/payment_intent.rb', line 6384 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
6378 6379 6380 |
# File 'lib/stripe/resources/payment_intent.rb', line 6378 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
6380 6381 6382 |
# File 'lib/stripe/resources/payment_intent.rb', line 6380 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
6382 6383 6384 |
# File 'lib/stripe/resources/payment_intent.rb', line 6382 def phone @phone end |