Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



6074
6075
6076
6077
6078
# File 'lib/stripe/resources/payment_intent.rb', line 6074

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



6068
6069
6070
# File 'lib/stripe/resources/payment_intent.rb', line 6068

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



6070
6071
6072
# File 'lib/stripe/resources/payment_intent.rb', line 6070

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



6072
6073
6074
# File 'lib/stripe/resources/payment_intent.rb', line 6072

def phone
  @phone
end