Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



5907
5908
5909
5910
5911
# File 'lib/stripe/resources/payment_intent.rb', line 5907

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



5901
5902
5903
# File 'lib/stripe/resources/payment_intent.rb', line 5901

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



5903
5904
5905
# File 'lib/stripe/resources/payment_intent.rb', line 5903

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



5905
5906
5907
# File 'lib/stripe/resources/payment_intent.rb', line 5905

def phone
  @phone
end