Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



5680
5681
5682
5683
5684
# File 'lib/stripe/resources/payment_intent.rb', line 5680

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



5674
5675
5676
# File 'lib/stripe/resources/payment_intent.rb', line 5674

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



5676
5677
5678
# File 'lib/stripe/resources/payment_intent.rb', line 5676

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



5678
5679
5680
# File 'lib/stripe/resources/payment_intent.rb', line 5678

def phone
  @phone
end