Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
5649 5650 5651 5652 5653 |
# File 'lib/stripe/resources/payment_intent.rb', line 5649 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
5643 5644 5645 |
# File 'lib/stripe/resources/payment_intent.rb', line 5643 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
5645 5646 5647 |
# File 'lib/stripe/resources/payment_intent.rb', line 5645 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
5647 5648 5649 |
# File 'lib/stripe/resources/payment_intent.rb', line 5647 def phone @phone end |