Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



8061
8062
8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
8089
8090
8091
8092
8093
8094
8095
8096
8097
8098
8099
8100
8101
8102
8103
8104
8105
# File 'lib/stripe/resources/payment_intent.rb', line 8061

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



8019
8020
8021
# File 'lib/stripe/resources/payment_intent.rb', line 8019

def address
  @address
end

#adultsObject

The number of adults on the booking



8021
8022
8023
# File 'lib/stripe/resources/payment_intent.rb', line 8021

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



8023
8024
8025
# File 'lib/stripe/resources/payment_intent.rb', line 8023

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



8025
8026
8027
# File 'lib/stripe/resources/payment_intent.rb', line 8025

def booking_number
  @booking_number
end

#categoryObject

The lodging category



8027
8028
8029
# File 'lib/stripe/resources/payment_intent.rb', line 8027

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



8029
8030
8031
# File 'lib/stripe/resources/payment_intent.rb', line 8029

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



8031
8032
8033
# File 'lib/stripe/resources/payment_intent.rb', line 8031

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



8033
8034
8035
# File 'lib/stripe/resources/payment_intent.rb', line 8033

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



8035
8036
8037
# File 'lib/stripe/resources/payment_intent.rb', line 8035

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



8037
8038
8039
# File 'lib/stripe/resources/payment_intent.rb', line 8037

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



8039
8040
8041
# File 'lib/stripe/resources/payment_intent.rb', line 8039

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



8041
8042
8043
# File 'lib/stripe/resources/payment_intent.rb', line 8041

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



8043
8044
8045
# File 'lib/stripe/resources/payment_intent.rb', line 8043

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



8045
8046
8047
# File 'lib/stripe/resources/payment_intent.rb', line 8045

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



8047
8048
8049
# File 'lib/stripe/resources/payment_intent.rb', line 8047

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



8049
8050
8051
# File 'lib/stripe/resources/payment_intent.rb', line 8049

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



8051
8052
8053
# File 'lib/stripe/resources/payment_intent.rb', line 8051

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



8053
8054
8055
# File 'lib/stripe/resources/payment_intent.rb', line 8053

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



8055
8056
8057
# File 'lib/stripe/resources/payment_intent.rb', line 8055

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



8057
8058
8059
# File 'lib/stripe/resources/payment_intent.rb', line 8057

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



8059
8060
8061
# File 'lib/stripe/resources/payment_intent.rb', line 8059

def total_tax_amount
  @total_tax_amount
end