Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 6634 6635 6636 6637 6638 6639 6640 6641 6642 6643 6644 6645 6646 6647 6648 |
# File 'lib/stripe/resources/payment_intent.rb', line 6604 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
6562 6563 6564 |
# File 'lib/stripe/resources/payment_intent.rb', line 6562 def address @address end |
#adults ⇒ Object
The number of adults on the booking
6564 6565 6566 |
# File 'lib/stripe/resources/payment_intent.rb', line 6564 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
6566 6567 6568 |
# File 'lib/stripe/resources/payment_intent.rb', line 6566 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
6568 6569 6570 |
# File 'lib/stripe/resources/payment_intent.rb', line 6568 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
6570 6571 6572 |
# File 'lib/stripe/resources/payment_intent.rb', line 6570 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
6572 6573 6574 |
# File 'lib/stripe/resources/payment_intent.rb', line 6572 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
6574 6575 6576 |
# File 'lib/stripe/resources/payment_intent.rb', line 6574 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
6576 6577 6578 |
# File 'lib/stripe/resources/payment_intent.rb', line 6576 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
6578 6579 6580 |
# File 'lib/stripe/resources/payment_intent.rb', line 6578 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
6580 6581 6582 |
# File 'lib/stripe/resources/payment_intent.rb', line 6580 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
6582 6583 6584 |
# File 'lib/stripe/resources/payment_intent.rb', line 6582 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
6584 6585 6586 |
# File 'lib/stripe/resources/payment_intent.rb', line 6584 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
6586 6587 6588 |
# File 'lib/stripe/resources/payment_intent.rb', line 6586 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
6588 6589 6590 |
# File 'lib/stripe/resources/payment_intent.rb', line 6588 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
6590 6591 6592 |
# File 'lib/stripe/resources/payment_intent.rb', line 6590 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
6592 6593 6594 |
# File 'lib/stripe/resources/payment_intent.rb', line 6592 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
6594 6595 6596 |
# File 'lib/stripe/resources/payment_intent.rb', line 6594 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
6596 6597 6598 |
# File 'lib/stripe/resources/payment_intent.rb', line 6596 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
6598 6599 6600 |
# File 'lib/stripe/resources/payment_intent.rb', line 6598 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
6600 6601 6602 |
# File 'lib/stripe/resources/payment_intent.rb', line 6600 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
6602 6603 6604 |
# File 'lib/stripe/resources/payment_intent.rb', line 6602 def total_tax_amount @total_tax_amount end |