Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
6321
6322
6323
6324
6325
6326
6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
6337
6338
# File 'lib/stripe/resources/payment_intent.rb', line 6294

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



6252
6253
6254
# File 'lib/stripe/resources/payment_intent.rb', line 6252

def address
  @address
end

#adultsObject

The number of adults on the booking



6254
6255
6256
# File 'lib/stripe/resources/payment_intent.rb', line 6254

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



6256
6257
6258
# File 'lib/stripe/resources/payment_intent.rb', line 6256

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



6258
6259
6260
# File 'lib/stripe/resources/payment_intent.rb', line 6258

def booking_number
  @booking_number
end

#categoryObject

The lodging category



6260
6261
6262
# File 'lib/stripe/resources/payment_intent.rb', line 6260

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



6262
6263
6264
# File 'lib/stripe/resources/payment_intent.rb', line 6262

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



6264
6265
6266
# File 'lib/stripe/resources/payment_intent.rb', line 6264

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



6266
6267
6268
# File 'lib/stripe/resources/payment_intent.rb', line 6266

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



6268
6269
6270
# File 'lib/stripe/resources/payment_intent.rb', line 6268

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



6270
6271
6272
# File 'lib/stripe/resources/payment_intent.rb', line 6270

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



6272
6273
6274
# File 'lib/stripe/resources/payment_intent.rb', line 6272

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



6274
6275
6276
# File 'lib/stripe/resources/payment_intent.rb', line 6274

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



6276
6277
6278
# File 'lib/stripe/resources/payment_intent.rb', line 6276

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



6278
6279
6280
# File 'lib/stripe/resources/payment_intent.rb', line 6278

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



6280
6281
6282
# File 'lib/stripe/resources/payment_intent.rb', line 6280

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



6282
6283
6284
# File 'lib/stripe/resources/payment_intent.rb', line 6282

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



6284
6285
6286
# File 'lib/stripe/resources/payment_intent.rb', line 6284

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



6286
6287
6288
# File 'lib/stripe/resources/payment_intent.rb', line 6286

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



6288
6289
6290
# File 'lib/stripe/resources/payment_intent.rb', line 6288

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



6290
6291
6292
# File 'lib/stripe/resources/payment_intent.rb', line 6290

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



6292
6293
6294
# File 'lib/stripe/resources/payment_intent.rb', line 6292

def total_tax_amount
  @total_tax_amount
end