Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
6203
6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
6218
6219
6220
6221
6222
6223
# File 'lib/stripe/resources/payment_intent.rb', line 6179

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



6137
6138
6139
# File 'lib/stripe/resources/payment_intent.rb', line 6137

def address
  @address
end

#adultsObject

The number of adults on the booking



6139
6140
6141
# File 'lib/stripe/resources/payment_intent.rb', line 6139

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



6141
6142
6143
# File 'lib/stripe/resources/payment_intent.rb', line 6141

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



6143
6144
6145
# File 'lib/stripe/resources/payment_intent.rb', line 6143

def booking_number
  @booking_number
end

#categoryObject

The lodging category



6145
6146
6147
# File 'lib/stripe/resources/payment_intent.rb', line 6145

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



6147
6148
6149
# File 'lib/stripe/resources/payment_intent.rb', line 6147

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



6149
6150
6151
# File 'lib/stripe/resources/payment_intent.rb', line 6149

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



6151
6152
6153
# File 'lib/stripe/resources/payment_intent.rb', line 6151

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



6153
6154
6155
# File 'lib/stripe/resources/payment_intent.rb', line 6153

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



6155
6156
6157
# File 'lib/stripe/resources/payment_intent.rb', line 6155

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



6157
6158
6159
# File 'lib/stripe/resources/payment_intent.rb', line 6157

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



6159
6160
6161
# File 'lib/stripe/resources/payment_intent.rb', line 6159

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



6161
6162
6163
# File 'lib/stripe/resources/payment_intent.rb', line 6161

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



6163
6164
6165
# File 'lib/stripe/resources/payment_intent.rb', line 6163

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



6165
6166
6167
# File 'lib/stripe/resources/payment_intent.rb', line 6165

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



6167
6168
6169
# File 'lib/stripe/resources/payment_intent.rb', line 6167

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



6169
6170
6171
# File 'lib/stripe/resources/payment_intent.rb', line 6169

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



6171
6172
6173
# File 'lib/stripe/resources/payment_intent.rb', line 6171

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



6173
6174
6175
# File 'lib/stripe/resources/payment_intent.rb', line 6173

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



6175
6176
6177
# File 'lib/stripe/resources/payment_intent.rb', line 6175

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



6177
6178
6179
# File 'lib/stripe/resources/payment_intent.rb', line 6177

def total_tax_amount
  @total_tax_amount
end