Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Loding check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
6083 6084 6085 6086 6087 6088 6089 6090 6091 6092 6093 6094 6095 6096 6097 6098 6099 6100 6101 6102 6103 6104 6105 6106 6107 6108 6109 6110 6111 6112 6113 6114 6115 6116 6117 6118 6119 6120 6121 6122 6123 6124 6125 6126 6127 |
# File 'lib/stripe/resources/payment_intent.rb', line 6083 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
6041 6042 6043 |
# File 'lib/stripe/resources/payment_intent.rb', line 6041 def address @address end |
#adults ⇒ Object
The number of adults on the booking
6043 6044 6045 |
# File 'lib/stripe/resources/payment_intent.rb', line 6043 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
6045 6046 6047 |
# File 'lib/stripe/resources/payment_intent.rb', line 6045 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
6047 6048 6049 |
# File 'lib/stripe/resources/payment_intent.rb', line 6047 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
6049 6050 6051 |
# File 'lib/stripe/resources/payment_intent.rb', line 6049 def category @category end |
#checkin_at ⇒ Object
Loding check-in time. Measured in seconds since the Unix epoch.
6051 6052 6053 |
# File 'lib/stripe/resources/payment_intent.rb', line 6051 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
6053 6054 6055 |
# File 'lib/stripe/resources/payment_intent.rb', line 6053 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
6055 6056 6057 |
# File 'lib/stripe/resources/payment_intent.rb', line 6055 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
6057 6058 6059 |
# File 'lib/stripe/resources/payment_intent.rb', line 6057 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
6059 6060 6061 |
# File 'lib/stripe/resources/payment_intent.rb', line 6059 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
6061 6062 6063 |
# File 'lib/stripe/resources/payment_intent.rb', line 6061 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
6063 6064 6065 |
# File 'lib/stripe/resources/payment_intent.rb', line 6063 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
6065 6066 6067 |
# File 'lib/stripe/resources/payment_intent.rb', line 6065 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
6067 6068 6069 |
# File 'lib/stripe/resources/payment_intent.rb', line 6067 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
6069 6070 6071 |
# File 'lib/stripe/resources/payment_intent.rb', line 6069 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
6071 6072 6073 |
# File 'lib/stripe/resources/payment_intent.rb', line 6071 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
6073 6074 6075 |
# File 'lib/stripe/resources/payment_intent.rb', line 6073 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
6075 6076 6077 |
# File 'lib/stripe/resources/payment_intent.rb', line 6075 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
6077 6078 6079 |
# File 'lib/stripe/resources/payment_intent.rb', line 6077 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
6079 6080 6081 |
# File 'lib/stripe/resources/payment_intent.rb', line 6079 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
6081 6082 6083 |
# File 'lib/stripe/resources/payment_intent.rb', line 6081 def total_tax_amount @total_tax_amount end |