Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
5919
5920
5921
5922
5923
5924
5925
5926
5927
5928
5929
5930
5931
5932
5933
5934
5935
5936
5937
5938
5939
5940
5941
5942
5943
5944
# File 'lib/stripe/resources/payment_intent.rb', line 5900

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



5858
5859
5860
# File 'lib/stripe/resources/payment_intent.rb', line 5858

def address
  @address
end

#adultsObject

The number of adults on the booking



5860
5861
5862
# File 'lib/stripe/resources/payment_intent.rb', line 5860

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



5862
5863
5864
# File 'lib/stripe/resources/payment_intent.rb', line 5862

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



5864
5865
5866
# File 'lib/stripe/resources/payment_intent.rb', line 5864

def booking_number
  @booking_number
end

#categoryObject

The lodging category



5866
5867
5868
# File 'lib/stripe/resources/payment_intent.rb', line 5866

def category
  @category
end

#checkin_atObject

Loding check-in time. Measured in seconds since the Unix epoch.



5868
5869
5870
# File 'lib/stripe/resources/payment_intent.rb', line 5868

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



5870
5871
5872
# File 'lib/stripe/resources/payment_intent.rb', line 5870

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



5872
5873
5874
# File 'lib/stripe/resources/payment_intent.rb', line 5872

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



5874
5875
5876
# File 'lib/stripe/resources/payment_intent.rb', line 5874

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



5876
5877
5878
# File 'lib/stripe/resources/payment_intent.rb', line 5876

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



5878
5879
5880
# File 'lib/stripe/resources/payment_intent.rb', line 5878

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



5880
5881
5882
# File 'lib/stripe/resources/payment_intent.rb', line 5880

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



5882
5883
5884
# File 'lib/stripe/resources/payment_intent.rb', line 5882

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



5884
5885
5886
# File 'lib/stripe/resources/payment_intent.rb', line 5884

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



5886
5887
5888
# File 'lib/stripe/resources/payment_intent.rb', line 5886

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



5888
5889
5890
# File 'lib/stripe/resources/payment_intent.rb', line 5888

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



5890
5891
5892
# File 'lib/stripe/resources/payment_intent.rb', line 5890

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



5892
5893
5894
# File 'lib/stripe/resources/payment_intent.rb', line 5892

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



5894
5895
5896
# File 'lib/stripe/resources/payment_intent.rb', line 5894

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



5896
5897
5898
# File 'lib/stripe/resources/payment_intent.rb', line 5896

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



5898
5899
5900
# File 'lib/stripe/resources/payment_intent.rb', line 5898

def total_tax_amount
  @total_tax_amount
end