Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Loding check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
6769 6770 6771 6772 6773 6774 6775 6776 6777 6778 6779 6780 6781 6782 6783 6784 6785 6786 6787 6788 6789 6790 6791 6792 6793 6794 6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 6813 |
# File 'lib/stripe/resources/payment_intent.rb', line 6769 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
6707 6708 6709 |
# File 'lib/stripe/resources/payment_intent.rb', line 6707 def address @address end |
#adults ⇒ Object
The number of adults on the booking
6710 6711 6712 |
# File 'lib/stripe/resources/payment_intent.rb', line 6710 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
6713 6714 6715 |
# File 'lib/stripe/resources/payment_intent.rb', line 6713 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
6716 6717 6718 |
# File 'lib/stripe/resources/payment_intent.rb', line 6716 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
6719 6720 6721 |
# File 'lib/stripe/resources/payment_intent.rb', line 6719 def category @category end |
#checkin_at ⇒ Object
Loding check-in time. Measured in seconds since the Unix epoch.
6722 6723 6724 |
# File 'lib/stripe/resources/payment_intent.rb', line 6722 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
6725 6726 6727 |
# File 'lib/stripe/resources/payment_intent.rb', line 6725 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
6728 6729 6730 |
# File 'lib/stripe/resources/payment_intent.rb', line 6728 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
6731 6732 6733 |
# File 'lib/stripe/resources/payment_intent.rb', line 6731 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
6734 6735 6736 |
# File 'lib/stripe/resources/payment_intent.rb', line 6734 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
6737 6738 6739 |
# File 'lib/stripe/resources/payment_intent.rb', line 6737 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
6740 6741 6742 |
# File 'lib/stripe/resources/payment_intent.rb', line 6740 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
6743 6744 6745 |
# File 'lib/stripe/resources/payment_intent.rb', line 6743 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
6746 6747 6748 |
# File 'lib/stripe/resources/payment_intent.rb', line 6746 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
6749 6750 6751 |
# File 'lib/stripe/resources/payment_intent.rb', line 6749 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
6752 6753 6754 |
# File 'lib/stripe/resources/payment_intent.rb', line 6752 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
6755 6756 6757 |
# File 'lib/stripe/resources/payment_intent.rb', line 6755 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
6758 6759 6760 |
# File 'lib/stripe/resources/payment_intent.rb', line 6758 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
6761 6762 6763 |
# File 'lib/stripe/resources/payment_intent.rb', line 6761 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
6764 6765 6766 |
# File 'lib/stripe/resources/payment_intent.rb', line 6764 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
6767 6768 6769 |
# File 'lib/stripe/resources/payment_intent.rb', line 6767 def total_tax_amount @total_tax_amount end |