Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
5893
5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
# File 'lib/stripe/resources/payment_intent.rb', line 5869

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



5827
5828
5829
# File 'lib/stripe/resources/payment_intent.rb', line 5827

def address
  @address
end

#adultsObject

The number of adults on the booking



5829
5830
5831
# File 'lib/stripe/resources/payment_intent.rb', line 5829

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



5831
5832
5833
# File 'lib/stripe/resources/payment_intent.rb', line 5831

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



5833
5834
5835
# File 'lib/stripe/resources/payment_intent.rb', line 5833

def booking_number
  @booking_number
end

#categoryObject

The lodging category



5835
5836
5837
# File 'lib/stripe/resources/payment_intent.rb', line 5835

def category
  @category
end

#checkin_atObject

Loding check-in time. Measured in seconds since the Unix epoch.



5837
5838
5839
# File 'lib/stripe/resources/payment_intent.rb', line 5837

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



5839
5840
5841
# File 'lib/stripe/resources/payment_intent.rb', line 5839

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



5841
5842
5843
# File 'lib/stripe/resources/payment_intent.rb', line 5841

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



5843
5844
5845
# File 'lib/stripe/resources/payment_intent.rb', line 5843

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



5845
5846
5847
# File 'lib/stripe/resources/payment_intent.rb', line 5845

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



5847
5848
5849
# File 'lib/stripe/resources/payment_intent.rb', line 5847

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



5849
5850
5851
# File 'lib/stripe/resources/payment_intent.rb', line 5849

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



5851
5852
5853
# File 'lib/stripe/resources/payment_intent.rb', line 5851

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



5853
5854
5855
# File 'lib/stripe/resources/payment_intent.rb', line 5853

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



5855
5856
5857
# File 'lib/stripe/resources/payment_intent.rb', line 5855

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



5857
5858
5859
# File 'lib/stripe/resources/payment_intent.rb', line 5857

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



5859
5860
5861
# File 'lib/stripe/resources/payment_intent.rb', line 5859

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



5861
5862
5863
# File 'lib/stripe/resources/payment_intent.rb', line 5861

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



5863
5864
5865
# File 'lib/stripe/resources/payment_intent.rb', line 5863

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



5865
5866
5867
# File 'lib/stripe/resources/payment_intent.rb', line 5865

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



5867
5868
5869
# File 'lib/stripe/resources/payment_intent.rb', line 5867

def total_tax_amount
  @total_tax_amount
end