Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



6536
6537
6538
6539
6540
# File 'lib/stripe/resources/payment_intent.rb', line 6536

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



6530
6531
6532
# File 'lib/stripe/resources/payment_intent.rb', line 6530

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



6532
6533
6534
# File 'lib/stripe/resources/payment_intent.rb', line 6532

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



6534
6535
6536
# File 'lib/stripe/resources/payment_intent.rb', line 6534

def phone
  @phone
end