Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
6059 6060 6061 6062 6063 |
# File 'lib/stripe/resources/payment_intent.rb', line 6059 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
6053 6054 6055 |
# File 'lib/stripe/resources/payment_intent.rb', line 6053 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
6055 6056 6057 |
# File 'lib/stripe/resources/payment_intent.rb', line 6055 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
6057 6058 6059 |
# File 'lib/stripe/resources/payment_intent.rb', line 6057 def phone @phone end |