Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



6015
6016
6017
6018
6019
# File 'lib/stripe/resources/payment_intent.rb', line 6015

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



6009
6010
6011
# File 'lib/stripe/resources/payment_intent.rb', line 6009

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



6011
6012
6013
# File 'lib/stripe/resources/payment_intent.rb', line 6011

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



6013
6014
6015
# File 'lib/stripe/resources/payment_intent.rb', line 6013

def phone
  @phone
end