Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
5832 5833 5834 5835 5836 |
# File 'lib/stripe/resources/payment_intent.rb', line 5832 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
5826 5827 5828 |
# File 'lib/stripe/resources/payment_intent.rb', line 5826 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
5828 5829 5830 |
# File 'lib/stripe/resources/payment_intent.rb', line 5828 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
5830 5831 5832 |
# File 'lib/stripe/resources/payment_intent.rb', line 5830 def phone @phone end |