Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



5801
5802
5803
5804
5805
# File 'lib/stripe/resources/payment_intent.rb', line 5801

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



5795
5796
5797
# File 'lib/stripe/resources/payment_intent.rb', line 5795

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



5797
5798
5799
# File 'lib/stripe/resources/payment_intent.rb', line 5797

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



5799
5800
5801
# File 'lib/stripe/resources/payment_intent.rb', line 5799

def phone
  @phone
end