Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



6680
6681
6682
6683
6684
# File 'lib/stripe/resources/payment_intent.rb', line 6680

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



6672
6673
6674
# File 'lib/stripe/resources/payment_intent.rb', line 6672

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



6675
6676
6677
# File 'lib/stripe/resources/payment_intent.rb', line 6675

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



6678
6679
6680
# File 'lib/stripe/resources/payment_intent.rb', line 6678

def phone
  @phone
end