Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
5783 5784 5785 5786 5787 |
# File 'lib/stripe/resources/payment_intent.rb', line 5783 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
5777 5778 5779 |
# File 'lib/stripe/resources/payment_intent.rb', line 5777 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
5779 5780 5781 |
# File 'lib/stripe/resources/payment_intent.rb', line 5779 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
5781 5782 5783 |
# File 'lib/stripe/resources/payment_intent.rb', line 5781 def phone @phone end |