Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentDetails::Subscription
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, BillingInterval
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#auto_renewal ⇒ Object
Info whether the subscription will be auto renewed upon expiry.
-
#billing_interval ⇒ Object
Subscription billing details for this purchase.
-
#ends_at ⇒ Object
Subscription end time.
-
#name ⇒ Object
Name of the product on subscription.
-
#starts_at ⇒ Object
Subscription start time.
Instance Method Summary collapse
-
#initialize(affiliate: nil, auto_renewal: nil, billing_interval: nil, ends_at: nil, name: nil, starts_at: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, auto_renewal: nil, billing_interval: nil, ends_at: nil, name: nil, starts_at: nil) ⇒ Subscription
Returns a new instance of Subscription.
6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 |
# File 'lib/stripe/resources/payment_intent.rb', line 6856 def initialize( affiliate: nil, auto_renewal: nil, billing_interval: nil, ends_at: nil, name: nil, starts_at: nil ) @affiliate = affiliate @auto_renewal = auto_renewal @billing_interval = billing_interval @ends_at = ends_at @name = name @starts_at = starts_at end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
6839 6840 6841 |
# File 'lib/stripe/resources/payment_intent.rb', line 6839 def affiliate @affiliate end |
#auto_renewal ⇒ Object
Info whether the subscription will be auto renewed upon expiry.
6842 6843 6844 |
# File 'lib/stripe/resources/payment_intent.rb', line 6842 def auto_renewal @auto_renewal end |
#billing_interval ⇒ Object
Subscription billing details for this purchase.
6845 6846 6847 |
# File 'lib/stripe/resources/payment_intent.rb', line 6845 def billing_interval @billing_interval end |
#ends_at ⇒ Object
Subscription end time. Measured in seconds since the Unix epoch.
6848 6849 6850 |
# File 'lib/stripe/resources/payment_intent.rb', line 6848 def ends_at @ends_at end |
#name ⇒ Object
Name of the product on subscription. e.g. Apple Music Subscription
6851 6852 6853 |
# File 'lib/stripe/resources/payment_intent.rb', line 6851 def name @name end |
#starts_at ⇒ Object
Subscription start time. Measured in seconds since the Unix epoch.
6854 6855 6856 |
# File 'lib/stripe/resources/payment_intent.rb', line 6854 def starts_at @starts_at end |