Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



6242
6243
6244
6245
# File 'lib/stripe/resources/payment_intent.rb', line 6242

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



6238
6239
6240
# File 'lib/stripe/resources/payment_intent.rb', line 6238

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



6240
6241
6242
# File 'lib/stripe/resources/payment_intent.rb', line 6240

def interval
  @interval
end