Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



5914
5915
5916
5917
# File 'lib/stripe/resources/payment_intent.rb', line 5914

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



5910
5911
5912
# File 'lib/stripe/resources/payment_intent.rb', line 5910

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



5912
5913
5914
# File 'lib/stripe/resources/payment_intent.rb', line 5912

def interval
  @interval
end