Class: Stripe::PaymentIntent::UpdateParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



5932
5933
5934
5935
# File 'lib/stripe/resources/payment_intent.rb', line 5932

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



5928
5929
5930
# File 'lib/stripe/resources/payment_intent.rb', line 5928

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



5930
5931
5932
# File 'lib/stripe/resources/payment_intent.rb', line 5930

def interval
  @interval
end