Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 |
# File 'lib/stripe/resources/payment_intent.rb', line 7025 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
7013 7014 7015 |
# File 'lib/stripe/resources/payment_intent.rb', line 7013 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
7015 7016 7017 |
# File 'lib/stripe/resources/payment_intent.rb', line 7015 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
7017 7018 7019 |
# File 'lib/stripe/resources/payment_intent.rb', line 7017 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
7019 7020 7021 |
# File 'lib/stripe/resources/payment_intent.rb', line 7019 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
7021 7022 7023 |
# File 'lib/stripe/resources/payment_intent.rb', line 7021 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
7023 7024 7025 |
# File 'lib/stripe/resources/payment_intent.rb', line 7023 def suffix @suffix end |