Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
8406 8407 8408 8409 8410 8411 8412 8413 8414 8415 8416 8417 8418 8419 8420 |
# File 'lib/stripe/resources/payment_intent.rb', line 8406 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
8394 8395 8396 |
# File 'lib/stripe/resources/payment_intent.rb', line 8394 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
8396 8397 8398 |
# File 'lib/stripe/resources/payment_intent.rb', line 8396 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
8398 8399 8400 |
# File 'lib/stripe/resources/payment_intent.rb', line 8398 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
8400 8401 8402 |
# File 'lib/stripe/resources/payment_intent.rb', line 8400 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
8402 8403 8404 |
# File 'lib/stripe/resources/payment_intent.rb', line 8402 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
8404 8405 8406 |
# File 'lib/stripe/resources/payment_intent.rb', line 8404 def suffix @suffix end |