Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



6949
6950
6951
6952
6953
6954
6955
6956
6957
6958
6959
6960
6961
6962
6963
# File 'lib/stripe/resources/payment_intent.rb', line 6949

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



6937
6938
6939
# File 'lib/stripe/resources/payment_intent.rb', line 6937

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



6939
6940
6941
# File 'lib/stripe/resources/payment_intent.rb', line 6939

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



6941
6942
6943
# File 'lib/stripe/resources/payment_intent.rb', line 6941

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



6943
6944
6945
# File 'lib/stripe/resources/payment_intent.rb', line 6943

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



6945
6946
6947
# File 'lib/stripe/resources/payment_intent.rb', line 6945

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



6947
6948
6949
# File 'lib/stripe/resources/payment_intent.rb', line 6947

def suffix
  @suffix
end