Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 |
# File 'lib/stripe/resources/payment_intent.rb', line 6949 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
6937 6938 6939 |
# File 'lib/stripe/resources/payment_intent.rb', line 6937 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
6939 6940 6941 |
# File 'lib/stripe/resources/payment_intent.rb', line 6939 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
6941 6942 6943 |
# File 'lib/stripe/resources/payment_intent.rb', line 6941 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
6943 6944 6945 |
# File 'lib/stripe/resources/payment_intent.rb', line 6943 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
6945 6946 6947 |
# File 'lib/stripe/resources/payment_intent.rb', line 6945 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
6947 6948 6949 |
# File 'lib/stripe/resources/payment_intent.rb', line 6947 def suffix @suffix end |