Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
6639 6640 6641 6642 6643 6644 6645 6646 6647 6648 6649 6650 6651 6652 6653 |
# File 'lib/stripe/resources/payment_intent.rb', line 6639 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
6627 6628 6629 |
# File 'lib/stripe/resources/payment_intent.rb', line 6627 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
6629 6630 6631 |
# File 'lib/stripe/resources/payment_intent.rb', line 6629 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
6631 6632 6633 |
# File 'lib/stripe/resources/payment_intent.rb', line 6631 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
6633 6634 6635 |
# File 'lib/stripe/resources/payment_intent.rb', line 6633 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
6635 6636 6637 |
# File 'lib/stripe/resources/payment_intent.rb', line 6635 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
6637 6638 6639 |
# File 'lib/stripe/resources/payment_intent.rb', line 6637 def suffix @suffix end |