Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 4270 |
# File 'lib/stripe/resources/payment_intent.rb', line 4256 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
4244 4245 4246 |
# File 'lib/stripe/resources/payment_intent.rb', line 4244 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
4246 4247 4248 |
# File 'lib/stripe/resources/payment_intent.rb', line 4246 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
4248 4249 4250 |
# File 'lib/stripe/resources/payment_intent.rb', line 4248 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
4250 4251 4252 |
# File 'lib/stripe/resources/payment_intent.rb', line 4250 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
4252 4253 4254 |
# File 'lib/stripe/resources/payment_intent.rb', line 4252 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
4254 4255 4256 |
# File 'lib/stripe/resources/payment_intent.rb', line 4254 def suffix @suffix end |