Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



4140
4141
4142
4143
4144
4145
4146
4147
4148
4149
4150
4151
4152
4153
4154
# File 'lib/stripe/resources/payment_intent.rb', line 4140

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



4128
4129
4130
# File 'lib/stripe/resources/payment_intent.rb', line 4128

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



4130
4131
4132
# File 'lib/stripe/resources/payment_intent.rb', line 4130

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



4132
4133
4134
# File 'lib/stripe/resources/payment_intent.rb', line 4132

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



4134
4135
4136
# File 'lib/stripe/resources/payment_intent.rb', line 4134

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



4136
4137
4138
# File 'lib/stripe/resources/payment_intent.rb', line 4136

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



4138
4139
4140
# File 'lib/stripe/resources/payment_intent.rb', line 4138

def suffix
  @suffix
end