Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
4211
4212
4213
# File 'lib/stripe/resources/payment_intent.rb', line 4199

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



4187
4188
4189
# File 'lib/stripe/resources/payment_intent.rb', line 4187

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



4189
4190
4191
# File 'lib/stripe/resources/payment_intent.rb', line 4189

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



4191
4192
4193
# File 'lib/stripe/resources/payment_intent.rb', line 4191

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



4193
4194
4195
# File 'lib/stripe/resources/payment_intent.rb', line 4193

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



4195
4196
4197
# File 'lib/stripe/resources/payment_intent.rb', line 4195

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



4197
4198
4199
# File 'lib/stripe/resources/payment_intent.rb', line 4197

def suffix
  @suffix
end