Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 |
# File 'lib/stripe/resources/payment_intent.rb', line 4199 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
4187 4188 4189 |
# File 'lib/stripe/resources/payment_intent.rb', line 4187 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
4189 4190 4191 |
# File 'lib/stripe/resources/payment_intent.rb', line 4189 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
4191 4192 4193 |
# File 'lib/stripe/resources/payment_intent.rb', line 4191 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
4193 4194 4195 |
# File 'lib/stripe/resources/payment_intent.rb', line 4193 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
4195 4196 4197 |
# File 'lib/stripe/resources/payment_intent.rb', line 4195 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
4197 4198 4199 |
# File 'lib/stripe/resources/payment_intent.rb', line 4197 def suffix @suffix end |