Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
6506 6507 6508 6509 6510 6511 6512 6513 6514 6515 6516 6517 6518 6519 6520 |
# File 'lib/stripe/resources/payment_intent.rb', line 6506 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
6494 6495 6496 |
# File 'lib/stripe/resources/payment_intent.rb', line 6494 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
6496 6497 6498 |
# File 'lib/stripe/resources/payment_intent.rb', line 6496 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
6498 6499 6500 |
# File 'lib/stripe/resources/payment_intent.rb', line 6498 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
6500 6501 6502 |
# File 'lib/stripe/resources/payment_intent.rb', line 6500 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
6502 6503 6504 |
# File 'lib/stripe/resources/payment_intent.rb', line 6502 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
6504 6505 6506 |
# File 'lib/stripe/resources/payment_intent.rb', line 6504 def suffix @suffix end |