Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



4172
4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
# File 'lib/stripe/resources/payment_intent.rb', line 4172

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



4160
4161
4162
# File 'lib/stripe/resources/payment_intent.rb', line 4160

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



4162
4163
4164
# File 'lib/stripe/resources/payment_intent.rb', line 4162

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



4164
4165
4166
# File 'lib/stripe/resources/payment_intent.rb', line 4164

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



4166
4167
4168
# File 'lib/stripe/resources/payment_intent.rb', line 4166

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



4168
4169
4170
# File 'lib/stripe/resources/payment_intent.rb', line 4168

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



4170
4171
4172
# File 'lib/stripe/resources/payment_intent.rb', line 4170

def suffix
  @suffix
end