Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



6451
6452
6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
6463
6464
6465
# File 'lib/stripe/resources/payment_intent.rb', line 6451

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



6439
6440
6441
# File 'lib/stripe/resources/payment_intent.rb', line 6439

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



6441
6442
6443
# File 'lib/stripe/resources/payment_intent.rb', line 6441

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



6443
6444
6445
# File 'lib/stripe/resources/payment_intent.rb', line 6443

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



6445
6446
6447
# File 'lib/stripe/resources/payment_intent.rb', line 6445

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



6447
6448
6449
# File 'lib/stripe/resources/payment_intent.rb', line 6447

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



6449
6450
6451
# File 'lib/stripe/resources/payment_intent.rb', line 6449

def suffix
  @suffix
end