Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodData::StripeBalance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodData::StripeBalance
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment.
-
#source_type ⇒ Object
The [source_type](docs.stripe.com/api/balance/balance_object#balance_object-available-source_types) of the balance.
Instance Method Summary collapse
-
#initialize(account: nil, source_type: nil) ⇒ StripeBalance
constructor
A new instance of StripeBalance.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, source_type: nil) ⇒ StripeBalance
Returns a new instance of StripeBalance.
6637 6638 6639 6640 |
# File 'lib/stripe/resources/payment_intent.rb', line 6637 def initialize(account: nil, source_type: nil) @account = account @source_type = source_type end |
Instance Attribute Details
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment
6633 6634 6635 |
# File 'lib/stripe/resources/payment_intent.rb', line 6633 def account @account end |
#source_type ⇒ Object
The [source_type](docs.stripe.com/api/balance/balance_object#balance_object-available-source_types) of the balance
6635 6636 6637 |
# File 'lib/stripe/resources/payment_intent.rb', line 6635 def source_type @source_type end |