Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 |
# File 'lib/stripe/resources/payment_intent.rb', line 7084 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
7074 7075 7076 |
# File 'lib/stripe/resources/payment_intent.rb', line 7074 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
7076 7077 7078 |
# File 'lib/stripe/resources/payment_intent.rb', line 7076 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
7078 7079 7080 |
# File 'lib/stripe/resources/payment_intent.rb', line 7078 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
7080 7081 7082 |
# File 'lib/stripe/resources/payment_intent.rb', line 7080 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
7082 7083 7084 |
# File 'lib/stripe/resources/payment_intent.rb', line 7082 def routing_number @routing_number end |