Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
6658 6659 6660 6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 |
# File 'lib/stripe/resources/payment_intent.rb', line 6658 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
6648 6649 6650 |
# File 'lib/stripe/resources/payment_intent.rb', line 6648 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
6650 6651 6652 |
# File 'lib/stripe/resources/payment_intent.rb', line 6650 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
6652 6653 6654 |
# File 'lib/stripe/resources/payment_intent.rb', line 6652 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
6654 6655 6656 |
# File 'lib/stripe/resources/payment_intent.rb', line 6654 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
6656 6657 6658 |
# File 'lib/stripe/resources/payment_intent.rb', line 6656 def routing_number @routing_number end |