Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 6618 6619 6620 |
# File 'lib/stripe/resources/payment_intent.rb', line 6608 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
6598 6599 6600 |
# File 'lib/stripe/resources/payment_intent.rb', line 6598 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
6600 6601 6602 |
# File 'lib/stripe/resources/payment_intent.rb', line 6600 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
6602 6603 6604 |
# File 'lib/stripe/resources/payment_intent.rb', line 6602 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
6604 6605 6606 |
# File 'lib/stripe/resources/payment_intent.rb', line 6604 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
6606 6607 6608 |
# File 'lib/stripe/resources/payment_intent.rb', line 6606 def routing_number @routing_number end |