Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 |
# File 'lib/stripe/resources/payment_intent.rb', line 4273 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
4263 4264 4265 |
# File 'lib/stripe/resources/payment_intent.rb', line 4263 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
4265 4266 4267 |
# File 'lib/stripe/resources/payment_intent.rb', line 4265 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
4267 4268 4269 |
# File 'lib/stripe/resources/payment_intent.rb', line 4267 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
4269 4270 4271 |
# File 'lib/stripe/resources/payment_intent.rb', line 4269 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
4271 4272 4273 |
# File 'lib/stripe/resources/payment_intent.rb', line 4271 def routing_number @routing_number end |