Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 |
# File 'lib/stripe/resources/payment_intent.rb', line 7275 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
7261 7262 7263 |
# File 'lib/stripe/resources/payment_intent.rb', line 7261 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
7264 7265 7266 |
# File 'lib/stripe/resources/payment_intent.rb', line 7264 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
7267 7268 7269 |
# File 'lib/stripe/resources/payment_intent.rb', line 7267 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
7270 7271 7272 |
# File 'lib/stripe/resources/payment_intent.rb', line 7270 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
7273 7274 7275 |
# File 'lib/stripe/resources/payment_intent.rb', line 7273 def routing_number @routing_number end |