Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 |
# File 'lib/stripe/resources/payment_intent.rb', line 6345 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
6335 6336 6337 |
# File 'lib/stripe/resources/payment_intent.rb', line 6335 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
6337 6338 6339 |
# File 'lib/stripe/resources/payment_intent.rb', line 6337 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
6339 6340 6341 |
# File 'lib/stripe/resources/payment_intent.rb', line 6339 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
6341 6342 6343 |
# File 'lib/stripe/resources/payment_intent.rb', line 6341 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
6343 6344 6345 |
# File 'lib/stripe/resources/payment_intent.rb', line 6343 def routing_number @routing_number end |