Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, StripeBalance, Swish, Twint, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, blik: nil, boleto: nil, card: nil, card_present: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



9314
9315
9316
9317
9318
9319
9320
9321
9322
9323
9324
9325
9326
9327
9328
9329
9330
9331
9332
9333
9334
9335
9336
9337
9338
9339
9340
9341
9342
9343
9344
9345
9346
9347
9348
9349
9350
9351
9352
9353
9354
9355
9356
9357
9358
9359
9360
9361
9362
9363
9364
9365
9366
9367
9368
9369
9370
9371
9372
9373
9374
9375
9376
9377
9378
9379
9380
9381
9382
9383
9384
9385
9386
9387
9388
9389
9390
9391
9392
9393
9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
# File 'lib/stripe/resources/payment_intent.rb', line 9314

def initialize(
  acss_debit: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  alma: nil,
  amazon_pay: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  billie: nil,
  blik: nil,
  boleto: nil,
  card: nil,
  card_present: nil,
  cashapp: nil,
  crypto: nil,
  customer_balance: nil,
  eps: nil,
  fpx: nil,
  giropay: nil,
  gopay: nil,
  grabpay: nil,
  id_bank_transfer: nil,
  ideal: nil,
  interac_present: nil,
  kakao_pay: nil,
  klarna: nil,
  konbini: nil,
  kr_card: nil,
  link: nil,
  mb_way: nil,
  mobilepay: nil,
  multibanco: nil,
  naver_pay: nil,
  nz_bank_account: nil,
  oxxo: nil,
  p24: nil,
  pay_by_bank: nil,
  payco: nil,
  paynow: nil,
  paypal: nil,
  payto: nil,
  pix: nil,
  promptpay: nil,
  qris: nil,
  rechnung: nil,
  revolut_pay: nil,
  samsung_pay: nil,
  satispay: nil,
  sepa_debit: nil,
  shopeepay: nil,
  sofort: nil,
  stripe_balance: nil,
  swish: nil,
  twint: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @alma = alma
  @amazon_pay = amazon_pay
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @billie = billie
  @blik = blik
  @boleto = boleto
  @card = card
  @card_present = card_present
  @cashapp = cashapp
  @crypto = crypto
  @customer_balance = customer_balance
  @eps = eps
  @fpx = fpx
  @giropay = giropay
  @gopay = gopay
  @grabpay = grabpay
  @id_bank_transfer = id_bank_transfer
  @ideal = ideal
  @interac_present = interac_present
  @kakao_pay = kakao_pay
  @klarna = klarna
  @konbini = konbini
  @kr_card = kr_card
  @link = link
  @mb_way = mb_way
  @mobilepay = mobilepay
  @multibanco = multibanco
  @naver_pay = naver_pay
  @nz_bank_account = 
  @oxxo = oxxo
  @p24 = p24
  @pay_by_bank = pay_by_bank
  @payco = payco
  @paynow = paynow
  @paypal = paypal
  @payto = payto
  @pix = pix
  @promptpay = promptpay
  @qris = qris
  @rechnung = rechnung
  @revolut_pay = revolut_pay
  @samsung_pay = samsung_pay
  @satispay = satispay
  @sepa_debit = sepa_debit
  @shopeepay = shopeepay
  @sofort = sofort
  @stripe_balance = stripe_balance
  @swish = swish
  @twint = twint
  @us_bank_account = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

If this is a ‘acss_debit` PaymentMethod, this sub-hash contains details about the ACSS Debit payment method options.



9198
9199
9200
# File 'lib/stripe/resources/payment_intent.rb', line 9198

def acss_debit
  @acss_debit
end

#affirmObject

If this is an ‘affirm` PaymentMethod, this sub-hash contains details about the Affirm payment method options.



9200
9201
9202
# File 'lib/stripe/resources/payment_intent.rb', line 9200

def affirm
  @affirm
end

#afterpay_clearpayObject

If this is a ‘afterpay_clearpay` PaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options.



9202
9203
9204
# File 'lib/stripe/resources/payment_intent.rb', line 9202

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If this is a ‘alipay` PaymentMethod, this sub-hash contains details about the Alipay payment method options.



9204
9205
9206
# File 'lib/stripe/resources/payment_intent.rb', line 9204

def alipay
  @alipay
end

#almaObject

If this is a ‘alma` PaymentMethod, this sub-hash contains details about the Alma payment method options.



9206
9207
9208
# File 'lib/stripe/resources/payment_intent.rb', line 9206

def alma
  @alma
end

#amazon_payObject

If this is a ‘amazon_pay` PaymentMethod, this sub-hash contains details about the Amazon Pay payment method options.



9208
9209
9210
# File 'lib/stripe/resources/payment_intent.rb', line 9208

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject

If this is a ‘au_becs_debit` PaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options.



9210
9211
9212
# File 'lib/stripe/resources/payment_intent.rb', line 9210

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

If this is a ‘bacs_debit` PaymentMethod, this sub-hash contains details about the BACS Debit payment method options.



9212
9213
9214
# File 'lib/stripe/resources/payment_intent.rb', line 9212

def bacs_debit
  @bacs_debit
end

#bancontactObject

If this is a ‘bancontact` PaymentMethod, this sub-hash contains details about the Bancontact payment method options.



9214
9215
9216
# File 'lib/stripe/resources/payment_intent.rb', line 9214

def bancontact
  @bancontact
end

#billieObject

If this is a ‘billie` PaymentMethod, this sub-hash contains details about the Billie payment method options.



9216
9217
9218
# File 'lib/stripe/resources/payment_intent.rb', line 9216

def billie
  @billie
end

#blikObject

If this is a ‘blik` PaymentMethod, this sub-hash contains details about the BLIK payment method options.



9218
9219
9220
# File 'lib/stripe/resources/payment_intent.rb', line 9218

def blik
  @blik
end

#boletoObject

If this is a ‘boleto` PaymentMethod, this sub-hash contains details about the Boleto payment method options.



9220
9221
9222
# File 'lib/stripe/resources/payment_intent.rb', line 9220

def boleto
  @boleto
end

#cardObject

Configuration for any card payments attempted on this PaymentIntent.



9222
9223
9224
# File 'lib/stripe/resources/payment_intent.rb', line 9222

def card
  @card
end

#card_presentObject

If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.



9224
9225
9226
# File 'lib/stripe/resources/payment_intent.rb', line 9224

def card_present
  @card_present
end

#cashappObject

If this is a ‘cashapp` PaymentMethod, this sub-hash contains details about the Cash App Pay payment method options.



9226
9227
9228
# File 'lib/stripe/resources/payment_intent.rb', line 9226

def cashapp
  @cashapp
end

#cryptoObject

If this is a ‘crypto` PaymentMethod, this sub-hash contains details about the Crypto payment method options.



9228
9229
9230
# File 'lib/stripe/resources/payment_intent.rb', line 9228

def crypto
  @crypto
end

#customer_balanceObject

If this is a ‘customer balance` PaymentMethod, this sub-hash contains details about the customer balance payment method options.



9230
9231
9232
# File 'lib/stripe/resources/payment_intent.rb', line 9230

def customer_balance
  @customer_balance
end

#epsObject

If this is a ‘eps` PaymentMethod, this sub-hash contains details about the EPS payment method options.



9232
9233
9234
# File 'lib/stripe/resources/payment_intent.rb', line 9232

def eps
  @eps
end

#fpxObject

If this is a ‘fpx` PaymentMethod, this sub-hash contains details about the FPX payment method options.



9234
9235
9236
# File 'lib/stripe/resources/payment_intent.rb', line 9234

def fpx
  @fpx
end

#giropayObject

If this is a ‘giropay` PaymentMethod, this sub-hash contains details about the Giropay payment method options.



9236
9237
9238
# File 'lib/stripe/resources/payment_intent.rb', line 9236

def giropay
  @giropay
end

#gopayObject

If this is a ‘gopay` PaymentMethod, this sub-hash contains details about the Gopay payment method options.



9238
9239
9240
# File 'lib/stripe/resources/payment_intent.rb', line 9238

def gopay
  @gopay
end

#grabpayObject

If this is a ‘grabpay` PaymentMethod, this sub-hash contains details about the Grabpay payment method options.



9240
9241
9242
# File 'lib/stripe/resources/payment_intent.rb', line 9240

def grabpay
  @grabpay
end

#id_bank_transferObject

If this is a ‘id_bank_transfer` PaymentMethod, this sub-hash contains details about the Indonesia Bank Transfer payment method options.



9242
9243
9244
# File 'lib/stripe/resources/payment_intent.rb', line 9242

def id_bank_transfer
  @id_bank_transfer
end

#idealObject

If this is a ‘ideal` PaymentMethod, this sub-hash contains details about the Ideal payment method options.



9244
9245
9246
# File 'lib/stripe/resources/payment_intent.rb', line 9244

def ideal
  @ideal
end

#interac_presentObject

If this is a ‘interac_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.



9246
9247
9248
# File 'lib/stripe/resources/payment_intent.rb', line 9246

def interac_present
  @interac_present
end

#kakao_payObject

If this is a ‘kakao_pay` PaymentMethod, this sub-hash contains details about the Kakao Pay payment method options.



9248
9249
9250
# File 'lib/stripe/resources/payment_intent.rb', line 9248

def kakao_pay
  @kakao_pay
end

#klarnaObject

If this is a ‘klarna` PaymentMethod, this sub-hash contains details about the Klarna payment method options.



9250
9251
9252
# File 'lib/stripe/resources/payment_intent.rb', line 9250

def klarna
  @klarna
end

#konbiniObject

If this is a ‘konbini` PaymentMethod, this sub-hash contains details about the Konbini payment method options.



9252
9253
9254
# File 'lib/stripe/resources/payment_intent.rb', line 9252

def konbini
  @konbini
end

#kr_cardObject

If this is a ‘kr_card` PaymentMethod, this sub-hash contains details about the KR Card payment method options.



9254
9255
9256
# File 'lib/stripe/resources/payment_intent.rb', line 9254

def kr_card
  @kr_card
end

If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options.



9256
9257
9258
# File 'lib/stripe/resources/payment_intent.rb', line 9256

def link
  @link
end

#mb_wayObject

If this is a ‘mb_way` PaymentMethod, this sub-hash contains details about the MB WAY payment method options.



9258
9259
9260
# File 'lib/stripe/resources/payment_intent.rb', line 9258

def mb_way
  @mb_way
end

#mobilepayObject

If this is a ‘MobilePay` PaymentMethod, this sub-hash contains details about the MobilePay payment method options.



9260
9261
9262
# File 'lib/stripe/resources/payment_intent.rb', line 9260

def mobilepay
  @mobilepay
end

#multibancoObject

If this is a ‘multibanco` PaymentMethod, this sub-hash contains details about the Multibanco payment method options.



9262
9263
9264
# File 'lib/stripe/resources/payment_intent.rb', line 9262

def multibanco
  @multibanco
end

If this is a ‘naver_pay` PaymentMethod, this sub-hash contains details about the Naver Pay payment method options.



9264
9265
9266
# File 'lib/stripe/resources/payment_intent.rb', line 9264

def naver_pay
  @naver_pay
end

#nz_bank_accountObject

If this is a ‘nz_bank_account` PaymentMethod, this sub-hash contains details about the NZ BECS Direct Debit payment method options.



9266
9267
9268
# File 'lib/stripe/resources/payment_intent.rb', line 9266

def 
  @nz_bank_account
end

#oxxoObject

If this is a ‘oxxo` PaymentMethod, this sub-hash contains details about the OXXO payment method options.



9268
9269
9270
# File 'lib/stripe/resources/payment_intent.rb', line 9268

def oxxo
  @oxxo
end

#p24Object

If this is a ‘p24` PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options.



9270
9271
9272
# File 'lib/stripe/resources/payment_intent.rb', line 9270

def p24
  @p24
end

#pay_by_bankObject

If this is a ‘pay_by_bank` PaymentMethod, this sub-hash contains details about the PayByBank payment method options.



9272
9273
9274
# File 'lib/stripe/resources/payment_intent.rb', line 9272

def pay_by_bank
  @pay_by_bank
end

#paycoObject

If this is a ‘payco` PaymentMethod, this sub-hash contains details about the PAYCO payment method options.



9274
9275
9276
# File 'lib/stripe/resources/payment_intent.rb', line 9274

def payco
  @payco
end

#paynowObject

If this is a ‘paynow` PaymentMethod, this sub-hash contains details about the PayNow payment method options.



9276
9277
9278
# File 'lib/stripe/resources/payment_intent.rb', line 9276

def paynow
  @paynow
end

#paypalObject

If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.



9278
9279
9280
# File 'lib/stripe/resources/payment_intent.rb', line 9278

def paypal
  @paypal
end

#paytoObject

If this is a ‘payto` PaymentMethod, this sub-hash contains details about the PayTo payment method options.



9280
9281
9282
# File 'lib/stripe/resources/payment_intent.rb', line 9280

def payto
  @payto
end

#pixObject

If this is a ‘pix` PaymentMethod, this sub-hash contains details about the Pix payment method options.



9282
9283
9284
# File 'lib/stripe/resources/payment_intent.rb', line 9282

def pix
  @pix
end

#promptpayObject

If this is a ‘promptpay` PaymentMethod, this sub-hash contains details about the PromptPay payment method options.



9284
9285
9286
# File 'lib/stripe/resources/payment_intent.rb', line 9284

def promptpay
  @promptpay
end

#qrisObject

If this is a ‘qris` PaymentMethod, this sub-hash contains details about the QRIS payment method options.



9286
9287
9288
# File 'lib/stripe/resources/payment_intent.rb', line 9286

def qris
  @qris
end

#rechnungObject

If this is a ‘rechnung` PaymentMethod, this sub-hash contains details about the Rechnung payment method options.



9288
9289
9290
# File 'lib/stripe/resources/payment_intent.rb', line 9288

def rechnung
  @rechnung
end

#revolut_payObject

If this is a ‘revolut_pay` PaymentMethod, this sub-hash contains details about the Revolut Pay payment method options.



9290
9291
9292
# File 'lib/stripe/resources/payment_intent.rb', line 9290

def revolut_pay
  @revolut_pay
end

#samsung_payObject

If this is a ‘samsung_pay` PaymentMethod, this sub-hash contains details about the Samsung Pay payment method options.



9292
9293
9294
# File 'lib/stripe/resources/payment_intent.rb', line 9292

def samsung_pay
  @samsung_pay
end

#satispayObject

If this is a ‘satispay` PaymentMethod, this sub-hash contains details about the Satispay payment method options.



9294
9295
9296
# File 'lib/stripe/resources/payment_intent.rb', line 9294

def satispay
  @satispay
end

#sepa_debitObject

If this is a ‘sepa_debit` PaymentIntent, this sub-hash contains details about the SEPA Debit payment method options.



9296
9297
9298
# File 'lib/stripe/resources/payment_intent.rb', line 9296

def sepa_debit
  @sepa_debit
end

#shopeepayObject

If this is a ‘shopeepay` PaymentMethod, this sub-hash contains details about the ShopeePay payment method options.



9298
9299
9300
# File 'lib/stripe/resources/payment_intent.rb', line 9298

def shopeepay
  @shopeepay
end

#sofortObject

If this is a ‘sofort` PaymentMethod, this sub-hash contains details about the SOFORT payment method options.



9300
9301
9302
# File 'lib/stripe/resources/payment_intent.rb', line 9300

def sofort
  @sofort
end

#stripe_balanceObject

If this is a ‘stripe_balance` PaymentMethod, this sub-hash contains details about the Stripe Balance payment method options.



9302
9303
9304
# File 'lib/stripe/resources/payment_intent.rb', line 9302

def stripe_balance
  @stripe_balance
end

#swishObject

If this is a ‘Swish` PaymentMethod, this sub-hash contains details about the Swish payment method options.



9304
9305
9306
# File 'lib/stripe/resources/payment_intent.rb', line 9304

def swish
  @swish
end

#twintObject

If this is a ‘twint` PaymentMethod, this sub-hash contains details about the TWINT payment method options.



9306
9307
9308
# File 'lib/stripe/resources/payment_intent.rb', line 9306

def twint
  @twint
end

#us_bank_accountObject

If this is a ‘us_bank_account` PaymentMethod, this sub-hash contains details about the US bank account payment method options.



9308
9309
9310
# File 'lib/stripe/resources/payment_intent.rb', line 9308

def 
  @us_bank_account
end

#wechat_payObject

If this is a ‘wechat_pay` PaymentMethod, this sub-hash contains details about the WeChat Pay payment method options.



9310
9311
9312
# File 'lib/stripe/resources/payment_intent.rb', line 9310

def wechat_pay
  @wechat_pay
end

#zipObject

If this is a ‘zip` PaymentMethod, this sub-hash contains details about the Zip payment method options.



9312
9313
9314
# File 'lib/stripe/resources/payment_intent.rb', line 9312

def zip
  @zip
end