Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CardPresent, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Grabpay, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Pix, Promptpay, RevolutPay, SamsungPay, Satispay, SepaDebit, Sofort, Swish, Twint, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, blik: nil, boleto: nil, card: nil, card_present: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, pix: nil, promptpay: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, sofort: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
5893
5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
5919
5920
5921
5922
5923
5924
5925
5926
5927
5928
5929
5930
5931
5932
5933
5934
5935
5936
5937
5938
5939
5940
5941
5942
5943
5944
5945
5946
5947
5948
5949
5950
5951
5952
5953
5954
5955
5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
5979
5980
5981
5982
# File 'lib/stripe/resources/payment_intent.rb', line 5882

def initialize(
  acss_debit: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  alma: nil,
  amazon_pay: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  billie: nil,
  blik: nil,
  boleto: nil,
  card: nil,
  card_present: nil,
  cashapp: nil,
  customer_balance: nil,
  eps: nil,
  fpx: nil,
  giropay: nil,
  grabpay: nil,
  ideal: nil,
  interac_present: nil,
  kakao_pay: nil,
  klarna: nil,
  konbini: nil,
  kr_card: nil,
  link: nil,
  mobilepay: nil,
  multibanco: nil,
  naver_pay: nil,
  nz_bank_account: nil,
  oxxo: nil,
  p24: nil,
  pay_by_bank: nil,
  payco: nil,
  paynow: nil,
  paypal: nil,
  pix: nil,
  promptpay: nil,
  revolut_pay: nil,
  samsung_pay: nil,
  satispay: nil,
  sepa_debit: nil,
  sofort: nil,
  swish: nil,
  twint: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @alma = alma
  @amazon_pay = amazon_pay
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @billie = billie
  @blik = blik
  @boleto = boleto
  @card = card
  @card_present = card_present
  @cashapp = cashapp
  @customer_balance = customer_balance
  @eps = eps
  @fpx = fpx
  @giropay = giropay
  @grabpay = grabpay
  @ideal = ideal
  @interac_present = interac_present
  @kakao_pay = kakao_pay
  @klarna = klarna
  @konbini = konbini
  @kr_card = kr_card
  @link = link
  @mobilepay = mobilepay
  @multibanco = multibanco
  @naver_pay = naver_pay
  @nz_bank_account = 
  @oxxo = oxxo
  @p24 = p24
  @pay_by_bank = pay_by_bank
  @payco = payco
  @paynow = paynow
  @paypal = paypal
  @pix = pix
  @promptpay = promptpay
  @revolut_pay = revolut_pay
  @samsung_pay = samsung_pay
  @satispay = satispay
  @sepa_debit = sepa_debit
  @sofort = sofort
  @swish = swish
  @twint = twint
  @us_bank_account = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

If this is a ‘acss_debit` PaymentMethod, this sub-hash contains details about the ACSS Debit payment method options.



5784
5785
5786
# File 'lib/stripe/resources/payment_intent.rb', line 5784

def acss_debit
  @acss_debit
end

#affirmObject

If this is an ‘affirm` PaymentMethod, this sub-hash contains details about the Affirm payment method options.



5786
5787
5788
# File 'lib/stripe/resources/payment_intent.rb', line 5786

def affirm
  @affirm
end

#afterpay_clearpayObject

If this is a ‘afterpay_clearpay` PaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options.



5788
5789
5790
# File 'lib/stripe/resources/payment_intent.rb', line 5788

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If this is a ‘alipay` PaymentMethod, this sub-hash contains details about the Alipay payment method options.



5790
5791
5792
# File 'lib/stripe/resources/payment_intent.rb', line 5790

def alipay
  @alipay
end

#almaObject

If this is a ‘alma` PaymentMethod, this sub-hash contains details about the Alma payment method options.



5792
5793
5794
# File 'lib/stripe/resources/payment_intent.rb', line 5792

def alma
  @alma
end

#amazon_payObject

If this is a ‘amazon_pay` PaymentMethod, this sub-hash contains details about the Amazon Pay payment method options.



5794
5795
5796
# File 'lib/stripe/resources/payment_intent.rb', line 5794

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject

If this is a ‘au_becs_debit` PaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options.



5796
5797
5798
# File 'lib/stripe/resources/payment_intent.rb', line 5796

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

If this is a ‘bacs_debit` PaymentMethod, this sub-hash contains details about the BACS Debit payment method options.



5798
5799
5800
# File 'lib/stripe/resources/payment_intent.rb', line 5798

def bacs_debit
  @bacs_debit
end

#bancontactObject

If this is a ‘bancontact` PaymentMethod, this sub-hash contains details about the Bancontact payment method options.



5800
5801
5802
# File 'lib/stripe/resources/payment_intent.rb', line 5800

def bancontact
  @bancontact
end

#billieObject

If this is a ‘billie` PaymentMethod, this sub-hash contains details about the Billie payment method options.



5802
5803
5804
# File 'lib/stripe/resources/payment_intent.rb', line 5802

def billie
  @billie
end

#blikObject

If this is a ‘blik` PaymentMethod, this sub-hash contains details about the BLIK payment method options.



5804
5805
5806
# File 'lib/stripe/resources/payment_intent.rb', line 5804

def blik
  @blik
end

#boletoObject

If this is a ‘boleto` PaymentMethod, this sub-hash contains details about the Boleto payment method options.



5806
5807
5808
# File 'lib/stripe/resources/payment_intent.rb', line 5806

def boleto
  @boleto
end

#cardObject

Configuration for any card payments attempted on this PaymentIntent.



5808
5809
5810
# File 'lib/stripe/resources/payment_intent.rb', line 5808

def card
  @card
end

#card_presentObject

If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.



5810
5811
5812
# File 'lib/stripe/resources/payment_intent.rb', line 5810

def card_present
  @card_present
end

#cashappObject

If this is a ‘cashapp` PaymentMethod, this sub-hash contains details about the Cash App Pay payment method options.



5812
5813
5814
# File 'lib/stripe/resources/payment_intent.rb', line 5812

def cashapp
  @cashapp
end

#customer_balanceObject

If this is a ‘customer balance` PaymentMethod, this sub-hash contains details about the customer balance payment method options.



5814
5815
5816
# File 'lib/stripe/resources/payment_intent.rb', line 5814

def customer_balance
  @customer_balance
end

#epsObject

If this is a ‘eps` PaymentMethod, this sub-hash contains details about the EPS payment method options.



5816
5817
5818
# File 'lib/stripe/resources/payment_intent.rb', line 5816

def eps
  @eps
end

#fpxObject

If this is a ‘fpx` PaymentMethod, this sub-hash contains details about the FPX payment method options.



5818
5819
5820
# File 'lib/stripe/resources/payment_intent.rb', line 5818

def fpx
  @fpx
end

#giropayObject

If this is a ‘giropay` PaymentMethod, this sub-hash contains details about the Giropay payment method options.



5820
5821
5822
# File 'lib/stripe/resources/payment_intent.rb', line 5820

def giropay
  @giropay
end

#grabpayObject

If this is a ‘grabpay` PaymentMethod, this sub-hash contains details about the Grabpay payment method options.



5822
5823
5824
# File 'lib/stripe/resources/payment_intent.rb', line 5822

def grabpay
  @grabpay
end

#idealObject

If this is a ‘ideal` PaymentMethod, this sub-hash contains details about the Ideal payment method options.



5824
5825
5826
# File 'lib/stripe/resources/payment_intent.rb', line 5824

def ideal
  @ideal
end

#interac_presentObject

If this is a ‘interac_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.



5826
5827
5828
# File 'lib/stripe/resources/payment_intent.rb', line 5826

def interac_present
  @interac_present
end

#kakao_payObject

If this is a ‘kakao_pay` PaymentMethod, this sub-hash contains details about the Kakao Pay payment method options.



5828
5829
5830
# File 'lib/stripe/resources/payment_intent.rb', line 5828

def kakao_pay
  @kakao_pay
end

#klarnaObject

If this is a ‘klarna` PaymentMethod, this sub-hash contains details about the Klarna payment method options.



5830
5831
5832
# File 'lib/stripe/resources/payment_intent.rb', line 5830

def klarna
  @klarna
end

#konbiniObject

If this is a ‘konbini` PaymentMethod, this sub-hash contains details about the Konbini payment method options.



5832
5833
5834
# File 'lib/stripe/resources/payment_intent.rb', line 5832

def konbini
  @konbini
end

#kr_cardObject

If this is a ‘kr_card` PaymentMethod, this sub-hash contains details about the KR Card payment method options.



5834
5835
5836
# File 'lib/stripe/resources/payment_intent.rb', line 5834

def kr_card
  @kr_card
end

If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options.



5836
5837
5838
# File 'lib/stripe/resources/payment_intent.rb', line 5836

def link
  @link
end

#mobilepayObject

If this is a ‘MobilePay` PaymentMethod, this sub-hash contains details about the MobilePay payment method options.



5838
5839
5840
# File 'lib/stripe/resources/payment_intent.rb', line 5838

def mobilepay
  @mobilepay
end

#multibancoObject

If this is a ‘multibanco` PaymentMethod, this sub-hash contains details about the Multibanco payment method options.



5840
5841
5842
# File 'lib/stripe/resources/payment_intent.rb', line 5840

def multibanco
  @multibanco
end

If this is a ‘naver_pay` PaymentMethod, this sub-hash contains details about the Naver Pay payment method options.



5842
5843
5844
# File 'lib/stripe/resources/payment_intent.rb', line 5842

def naver_pay
  @naver_pay
end

#nz_bank_accountObject

If this is a ‘nz_bank_account` PaymentMethod, this sub-hash contains details about the NZ BECS Direct Debit payment method options.



5844
5845
5846
# File 'lib/stripe/resources/payment_intent.rb', line 5844

def 
  @nz_bank_account
end

#oxxoObject

If this is a ‘oxxo` PaymentMethod, this sub-hash contains details about the OXXO payment method options.



5846
5847
5848
# File 'lib/stripe/resources/payment_intent.rb', line 5846

def oxxo
  @oxxo
end

#p24Object

If this is a ‘p24` PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options.



5848
5849
5850
# File 'lib/stripe/resources/payment_intent.rb', line 5848

def p24
  @p24
end

#pay_by_bankObject

If this is a ‘pay_by_bank` PaymentMethod, this sub-hash contains details about the PayByBank payment method options.



5850
5851
5852
# File 'lib/stripe/resources/payment_intent.rb', line 5850

def pay_by_bank
  @pay_by_bank
end

#paycoObject

If this is a ‘payco` PaymentMethod, this sub-hash contains details about the PAYCO payment method options.



5852
5853
5854
# File 'lib/stripe/resources/payment_intent.rb', line 5852

def payco
  @payco
end

#paynowObject

If this is a ‘paynow` PaymentMethod, this sub-hash contains details about the PayNow payment method options.



5854
5855
5856
# File 'lib/stripe/resources/payment_intent.rb', line 5854

def paynow
  @paynow
end

#paypalObject

If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.



5856
5857
5858
# File 'lib/stripe/resources/payment_intent.rb', line 5856

def paypal
  @paypal
end

#pixObject

If this is a ‘pix` PaymentMethod, this sub-hash contains details about the Pix payment method options.



5858
5859
5860
# File 'lib/stripe/resources/payment_intent.rb', line 5858

def pix
  @pix
end

#promptpayObject

If this is a ‘promptpay` PaymentMethod, this sub-hash contains details about the PromptPay payment method options.



5860
5861
5862
# File 'lib/stripe/resources/payment_intent.rb', line 5860

def promptpay
  @promptpay
end

#revolut_payObject

If this is a ‘revolut_pay` PaymentMethod, this sub-hash contains details about the Revolut Pay payment method options.



5862
5863
5864
# File 'lib/stripe/resources/payment_intent.rb', line 5862

def revolut_pay
  @revolut_pay
end

#samsung_payObject

If this is a ‘samsung_pay` PaymentMethod, this sub-hash contains details about the Samsung Pay payment method options.



5864
5865
5866
# File 'lib/stripe/resources/payment_intent.rb', line 5864

def samsung_pay
  @samsung_pay
end

#satispayObject

If this is a ‘satispay` PaymentMethod, this sub-hash contains details about the Satispay payment method options.



5866
5867
5868
# File 'lib/stripe/resources/payment_intent.rb', line 5866

def satispay
  @satispay
end

#sepa_debitObject

If this is a ‘sepa_debit` PaymentIntent, this sub-hash contains details about the SEPA Debit payment method options.



5868
5869
5870
# File 'lib/stripe/resources/payment_intent.rb', line 5868

def sepa_debit
  @sepa_debit
end

#sofortObject

If this is a ‘sofort` PaymentMethod, this sub-hash contains details about the SOFORT payment method options.



5870
5871
5872
# File 'lib/stripe/resources/payment_intent.rb', line 5870

def sofort
  @sofort
end

#swishObject

If this is a ‘Swish` PaymentMethod, this sub-hash contains details about the Swish payment method options.



5872
5873
5874
# File 'lib/stripe/resources/payment_intent.rb', line 5872

def swish
  @swish
end

#twintObject

If this is a ‘twint` PaymentMethod, this sub-hash contains details about the TWINT payment method options.



5874
5875
5876
# File 'lib/stripe/resources/payment_intent.rb', line 5874

def twint
  @twint
end

#us_bank_accountObject

If this is a ‘us_bank_account` PaymentMethod, this sub-hash contains details about the US bank account payment method options.



5876
5877
5878
# File 'lib/stripe/resources/payment_intent.rb', line 5876

def 
  @us_bank_account
end

#wechat_payObject

If this is a ‘wechat_pay` PaymentMethod, this sub-hash contains details about the WeChat Pay payment method options.



5878
5879
5880
# File 'lib/stripe/resources/payment_intent.rb', line 5878

def wechat_pay
  @wechat_pay
end

#zipObject

If this is a ‘zip` PaymentMethod, this sub-hash contains details about the Zip payment method options.



5880
5881
5882
# File 'lib/stripe/resources/payment_intent.rb', line 5880

def zip
  @zip
end