Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Blik, Boleto, Card, CardPresent, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, Oxxo, P24, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, SepaDebit, Shopeepay, Sofort, Swish, Twint, UsBankAccount, WechatPay, Zip
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If this is a ‘acss_debit` PaymentMethod, this sub-hash contains details about the ACSS Debit payment method options.
-
#affirm ⇒ Object
If this is an ‘affirm` PaymentMethod, this sub-hash contains details about the Affirm payment method options.
-
#afterpay_clearpay ⇒ Object
If this is a ‘afterpay_clearpay` PaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options.
-
#alipay ⇒ Object
If this is a ‘alipay` PaymentMethod, this sub-hash contains details about the Alipay payment method options.
-
#alma ⇒ Object
If this is a ‘alma` PaymentMethod, this sub-hash contains details about the Alma payment method options.
-
#amazon_pay ⇒ Object
If this is a ‘amazon_pay` PaymentMethod, this sub-hash contains details about the Amazon Pay payment method options.
-
#au_becs_debit ⇒ Object
If this is a ‘au_becs_debit` PaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options.
-
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` PaymentMethod, this sub-hash contains details about the BACS Debit payment method options.
-
#bancontact ⇒ Object
If this is a ‘bancontact` PaymentMethod, this sub-hash contains details about the Bancontact payment method options.
-
#blik ⇒ Object
If this is a ‘blik` PaymentMethod, this sub-hash contains details about the BLIK payment method options.
-
#boleto ⇒ Object
If this is a ‘boleto` PaymentMethod, this sub-hash contains details about the Boleto payment method options.
-
#card ⇒ Object
Configuration for any card payments attempted on this PaymentIntent.
-
#card_present ⇒ Object
If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.
-
#cashapp ⇒ Object
If this is a ‘cashapp` PaymentMethod, this sub-hash contains details about the Cash App Pay payment method options.
-
#customer_balance ⇒ Object
If this is a ‘customer balance` PaymentMethod, this sub-hash contains details about the customer balance payment method options.
-
#eps ⇒ Object
If this is a ‘eps` PaymentMethod, this sub-hash contains details about the EPS payment method options.
-
#fpx ⇒ Object
If this is a ‘fpx` PaymentMethod, this sub-hash contains details about the FPX payment method options.
-
#giropay ⇒ Object
If this is a ‘giropay` PaymentMethod, this sub-hash contains details about the Giropay payment method options.
-
#gopay ⇒ Object
If this is a ‘gopay` PaymentMethod, this sub-hash contains details about the GoPay payment method options.
-
#grabpay ⇒ Object
If this is a ‘grabpay` PaymentMethod, this sub-hash contains details about the Grabpay payment method options.
-
#id_bank_transfer ⇒ Object
If this is a ‘id_bank_transfer` PaymentMethod, this sub-hash contains details about the Indonesia Bank Transfer payment method options.
-
#ideal ⇒ Object
If this is a ‘ideal` PaymentMethod, this sub-hash contains details about the Ideal payment method options.
-
#interac_present ⇒ Object
If this is a ‘interac_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.
-
#kakao_pay ⇒ Object
If this is a ‘kakao_pay` PaymentMethod, this sub-hash contains details about the Kakao Pay payment method options.
-
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this sub-hash contains details about the Klarna payment method options.
-
#konbini ⇒ Object
If this is a ‘konbini` PaymentMethod, this sub-hash contains details about the Konbini payment method options.
-
#kr_card ⇒ Object
If this is a ‘kr_card` PaymentMethod, this sub-hash contains details about the KR Card payment method options.
-
#link ⇒ Object
If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options.
-
#mb_way ⇒ Object
If this is a ‘mb_way` PaymentMethod, this sub-hash contains details about the MB WAY payment method options.
-
#mobilepay ⇒ Object
If this is a ‘MobilePay` PaymentMethod, this sub-hash contains details about the MobilePay payment method options.
-
#multibanco ⇒ Object
If this is a ‘multibanco` PaymentMethod, this sub-hash contains details about the Multibanco payment method options.
-
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this sub-hash contains details about the Naver Pay payment method options.
-
#oxxo ⇒ Object
If this is a ‘oxxo` PaymentMethod, this sub-hash contains details about the OXXO payment method options.
-
#p24 ⇒ Object
If this is a ‘p24` PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options.
-
#payco ⇒ Object
If this is a ‘payco` PaymentMethod, this sub-hash contains details about the PAYCO payment method options.
-
#paynow ⇒ Object
If this is a ‘paynow` PaymentMethod, this sub-hash contains details about the PayNow payment method options.
-
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.
-
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this sub-hash contains details about the PayTo payment method options.
-
#pix ⇒ Object
If this is a ‘pix` PaymentMethod, this sub-hash contains details about the Pix payment method options.
-
#promptpay ⇒ Object
If this is a ‘promptpay` PaymentMethod, this sub-hash contains details about the PromptPay payment method options.
-
#qris ⇒ Object
If this is a ‘qris` PaymentMethod, this sub-hash contains details about the QRIS payment method options.
-
#rechnung ⇒ Object
If this is a ‘rechnung` PaymentMethod, this sub-hash contains details about the Rechnung payment method options.
-
#revolut_pay ⇒ Object
If this is a ‘revolut_pay` PaymentMethod, this sub-hash contains details about the Revolut Pay payment method options.
-
#samsung_pay ⇒ Object
If this is a ‘samsung_pay` PaymentMethod, this sub-hash contains details about the Samsung Pay payment method options.
-
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` PaymentIntent, this sub-hash contains details about the SEPA Debit payment method options.
-
#shopeepay ⇒ Object
If this is a ‘shopeepay` PaymentMethod, this sub-hash contains details about the ShopeePay payment method options.
-
#sofort ⇒ Object
If this is a ‘sofort` PaymentMethod, this sub-hash contains details about the SOFORT payment method options.
-
#swish ⇒ Object
If this is a ‘Swish` PaymentMethod, this sub-hash contains details about the Swish payment method options.
-
#twint ⇒ Object
If this is a ‘twint` PaymentMethod, this sub-hash contains details about the TWINT payment method options.
-
#us_bank_account ⇒ Object
If this is a ‘us_bank_account` PaymentMethod, this sub-hash contains details about the US bank account payment method options.
-
#wechat_pay ⇒ Object
If this is a ‘wechat_pay` PaymentMethod, this sub-hash contains details about the WeChat Pay payment method options.
-
#zip ⇒ Object
If this is a ‘zip` PaymentMethod, this sub-hash contains details about the Zip payment method options.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, blik: nil, boleto: nil, card: nil, card_present: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, oxxo: nil, p24: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
9384 9385 9386 9387 9388 9389 9390 9391 9392 9393 9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 9425 9426 9427 9428 9429 9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 |
# File 'lib/stripe/resources/payment_intent.rb', line 9384 def initialize( acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, blik: nil, boleto: nil, card: nil, card_present: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, oxxo: nil, p24: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil ) @acss_debit = acss_debit @affirm = affirm @afterpay_clearpay = afterpay_clearpay @alipay = alipay @alma = alma @amazon_pay = amazon_pay @au_becs_debit = au_becs_debit @bacs_debit = bacs_debit @bancontact = bancontact @blik = blik @boleto = boleto @card = card @card_present = card_present @cashapp = cashapp @customer_balance = customer_balance @eps = eps @fpx = fpx @giropay = giropay @gopay = gopay @grabpay = grabpay @id_bank_transfer = id_bank_transfer @ideal = ideal @interac_present = interac_present @kakao_pay = kakao_pay @klarna = klarna @konbini = konbini @kr_card = kr_card @link = link @mb_way = mb_way @mobilepay = mobilepay @multibanco = multibanco @naver_pay = naver_pay @oxxo = oxxo @p24 = p24 @payco = payco @paynow = paynow @paypal = paypal @payto = payto @pix = pix @promptpay = promptpay @qris = qris @rechnung = rechnung @revolut_pay = revolut_pay @samsung_pay = samsung_pay @sepa_debit = sepa_debit @shopeepay = shopeepay @sofort = sofort @swish = swish @twint = twint @us_bank_account = us_bank_account @wechat_pay = wechat_pay @zip = zip end |
Instance Attribute Details
#acss_debit ⇒ Object
If this is a ‘acss_debit` PaymentMethod, this sub-hash contains details about the ACSS Debit payment method options.
9229 9230 9231 |
# File 'lib/stripe/resources/payment_intent.rb', line 9229 def acss_debit @acss_debit end |
#affirm ⇒ Object
If this is an ‘affirm` PaymentMethod, this sub-hash contains details about the Affirm payment method options.
9232 9233 9234 |
# File 'lib/stripe/resources/payment_intent.rb', line 9232 def affirm @affirm end |
#afterpay_clearpay ⇒ Object
If this is a ‘afterpay_clearpay` PaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options.
9235 9236 9237 |
# File 'lib/stripe/resources/payment_intent.rb', line 9235 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
If this is a ‘alipay` PaymentMethod, this sub-hash contains details about the Alipay payment method options.
9238 9239 9240 |
# File 'lib/stripe/resources/payment_intent.rb', line 9238 def alipay @alipay end |
#alma ⇒ Object
If this is a ‘alma` PaymentMethod, this sub-hash contains details about the Alma payment method options.
9241 9242 9243 |
# File 'lib/stripe/resources/payment_intent.rb', line 9241 def alma @alma end |
#amazon_pay ⇒ Object
If this is a ‘amazon_pay` PaymentMethod, this sub-hash contains details about the Amazon Pay payment method options.
9244 9245 9246 |
# File 'lib/stripe/resources/payment_intent.rb', line 9244 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object
If this is a ‘au_becs_debit` PaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options.
9247 9248 9249 |
# File 'lib/stripe/resources/payment_intent.rb', line 9247 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` PaymentMethod, this sub-hash contains details about the BACS Debit payment method options.
9250 9251 9252 |
# File 'lib/stripe/resources/payment_intent.rb', line 9250 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object
If this is a ‘bancontact` PaymentMethod, this sub-hash contains details about the Bancontact payment method options.
9253 9254 9255 |
# File 'lib/stripe/resources/payment_intent.rb', line 9253 def bancontact @bancontact end |
#blik ⇒ Object
If this is a ‘blik` PaymentMethod, this sub-hash contains details about the BLIK payment method options.
9256 9257 9258 |
# File 'lib/stripe/resources/payment_intent.rb', line 9256 def blik @blik end |
#boleto ⇒ Object
If this is a ‘boleto` PaymentMethod, this sub-hash contains details about the Boleto payment method options.
9259 9260 9261 |
# File 'lib/stripe/resources/payment_intent.rb', line 9259 def boleto @boleto end |
#card ⇒ Object
Configuration for any card payments attempted on this PaymentIntent.
9262 9263 9264 |
# File 'lib/stripe/resources/payment_intent.rb', line 9262 def card @card end |
#card_present ⇒ Object
If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.
9265 9266 9267 |
# File 'lib/stripe/resources/payment_intent.rb', line 9265 def card_present @card_present end |
#cashapp ⇒ Object
If this is a ‘cashapp` PaymentMethod, this sub-hash contains details about the Cash App Pay payment method options.
9268 9269 9270 |
# File 'lib/stripe/resources/payment_intent.rb', line 9268 def cashapp @cashapp end |
#customer_balance ⇒ Object
If this is a ‘customer balance` PaymentMethod, this sub-hash contains details about the customer balance payment method options.
9271 9272 9273 |
# File 'lib/stripe/resources/payment_intent.rb', line 9271 def customer_balance @customer_balance end |
#eps ⇒ Object
If this is a ‘eps` PaymentMethod, this sub-hash contains details about the EPS payment method options.
9274 9275 9276 |
# File 'lib/stripe/resources/payment_intent.rb', line 9274 def eps @eps end |
#fpx ⇒ Object
If this is a ‘fpx` PaymentMethod, this sub-hash contains details about the FPX payment method options.
9277 9278 9279 |
# File 'lib/stripe/resources/payment_intent.rb', line 9277 def fpx @fpx end |
#giropay ⇒ Object
If this is a ‘giropay` PaymentMethod, this sub-hash contains details about the Giropay payment method options.
9280 9281 9282 |
# File 'lib/stripe/resources/payment_intent.rb', line 9280 def giropay @giropay end |
#gopay ⇒ Object
If this is a ‘gopay` PaymentMethod, this sub-hash contains details about the GoPay payment method options.
9283 9284 9285 |
# File 'lib/stripe/resources/payment_intent.rb', line 9283 def gopay @gopay end |
#grabpay ⇒ Object
If this is a ‘grabpay` PaymentMethod, this sub-hash contains details about the Grabpay payment method options.
9286 9287 9288 |
# File 'lib/stripe/resources/payment_intent.rb', line 9286 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object
If this is a ‘id_bank_transfer` PaymentMethod, this sub-hash contains details about the Indonesia Bank Transfer payment method options.
9289 9290 9291 |
# File 'lib/stripe/resources/payment_intent.rb', line 9289 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object
If this is a ‘ideal` PaymentMethod, this sub-hash contains details about the Ideal payment method options.
9292 9293 9294 |
# File 'lib/stripe/resources/payment_intent.rb', line 9292 def ideal @ideal end |
#interac_present ⇒ Object
If this is a ‘interac_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.
9295 9296 9297 |
# File 'lib/stripe/resources/payment_intent.rb', line 9295 def interac_present @interac_present end |
#kakao_pay ⇒ Object
If this is a ‘kakao_pay` PaymentMethod, this sub-hash contains details about the Kakao Pay payment method options.
9298 9299 9300 |
# File 'lib/stripe/resources/payment_intent.rb', line 9298 def kakao_pay @kakao_pay end |
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this sub-hash contains details about the Klarna payment method options.
9301 9302 9303 |
# File 'lib/stripe/resources/payment_intent.rb', line 9301 def klarna @klarna end |
#konbini ⇒ Object
If this is a ‘konbini` PaymentMethod, this sub-hash contains details about the Konbini payment method options.
9304 9305 9306 |
# File 'lib/stripe/resources/payment_intent.rb', line 9304 def konbini @konbini end |
#kr_card ⇒ Object
If this is a ‘kr_card` PaymentMethod, this sub-hash contains details about the KR Card payment method options.
9307 9308 9309 |
# File 'lib/stripe/resources/payment_intent.rb', line 9307 def kr_card @kr_card end |
#link ⇒ Object
If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options.
9310 9311 9312 |
# File 'lib/stripe/resources/payment_intent.rb', line 9310 def link @link end |
#mb_way ⇒ Object
If this is a ‘mb_way` PaymentMethod, this sub-hash contains details about the MB WAY payment method options.
9313 9314 9315 |
# File 'lib/stripe/resources/payment_intent.rb', line 9313 def mb_way @mb_way end |
#mobilepay ⇒ Object
If this is a ‘MobilePay` PaymentMethod, this sub-hash contains details about the MobilePay payment method options.
9316 9317 9318 |
# File 'lib/stripe/resources/payment_intent.rb', line 9316 def mobilepay @mobilepay end |
#multibanco ⇒ Object
If this is a ‘multibanco` PaymentMethod, this sub-hash contains details about the Multibanco payment method options.
9319 9320 9321 |
# File 'lib/stripe/resources/payment_intent.rb', line 9319 def multibanco @multibanco end |
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this sub-hash contains details about the Naver Pay payment method options.
9322 9323 9324 |
# File 'lib/stripe/resources/payment_intent.rb', line 9322 def naver_pay @naver_pay end |
#oxxo ⇒ Object
If this is a ‘oxxo` PaymentMethod, this sub-hash contains details about the OXXO payment method options.
9325 9326 9327 |
# File 'lib/stripe/resources/payment_intent.rb', line 9325 def oxxo @oxxo end |
#p24 ⇒ Object
If this is a ‘p24` PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options.
9328 9329 9330 |
# File 'lib/stripe/resources/payment_intent.rb', line 9328 def p24 @p24 end |
#payco ⇒ Object
If this is a ‘payco` PaymentMethod, this sub-hash contains details about the PAYCO payment method options.
9331 9332 9333 |
# File 'lib/stripe/resources/payment_intent.rb', line 9331 def payco @payco end |
#paynow ⇒ Object
If this is a ‘paynow` PaymentMethod, this sub-hash contains details about the PayNow payment method options.
9334 9335 9336 |
# File 'lib/stripe/resources/payment_intent.rb', line 9334 def paynow @paynow end |
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.
9337 9338 9339 |
# File 'lib/stripe/resources/payment_intent.rb', line 9337 def paypal @paypal end |
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this sub-hash contains details about the PayTo payment method options.
9340 9341 9342 |
# File 'lib/stripe/resources/payment_intent.rb', line 9340 def payto @payto end |
#pix ⇒ Object
If this is a ‘pix` PaymentMethod, this sub-hash contains details about the Pix payment method options.
9343 9344 9345 |
# File 'lib/stripe/resources/payment_intent.rb', line 9343 def pix @pix end |
#promptpay ⇒ Object
If this is a ‘promptpay` PaymentMethod, this sub-hash contains details about the PromptPay payment method options.
9346 9347 9348 |
# File 'lib/stripe/resources/payment_intent.rb', line 9346 def promptpay @promptpay end |
#qris ⇒ Object
If this is a ‘qris` PaymentMethod, this sub-hash contains details about the QRIS payment method options.
9349 9350 9351 |
# File 'lib/stripe/resources/payment_intent.rb', line 9349 def qris @qris end |
#rechnung ⇒ Object
If this is a ‘rechnung` PaymentMethod, this sub-hash contains details about the Rechnung payment method options.
9352 9353 9354 |
# File 'lib/stripe/resources/payment_intent.rb', line 9352 def rechnung @rechnung end |
#revolut_pay ⇒ Object
If this is a ‘revolut_pay` PaymentMethod, this sub-hash contains details about the Revolut Pay payment method options.
9355 9356 9357 |
# File 'lib/stripe/resources/payment_intent.rb', line 9355 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object
If this is a ‘samsung_pay` PaymentMethod, this sub-hash contains details about the Samsung Pay payment method options.
9358 9359 9360 |
# File 'lib/stripe/resources/payment_intent.rb', line 9358 def samsung_pay @samsung_pay end |
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` PaymentIntent, this sub-hash contains details about the SEPA Debit payment method options.
9361 9362 9363 |
# File 'lib/stripe/resources/payment_intent.rb', line 9361 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object
If this is a ‘shopeepay` PaymentMethod, this sub-hash contains details about the ShopeePay payment method options.
9364 9365 9366 |
# File 'lib/stripe/resources/payment_intent.rb', line 9364 def shopeepay @shopeepay end |
#sofort ⇒ Object
If this is a ‘sofort` PaymentMethod, this sub-hash contains details about the SOFORT payment method options.
9367 9368 9369 |
# File 'lib/stripe/resources/payment_intent.rb', line 9367 def sofort @sofort end |
#swish ⇒ Object
If this is a ‘Swish` PaymentMethod, this sub-hash contains details about the Swish payment method options.
9370 9371 9372 |
# File 'lib/stripe/resources/payment_intent.rb', line 9370 def swish @swish end |
#twint ⇒ Object
If this is a ‘twint` PaymentMethod, this sub-hash contains details about the TWINT payment method options.
9373 9374 9375 |
# File 'lib/stripe/resources/payment_intent.rb', line 9373 def twint @twint end |
#us_bank_account ⇒ Object
If this is a ‘us_bank_account` PaymentMethod, this sub-hash contains details about the US bank account payment method options.
9376 9377 9378 |
# File 'lib/stripe/resources/payment_intent.rb', line 9376 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
If this is a ‘wechat_pay` PaymentMethod, this sub-hash contains details about the WeChat Pay payment method options.
9379 9380 9381 |
# File 'lib/stripe/resources/payment_intent.rb', line 9379 def wechat_pay @wechat_pay end |
#zip ⇒ Object
If this is a ‘zip` PaymentMethod, this sub-hash contains details about the Zip payment method options.
9382 9383 9384 |
# File 'lib/stripe/resources/payment_intent.rb', line 9382 def zip @zip end |