Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Card

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Installments, MandateOptions, ThreeDSecure

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capture_method: nil, cvc_token: nil, installments: nil, mandate_options: nil, moto: nil, network: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_three_d_secure: nil, require_cvc_recollection: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil, three_d_secure: nil) ⇒ Card

Returns a new instance of Card.



4937
4938
4939
4940
4941
4942
4943
4944
4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
4970
4971
# File 'lib/stripe/resources/payment_intent.rb', line 4937

def initialize(
  capture_method: nil,
  cvc_token: nil,
  installments: nil,
  mandate_options: nil,
  moto: nil,
  network: nil,
  request_extended_authorization: nil,
  request_incremental_authorization: nil,
  request_multicapture: nil,
  request_overcapture: nil,
  request_three_d_secure: nil,
  require_cvc_recollection: nil,
  setup_future_usage: nil,
  statement_descriptor_suffix_kana: nil,
  statement_descriptor_suffix_kanji: nil,
  three_d_secure: nil
)
  @capture_method = capture_method
  @cvc_token = cvc_token
  @installments = installments
  @mandate_options = mandate_options
  @moto = moto
  @network = network
  @request_extended_authorization = request_extended_authorization
  @request_incremental_authorization = request_incremental_authorization
  @request_multicapture = request_multicapture
  @request_overcapture = request_overcapture
  @request_three_d_secure = request_three_d_secure
  @require_cvc_recollection = require_cvc_recollection
  @setup_future_usage = setup_future_usage
  @statement_descriptor_suffix_kana = statement_descriptor_suffix_kana
  @statement_descriptor_suffix_kanji = statement_descriptor_suffix_kanji
  @three_d_secure = three_d_secure
end

Instance Attribute Details

#capture_methodObject

Controls when the funds are captured from the customer’s account.

If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.

If ‘capture_method` is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.



4892
4893
4894
# File 'lib/stripe/resources/payment_intent.rb', line 4892

def capture_method
  @capture_method
end

#cvc_tokenObject

A single-use ‘cvc_update` Token that represents a card CVC value. When provided, the CVC value will be verified during the card payment attempt. This parameter can only be provided during confirmation.



4894
4895
4896
# File 'lib/stripe/resources/payment_intent.rb', line 4894

def cvc_token
  @cvc_token
end

#installmentsObject

Installment configuration for payments attempted on this PaymentIntent (Mexico Only).

For more information, see the [installments integration guide](stripe.com/docs/payments/installments).



4898
4899
4900
# File 'lib/stripe/resources/payment_intent.rb', line 4898

def installments
  @installments
end

#mandate_optionsObject

Configuration options for setting up an eMandate for cards issued in India.



4900
4901
4902
# File 'lib/stripe/resources/payment_intent.rb', line 4900

def mandate_options
  @mandate_options
end

#motoObject

When specified, this parameter indicates that a transaction will be marked as MOTO (Mail Order Telephone Order) and thus out of scope for SCA. This parameter can only be provided during confirmation.



4904
4905
4906
# File 'lib/stripe/resources/payment_intent.rb', line 4904

def moto
  @moto
end

#networkObject

Selected network to process this PaymentIntent on. Depends on the available networks of the card attached to the PaymentIntent. Can be only set confirm-time.



4906
4907
4908
# File 'lib/stripe/resources/payment_intent.rb', line 4906

def network
  @network
end

#request_extended_authorizationObject

Request ability to [capture beyond the standard authorization validity window](stripe.com/docs/payments/extended-authorization) for this PaymentIntent.



4908
4909
4910
# File 'lib/stripe/resources/payment_intent.rb', line 4908

def request_extended_authorization
  @request_extended_authorization
end

#request_incremental_authorizationObject

Request ability to [increment the authorization](stripe.com/docs/payments/incremental-authorization) for this PaymentIntent.



4910
4911
4912
# File 'lib/stripe/resources/payment_intent.rb', line 4910

def request_incremental_authorization
  @request_incremental_authorization
end

#request_multicaptureObject

Request ability to make [multiple captures](stripe.com/docs/payments/multicapture) for this PaymentIntent.



4912
4913
4914
# File 'lib/stripe/resources/payment_intent.rb', line 4912

def request_multicapture
  @request_multicapture
end

#request_overcaptureObject

Request ability to [overcapture](stripe.com/docs/payments/overcapture) for this PaymentIntent.



4914
4915
4916
# File 'lib/stripe/resources/payment_intent.rb', line 4914

def request_overcapture
  @request_overcapture
end

#request_three_d_secureObject

We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](stripe.com/docs/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.



4916
4917
4918
# File 'lib/stripe/resources/payment_intent.rb', line 4916

def request_three_d_secure
  @request_three_d_secure
end

#require_cvc_recollectionObject

When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).



4918
4919
4920
# File 'lib/stripe/resources/payment_intent.rb', line 4918

def require_cvc_recollection
  @require_cvc_recollection
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



4928
4929
4930
# File 'lib/stripe/resources/payment_intent.rb', line 4928

def setup_future_usage
  @setup_future_usage
end

#statement_descriptor_suffix_kanaObject

Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.



4930
4931
4932
# File 'lib/stripe/resources/payment_intent.rb', line 4930

def statement_descriptor_suffix_kana
  @statement_descriptor_suffix_kana
end

#statement_descriptor_suffix_kanjiObject

Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.



4932
4933
4934
# File 'lib/stripe/resources/payment_intent.rb', line 4932

def statement_descriptor_suffix_kanji
  @statement_descriptor_suffix_kanji
end

#three_d_secureObject

If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this payment.



4935
4936
4937
# File 'lib/stripe/resources/payment_intent.rb', line 4935

def three_d_secure
  @three_d_secure
end