Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Card::Installments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Card::Installments
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Plan
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Setting to true enables installments for this PaymentIntent.
-
#plan ⇒ Object
The selected installment plan to use for this payment attempt.
Instance Method Summary collapse
-
#initialize(enabled: nil, plan: nil) ⇒ Installments
constructor
A new instance of Installments.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, plan: nil) ⇒ Installments
Returns a new instance of Installments.
4764 4765 4766 4767 |
# File 'lib/stripe/resources/payment_intent.rb', line 4764 def initialize(enabled: nil, plan: nil) @enabled = enabled @plan = plan end |
Instance Attribute Details
#enabled ⇒ Object
Setting to true enables installments for this PaymentIntent. This will cause the response to contain a list of available installment plans. Setting to false will prevent any selected plan from applying to a charge.
4759 4760 4761 |
# File 'lib/stripe/resources/payment_intent.rb', line 4759 def enabled @enabled end |
#plan ⇒ Object
The selected installment plan to use for this payment attempt. This parameter can only be provided during confirmation.
4762 4763 4764 |
# File 'lib/stripe/resources/payment_intent.rb', line 4762 def plan @plan end |