Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



7649
7650
7651
7652
7653
# File 'lib/stripe/resources/payment_intent.rb', line 7649

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



7642
7643
7644
# File 'lib/stripe/resources/payment_intent.rb', line 7642

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



7645
7646
7647
# File 'lib/stripe/resources/payment_intent.rb', line 7645

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



7647
7648
7649
# File 'lib/stripe/resources/payment_intent.rb', line 7647

def type
  @type
end