Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



4870
4871
4872
4873
4874
# File 'lib/stripe/resources/payment_intent.rb', line 4870

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



4863
4864
4865
# File 'lib/stripe/resources/payment_intent.rb', line 4863

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



4866
4867
4868
# File 'lib/stripe/resources/payment_intent.rb', line 4866

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



4868
4869
4870
# File 'lib/stripe/resources/payment_intent.rb', line 4868

def type
  @type
end