Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



7227
7228
7229
7230
7231
# File 'lib/stripe/resources/payment_intent.rb', line 7227

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



7220
7221
7222
# File 'lib/stripe/resources/payment_intent.rb', line 7220

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



7223
7224
7225
# File 'lib/stripe/resources/payment_intent.rb', line 7223

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`.



7225
7226
7227
# File 'lib/stripe/resources/payment_intent.rb', line 7225

def type
  @type
end