Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



7172
7173
7174
7175
7176
# File 'lib/stripe/resources/payment_intent.rb', line 7172

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



7165
7166
7167
# File 'lib/stripe/resources/payment_intent.rb', line 7165

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



7168
7169
7170
# File 'lib/stripe/resources/payment_intent.rb', line 7168

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`.



7170
7171
7172
# File 'lib/stripe/resources/payment_intent.rb', line 7170

def type
  @type
end