Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



6911
6912
6913
6914
6915
# File 'lib/stripe/resources/payment_intent.rb', line 6911

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



6904
6905
6906
# File 'lib/stripe/resources/payment_intent.rb', line 6904

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



6907
6908
6909
# File 'lib/stripe/resources/payment_intent.rb', line 6907

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`.



6909
6910
6911
# File 'lib/stripe/resources/payment_intent.rb', line 6909

def type
  @type
end