Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Card::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Card::MandateOptions
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments.
-
#amount_type ⇒ Object
One of ‘fixed` or `maximum`.
-
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
-
#end_date ⇒ Object
End date of the mandate or subscription.
-
#interval ⇒ Object
Specifies payment frequency.
-
#interval_count ⇒ Object
The number of intervals between payments.
-
#reference ⇒ Object
Unique identifier for the mandate or subscription.
-
#start_date ⇒ Object
Start date of the mandate or subscription.
-
#supported_types ⇒ Object
Specifies the type of mandates supported.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 |
# File 'lib/stripe/resources/payment_intent.rb', line 7267 def initialize( amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil ) @amount = amount @amount_type = amount_type @description = description @end_date = end_date @interval = interval @interval_count = interval_count @reference = reference @start_date = start_date @supported_types = supported_types end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments.
7249 7250 7251 |
# File 'lib/stripe/resources/payment_intent.rb', line 7249 def amount @amount end |
#amount_type ⇒ Object
One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.
7251 7252 7253 |
# File 'lib/stripe/resources/payment_intent.rb', line 7251 def amount_type @amount_type end |
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
7253 7254 7255 |
# File 'lib/stripe/resources/payment_intent.rb', line 7253 def description @description end |
#end_date ⇒ Object
End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.
7255 7256 7257 |
# File 'lib/stripe/resources/payment_intent.rb', line 7255 def end_date @end_date end |
#interval ⇒ Object
Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.
7257 7258 7259 |
# File 'lib/stripe/resources/payment_intent.rb', line 7257 def interval @interval end |
#interval_count ⇒ Object
The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.
7259 7260 7261 |
# File 'lib/stripe/resources/payment_intent.rb', line 7259 def interval_count @interval_count end |
#reference ⇒ Object
Unique identifier for the mandate or subscription.
7261 7262 7263 |
# File 'lib/stripe/resources/payment_intent.rb', line 7261 def reference @reference end |
#start_date ⇒ Object
Start date of the mandate or subscription. Start date should not be lesser than yesterday.
7263 7264 7265 |
# File 'lib/stripe/resources/payment_intent.rb', line 7263 def start_date @start_date end |
#supported_types ⇒ Object
Specifies the type of mandates supported. Possible values are ‘india`.
7265 7266 7267 |
# File 'lib/stripe/resources/payment_intent.rb', line 7265 def supported_types @supported_types end |