Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



6881
6882
6883
6884
6885
6886
6887
6888
6889
6890
6891
6892
6893
6894
6895
6896
6897
6898
6899
6900
6901
# File 'lib/stripe/resources/payment_intent.rb', line 6881

def initialize(
  amount: nil,
  amount_type: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



6863
6864
6865
# File 'lib/stripe/resources/payment_intent.rb', line 6863

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



6865
6866
6867
# File 'lib/stripe/resources/payment_intent.rb', line 6865

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



6867
6868
6869
# File 'lib/stripe/resources/payment_intent.rb', line 6867

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



6869
6870
6871
# File 'lib/stripe/resources/payment_intent.rb', line 6869

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



6871
6872
6873
# File 'lib/stripe/resources/payment_intent.rb', line 6871

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



6873
6874
6875
# File 'lib/stripe/resources/payment_intent.rb', line 6873

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



6875
6876
6877
# File 'lib/stripe/resources/payment_intent.rb', line 6875

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



6877
6878
6879
# File 'lib/stripe/resources/payment_intent.rb', line 6877

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are ‘india`.



6879
6880
6881
# File 'lib/stripe/resources/payment_intent.rb', line 6879

def supported_types
  @supported_types
end