Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Card::ThreeDSecure
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Card::ThreeDSecure
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: NetworkOptions
Instance Attribute Summary collapse
-
#ares_trans_status ⇒ Object
The ‘transStatus` returned from the card Issuer’s ACS in the ARes.
-
#cryptogram ⇒ Object
The cryptogram, also known as the “authentication value” (AAV, CAVV or AEVV).
-
#electronic_commerce_indicator ⇒ Object
The Electronic Commerce Indicator (ECI) is returned by your 3D Secure provider and indicates what degree of authentication was performed.
-
#exemption_indicator ⇒ Object
The exemption requested via 3DS and accepted by the issuer at authentication time.
-
#network_options ⇒ Object
Network specific 3DS fields.
-
#requestor_challenge_indicator ⇒ Object
The challenge indicator (‘threeDSRequestorChallengeInd`) which was requested in the AReq sent to the card Issuer’s ACS.
-
#transaction_id ⇒ Object
For 3D Secure 1, the XID.
-
#version ⇒ Object
The version of 3D Secure that was performed.
Instance Method Summary collapse
-
#initialize(ares_trans_status: nil, cryptogram: nil, electronic_commerce_indicator: nil, exemption_indicator: nil, network_options: nil, requestor_challenge_indicator: nil, transaction_id: nil, version: nil) ⇒ ThreeDSecure
constructor
A new instance of ThreeDSecure.
Methods inherited from RequestParams
Constructor Details
#initialize(ares_trans_status: nil, cryptogram: nil, electronic_commerce_indicator: nil, exemption_indicator: nil, network_options: nil, requestor_challenge_indicator: nil, transaction_id: nil, version: nil) ⇒ ThreeDSecure
Returns a new instance of ThreeDSecure.
7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 |
# File 'lib/stripe/resources/payment_intent.rb', line 7378 def initialize( ares_trans_status: nil, cryptogram: nil, electronic_commerce_indicator: nil, exemption_indicator: nil, network_options: nil, requestor_challenge_indicator: nil, transaction_id: nil, version: nil ) @ares_trans_status = ares_trans_status @cryptogram = cryptogram @electronic_commerce_indicator = electronic_commerce_indicator @exemption_indicator = exemption_indicator @network_options = @requestor_challenge_indicator = requestor_challenge_indicator @transaction_id = transaction_id @version = version end |
Instance Attribute Details
#ares_trans_status ⇒ Object
The ‘transStatus` returned from the card Issuer’s ACS in the ARes.
7354 7355 7356 |
# File 'lib/stripe/resources/payment_intent.rb', line 7354 def ares_trans_status @ares_trans_status end |
#cryptogram ⇒ Object
The cryptogram, also known as the “authentication value” (AAV, CAVV or AEVV). This value is 20 bytes, base64-encoded into a 28-character string. (Most 3D Secure providers will return the base64-encoded version, which is what you should specify here.)
7359 7360 7361 |
# File 'lib/stripe/resources/payment_intent.rb', line 7359 def cryptogram @cryptogram end |
#electronic_commerce_indicator ⇒ Object
The Electronic Commerce Indicator (ECI) is returned by your 3D Secure provider and indicates what degree of authentication was performed.
7362 7363 7364 |
# File 'lib/stripe/resources/payment_intent.rb', line 7362 def electronic_commerce_indicator @electronic_commerce_indicator end |
#exemption_indicator ⇒ Object
The exemption requested via 3DS and accepted by the issuer at authentication time.
7364 7365 7366 |
# File 'lib/stripe/resources/payment_intent.rb', line 7364 def exemption_indicator @exemption_indicator end |
#network_options ⇒ Object
Network specific 3DS fields. Network specific arguments require an explicit card brand choice. The parameter ‘payment_method_options.card.network“ must be populated accordingly
7368 7369 7370 |
# File 'lib/stripe/resources/payment_intent.rb', line 7368 def @network_options end |
#requestor_challenge_indicator ⇒ Object
The challenge indicator (‘threeDSRequestorChallengeInd`) which was requested in the AReq sent to the card Issuer’s ACS. A string containing 2 digits from 01-99.
7371 7372 7373 |
# File 'lib/stripe/resources/payment_intent.rb', line 7371 def requestor_challenge_indicator @requestor_challenge_indicator end |
#transaction_id ⇒ Object
For 3D Secure 1, the XID. For 3D Secure 2, the Directory Server Transaction ID (dsTransID).
7374 7375 7376 |
# File 'lib/stripe/resources/payment_intent.rb', line 7374 def transaction_id @transaction_id end |
#version ⇒ Object
The version of 3D Secure that was performed.
7376 7377 7378 |
# File 'lib/stripe/resources/payment_intent.rb', line 7376 def version @version end |