Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Klarna::OnDemand

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand

Returns a new instance of OnDemand.



8204
8205
8206
8207
8208
8209
8210
8211
8212
8213
8214
8215
8216
# File 'lib/stripe/resources/payment_intent.rb', line 8204

def initialize(
  average_amount: nil,
  maximum_amount: nil,
  minimum_amount: nil,
  purchase_interval: nil,
  purchase_interval_count: nil
)
  @average_amount = average_amount
  @maximum_amount = maximum_amount
  @minimum_amount = minimum_amount
  @purchase_interval = purchase_interval
  @purchase_interval_count = purchase_interval_count
end

Instance Attribute Details

#average_amountObject

Your average amount value. You can use a value across your customer base, or segment based on customer type, country, etc.



8194
8195
8196
# File 'lib/stripe/resources/payment_intent.rb', line 8194

def average_amount
  @average_amount
end

#maximum_amountObject

The maximum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



8196
8197
8198
# File 'lib/stripe/resources/payment_intent.rb', line 8196

def maximum_amount
  @maximum_amount
end

#minimum_amountObject

The lowest or minimum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



8198
8199
8200
# File 'lib/stripe/resources/payment_intent.rb', line 8198

def minimum_amount
  @minimum_amount
end

#purchase_intervalObject

Interval at which the customer is making purchases



8200
8201
8202
# File 'lib/stripe/resources/payment_intent.rb', line 8200

def purchase_interval
  @purchase_interval
end

#purchase_interval_countObject

The number of ‘purchase_interval` between charges



8202
8203
8204
# File 'lib/stripe/resources/payment_intent.rb', line 8202

def purchase_interval_count
  @purchase_interval_count
end