Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Klarna::OnDemand

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand

Returns a new instance of OnDemand.



5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
# File 'lib/stripe/resources/payment_intent.rb', line 5331

def initialize(
  average_amount: nil,
  maximum_amount: nil,
  minimum_amount: nil,
  purchase_interval: nil,
  purchase_interval_count: nil
)
  @average_amount = average_amount
  @maximum_amount = maximum_amount
  @minimum_amount = minimum_amount
  @purchase_interval = purchase_interval
  @purchase_interval_count = purchase_interval_count
end

Instance Attribute Details

#average_amountObject

Your average amount value. You can use a value across your customer base, or segment based on customer type, country, etc.



5321
5322
5323
# File 'lib/stripe/resources/payment_intent.rb', line 5321

def average_amount
  @average_amount
end

#maximum_amountObject

The maximum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



5323
5324
5325
# File 'lib/stripe/resources/payment_intent.rb', line 5323

def maximum_amount
  @maximum_amount
end

#minimum_amountObject

The lowest or minimum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



5325
5326
5327
# File 'lib/stripe/resources/payment_intent.rb', line 5325

def minimum_amount
  @minimum_amount
end

#purchase_intervalObject

Interval at which the customer is making purchases



5327
5328
5329
# File 'lib/stripe/resources/payment_intent.rb', line 5327

def purchase_interval
  @purchase_interval
end

#purchase_interval_countObject

The number of ‘purchase_interval` between charges



5329
5330
5331
# File 'lib/stripe/resources/payment_intent.rb', line 5329

def purchase_interval_count
  @purchase_interval_count
end