Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
5383 5384 5385 5386 5387 5388 5389 5390 5391 5392 5393 5394 5395 |
# File 'lib/stripe/resources/payment_intent.rb', line 5383 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
5373 5374 5375 |
# File 'lib/stripe/resources/payment_intent.rb', line 5373 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
5375 5376 5377 |
# File 'lib/stripe/resources/payment_intent.rb', line 5375 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
5377 5378 5379 |
# File 'lib/stripe/resources/payment_intent.rb', line 5377 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
5379 5380 5381 |
# File 'lib/stripe/resources/payment_intent.rb', line 5379 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
5381 5382 5383 |
# File 'lib/stripe/resources/payment_intent.rb', line 5381 def reference @reference end |