Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 |
# File 'lib/stripe/resources/payment_intent.rb', line 7932 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
7922 7923 7924 |
# File 'lib/stripe/resources/payment_intent.rb', line 7922 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
7924 7925 7926 |
# File 'lib/stripe/resources/payment_intent.rb', line 7924 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
7926 7927 7928 |
# File 'lib/stripe/resources/payment_intent.rb', line 7926 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
7928 7929 7930 |
# File 'lib/stripe/resources/payment_intent.rb', line 7928 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
7930 7931 7932 |
# File 'lib/stripe/resources/payment_intent.rb', line 7930 def reference @reference end |