Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



8302
8303
8304
8305
# File 'lib/stripe/resources/payment_intent.rb', line 8302

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



8298
8299
8300
# File 'lib/stripe/resources/payment_intent.rb', line 8298

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



8300
8301
8302
# File 'lib/stripe/resources/payment_intent.rb', line 8300

def date
  @date
end