Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



5367
5368
5369
5370
# File 'lib/stripe/resources/payment_intent.rb', line 5367

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



5363
5364
5365
# File 'lib/stripe/resources/payment_intent.rb', line 5363

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



5365
5366
5367
# File 'lib/stripe/resources/payment_intent.rb', line 5365

def date
  @date
end