Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



8226
8227
8228
8229
# File 'lib/stripe/resources/payment_intent.rb', line 8226

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



8222
8223
8224
# File 'lib/stripe/resources/payment_intent.rb', line 8222

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



8224
8225
8226
# File 'lib/stripe/resources/payment_intent.rb', line 8224

def date
  @date
end