Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



5353
5354
5355
5356
# File 'lib/stripe/resources/payment_intent.rb', line 5353

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



5349
5350
5351
# File 'lib/stripe/resources/payment_intent.rb', line 5349

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



5351
5352
5353
# File 'lib/stripe/resources/payment_intent.rb', line 5351

def date
  @date
end