Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Paypal

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capture_method: nil, preferred_locale: nil, reference: nil, risk_correlation_id: nil, setup_future_usage: nil) ⇒ Paypal

Returns a new instance of Paypal.



5680
5681
5682
5683
5684
5685
5686
5687
5688
5689
5690
5691
5692
# File 'lib/stripe/resources/payment_intent.rb', line 5680

def initialize(
  capture_method: nil,
  preferred_locale: nil,
  reference: nil,
  risk_correlation_id: nil,
  setup_future_usage: nil
)
  @capture_method = capture_method
  @preferred_locale = preferred_locale
  @reference = reference
  @risk_correlation_id = risk_correlation_id
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#capture_methodObject

Controls when the funds will be captured from the customer’s account.



5662
5663
5664
# File 'lib/stripe/resources/payment_intent.rb', line 5662

def capture_method
  @capture_method
end

#preferred_localeObject

[Preferred locale](stripe.com/docs/payments/paypal/supported-locales) of the PayPal checkout page that the customer is redirected to.



5664
5665
5666
# File 'lib/stripe/resources/payment_intent.rb', line 5664

def preferred_locale
  @preferred_locale
end

#referenceObject

A reference of the PayPal transaction visible to customer which is mapped to PayPal’s invoice ID. This must be a globally unique ID if you have configured in your PayPal settings to block multiple payments per invoice ID.



5666
5667
5668
# File 'lib/stripe/resources/payment_intent.rb', line 5666

def reference
  @reference
end

#risk_correlation_idObject

The risk correlation ID for an on-session payment using a saved PayPal payment method.



5668
5669
5670
# File 'lib/stripe/resources/payment_intent.rb', line 5668

def risk_correlation_id
  @risk_correlation_id
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



5678
5679
5680
# File 'lib/stripe/resources/payment_intent.rb', line 5678

def setup_future_usage
  @setup_future_usage
end