Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
8656 8657 8658 8659 8660 8661 8662 8663 8664 8665 8666 8667 8668 8669 8670 8671 8672 8673 8674 |
# File 'lib/stripe/resources/payment_intent.rb', line 8656 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
8640 8641 8642 |
# File 'lib/stripe/resources/payment_intent.rb', line 8640 def category @category end |
#description ⇒ Object
Description of the line item.
8642 8643 8644 |
# File 'lib/stripe/resources/payment_intent.rb', line 8642 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
8644 8645 8646 |
# File 'lib/stripe/resources/payment_intent.rb', line 8644 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
8646 8647 8648 |
# File 'lib/stripe/resources/payment_intent.rb', line 8646 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
8648 8649 8650 |
# File 'lib/stripe/resources/payment_intent.rb', line 8648 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
8650 8651 8652 |
# File 'lib/stripe/resources/payment_intent.rb', line 8650 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
8652 8653 8654 |
# File 'lib/stripe/resources/payment_intent.rb', line 8652 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
8654 8655 8656 |
# File 'lib/stripe/resources/payment_intent.rb', line 8654 def unit_amount @unit_amount end |