Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
8580 8581 8582 8583 8584 8585 8586 8587 8588 8589 8590 8591 8592 8593 8594 8595 8596 8597 8598 |
# File 'lib/stripe/resources/payment_intent.rb', line 8580 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
8564 8565 8566 |
# File 'lib/stripe/resources/payment_intent.rb', line 8564 def category @category end |
#description ⇒ Object
Description of the line item.
8566 8567 8568 |
# File 'lib/stripe/resources/payment_intent.rb', line 8566 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
8568 8569 8570 |
# File 'lib/stripe/resources/payment_intent.rb', line 8568 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
8570 8571 8572 |
# File 'lib/stripe/resources/payment_intent.rb', line 8570 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
8572 8573 8574 |
# File 'lib/stripe/resources/payment_intent.rb', line 8572 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
8574 8575 8576 |
# File 'lib/stripe/resources/payment_intent.rb', line 8574 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
8576 8577 8578 |
# File 'lib/stripe/resources/payment_intent.rb', line 8576 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
8578 8579 8580 |
# File 'lib/stripe/resources/payment_intent.rb', line 8578 def unit_amount @unit_amount end |