Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
8281
8282
8283
8284
8285
8286
8287
8288
# File 'lib/stripe/resources/payment_intent.rb', line 8270

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



8254
8255
8256
# File 'lib/stripe/resources/payment_intent.rb', line 8254

def category
  @category
end

#descriptionObject

Description of the line item.



8256
8257
8258
# File 'lib/stripe/resources/payment_intent.rb', line 8256

def description
  @description
end

#nameObject

Descriptive name of the line item.



8258
8259
8260
# File 'lib/stripe/resources/payment_intent.rb', line 8258

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



8260
8261
8262
# File 'lib/stripe/resources/payment_intent.rb', line 8260

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



8262
8263
8264
# File 'lib/stripe/resources/payment_intent.rb', line 8262

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



8264
8265
8266
# File 'lib/stripe/resources/payment_intent.rb', line 8264

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



8266
8267
8268
# File 'lib/stripe/resources/payment_intent.rb', line 8266

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



8268
8269
8270
# File 'lib/stripe/resources/payment_intent.rb', line 8268

def unit_amount
  @unit_amount
end