Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



8057
8058
8059
8060
8061
8062
8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
# File 'lib/stripe/resources/payment_intent.rb', line 8057

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



8041
8042
8043
# File 'lib/stripe/resources/payment_intent.rb', line 8041

def category
  @category
end

#descriptionObject

Description of the line item.



8043
8044
8045
# File 'lib/stripe/resources/payment_intent.rb', line 8043

def description
  @description
end

#nameObject

Descriptive name of the line item.



8045
8046
8047
# File 'lib/stripe/resources/payment_intent.rb', line 8045

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



8047
8048
8049
# File 'lib/stripe/resources/payment_intent.rb', line 8047

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



8049
8050
8051
# File 'lib/stripe/resources/payment_intent.rb', line 8049

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



8051
8052
8053
# File 'lib/stripe/resources/payment_intent.rb', line 8051

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



8053
8054
8055
# File 'lib/stripe/resources/payment_intent.rb', line 8053

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



8055
8056
8057
# File 'lib/stripe/resources/payment_intent.rb', line 8055

def unit_amount
  @unit_amount
end