Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
8067 8068 8069 8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 8082 8083 8084 8085 |
# File 'lib/stripe/resources/payment_intent.rb', line 8067 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
8051 8052 8053 |
# File 'lib/stripe/resources/payment_intent.rb', line 8051 def category @category end |
#description ⇒ Object
Description of the line item.
8053 8054 8055 |
# File 'lib/stripe/resources/payment_intent.rb', line 8053 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
8055 8056 8057 |
# File 'lib/stripe/resources/payment_intent.rb', line 8055 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
8057 8058 8059 |
# File 'lib/stripe/resources/payment_intent.rb', line 8057 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
8059 8060 8061 |
# File 'lib/stripe/resources/payment_intent.rb', line 8059 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
8061 8062 8063 |
# File 'lib/stripe/resources/payment_intent.rb', line 8061 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
8063 8064 8065 |
# File 'lib/stripe/resources/payment_intent.rb', line 8063 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
8065 8066 8067 |
# File 'lib/stripe/resources/payment_intent.rb', line 8065 def unit_amount @unit_amount end |