Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



8012
8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
# File 'lib/stripe/resources/payment_intent.rb', line 8012

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



7996
7997
7998
# File 'lib/stripe/resources/payment_intent.rb', line 7996

def category
  @category
end

#descriptionObject

Description of the line item.



7998
7999
8000
# File 'lib/stripe/resources/payment_intent.rb', line 7998

def description
  @description
end

#nameObject

Descriptive name of the line item.



8000
8001
8002
# File 'lib/stripe/resources/payment_intent.rb', line 8000

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



8002
8003
8004
# File 'lib/stripe/resources/payment_intent.rb', line 8002

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



8004
8005
8006
# File 'lib/stripe/resources/payment_intent.rb', line 8004

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



8006
8007
8008
# File 'lib/stripe/resources/payment_intent.rb', line 8006

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



8008
8009
8010
# File 'lib/stripe/resources/payment_intent.rb', line 8008

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



8010
8011
8012
# File 'lib/stripe/resources/payment_intent.rb', line 8010

def unit_amount
  @unit_amount
end