Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



7722
7723
7724
7725
7726
7727
7728
7729
7730
7731
7732
7733
7734
7735
7736
7737
7738
7739
7740
# File 'lib/stripe/resources/payment_intent.rb', line 7722

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



7706
7707
7708
# File 'lib/stripe/resources/payment_intent.rb', line 7706

def category
  @category
end

#descriptionObject

Description of the line item.



7708
7709
7710
# File 'lib/stripe/resources/payment_intent.rb', line 7708

def description
  @description
end

#nameObject

Descriptive name of the line item.



7710
7711
7712
# File 'lib/stripe/resources/payment_intent.rb', line 7710

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



7712
7713
7714
# File 'lib/stripe/resources/payment_intent.rb', line 7712

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



7714
7715
7716
# File 'lib/stripe/resources/payment_intent.rb', line 7714

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



7716
7717
7718
# File 'lib/stripe/resources/payment_intent.rb', line 7716

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



7718
7719
7720
# File 'lib/stripe/resources/payment_intent.rb', line 7718

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



7720
7721
7722
# File 'lib/stripe/resources/payment_intent.rb', line 7720

def unit_amount
  @unit_amount
end