Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 |
# File 'lib/stripe/resources/payment_intent.rb', line 7677 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
7661 7662 7663 |
# File 'lib/stripe/resources/payment_intent.rb', line 7661 def category @category end |
#description ⇒ Object
Description of the line item.
7663 7664 7665 |
# File 'lib/stripe/resources/payment_intent.rb', line 7663 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
7665 7666 7667 |
# File 'lib/stripe/resources/payment_intent.rb', line 7665 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
7667 7668 7669 |
# File 'lib/stripe/resources/payment_intent.rb', line 7667 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
7669 7670 7671 |
# File 'lib/stripe/resources/payment_intent.rb', line 7669 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
7671 7672 7673 |
# File 'lib/stripe/resources/payment_intent.rb', line 7671 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
7673 7674 7675 |
# File 'lib/stripe/resources/payment_intent.rb', line 7673 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
7675 7676 7677 |
# File 'lib/stripe/resources/payment_intent.rb', line 7675 def unit_amount @unit_amount end |