Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



8742
8743
8744
8745
8746
8747
8748
8749
8750
8751
8752
8753
8754
8755
8756
8757
8758
8759
8760
# File 'lib/stripe/resources/payment_intent.rb', line 8742

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



8719
8720
8721
# File 'lib/stripe/resources/payment_intent.rb', line 8719

def category
  @category
end

#descriptionObject

Description of the line item.



8722
8723
8724
# File 'lib/stripe/resources/payment_intent.rb', line 8722

def description
  @description
end

#nameObject

Descriptive name of the line item.



8725
8726
8727
# File 'lib/stripe/resources/payment_intent.rb', line 8725

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



8728
8729
8730
# File 'lib/stripe/resources/payment_intent.rb', line 8728

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



8731
8732
8733
# File 'lib/stripe/resources/payment_intent.rb', line 8731

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



8734
8735
8736
# File 'lib/stripe/resources/payment_intent.rb', line 8734

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



8737
8738
8739
# File 'lib/stripe/resources/payment_intent.rb', line 8737

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



8740
8741
8742
# File 'lib/stripe/resources/payment_intent.rb', line 8740

def unit_amount
  @unit_amount
end