Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
7649 7650 7651 7652 7653 7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 |
# File 'lib/stripe/resources/payment_intent.rb', line 7649 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
7633 7634 7635 |
# File 'lib/stripe/resources/payment_intent.rb', line 7633 def category @category end |
#description ⇒ Object
Description of the line item.
7635 7636 7637 |
# File 'lib/stripe/resources/payment_intent.rb', line 7635 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
7637 7638 7639 |
# File 'lib/stripe/resources/payment_intent.rb', line 7637 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
7639 7640 7641 |
# File 'lib/stripe/resources/payment_intent.rb', line 7639 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
7641 7642 7643 |
# File 'lib/stripe/resources/payment_intent.rb', line 7641 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
7643 7644 7645 |
# File 'lib/stripe/resources/payment_intent.rb', line 7643 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
7645 7646 7647 |
# File 'lib/stripe/resources/payment_intent.rb', line 7645 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
7647 7648 7649 |
# File 'lib/stripe/resources/payment_intent.rb', line 7647 def unit_amount @unit_amount end |