Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The tax for a single unit of the line item in minor units.
-
#behavior ⇒ Object
The tax behavior for the line item.
Instance Method Summary collapse
-
#initialize(amount: nil, behavior: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, behavior: nil) ⇒ Tax
Returns a new instance of Tax.
7627 7628 7629 7630 |
# File 'lib/stripe/resources/payment_intent.rb', line 7627 def initialize(amount: nil, behavior: nil) @amount = amount @behavior = behavior end |
Instance Attribute Details
#amount ⇒ Object
The tax for a single unit of the line item in minor units. Cannot be a negative number.
7623 7624 7625 |
# File 'lib/stripe/resources/payment_intent.rb', line 7623 def amount @amount end |
#behavior ⇒ Object
The tax behavior for the line item.
7625 7626 7627 |
# File 'lib/stripe/resources/payment_intent.rb', line 7625 def behavior @behavior end |