Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



8835
8836
8837
8838
8839
8840
8841
8842
8843
8844
8845
8846
8847
8848
8849
# File 'lib/stripe/resources/payment_intent.rb', line 8835

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when ‘amount_type` is `fixed`.



8818
8819
8820
# File 'lib/stripe/resources/payment_intent.rb', line 8818

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.



8821
8822
8823
# File 'lib/stripe/resources/payment_intent.rb', line 8821

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



8824
8825
8826
# File 'lib/stripe/resources/payment_intent.rb', line 8824

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected.



8827
8828
8829
# File 'lib/stripe/resources/payment_intent.rb', line 8827

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.



8830
8831
8832
# File 'lib/stripe/resources/payment_intent.rb', line 8830

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Defaults to retail.



8833
8834
8835
# File 'lib/stripe/resources/payment_intent.rb', line 8833

def purpose
  @purpose
end