Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



7758
7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
7772
# File 'lib/stripe/resources/payment_intent.rb', line 7758

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when ‘amount_type` is `fixed`.



7746
7747
7748
# File 'lib/stripe/resources/payment_intent.rb', line 7746

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.



7748
7749
7750
# File 'lib/stripe/resources/payment_intent.rb', line 7748

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



7750
7751
7752
# File 'lib/stripe/resources/payment_intent.rb', line 7750

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected.



7752
7753
7754
# File 'lib/stripe/resources/payment_intent.rb', line 7752

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.



7754
7755
7756
# File 'lib/stripe/resources/payment_intent.rb', line 7754

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Defaults to retail.



7756
7757
7758
# File 'lib/stripe/resources/payment_intent.rb', line 7756

def purpose
  @purpose
end