Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::Pix::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



10172
10173
10174
10175
10176
10177
10178
10179
10180
10181
10182
10183
10184
10185
10186
10187
10188
10189
10190
# File 'lib/stripe/resources/payment_intent.rb', line 10172

def initialize(
  amount: nil,
  amount_includes_iof: nil,
  amount_type: nil,
  currency: nil,
  end_date: nil,
  payment_schedule: nil,
  reference: nil,
  start_date: nil
)
  @amount = amount
  @amount_includes_iof = amount_includes_iof
  @amount_type = amount_type
  @currency = currency
  @end_date = end_date
  @payment_schedule = payment_schedule
  @reference = reference
  @start_date = start_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments. Required when ‘amount_type=fixed`. If not provided for `amount_type=maximum`, defaults to 40000.



10156
10157
10158
# File 'lib/stripe/resources/payment_intent.rb', line 10156

def amount
  @amount
end

#amount_includes_iofObject

Determines if the amount includes the IOF tax. Defaults to ‘never`.



10158
10159
10160
# File 'lib/stripe/resources/payment_intent.rb', line 10158

def amount_includes_iof
  @amount_includes_iof
end

#amount_typeObject

Type of amount. Defaults to ‘maximum`.



10160
10161
10162
# File 'lib/stripe/resources/payment_intent.rb', line 10160

def amount_type
  @amount_type
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Only ‘brl` is supported currently.



10162
10163
10164
# File 'lib/stripe/resources/payment_intent.rb', line 10162

def currency
  @currency
end

#end_dateObject

Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



10164
10165
10166
# File 'lib/stripe/resources/payment_intent.rb', line 10164

def end_date
  @end_date
end

#payment_scheduleObject

Schedule at which the future payments will be charged. Defaults to ‘weekly`.



10166
10167
10168
# File 'lib/stripe/resources/payment_intent.rb', line 10166

def payment_schedule
  @payment_schedule
end

#referenceObject

Subscription name displayed to buyers in their bank app. Defaults to the displayable business name.



10168
10169
10170
# File 'lib/stripe/resources/payment_intent.rb', line 10168

def reference
  @reference
end

#start_dateObject

Start date of the mandate, in ‘YYYY-MM-DD`. Start date should be at least 3 days in the future. Defaults to 3 days after the current date.



10170
10171
10172
# File 'lib/stripe/resources/payment_intent.rb', line 10170

def start_date
  @start_date
end