Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::UsBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: FinancialConnections, MandateOptions, Networks

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(financial_connections: nil, mandate_options: nil, networks: nil, preferred_settlement_speed: nil, setup_future_usage: nil, target_date: nil, verification_method: nil) ⇒ UsBankAccount

Returns a new instance of UsBankAccount.



5756
5757
5758
5759
5760
5761
5762
5763
5764
5765
5766
5767
5768
5769
5770
5771
5772
# File 'lib/stripe/resources/payment_intent.rb', line 5756

def initialize(
  financial_connections: nil,
  mandate_options: nil,
  networks: nil,
  preferred_settlement_speed: nil,
  setup_future_usage: nil,
  target_date: nil,
  verification_method: nil
)
  @financial_connections = financial_connections
  @mandate_options = mandate_options
  @networks = networks
  @preferred_settlement_speed = preferred_settlement_speed
  @setup_future_usage = setup_future_usage
  @target_date = target_date
  @verification_method = verification_method
end

Instance Attribute Details

#financial_connectionsObject

Additional fields for Financial Connections Session creation



5734
5735
5736
# File 'lib/stripe/resources/payment_intent.rb', line 5734

def financial_connections
  @financial_connections
end

#mandate_optionsObject

Additional fields for Mandate creation



5736
5737
5738
# File 'lib/stripe/resources/payment_intent.rb', line 5736

def mandate_options
  @mandate_options
end

#networksObject

Additional fields for network related functions



5738
5739
5740
# File 'lib/stripe/resources/payment_intent.rb', line 5738

def networks
  @networks
end

#preferred_settlement_speedObject

Preferred transaction settlement speed



5740
5741
5742
# File 'lib/stripe/resources/payment_intent.rb', line 5740

def preferred_settlement_speed
  @preferred_settlement_speed
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



5750
5751
5752
# File 'lib/stripe/resources/payment_intent.rb', line 5750

def setup_future_usage
  @setup_future_usage
end

#target_dateObject

Controls when Stripe will attempt to debit the funds from the customer’s account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.



5752
5753
5754
# File 'lib/stripe/resources/payment_intent.rb', line 5752

def target_date
  @target_date
end

#verification_methodObject

Bank account verification method.



5754
5755
5756
# File 'lib/stripe/resources/payment_intent.rb', line 5754

def verification_method
  @verification_method
end