Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::UsBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: FinancialConnections, MandateOptions, Networks

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(financial_connections: nil, mandate_options: nil, networks: nil, preferred_settlement_speed: nil, setup_future_usage: nil, verification_method: nil) ⇒ UsBankAccount

Returns a new instance of UsBankAccount.



8048
8049
8050
8051
8052
8053
8054
8055
8056
8057
8058
8059
8060
8061
8062
# File 'lib/stripe/resources/payment_intent.rb', line 8048

def initialize(
  financial_connections: nil,
  mandate_options: nil,
  networks: nil,
  preferred_settlement_speed: nil,
  setup_future_usage: nil,
  verification_method: nil
)
  @financial_connections = financial_connections
  @mandate_options = mandate_options
  @networks = networks
  @preferred_settlement_speed = preferred_settlement_speed
  @setup_future_usage = setup_future_usage
  @verification_method = verification_method
end

Instance Attribute Details

#financial_connectionsObject

Additional fields for Financial Connections Session creation



8028
8029
8030
# File 'lib/stripe/resources/payment_intent.rb', line 8028

def financial_connections
  @financial_connections
end

#mandate_optionsObject

Additional fields for Mandate creation



8030
8031
8032
# File 'lib/stripe/resources/payment_intent.rb', line 8030

def mandate_options
  @mandate_options
end

#networksObject

Additional fields for network related functions



8032
8033
8034
# File 'lib/stripe/resources/payment_intent.rb', line 8032

def networks
  @networks
end

#preferred_settlement_speedObject

Preferred transaction settlement speed



8034
8035
8036
# File 'lib/stripe/resources/payment_intent.rb', line 8034

def preferred_settlement_speed
  @preferred_settlement_speed
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



8044
8045
8046
# File 'lib/stripe/resources/payment_intent.rb', line 8044

def setup_future_usage
  @setup_future_usage
end

#verification_methodObject

Bank account verification method.



8046
8047
8048
# File 'lib/stripe/resources/payment_intent.rb', line 8046

def verification_method
  @verification_method
end