Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



8958
8959
8960
8961
8962
8963
8964
8965
8966
8967
8968
8969
8970
# File 'lib/stripe/resources/payment_intent.rb', line 8958

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



8948
8949
8950
# File 'lib/stripe/resources/payment_intent.rb', line 8948

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



8950
8951
8952
# File 'lib/stripe/resources/payment_intent.rb', line 8950

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



8952
8953
8954
# File 'lib/stripe/resources/payment_intent.rb', line 8952

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



8954
8955
8956
# File 'lib/stripe/resources/payment_intent.rb', line 8954

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



8956
8957
8958
# File 'lib/stripe/resources/payment_intent.rb', line 8956

def return_url
  @return_url
end