Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



8648
8649
8650
8651
8652
8653
8654
8655
8656
8657
8658
8659
8660
# File 'lib/stripe/resources/payment_intent.rb', line 8648

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



8638
8639
8640
# File 'lib/stripe/resources/payment_intent.rb', line 8638

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



8640
8641
8642
# File 'lib/stripe/resources/payment_intent.rb', line 8640

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



8642
8643
8644
# File 'lib/stripe/resources/payment_intent.rb', line 8642

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



8644
8645
8646
# File 'lib/stripe/resources/payment_intent.rb', line 8644

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



8646
8647
8648
# File 'lib/stripe/resources/payment_intent.rb', line 8646

def return_url
  @return_url
end