Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



8433
8434
8435
8436
8437
8438
8439
8440
8441
8442
8443
8444
8445
# File 'lib/stripe/resources/payment_intent.rb', line 8433

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



8423
8424
8425
# File 'lib/stripe/resources/payment_intent.rb', line 8423

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



8425
8426
8427
# File 'lib/stripe/resources/payment_intent.rb', line 8425

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



8427
8428
8429
# File 'lib/stripe/resources/payment_intent.rb', line 8427

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



8429
8430
8431
# File 'lib/stripe/resources/payment_intent.rb', line 8429

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



8431
8432
8433
# File 'lib/stripe/resources/payment_intent.rb', line 8431

def return_url
  @return_url
end