Class: Stripe::PaymentIntent::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
# File 'lib/stripe/resources/payment_intent.rb', line 8023

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method



8013
8014
8015
# File 'lib/stripe/resources/payment_intent.rb', line 8013

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



8015
8016
8017
# File 'lib/stripe/resources/payment_intent.rb', line 8015

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



8017
8018
8019
# File 'lib/stripe/resources/payment_intent.rb', line 8017

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



8019
8020
8021
# File 'lib/stripe/resources/payment_intent.rb', line 8019

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



8021
8022
8023
# File 'lib/stripe/resources/payment_intent.rb', line 8021

def return_url
  @return_url
end