Class: Stripe::PaymentIntent::UpdateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



6266
6267
6268
6269
6270
6271
6272
# File 'lib/stripe/resources/payment_intent.rb', line 6266

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



6256
6257
6258
# File 'lib/stripe/resources/payment_intent.rb', line 6256

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



6258
6259
6260
# File 'lib/stripe/resources/payment_intent.rb', line 6258

def carrier
  @carrier
end

#nameObject

Recipient name.



6260
6261
6262
# File 'lib/stripe/resources/payment_intent.rb', line 6260

def name
  @name
end

#phoneObject

Recipient phone (including extension).



6262
6263
6264
# File 'lib/stripe/resources/payment_intent.rb', line 6262

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



6264
6265
6266
# File 'lib/stripe/resources/payment_intent.rb', line 6264

def tracking_number
  @tracking_number
end