Class: Stripe::PaymentIntent::UpdateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::Shipping
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
9351 9352 9353 9354 9355 9356 9357 |
# File 'lib/stripe/resources/payment_intent.rb', line 9351 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
9341 9342 9343 |
# File 'lib/stripe/resources/payment_intent.rb', line 9341 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
9343 9344 9345 |
# File 'lib/stripe/resources/payment_intent.rb', line 9343 def carrier @carrier end |
#name ⇒ Object
Recipient name.
9345 9346 9347 |
# File 'lib/stripe/resources/payment_intent.rb', line 9345 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
9347 9348 9349 |
# File 'lib/stripe/resources/payment_intent.rb', line 9347 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
9349 9350 9351 |
# File 'lib/stripe/resources/payment_intent.rb', line 9349 def tracking_number @tracking_number end |