Class: Stripe::PaymentIntent::UpdateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::Shipping
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
6244 6245 6246 6247 6248 6249 6250 |
# File 'lib/stripe/resources/payment_intent.rb', line 6244 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
6234 6235 6236 |
# File 'lib/stripe/resources/payment_intent.rb', line 6234 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
6236 6237 6238 |
# File 'lib/stripe/resources/payment_intent.rb', line 6236 def carrier @carrier end |
#name ⇒ Object
Recipient name.
6238 6239 6240 |
# File 'lib/stripe/resources/payment_intent.rb', line 6238 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
6240 6241 6242 |
# File 'lib/stripe/resources/payment_intent.rb', line 6240 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
6242 6243 6244 |
# File 'lib/stripe/resources/payment_intent.rb', line 6242 def tracking_number @tracking_number end |