Class: Stripe::PaymentIntent::UpdateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



9041
9042
9043
9044
9045
9046
9047
# File 'lib/stripe/resources/payment_intent.rb', line 9041

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



9031
9032
9033
# File 'lib/stripe/resources/payment_intent.rb', line 9031

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



9033
9034
9035
# File 'lib/stripe/resources/payment_intent.rb', line 9033

def carrier
  @carrier
end

#nameObject

Recipient name.



9035
9036
9037
# File 'lib/stripe/resources/payment_intent.rb', line 9035

def name
  @name
end

#phoneObject

Recipient phone (including extension).



9037
9038
9039
# File 'lib/stripe/resources/payment_intent.rb', line 9037

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



9039
9040
9041
# File 'lib/stripe/resources/payment_intent.rb', line 9039

def tracking_number
  @tracking_number
end