Class: Stripe::PaymentIntent::UpdateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::Shipping
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
6027 6028 6029 6030 6031 6032 6033 |
# File 'lib/stripe/resources/payment_intent.rb', line 6027 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
6017 6018 6019 |
# File 'lib/stripe/resources/payment_intent.rb', line 6017 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
6019 6020 6021 |
# File 'lib/stripe/resources/payment_intent.rb', line 6019 def carrier @carrier end |
#name ⇒ Object
Recipient name.
6021 6022 6023 |
# File 'lib/stripe/resources/payment_intent.rb', line 6021 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
6023 6024 6025 |
# File 'lib/stripe/resources/payment_intent.rb', line 6023 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
6025 6026 6027 |
# File 'lib/stripe/resources/payment_intent.rb', line 6025 def tracking_number @tracking_number end |