Class: Stripe::PaymentIntent::UpdateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



8818
8819
8820
8821
8822
8823
8824
# File 'lib/stripe/resources/payment_intent.rb', line 8818

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



8808
8809
8810
# File 'lib/stripe/resources/payment_intent.rb', line 8808

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



8810
8811
8812
# File 'lib/stripe/resources/payment_intent.rb', line 8810

def carrier
  @carrier
end

#nameObject

Recipient name.



8812
8813
8814
# File 'lib/stripe/resources/payment_intent.rb', line 8812

def name
  @name
end

#phoneObject

Recipient phone (including extension).



8814
8815
8816
# File 'lib/stripe/resources/payment_intent.rb', line 8814

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



8816
8817
8818
# File 'lib/stripe/resources/payment_intent.rb', line 8816

def tracking_number
  @tracking_number
end