Class: Stripe::PaymentIntent::UpdateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



6094
6095
6096
6097
6098
6099
6100
# File 'lib/stripe/resources/payment_intent.rb', line 6094

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



6084
6085
6086
# File 'lib/stripe/resources/payment_intent.rb', line 6084

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



6086
6087
6088
# File 'lib/stripe/resources/payment_intent.rb', line 6086

def carrier
  @carrier
end

#nameObject

Recipient name.



6088
6089
6090
# File 'lib/stripe/resources/payment_intent.rb', line 6088

def name
  @name
end

#phoneObject

Recipient phone (including extension).



6090
6091
6092
# File 'lib/stripe/resources/payment_intent.rb', line 6090

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



6092
6093
6094
# File 'lib/stripe/resources/payment_intent.rb', line 6092

def tracking_number
  @tracking_number
end