Class: Stripe::PaymentIntent::UpdateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::Shipping
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
8763 8764 8765 8766 8767 8768 8769 |
# File 'lib/stripe/resources/payment_intent.rb', line 8763 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
8753 8754 8755 |
# File 'lib/stripe/resources/payment_intent.rb', line 8753 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
8755 8756 8757 |
# File 'lib/stripe/resources/payment_intent.rb', line 8755 def carrier @carrier end |
#name ⇒ Object
Recipient name.
8757 8758 8759 |
# File 'lib/stripe/resources/payment_intent.rb', line 8757 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
8759 8760 8761 |
# File 'lib/stripe/resources/payment_intent.rb', line 8759 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
8761 8762 8763 |
# File 'lib/stripe/resources/payment_intent.rb', line 8761 def tracking_number @tracking_number end |