Class: Stripe::PaymentIntent::UpdateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



9544
9545
9546
9547
9548
9549
9550
# File 'lib/stripe/resources/payment_intent.rb', line 9544

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



9530
9531
9532
# File 'lib/stripe/resources/payment_intent.rb', line 9530

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



9533
9534
9535
# File 'lib/stripe/resources/payment_intent.rb', line 9533

def carrier
  @carrier
end

#nameObject

Recipient name.



9536
9537
9538
# File 'lib/stripe/resources/payment_intent.rb', line 9536

def name
  @name
end

#phoneObject

Recipient phone (including extension).



9539
9540
9541
# File 'lib/stripe/resources/payment_intent.rb', line 9539

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



9542
9543
9544
# File 'lib/stripe/resources/payment_intent.rb', line 9542

def tracking_number
  @tracking_number
end