Class: Stripe::PaymentIntent::UpdateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



8360
8361
8362
8363
8364
8365
8366
# File 'lib/stripe/resources/payment_intent.rb', line 8360

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



8350
8351
8352
# File 'lib/stripe/resources/payment_intent.rb', line 8350

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



8352
8353
8354
# File 'lib/stripe/resources/payment_intent.rb', line 8352

def carrier
  @carrier
end

#nameObject

Recipient name.



8354
8355
8356
# File 'lib/stripe/resources/payment_intent.rb', line 8354

def name
  @name
end

#phoneObject

Recipient phone (including extension).



8356
8357
8358
# File 'lib/stripe/resources/payment_intent.rb', line 8356

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



8358
8359
8360
# File 'lib/stripe/resources/payment_intent.rb', line 8358

def tracking_number
  @tracking_number
end