Class: Stripe::PaymentIntent::UpdateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::UpdateParams::Shipping
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
8392 8393 8394 8395 8396 8397 8398 |
# File 'lib/stripe/resources/payment_intent.rb', line 8392 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
8382 8383 8384 |
# File 'lib/stripe/resources/payment_intent.rb', line 8382 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
8384 8385 8386 |
# File 'lib/stripe/resources/payment_intent.rb', line 8384 def carrier @carrier end |
#name ⇒ Object
Recipient name.
8386 8387 8388 |
# File 'lib/stripe/resources/payment_intent.rb', line 8386 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
8388 8389 8390 |
# File 'lib/stripe/resources/payment_intent.rb', line 8388 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
8390 8391 8392 |
# File 'lib/stripe/resources/payment_intent.rb', line 8390 def tracking_number @tracking_number end |