Class: Stripe::PaymentIntent::VerifyMicrodepositsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams

Returns a new instance of VerifyMicrodepositsParams.



14501
14502
14503
14504
14505
# File 'lib/stripe/resources/payment_intent.rb', line 14501

def initialize(amounts: nil, descriptor_code: nil, expand: nil)
  @amounts = amounts
  @descriptor_code = descriptor_code
  @expand = expand
end

Instance Attribute Details

#amountsObject

Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.



14495
14496
14497
# File 'lib/stripe/resources/payment_intent.rb', line 14495

def amounts
  @amounts
end

#descriptor_codeObject

A six-character code starting with SM present in the microdeposit sent to the bank account.



14497
14498
14499
# File 'lib/stripe/resources/payment_intent.rb', line 14497

def descriptor_code
  @descriptor_code
end

#expandObject

Specifies which fields in the response should be expanded.



14499
14500
14501
# File 'lib/stripe/resources/payment_intent.rb', line 14499

def expand
  @expand
end