Class: Stripe::PaymentIntent::VerifyMicrodepositsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams

Returns a new instance of VerifyMicrodepositsParams.



13381
13382
13383
13384
13385
# File 'lib/stripe/resources/payment_intent.rb', line 13381

def initialize(amounts: nil, descriptor_code: nil, expand: nil)
  @amounts = amounts
  @descriptor_code = descriptor_code
  @expand = expand
end

Instance Attribute Details

#amountsObject

Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.



13375
13376
13377
# File 'lib/stripe/resources/payment_intent.rb', line 13375

def amounts
  @amounts
end

#descriptor_codeObject

A six-character code starting with SM present in the microdeposit sent to the bank account.



13377
13378
13379
# File 'lib/stripe/resources/payment_intent.rb', line 13377

def descriptor_code
  @descriptor_code
end

#expandObject

Specifies which fields in the response should be expanded.



13379
13380
13381
# File 'lib/stripe/resources/payment_intent.rb', line 13379

def expand
  @expand
end