Class: Stripe::PaymentIntent::VerifyMicrodepositsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams

Returns a new instance of VerifyMicrodepositsParams.



8532
8533
8534
8535
8536
# File 'lib/stripe/resources/payment_intent.rb', line 8532

def initialize(amounts: nil, descriptor_code: nil, expand: nil)
  @amounts = amounts
  @descriptor_code = descriptor_code
  @expand = expand
end

Instance Attribute Details

#amountsObject

Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.



8526
8527
8528
# File 'lib/stripe/resources/payment_intent.rb', line 8526

def amounts
  @amounts
end

#descriptor_codeObject

A six-character code starting with SM present in the microdeposit sent to the bank account.



8528
8529
8530
# File 'lib/stripe/resources/payment_intent.rb', line 8528

def descriptor_code
  @descriptor_code
end

#expandObject

Specifies which fields in the response should be expanded.



8530
8531
8532
# File 'lib/stripe/resources/payment_intent.rb', line 8530

def expand
  @expand
end