Class: Stripe::PaymentIntent::VerifyMicrodepositsParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::VerifyMicrodepositsParams
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#amounts ⇒ Object
Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.
-
#descriptor_code ⇒ Object
A six-character code starting with SM present in the microdeposit sent to the bank account.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams
constructor
A new instance of VerifyMicrodepositsParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams
Returns a new instance of VerifyMicrodepositsParams.
8574 8575 8576 8577 8578 |
# File 'lib/stripe/resources/payment_intent.rb', line 8574 def initialize(amounts: nil, descriptor_code: nil, expand: nil) @amounts = amounts @descriptor_code = descriptor_code @expand = end |
Instance Attribute Details
#amounts ⇒ Object
Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.
8568 8569 8570 |
# File 'lib/stripe/resources/payment_intent.rb', line 8568 def amounts @amounts end |
#descriptor_code ⇒ Object
A six-character code starting with SM present in the microdeposit sent to the bank account.
8570 8571 8572 |
# File 'lib/stripe/resources/payment_intent.rb', line 8570 def descriptor_code @descriptor_code end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
8572 8573 8574 |
# File 'lib/stripe/resources/payment_intent.rb', line 8572 def @expand end |