Class: Stripe::PaymentIntent::VerifyMicrodepositsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams

Returns a new instance of VerifyMicrodepositsParams.



12808
12809
12810
12811
12812
# File 'lib/stripe/resources/payment_intent.rb', line 12808

def initialize(amounts: nil, descriptor_code: nil, expand: nil)
  @amounts = amounts
  @descriptor_code = descriptor_code
  @expand = expand
end

Instance Attribute Details

#amountsObject

Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.



12802
12803
12804
# File 'lib/stripe/resources/payment_intent.rb', line 12802

def amounts
  @amounts
end

#descriptor_codeObject

A six-character code starting with SM present in the microdeposit sent to the bank account.



12804
12805
12806
# File 'lib/stripe/resources/payment_intent.rb', line 12804

def descriptor_code
  @descriptor_code
end

#expandObject

Specifies which fields in the response should be expanded.



12806
12807
12808
# File 'lib/stripe/resources/payment_intent.rb', line 12806

def expand
  @expand
end