Class: Stripe::PaymentIntent::VerifyMicrodepositsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams

Returns a new instance of VerifyMicrodepositsParams.



14411
14412
14413
14414
14415
# File 'lib/stripe/resources/payment_intent.rb', line 14411

def initialize(amounts: nil, descriptor_code: nil, expand: nil)
  @amounts = amounts
  @descriptor_code = descriptor_code
  @expand = expand
end

Instance Attribute Details

#amountsObject

Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.



14403
14404
14405
# File 'lib/stripe/resources/payment_intent.rb', line 14403

def amounts
  @amounts
end

#descriptor_codeObject

A six-character code starting with SM present in the microdeposit sent to the bank account.



14406
14407
14408
# File 'lib/stripe/resources/payment_intent.rb', line 14406

def descriptor_code
  @descriptor_code
end

#expandObject

Specifies which fields in the response should be expanded.



14409
14410
14411
# File 'lib/stripe/resources/payment_intent.rb', line 14409

def expand
  @expand
end