Class: Stripe::PaymentIntentAmountDetailsLineItem
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::PaymentIntentAmountDetailsLineItem
- Defined in:
- lib/stripe/resources/payment_intent_amount_details_line_item.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Constant Summary collapse
- OBJECT_NAME =
"payment_intent_amount_details_line_item"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
readonly
The discount applied on this line item represented in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal).
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#payment_method_options ⇒ Object
readonly
Payment method-specific information for line items.
-
#product_code ⇒ Object
readonly
The product code of the line item, such as an SKU.
-
#product_name ⇒ Object
readonly
The product name of the line item.
-
#quantity ⇒ Object
readonly
The quantity of items.
-
#quantity_precision ⇒ Object
readonly
The number of decimal places implied in the quantity.
-
#tax ⇒ Object
readonly
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
readonly
The unit cost of the line item represented in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal).
-
#unit_of_measure ⇒ Object
readonly
A unit of measure for the line item, such as gallons, feet, meters, etc.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#discount_amount ⇒ Object (readonly)
The discount applied on this line item represented in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal). An integer greater than 0.
This field is mutually exclusive with the ‘amount_details` field.
124 125 126 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 124 def discount_amount @discount_amount end |
#id ⇒ Object (readonly)
Unique identifier for the object.
126 127 128 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 126 def id @id end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
128 129 130 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 128 def object @object end |
#payment_method_options ⇒ Object (readonly)
Payment method-specific information for line items.
130 131 132 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 130 def @payment_method_options end |
#product_code ⇒ Object (readonly)
The product code of the line item, such as an SKU. Required for L3 rates. At most 12 characters long.
132 133 134 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 132 def product_code @product_code end |
#product_name ⇒ Object (readonly)
The product name of the line item. Required for L3 rates. At most 1024 characters long.
For Cards, this field is truncated to 26 alphanumeric characters before being sent to the card networks. For PayPal, this field is truncated to 127 characters.
136 137 138 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 136 def product_name @product_name end |
#quantity ⇒ Object (readonly)
The quantity of items. Required for L3 rates. An integer greater than 0.
138 139 140 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 138 def quantity @quantity end |
#quantity_precision ⇒ Object (readonly)
The number of decimal places implied in the quantity. For example, if quantity is 10000 and quantity_precision is 2, the actual quantity is 100.00. Defaults to 0 if not provided.
140 141 142 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 140 def quantity_precision @quantity_precision end |
#tax ⇒ Object (readonly)
Contains information about the tax on the item.
142 143 144 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 142 def tax @tax end |
#unit_cost ⇒ Object (readonly)
The unit cost of the line item represented in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal). Required for L3 rates. An integer greater than or equal to 0.
144 145 146 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 144 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object (readonly)
A unit of measure for the line item, such as gallons, feet, meters, etc. Required for L3 rates. At most 12 alphanumeric characters long.
146 147 148 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 146 def unit_of_measure @unit_of_measure end |
Class Method Details
.field_remappings ⇒ Object
152 153 154 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 152 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
148 149 150 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 148 def self.inner_class_types @inner_class_types = { payment_method_options: PaymentMethodOptions, tax: Tax } end |
.object_name ⇒ Object
7 8 9 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 7 def self.object_name "payment_intent_amount_details_line_item" end |