Class: Stripe::PaymentIntentAmountDetailsLineItem

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/payment_intent_amount_details_line_item.rb

Defined Under Namespace

Classes: PaymentMethodOptions, Tax

Constant Summary collapse

OBJECT_NAME =
"payment_intent_amount_details_line_item"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#discount_amountObject (readonly)

The discount applied on this line item represented in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal). An integer greater than 0.

This field is mutually exclusive with the ‘amount_details` field.



124
125
126
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 124

def discount_amount
  @discount_amount
end

#idObject (readonly)

Unique identifier for the object.



126
127
128
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 126

def id
  @id
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



128
129
130
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 128

def object
  @object
end

#payment_method_optionsObject (readonly)

Payment method-specific information for line items.



130
131
132
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 130

def payment_method_options
  @payment_method_options
end

#product_codeObject (readonly)

The product code of the line item, such as an SKU. Required for L3 rates. At most 12 characters long.



132
133
134
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 132

def product_code
  @product_code
end

#product_nameObject (readonly)

The product name of the line item. Required for L3 rates. At most 1024 characters long.

For Cards, this field is truncated to 26 alphanumeric characters before being sent to the card networks. For PayPal, this field is truncated to 127 characters.



136
137
138
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 136

def product_name
  @product_name
end

#quantityObject (readonly)

The quantity of items. Required for L3 rates. An integer greater than 0.



138
139
140
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 138

def quantity
  @quantity
end

#quantity_precisionObject (readonly)

The number of decimal places implied in the quantity. For example, if quantity is 10000 and quantity_precision is 2, the actual quantity is 100.00. Defaults to 0 if not provided.



146
147
148
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 146

def quantity_precision
  @quantity_precision
end

#taxObject (readonly)

Contains information about the tax on the item.



140
141
142
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 140

def tax
  @tax
end

#unit_costObject (readonly)

The unit cost of the line item represented in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal). Required for L3 rates. An integer greater than or equal to 0.



142
143
144
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 142

def unit_cost
  @unit_cost
end

#unit_of_measureObject (readonly)

A unit of measure for the line item, such as gallons, feet, meters, etc. Required for L3 rates. At most 12 alphanumeric characters long.



144
145
146
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 144

def unit_of_measure
  @unit_of_measure
end

Class Method Details

.field_remappingsObject



152
153
154
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 152

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



148
149
150
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 148

def self.inner_class_types
  @inner_class_types = { payment_method_options: PaymentMethodOptions, tax: Tax }
end

.object_nameObject



7
8
9
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 7

def self.object_name
  "payment_intent_amount_details_line_item"
end