Class: Stripe::PaymentIntentAmountDetailsLineItem
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::PaymentIntentAmountDetailsLineItem
- Defined in:
- lib/stripe/resources/payment_intent_amount_details_line_item.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Constant Summary collapse
- OBJECT_NAME =
"payment_intent_amount_details_line_item"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
readonly
The amount an item was discounted for.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#payment_method_options ⇒ Object
readonly
Payment method-specific information for line items.
-
#product_code ⇒ Object
readonly
Unique identifier of the product.
-
#product_name ⇒ Object
readonly
Name of the product.
-
#quantity ⇒ Object
readonly
Number of items of the product.
-
#tax ⇒ Object
readonly
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
readonly
Cost of the product.
-
#unit_of_measure ⇒ Object
readonly
A unit of measure for the line item, such as gallons, feet, meters, etc.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#discount_amount ⇒ Object (readonly)
The amount an item was discounted for. Positive integer.
104 105 106 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 104 def discount_amount @discount_amount end |
#id ⇒ Object (readonly)
Unique identifier for the object.
106 107 108 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 106 def id @id end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
108 109 110 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 108 def object @object end |
#payment_method_options ⇒ Object (readonly)
Payment method-specific information for line items.
110 111 112 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 110 def @payment_method_options end |
#product_code ⇒ Object (readonly)
Unique identifier of the product. At most 12 characters long.
112 113 114 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 112 def product_code @product_code end |
#product_name ⇒ Object (readonly)
Name of the product. At most 100 characters long.
114 115 116 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 114 def product_name @product_name end |
#quantity ⇒ Object (readonly)
Number of items of the product. Positive integer.
116 117 118 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 116 def quantity @quantity end |
#tax ⇒ Object (readonly)
Contains information about the tax on the item.
118 119 120 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 118 def tax @tax end |
#unit_cost ⇒ Object (readonly)
Cost of the product. Non-negative integer.
120 121 122 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 120 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object (readonly)
A unit of measure for the line item, such as gallons, feet, meters, etc.
122 123 124 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 122 def unit_of_measure @unit_of_measure end |
Class Method Details
.field_remappings ⇒ Object
128 129 130 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 128 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
124 125 126 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 124 def self.inner_class_types @inner_class_types = { payment_method_options: PaymentMethodOptions, tax: Tax } end |
.object_name ⇒ Object
7 8 9 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 7 def self.object_name "payment_intent_amount_details_line_item" end |