Class: Stripe::PaymentIntentAmountDetailsLineItem

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/payment_intent_amount_details_line_item.rb

Defined Under Namespace

Classes: PaymentMethodOptions, Tax

Constant Summary collapse

OBJECT_NAME =
"payment_intent_amount_details_line_item"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#discount_amountObject (readonly)

The amount an item was discounted for. Positive integer.



45
46
47
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 45

def discount_amount
  @discount_amount
end

#idObject (readonly)

Unique identifier for the object.



47
48
49
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 47

def id
  @id
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



49
50
51
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 49

def object
  @object
end

#payment_method_optionsObject (readonly)

Payment method-specific information for line items.



51
52
53
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 51

def payment_method_options
  @payment_method_options
end

#product_codeObject (readonly)

Unique identifier of the product. At most 12 characters long.



53
54
55
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 53

def product_code
  @product_code
end

#product_nameObject (readonly)

Name of the product. At most 100 characters long.



55
56
57
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 55

def product_name
  @product_name
end

#quantityObject (readonly)

Number of items of the product. Positive integer.



57
58
59
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 57

def quantity
  @quantity
end

#taxObject (readonly)

Contains information about the tax on the item.



59
60
61
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 59

def tax
  @tax
end

#unit_costObject (readonly)

Cost of the product. Non-negative integer.



61
62
63
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 61

def unit_cost
  @unit_cost
end

#unit_of_measureObject (readonly)

A unit of measure for the line item, such as gallons, feet, meters, etc.



63
64
65
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 63

def unit_of_measure
  @unit_of_measure
end

Class Method Details

.object_nameObject



7
8
9
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 7

def self.object_name
  "payment_intent_amount_details_line_item"
end