Class: Stripe::PaymentIntentAmountDetailsLineItem::PaymentMethodOptions::Card::EvCharging
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntentAmountDetailsLineItem::PaymentMethodOptions::Card::EvCharging
- Defined in:
- lib/stripe/resources/payment_intent_amount_details_line_item.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#carbon_footprint_avoided_grams_co2 ⇒ Object
readonly
The carbon footprint avoided by the charging session, in grams of CO2.
-
#charging_ended_at ⇒ Object
readonly
The time the charging session ended, measured in seconds since the Unix epoch.
-
#charging_power_output_capacity_kw ⇒ Object
readonly
The power output capacity of the charging station, in kilowatts (kW).
-
#charging_started_at ⇒ Object
readonly
The time the charging session started, measured in seconds since the Unix epoch.
-
#connector_type ⇒ Object
readonly
The type of connector used for the charging session.
-
#estimated_range_added ⇒ Object
readonly
The estimated distance in kilometers or miles added to the vehicle during the charging session.
-
#estimated_range_left ⇒ Object
readonly
The estimated distance in kilometers or miles remaining in the vehicle after the charging session.
-
#maximum_power_dispensed_kw ⇒ Object
readonly
The maximum power dispensed during the charging session, in kilowatts (kW).
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#carbon_footprint_avoided_grams_co2 ⇒ Object (readonly)
The carbon footprint avoided by the charging session, in grams of CO2.
15 16 17 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 15 def carbon_footprint_avoided_grams_co2 @carbon_footprint_avoided_grams_co2 end |
#charging_ended_at ⇒ Object (readonly)
The time the charging session ended, measured in seconds since the Unix epoch.
17 18 19 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 17 def charging_ended_at @charging_ended_at end |
#charging_power_output_capacity_kw ⇒ Object (readonly)
The power output capacity of the charging station, in kilowatts (kW).
19 20 21 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 19 def charging_power_output_capacity_kw @charging_power_output_capacity_kw end |
#charging_started_at ⇒ Object (readonly)
The time the charging session started, measured in seconds since the Unix epoch.
21 22 23 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 21 def charging_started_at @charging_started_at end |
#connector_type ⇒ Object (readonly)
The type of connector used for the charging session.
23 24 25 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 23 def connector_type @connector_type end |
#estimated_range_added ⇒ Object (readonly)
The estimated distance in kilometers or miles added to the vehicle during the charging session.
25 26 27 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 25 def estimated_range_added @estimated_range_added end |
#estimated_range_left ⇒ Object (readonly)
The estimated distance in kilometers or miles remaining in the vehicle after the charging session.
27 28 29 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 27 def estimated_range_left @estimated_range_left end |
#maximum_power_dispensed_kw ⇒ Object (readonly)
The maximum power dispensed during the charging session, in kilowatts (kW).
29 30 31 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 29 def maximum_power_dispensed_kw @maximum_power_dispensed_kw end |
Class Method Details
.field_remappings ⇒ Object
35 36 37 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 35 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
31 32 33 |
# File 'lib/stripe/resources/payment_intent_amount_details_line_item.rb', line 31 def self.inner_class_types @inner_class_types = {} end |