Class: Stripe::PaymentIntentCaptureParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Defined Under Namespace
Classes: AmountDetails, Hooks, PaymentDetails, TransferData
Instance Attribute Summary collapse
-
#amount_details ⇒ Object
Provides industry-specific information about the amount.
-
#amount_to_capture ⇒ Object
The amount to capture from the PaymentIntent, which must be less than or equal to the original amount.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#final_capture ⇒ Object
Defaults to ‘true`.
-
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#payment_details ⇒ Object
Provides industry-specific information about the charge.
-
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card charge.
-
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge.
-
#transfer_data ⇒ Object
The parameters that you can use to automatically create a transfer after the payment is captured.
Instance Method Summary collapse
-
#initialize(amount_details: nil, amount_to_capture: nil, application_fee_amount: nil, expand: nil, final_capture: nil, hooks: nil, metadata: nil, payment_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ PaymentIntentCaptureParams
constructor
A new instance of PaymentIntentCaptureParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount_details: nil, amount_to_capture: nil, application_fee_amount: nil, expand: nil, final_capture: nil, hooks: nil, metadata: nil, payment_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ PaymentIntentCaptureParams
Returns a new instance of PaymentIntentCaptureParams.
1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1924 def initialize( amount_details: nil, amount_to_capture: nil, application_fee_amount: nil, expand: nil, final_capture: nil, hooks: nil, metadata: nil, payment_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil ) @amount_details = amount_details @amount_to_capture = amount_to_capture @application_fee_amount = application_fee_amount @expand = @final_capture = final_capture @hooks = hooks @metadata = @payment_details = payment_details @statement_descriptor = statement_descriptor @statement_descriptor_suffix = statement_descriptor_suffix @transfer_data = transfer_data end |
Instance Attribute Details
#amount_details ⇒ Object
Provides industry-specific information about the amount.
1899 1900 1901 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1899 def amount_details @amount_details end |
#amount_to_capture ⇒ Object
The amount to capture from the PaymentIntent, which must be less than or equal to the original amount. Defaults to the full ‘amount_capturable` if it’s not provided.
1901 1902 1903 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1901 def amount_to_capture @amount_to_capture end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](docs.stripe.com/payments/connected-accounts).
1903 1904 1905 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1903 def application_fee_amount @application_fee_amount end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1905 1906 1907 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1905 def @expand end |
#final_capture ⇒ Object
Defaults to ‘true`. When capturing a PaymentIntent, setting `final_capture` to `false` notifies Stripe to not release the remaining uncaptured funds to make sure that they’re captured in future requests. You can only use this setting when [multicapture](docs.stripe.com/payments/multicapture) is available for PaymentIntents.
1907 1908 1909 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1907 def final_capture @final_capture end |
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle
1909 1910 1911 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1909 def hooks @hooks end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1911 1912 1913 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1911 def @metadata end |
#payment_details ⇒ Object
Provides industry-specific information about the charge.
1913 1914 1915 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1913 def payment_details @payment_details end |
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.
1917 1918 1919 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1917 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.
1919 1920 1921 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1919 def statement_descriptor_suffix @statement_descriptor_suffix end |
#transfer_data ⇒ Object
The parameters that you can use to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](docs.stripe.com/payments/connected-accounts).
1922 1923 1924 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1922 def transfer_data @transfer_data end |