Class: Stripe::PaymentIntentCaptureParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/payment_intent_capture_params.rb

Defined Under Namespace

Classes: AmountDetails, Hooks, PaymentDetails, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_details: nil, amount_to_capture: nil, application_fee_amount: nil, expand: nil, final_capture: nil, hooks: nil, metadata: nil, payment_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ PaymentIntentCaptureParams

Returns a new instance of PaymentIntentCaptureParams.



1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1893

def initialize(
  amount_details: nil,
  amount_to_capture: nil,
  application_fee_amount: nil,
  expand: nil,
  final_capture: nil,
  hooks: nil,
  metadata: nil,
  payment_details: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil
)
  @amount_details = amount_details
  @amount_to_capture = amount_to_capture
  @application_fee_amount = application_fee_amount
  @expand = expand
  @final_capture = final_capture
  @hooks = hooks
  @metadata = 
  @payment_details = payment_details
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
end

Instance Attribute Details

#amount_detailsObject

Provides industry-specific information about the amount.



1868
1869
1870
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1868

def amount_details
  @amount_details
end

#amount_to_captureObject

The amount to capture from the PaymentIntent, which must be less than or equal to the original amount. Defaults to the full ‘amount_capturable` if it’s not provided.



1870
1871
1872
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1870

def amount_to_capture
  @amount_to_capture
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](docs.stripe.com/payments/connected-accounts).



1872
1873
1874
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1872

def application_fee_amount
  @application_fee_amount
end

#expandObject

Specifies which fields in the response should be expanded.



1874
1875
1876
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1874

def expand
  @expand
end

#final_captureObject

Defaults to ‘true`. When capturing a PaymentIntent, setting `final_capture` to `false` notifies Stripe to not release the remaining uncaptured funds to make sure that they’re captured in future requests. You can only use this setting when [multicapture](docs.stripe.com/payments/multicapture) is available for PaymentIntents.



1876
1877
1878
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1876

def final_capture
  @final_capture
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



1878
1879
1880
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1878

def hooks
  @hooks
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1880
1881
1882
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1880

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



1882
1883
1884
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1882

def payment_details
  @payment_details
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).

Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.



1886
1887
1888
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1886

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



1888
1889
1890
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1888

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

The parameters that you can use to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](docs.stripe.com/payments/connected-accounts).



1891
1892
1893
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1891

def transfer_data
  @transfer_data
end