Class: Stripe::PaymentIntentCaptureParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/payment_intent_capture_params.rb

Defined Under Namespace

Classes: AmountDetails, Hooks, PaymentDetails, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_details: nil, amount_to_capture: nil, application_fee_amount: nil, expand: nil, final_capture: nil, hooks: nil, metadata: nil, payment_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ PaymentIntentCaptureParams

Returns a new instance of PaymentIntentCaptureParams.



931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 931

def initialize(
  amount_details: nil,
  amount_to_capture: nil,
  application_fee_amount: nil,
  expand: nil,
  final_capture: nil,
  hooks: nil,
  metadata: nil,
  payment_details: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil
)
  @amount_details = amount_details
  @amount_to_capture = amount_to_capture
  @application_fee_amount = application_fee_amount
  @expand = expand
  @final_capture = final_capture
  @hooks = hooks
  @metadata = 
  @payment_details = payment_details
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
end

Instance Attribute Details

#amount_detailsObject

Provides industry-specific information about the amount.



906
907
908
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 906

def amount_details
  @amount_details
end

#amount_to_captureObject

The amount to capture from the PaymentIntent, which must be less than or equal to the original amount. Defaults to the full ‘amount_capturable` if it’s not provided.



908
909
910
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 908

def amount_to_capture
  @amount_to_capture
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



910
911
912
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 910

def application_fee_amount
  @application_fee_amount
end

#expandObject

Specifies which fields in the response should be expanded.



912
913
914
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 912

def expand
  @expand
end

#final_captureObject

Defaults to ‘true`. When capturing a PaymentIntent, setting `final_capture` to `false` notifies Stripe to not release the remaining uncaptured funds to make sure that they’re captured in future requests. You can only use this setting when [multicapture](stripe.com/docs/payments/multicapture) is available for PaymentIntents.



914
915
916
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 914

def final_capture
  @final_capture
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



916
917
918
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 916

def hooks
  @hooks
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



918
919
920
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 918

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



920
921
922
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 920

def payment_details
  @payment_details
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).

Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.



924
925
926
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 924

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



926
927
928
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 926

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

The parameters that you can use to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



929
930
931
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 929

def transfer_data
  @transfer_data
end