Class: Stripe::PaymentIntentCaptureParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Defined Under Namespace
Classes: AmountDetails, PaymentDetails, TransferData
Instance Attribute Summary collapse
-
#amount_details ⇒ Object
Provides industry-specific information about the amount.
-
#amount_to_capture ⇒ Object
The amount to capture from the PaymentIntent, which must be less than or equal to the original amount.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#final_capture ⇒ Object
Defaults to ‘true`.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment_details ⇒ Object
Provides industry-specific information about the charge.
-
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card charge.
-
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge.
-
#transfer_data ⇒ Object
The parameters that you can use to automatically create a transfer after the payment is captured.
Instance Method Summary collapse
-
#initialize(amount_details: nil, amount_to_capture: nil, application_fee_amount: nil, expand: nil, final_capture: nil, metadata: nil, payment_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ PaymentIntentCaptureParams
constructor
A new instance of PaymentIntentCaptureParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_details: nil, amount_to_capture: nil, application_fee_amount: nil, expand: nil, final_capture: nil, metadata: nil, payment_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ PaymentIntentCaptureParams
Returns a new instance of PaymentIntentCaptureParams.
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 227 def initialize( amount_details: nil, amount_to_capture: nil, application_fee_amount: nil, expand: nil, final_capture: nil, metadata: nil, payment_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil ) @amount_details = amount_details @amount_to_capture = amount_to_capture @application_fee_amount = application_fee_amount @expand = @final_capture = final_capture @metadata = @payment_details = payment_details @statement_descriptor = statement_descriptor @statement_descriptor_suffix = statement_descriptor_suffix @transfer_data = transfer_data end |
Instance Attribute Details
#amount_details ⇒ Object
Provides industry-specific information about the amount.
204 205 206 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 204 def amount_details @amount_details end |
#amount_to_capture ⇒ Object
The amount to capture from the PaymentIntent, which must be less than or equal to the original amount. Defaults to the full ‘amount_capturable` if it’s not provided.
206 207 208 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 206 def amount_to_capture @amount_to_capture end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
208 209 210 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 208 def application_fee_amount @application_fee_amount end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
210 211 212 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 210 def @expand end |
#final_capture ⇒ Object
Defaults to ‘true`. When capturing a PaymentIntent, setting `final_capture` to `false` notifies Stripe to not release the remaining uncaptured funds to make sure that they’re captured in future requests. You can only use this setting when [multicapture](stripe.com/docs/payments/multicapture) is available for PaymentIntents.
212 213 214 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 212 def final_capture @final_capture end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
214 215 216 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 214 def @metadata end |
#payment_details ⇒ Object
Provides industry-specific information about the charge.
216 217 218 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 216 def payment_details @payment_details end |
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.
220 221 222 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 220 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.
222 223 224 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 222 def statement_descriptor_suffix @statement_descriptor_suffix end |
#transfer_data ⇒ Object
The parameters that you can use to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
225 226 227 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 225 def transfer_data @transfer_data end |