Class: Stripe::PaymentIntentCaptureParams::AmountDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_capture_params.rb

Defined Under Namespace

Classes: LineItem, Shipping, Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails

Returns a new instance of AmountDetails.



151
152
153
154
155
156
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 151

def initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil)
  @discount_amount = discount_amount
  @line_items = line_items
  @shipping = shipping
  @tax = tax
end

Instance Attribute Details

#discount_amountObject

The total discount applied on the transaction.



143
144
145
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 143

def discount_amount
  @discount_amount
end

#line_itemsObject

A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.



145
146
147
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 145

def line_items
  @line_items
end

#shippingObject

Contains information about the shipping portion of the amount.



147
148
149
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 147

def shipping
  @shipping
end

#taxObject

Contains information about the tax portion of the amount.



149
150
151
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 149

def tax
  @tax
end