Class: Stripe::PaymentIntentCaptureParams::AmountDetails::Surcharge

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_capture_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, enforce_validation: nil) ⇒ Surcharge

Returns a new instance of Surcharge.



172
173
174
175
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 172

def initialize(amount: nil, enforce_validation: nil)
  @amount = amount
  @enforce_validation = enforce_validation
end

Instance Attribute Details

#amountObject

Portion of the amount that corresponds to a surcharge.



168
169
170
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 168

def amount
  @amount
end

#enforce_validationObject

Indicate whether to enforce validations on the surcharge amount.



170
171
172
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 170

def enforce_validation
  @enforce_validation
end