Class: Stripe::PaymentIntentCaptureParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Defined Under Namespace
Classes: CarRental, CarRentalDatum, EventDetails, FleetDatum, Flight, FlightDatum, Lodging, LodgingDatum, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#car_rental_data ⇒ Object
Car rental data for this PaymentIntent.
-
#customer_reference ⇒ Object
A unique value to identify the customer.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#fleet_data ⇒ Object
Fleet data for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#flight_data ⇒ Object
Flight data for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#lodging_data ⇒ Object
Lodging data for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, fleet_data: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, fleet_data: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2016 def initialize( car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, fleet_data: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @car_rental_data = car_rental_data @customer_reference = customer_reference @event_details = event_details @fleet_data = fleet_data @flight = flight @flight_data = flight_data @lodging = lodging @lodging_data = lodging_data @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
1990 1991 1992 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1990 def car_rental @car_rental end |
#car_rental_data ⇒ Object
Car rental data for this PaymentIntent.
1992 1993 1994 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1992 def car_rental_data @car_rental_data end |
#customer_reference ⇒ Object
A unique value to identify the customer. This field is available only for card payments.
This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.
1996 1997 1998 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1996 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
1998 1999 2000 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1998 def event_details @event_details end |
#fleet_data ⇒ Object
Fleet data for this PaymentIntent.
2000 2001 2002 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2000 def fleet_data @fleet_data end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
2002 2003 2004 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2002 def flight @flight end |
#flight_data ⇒ Object
Flight data for this PaymentIntent.
2004 2005 2006 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2004 def flight_data @flight_data end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
2006 2007 2008 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2006 def lodging @lodging end |
#lodging_data ⇒ Object
Lodging data for this PaymentIntent.
2008 2009 2010 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2008 def lodging_data @lodging_data end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.
For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.
2012 2013 2014 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2012 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
2014 2015 2016 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2014 def subscription @subscription end |