Class: Stripe::PaymentIntentCaptureParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Defined Under Namespace
Classes: CarRental, CarRentalDatum, EventDetails, FleetDatum, Flight, FlightDatum, Lodging, LodgingDatum, MoneyServices, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#car_rental_data ⇒ Object
Car rental data for this PaymentIntent.
-
#customer_reference ⇒ Object
A unique value to identify the customer.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#fleet_data ⇒ Object
Fleet data for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#flight_data ⇒ Object
Flight data for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#lodging_data ⇒ Object
Lodging data for this PaymentIntent.
-
#money_services ⇒ Object
Money services details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, fleet_data: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, money_services: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, fleet_data: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, money_services: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2128 def initialize( car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, fleet_data: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, money_services: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @car_rental_data = car_rental_data @customer_reference = customer_reference @event_details = event_details @fleet_data = fleet_data @flight = flight @flight_data = flight_data @lodging = lodging @lodging_data = lodging_data @money_services = money_services @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
2100 2101 2102 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2100 def car_rental @car_rental end |
#car_rental_data ⇒ Object
Car rental data for this PaymentIntent.
2102 2103 2104 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2102 def car_rental_data @car_rental_data end |
#customer_reference ⇒ Object
A unique value to identify the customer. This field is available only for card payments.
This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.
2106 2107 2108 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2106 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
2108 2109 2110 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2108 def event_details @event_details end |
#fleet_data ⇒ Object
Fleet data for this PaymentIntent.
2110 2111 2112 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2110 def fleet_data @fleet_data end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
2112 2113 2114 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2112 def flight @flight end |
#flight_data ⇒ Object
Flight data for this PaymentIntent.
2114 2115 2116 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2114 def flight_data @flight_data end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
2116 2117 2118 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2116 def lodging @lodging end |
#lodging_data ⇒ Object
Lodging data for this PaymentIntent.
2118 2119 2120 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2118 def lodging_data @lodging_data end |
#money_services ⇒ Object
Money services details for this PaymentIntent.
2120 2121 2122 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2120 def money_services @money_services end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.
For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.
2124 2125 2126 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2124 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
2126 2127 2128 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2126 def subscription @subscription end |