Class: Stripe::PaymentIntentCaptureParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Defined Under Namespace
Classes: CarRental, CarRentalDatum, EventDetails, Flight, FlightDatum, Lodging, LodgingDatum, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#car_rental_data ⇒ Object
Car rental data for this PaymentIntent.
-
#customer_reference ⇒ Object
A unique value to identify the customer.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#flight_data ⇒ Object
Flight data for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#lodging_data ⇒ Object
Lodging data for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1848 def initialize( car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @car_rental_data = car_rental_data @customer_reference = customer_reference @event_details = event_details @flight = flight @flight_data = flight_data @lodging = lodging @lodging_data = lodging_data @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
1824 1825 1826 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1824 def car_rental @car_rental end |
#car_rental_data ⇒ Object
Car rental data for this PaymentIntent.
1826 1827 1828 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1826 def car_rental_data @car_rental_data end |
#customer_reference ⇒ Object
A unique value to identify the customer. This field is available only for card payments.
This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.
1830 1831 1832 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1830 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
1832 1833 1834 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1832 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
1834 1835 1836 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1834 def flight @flight end |
#flight_data ⇒ Object
Flight data for this PaymentIntent.
1836 1837 1838 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1836 def flight_data @flight_data end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
1838 1839 1840 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1838 def lodging @lodging end |
#lodging_data ⇒ Object
Lodging data for this PaymentIntent.
1840 1841 1842 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1840 def lodging_data @lodging_data end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.
For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.
1844 1845 1846 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1844 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
1846 1847 1848 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1846 def subscription @subscription end |