Class: Stripe::PaymentIntentCaptureParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Defined Under Namespace
Classes: CarRental, CarRentalDatum, EventDetails, Flight, FlightDatum, Lodging, LodgingDatum, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#car_rental_data ⇒ Object
Car rental data for this PaymentIntent.
-
#customer_reference ⇒ Object
A unique value to identify the customer.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#flight_data ⇒ Object
Flight data for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#lodging_data ⇒ Object
Lodging data for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1834 def initialize( car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @car_rental_data = car_rental_data @customer_reference = customer_reference @event_details = event_details @flight = flight @flight_data = flight_data @lodging = lodging @lodging_data = lodging_data @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
1808 1809 1810 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1808 def car_rental @car_rental end |
#car_rental_data ⇒ Object
Car rental data for this PaymentIntent.
1810 1811 1812 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1810 def car_rental_data @car_rental_data end |
#customer_reference ⇒ Object
A unique value to identify the customer. This field is available only for card payments.
This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.
1814 1815 1816 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1814 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
1816 1817 1818 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1816 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
1818 1819 1820 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1818 def flight @flight end |
#flight_data ⇒ Object
Flight data for this PaymentIntent.
1820 1821 1822 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1820 def flight_data @flight_data end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
1822 1823 1824 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1822 def lodging @lodging end |
#lodging_data ⇒ Object
Lodging data for this PaymentIntent.
1824 1825 1826 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1824 def lodging_data @lodging_data end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.
Required when the Payment Method Types array contains ‘card`, including when [automatic_payment_methods.enabled](/api/payment_intents/create#create_payment_intent-automatic_payment_methods-enabled) is set to `true`.
For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.
1830 1831 1832 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1830 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
1832 1833 1834 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1832 def subscription @subscription end |