Class: Stripe::PaymentIntentCaptureParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_capture_params.rb

Defined Under Namespace

Classes: CarRental, CarRentalDatum, EventDetails, Flight, FlightDatum, Lodging, LodgingDatum, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
1837
1838
1839
1840
1841
1842
1843
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1821

def initialize(
  car_rental: nil,
  car_rental_data: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  flight_data: nil,
  lodging: nil,
  lodging_data: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @car_rental_data = car_rental_data
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @flight_data = flight_data
  @lodging = lodging
  @lodging_data = lodging_data
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



1795
1796
1797
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1795

def car_rental
  @car_rental
end

#car_rental_dataObject

Car rental data for this PaymentIntent.



1797
1798
1799
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1797

def car_rental_data
  @car_rental_data
end

#customer_referenceObject

A unique value to identify the customer. This field is available only for card payments.

This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.



1801
1802
1803
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1801

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



1803
1804
1805
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1803

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



1805
1806
1807
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1805

def flight
  @flight
end

#flight_dataObject

Flight data for this PaymentIntent.



1807
1808
1809
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1807

def flight_data
  @flight_data
end

#lodgingObject

Lodging reservation details for this PaymentIntent



1809
1810
1811
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1809

def lodging
  @lodging
end

#lodging_dataObject

Lodging data for this PaymentIntent.



1811
1812
1813
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1811

def lodging_data
  @lodging_data
end

#order_referenceObject

A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.

Required when the Payment Method Types array contains ‘card`, including when [automatic_payment_methods.enabled](/api/payment_intents/create#create_payment_intent-automatic_payment_methods-enabled) is set to `true`.

For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.



1817
1818
1819
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1817

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



1819
1820
1821
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1819

def subscription
  @subscription
end