Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_capture_params.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental

Returns a new instance of CarRental.



376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 376

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  distance: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  pickup_location_name: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  return_location_name: nil,
  tax_exempt: nil,
  vehicle_identification_number: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @distance = distance
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @pickup_location_name = pickup_location_name
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @return_location_name = return_location_name
  @tax_exempt = tax_exempt
  @vehicle_identification_number = vehicle_identification_number
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



328
329
330
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 328

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



330
331
332
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 330

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



332
333
334
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 332

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



334
335
336
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 334

def car_make
  @car_make
end

#car_modelObject

Model of the car.



336
337
338
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 336

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



338
339
340
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 338

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



340
341
342
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 340

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



342
343
344
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 342

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



344
345
346
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 344

def delivery
  @delivery
end

#distanceObject

The details of the distance traveled during the rental period.



346
347
348
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 346

def distance
  @distance
end

#driversObject

The details of the passengers in the travel reservation



348
349
350
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 348

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



350
351
352
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 350

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



352
353
354
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 352

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



354
355
356
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 354

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



356
357
358
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 356

def pickup_at
  @pickup_at
end

#pickup_location_nameObject

Name of the pickup location.



358
359
360
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 358

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject

Rental rate.



360
361
362
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 360

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



362
363
364
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 362

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



364
365
366
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 364

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



366
367
368
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 366

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



368
369
370
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 368

def return_at
  @return_at
end

#return_location_nameObject

Name of the return location.



370
371
372
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 370

def return_location_name
  @return_location_name
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



372
373
374
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 372

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject

The vehicle identification number.



374
375
376
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 374

def vehicle_identification_number
  @vehicle_identification_number
end