Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
212 213 214 215 216 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 212 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
206 207 208 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 206 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
208 209 210 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 208 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
210 211 212 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 210 def phone @phone end |