Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
204 205 206 207 208 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 204 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
198 199 200 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 198 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
200 201 202 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 200 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
202 203 204 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 202 def phone @phone end |