Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::CarRentalDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::CarRentalDatum
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Defined Under Namespace
Classes: Affiliate, Distance, Driver, DropOff, Insurance, Pickup, Total, Vehicle
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate (such as travel agency) details for the rental.
-
#booking_number ⇒ Object
Booking confirmation number for the car rental.
-
#carrier_name ⇒ Object
Name of the car rental company.
-
#customer_service_phone_number ⇒ Object
Customer service phone number for the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#distance ⇒ Object
Distance details for the rental.
-
#drivers ⇒ Object
List of drivers for the rental.
-
#drop_off ⇒ Object
Drop-off location details.
-
#insurances ⇒ Object
Insurance details for the rental.
-
#no_show_indicator ⇒ Object
Indicates if the customer was a no-show.
-
#pickup ⇒ Object
Pickup location details.
-
#renter_name ⇒ Object
Name of the person renting the vehicle.
-
#total ⇒ Object
Total cost breakdown for the rental.
-
#vehicle ⇒ Object
Vehicle details for the rental.
Instance Method Summary collapse
-
#initialize(affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil) ⇒ CarRentalDatum
constructor
A new instance of CarRentalDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil) ⇒ CarRentalDatum
Returns a new instance of CarRentalDatum.
783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 783 def initialize( affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil ) @affiliate = affiliate @booking_number = booking_number @carrier_name = carrier_name @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @distance = distance @drivers = drivers @drop_off = drop_off @insurances = insurances @no_show_indicator = no_show_indicator @pickup = pickup @renter_name = renter_name @total = total @vehicle = vehicle end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate (such as travel agency) details for the rental.
755 756 757 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 755 def affiliate @affiliate end |
#booking_number ⇒ Object
Booking confirmation number for the car rental.
757 758 759 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 757 def booking_number @booking_number end |
#carrier_name ⇒ Object
Name of the car rental company.
759 760 761 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 759 def carrier_name @carrier_name end |
#customer_service_phone_number ⇒ Object
Customer service phone number for the car rental company.
761 762 763 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 761 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
763 764 765 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 763 def days_rented @days_rented end |
#distance ⇒ Object
Distance details for the rental.
765 766 767 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 765 def distance @distance end |
#drivers ⇒ Object
List of drivers for the rental.
767 768 769 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 767 def drivers @drivers end |
#drop_off ⇒ Object
Drop-off location details.
769 770 771 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 769 def drop_off @drop_off end |
#insurances ⇒ Object
Insurance details for the rental.
771 772 773 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 771 def insurances @insurances end |
#no_show_indicator ⇒ Object
Indicates if the customer was a no-show.
773 774 775 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 773 def no_show_indicator @no_show_indicator end |
#pickup ⇒ Object
Pickup location details.
775 776 777 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 775 def pickup @pickup end |
#renter_name ⇒ Object
Name of the person renting the vehicle.
777 778 779 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 777 def renter_name @renter_name end |
#total ⇒ Object
Total cost breakdown for the rental.
779 780 781 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 779 def total @total end |
#vehicle ⇒ Object
Vehicle details for the rental.
781 782 783 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 781 def vehicle @vehicle end |