Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::CarRentalDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::CarRentalDatum
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Defined Under Namespace
Classes: Affiliate, Distance, Driver, DropOff, Insurance, Pickup, Total, Vehicle
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate (such as travel agency) details for the rental.
-
#booking_number ⇒ Object
Booking confirmation number for the car rental.
-
#carrier_name ⇒ Object
Name of the car rental company.
-
#customer_service_phone_number ⇒ Object
Customer service phone number for the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#distance ⇒ Object
Distance details for the rental.
-
#drivers ⇒ Object
List of drivers for the rental.
-
#drop_off ⇒ Object
Drop-off location details.
-
#insurances ⇒ Object
Insurance details for the rental.
-
#no_show_indicator ⇒ Object
Indicates if the customer was a no-show.
-
#pickup ⇒ Object
Pickup location details.
-
#renter_name ⇒ Object
Name of the person renting the vehicle.
-
#total ⇒ Object
Total cost breakdown for the rental.
-
#vehicle ⇒ Object
Vehicle details for the rental.
Instance Method Summary collapse
-
#initialize(affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil) ⇒ CarRentalDatum
constructor
A new instance of CarRentalDatum.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil) ⇒ CarRentalDatum
Returns a new instance of CarRentalDatum.
767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 767 def initialize( affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil ) @affiliate = affiliate @booking_number = booking_number @carrier_name = carrier_name @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @distance = distance @drivers = drivers @drop_off = drop_off @insurances = insurances @no_show_indicator = no_show_indicator @pickup = pickup @renter_name = renter_name @total = total @vehicle = vehicle end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate (such as travel agency) details for the rental.
739 740 741 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 739 def affiliate @affiliate end |
#booking_number ⇒ Object
Booking confirmation number for the car rental.
741 742 743 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 741 def booking_number @booking_number end |
#carrier_name ⇒ Object
Name of the car rental company.
743 744 745 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 743 def carrier_name @carrier_name end |
#customer_service_phone_number ⇒ Object
Customer service phone number for the car rental company.
745 746 747 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 745 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
747 748 749 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 747 def days_rented @days_rented end |
#distance ⇒ Object
Distance details for the rental.
749 750 751 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 749 def distance @distance end |
#drivers ⇒ Object
List of drivers for the rental.
751 752 753 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 751 def drivers @drivers end |
#drop_off ⇒ Object
Drop-off location details.
753 754 755 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 753 def drop_off @drop_off end |
#insurances ⇒ Object
Insurance details for the rental.
755 756 757 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 755 def insurances @insurances end |
#no_show_indicator ⇒ Object
Indicates if the customer was a no-show.
757 758 759 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 757 def no_show_indicator @no_show_indicator end |
#pickup ⇒ Object
Pickup location details.
759 760 761 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 759 def pickup @pickup end |
#renter_name ⇒ Object
Name of the person renting the vehicle.
761 762 763 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 761 def renter_name @renter_name end |
#total ⇒ Object
Total cost breakdown for the rental.
763 764 765 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 763 def total @total end |
#vehicle ⇒ Object
Vehicle details for the rental.
765 766 767 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 765 def vehicle @vehicle end |