Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 872 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
854 855 856 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 854 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
856 857 858 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 856 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
858 859 860 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 858 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
860 861 862 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 860 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
862 863 864 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 862 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
864 865 866 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 864 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
866 867 868 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 866 def genre @genre end |
#name ⇒ Object
The name of the event.
868 869 870 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 868 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
870 871 872 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 870 def starts_at @starts_at end |