Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_capture_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



850
851
852
853
854
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 850

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



844
845
846
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 844

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



846
847
848
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 846

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



848
849
850
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 848

def phone
  @phone
end