Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
469 470 471 472 473 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 469 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
463 464 465 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 463 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
465 466 467 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 465 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
467 468 469 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 467 def phone @phone end |