Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 995 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
979 980 981 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 979 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
981 982 983 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 981 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
983 984 985 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 983 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
985 986 987 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 985 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
987 988 989 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 987 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
989 990 991 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 989 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
991 992 993 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 991 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
993 994 995 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 993 def ticket_number @ticket_number end |