Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 619 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
603 604 605 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 603 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
605 606 607 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 605 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
607 608 609 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 607 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
609 610 611 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 609 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
611 612 613 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 611 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
613 614 615 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 613 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
615 616 617 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 615 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
617 618 619 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 617 def ticket_number @ticket_number end |