Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
943 944 945 946 947 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 943 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
937 938 939 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 937 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
939 940 941 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 939 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
941 942 943 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 941 def phone @phone end |