Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
914 915 916 917 918 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 914 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
908 909 910 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 908 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
910 911 912 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 910 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
912 913 914 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 912 def phone @phone end |