Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
546 547 548 549 550 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 546 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
540 541 542 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 540 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
542 543 544 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 542 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
544 545 546 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 544 def phone @phone end |