Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_capture_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



538
539
540
541
542
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 538

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



532
533
534
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 532

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



534
535
536
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 534

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



536
537
538
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 536

def phone
  @phone
end