Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Flight::Passenger
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::Flight::Passenger
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
Full name of the person or entity on the flight reservation.
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Passenger
constructor
A new instance of Passenger.
Methods inherited from RequestParams
Constructor Details
#initialize(name: nil) ⇒ Passenger
Returns a new instance of Passenger.
935 936 937 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 935 def initialize(name: nil) @name = name end |
Instance Attribute Details
#name ⇒ Object
Full name of the person or entity on the flight reservation.
933 934 935 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 933 def name @name end |