Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::FlightDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::FlightDatum
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Defined Under Namespace
Classes: Affiliate, Insurance, Passenger, Segment, Total
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details if applicable.
-
#booking_number ⇒ Object
Reservation reference.
-
#computerized_reservation_system ⇒ Object
Computerized reservation system used to make the reservation and purchase the ticket.
-
#endorsements_and_restrictions ⇒ Object
Ticket restrictions.
-
#insurances ⇒ Object
List of insurances.
-
#passengers ⇒ Object
List of passengers.
-
#segments ⇒ Object
List of flight segments.
-
#ticket_electronically_issued_indicator ⇒ Object
Electronic ticket indicator.
-
#total ⇒ Object
Total cost breakdown.
-
#transaction_type ⇒ Object
Type of flight transaction.
Instance Method Summary collapse
-
#initialize(affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil) ⇒ FlightDatum
constructor
A new instance of FlightDatum.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil) ⇒ FlightDatum
Returns a new instance of FlightDatum.
1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1273 def initialize( affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil ) @affiliate = affiliate @booking_number = booking_number @computerized_reservation_system = computerized_reservation_system @endorsements_and_restrictions = endorsements_and_restrictions @insurances = insurances @passengers = passengers @segments = segments @ticket_electronically_issued_indicator = ticket_electronically_issued_indicator @total = total @transaction_type = transaction_type end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details if applicable.
1253 1254 1255 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1253 def affiliate @affiliate end |
#booking_number ⇒ Object
Reservation reference.
1255 1256 1257 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1255 def booking_number @booking_number end |
#computerized_reservation_system ⇒ Object
Computerized reservation system used to make the reservation and purchase the ticket.
1257 1258 1259 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1257 def computerized_reservation_system @computerized_reservation_system end |
#endorsements_and_restrictions ⇒ Object
Ticket restrictions.
1259 1260 1261 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1259 def endorsements_and_restrictions @endorsements_and_restrictions end |
#insurances ⇒ Object
List of insurances.
1261 1262 1263 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1261 def insurances @insurances end |
#passengers ⇒ Object
List of passengers.
1263 1264 1265 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1263 def passengers @passengers end |
#segments ⇒ Object
List of flight segments.
1265 1266 1267 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1265 def segments @segments end |
#ticket_electronically_issued_indicator ⇒ Object
Electronic ticket indicator.
1267 1268 1269 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1267 def ticket_electronically_issued_indicator @ticket_electronically_issued_indicator end |
#total ⇒ Object
Total cost breakdown.
1269 1270 1271 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1269 def total @total end |
#transaction_type ⇒ Object
Type of flight transaction.
1271 1272 1273 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1271 def transaction_type @transaction_type end |