Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::FlightDatum::Affiliate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::FlightDatum::Affiliate
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Instance Attribute Summary collapse
-
#code ⇒ Object
Affiliate partner code.
-
#name ⇒ Object
Name of affiliate partner.
-
#travel_authorization_code ⇒ Object
Code provided by the company to a travel agent authorizing ticket issuance.
Instance Method Summary collapse
-
#initialize(code: nil, name: nil, travel_authorization_code: nil) ⇒ Affiliate
constructor
A new instance of Affiliate.
Methods inherited from RequestParams
Constructor Details
#initialize(code: nil, name: nil, travel_authorization_code: nil) ⇒ Affiliate
Returns a new instance of Affiliate.
1025 1026 1027 1028 1029 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1025 def initialize(code: nil, name: nil, travel_authorization_code: nil) @code = code @name = name @travel_authorization_code = end |
Instance Attribute Details
#code ⇒ Object
Affiliate partner code.
1019 1020 1021 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1019 def code @code end |
#name ⇒ Object
Name of affiliate partner.
1021 1022 1023 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1021 def name @name end |
#travel_authorization_code ⇒ Object
Code provided by the company to a travel agent authorizing ticket issuance.
1023 1024 1025 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1023 def @travel_authorization_code end |