Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1432 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
1390 1391 1392 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1390 def address @address end |
#adults ⇒ Object
The number of adults on the booking
1392 1393 1394 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1392 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
1394 1395 1396 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1394 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
1396 1397 1398 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1396 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
1398 1399 1400 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1398 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
1400 1401 1402 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1400 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
1402 1403 1404 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1402 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
1404 1405 1406 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1404 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
1406 1407 1408 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1406 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
1408 1409 1410 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1408 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
1410 1411 1412 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1410 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
1412 1413 1414 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1412 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
1414 1415 1416 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1414 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
1416 1417 1418 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1416 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
1418 1419 1420 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1418 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
1420 1421 1422 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1420 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
1422 1423 1424 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1422 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
1424 1425 1426 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1424 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
1426 1427 1428 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1426 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
1428 1429 1430 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1428 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
1430 1431 1432 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1430 def total_tax_amount @total_tax_amount end |