Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1403 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
1361 1362 1363 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1361 def address @address end |
#adults ⇒ Object
The number of adults on the booking
1363 1364 1365 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1363 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
1365 1366 1367 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1365 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
1367 1368 1369 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1367 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
1369 1370 1371 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1369 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
1371 1372 1373 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1371 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
1373 1374 1375 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1373 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
1375 1376 1377 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1375 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
1377 1378 1379 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1377 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
1379 1380 1381 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1379 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
1381 1382 1383 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1381 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
1383 1384 1385 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1383 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
1385 1386 1387 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1385 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
1387 1388 1389 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1387 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
1389 1390 1391 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1389 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
1391 1392 1393 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1391 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
1393 1394 1395 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1393 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
1395 1396 1397 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1395 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
1397 1398 1399 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1397 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
1399 1400 1401 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1399 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
1401 1402 1403 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1401 def total_tax_amount @total_tax_amount end |