Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 758 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
716 717 718 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 716 def address @address end |
#adults ⇒ Object
The number of adults on the booking
718 719 720 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 718 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
720 721 722 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 720 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
722 723 724 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 722 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
724 725 726 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 724 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
726 727 728 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 726 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
728 729 730 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 728 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
730 731 732 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 730 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
732 733 734 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 732 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
734 735 736 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 734 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
736 737 738 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 736 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
738 739 740 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 738 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
740 741 742 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 740 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
742 743 744 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 742 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
744 745 746 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 744 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
746 747 748 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 746 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
748 749 750 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 748 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
750 751 752 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 750 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
752 753 754 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 752 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
754 755 756 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 754 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
756 757 758 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 756 def total_tax_amount @total_tax_amount end |