Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
1364 1365 1366 1367 1368 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1364 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
1358 1359 1360 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1358 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
1360 1361 1362 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1360 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
1362 1363 1364 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1362 def phone @phone end |