Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
1348 1349 1350 1351 1352 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1348 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
1342 1343 1344 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1342 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
1344 1345 1346 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1344 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
1346 1347 1348 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1346 def phone @phone end |