Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_capture_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1335
1336
1337
1338
1339
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1335

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1329
1330
1331
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1329

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1331
1332
1333
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1331

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1333
1334
1335
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1333

def phone
  @phone
end