Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_capture_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



690
691
692
693
694
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 690

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



684
685
686
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 684

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



686
687
688
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 686

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



688
689
690
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 688

def phone
  @phone
end