Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Lodging::Passenger
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::Lodging::Passenger
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
Full name of the person or entity on the lodging reservation.
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Passenger
constructor
A new instance of Passenger.
Methods inherited from RequestParams
Constructor Details
#initialize(name: nil) ⇒ Passenger
Returns a new instance of Passenger.
711 712 713 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 711 def initialize(name: nil) @name = name end |
Instance Attribute Details
#name ⇒ Object
Full name of the person or entity on the lodging reservation.
709 710 711 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 709 def name @name end |