Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::LodgingDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::LodgingDatum
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Defined Under Namespace
Classes: Accommodation, Affiliate, Guest, Host, Insurance, Total
Instance Attribute Summary collapse
-
#accommodation ⇒ Object
Accommodation details for the lodging.
-
#affiliate ⇒ Object
Affiliate details if applicable.
-
#booking_number ⇒ Object
Booking confirmation number for the lodging.
-
#checkin_at ⇒ Object
Check-in date.
-
#checkout_at ⇒ Object
Check-out date.
-
#customer_service_phone_number ⇒ Object
Customer service phone number for the lodging company.
-
#fire_safety_act_compliance_indicator ⇒ Object
Whether the lodging is compliant with any hotel fire safety regulations.
-
#guests ⇒ Object
List of guests for the lodging.
-
#host ⇒ Object
Host details for the lodging.
-
#insurances ⇒ Object
List of insurances for the lodging.
-
#no_show_indicator ⇒ Object
Whether the renter is a no-show.
-
#renter_id_number ⇒ Object
Renter ID number for the lodging.
-
#renter_name ⇒ Object
Renter name for the lodging.
-
#total ⇒ Object
Total details for the lodging.
Instance Method Summary collapse
-
#initialize(accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil) ⇒ LodgingDatum
constructor
A new instance of LodgingDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil) ⇒ LodgingDatum
Returns a new instance of LodgingDatum.
1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1740 def initialize( accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil ) @accommodation = accommodation @affiliate = affiliate @booking_number = booking_number @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @fire_safety_act_compliance_indicator = fire_safety_act_compliance_indicator @guests = guests @host = host @insurances = insurances @no_show_indicator = no_show_indicator @renter_id_number = renter_id_number @renter_name = renter_name @total = total end |
Instance Attribute Details
#accommodation ⇒ Object
Accommodation details for the lodging.
1712 1713 1714 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1712 def accommodation @accommodation end |
#affiliate ⇒ Object
Affiliate details if applicable.
1714 1715 1716 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1714 def affiliate @affiliate end |
#booking_number ⇒ Object
Booking confirmation number for the lodging.
1716 1717 1718 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1716 def booking_number @booking_number end |
#checkin_at ⇒ Object
Check-in date.
1718 1719 1720 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1718 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Check-out date.
1720 1721 1722 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1720 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
Customer service phone number for the lodging company.
1722 1723 1724 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1722 def customer_service_phone_number @customer_service_phone_number end |
#fire_safety_act_compliance_indicator ⇒ Object
Whether the lodging is compliant with any hotel fire safety regulations.
1724 1725 1726 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1724 def fire_safety_act_compliance_indicator @fire_safety_act_compliance_indicator end |
#guests ⇒ Object
List of guests for the lodging.
1726 1727 1728 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1726 def guests @guests end |
#host ⇒ Object
Host details for the lodging.
1728 1729 1730 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1728 def host @host end |
#insurances ⇒ Object
List of insurances for the lodging.
1730 1731 1732 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1730 def insurances @insurances end |
#no_show_indicator ⇒ Object
Whether the renter is a no-show.
1732 1733 1734 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1732 def no_show_indicator @no_show_indicator end |
#renter_id_number ⇒ Object
Renter ID number for the lodging.
1734 1735 1736 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1734 def renter_id_number @renter_id_number end |
#renter_name ⇒ Object
Renter name for the lodging.
1736 1737 1738 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1736 def renter_name @renter_name end |
#total ⇒ Object
Total details for the lodging.
1738 1739 1740 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1738 def total @total end |