Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::MoneyServices::AccountFunding
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCaptureParams::PaymentDetails::MoneyServices::AccountFunding
- Defined in:
- lib/stripe/params/payment_intent_capture_params.rb
Defined Under Namespace
Classes: BeneficiaryDetails, SenderDetails
Instance Attribute Summary collapse
-
#beneficiary_account ⇒ Object
ID of the Account representing the beneficiary in this account funding transaction.
-
#beneficiary_details ⇒ Object
Inline identity details for the beneficiary of this account funding transaction.
-
#sender_account ⇒ Object
ID of the Account representing the sender in this account funding transaction.
-
#sender_details ⇒ Object
Inline identity details for the sender of this account funding transaction.
Instance Method Summary collapse
-
#initialize(beneficiary_account: nil, beneficiary_details: nil, sender_account: nil, sender_details: nil) ⇒ AccountFunding
constructor
A new instance of AccountFunding.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(beneficiary_account: nil, beneficiary_details: nil, sender_account: nil, sender_details: nil) ⇒ AccountFunding
Returns a new instance of AccountFunding.
2026 2027 2028 2029 2030 2031 2032 2033 2034 2035 2036 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2026 def initialize( beneficiary_account: nil, beneficiary_details: nil, sender_account: nil, sender_details: nil ) @beneficiary_account = beneficiary_account @beneficiary_details = beneficiary_details @sender_account = sender_account @sender_details = sender_details end |
Instance Attribute Details
#beneficiary_account ⇒ Object
ID of the Account representing the beneficiary in this account funding transaction.
2018 2019 2020 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2018 def beneficiary_account @beneficiary_account end |
#beneficiary_details ⇒ Object
Inline identity details for the beneficiary of this account funding transaction.
2020 2021 2022 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2020 def beneficiary_details @beneficiary_details end |
#sender_account ⇒ Object
ID of the Account representing the sender in this account funding transaction.
2022 2023 2024 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2022 def sender_account @sender_account end |
#sender_details ⇒ Object
Inline identity details for the sender of this account funding transaction.
2024 2025 2026 |
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 2024 def sender_details @sender_details end |