Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_capture_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



1789
1790
1791
1792
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1789

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1785
1786
1787
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1785

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1787
1788
1789
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1787

def interval
  @interval
end