Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_capture_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



1802
1803
1804
1805
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1802

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1798
1799
1800
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1798

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1800
1801
1802
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1800

def interval
  @interval
end