Class: Stripe::PaymentIntentCaptureParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_capture_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



1773
1774
1775
1776
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1773

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1769
1770
1771
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1769

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1771
1772
1773
# File 'lib/stripe/params/payment_intent_capture_params.rb', line 1771

def interval
  @interval
end