Class: Stripe::PaymentIntentConfirmParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: AllocatedFunds, AmountDetails, Hooks, MandateData, PaymentDetails, PaymentMethodData, PaymentMethodOptions, RadarOptions, Shipping
Instance Attribute Summary collapse
-
#allocated_funds ⇒ Object
Allocated Funds configuration for this PaymentIntent.
-
#allowed_payment_method_types ⇒ Object
The list of payment method types allowed for use with this payment.
-
#amount_details ⇒ Object
Provides industry-specific information about the amount.
-
#amount_to_confirm ⇒ Object
Amount to confirm on the PaymentIntent.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account.
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer's account.
-
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this PaymentIntent.
-
#error_on_requires_action ⇒ Object
Set to
trueto fail the payment attempt if the PaymentIntent transitions intorequires_action. -
#excluded_payment_method_types ⇒ Object
The list of payment method types to exclude from use with this payment.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fx_quote ⇒ Object
The FX rate in the quote is validated and used to convert the presentment amount to the settlement amount.
-
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle.
-
#mandate ⇒ Object
ID of the mandate that's used for this payment.
-
#mandate_data ⇒ Object
Attribute for param field mandate_data.
-
#off_session ⇒ Object
Set to
trueto indicate that the customer isn't in your checkout flow during this payment attempt and can't authenticate. -
#payment_details ⇒ Object
Provides industry-specific information about the charge.
-
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or compatible Source object) to attach to this PaymentIntent.
-
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod.
-
#payment_method_options ⇒ Object
Payment method-specific configuration for this PaymentIntent.
-
#payment_method_types ⇒ Object
The list of payment method types (for example, a card) that this PaymentIntent can use.
-
#radar_options ⇒ Object
Options to configure Radar.
-
#receipt_email ⇒ Object
Email address that the receipt for the resulting payment will be sent to.
-
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method's app or site.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
-
#shipping ⇒ Object
Shipping information for this PaymentIntent.
-
#use_stripe_sdk ⇒ Object
Set to
truewhen confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(allocated_funds: nil, allowed_payment_method_types: nil, amount_details: nil, amount_to_confirm: nil, application_fee_amount: nil, capture_method: nil, confirmation_token: nil, error_on_requires_action: nil, excluded_payment_method_types: nil, expand: nil, fx_quote: nil, hooks: nil, mandate: nil, mandate_data: nil, off_session: nil, payment_details: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shipping: nil, use_stripe_sdk: nil) ⇒ PaymentIntentConfirmParams
Returns a new instance of PaymentIntentConfirmParams.
6467 6468 6469 6470 6471 6472 6473 6474 6475 6476 6477 6478 6479 6480 6481 6482 6483 6484 6485 6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 6504 6505 6506 6507 6508 6509 6510 6511 6512 6513 6514 6515 6516 6517 6518 6519 6520 6521 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6467 def initialize( allocated_funds: nil, allowed_payment_method_types: nil, amount_details: nil, amount_to_confirm: nil, application_fee_amount: nil, capture_method: nil, confirmation_token: nil, error_on_requires_action: nil, excluded_payment_method_types: nil, expand: nil, fx_quote: nil, hooks: nil, mandate: nil, mandate_data: nil, off_session: nil, payment_details: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shipping: nil, use_stripe_sdk: nil ) @allocated_funds = allocated_funds @allowed_payment_method_types = allowed_payment_method_types @amount_details = amount_details @amount_to_confirm = amount_to_confirm @application_fee_amount = application_fee_amount @capture_method = capture_method @confirmation_token = confirmation_token @error_on_requires_action = error_on_requires_action @excluded_payment_method_types = excluded_payment_method_types @expand = @fx_quote = fx_quote @hooks = hooks @mandate = mandate @mandate_data = mandate_data @off_session = off_session @payment_details = payment_details @payment_method = payment_method @payment_method_data = payment_method_data @payment_method_options = @payment_method_types = payment_method_types @radar_options = @receipt_email = receipt_email @return_url = return_url @setup_future_usage = setup_future_usage @shipping = shipping @use_stripe_sdk = use_stripe_sdk end |
Instance Attribute Details
#allocated_funds ⇒ Object
Allocated Funds configuration for this PaymentIntent.
6400 6401 6402 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6400 def allocated_funds @allocated_funds end |
#allowed_payment_method_types ⇒ Object
The list of payment method types allowed for use with this payment. Stripe automatically returns compatible payment methods from this list in the payment_method_types field of the response, based on the other PaymentIntent parameters, such as currency, amount, and customer.
6402 6403 6404 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6402 def allowed_payment_method_types @allowed_payment_method_types end |
#amount_details ⇒ Object
Provides industry-specific information about the amount.
6404 6405 6406 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6404 def amount_details @amount_details end |
#amount_to_confirm ⇒ Object
Amount to confirm on the PaymentIntent. Defaults to amount if not provided.
6406 6407 6408 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6406 def amount_to_confirm @amount_to_confirm end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents use case for connected accounts.
6408 6409 6410 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6408 def application_fee_amount @application_fee_amount end |
#capture_method ⇒ Object
Controls when the funds will be captured from the customer's account.
6410 6411 6412 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6410 def capture_method @capture_method end |
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this PaymentIntent.
If the provided ConfirmationToken contains properties that are also being provided in this request, such as payment_method, then the values in this request will take precedence.
6414 6415 6416 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6414 def confirmation_token @confirmation_token end |
#error_on_requires_action ⇒ Object
Set to true to fail the payment attempt if the PaymentIntent transitions into requires_action. This parameter is intended for simpler integrations that do not handle customer actions, like saving cards without authentication.
6416 6417 6418 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6416 def error_on_requires_action @error_on_requires_action end |
#excluded_payment_method_types ⇒ Object
The list of payment method types to exclude from use with this payment.
6418 6419 6420 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6418 def excluded_payment_method_types @excluded_payment_method_types end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
6420 6421 6422 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6420 def @expand end |
#fx_quote ⇒ Object
The FX rate in the quote is validated and used to convert the presentment amount to the settlement amount.
6422 6423 6424 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6422 def fx_quote @fx_quote end |
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle
6424 6425 6426 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6424 def hooks @hooks end |
#mandate ⇒ Object
ID of the mandate that's used for this payment.
6426 6427 6428 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6426 def mandate @mandate end |
#mandate_data ⇒ Object
Attribute for param field mandate_data
6428 6429 6430 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6428 def mandate_data @mandate_data end |
#off_session ⇒ Object
Set to true to indicate that the customer isn't in your checkout flow during this payment attempt and can't authenticate. Use this parameter in scenarios where you collect payment method details and charge them later.
6430 6431 6432 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6430 def off_session @off_session end |
#payment_details ⇒ Object
Provides industry-specific information about the charge.
6432 6433 6434 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6432 def payment_details @payment_details end |
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or compatible Source object) to attach to this PaymentIntent. If the payment method is attached to a Customer, it must match the customer that is set on this PaymentIntent.
6435 6436 6437 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6435 def payment_method @payment_method end |
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the payment_method property on the PaymentIntent.
6439 6440 6441 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6439 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment method-specific configuration for this PaymentIntent.
6441 6442 6443 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6441 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types (for example, a card) that this PaymentIntent can use. If you don't provide this, Stripe will dynamically show relevant payment methods from your payment method settings. A list of valid payment method types can be found here.
6443 6444 6445 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6443 def payment_method_types @payment_method_types end |
#radar_options ⇒ Object
Options to configure Radar. Learn more about Radar Sessions.
6445 6446 6447 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6445 def @radar_options end |
#receipt_email ⇒ Object
Email address that the receipt for the resulting payment will be sent to. If receipt_email is specified for a payment in live mode, a receipt will be sent regardless of your email settings.
6447 6448 6449 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6447 def receipt_email @receipt_email end |
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method's app or site. If you'd prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.
6451 6452 6453 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6451 def return_url @return_url end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.
6461 6462 6463 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6461 def setup_future_usage @setup_future_usage end |
#shipping ⇒ Object
Shipping information for this PaymentIntent.
6463 6464 6465 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6463 def shipping @shipping end |
#use_stripe_sdk ⇒ Object
Set to true when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
6465 6466 6467 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6465 def use_stripe_sdk @use_stripe_sdk end |