Class: Stripe::PaymentIntentConfirmParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: AmountDetails, Hooks, MandateData, PaymentDetails, PaymentMethodData, PaymentMethodOptions, RadarOptions, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(allowed_payment_method_types: nil, amount_details: nil, amount_to_confirm: nil, capture_method: nil, confirmation_token: nil, error_on_requires_action: nil, excluded_payment_method_types: nil, expand: nil, hooks: nil, mandate: nil, mandate_data: nil, off_session: nil, payment_details: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shipping: nil, use_stripe_sdk: nil) ⇒ PaymentIntentConfirmParams

Returns a new instance of PaymentIntentConfirmParams.



2853
2854
2855
2856
2857
2858
2859
2860
2861
2862
2863
2864
2865
2866
2867
2868
2869
2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2853

def initialize(
  allowed_payment_method_types: nil,
  amount_details: nil,
  amount_to_confirm: nil,
  capture_method: nil,
  confirmation_token: nil,
  error_on_requires_action: nil,
  excluded_payment_method_types: nil,
  expand: nil,
  hooks: nil,
  mandate: nil,
  mandate_data: nil,
  off_session: nil,
  payment_details: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  radar_options: nil,
  receipt_email: nil,
  return_url: nil,
  setup_future_usage: nil,
  shipping: nil,
  use_stripe_sdk: nil
)
  @allowed_payment_method_types = allowed_payment_method_types
  @amount_details = amount_details
  @amount_to_confirm = amount_to_confirm
  @capture_method = capture_method
  @confirmation_token = confirmation_token
  @error_on_requires_action = error_on_requires_action
  @excluded_payment_method_types = excluded_payment_method_types
  @expand = expand
  @hooks = hooks
  @mandate = mandate
  @mandate_data = mandate_data
  @off_session = off_session
  @payment_details = payment_details
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @radar_options = radar_options
  @receipt_email = receipt_email
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shipping = shipping
  @use_stripe_sdk = use_stripe_sdk
end

Instance Attribute Details

#allowed_payment_method_typesObject

The list of payment method types allowed for use with this payment. Stripe automatically returns compatible payment methods from this list in the payment_method_types field of the response, based on the other PaymentIntent parameters, such as currency, amount, and customer.



2792
2793
2794
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2792

def allowed_payment_method_types
  @allowed_payment_method_types
end

#amount_detailsObject

Provides industry-specific information about the amount.



2794
2795
2796
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2794

def amount_details
  @amount_details
end

#amount_to_confirmObject

Amount to confirm on the PaymentIntent. Defaults to amount if not provided.



2796
2797
2798
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2796

def amount_to_confirm
  @amount_to_confirm
end

#capture_methodObject

Controls when the funds will be captured from the customer's account.



2798
2799
2800
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2798

def capture_method
  @capture_method
end

#confirmation_tokenObject

ID of the ConfirmationToken used to confirm this PaymentIntent.

If the provided ConfirmationToken contains properties that are also being provided in this request, such as payment_method, then the values in this request will take precedence.



2802
2803
2804
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2802

def confirmation_token
  @confirmation_token
end

#error_on_requires_actionObject

Set to true to fail the payment attempt if the PaymentIntent transitions into requires_action. This parameter is intended for simpler integrations that do not handle customer actions, like saving cards without authentication.



2804
2805
2806
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2804

def error_on_requires_action
  @error_on_requires_action
end

#excluded_payment_method_typesObject

The list of payment method types to exclude from use with this payment.



2806
2807
2808
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2806

def excluded_payment_method_types
  @excluded_payment_method_types
end

#expandObject

Specifies which fields in the response should be expanded.



2808
2809
2810
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2808

def expand
  @expand
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



2810
2811
2812
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2810

def hooks
  @hooks
end

#mandateObject

ID of the mandate that's used for this payment.



2812
2813
2814
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2812

def mandate
  @mandate
end

#mandate_dataObject

Attribute for param field mandate_data



2814
2815
2816
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2814

def mandate_data
  @mandate_data
end

#off_sessionObject

Set to true to indicate that the customer isn't in your checkout flow during this payment attempt and can't authenticate. Use this parameter in scenarios where you collect payment method details and charge them later.



2816
2817
2818
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2816

def off_session
  @off_session
end

#payment_detailsObject

Provides industry-specific information about the charge.



2818
2819
2820
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2818

def payment_details
  @payment_details
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or compatible Source object) to attach to this PaymentIntent. If the payment method is attached to a Customer, it must match the customer that is set on this PaymentIntent.



2821
2822
2823
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2821

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the payment_method property on the PaymentIntent.



2825
2826
2827
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2825

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this PaymentIntent.



2827
2828
2829
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2827

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, a card) that this PaymentIntent can use. If you don't provide this, Stripe will dynamically show relevant payment methods from your payment method settings. A list of valid payment method types can be found here.



2829
2830
2831
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2829

def payment_method_types
  @payment_method_types
end

#radar_optionsObject

Options to configure Radar. Learn more about Radar Sessions.



2831
2832
2833
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2831

def radar_options
  @radar_options
end

#receipt_emailObject

Email address that the receipt for the resulting payment will be sent to. If receipt_email is specified for a payment in live mode, a receipt will be sent regardless of your email settings.



2833
2834
2835
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2833

def receipt_email
  @receipt_email
end

#return_urlObject

The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method's app or site. If you'd prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.



2837
2838
2839
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2837

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.

If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.



2847
2848
2849
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2847

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this PaymentIntent.



2849
2850
2851
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2849

def shipping
  @shipping
end

#use_stripe_sdkObject

Set to true when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.



2851
2852
2853
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2851

def use_stripe_sdk
  @use_stripe_sdk
end