Class: Stripe::PaymentIntentConfirmParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: AllocatedFunds, AmountDetails, Hooks, MandateData, PaymentDetails, PaymentMethodData, PaymentMethodOptions, RadarOptions, Shipping
Instance Attribute Summary collapse
-
#allocated_funds ⇒ Object
Allocated Funds configuration for this PaymentIntent.
-
#amount_details ⇒ Object
Provides industry-specific information about the amount.
-
#amount_to_confirm ⇒ Object
Amount to confirm on the PaymentIntent.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
-
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this PaymentIntent.
-
#error_on_requires_action ⇒ Object
Set to ‘true` to fail the payment attempt if the PaymentIntent transitions into `requires_action`.
-
#excluded_payment_method_types ⇒ Object
The list of payment method types to exclude from use with this payment.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fx_quote ⇒ Object
The FX rate in the quote is validated and used to convert the presentment amount to the settlement amount.
-
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle.
-
#mandate ⇒ Object
ID of the mandate that’s used for this payment.
-
#mandate_data ⇒ Object
Attribute for param field mandate_data.
-
#off_session ⇒ Object
Set to ‘true` to indicate that the customer isn’t in your checkout flow during this payment attempt and can’t authenticate.
-
#payment_details ⇒ Object
Provides industry-specific information about the charge.
-
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or [compatible Source](docs.stripe.com/payments/payment-methods/transitioning#compatibility) object) to attach to this PaymentIntent.
-
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod.
-
#payment_method_options ⇒ Object
Payment method-specific configuration for this PaymentIntent.
-
#payment_method_types ⇒ Object
The list of payment method types (for example, a card) that this PaymentIntent can use.
-
#radar_options ⇒ Object
Options to configure Radar.
-
#receipt_email ⇒ Object
Email address that the receipt for the resulting payment will be sent to.
-
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#shipping ⇒ Object
Shipping information for this PaymentIntent.
-
#use_stripe_sdk ⇒ Object
Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(allocated_funds: nil, amount_details: nil, amount_to_confirm: nil, application_fee_amount: nil, capture_method: nil, confirmation_token: nil, error_on_requires_action: nil, excluded_payment_method_types: nil, expand: nil, fx_quote: nil, hooks: nil, mandate: nil, mandate_data: nil, off_session: nil, payment_details: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shipping: nil, use_stripe_sdk: nil) ⇒ PaymentIntentConfirmParams
Returns a new instance of PaymentIntentConfirmParams.
6235 6236 6237 6238 6239 6240 6241 6242 6243 6244 6245 6246 6247 6248 6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 6264 6265 6266 6267 6268 6269 6270 6271 6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 6286 6287 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6235 def initialize( allocated_funds: nil, amount_details: nil, amount_to_confirm: nil, application_fee_amount: nil, capture_method: nil, confirmation_token: nil, error_on_requires_action: nil, excluded_payment_method_types: nil, expand: nil, fx_quote: nil, hooks: nil, mandate: nil, mandate_data: nil, off_session: nil, payment_details: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shipping: nil, use_stripe_sdk: nil ) @allocated_funds = allocated_funds @amount_details = amount_details @amount_to_confirm = amount_to_confirm @application_fee_amount = application_fee_amount @capture_method = capture_method @confirmation_token = confirmation_token @error_on_requires_action = error_on_requires_action @excluded_payment_method_types = excluded_payment_method_types @expand = @fx_quote = fx_quote @hooks = hooks @mandate = mandate @mandate_data = mandate_data @off_session = off_session @payment_details = payment_details @payment_method = payment_method @payment_method_data = payment_method_data @payment_method_options = @payment_method_types = payment_method_types @radar_options = @receipt_email = receipt_email @return_url = return_url @setup_future_usage = setup_future_usage @shipping = shipping @use_stripe_sdk = use_stripe_sdk end |
Instance Attribute Details
#allocated_funds ⇒ Object
Allocated Funds configuration for this PaymentIntent.
6170 6171 6172 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6170 def allocated_funds @allocated_funds end |
#amount_details ⇒ Object
Provides industry-specific information about the amount.
6172 6173 6174 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6172 def amount_details @amount_details end |
#amount_to_confirm ⇒ Object
Amount to confirm on the PaymentIntent. Defaults to ‘amount` if not provided.
6174 6175 6176 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6174 def amount_to_confirm @amount_to_confirm end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](docs.stripe.com/payments/connected-accounts).
6176 6177 6178 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6176 def application_fee_amount @application_fee_amount end |
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
6178 6179 6180 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6178 def capture_method @capture_method end |
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this PaymentIntent.
If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.
6182 6183 6184 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6182 def confirmation_token @confirmation_token end |
#error_on_requires_action ⇒ Object
Set to ‘true` to fail the payment attempt if the PaymentIntent transitions into `requires_action`. This parameter is intended for simpler integrations that do not handle customer actions, like [saving cards without authentication](docs.stripe.com/payments/save-card-without-authentication).
6184 6185 6186 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6184 def error_on_requires_action @error_on_requires_action end |
#excluded_payment_method_types ⇒ Object
The list of payment method types to exclude from use with this payment.
6186 6187 6188 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6186 def excluded_payment_method_types @excluded_payment_method_types end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
6188 6189 6190 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6188 def @expand end |
#fx_quote ⇒ Object
The FX rate in the quote is validated and used to convert the presentment amount to the settlement amount.
6190 6191 6192 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6190 def fx_quote @fx_quote end |
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle
6192 6193 6194 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6192 def hooks @hooks end |
#mandate ⇒ Object
ID of the mandate that’s used for this payment.
6194 6195 6196 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6194 def mandate @mandate end |
#mandate_data ⇒ Object
Attribute for param field mandate_data
6196 6197 6198 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6196 def mandate_data @mandate_data end |
#off_session ⇒ Object
Set to ‘true` to indicate that the customer isn’t in your checkout flow during this payment attempt and can’t authenticate. Use this parameter in scenarios where you collect card details and [charge them later](docs.stripe.com/payments/cards/charging-saved-cards).
6198 6199 6200 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6198 def off_session @off_session end |
#payment_details ⇒ Object
Provides industry-specific information about the charge.
6200 6201 6202 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6200 def payment_details @payment_details end |
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or [compatible Source](docs.stripe.com/payments/payment-methods/transitioning#compatibility) object) to attach to this PaymentIntent. If the payment method is attached to a Customer, it must match the [customer](api.stripe.com#create_payment_intent-customer) that is set on this PaymentIntent.
6203 6204 6205 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6203 def payment_method @payment_method end |
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the [payment_method](docs.stripe.com/api/payment_intents/object#payment_intent_object-payment_method) property on the PaymentIntent.
6207 6208 6209 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6207 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment method-specific configuration for this PaymentIntent.
6209 6210 6211 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6209 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types (for example, a card) that this PaymentIntent can use. Use ‘automatic_payment_methods` to manage payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).
6211 6212 6213 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6211 def payment_method_types @payment_method_types end |
#radar_options ⇒ Object
Options to configure Radar. Learn more about [Radar Sessions](docs.stripe.com/radar/radar-session).
6213 6214 6215 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6213 def @radar_options end |
#receipt_email ⇒ Object
Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).
6215 6216 6217 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6215 def receipt_email @receipt_email end |
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.
6219 6220 6221 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6219 def return_url @return_url end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.
6229 6230 6231 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6229 def setup_future_usage @setup_future_usage end |
#shipping ⇒ Object
Shipping information for this PaymentIntent.
6231 6232 6233 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6231 def shipping @shipping end |
#use_stripe_sdk ⇒ Object
Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
6233 6234 6235 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6233 def use_stripe_sdk @use_stripe_sdk end |