Class: Stripe::PaymentIntentConfirmParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: AllocatedFunds, AmountDetails, Hooks, MandateData, PaymentDetails, PaymentMethodData, PaymentMethodOptions, RadarOptions, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(allocated_funds: nil, amount_details: nil, application_fee_amount: nil, capture_method: nil, confirmation_token: nil, error_on_requires_action: nil, excluded_payment_method_types: nil, expand: nil, fx_quote: nil, hooks: nil, mandate: nil, mandate_data: nil, off_session: nil, payment_details: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shared_payment_granted_token: nil, shipping: nil, use_stripe_sdk: nil) ⇒ PaymentIntentConfirmParams

Returns a new instance of PaymentIntentConfirmParams.



5812
5813
5814
5815
5816
5817
5818
5819
5820
5821
5822
5823
5824
5825
5826
5827
5828
5829
5830
5831
5832
5833
5834
5835
5836
5837
5838
5839
5840
5841
5842
5843
5844
5845
5846
5847
5848
5849
5850
5851
5852
5853
5854
5855
5856
5857
5858
5859
5860
5861
5862
5863
5864
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5812

def initialize(
  allocated_funds: nil,
  amount_details: nil,
  application_fee_amount: nil,
  capture_method: nil,
  confirmation_token: nil,
  error_on_requires_action: nil,
  excluded_payment_method_types: nil,
  expand: nil,
  fx_quote: nil,
  hooks: nil,
  mandate: nil,
  mandate_data: nil,
  off_session: nil,
  payment_details: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  radar_options: nil,
  receipt_email: nil,
  return_url: nil,
  setup_future_usage: nil,
  shared_payment_granted_token: nil,
  shipping: nil,
  use_stripe_sdk: nil
)
  @allocated_funds = allocated_funds
  @amount_details = amount_details
  @application_fee_amount = application_fee_amount
  @capture_method = capture_method
  @confirmation_token = confirmation_token
  @error_on_requires_action = error_on_requires_action
  @excluded_payment_method_types = excluded_payment_method_types
  @expand = expand
  @fx_quote = fx_quote
  @hooks = hooks
  @mandate = mandate
  @mandate_data = mandate_data
  @off_session = off_session
  @payment_details = payment_details
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @radar_options = radar_options
  @receipt_email = receipt_email
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shared_payment_granted_token = shared_payment_granted_token
  @shipping = shipping
  @use_stripe_sdk = use_stripe_sdk
end

Instance Attribute Details

#allocated_fundsObject

Allocated Funds configuration for this PaymentIntent.



5747
5748
5749
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5747

def allocated_funds
  @allocated_funds
end

#amount_detailsObject

Provides industry-specific information about the amount.



5749
5750
5751
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5749

def amount_details
  @amount_details
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](docs.stripe.com/payments/connected-accounts).



5751
5752
5753
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5751

def application_fee_amount
  @application_fee_amount
end

#capture_methodObject

Controls when the funds will be captured from the customer’s account.



5753
5754
5755
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5753

def capture_method
  @capture_method
end

#confirmation_tokenObject

ID of the ConfirmationToken used to confirm this PaymentIntent.

If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.



5757
5758
5759
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5757

def confirmation_token
  @confirmation_token
end

#error_on_requires_actionObject

Set to ‘true` to fail the payment attempt if the PaymentIntent transitions into `requires_action`. This parameter is intended for simpler integrations that do not handle customer actions, like [saving cards without authentication](docs.stripe.com/payments/save-card-without-authentication).



5759
5760
5761
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5759

def error_on_requires_action
  @error_on_requires_action
end

#excluded_payment_method_typesObject

The list of payment method types to exclude from use with this payment.



5761
5762
5763
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5761

def excluded_payment_method_types
  @excluded_payment_method_types
end

#expandObject

Specifies which fields in the response should be expanded.



5763
5764
5765
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5763

def expand
  @expand
end

#fx_quoteObject

The FX rate in the quote is validated and used to convert the presentment amount to the settlement amount.



5765
5766
5767
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5765

def fx_quote
  @fx_quote
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



5767
5768
5769
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5767

def hooks
  @hooks
end

#mandateObject

ID of the mandate that’s used for this payment.



5769
5770
5771
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5769

def mandate
  @mandate
end

#mandate_dataObject

Attribute for param field mandate_data



5771
5772
5773
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5771

def mandate_data
  @mandate_data
end

#off_sessionObject

Set to ‘true` to indicate that the customer isn’t in your checkout flow during this payment attempt and can’t authenticate. Use this parameter in scenarios where you collect card details and [charge them later](docs.stripe.com/payments/cards/charging-saved-cards).



5773
5774
5775
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5773

def off_session
  @off_session
end

#payment_detailsObject

Provides industry-specific information about the charge.



5775
5776
5777
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5775

def payment_details
  @payment_details
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or [compatible Source](docs.stripe.com/payments/payment-methods/transitioning#compatibility) object) to attach to this PaymentIntent. If the payment method is attached to a Customer, it must match the [customer](api.stripe.com#create_payment_intent-customer) that is set on this PaymentIntent.



5778
5779
5780
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5778

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the [payment_method](docs.stripe.com/api/payment_intents/object#payment_intent_object-payment_method) property on the PaymentIntent.



5782
5783
5784
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5782

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this PaymentIntent.



5784
5785
5786
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5784

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, a card) that this PaymentIntent can use. Use ‘automatic_payment_methods` to manage payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).



5786
5787
5788
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5786

def payment_method_types
  @payment_method_types
end

#radar_optionsObject

Options to configure Radar. Learn more about [Radar Sessions](docs.stripe.com/radar/radar-session).



5788
5789
5790
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5788

def radar_options
  @radar_options
end

#receipt_emailObject

Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).



5790
5791
5792
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5790

def receipt_email
  @receipt_email
end

#return_urlObject

The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.



5794
5795
5796
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5794

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



5804
5805
5806
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5804

def setup_future_usage
  @setup_future_usage
end

#shared_payment_granted_tokenObject

ID of the SharedPaymentToken used to confirm this PaymentIntent.



5806
5807
5808
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5806

def shared_payment_granted_token
  @shared_payment_granted_token
end

#shippingObject

Shipping information for this PaymentIntent.



5808
5809
5810
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5808

def shipping
  @shipping
end

#use_stripe_sdkObject

Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.



5810
5811
5812
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5810

def use_stripe_sdk
  @use_stripe_sdk
end