Class: Stripe::PaymentIntentConfirmParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: AmountDetails, Hooks, MandateData, PaymentDetails, PaymentMethodData, PaymentMethodOptions, RadarOptions, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount_details: nil, capture_method: nil, confirmation_token: nil, error_on_requires_action: nil, excluded_payment_method_types: nil, expand: nil, hooks: nil, mandate: nil, mandate_data: nil, off_session: nil, payment_details: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shipping: nil, use_stripe_sdk: nil) ⇒ PaymentIntentConfirmParams

Returns a new instance of PaymentIntentConfirmParams.



2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2715

def initialize(
  amount_details: nil,
  capture_method: nil,
  confirmation_token: nil,
  error_on_requires_action: nil,
  excluded_payment_method_types: nil,
  expand: nil,
  hooks: nil,
  mandate: nil,
  mandate_data: nil,
  off_session: nil,
  payment_details: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  radar_options: nil,
  receipt_email: nil,
  return_url: nil,
  setup_future_usage: nil,
  shipping: nil,
  use_stripe_sdk: nil
)
  @amount_details = amount_details
  @capture_method = capture_method
  @confirmation_token = confirmation_token
  @error_on_requires_action = error_on_requires_action
  @excluded_payment_method_types = excluded_payment_method_types
  @expand = expand
  @hooks = hooks
  @mandate = mandate
  @mandate_data = mandate_data
  @off_session = off_session
  @payment_details = payment_details
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @radar_options = radar_options
  @receipt_email = receipt_email
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shipping = shipping
  @use_stripe_sdk = use_stripe_sdk
end

Instance Attribute Details

#amount_detailsObject

Provides industry-specific information about the amount.



2658
2659
2660
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2658

def amount_details
  @amount_details
end

#capture_methodObject

Controls when the funds will be captured from the customer’s account.



2660
2661
2662
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2660

def capture_method
  @capture_method
end

#confirmation_tokenObject

ID of the ConfirmationToken used to confirm this PaymentIntent.

If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.



2664
2665
2666
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2664

def confirmation_token
  @confirmation_token
end

#error_on_requires_actionObject

Set to ‘true` to fail the payment attempt if the PaymentIntent transitions into `requires_action`. This parameter is intended for simpler integrations that do not handle customer actions, like [saving cards without authentication](docs.stripe.com/payments/save-card-without-authentication).



2666
2667
2668
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2666

def error_on_requires_action
  @error_on_requires_action
end

#excluded_payment_method_typesObject

The list of payment method types to exclude from use with this payment.



2668
2669
2670
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2668

def excluded_payment_method_types
  @excluded_payment_method_types
end

#expandObject

Specifies which fields in the response should be expanded.



2670
2671
2672
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2670

def expand
  @expand
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



2672
2673
2674
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2672

def hooks
  @hooks
end

#mandateObject

ID of the mandate that’s used for this payment.



2674
2675
2676
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2674

def mandate
  @mandate
end

#mandate_dataObject

Attribute for param field mandate_data



2676
2677
2678
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2676

def mandate_data
  @mandate_data
end

#off_sessionObject

Set to ‘true` to indicate that the customer isn’t in your checkout flow during this payment attempt and can’t authenticate. Use this parameter in scenarios where you collect card details and [charge them later](docs.stripe.com/payments/cards/charging-saved-cards).



2678
2679
2680
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2678

def off_session
  @off_session
end

#payment_detailsObject

Provides industry-specific information about the charge.



2680
2681
2682
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2680

def payment_details
  @payment_details
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or [compatible Source](docs.stripe.com/payments/payment-methods/transitioning#compatibility) object) to attach to this PaymentIntent. If the payment method is attached to a Customer, it must match the [customer](api.stripe.com#create_payment_intent-customer) that is set on this PaymentIntent.



2683
2684
2685
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2683

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the [payment_method](docs.stripe.com/api/payment_intents/object#payment_intent_object-payment_method) property on the PaymentIntent.



2687
2688
2689
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2687

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this PaymentIntent.



2689
2690
2691
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2689

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, a card) that this PaymentIntent can use. Use ‘automatic_payment_methods` to manage payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).



2691
2692
2693
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2691

def payment_method_types
  @payment_method_types
end

#radar_optionsObject

Options to configure Radar. Learn more about [Radar Sessions](docs.stripe.com/radar/radar-session).



2693
2694
2695
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2693

def radar_options
  @radar_options
end

#receipt_emailObject

Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).



2695
2696
2697
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2695

def receipt_email
  @receipt_email
end

#return_urlObject

The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.



2699
2700
2701
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2699

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



2709
2710
2711
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2709

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this PaymentIntent.



2711
2712
2713
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2711

def shipping
  @shipping
end

#use_stripe_sdkObject

Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.



2713
2714
2715
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2713

def use_stripe_sdk
  @use_stripe_sdk
end