Class: Stripe::PaymentIntentConfirmParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: AllocatedFunds, AmountDetails, Hooks, MandateData, PaymentDetails, PaymentMethodData, PaymentMethodOptions, RadarOptions, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(allocated_funds: nil, amount_details: nil, application_fee_amount: nil, capture_method: nil, confirmation_token: nil, error_on_requires_action: nil, excluded_payment_method_types: nil, expand: nil, fx_quote: nil, hooks: nil, mandate: nil, mandate_data: nil, off_session: nil, payment_details: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shared_payment_granted_token: nil, shipping: nil, use_stripe_sdk: nil) ⇒ PaymentIntentConfirmParams

Returns a new instance of PaymentIntentConfirmParams.



5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
5688
5689
5690
5691
5692
5693
5694
5695
5696
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5644

def initialize(
  allocated_funds: nil,
  amount_details: nil,
  application_fee_amount: nil,
  capture_method: nil,
  confirmation_token: nil,
  error_on_requires_action: nil,
  excluded_payment_method_types: nil,
  expand: nil,
  fx_quote: nil,
  hooks: nil,
  mandate: nil,
  mandate_data: nil,
  off_session: nil,
  payment_details: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  radar_options: nil,
  receipt_email: nil,
  return_url: nil,
  setup_future_usage: nil,
  shared_payment_granted_token: nil,
  shipping: nil,
  use_stripe_sdk: nil
)
  @allocated_funds = allocated_funds
  @amount_details = amount_details
  @application_fee_amount = application_fee_amount
  @capture_method = capture_method
  @confirmation_token = confirmation_token
  @error_on_requires_action = error_on_requires_action
  @excluded_payment_method_types = excluded_payment_method_types
  @expand = expand
  @fx_quote = fx_quote
  @hooks = hooks
  @mandate = mandate
  @mandate_data = mandate_data
  @off_session = off_session
  @payment_details = payment_details
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @radar_options = radar_options
  @receipt_email = receipt_email
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shared_payment_granted_token = shared_payment_granted_token
  @shipping = shipping
  @use_stripe_sdk = use_stripe_sdk
end

Instance Attribute Details

#allocated_fundsObject

Allocated Funds configuration for this PaymentIntent.



5579
5580
5581
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5579

def allocated_funds
  @allocated_funds
end

#amount_detailsObject

Provides industry-specific information about the amount.



5581
5582
5583
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5581

def amount_details
  @amount_details
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](docs.stripe.com/payments/connected-accounts).



5583
5584
5585
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5583

def application_fee_amount
  @application_fee_amount
end

#capture_methodObject

Controls when the funds will be captured from the customer’s account.



5585
5586
5587
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5585

def capture_method
  @capture_method
end

#confirmation_tokenObject

ID of the ConfirmationToken used to confirm this PaymentIntent.

If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.



5589
5590
5591
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5589

def confirmation_token
  @confirmation_token
end

#error_on_requires_actionObject

Set to ‘true` to fail the payment attempt if the PaymentIntent transitions into `requires_action`. This parameter is intended for simpler integrations that do not handle customer actions, like [saving cards without authentication](docs.stripe.com/payments/save-card-without-authentication).



5591
5592
5593
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5591

def error_on_requires_action
  @error_on_requires_action
end

#excluded_payment_method_typesObject

The list of payment method types to exclude from use with this payment.



5593
5594
5595
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5593

def excluded_payment_method_types
  @excluded_payment_method_types
end

#expandObject

Specifies which fields in the response should be expanded.



5595
5596
5597
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5595

def expand
  @expand
end

#fx_quoteObject

The FX rate in the quote is validated and used to convert the presentment amount to the settlement amount.



5597
5598
5599
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5597

def fx_quote
  @fx_quote
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



5599
5600
5601
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5599

def hooks
  @hooks
end

#mandateObject

ID of the mandate that’s used for this payment.



5601
5602
5603
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5601

def mandate
  @mandate
end

#mandate_dataObject

Attribute for param field mandate_data



5603
5604
5605
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5603

def mandate_data
  @mandate_data
end

#off_sessionObject

Set to ‘true` to indicate that the customer isn’t in your checkout flow during this payment attempt and can’t authenticate. Use this parameter in scenarios where you collect card details and [charge them later](docs.stripe.com/payments/cards/charging-saved-cards).



5605
5606
5607
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5605

def off_session
  @off_session
end

#payment_detailsObject

Provides industry-specific information about the charge.



5607
5608
5609
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5607

def payment_details
  @payment_details
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or [compatible Source](docs.stripe.com/payments/payment-methods/transitioning#compatibility) object) to attach to this PaymentIntent. If the payment method is attached to a Customer, it must match the [customer](api.stripe.com#create_payment_intent-customer) that is set on this PaymentIntent.



5610
5611
5612
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5610

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the [payment_method](docs.stripe.com/api/payment_intents/object#payment_intent_object-payment_method) property on the PaymentIntent.



5614
5615
5616
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5614

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this PaymentIntent.



5616
5617
5618
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5616

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, a card) that this PaymentIntent can use. Use ‘automatic_payment_methods` to manage payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).



5618
5619
5620
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5618

def payment_method_types
  @payment_method_types
end

#radar_optionsObject

Options to configure Radar. Learn more about [Radar Sessions](docs.stripe.com/radar/radar-session).



5620
5621
5622
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5620

def radar_options
  @radar_options
end

#receipt_emailObject

Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).



5622
5623
5624
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5622

def receipt_email
  @receipt_email
end

#return_urlObject

The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.



5626
5627
5628
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5626

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



5636
5637
5638
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5636

def setup_future_usage
  @setup_future_usage
end

#shared_payment_granted_tokenObject

ID of the SharedPaymentToken used to confirm this PaymentIntent.



5638
5639
5640
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5638

def shared_payment_granted_token
  @shared_payment_granted_token
end

#shippingObject

Shipping information for this PaymentIntent.



5640
5641
5642
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5640

def shipping
  @shipping
end

#use_stripe_sdkObject

Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.



5642
5643
5644
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5642

def use_stripe_sdk
  @use_stripe_sdk
end