Class: Stripe::PaymentIntentConfirmParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: AmountDetails, Hooks, MandateData, PaymentDetails, PaymentMethodData, PaymentMethodOptions, RadarOptions, Shipping
Instance Attribute Summary collapse
-
#amount_details ⇒ Object
Provides industry-specific information about the amount.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
-
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this PaymentIntent.
-
#error_on_requires_action ⇒ Object
Set to ‘true` to fail the payment attempt if the PaymentIntent transitions into `requires_action`.
-
#excluded_payment_method_types ⇒ Object
The list of payment method types to exclude from use with this payment.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fx_quote ⇒ Object
The FX rate in the quote is validated and used to convert the presentment amount to the settlement amount.
-
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle.
-
#mandate ⇒ Object
ID of the mandate that’s used for this payment.
-
#mandate_data ⇒ Object
Attribute for param field mandate_data.
-
#off_session ⇒ Object
Set to ‘true` to indicate that the customer isn’t in your checkout flow during this payment attempt and can’t authenticate.
-
#payment_details ⇒ Object
Provides industry-specific information about the charge.
-
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or [compatible Source](docs.stripe.com/payments/payment-methods/transitioning#compatibility) object) to attach to this PaymentIntent.
-
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod.
-
#payment_method_options ⇒ Object
Payment method-specific configuration for this PaymentIntent.
-
#payment_method_types ⇒ Object
The list of payment method types (for example, a card) that this PaymentIntent can use.
-
#radar_options ⇒ Object
Options to configure Radar.
-
#receipt_email ⇒ Object
Email address that the receipt for the resulting payment will be sent to.
-
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#shipping ⇒ Object
Shipping information for this PaymentIntent.
-
#use_stripe_sdk ⇒ Object
Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(amount_details: nil, application_fee_amount: nil, capture_method: nil, confirmation_token: nil, error_on_requires_action: nil, excluded_payment_method_types: nil, expand: nil, fx_quote: nil, hooks: nil, mandate: nil, mandate_data: nil, off_session: nil, payment_details: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shipping: nil, use_stripe_sdk: nil) ⇒ PaymentIntentConfirmParams
Returns a new instance of PaymentIntentConfirmParams.
5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 5654 5655 5656 5657 5658 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5610 def initialize( amount_details: nil, application_fee_amount: nil, capture_method: nil, confirmation_token: nil, error_on_requires_action: nil, excluded_payment_method_types: nil, expand: nil, fx_quote: nil, hooks: nil, mandate: nil, mandate_data: nil, off_session: nil, payment_details: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shipping: nil, use_stripe_sdk: nil ) @amount_details = amount_details @application_fee_amount = application_fee_amount @capture_method = capture_method @confirmation_token = confirmation_token @error_on_requires_action = error_on_requires_action @excluded_payment_method_types = excluded_payment_method_types @expand = @fx_quote = fx_quote @hooks = hooks @mandate = mandate @mandate_data = mandate_data @off_session = off_session @payment_details = payment_details @payment_method = payment_method @payment_method_data = payment_method_data @payment_method_options = @payment_method_types = payment_method_types @radar_options = @receipt_email = receipt_email @return_url = return_url @setup_future_usage = setup_future_usage @shipping = shipping @use_stripe_sdk = use_stripe_sdk end |
Instance Attribute Details
#amount_details ⇒ Object
Provides industry-specific information about the amount.
5549 5550 5551 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5549 def amount_details @amount_details end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](docs.stripe.com/payments/connected-accounts).
5551 5552 5553 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5551 def application_fee_amount @application_fee_amount end |
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
5553 5554 5555 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5553 def capture_method @capture_method end |
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this PaymentIntent.
If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.
5557 5558 5559 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5557 def confirmation_token @confirmation_token end |
#error_on_requires_action ⇒ Object
Set to ‘true` to fail the payment attempt if the PaymentIntent transitions into `requires_action`. This parameter is intended for simpler integrations that do not handle customer actions, like [saving cards without authentication](docs.stripe.com/payments/save-card-without-authentication).
5559 5560 5561 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5559 def error_on_requires_action @error_on_requires_action end |
#excluded_payment_method_types ⇒ Object
The list of payment method types to exclude from use with this payment.
5561 5562 5563 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5561 def excluded_payment_method_types @excluded_payment_method_types end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
5563 5564 5565 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5563 def @expand end |
#fx_quote ⇒ Object
The FX rate in the quote is validated and used to convert the presentment amount to the settlement amount.
5565 5566 5567 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5565 def fx_quote @fx_quote end |
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle
5567 5568 5569 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5567 def hooks @hooks end |
#mandate ⇒ Object
ID of the mandate that’s used for this payment.
5569 5570 5571 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5569 def mandate @mandate end |
#mandate_data ⇒ Object
Attribute for param field mandate_data
5571 5572 5573 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5571 def mandate_data @mandate_data end |
#off_session ⇒ Object
Set to ‘true` to indicate that the customer isn’t in your checkout flow during this payment attempt and can’t authenticate. Use this parameter in scenarios where you collect card details and [charge them later](docs.stripe.com/payments/cards/charging-saved-cards).
5573 5574 5575 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5573 def off_session @off_session end |
#payment_details ⇒ Object
Provides industry-specific information about the charge.
5575 5576 5577 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5575 def payment_details @payment_details end |
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or [compatible Source](docs.stripe.com/payments/payment-methods/transitioning#compatibility) object) to attach to this PaymentIntent. If the payment method is attached to a Customer, it must match the [customer](api.stripe.com#create_payment_intent-customer) that is set on this PaymentIntent.
5578 5579 5580 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5578 def payment_method @payment_method end |
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the [payment_method](docs.stripe.com/api/payment_intents/object#payment_intent_object-payment_method) property on the PaymentIntent.
5582 5583 5584 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5582 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment method-specific configuration for this PaymentIntent.
5584 5585 5586 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5584 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types (for example, a card) that this PaymentIntent can use. Use ‘automatic_payment_methods` to manage payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).
5586 5587 5588 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5586 def payment_method_types @payment_method_types end |
#radar_options ⇒ Object
Options to configure Radar. Learn more about [Radar Sessions](docs.stripe.com/radar/radar-session).
5588 5589 5590 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5588 def @radar_options end |
#receipt_email ⇒ Object
Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).
5590 5591 5592 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5590 def receipt_email @receipt_email end |
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.
5594 5595 5596 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5594 def return_url @return_url end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.
5604 5605 5606 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5604 def setup_future_usage @setup_future_usage end |
#shipping ⇒ Object
Shipping information for this PaymentIntent.
5606 5607 5608 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5606 def shipping @shipping end |
#use_stripe_sdk ⇒ Object
Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
5608 5609 5610 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5608 def use_stripe_sdk @use_stripe_sdk end |