Class: Stripe::PaymentIntentConfirmParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: AmountDetails, Hooks, MandateData, PaymentDetails, PaymentMethodData, PaymentMethodOptions, RadarOptions, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_details: nil, application_fee_amount: nil, capture_method: nil, confirmation_token: nil, error_on_requires_action: nil, excluded_payment_method_types: nil, expand: nil, fx_quote: nil, hooks: nil, mandate: nil, mandate_data: nil, off_session: nil, payment_details: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shipping: nil, use_stripe_sdk: nil) ⇒ PaymentIntentConfirmParams

Returns a new instance of PaymentIntentConfirmParams.



3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
3741
3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3716

def initialize(
  amount_details: nil,
  application_fee_amount: nil,
  capture_method: nil,
  confirmation_token: nil,
  error_on_requires_action: nil,
  excluded_payment_method_types: nil,
  expand: nil,
  fx_quote: nil,
  hooks: nil,
  mandate: nil,
  mandate_data: nil,
  off_session: nil,
  payment_details: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  radar_options: nil,
  receipt_email: nil,
  return_url: nil,
  setup_future_usage: nil,
  shipping: nil,
  use_stripe_sdk: nil
)
  @amount_details = amount_details
  @application_fee_amount = application_fee_amount
  @capture_method = capture_method
  @confirmation_token = confirmation_token
  @error_on_requires_action = error_on_requires_action
  @excluded_payment_method_types = excluded_payment_method_types
  @expand = expand
  @fx_quote = fx_quote
  @hooks = hooks
  @mandate = mandate
  @mandate_data = mandate_data
  @off_session = off_session
  @payment_details = payment_details
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @radar_options = radar_options
  @receipt_email = receipt_email
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shipping = shipping
  @use_stripe_sdk = use_stripe_sdk
end

Instance Attribute Details

#amount_detailsObject

Provides industry-specific information about the amount.



3655
3656
3657
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3655

def amount_details
  @amount_details
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



3657
3658
3659
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3657

def application_fee_amount
  @application_fee_amount
end

#capture_methodObject

Controls when the funds will be captured from the customer’s account.



3659
3660
3661
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3659

def capture_method
  @capture_method
end

#confirmation_tokenObject

ID of the ConfirmationToken used to confirm this PaymentIntent.

If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.



3663
3664
3665
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3663

def confirmation_token
  @confirmation_token
end

#error_on_requires_actionObject

Set to ‘true` to fail the payment attempt if the PaymentIntent transitions into `requires_action`. This parameter is intended for simpler integrations that do not handle customer actions, like [saving cards without authentication](stripe.com/docs/payments/save-card-without-authentication).



3665
3666
3667
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3665

def error_on_requires_action
  @error_on_requires_action
end

#excluded_payment_method_typesObject

The list of payment method types to exclude from use with this payment.



3667
3668
3669
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3667

def excluded_payment_method_types
  @excluded_payment_method_types
end

#expandObject

Specifies which fields in the response should be expanded.



3669
3670
3671
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3669

def expand
  @expand
end

#fx_quoteObject

The FX rate in the quote is validated and used to convert the presentment amount to the settlement amount.



3671
3672
3673
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3671

def fx_quote
  @fx_quote
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



3673
3674
3675
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3673

def hooks
  @hooks
end

#mandateObject

ID of the mandate that’s used for this payment.



3675
3676
3677
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3675

def mandate
  @mandate
end

#mandate_dataObject

Attribute for param field mandate_data



3677
3678
3679
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3677

def mandate_data
  @mandate_data
end

#off_sessionObject

Set to ‘true` to indicate that the customer isn’t in your checkout flow during this payment attempt and can’t authenticate. Use this parameter in scenarios where you collect card details and [charge them later](stripe.com/docs/payments/cards/charging-saved-cards).



3679
3680
3681
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3679

def off_session
  @off_session
end

#payment_detailsObject

Provides industry-specific information about the charge.



3681
3682
3683
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3681

def payment_details
  @payment_details
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or [compatible Source](stripe.com/docs/payments/payment-methods/transitioning#compatibility) object) to attach to this PaymentIntent. If the payment method is attached to a Customer, it must match the [customer](stripe.com/docs/api#create_payment_intent-customer) that is set on this PaymentIntent.



3684
3685
3686
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3684

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the [payment_method](stripe.com/docs/api/payment_intents/object#payment_intent_object-payment_method) property on the PaymentIntent.



3688
3689
3690
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3688

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this PaymentIntent.



3690
3691
3692
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3690

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, a card) that this PaymentIntent can use. Use ‘automatic_payment_methods` to manage payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).



3692
3693
3694
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3692

def payment_method_types
  @payment_method_types
end

#radar_optionsObject

Options to configure Radar. Learn more about [Radar Sessions](stripe.com/docs/radar/radar-session).



3694
3695
3696
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3694

def radar_options
  @radar_options
end

#receipt_emailObject

Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).



3696
3697
3698
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3696

def receipt_email
  @receipt_email
end

#return_urlObject

The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.



3700
3701
3702
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3700

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



3710
3711
3712
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3710

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this PaymentIntent.



3712
3713
3714
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3712

def shipping
  @shipping
end

#use_stripe_sdkObject

Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.



3714
3715
3716
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3714

def use_stripe_sdk
  @use_stripe_sdk
end