Class: Stripe::PaymentIntentConfirmParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: AmountDetails, Hooks, MandateData, PaymentDetails, PaymentMethodData, PaymentMethodOptions, RadarOptions, Shipping
Instance Attribute Summary collapse
-
#allowed_payment_method_types ⇒ Object
The list of payment method types allowed for use with this payment.
-
#amount_details ⇒ Object
Provides industry-specific information about the amount.
-
#amount_to_confirm ⇒ Object
Amount to confirm on the PaymentIntent.
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer's account.
-
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this PaymentIntent.
-
#error_on_requires_action ⇒ Object
Set to
trueto fail the payment attempt if the PaymentIntent transitions intorequires_action. -
#excluded_payment_method_types ⇒ Object
The list of payment method types to exclude from use with this payment.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle.
-
#mandate ⇒ Object
ID of the mandate that's used for this payment.
-
#mandate_data ⇒ Object
Attribute for param field mandate_data.
-
#off_session ⇒ Object
Set to
trueto indicate that the customer isn't in your checkout flow during this payment attempt and can't authenticate. -
#payment_details ⇒ Object
Provides industry-specific information about the charge.
-
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or compatible Source object) to attach to this PaymentIntent.
-
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod.
-
#payment_method_options ⇒ Object
Payment method-specific configuration for this PaymentIntent.
-
#radar_options ⇒ Object
Options to configure Radar.
-
#receipt_email ⇒ Object
Email address that the receipt for the resulting payment will be sent to.
-
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method's app or site.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
-
#shipping ⇒ Object
Shipping information for this PaymentIntent.
-
#use_stripe_sdk ⇒ Object
Set to
truewhen confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(allowed_payment_method_types: nil, amount_details: nil, amount_to_confirm: nil, capture_method: nil, confirmation_token: nil, error_on_requires_action: nil, excluded_payment_method_types: nil, expand: nil, hooks: nil, mandate: nil, mandate_data: nil, off_session: nil, payment_details: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shipping: nil, use_stripe_sdk: nil) ⇒ PaymentIntentConfirmParams
Returns a new instance of PaymentIntentConfirmParams.
2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2969 def initialize( allowed_payment_method_types: nil, amount_details: nil, amount_to_confirm: nil, capture_method: nil, confirmation_token: nil, error_on_requires_action: nil, excluded_payment_method_types: nil, expand: nil, hooks: nil, mandate: nil, mandate_data: nil, off_session: nil, payment_details: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shipping: nil, use_stripe_sdk: nil ) @allowed_payment_method_types = allowed_payment_method_types @amount_details = amount_details @amount_to_confirm = amount_to_confirm @capture_method = capture_method @confirmation_token = confirmation_token @error_on_requires_action = error_on_requires_action @excluded_payment_method_types = excluded_payment_method_types @expand = @hooks = hooks @mandate = mandate @mandate_data = mandate_data @off_session = off_session @payment_details = payment_details @payment_method = payment_method @payment_method_data = payment_method_data @payment_method_options = @radar_options = @receipt_email = receipt_email @return_url = return_url @setup_future_usage = setup_future_usage @shipping = shipping @use_stripe_sdk = use_stripe_sdk end |
Instance Attribute Details
#allowed_payment_method_types ⇒ Object
The list of payment method types allowed for use with this payment. Stripe automatically returns compatible payment methods from this list in the payment_method_types field of the response, based on the other PaymentIntent parameters, such as currency, amount, and customer.
2910 2911 2912 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2910 def allowed_payment_method_types @allowed_payment_method_types end |
#amount_details ⇒ Object
Provides industry-specific information about the amount.
2912 2913 2914 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2912 def amount_details @amount_details end |
#amount_to_confirm ⇒ Object
Amount to confirm on the PaymentIntent. Defaults to amount if not provided.
2914 2915 2916 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2914 def amount_to_confirm @amount_to_confirm end |
#capture_method ⇒ Object
Controls when the funds will be captured from the customer's account.
2916 2917 2918 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2916 def capture_method @capture_method end |
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this PaymentIntent.
If the provided ConfirmationToken contains properties that are also being provided in this request, such as payment_method, then the values in this request will take precedence.
2920 2921 2922 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2920 def confirmation_token @confirmation_token end |
#error_on_requires_action ⇒ Object
Set to true to fail the payment attempt if the PaymentIntent transitions into requires_action. This parameter is intended for simpler integrations that do not handle customer actions, like saving cards without authentication.
2922 2923 2924 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2922 def error_on_requires_action @error_on_requires_action end |
#excluded_payment_method_types ⇒ Object
The list of payment method types to exclude from use with this payment.
2924 2925 2926 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2924 def excluded_payment_method_types @excluded_payment_method_types end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2926 2927 2928 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2926 def @expand end |
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle
2928 2929 2930 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2928 def hooks @hooks end |
#mandate ⇒ Object
ID of the mandate that's used for this payment.
2930 2931 2932 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2930 def mandate @mandate end |
#mandate_data ⇒ Object
Attribute for param field mandate_data
2932 2933 2934 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2932 def mandate_data @mandate_data end |
#off_session ⇒ Object
Set to true to indicate that the customer isn't in your checkout flow during this payment attempt and can't authenticate. Use this parameter in scenarios where you collect payment method details and charge them later.
2934 2935 2936 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2934 def off_session @off_session end |
#payment_details ⇒ Object
Provides industry-specific information about the charge.
2936 2937 2938 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2936 def payment_details @payment_details end |
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or compatible Source object) to attach to this PaymentIntent. If the payment method is attached to a Customer, it must match the customer that is set on this PaymentIntent.
2939 2940 2941 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2939 def payment_method @payment_method end |
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the payment_method property on the PaymentIntent.
2943 2944 2945 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2943 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment method-specific configuration for this PaymentIntent.
2945 2946 2947 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2945 def @payment_method_options end |
#radar_options ⇒ Object
Options to configure Radar. Learn more about Radar Sessions.
2947 2948 2949 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2947 def @radar_options end |
#receipt_email ⇒ Object
Email address that the receipt for the resulting payment will be sent to. If receipt_email is specified for a payment in live mode, a receipt will be sent regardless of your email settings.
2949 2950 2951 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2949 def receipt_email @receipt_email end |
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method's app or site. If you'd prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.
2953 2954 2955 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2953 def return_url @return_url end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.
2963 2964 2965 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2963 def setup_future_usage @setup_future_usage end |
#shipping ⇒ Object
Shipping information for this PaymentIntent.
2965 2966 2967 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2965 def shipping @shipping end |
#use_stripe_sdk ⇒ Object
Set to true when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
2967 2968 2969 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2967 def use_stripe_sdk @use_stripe_sdk end |