Class: Stripe::PaymentIntentConfirmParams::AmountDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: LineItem, Shipping, Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails

Returns a new instance of AmountDetails.



178
179
180
181
182
183
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 178

def initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil)
  @discount_amount = discount_amount
  @line_items = line_items
  @shipping = shipping
  @tax = tax
end

Instance Attribute Details

#discount_amountObject

The total discount applied on the transaction represented in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal). An integer greater than 0.

This field is mutually exclusive with the ‘amount_details[#][discount_amount]` field.



170
171
172
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 170

def discount_amount
  @discount_amount
end

#line_itemsObject

A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.



172
173
174
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 172

def line_items
  @line_items
end

#shippingObject

Contains information about the shipping portion of the amount.



174
175
176
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 174

def shipping
  @shipping
end

#taxObject

Contains information about the tax portion of the amount.



176
177
178
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 176

def tax
  @tax
end