Class: Stripe::PaymentIntentConfirmParams::MandateData::CustomerAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::MandateData::CustomerAcceptance
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#accepted_at ⇒ Object
The time at which the customer accepted the Mandate.
-
#offline ⇒ Object
If this is a Mandate accepted offline, this hash contains details about the offline acceptance.
-
#online ⇒ Object
If this is a Mandate accepted online, this hash contains details about the online acceptance.
-
#type ⇒ Object
The type of customer acceptance information included with the Mandate.
Instance Method Summary collapse
-
#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance
constructor
A new instance of CustomerAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance
Returns a new instance of CustomerAcceptance.
248 249 250 251 252 253 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 248 def initialize(accepted_at: nil, offline: nil, online: nil, type: nil) @accepted_at = accepted_at @offline = offline @online = online @type = type end |
Instance Attribute Details
#accepted_at ⇒ Object
The time at which the customer accepted the Mandate.
240 241 242 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 240 def accepted_at @accepted_at end |
#offline ⇒ Object
If this is a Mandate accepted offline, this hash contains details about the offline acceptance.
242 243 244 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 242 def offline @offline end |
#online ⇒ Object
If this is a Mandate accepted online, this hash contains details about the online acceptance.
244 245 246 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 244 def online @online end |
#type ⇒ Object
The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.
246 247 248 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 246 def type @type end |