Class: Stripe::PaymentIntentConfirmParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



216
217
218
219
220
221
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 216

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



208
209
210
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 208

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



210
211
212
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 210

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



212
213
214
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 212

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



214
215
216
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 214

def type
  @type
end