Class: Stripe::PaymentIntentConfirmParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



201
202
203
204
205
206
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 201

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



193
194
195
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 193

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



195
196
197
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 195

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



197
198
199
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 197

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



199
200
201
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 199

def type
  @type
end