Class: Stripe::PaymentIntentConfirmParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Benefit, CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(benefit: nil, car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 936

def initialize(
  benefit: nil,
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @benefit = benefit
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#benefitObject

Benefit details for this PaymentIntent



920
921
922
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 920

def benefit
  @benefit
end

#car_rentalObject

Car rental details for this PaymentIntent.



922
923
924
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 922

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



924
925
926
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 924

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



926
927
928
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 926

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



928
929
930
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 928

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



930
931
932
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 930

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



932
933
934
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 932

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



934
935
936
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 934

def subscription
  @subscription
end