Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental

Returns a new instance of CarRental.



488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 488

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  distance: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  pickup_location_name: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  return_location_name: nil,
  tax_exempt: nil,
  vehicle_identification_number: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @distance = distance
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @pickup_location_name = pickup_location_name
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @return_location_name = return_location_name
  @tax_exempt = tax_exempt
  @vehicle_identification_number = vehicle_identification_number
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



440
441
442
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 440

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



442
443
444
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 442

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



444
445
446
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 444

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



446
447
448
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 446

def car_make
  @car_make
end

#car_modelObject

Model of the car.



448
449
450
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 448

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



450
451
452
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 450

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



452
453
454
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 452

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



454
455
456
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 454

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



456
457
458
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 456

def delivery
  @delivery
end

#distanceObject

The details of the distance traveled during the rental period.



458
459
460
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 458

def distance
  @distance
end

#driversObject

The details of the passengers in the travel reservation



460
461
462
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 460

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



462
463
464
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 462

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



464
465
466
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 464

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



466
467
468
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 466

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



468
469
470
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 468

def pickup_at
  @pickup_at
end

#pickup_location_nameObject

Name of the pickup location.



470
471
472
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 470

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject

Rental rate.



472
473
474
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 472

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



474
475
476
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 474

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



476
477
478
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 476

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



478
479
480
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 478

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



480
481
482
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 480

def return_at
  @return_at
end

#return_location_nameObject

Name of the return location.



482
483
484
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 482

def return_location_name
  @return_location_name
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



484
485
486
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 484

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject

The vehicle identification number.



486
487
488
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 486

def vehicle_identification_number
  @vehicle_identification_number
end