Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#distance ⇒ Object
The details of the distance traveled during the rental period.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#pickup_location_name ⇒ Object
Name of the pickup location.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#return_location_name ⇒ Object
Name of the return location.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
The vehicle identification number.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental
Returns a new instance of CarRental.
441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 441 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @distance = distance @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @pickup_location_name = pickup_location_name @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @return_location_name = return_location_name @tax_exempt = tax_exempt @vehicle_identification_number = vehicle_identification_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
393 394 395 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 393 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
395 396 397 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 395 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
397 398 399 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 397 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
399 400 401 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 399 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
401 402 403 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 401 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
403 404 405 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 403 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
405 406 407 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 405 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
407 408 409 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 407 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
409 410 411 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 409 def delivery @delivery end |
#distance ⇒ Object
The details of the distance traveled during the rental period.
411 412 413 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 411 def distance @distance end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
413 414 415 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 413 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
415 416 417 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 415 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
417 418 419 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 417 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
419 420 421 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 419 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
421 422 423 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 421 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object
Name of the pickup location.
423 424 425 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 423 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object
Rental rate.
425 426 427 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 425 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
427 428 429 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 427 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
429 430 431 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 429 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
431 432 433 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 431 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
433 434 435 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 433 def return_at @return_at end |
#return_location_name ⇒ Object
Name of the return location.
435 436 437 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 435 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
437 438 439 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 437 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object
The vehicle identification number.
439 440 441 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 439 def vehicle_identification_number @vehicle_identification_number end |