Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
334 335 336 337 338 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 334 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
328 329 330 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 328 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
330 331 332 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 330 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
332 333 334 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 332 def phone @phone end |