Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



316
317
318
319
320
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 316

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



310
311
312
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 310

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



312
313
314
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 312

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



314
315
316
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 314

def phone
  @phone
end