Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



949
950
951
952
953
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 949

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



943
944
945
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 943

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



945
946
947
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 945

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



947
948
949
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 947

def phone
  @phone
end