Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



905
906
907
908
909
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 905

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



899
900
901
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 899

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



901
902
903
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 901

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



903
904
905
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 903

def phone
  @phone
end