Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



889
890
891
892
893
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 889

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



883
884
885
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 883

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



885
886
887
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 885

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



887
888
889
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 887

def phone
  @phone
end