Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
525 526 527 528 529 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 525 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
519 520 521 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 519 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
521 522 523 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 521 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
523 524 525 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 523 def phone @phone end |