Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



517
518
519
520
521
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 517

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



511
512
513
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 511

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



513
514
515
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 513

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



515
516
517
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 515

def phone
  @phone
end