Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
1122 1123 1124 1125 1126 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1122 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
1116 1117 1118 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1116 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
1118 1119 1120 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1118 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
1120 1121 1122 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1120 def phone @phone end |