Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



982
983
984
985
986
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 982

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



976
977
978
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 976

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



978
979
980
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 978

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



980
981
982
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 980

def phone
  @phone
end