Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
577 578 579 580 581 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 577 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
571 572 573 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 571 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
573 574 575 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 573 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
575 576 577 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 575 def phone @phone end |