Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::FlightDatum::Affiliate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentDetails::FlightDatum::Affiliate
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#code ⇒ Object
Affiliate partner code.
-
#name ⇒ Object
Name of affiliate partner.
-
#travel_authorization_code ⇒ Object
Code provided by the company to a travel agent authorizing ticket issuance.
Instance Method Summary collapse
-
#initialize(code: nil, name: nil, travel_authorization_code: nil) ⇒ Affiliate
constructor
A new instance of Affiliate.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(code: nil, name: nil, travel_authorization_code: nil) ⇒ Affiliate
Returns a new instance of Affiliate.
1233 1234 1235 1236 1237 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1233 def initialize(code: nil, name: nil, travel_authorization_code: nil) @code = code @name = name @travel_authorization_code = end |
Instance Attribute Details
#code ⇒ Object
Affiliate partner code.
1227 1228 1229 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1227 def code @code end |
#name ⇒ Object
Name of affiliate partner.
1229 1230 1231 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1229 def name @name end |
#travel_authorization_code ⇒ Object
Code provided by the company to a travel agent authorizing ticket issuance.
1231 1232 1233 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1231 def @travel_authorization_code end |