Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::FlightDatum::Affiliate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentDetails::FlightDatum::Affiliate
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#code ⇒ Object
Affiliate partner code.
-
#name ⇒ Object
Name of affiliate partner.
-
#travel_authorization_code ⇒ Object
Code provided by the company to a travel agent authorizing ticket issuance.
Instance Method Summary collapse
-
#initialize(code: nil, name: nil, travel_authorization_code: nil) ⇒ Affiliate
constructor
A new instance of Affiliate.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(code: nil, name: nil, travel_authorization_code: nil) ⇒ Affiliate
Returns a new instance of Affiliate.
1093 1094 1095 1096 1097 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1093 def initialize(code: nil, name: nil, travel_authorization_code: nil) @code = code @name = name @travel_authorization_code = end |
Instance Attribute Details
#code ⇒ Object
Affiliate partner code.
1087 1088 1089 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1087 def code @code end |
#name ⇒ Object
Name of affiliate partner.
1089 1090 1091 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1089 def name @name end |
#travel_authorization_code ⇒ Object
Code provided by the company to a travel agent authorizing ticket issuance.
1091 1092 1093 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1091 def @travel_authorization_code end |