Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::FlightDatum::Affiliate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentDetails::FlightDatum::Affiliate
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#code ⇒ Object
Affiliate partner code.
-
#name ⇒ Object
Name of affiliate partner.
-
#travel_authorization_code ⇒ Object
Code provided by the company to a travel agent authorizing ticket issuance.
Instance Method Summary collapse
-
#initialize(code: nil, name: nil, travel_authorization_code: nil) ⇒ Affiliate
constructor
A new instance of Affiliate.
Methods inherited from RequestParams
Constructor Details
#initialize(code: nil, name: nil, travel_authorization_code: nil) ⇒ Affiliate
Returns a new instance of Affiliate.
1077 1078 1079 1080 1081 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1077 def initialize(code: nil, name: nil, travel_authorization_code: nil) @code = code @name = name @travel_authorization_code = end |
Instance Attribute Details
#code ⇒ Object
Affiliate partner code.
1071 1072 1073 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1071 def code @code end |
#name ⇒ Object
Name of affiliate partner.
1073 1074 1075 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1073 def name @name end |
#travel_authorization_code ⇒ Object
Code provided by the company to a travel agent authorizing ticket issuance.
1075 1076 1077 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1075 def @travel_authorization_code end |