Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::FlightDatum::Affiliate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentDetails::FlightDatum::Affiliate
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#code ⇒ Object
Affiliate partner code.
-
#name ⇒ Object
Name of affiliate partner.
-
#travel_authorization_code ⇒ Object
Code provided by the company to a travel agent authorizing ticket issuance.
Instance Method Summary collapse
-
#initialize(code: nil, name: nil, travel_authorization_code: nil) ⇒ Affiliate
constructor
A new instance of Affiliate.
Methods inherited from RequestParams
Constructor Details
#initialize(code: nil, name: nil, travel_authorization_code: nil) ⇒ Affiliate
Returns a new instance of Affiliate.
1090 1091 1092 1093 1094 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1090 def initialize(code: nil, name: nil, travel_authorization_code: nil) @code = code @name = name @travel_authorization_code = end |
Instance Attribute Details
#code ⇒ Object
Affiliate partner code.
1084 1085 1086 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1084 def code @code end |
#name ⇒ Object
Name of affiliate partner.
1086 1087 1088 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1086 def name @name end |
#travel_authorization_code ⇒ Object
Code provided by the company to a travel agent authorizing ticket issuance.
1088 1089 1090 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1088 def @travel_authorization_code end |