Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1471

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



1429
1430
1431
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1429

def address
  @address
end

#adultsObject

The number of adults on the booking



1431
1432
1433
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1431

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



1433
1434
1435
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1433

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



1435
1436
1437
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1435

def booking_number
  @booking_number
end

#categoryObject

The lodging category



1437
1438
1439
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1437

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



1439
1440
1441
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1439

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



1441
1442
1443
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1441

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



1443
1444
1445
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1443

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



1445
1446
1447
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1445

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



1447
1448
1449
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1447

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



1449
1450
1451
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1449

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



1451
1452
1453
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1451

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



1453
1454
1455
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1453

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



1455
1456
1457
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1455

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



1457
1458
1459
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1457

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



1459
1460
1461
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1459

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



1461
1462
1463
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1461

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



1463
1464
1465
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1463

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



1465
1466
1467
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1465

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



1467
1468
1469
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1467

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



1469
1470
1471
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1469

def total_tax_amount
  @total_tax_amount
end