Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1543
1544
1545
1546
1547
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1543

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1537
1538
1539
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1537

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1539
1540
1541
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1539

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1541
1542
1543
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1541

def phone
  @phone
end