Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1403
1404
1405
1406
1407
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1403

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1397
1398
1399
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1397

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1399
1400
1401
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1399

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1401
1402
1403
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1401

def phone
  @phone
end