Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1387
1388
1389
1390
1391
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1387

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1381
1382
1383
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1381

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1383
1384
1385
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1383

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1385
1386
1387
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1385

def phone
  @phone
end