Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1400
1401
1402
1403
1404
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1400

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1394
1395
1396
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1394

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1396
1397
1398
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1396

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1398
1399
1400
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1398

def phone
  @phone
end