Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
754 755 756 757 758 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 754 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
748 749 750 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 748 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
750 751 752 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 750 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
752 753 754 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 752 def phone @phone end |