Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



729
730
731
732
733
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 729

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



723
724
725
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 723

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



725
726
727
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 725

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



727
728
729
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 727

def phone
  @phone
end