Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::MoneyServices
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentDetails::MoneyServices
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: AccountFunding
Instance Attribute Summary collapse
-
#account_funding ⇒ Object
Account funding transaction details including sender and beneficiary information.
-
#transaction_type ⇒ Object
The type of money services transaction.
Instance Method Summary collapse
-
#initialize(account_funding: nil, transaction_type: nil) ⇒ MoneyServices
constructor
A new instance of MoneyServices.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_funding: nil, transaction_type: nil) ⇒ MoneyServices
Returns a new instance of MoneyServices.
2111 2112 2113 2114 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2111 def initialize(account_funding: nil, transaction_type: nil) @account_funding = account_funding @transaction_type = transaction_type end |
Instance Attribute Details
#account_funding ⇒ Object
Account funding transaction details including sender and beneficiary information.
2107 2108 2109 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2107 def account_funding @account_funding end |
#transaction_type ⇒ Object
The type of money services transaction.
2109 2110 2111 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2109 def transaction_type @transaction_type end |