Class: Stripe::PaymentIntentConfirmParams::PaymentDetails::MoneyServices::AccountFunding
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentDetails::MoneyServices::AccountFunding
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: BeneficiaryDetails, SenderDetails
Instance Attribute Summary collapse
-
#beneficiary_account ⇒ Object
ID of the Account representing the beneficiary in this account funding transaction.
-
#beneficiary_details ⇒ Object
Inline identity details for the beneficiary of this account funding transaction.
-
#sender_account ⇒ Object
ID of the Account representing the sender in this account funding transaction.
-
#sender_details ⇒ Object
Inline identity details for the sender of this account funding transaction.
Instance Method Summary collapse
-
#initialize(beneficiary_account: nil, beneficiary_details: nil, sender_account: nil, sender_details: nil) ⇒ AccountFunding
constructor
A new instance of AccountFunding.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(beneficiary_account: nil, beneficiary_details: nil, sender_account: nil, sender_details: nil) ⇒ AccountFunding
Returns a new instance of AccountFunding.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2094 def initialize( beneficiary_account: nil, beneficiary_details: nil, sender_account: nil, sender_details: nil ) @beneficiary_account = beneficiary_account @beneficiary_details = beneficiary_details @sender_account = sender_account @sender_details = sender_details end |
Instance Attribute Details
#beneficiary_account ⇒ Object
ID of the Account representing the beneficiary in this account funding transaction.
2086 2087 2088 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2086 def beneficiary_account @beneficiary_account end |
#beneficiary_details ⇒ Object
Inline identity details for the beneficiary of this account funding transaction.
2088 2089 2090 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2088 def beneficiary_details @beneficiary_details end |
#sender_account ⇒ Object
ID of the Account representing the sender in this account funding transaction.
2090 2091 2092 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2090 def sender_account @sender_account end |
#sender_details ⇒ Object
Inline identity details for the sender of this account funding transaction.
2092 2093 2094 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2092 def sender_details @sender_details end |