Class: Stripe::PaymentIntentConfirmParams::PaymentMethodData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodData
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, RadarOptions, Rechnung, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, StripeBalance, Swish, Twint, UsBankAccount, WechatPay, Zip
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If this is an ‘acss_debit` PaymentMethod, this hash contains details about the ACSS Debit payment method.
-
#affirm ⇒ Object
If this is an ‘affirm` PaymentMethod, this hash contains details about the Affirm payment method.
-
#afterpay_clearpay ⇒ Object
If this is an ‘AfterpayClearpay` PaymentMethod, this hash contains details about the AfterpayClearpay payment method.
-
#alipay ⇒ Object
If this is an ‘Alipay` PaymentMethod, this hash contains details about the Alipay payment method.
-
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#alma ⇒ Object
If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.
-
#amazon_pay ⇒ Object
If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.
-
#au_becs_debit ⇒ Object
If this is an ‘au_becs_debit` PaymentMethod, this hash contains details about the bank account.
-
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.
-
#bancontact ⇒ Object
If this is a ‘bancontact` PaymentMethod, this hash contains details about the Bancontact payment method.
-
#billie ⇒ Object
If this is a ‘billie` PaymentMethod, this hash contains details about the Billie payment method.
-
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
-
#blik ⇒ Object
If this is a ‘blik` PaymentMethod, this hash contains details about the BLIK payment method.
-
#boleto ⇒ Object
If this is a ‘boleto` PaymentMethod, this hash contains details about the Boleto payment method.
-
#cashapp ⇒ Object
If this is a ‘cashapp` PaymentMethod, this hash contains details about the Cash App Pay payment method.
-
#crypto ⇒ Object
If this is a Crypto PaymentMethod, this hash contains details about the Crypto payment method.
-
#customer_balance ⇒ Object
If this is a ‘customer_balance` PaymentMethod, this hash contains details about the CustomerBalance payment method.
-
#eps ⇒ Object
If this is an ‘eps` PaymentMethod, this hash contains details about the EPS payment method.
-
#fpx ⇒ Object
If this is an ‘fpx` PaymentMethod, this hash contains details about the FPX payment method.
-
#giropay ⇒ Object
If this is a ‘giropay` PaymentMethod, this hash contains details about the Giropay payment method.
-
#gopay ⇒ Object
If this is a Gopay PaymentMethod, this hash contains details about the Gopay payment method.
-
#grabpay ⇒ Object
If this is a ‘grabpay` PaymentMethod, this hash contains details about the GrabPay payment method.
-
#id_bank_transfer ⇒ Object
If this is an ‘IdBankTransfer` PaymentMethod, this hash contains details about the IdBankTransfer payment method.
-
#ideal ⇒ Object
If this is an ‘ideal` PaymentMethod, this hash contains details about the iDEAL payment method.
-
#interac_present ⇒ Object
If this is an ‘interac_present` PaymentMethod, this hash contains details about the Interac Present payment method.
-
#kakao_pay ⇒ Object
If this is a ‘kakao_pay` PaymentMethod, this hash contains details about the Kakao Pay payment method.
-
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method.
-
#konbini ⇒ Object
If this is a ‘konbini` PaymentMethod, this hash contains details about the Konbini payment method.
-
#kr_card ⇒ Object
If this is a ‘kr_card` PaymentMethod, this hash contains details about the Korean Card payment method.
-
#link ⇒ Object
If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.
-
#mb_way ⇒ Object
If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#mobilepay ⇒ Object
If this is a ‘mobilepay` PaymentMethod, this hash contains details about the MobilePay payment method.
-
#multibanco ⇒ Object
If this is a ‘multibanco` PaymentMethod, this hash contains details about the Multibanco payment method.
-
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.
-
#nz_bank_account ⇒ Object
If this is an nz_bank_account PaymentMethod, this hash contains details about the nz_bank_account payment method.
-
#oxxo ⇒ Object
If this is an ‘oxxo` PaymentMethod, this hash contains details about the OXXO payment method.
-
#p24 ⇒ Object
If this is a ‘p24` PaymentMethod, this hash contains details about the P24 payment method.
-
#pay_by_bank ⇒ Object
If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.
-
#payco ⇒ Object
If this is a ‘payco` PaymentMethod, this hash contains details about the PAYCO payment method.
-
#paynow ⇒ Object
If this is a ‘paynow` PaymentMethod, this hash contains details about the PayNow payment method.
-
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this hash contains details about the PayPal payment method.
-
#paypay ⇒ Object
If this is a ‘paypay` PaymentMethod, this hash contains details about the PayPay payment method.
-
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.
-
#pix ⇒ Object
If this is a ‘pix` PaymentMethod, this hash contains details about the Pix payment method.
-
#promptpay ⇒ Object
If this is a ‘promptpay` PaymentMethod, this hash contains details about the PromptPay payment method.
-
#qris ⇒ Object
If this is a ‘qris` PaymentMethod, this hash contains details about the QRIS payment method.
-
#radar_options ⇒ Object
Options to configure Radar.
-
#rechnung ⇒ Object
If this is a ‘rechnung` PaymentMethod, this hash contains details about the Rechnung payment method.
-
#revolut_pay ⇒ Object
If this is a ‘revolut_pay` PaymentMethod, this hash contains details about the Revolut Pay payment method.
-
#samsung_pay ⇒ Object
If this is a ‘samsung_pay` PaymentMethod, this hash contains details about the SamsungPay payment method.
-
#satispay ⇒ Object
If this is a ‘satispay` PaymentMethod, this hash contains details about the Satispay payment method.
-
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` PaymentMethod, this hash contains details about the SEPA debit bank account.
-
#shopeepay ⇒ Object
If this is a Shopeepay PaymentMethod, this hash contains details about the Shopeepay payment method.
-
#sofort ⇒ Object
If this is a ‘sofort` PaymentMethod, this hash contains details about the SOFORT payment method.
-
#stripe_balance ⇒ Object
This hash contains details about the Stripe balance payment method.
-
#swish ⇒ Object
If this is a ‘swish` PaymentMethod, this hash contains details about the Swish payment method.
-
#twint ⇒ Object
If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.
-
#type ⇒ Object
The type of the PaymentMethod.
-
#us_bank_account ⇒ Object
If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.
-
#wechat_pay ⇒ Object
If this is an ‘wechat_pay` PaymentMethod, this hash contains details about the wechat_pay payment method.
-
#zip ⇒ Object
If this is a ‘zip` PaymentMethod, this hash contains details about the Zip payment method.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, billing_details: nil, blik: nil, boleto: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, paypay: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, radar_options: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, swish: nil, twint: nil, type: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodData
Returns a new instance of PaymentMethodData.
2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 2479 2480 2481 2482 2483 2484 2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 2496 2497 2498 2499 2500 2501 2502 2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2407 def initialize( acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, billing_details: nil, blik: nil, boleto: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, paypay: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, radar_options: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, swish: nil, twint: nil, type: nil, us_bank_account: nil, wechat_pay: nil, zip: nil ) @acss_debit = acss_debit @affirm = affirm @afterpay_clearpay = afterpay_clearpay @alipay = alipay @allow_redisplay = allow_redisplay @alma = alma @amazon_pay = amazon_pay @au_becs_debit = au_becs_debit @bacs_debit = bacs_debit @bancontact = bancontact @billie = billie @billing_details = billing_details @blik = blik @boleto = boleto @cashapp = cashapp @crypto = crypto @customer_balance = customer_balance @eps = eps @fpx = fpx @giropay = giropay @gopay = gopay @grabpay = grabpay @id_bank_transfer = id_bank_transfer @ideal = ideal @interac_present = interac_present @kakao_pay = kakao_pay @klarna = klarna @konbini = konbini @kr_card = kr_card @link = link @mb_way = mb_way @metadata = @mobilepay = mobilepay @multibanco = multibanco @naver_pay = naver_pay @nz_bank_account = nz_bank_account @oxxo = oxxo @p24 = p24 @pay_by_bank = pay_by_bank @payco = payco @paynow = paynow @paypal = paypal @paypay = paypay @payto = payto @pix = pix @promptpay = promptpay @qris = qris @radar_options = @rechnung = rechnung @revolut_pay = revolut_pay @samsung_pay = samsung_pay @satispay = satispay @sepa_debit = sepa_debit @shopeepay = shopeepay @sofort = sofort @stripe_balance = stripe_balance @swish = swish @twint = twint @type = type @us_bank_account = us_bank_account @wechat_pay = wechat_pay @zip = zip end |
Instance Attribute Details
#acss_debit ⇒ Object
If this is an ‘acss_debit` PaymentMethod, this hash contains details about the ACSS Debit payment method.
2283 2284 2285 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2283 def acss_debit @acss_debit end |
#affirm ⇒ Object
If this is an ‘affirm` PaymentMethod, this hash contains details about the Affirm payment method.
2285 2286 2287 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2285 def affirm @affirm end |
#afterpay_clearpay ⇒ Object
If this is an ‘AfterpayClearpay` PaymentMethod, this hash contains details about the AfterpayClearpay payment method.
2287 2288 2289 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2287 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
If this is an ‘Alipay` PaymentMethod, this hash contains details about the Alipay payment method.
2289 2290 2291 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2289 def alipay @alipay end |
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.
2291 2292 2293 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2291 def allow_redisplay @allow_redisplay end |
#alma ⇒ Object
If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.
2293 2294 2295 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2293 def alma @alma end |
#amazon_pay ⇒ Object
If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.
2295 2296 2297 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2295 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object
If this is an ‘au_becs_debit` PaymentMethod, this hash contains details about the bank account.
2297 2298 2299 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2297 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.
2299 2300 2301 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2299 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object
If this is a ‘bancontact` PaymentMethod, this hash contains details about the Bancontact payment method.
2301 2302 2303 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2301 def bancontact @bancontact end |
#billie ⇒ Object
If this is a ‘billie` PaymentMethod, this hash contains details about the Billie payment method.
2303 2304 2305 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2303 def billie @billie end |
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
2305 2306 2307 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2305 def billing_details @billing_details end |
#blik ⇒ Object
If this is a ‘blik` PaymentMethod, this hash contains details about the BLIK payment method.
2307 2308 2309 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2307 def blik @blik end |
#boleto ⇒ Object
If this is a ‘boleto` PaymentMethod, this hash contains details about the Boleto payment method.
2309 2310 2311 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2309 def boleto @boleto end |
#cashapp ⇒ Object
If this is a ‘cashapp` PaymentMethod, this hash contains details about the Cash App Pay payment method.
2311 2312 2313 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2311 def cashapp @cashapp end |
#crypto ⇒ Object
If this is a Crypto PaymentMethod, this hash contains details about the Crypto payment method.
2313 2314 2315 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2313 def crypto @crypto end |
#customer_balance ⇒ Object
If this is a ‘customer_balance` PaymentMethod, this hash contains details about the CustomerBalance payment method.
2315 2316 2317 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2315 def customer_balance @customer_balance end |
#eps ⇒ Object
If this is an ‘eps` PaymentMethod, this hash contains details about the EPS payment method.
2317 2318 2319 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2317 def eps @eps end |
#fpx ⇒ Object
If this is an ‘fpx` PaymentMethod, this hash contains details about the FPX payment method.
2319 2320 2321 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2319 def fpx @fpx end |
#giropay ⇒ Object
If this is a ‘giropay` PaymentMethod, this hash contains details about the Giropay payment method.
2321 2322 2323 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2321 def giropay @giropay end |
#gopay ⇒ Object
If this is a Gopay PaymentMethod, this hash contains details about the Gopay payment method.
2323 2324 2325 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2323 def gopay @gopay end |
#grabpay ⇒ Object
If this is a ‘grabpay` PaymentMethod, this hash contains details about the GrabPay payment method.
2325 2326 2327 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2325 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object
If this is an ‘IdBankTransfer` PaymentMethod, this hash contains details about the IdBankTransfer payment method.
2327 2328 2329 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2327 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object
If this is an ‘ideal` PaymentMethod, this hash contains details about the iDEAL payment method.
2329 2330 2331 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2329 def ideal @ideal end |
#interac_present ⇒ Object
If this is an ‘interac_present` PaymentMethod, this hash contains details about the Interac Present payment method.
2331 2332 2333 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2331 def interac_present @interac_present end |
#kakao_pay ⇒ Object
If this is a ‘kakao_pay` PaymentMethod, this hash contains details about the Kakao Pay payment method.
2333 2334 2335 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2333 def kakao_pay @kakao_pay end |
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method.
2335 2336 2337 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2335 def klarna @klarna end |
#konbini ⇒ Object
If this is a ‘konbini` PaymentMethod, this hash contains details about the Konbini payment method.
2337 2338 2339 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2337 def konbini @konbini end |
#kr_card ⇒ Object
If this is a ‘kr_card` PaymentMethod, this hash contains details about the Korean Card payment method.
2339 2340 2341 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2339 def kr_card @kr_card end |
#link ⇒ Object
If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.
2341 2342 2343 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2341 def link @link end |
#mb_way ⇒ Object
If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.
2343 2344 2345 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2343 def mb_way @mb_way end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2345 2346 2347 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2345 def @metadata end |
#mobilepay ⇒ Object
If this is a ‘mobilepay` PaymentMethod, this hash contains details about the MobilePay payment method.
2347 2348 2349 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2347 def mobilepay @mobilepay end |
#multibanco ⇒ Object
If this is a ‘multibanco` PaymentMethod, this hash contains details about the Multibanco payment method.
2349 2350 2351 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2349 def multibanco @multibanco end |
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.
2351 2352 2353 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2351 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object
If this is an nz_bank_account PaymentMethod, this hash contains details about the nz_bank_account payment method.
2353 2354 2355 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2353 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object
If this is an ‘oxxo` PaymentMethod, this hash contains details about the OXXO payment method.
2355 2356 2357 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2355 def oxxo @oxxo end |
#p24 ⇒ Object
If this is a ‘p24` PaymentMethod, this hash contains details about the P24 payment method.
2357 2358 2359 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2357 def p24 @p24 end |
#pay_by_bank ⇒ Object
If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.
2359 2360 2361 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2359 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object
If this is a ‘payco` PaymentMethod, this hash contains details about the PAYCO payment method.
2361 2362 2363 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2361 def payco @payco end |
#paynow ⇒ Object
If this is a ‘paynow` PaymentMethod, this hash contains details about the PayNow payment method.
2363 2364 2365 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2363 def paynow @paynow end |
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this hash contains details about the PayPal payment method.
2365 2366 2367 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2365 def paypal @paypal end |
#paypay ⇒ Object
If this is a ‘paypay` PaymentMethod, this hash contains details about the PayPay payment method.
2367 2368 2369 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2367 def paypay @paypay end |
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.
2369 2370 2371 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2369 def payto @payto end |
#pix ⇒ Object
If this is a ‘pix` PaymentMethod, this hash contains details about the Pix payment method.
2371 2372 2373 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2371 def pix @pix end |
#promptpay ⇒ Object
If this is a ‘promptpay` PaymentMethod, this hash contains details about the PromptPay payment method.
2373 2374 2375 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2373 def promptpay @promptpay end |
#qris ⇒ Object
If this is a ‘qris` PaymentMethod, this hash contains details about the QRIS payment method.
2375 2376 2377 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2375 def qris @qris end |
#radar_options ⇒ Object
Options to configure Radar. See [Radar Session](stripe.com/docs/radar/radar-session) for more information.
2377 2378 2379 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2377 def @radar_options end |
#rechnung ⇒ Object
If this is a ‘rechnung` PaymentMethod, this hash contains details about the Rechnung payment method.
2379 2380 2381 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2379 def rechnung @rechnung end |
#revolut_pay ⇒ Object
If this is a ‘revolut_pay` PaymentMethod, this hash contains details about the Revolut Pay payment method.
2381 2382 2383 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2381 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object
If this is a ‘samsung_pay` PaymentMethod, this hash contains details about the SamsungPay payment method.
2383 2384 2385 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2383 def samsung_pay @samsung_pay end |
#satispay ⇒ Object
If this is a ‘satispay` PaymentMethod, this hash contains details about the Satispay payment method.
2385 2386 2387 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2385 def satispay @satispay end |
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` PaymentMethod, this hash contains details about the SEPA debit bank account.
2387 2388 2389 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2387 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object
If this is a Shopeepay PaymentMethod, this hash contains details about the Shopeepay payment method.
2389 2390 2391 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2389 def shopeepay @shopeepay end |
#sofort ⇒ Object
If this is a ‘sofort` PaymentMethod, this hash contains details about the SOFORT payment method.
2391 2392 2393 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2391 def sofort @sofort end |
#stripe_balance ⇒ Object
This hash contains details about the Stripe balance payment method.
2393 2394 2395 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2393 def stripe_balance @stripe_balance end |
#swish ⇒ Object
If this is a ‘swish` PaymentMethod, this hash contains details about the Swish payment method.
2395 2396 2397 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2395 def swish @swish end |
#twint ⇒ Object
If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.
2397 2398 2399 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2397 def twint @twint end |
#type ⇒ Object
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
2399 2400 2401 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2399 def type @type end |
#us_bank_account ⇒ Object
If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.
2401 2402 2403 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2401 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
If this is an ‘wechat_pay` PaymentMethod, this hash contains details about the wechat_pay payment method.
2403 2404 2405 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2403 def wechat_pay @wechat_pay end |
#zip ⇒ Object
If this is a ‘zip` PaymentMethod, this hash contains details about the Zip payment method.
2405 2406 2407 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2405 def zip @zip end |