Class: Stripe::PaymentIntentConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 475

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



463
464
465
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 463

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



465
466
467
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 465

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



467
468
469
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 467

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



469
470
471
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 469

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



471
472
473
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 471

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



473
474
475
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 473

def suffix
  @suffix
end