Class: Stripe::PaymentIntentConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2126

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



2114
2115
2116
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2114

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



2116
2117
2118
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2116

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



2118
2119
2120
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2118

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



2120
2121
2122
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2120

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



2122
2123
2124
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2122

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



2124
2125
2126
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2124

def suffix
  @suffix
end