Class: Stripe::PaymentIntentConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2156 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
2144 2145 2146 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2144 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
2146 2147 2148 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2146 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
2148 2149 2150 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2148 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
2150 2151 2152 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2150 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
2152 2153 2154 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2152 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
2154 2155 2156 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2154 def suffix @suffix end |