Class: Stripe::PaymentIntentConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2112 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
2100 2101 2102 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2100 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
2102 2103 2104 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2102 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
2104 2105 2106 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2104 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
2106 2107 2108 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2106 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
2108 2109 2110 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2108 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
2110 2111 2112 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2110 def suffix @suffix end |