Class: Stripe::PaymentIntentConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 438 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
426 427 428 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 426 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
428 429 430 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 428 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
430 431 432 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 430 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
432 433 434 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 432 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
434 435 436 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 434 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
436 437 438 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 436 def suffix @suffix end |