Class: Stripe::PaymentIntentConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1142 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1130 1131 1132 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1130 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
1132 1133 1134 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1132 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
1134 1135 1136 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1134 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
1136 1137 1138 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1136 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
1138 1139 1140 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1138 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
1140 1141 1142 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1140 def suffix @suffix end |