Class: Stripe::PaymentIntentConfirmParams::PaymentMethodData::Upi::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodData::Upi::MandateOptions
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments.
-
#amount_type ⇒ Object
One of
fixedormaximum. -
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
-
#end_date ⇒ Object
End date of the mandate or subscription.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
2660 2661 2662 2663 2664 2665 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2660 def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) @amount = amount @amount_type = amount_type @description = description @end_date = end_date end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments.
2652 2653 2654 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2652 def amount @amount end |
#amount_type ⇒ Object
One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.
2654 2655 2656 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2654 def amount_type @amount_type end |
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
2656 2657 2658 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2656 def description @description end |
#end_date ⇒ Object
End date of the mandate or subscription.
2658 2659 2660 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2658 def end_date @end_date end |