Class: Stripe::PaymentIntentConfirmParams::PaymentMethodData::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



573
574
575
576
577
578
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 573

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



565
566
567
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 565

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



567
568
569
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 567

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



569
570
571
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 569

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



571
572
573
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 571

def end_date
  @end_date
end