Class: Stripe::PaymentIntentConfirmParams::PaymentMethodData::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2572
2573
2574
2575
2576
2577
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2572

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



2564
2565
2566
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2564

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



2566
2567
2568
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2566

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



2568
2569
2570
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2568

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



2570
2571
2572
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2570

def end_date
  @end_date
end