Class: Stripe::PaymentIntentConfirmParams::PaymentMethodData::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2288
2289
2290
2291
2292
2293
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2288

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



2280
2281
2282
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2280

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



2282
2283
2284
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2282

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



2284
2285
2286
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2284

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



2286
2287
2288
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2286

def end_date
  @end_date
end