Class: Stripe::PaymentIntentConfirmParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2286 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
2276 2277 2278 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2276 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
2278 2279 2280 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2278 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
2280 2281 2282 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2280 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
2282 2283 2284 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2282 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
2284 2285 2286 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2284 def routing_number @routing_number end |