Class: Stripe::PaymentIntentConfirmParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1278 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
1268 1269 1270 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1268 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
1270 1271 1272 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1270 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
1272 1273 1274 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1272 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
1274 1275 1276 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1274 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
1276 1277 1278 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1276 def routing_number @routing_number end |