Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Bizum, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, GiftCard, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, Scalapay, SepaDebit, Shopeepay, Sofort, StripeBalance, Swish, Twint, Upi, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, bizum: nil, blik: nil, boleto: nil, card: nil, card_present: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, gift_card: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, paypay: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, scalapay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, swish: nil, twint: nil, upi: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



6030
6031
6032
6033
6034
6035
6036
6037
6038
6039
6040
6041
6042
6043
6044
6045
6046
6047
6048
6049
6050
6051
6052
6053
6054
6055
6056
6057
6058
6059
6060
6061
6062
6063
6064
6065
6066
6067
6068
6069
6070
6071
6072
6073
6074
6075
6076
6077
6078
6079
6080
6081
6082
6083
6084
6085
6086
6087
6088
6089
6090
6091
6092
6093
6094
6095
6096
6097
6098
6099
6100
6101
6102
6103
6104
6105
6106
6107
6108
6109
6110
6111
6112
6113
6114
6115
6116
6117
6118
6119
6120
6121
6122
6123
6124
6125
6126
6127
6128
6129
6130
6131
6132
6133
6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
6144
6145
6146
6147
6148
6149
6150
6151
6152
6153
6154
6155
6156
6157
6158
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6030

def initialize(
  acss_debit: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  alma: nil,
  amazon_pay: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  billie: nil,
  bizum: nil,
  blik: nil,
  boleto: nil,
  card: nil,
  card_present: nil,
  cashapp: nil,
  crypto: nil,
  customer_balance: nil,
  eps: nil,
  fpx: nil,
  gift_card: nil,
  giropay: nil,
  gopay: nil,
  grabpay: nil,
  id_bank_transfer: nil,
  ideal: nil,
  interac_present: nil,
  kakao_pay: nil,
  klarna: nil,
  konbini: nil,
  kr_card: nil,
  link: nil,
  mb_way: nil,
  mobilepay: nil,
  multibanco: nil,
  naver_pay: nil,
  nz_bank_account: nil,
  oxxo: nil,
  p24: nil,
  pay_by_bank: nil,
  payco: nil,
  paynow: nil,
  paypal: nil,
  paypay: nil,
  payto: nil,
  pix: nil,
  promptpay: nil,
  qris: nil,
  rechnung: nil,
  revolut_pay: nil,
  samsung_pay: nil,
  satispay: nil,
  scalapay: nil,
  sepa_debit: nil,
  shopeepay: nil,
  sofort: nil,
  stripe_balance: nil,
  swish: nil,
  twint: nil,
  upi: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @alma = alma
  @amazon_pay = amazon_pay
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @billie = billie
  @bizum = bizum
  @blik = blik
  @boleto = boleto
  @card = card
  @card_present = card_present
  @cashapp = cashapp
  @crypto = crypto
  @customer_balance = customer_balance
  @eps = eps
  @fpx = fpx
  @gift_card = gift_card
  @giropay = giropay
  @gopay = gopay
  @grabpay = grabpay
  @id_bank_transfer = id_bank_transfer
  @ideal = ideal
  @interac_present = interac_present
  @kakao_pay = kakao_pay
  @klarna = klarna
  @konbini = konbini
  @kr_card = kr_card
  @link = link
  @mb_way = mb_way
  @mobilepay = mobilepay
  @multibanco = multibanco
  @naver_pay = naver_pay
  @nz_bank_account = 
  @oxxo = oxxo
  @p24 = p24
  @pay_by_bank = pay_by_bank
  @payco = payco
  @paynow = paynow
  @paypal = paypal
  @paypay = paypay
  @payto = payto
  @pix = pix
  @promptpay = promptpay
  @qris = qris
  @rechnung = rechnung
  @revolut_pay = revolut_pay
  @samsung_pay = samsung_pay
  @satispay = satispay
  @scalapay = scalapay
  @sepa_debit = sepa_debit
  @shopeepay = shopeepay
  @sofort = sofort
  @stripe_balance = stripe_balance
  @swish = swish
  @twint = twint
  @upi = upi
  @us_bank_account = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

If this is a ‘acss_debit` PaymentMethod, this sub-hash contains details about the ACSS Debit payment method options.



5904
5905
5906
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5904

def acss_debit
  @acss_debit
end

#affirmObject

If this is an ‘affirm` PaymentMethod, this sub-hash contains details about the Affirm payment method options.



5906
5907
5908
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5906

def affirm
  @affirm
end

#afterpay_clearpayObject

If this is a ‘afterpay_clearpay` PaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options.



5908
5909
5910
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5908

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If this is a ‘alipay` PaymentMethod, this sub-hash contains details about the Alipay payment method options.



5910
5911
5912
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5910

def alipay
  @alipay
end

#almaObject

If this is a ‘alma` PaymentMethod, this sub-hash contains details about the Alma payment method options.



5912
5913
5914
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5912

def alma
  @alma
end

#amazon_payObject

If this is a ‘amazon_pay` PaymentMethod, this sub-hash contains details about the Amazon Pay payment method options.



5914
5915
5916
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5914

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject

If this is a ‘au_becs_debit` PaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options.



5916
5917
5918
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5916

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

If this is a ‘bacs_debit` PaymentMethod, this sub-hash contains details about the BACS Debit payment method options.



5918
5919
5920
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5918

def bacs_debit
  @bacs_debit
end

#bancontactObject

If this is a ‘bancontact` PaymentMethod, this sub-hash contains details about the Bancontact payment method options.



5920
5921
5922
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5920

def bancontact
  @bancontact
end

#billieObject

If this is a ‘billie` PaymentMethod, this sub-hash contains details about the Billie payment method options.



5922
5923
5924
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5922

def billie
  @billie
end

#bizumObject

If this is a ‘bizum` PaymentMethod, this sub-hash contains details about the Bizum payment method options.



5924
5925
5926
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5924

def bizum
  @bizum
end

#blikObject

If this is a ‘blik` PaymentMethod, this sub-hash contains details about the BLIK payment method options.



5926
5927
5928
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5926

def blik
  @blik
end

#boletoObject

If this is a ‘boleto` PaymentMethod, this sub-hash contains details about the Boleto payment method options.



5928
5929
5930
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5928

def boleto
  @boleto
end

#cardObject

Configuration for any card payments attempted on this PaymentIntent.



5930
5931
5932
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5930

def card
  @card
end

#card_presentObject

If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.



5932
5933
5934
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5932

def card_present
  @card_present
end

#cashappObject

If this is a ‘cashapp` PaymentMethod, this sub-hash contains details about the Cash App Pay payment method options.



5934
5935
5936
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5934

def cashapp
  @cashapp
end

#cryptoObject

If this is a ‘crypto` PaymentMethod, this sub-hash contains details about the Crypto payment method options.



5936
5937
5938
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5936

def crypto
  @crypto
end

#customer_balanceObject

If this is a ‘customer balance` PaymentMethod, this sub-hash contains details about the customer balance payment method options.



5938
5939
5940
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5938

def customer_balance
  @customer_balance
end

#epsObject

If this is a ‘eps` PaymentMethod, this sub-hash contains details about the EPS payment method options.



5940
5941
5942
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5940

def eps
  @eps
end

#fpxObject

If this is a ‘fpx` PaymentMethod, this sub-hash contains details about the FPX payment method options.



5942
5943
5944
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5942

def fpx
  @fpx
end

#gift_cardObject

If this is a ‘gift_card` PaymentMethod, this sub-hash contains details about the gift card payment method options.



5944
5945
5946
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5944

def gift_card
  @gift_card
end

#giropayObject

If this is a ‘giropay` PaymentMethod, this sub-hash contains details about the Giropay payment method options.



5946
5947
5948
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5946

def giropay
  @giropay
end

#gopayObject

If this is a ‘gopay` PaymentMethod, this sub-hash contains details about the Gopay payment method options.



5948
5949
5950
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5948

def gopay
  @gopay
end

#grabpayObject

If this is a ‘grabpay` PaymentMethod, this sub-hash contains details about the Grabpay payment method options.



5950
5951
5952
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5950

def grabpay
  @grabpay
end

#id_bank_transferObject

If this is a ‘id_bank_transfer` PaymentMethod, this sub-hash contains details about the Indonesia Bank Transfer payment method options.



5952
5953
5954
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5952

def id_bank_transfer
  @id_bank_transfer
end

#idealObject

If this is a ‘ideal` PaymentMethod, this sub-hash contains details about the Ideal payment method options.



5954
5955
5956
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5954

def ideal
  @ideal
end

#interac_presentObject

If this is a ‘interac_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.



5956
5957
5958
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5956

def interac_present
  @interac_present
end

#kakao_payObject

If this is a ‘kakao_pay` PaymentMethod, this sub-hash contains details about the Kakao Pay payment method options.



5958
5959
5960
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5958

def kakao_pay
  @kakao_pay
end

#klarnaObject

If this is a ‘klarna` PaymentMethod, this sub-hash contains details about the Klarna payment method options.



5960
5961
5962
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5960

def klarna
  @klarna
end

#konbiniObject

If this is a ‘konbini` PaymentMethod, this sub-hash contains details about the Konbini payment method options.



5962
5963
5964
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5962

def konbini
  @konbini
end

#kr_cardObject

If this is a ‘kr_card` PaymentMethod, this sub-hash contains details about the KR Card payment method options.



5964
5965
5966
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5964

def kr_card
  @kr_card
end

If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options (Link is also known as Onelink in the UK).



5966
5967
5968
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5966

def link
  @link
end

#mb_wayObject

If this is a ‘mb_way` PaymentMethod, this sub-hash contains details about the MB WAY payment method options.



5968
5969
5970
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5968

def mb_way
  @mb_way
end

#mobilepayObject

If this is a ‘MobilePay` PaymentMethod, this sub-hash contains details about the MobilePay payment method options.



5970
5971
5972
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5970

def mobilepay
  @mobilepay
end

#multibancoObject

If this is a ‘multibanco` PaymentMethod, this sub-hash contains details about the Multibanco payment method options.



5972
5973
5974
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5972

def multibanco
  @multibanco
end

If this is a ‘naver_pay` PaymentMethod, this sub-hash contains details about the Naver Pay payment method options.



5974
5975
5976
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5974

def naver_pay
  @naver_pay
end

#nz_bank_accountObject

If this is a ‘nz_bank_account` PaymentMethod, this sub-hash contains details about the NZ BECS Direct Debit payment method options.



5976
5977
5978
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5976

def 
  @nz_bank_account
end

#oxxoObject

If this is a ‘oxxo` PaymentMethod, this sub-hash contains details about the OXXO payment method options.



5978
5979
5980
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5978

def oxxo
  @oxxo
end

#p24Object

If this is a ‘p24` PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options.



5980
5981
5982
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5980

def p24
  @p24
end

#pay_by_bankObject

If this is a ‘pay_by_bank` PaymentMethod, this sub-hash contains details about the PayByBank payment method options.



5982
5983
5984
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5982

def pay_by_bank
  @pay_by_bank
end

#paycoObject

If this is a ‘payco` PaymentMethod, this sub-hash contains details about the PAYCO payment method options.



5984
5985
5986
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5984

def payco
  @payco
end

#paynowObject

If this is a ‘paynow` PaymentMethod, this sub-hash contains details about the PayNow payment method options.



5986
5987
5988
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5986

def paynow
  @paynow
end

#paypalObject

If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.



5988
5989
5990
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5988

def paypal
  @paypal
end

#paypayObject

If this is a ‘paypay` PaymentMethod, this sub-hash contains details about the PayPay payment method options.



5990
5991
5992
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5990

def paypay
  @paypay
end

#paytoObject

If this is a ‘payto` PaymentMethod, this sub-hash contains details about the PayTo payment method options.



5992
5993
5994
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5992

def payto
  @payto
end

#pixObject

If this is a ‘pix` PaymentMethod, this sub-hash contains details about the Pix payment method options.



5994
5995
5996
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5994

def pix
  @pix
end

#promptpayObject

If this is a ‘promptpay` PaymentMethod, this sub-hash contains details about the PromptPay payment method options.



5996
5997
5998
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5996

def promptpay
  @promptpay
end

#qrisObject

If this is a ‘qris` PaymentMethod, this sub-hash contains details about the QRIS payment method options.



5998
5999
6000
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5998

def qris
  @qris
end

#rechnungObject

If this is a ‘rechnung` PaymentMethod, this sub-hash contains details about the Rechnung payment method options.



6000
6001
6002
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6000

def rechnung
  @rechnung
end

#revolut_payObject

If this is a ‘revolut_pay` PaymentMethod, this sub-hash contains details about the Revolut Pay payment method options.



6002
6003
6004
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6002

def revolut_pay
  @revolut_pay
end

#samsung_payObject

If this is a ‘samsung_pay` PaymentMethod, this sub-hash contains details about the Samsung Pay payment method options.



6004
6005
6006
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6004

def samsung_pay
  @samsung_pay
end

#satispayObject

If this is a ‘satispay` PaymentMethod, this sub-hash contains details about the Satispay payment method options.



6006
6007
6008
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6006

def satispay
  @satispay
end

#scalapayObject

If this is a ‘scalapay` PaymentMethod, this sub-hash contains details about the ScalaPay payment method options.



6008
6009
6010
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6008

def scalapay
  @scalapay
end

#sepa_debitObject

If this is a ‘sepa_debit` PaymentIntent, this sub-hash contains details about the SEPA Debit payment method options.



6010
6011
6012
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6010

def sepa_debit
  @sepa_debit
end

#shopeepayObject

If this is a ‘shopeepay` PaymentMethod, this sub-hash contains details about the ShopeePay payment method options.



6012
6013
6014
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6012

def shopeepay
  @shopeepay
end

#sofortObject

If this is a ‘sofort` PaymentMethod, this sub-hash contains details about the SOFORT payment method options.



6014
6015
6016
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6014

def sofort
  @sofort
end

#stripe_balanceObject

If this is a ‘stripe_balance` PaymentMethod, this sub-hash contains details about the Stripe Balance payment method options.



6016
6017
6018
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6016

def stripe_balance
  @stripe_balance
end

#swishObject

If this is a ‘Swish` PaymentMethod, this sub-hash contains details about the Swish payment method options.



6018
6019
6020
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6018

def swish
  @swish
end

#twintObject

If this is a ‘twint` PaymentMethod, this sub-hash contains details about the TWINT payment method options.



6020
6021
6022
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6020

def twint
  @twint
end

#upiObject

If this is a ‘upi` PaymentIntent, this sub-hash contains details about the UPI payment method options.



6022
6023
6024
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6022

def upi
  @upi
end

#us_bank_accountObject

If this is a ‘us_bank_account` PaymentMethod, this sub-hash contains details about the US bank account payment method options.



6024
6025
6026
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6024

def 
  @us_bank_account
end

#wechat_payObject

If this is a ‘wechat_pay` PaymentMethod, this sub-hash contains details about the WeChat Pay payment method options.



6026
6027
6028
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6026

def wechat_pay
  @wechat_pay
end

#zipObject

If this is a ‘zip` PaymentMethod, this sub-hash contains details about the Zip payment method options.



6028
6029
6030
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6028

def zip
  @zip
end