Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Bizum, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Grabpay, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, RevolutPay, SamsungPay, Satispay, Scalapay, SepaDebit, Sofort, Swish, Twint, Upi, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, bizum: nil, blik: nil, boleto: nil, card: nil, card_present: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, scalapay: nil, sepa_debit: nil, sofort: nil, swish: nil, twint: nil, upi: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
2598
2599
2600
2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
2652
2653
2654
2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2561

def initialize(
  acss_debit: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  alma: nil,
  amazon_pay: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  billie: nil,
  bizum: nil,
  blik: nil,
  boleto: nil,
  card: nil,
  card_present: nil,
  cashapp: nil,
  crypto: nil,
  customer_balance: nil,
  eps: nil,
  fpx: nil,
  giropay: nil,
  grabpay: nil,
  ideal: nil,
  interac_present: nil,
  kakao_pay: nil,
  klarna: nil,
  konbini: nil,
  kr_card: nil,
  link: nil,
  mb_way: nil,
  mobilepay: nil,
  multibanco: nil,
  naver_pay: nil,
  nz_bank_account: nil,
  oxxo: nil,
  p24: nil,
  pay_by_bank: nil,
  payco: nil,
  paynow: nil,
  paypal: nil,
  payto: nil,
  pix: nil,
  promptpay: nil,
  revolut_pay: nil,
  samsung_pay: nil,
  satispay: nil,
  scalapay: nil,
  sepa_debit: nil,
  sofort: nil,
  swish: nil,
  twint: nil,
  upi: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @alma = alma
  @amazon_pay = amazon_pay
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @billie = billie
  @bizum = bizum
  @blik = blik
  @boleto = boleto
  @card = card
  @card_present = card_present
  @cashapp = cashapp
  @crypto = crypto
  @customer_balance = customer_balance
  @eps = eps
  @fpx = fpx
  @giropay = giropay
  @grabpay = grabpay
  @ideal = ideal
  @interac_present = interac_present
  @kakao_pay = kakao_pay
  @klarna = klarna
  @konbini = konbini
  @kr_card = kr_card
  @link = link
  @mb_way = mb_way
  @mobilepay = mobilepay
  @multibanco = multibanco
  @naver_pay = naver_pay
  @nz_bank_account = 
  @oxxo = oxxo
  @p24 = p24
  @pay_by_bank = pay_by_bank
  @payco = payco
  @paynow = paynow
  @paypal = paypal
  @payto = payto
  @pix = pix
  @promptpay = promptpay
  @revolut_pay = revolut_pay
  @samsung_pay = samsung_pay
  @satispay = satispay
  @scalapay = scalapay
  @sepa_debit = sepa_debit
  @sofort = sofort
  @swish = swish
  @twint = twint
  @upi = upi
  @us_bank_account = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

If this is a ‘acss_debit` PaymentMethod, this sub-hash contains details about the ACSS Debit payment method options.



2451
2452
2453
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2451

def acss_debit
  @acss_debit
end

#affirmObject

If this is an ‘affirm` PaymentMethod, this sub-hash contains details about the Affirm payment method options.



2453
2454
2455
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2453

def affirm
  @affirm
end

#afterpay_clearpayObject

If this is a ‘afterpay_clearpay` PaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options.



2455
2456
2457
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2455

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If this is a ‘alipay` PaymentMethod, this sub-hash contains details about the Alipay payment method options.



2457
2458
2459
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2457

def alipay
  @alipay
end

#almaObject

If this is a ‘alma` PaymentMethod, this sub-hash contains details about the Alma payment method options.



2459
2460
2461
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2459

def alma
  @alma
end

#amazon_payObject

If this is a ‘amazon_pay` PaymentMethod, this sub-hash contains details about the Amazon Pay payment method options.



2461
2462
2463
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2461

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject

If this is a ‘au_becs_debit` PaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options.



2463
2464
2465
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2463

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

If this is a ‘bacs_debit` PaymentMethod, this sub-hash contains details about the BACS Debit payment method options.



2465
2466
2467
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2465

def bacs_debit
  @bacs_debit
end

#bancontactObject

If this is a ‘bancontact` PaymentMethod, this sub-hash contains details about the Bancontact payment method options.



2467
2468
2469
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2467

def bancontact
  @bancontact
end

#billieObject

If this is a ‘billie` PaymentMethod, this sub-hash contains details about the Billie payment method options.



2469
2470
2471
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2469

def billie
  @billie
end

#bizumObject

If this is a ‘bizum` PaymentMethod, this sub-hash contains details about the Bizum payment method options.



2471
2472
2473
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2471

def bizum
  @bizum
end

#blikObject

If this is a ‘blik` PaymentMethod, this sub-hash contains details about the BLIK payment method options.



2473
2474
2475
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2473

def blik
  @blik
end

#boletoObject

If this is a ‘boleto` PaymentMethod, this sub-hash contains details about the Boleto payment method options.



2475
2476
2477
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2475

def boleto
  @boleto
end

#cardObject

Configuration for any card payments attempted on this PaymentIntent.



2477
2478
2479
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2477

def card
  @card
end

#card_presentObject

If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.



2479
2480
2481
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2479

def card_present
  @card_present
end

#cashappObject

If this is a ‘cashapp` PaymentMethod, this sub-hash contains details about the Cash App Pay payment method options.



2481
2482
2483
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2481

def cashapp
  @cashapp
end

#cryptoObject

If this is a ‘crypto` PaymentMethod, this sub-hash contains details about the Crypto payment method options.



2483
2484
2485
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2483

def crypto
  @crypto
end

#customer_balanceObject

If this is a ‘customer balance` PaymentMethod, this sub-hash contains details about the customer balance payment method options.



2485
2486
2487
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2485

def customer_balance
  @customer_balance
end

#epsObject

If this is a ‘eps` PaymentMethod, this sub-hash contains details about the EPS payment method options.



2487
2488
2489
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2487

def eps
  @eps
end

#fpxObject

If this is a ‘fpx` PaymentMethod, this sub-hash contains details about the FPX payment method options.



2489
2490
2491
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2489

def fpx
  @fpx
end

#giropayObject

If this is a ‘giropay` PaymentMethod, this sub-hash contains details about the Giropay payment method options.



2491
2492
2493
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2491

def giropay
  @giropay
end

#grabpayObject

If this is a ‘grabpay` PaymentMethod, this sub-hash contains details about the Grabpay payment method options.



2493
2494
2495
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2493

def grabpay
  @grabpay
end

#idealObject

If this is a ‘ideal` PaymentMethod, this sub-hash contains details about the Ideal payment method options.



2495
2496
2497
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2495

def ideal
  @ideal
end

#interac_presentObject

If this is a ‘interac_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.



2497
2498
2499
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2497

def interac_present
  @interac_present
end

#kakao_payObject

If this is a ‘kakao_pay` PaymentMethod, this sub-hash contains details about the Kakao Pay payment method options.



2499
2500
2501
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2499

def kakao_pay
  @kakao_pay
end

#klarnaObject

If this is a ‘klarna` PaymentMethod, this sub-hash contains details about the Klarna payment method options.



2501
2502
2503
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2501

def klarna
  @klarna
end

#konbiniObject

If this is a ‘konbini` PaymentMethod, this sub-hash contains details about the Konbini payment method options.



2503
2504
2505
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2503

def konbini
  @konbini
end

#kr_cardObject

If this is a ‘kr_card` PaymentMethod, this sub-hash contains details about the KR Card payment method options.



2505
2506
2507
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2505

def kr_card
  @kr_card
end

If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options (Link is also known as Onelink in the UK).



2507
2508
2509
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2507

def link
  @link
end

#mb_wayObject

If this is a ‘mb_way` PaymentMethod, this sub-hash contains details about the MB WAY payment method options.



2509
2510
2511
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2509

def mb_way
  @mb_way
end

#mobilepayObject

If this is a ‘MobilePay` PaymentMethod, this sub-hash contains details about the MobilePay payment method options.



2511
2512
2513
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2511

def mobilepay
  @mobilepay
end

#multibancoObject

If this is a ‘multibanco` PaymentMethod, this sub-hash contains details about the Multibanco payment method options.



2513
2514
2515
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2513

def multibanco
  @multibanco
end

If this is a ‘naver_pay` PaymentMethod, this sub-hash contains details about the Naver Pay payment method options.



2515
2516
2517
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2515

def naver_pay
  @naver_pay
end

#nz_bank_accountObject

If this is a ‘nz_bank_account` PaymentMethod, this sub-hash contains details about the NZ BECS Direct Debit payment method options.



2517
2518
2519
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2517

def 
  @nz_bank_account
end

#oxxoObject

If this is a ‘oxxo` PaymentMethod, this sub-hash contains details about the OXXO payment method options.



2519
2520
2521
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2519

def oxxo
  @oxxo
end

#p24Object

If this is a ‘p24` PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options.



2521
2522
2523
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2521

def p24
  @p24
end

#pay_by_bankObject

If this is a ‘pay_by_bank` PaymentMethod, this sub-hash contains details about the PayByBank payment method options.



2523
2524
2525
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2523

def pay_by_bank
  @pay_by_bank
end

#paycoObject

If this is a ‘payco` PaymentMethod, this sub-hash contains details about the PAYCO payment method options.



2525
2526
2527
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2525

def payco
  @payco
end

#paynowObject

If this is a ‘paynow` PaymentMethod, this sub-hash contains details about the PayNow payment method options.



2527
2528
2529
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2527

def paynow
  @paynow
end

#paypalObject

If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.



2529
2530
2531
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2529

def paypal
  @paypal
end

#paytoObject

If this is a ‘payto` PaymentMethod, this sub-hash contains details about the PayTo payment method options.



2531
2532
2533
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2531

def payto
  @payto
end

#pixObject

If this is a ‘pix` PaymentMethod, this sub-hash contains details about the Pix payment method options.



2533
2534
2535
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2533

def pix
  @pix
end

#promptpayObject

If this is a ‘promptpay` PaymentMethod, this sub-hash contains details about the PromptPay payment method options.



2535
2536
2537
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2535

def promptpay
  @promptpay
end

#revolut_payObject

If this is a ‘revolut_pay` PaymentMethod, this sub-hash contains details about the Revolut Pay payment method options.



2537
2538
2539
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2537

def revolut_pay
  @revolut_pay
end

#samsung_payObject

If this is a ‘samsung_pay` PaymentMethod, this sub-hash contains details about the Samsung Pay payment method options.



2539
2540
2541
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2539

def samsung_pay
  @samsung_pay
end

#satispayObject

If this is a ‘satispay` PaymentMethod, this sub-hash contains details about the Satispay payment method options.



2541
2542
2543
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2541

def satispay
  @satispay
end

#scalapayObject

If this is a ‘scalapay` PaymentMethod, this sub-hash contains details about the ScalaPay payment method options.



2543
2544
2545
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2543

def scalapay
  @scalapay
end

#sepa_debitObject

If this is a ‘sepa_debit` PaymentIntent, this sub-hash contains details about the SEPA Debit payment method options.



2545
2546
2547
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2545

def sepa_debit
  @sepa_debit
end

#sofortObject

If this is a ‘sofort` PaymentMethod, this sub-hash contains details about the SOFORT payment method options.



2547
2548
2549
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2547

def sofort
  @sofort
end

#swishObject

If this is a ‘Swish` PaymentMethod, this sub-hash contains details about the Swish payment method options.



2549
2550
2551
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2549

def swish
  @swish
end

#twintObject

If this is a ‘twint` PaymentMethod, this sub-hash contains details about the TWINT payment method options.



2551
2552
2553
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2551

def twint
  @twint
end

#upiObject

If this is a ‘upi` PaymentIntent, this sub-hash contains details about the UPI payment method options.



2553
2554
2555
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2553

def upi
  @upi
end

#us_bank_accountObject

If this is a ‘us_bank_account` PaymentMethod, this sub-hash contains details about the US bank account payment method options.



2555
2556
2557
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2555

def 
  @us_bank_account
end

#wechat_payObject

If this is a ‘wechat_pay` PaymentMethod, this sub-hash contains details about the WeChat Pay payment method options.



2557
2558
2559
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2557

def wechat_pay
  @wechat_pay
end

#zipObject

If this is a ‘zip` PaymentMethod, this sub-hash contains details about the Zip payment method options.



2559
2560
2561
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2559

def zip
  @zip
end