Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, StripeBalance, Swish, Twint, Upi, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, blik: nil, boleto: nil, card: nil, card_present: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, paypay: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, swish: nil, twint: nil, upi: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



5562
5563
5564
5565
5566
5567
5568
5569
5570
5571
5572
5573
5574
5575
5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
5594
5595
5596
5597
5598
5599
5600
5601
5602
5603
5604
5605
5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
5634
5635
5636
5637
5638
5639
5640
5641
5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5562

def initialize(
  acss_debit: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  alma: nil,
  amazon_pay: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  billie: nil,
  blik: nil,
  boleto: nil,
  card: nil,
  card_present: nil,
  cashapp: nil,
  crypto: nil,
  customer_balance: nil,
  eps: nil,
  fpx: nil,
  giropay: nil,
  gopay: nil,
  grabpay: nil,
  id_bank_transfer: nil,
  ideal: nil,
  interac_present: nil,
  kakao_pay: nil,
  klarna: nil,
  konbini: nil,
  kr_card: nil,
  link: nil,
  mb_way: nil,
  mobilepay: nil,
  multibanco: nil,
  naver_pay: nil,
  nz_bank_account: nil,
  oxxo: nil,
  p24: nil,
  pay_by_bank: nil,
  payco: nil,
  paynow: nil,
  paypal: nil,
  paypay: nil,
  payto: nil,
  pix: nil,
  promptpay: nil,
  qris: nil,
  rechnung: nil,
  revolut_pay: nil,
  samsung_pay: nil,
  satispay: nil,
  sepa_debit: nil,
  shopeepay: nil,
  sofort: nil,
  stripe_balance: nil,
  swish: nil,
  twint: nil,
  upi: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @alma = alma
  @amazon_pay = amazon_pay
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @billie = billie
  @blik = blik
  @boleto = boleto
  @card = card
  @card_present = card_present
  @cashapp = cashapp
  @crypto = crypto
  @customer_balance = customer_balance
  @eps = eps
  @fpx = fpx
  @giropay = giropay
  @gopay = gopay
  @grabpay = grabpay
  @id_bank_transfer = id_bank_transfer
  @ideal = ideal
  @interac_present = interac_present
  @kakao_pay = kakao_pay
  @klarna = klarna
  @konbini = konbini
  @kr_card = kr_card
  @link = link
  @mb_way = mb_way
  @mobilepay = mobilepay
  @multibanco = multibanco
  @naver_pay = naver_pay
  @nz_bank_account = 
  @oxxo = oxxo
  @p24 = p24
  @pay_by_bank = pay_by_bank
  @payco = payco
  @paynow = paynow
  @paypal = paypal
  @paypay = paypay
  @payto = payto
  @pix = pix
  @promptpay = promptpay
  @qris = qris
  @rechnung = rechnung
  @revolut_pay = revolut_pay
  @samsung_pay = samsung_pay
  @satispay = satispay
  @sepa_debit = sepa_debit
  @shopeepay = shopeepay
  @sofort = sofort
  @stripe_balance = stripe_balance
  @swish = swish
  @twint = twint
  @upi = upi
  @us_bank_account = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

If this is a ‘acss_debit` PaymentMethod, this sub-hash contains details about the ACSS Debit payment method options.



5442
5443
5444
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5442

def acss_debit
  @acss_debit
end

#affirmObject

If this is an ‘affirm` PaymentMethod, this sub-hash contains details about the Affirm payment method options.



5444
5445
5446
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5444

def affirm
  @affirm
end

#afterpay_clearpayObject

If this is a ‘afterpay_clearpay` PaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options.



5446
5447
5448
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5446

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If this is a ‘alipay` PaymentMethod, this sub-hash contains details about the Alipay payment method options.



5448
5449
5450
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5448

def alipay
  @alipay
end

#almaObject

If this is a ‘alma` PaymentMethod, this sub-hash contains details about the Alma payment method options.



5450
5451
5452
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5450

def alma
  @alma
end

#amazon_payObject

If this is a ‘amazon_pay` PaymentMethod, this sub-hash contains details about the Amazon Pay payment method options.



5452
5453
5454
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5452

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject

If this is a ‘au_becs_debit` PaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options.



5454
5455
5456
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5454

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

If this is a ‘bacs_debit` PaymentMethod, this sub-hash contains details about the BACS Debit payment method options.



5456
5457
5458
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5456

def bacs_debit
  @bacs_debit
end

#bancontactObject

If this is a ‘bancontact` PaymentMethod, this sub-hash contains details about the Bancontact payment method options.



5458
5459
5460
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5458

def bancontact
  @bancontact
end

#billieObject

If this is a ‘billie` PaymentMethod, this sub-hash contains details about the Billie payment method options.



5460
5461
5462
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5460

def billie
  @billie
end

#blikObject

If this is a ‘blik` PaymentMethod, this sub-hash contains details about the BLIK payment method options.



5462
5463
5464
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5462

def blik
  @blik
end

#boletoObject

If this is a ‘boleto` PaymentMethod, this sub-hash contains details about the Boleto payment method options.



5464
5465
5466
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5464

def boleto
  @boleto
end

#cardObject

Configuration for any card payments attempted on this PaymentIntent.



5466
5467
5468
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5466

def card
  @card
end

#card_presentObject

If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.



5468
5469
5470
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5468

def card_present
  @card_present
end

#cashappObject

If this is a ‘cashapp` PaymentMethod, this sub-hash contains details about the Cash App Pay payment method options.



5470
5471
5472
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5470

def cashapp
  @cashapp
end

#cryptoObject

If this is a ‘crypto` PaymentMethod, this sub-hash contains details about the Crypto payment method options.



5472
5473
5474
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5472

def crypto
  @crypto
end

#customer_balanceObject

If this is a ‘customer balance` PaymentMethod, this sub-hash contains details about the customer balance payment method options.



5474
5475
5476
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5474

def customer_balance
  @customer_balance
end

#epsObject

If this is a ‘eps` PaymentMethod, this sub-hash contains details about the EPS payment method options.



5476
5477
5478
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5476

def eps
  @eps
end

#fpxObject

If this is a ‘fpx` PaymentMethod, this sub-hash contains details about the FPX payment method options.



5478
5479
5480
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5478

def fpx
  @fpx
end

#giropayObject

If this is a ‘giropay` PaymentMethod, this sub-hash contains details about the Giropay payment method options.



5480
5481
5482
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5480

def giropay
  @giropay
end

#gopayObject

If this is a ‘gopay` PaymentMethod, this sub-hash contains details about the Gopay payment method options.



5482
5483
5484
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5482

def gopay
  @gopay
end

#grabpayObject

If this is a ‘grabpay` PaymentMethod, this sub-hash contains details about the Grabpay payment method options.



5484
5485
5486
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5484

def grabpay
  @grabpay
end

#id_bank_transferObject

If this is a ‘id_bank_transfer` PaymentMethod, this sub-hash contains details about the Indonesia Bank Transfer payment method options.



5486
5487
5488
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5486

def id_bank_transfer
  @id_bank_transfer
end

#idealObject

If this is a ‘ideal` PaymentMethod, this sub-hash contains details about the Ideal payment method options.



5488
5489
5490
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5488

def ideal
  @ideal
end

#interac_presentObject

If this is a ‘interac_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.



5490
5491
5492
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5490

def interac_present
  @interac_present
end

#kakao_payObject

If this is a ‘kakao_pay` PaymentMethod, this sub-hash contains details about the Kakao Pay payment method options.



5492
5493
5494
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5492

def kakao_pay
  @kakao_pay
end

#klarnaObject

If this is a ‘klarna` PaymentMethod, this sub-hash contains details about the Klarna payment method options.



5494
5495
5496
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5494

def klarna
  @klarna
end

#konbiniObject

If this is a ‘konbini` PaymentMethod, this sub-hash contains details about the Konbini payment method options.



5496
5497
5498
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5496

def konbini
  @konbini
end

#kr_cardObject

If this is a ‘kr_card` PaymentMethod, this sub-hash contains details about the KR Card payment method options.



5498
5499
5500
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5498

def kr_card
  @kr_card
end

If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options.



5500
5501
5502
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5500

def link
  @link
end

#mb_wayObject

If this is a ‘mb_way` PaymentMethod, this sub-hash contains details about the MB WAY payment method options.



5502
5503
5504
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5502

def mb_way
  @mb_way
end

#mobilepayObject

If this is a ‘MobilePay` PaymentMethod, this sub-hash contains details about the MobilePay payment method options.



5504
5505
5506
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5504

def mobilepay
  @mobilepay
end

#multibancoObject

If this is a ‘multibanco` PaymentMethod, this sub-hash contains details about the Multibanco payment method options.



5506
5507
5508
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5506

def multibanco
  @multibanco
end

If this is a ‘naver_pay` PaymentMethod, this sub-hash contains details about the Naver Pay payment method options.



5508
5509
5510
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5508

def naver_pay
  @naver_pay
end

#nz_bank_accountObject

If this is a ‘nz_bank_account` PaymentMethod, this sub-hash contains details about the NZ BECS Direct Debit payment method options.



5510
5511
5512
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5510

def 
  @nz_bank_account
end

#oxxoObject

If this is a ‘oxxo` PaymentMethod, this sub-hash contains details about the OXXO payment method options.



5512
5513
5514
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5512

def oxxo
  @oxxo
end

#p24Object

If this is a ‘p24` PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options.



5514
5515
5516
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5514

def p24
  @p24
end

#pay_by_bankObject

If this is a ‘pay_by_bank` PaymentMethod, this sub-hash contains details about the PayByBank payment method options.



5516
5517
5518
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5516

def pay_by_bank
  @pay_by_bank
end

#paycoObject

If this is a ‘payco` PaymentMethod, this sub-hash contains details about the PAYCO payment method options.



5518
5519
5520
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5518

def payco
  @payco
end

#paynowObject

If this is a ‘paynow` PaymentMethod, this sub-hash contains details about the PayNow payment method options.



5520
5521
5522
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5520

def paynow
  @paynow
end

#paypalObject

If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.



5522
5523
5524
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5522

def paypal
  @paypal
end

#paypayObject

If this is a ‘paypay` PaymentMethod, this sub-hash contains details about the PayPay payment method options.



5524
5525
5526
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5524

def paypay
  @paypay
end

#paytoObject

If this is a ‘payto` PaymentMethod, this sub-hash contains details about the PayTo payment method options.



5526
5527
5528
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5526

def payto
  @payto
end

#pixObject

If this is a ‘pix` PaymentMethod, this sub-hash contains details about the Pix payment method options.



5528
5529
5530
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5528

def pix
  @pix
end

#promptpayObject

If this is a ‘promptpay` PaymentMethod, this sub-hash contains details about the PromptPay payment method options.



5530
5531
5532
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5530

def promptpay
  @promptpay
end

#qrisObject

If this is a ‘qris` PaymentMethod, this sub-hash contains details about the QRIS payment method options.



5532
5533
5534
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5532

def qris
  @qris
end

#rechnungObject

If this is a ‘rechnung` PaymentMethod, this sub-hash contains details about the Rechnung payment method options.



5534
5535
5536
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5534

def rechnung
  @rechnung
end

#revolut_payObject

If this is a ‘revolut_pay` PaymentMethod, this sub-hash contains details about the Revolut Pay payment method options.



5536
5537
5538
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5536

def revolut_pay
  @revolut_pay
end

#samsung_payObject

If this is a ‘samsung_pay` PaymentMethod, this sub-hash contains details about the Samsung Pay payment method options.



5538
5539
5540
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5538

def samsung_pay
  @samsung_pay
end

#satispayObject

If this is a ‘satispay` PaymentMethod, this sub-hash contains details about the Satispay payment method options.



5540
5541
5542
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5540

def satispay
  @satispay
end

#sepa_debitObject

If this is a ‘sepa_debit` PaymentIntent, this sub-hash contains details about the SEPA Debit payment method options.



5542
5543
5544
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5542

def sepa_debit
  @sepa_debit
end

#shopeepayObject

If this is a ‘shopeepay` PaymentMethod, this sub-hash contains details about the ShopeePay payment method options.



5544
5545
5546
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5544

def shopeepay
  @shopeepay
end

#sofortObject

If this is a ‘sofort` PaymentMethod, this sub-hash contains details about the SOFORT payment method options.



5546
5547
5548
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5546

def sofort
  @sofort
end

#stripe_balanceObject

If this is a ‘stripe_balance` PaymentMethod, this sub-hash contains details about the Stripe Balance payment method options.



5548
5549
5550
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5548

def stripe_balance
  @stripe_balance
end

#swishObject

If this is a ‘Swish` PaymentMethod, this sub-hash contains details about the Swish payment method options.



5550
5551
5552
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5550

def swish
  @swish
end

#twintObject

If this is a ‘twint` PaymentMethod, this sub-hash contains details about the TWINT payment method options.



5552
5553
5554
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5552

def twint
  @twint
end

#upiObject

If this is a ‘upi` PaymentIntent, this sub-hash contains details about the UPI payment method options.



5554
5555
5556
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5554

def upi
  @upi
end

#us_bank_accountObject

If this is a ‘us_bank_account` PaymentMethod, this sub-hash contains details about the US bank account payment method options.



5556
5557
5558
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5556

def 
  @us_bank_account
end

#wechat_payObject

If this is a ‘wechat_pay` PaymentMethod, this sub-hash contains details about the WeChat Pay payment method options.



5558
5559
5560
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5558

def wechat_pay
  @wechat_pay
end

#zipObject

If this is a ‘zip` PaymentMethod, this sub-hash contains details about the Zip payment method options.



5560
5561
5562
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5560

def zip
  @zip
end