Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: CaptureDelay, Installments, MandateOptions, PaymentDetails, StatementDetails, ThreeDSecure
Instance Attribute Summary collapse
-
#capture_by ⇒ Object
Controls when funds are captured from the customer's account when
capture_methodisautomatic_delayed. -
#capture_delay ⇒ Object
The number of days or hours to delay the capture of the funds.
-
#capture_method ⇒ Object
Controls when the funds are captured from the customer's account.
-
#cvc_token ⇒ Object
A single-use
cvc_updateToken that represents a card CVC value. -
#installments ⇒ Object
Installment configuration for payments attempted on this PaymentIntent.
-
#mandate_options ⇒ Object
Configuration options for setting up an eMandate for cards issued in India.
-
#moto ⇒ Object
When specified, this parameter indicates that a transaction will be marked as MOTO (Mail Order Telephone Order) and thus out of scope for SCA.
-
#network ⇒ Object
Selected network to process this PaymentIntent on.
-
#payment_details ⇒ Object
Payment details for payment method specific funding fields.
-
#request_decremental_authorization ⇒ Object
Request ability to decrement the authorization for this PaymentIntent.
-
#request_extended_authorization ⇒ Object
Request ability to capture beyond the standard authorization validity window for this PaymentIntent.
-
#request_incremental_authorization ⇒ Object
Request ability to increment the authorization for this PaymentIntent.
-
#request_multicapture ⇒ Object
Request ability to make multiple captures for this PaymentIntent.
-
#request_overcapture ⇒ Object
Request ability to overcapture for this PaymentIntent.
-
#request_partial_authorization ⇒ Object
Request partial authorization on this PaymentIntent.
-
#request_reauthorization ⇒ Object
Request ability to reauthorize for this PaymentIntent.
-
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements.
-
#require_cvc_recollection ⇒ Object
When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
-
#statement_descriptor_suffix_kana ⇒ Object
Provides information about a card payment that customers see on their statements.
-
#statement_descriptor_suffix_kanji ⇒ Object
Provides information about a card payment that customers see on their statements.
-
#statement_details ⇒ Object
Statement details for this payment intent.
-
#three_d_secure ⇒ Object
If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this payment.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(capture_by: nil, capture_delay: nil, capture_method: nil, cvc_token: nil, installments: nil, mandate_options: nil, moto: nil, network: nil, payment_details: nil, request_decremental_authorization: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_partial_authorization: nil, request_reauthorization: nil, request_three_d_secure: nil, require_cvc_recollection: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil, statement_details: nil, three_d_secure: nil) ⇒ Card
Returns a new instance of Card.
3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3575 def initialize( capture_by: nil, capture_delay: nil, capture_method: nil, cvc_token: nil, installments: nil, mandate_options: nil, moto: nil, network: nil, payment_details: nil, request_decremental_authorization: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_partial_authorization: nil, request_reauthorization: nil, request_three_d_secure: nil, require_cvc_recollection: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil, statement_details: nil, three_d_secure: nil ) @capture_by = capture_by @capture_delay = capture_delay @capture_method = capture_method @cvc_token = cvc_token @installments = installments @mandate_options = @moto = moto @network = network @payment_details = payment_details @request_decremental_authorization = @request_extended_authorization = @request_incremental_authorization = @request_multicapture = request_multicapture @request_overcapture = request_overcapture @request_partial_authorization = @request_reauthorization = @request_three_d_secure = request_three_d_secure @require_cvc_recollection = require_cvc_recollection @setup_future_usage = setup_future_usage @statement_descriptor_suffix_kana = statement_descriptor_suffix_kana @statement_descriptor_suffix_kanji = statement_descriptor_suffix_kanji @statement_details = statement_details @three_d_secure = three_d_secure end |
Instance Attribute Details
#capture_by ⇒ Object
Controls when funds are captured from the customer's account when capture_method is automatic_delayed.
If omitted, funds are captured before the authorization expires.
3510 3511 3512 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3510 def capture_by @capture_by end |
#capture_delay ⇒ Object
The number of days or hours to delay the capture of the funds. You can set both days and hours as long as the total delay does not exceed 30 days.
You can only set this if capture_method is automatic_delayed and capture_by is target_delay.
3514 3515 3516 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3514 def capture_delay @capture_delay end |
#capture_method ⇒ Object
Controls when the funds are captured from the customer's account.
If provided, this parameter overrides the behavior of the top-level capture_method for this payment method type when finalizing the payment with this payment method type.
If capture_method is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.
3520 3521 3522 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3520 def capture_method @capture_method end |
#cvc_token ⇒ Object
A single-use cvc_update Token that represents a card CVC value. When provided, the CVC value will be verified during the card payment attempt. This parameter can only be provided during confirmation.
3522 3523 3524 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3522 def cvc_token @cvc_token end |
#installments ⇒ Object
Installment configuration for payments attempted on this PaymentIntent.
For more information, see the installments integration guide.
3526 3527 3528 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3526 def installments @installments end |
#mandate_options ⇒ Object
Configuration options for setting up an eMandate for cards issued in India.
3528 3529 3530 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3528 def @mandate_options end |
#moto ⇒ Object
When specified, this parameter indicates that a transaction will be marked as MOTO (Mail Order Telephone Order) and thus out of scope for SCA. This parameter can only be provided during confirmation.
3532 3533 3534 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3532 def moto @moto end |
#network ⇒ Object
Selected network to process this PaymentIntent on. Depends on the available networks of the card attached to the PaymentIntent. Can be only set confirm-time.
3534 3535 3536 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3534 def network @network end |
#payment_details ⇒ Object
Payment details for payment method specific funding fields.
3536 3537 3538 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3536 def payment_details @payment_details end |
#request_decremental_authorization ⇒ Object
Request ability to decrement the authorization for this PaymentIntent.
3538 3539 3540 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3538 def @request_decremental_authorization end |
#request_extended_authorization ⇒ Object
Request ability to capture beyond the standard authorization validity window for this PaymentIntent.
3540 3541 3542 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3540 def @request_extended_authorization end |
#request_incremental_authorization ⇒ Object
Request ability to increment the authorization for this PaymentIntent.
3542 3543 3544 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3542 def @request_incremental_authorization end |
#request_multicapture ⇒ Object
Request ability to make multiple captures for this PaymentIntent.
3544 3545 3546 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3544 def request_multicapture @request_multicapture end |
#request_overcapture ⇒ Object
Request ability to overcapture for this PaymentIntent.
3546 3547 3548 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3546 def request_overcapture @request_overcapture end |
#request_partial_authorization ⇒ Object
Request partial authorization on this PaymentIntent.
3548 3549 3550 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3548 def @request_partial_authorization end |
#request_reauthorization ⇒ Object
Request ability to reauthorize for this PaymentIntent.
3550 3551 3552 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3550 def @request_reauthorization end |
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements. However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to automatic. Read our guide on manually requesting 3D Secure for more information on how this configuration interacts with Radar and our SCA Engine.
3552 3553 3554 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3552 def request_three_d_secure @request_three_d_secure end |
#require_cvc_recollection ⇒ Object
When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).
3554 3555 3556 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3554 def require_cvc_recollection @require_cvc_recollection end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.
3564 3565 3566 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3564 def setup_future_usage @setup_future_usage end |
#statement_descriptor_suffix_kana ⇒ Object
Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.
3566 3567 3568 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3566 def statement_descriptor_suffix_kana @statement_descriptor_suffix_kana end |
#statement_descriptor_suffix_kanji ⇒ Object
Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.
3568 3569 3570 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3568 def statement_descriptor_suffix_kanji @statement_descriptor_suffix_kanji end |
#statement_details ⇒ Object
Statement details for this payment intent. You can use this to override the merchant details shown on your customers' statements.
3570 3571 3572 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3570 def statement_details @statement_details end |
#three_d_secure ⇒ Object
If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this payment.
3573 3574 3575 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3573 def three_d_secure @three_d_secure end |