Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Card

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Installments, MandateOptions, StatementDetails, ThreeDSecure

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(capture_method: nil, cvc_token: nil, installments: nil, mandate_options: nil, moto: nil, network: nil, request_decremental_authorization: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_partial_authorization: nil, request_reauthorization: nil, request_three_d_secure: nil, require_cvc_recollection: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil, statement_details: nil, three_d_secure: nil) ⇒ Card

Returns a new instance of Card.



3125
3126
3127
3128
3129
3130
3131
3132
3133
3134
3135
3136
3137
3138
3139
3140
3141
3142
3143
3144
3145
3146
3147
3148
3149
3150
3151
3152
3153
3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
3166
3167
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3125

def initialize(
  capture_method: nil,
  cvc_token: nil,
  installments: nil,
  mandate_options: nil,
  moto: nil,
  network: nil,
  request_decremental_authorization: nil,
  request_extended_authorization: nil,
  request_incremental_authorization: nil,
  request_multicapture: nil,
  request_overcapture: nil,
  request_partial_authorization: nil,
  request_reauthorization: nil,
  request_three_d_secure: nil,
  require_cvc_recollection: nil,
  setup_future_usage: nil,
  statement_descriptor_suffix_kana: nil,
  statement_descriptor_suffix_kanji: nil,
  statement_details: nil,
  three_d_secure: nil
)
  @capture_method = capture_method
  @cvc_token = cvc_token
  @installments = installments
  @mandate_options = mandate_options
  @moto = moto
  @network = network
  @request_decremental_authorization = request_decremental_authorization
  @request_extended_authorization = request_extended_authorization
  @request_incremental_authorization = request_incremental_authorization
  @request_multicapture = request_multicapture
  @request_overcapture = request_overcapture
  @request_partial_authorization = request_partial_authorization
  @request_reauthorization = request_reauthorization
  @request_three_d_secure = request_three_d_secure
  @require_cvc_recollection = require_cvc_recollection
  @setup_future_usage = setup_future_usage
  @statement_descriptor_suffix_kana = statement_descriptor_suffix_kana
  @statement_descriptor_suffix_kanji = statement_descriptor_suffix_kanji
  @statement_details = statement_details
  @three_d_secure = three_d_secure
end

Instance Attribute Details

#capture_methodObject

Controls when the funds are captured from the customer’s account.

If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.

If ‘capture_method` is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.



3072
3073
3074
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3072

def capture_method
  @capture_method
end

#cvc_tokenObject

A single-use ‘cvc_update` Token that represents a card CVC value. When provided, the CVC value will be verified during the card payment attempt. This parameter can only be provided during confirmation.



3074
3075
3076
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3074

def cvc_token
  @cvc_token
end

#installmentsObject

Installment configuration for payments attempted on this PaymentIntent.

For more information, see the [installments integration guide](docs.stripe.com/payments/installments).



3078
3079
3080
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3078

def installments
  @installments
end

#mandate_optionsObject

Configuration options for setting up an eMandate for cards issued in India.



3080
3081
3082
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3080

def mandate_options
  @mandate_options
end

#motoObject

When specified, this parameter indicates that a transaction will be marked as MOTO (Mail Order Telephone Order) and thus out of scope for SCA. This parameter can only be provided during confirmation.



3084
3085
3086
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3084

def moto
  @moto
end

#networkObject

Selected network to process this PaymentIntent on. Depends on the available networks of the card attached to the PaymentIntent. Can be only set confirm-time.



3086
3087
3088
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3086

def network
  @network
end

#request_decremental_authorizationObject

Request ability to [decrement the authorization](docs.stripe.com/payments/decremental-authorization) for this PaymentIntent.



3088
3089
3090
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3088

def request_decremental_authorization
  @request_decremental_authorization
end

#request_extended_authorizationObject

Request ability to [capture beyond the standard authorization validity window](docs.stripe.com/payments/extended-authorization) for this PaymentIntent.



3090
3091
3092
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3090

def request_extended_authorization
  @request_extended_authorization
end

#request_incremental_authorizationObject

Request ability to [increment the authorization](docs.stripe.com/payments/incremental-authorization) for this PaymentIntent.



3092
3093
3094
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3092

def request_incremental_authorization
  @request_incremental_authorization
end

#request_multicaptureObject

Request ability to make [multiple captures](docs.stripe.com/payments/multicapture) for this PaymentIntent.



3094
3095
3096
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3094

def request_multicapture
  @request_multicapture
end

#request_overcaptureObject

Request ability to [overcapture](docs.stripe.com/payments/overcapture) for this PaymentIntent.



3096
3097
3098
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3096

def request_overcapture
  @request_overcapture
end

#request_partial_authorizationObject

Request partial authorization on this PaymentIntent.



3098
3099
3100
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3098

def request_partial_authorization
  @request_partial_authorization
end

#request_reauthorizationObject

Request ability to [reauthorize](docs.stripe.com/payments/reauthorization) for this PaymentIntent.



3100
3101
3102
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3100

def request_reauthorization
  @request_reauthorization
end

#request_three_d_secureObject

We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](docs.stripe.com/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](docs.stripe.com/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.



3102
3103
3104
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3102

def request_three_d_secure
  @request_three_d_secure
end

#require_cvc_recollectionObject

When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).



3104
3105
3106
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3104

def require_cvc_recollection
  @require_cvc_recollection
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



3114
3115
3116
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3114

def setup_future_usage
  @setup_future_usage
end

#statement_descriptor_suffix_kanaObject

Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.



3116
3117
3118
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3116

def statement_descriptor_suffix_kana
  @statement_descriptor_suffix_kana
end

#statement_descriptor_suffix_kanjiObject

Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.



3118
3119
3120
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3118

def statement_descriptor_suffix_kanji
  @statement_descriptor_suffix_kanji
end

#statement_detailsObject

Statement details for this payment intent. You can use this to override the merchant details shown on your customers’ statements.



3120
3121
3122
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3120

def statement_details
  @statement_details
end

#three_d_secureObject

If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this payment.



3123
3124
3125
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3123

def three_d_secure
  @three_d_secure
end