Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Card::Installments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Plan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, plan: nil) ⇒ Installments

Returns a new instance of Installments.



2831
2832
2833
2834
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2831

def initialize(enabled: nil, plan: nil)
  @enabled = enabled
  @plan = plan
end

Instance Attribute Details

#enabledObject

Setting to true enables installments for this PaymentIntent. This will cause the response to contain a list of available installment plans. Setting to false will prevent any selected plan from applying to a charge.



2826
2827
2828
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2826

def enabled
  @enabled
end

#planObject

The selected installment plan to use for this payment attempt. This parameter can only be provided during confirmation.



2829
2830
2831
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2829

def plan
  @plan
end