Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Card::Installments::Plan
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Card::Installments::Plan
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#count ⇒ Object
For
fixed_countinstallment plans, this is required. -
#interval ⇒ Object
For
fixed_countinstallment plans, this is required. -
#type ⇒ Object
Type of installment plan, one of
fixed_count,bonus, orrevolving.
Instance Method Summary collapse
-
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
constructor
A new instance of Plan.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
Returns a new instance of Plan.
2879 2880 2881 2882 2883 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2879 def initialize(count: nil, interval: nil, type: nil) @count = count @interval = interval @type = type end |
Instance Attribute Details
#count ⇒ Object
For fixed_count installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.
2872 2873 2874 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2872 def count @count end |
#interval ⇒ Object
For fixed_count installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card.
One of month.
2875 2876 2877 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2875 def interval @interval end |
#type ⇒ Object
Type of installment plan, one of fixed_count, bonus, or revolving.
2877 2878 2879 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2877 def type @type end |