Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



3213
3214
3215
3216
3217
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3213

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



3206
3207
3208
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3206

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



3209
3210
3211
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3209

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



3211
3212
3213
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3211

def type
  @type
end