Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



2867
2868
2869
2870
2871
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2867

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



2860
2861
2862
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2860

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



2863
2864
2865
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2863

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



2865
2866
2867
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2865

def type
  @type
end