Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



2847
2848
2849
2850
2851
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2847

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



2840
2841
2842
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2840

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



2843
2844
2845
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2843

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



2845
2846
2847
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2845

def type
  @type
end