Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



2817
2818
2819
2820
2821
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2817

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



2810
2811
2812
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2810

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



2813
2814
2815
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2813

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



2815
2816
2817
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2815

def type
  @type
end