Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



1868
1869
1870
1871
1872
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1868

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



1861
1862
1863
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1861

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



1864
1865
1866
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1864

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



1866
1867
1868
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1866

def type
  @type
end