Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Card::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Card::MandateOptions
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments, specified in the presentment currency.
-
#amount_type ⇒ Object
One of
fixedormaximum. -
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
-
#end_date ⇒ Object
End date of the mandate or subscription.
-
#interval ⇒ Object
Specifies payment frequency.
-
#interval_count ⇒ Object
The number of intervals between payments.
-
#reference ⇒ Object
Unique identifier for the mandate or subscription.
-
#start_date ⇒ Object
Start date of the mandate or subscription.
-
#supported_types ⇒ Object
Specifies the type of mandates supported.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2919 def initialize( amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil ) @amount = amount @amount_type = amount_type @description = description @end_date = end_date @interval = interval @interval_count = interval_count @reference = reference @start_date = start_date @supported_types = supported_types end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments, specified in the presentment currency.
2901 2902 2903 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2901 def amount @amount end |
#amount_type ⇒ Object
One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.
2903 2904 2905 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2903 def amount_type @amount_type end |
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
2905 2906 2907 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2905 def description @description end |
#end_date ⇒ Object
End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.
2907 2908 2909 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2907 def end_date @end_date end |
#interval ⇒ Object
Specifies payment frequency. One of day, week, month, year, or sporadic.
2909 2910 2911 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2909 def interval @interval end |
#interval_count ⇒ Object
The number of intervals between payments. For example, interval=month and interval_count=3 indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when interval=sporadic.
2911 2912 2913 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2911 def interval_count @interval_count end |
#reference ⇒ Object
Unique identifier for the mandate or subscription.
2913 2914 2915 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2913 def reference @reference end |
#start_date ⇒ Object
Start date of the mandate or subscription. Start date should not be lesser than yesterday.
2915 2916 2917 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2915 def start_date @start_date end |
#supported_types ⇒ Object
Specifies the type of mandates supported. Possible values are india.
2917 2918 2919 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2917 def supported_types @supported_types end |