Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2945
2946
2947
2948
2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2945

def initialize(
  amount: nil,
  amount_type: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments, specified in the presentment currency.



2927
2928
2929
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2927

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



2929
2930
2931
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2929

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



2931
2932
2933
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2931

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



2933
2934
2935
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2933

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



2935
2936
2937
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2935

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



2937
2938
2939
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2937

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



2939
2940
2941
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2939

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



2941
2942
2943
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2941

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are ‘india`.



2943
2944
2945
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2943

def supported_types
  @supported_types
end