Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1908

def initialize(
  amount: nil,
  amount_type: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



1890
1891
1892
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1890

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



1892
1893
1894
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1892

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



1894
1895
1896
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1894

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



1896
1897
1898
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1896

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



1898
1899
1900
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1898

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



1900
1901
1902
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1900

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



1902
1903
1904
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1902

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



1904
1905
1906
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1904

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are ‘india`.



1906
1907
1908
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1906

def supported_types
  @supported_types
end