Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Card::StatementDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Card::StatementDetails
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Please pass in an address that is within your Stripe user account country.
-
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call).
Instance Method Summary collapse
-
#initialize(address: nil, phone: nil) ⇒ StatementDetails
constructor
A new instance of StatementDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, phone: nil) ⇒ StatementDetails
Returns a new instance of StatementDetails.
1967 1968 1969 1970 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1967 def initialize(address: nil, phone: nil) @address = address @phone = phone end |
Instance Attribute Details
#address ⇒ Object
Please pass in an address that is within your Stripe user account country
1963 1964 1965 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1963 def address @address end |
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call)
1965 1966 1967 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1965 def phone @phone end |