Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Card::ThreeDSecure::NetworkOptions::CartesBancaires

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(cb_avalgo: nil, cb_exemption: nil, cb_score: nil) ⇒ CartesBancaires

Returns a new instance of CartesBancaires.



2968
2969
2970
2971
2972
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2968

def initialize(cb_avalgo: nil, cb_exemption: nil, cb_score: nil)
  @cb_avalgo = cb_avalgo
  @cb_exemption = cb_exemption
  @cb_score = cb_score
end

Instance Attribute Details

#cb_avalgoObject

The cryptogram calculation algorithm used by the card Issuer’s ACS to calculate the Authentication cryptogram. Also known as ‘cavvAlgorithm`. messageExtension: CB-AVALGO



2958
2959
2960
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2958

def cb_avalgo
  @cb_avalgo
end

#cb_exemptionObject

The exemption indicator returned from Cartes Bancaires in the ARes. message extension: CB-EXEMPTION; string (4 characters) This is a 3 byte bitmap (low significant byte first and most significant bit first) that has been Base64 encoded



2963
2964
2965
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2963

def cb_exemption
  @cb_exemption
end

#cb_scoreObject

The risk score returned from Cartes Bancaires in the ARes. message extension: CB-SCORE; numeric value 0-99



2966
2967
2968
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2966

def cb_score
  @cb_score
end