Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Card::ThreeDSecure::NetworkOptions::CartesBancaires

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(cb_avalgo: nil, cb_exemption: nil, cb_score: nil) ⇒ CartesBancaires

Returns a new instance of CartesBancaires.



1135
1136
1137
1138
1139
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1135

def initialize(cb_avalgo: nil, cb_exemption: nil, cb_score: nil)
  @cb_avalgo = cb_avalgo
  @cb_exemption = cb_exemption
  @cb_score = cb_score
end

Instance Attribute Details

#cb_avalgoObject

The cryptogram calculation algorithm used by the card Issuer’s ACS to calculate the Authentication cryptogram. Also known as ‘cavvAlgorithm`. messageExtension: CB-AVALGO



1125
1126
1127
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1125

def cb_avalgo
  @cb_avalgo
end

#cb_exemptionObject

The exemption indicator returned from Cartes Bancaires in the ARes. message extension: CB-EXEMPTION; string (4 characters) This is a 3 byte bitmap (low significant byte first and most significant bit first) that has been Base64 encoded



1130
1131
1132
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1130

def cb_exemption
  @cb_exemption
end

#cb_scoreObject

The risk score returned from Cartes Bancaires in the ARes. message extension: CB-SCORE; numeric value 0-99



1133
1134
1135
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1133

def cb_score
  @cb_score
end