Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: OnDemand, Subscription, SupplementaryPurchaseData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(capture_method: nil, on_demand: nil, preferred_locale: nil, setup_future_usage: nil, subscriptions: nil, supplementary_purchase_data: nil) ⇒ Klarna

Returns a new instance of Klarna.



4452
4453
4454
4455
4456
4457
4458
4459
4460
4461
4462
4463
4464
4465
4466
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4452

def initialize(
  capture_method: nil,
  on_demand: nil,
  preferred_locale: nil,
  setup_future_usage: nil,
  subscriptions: nil,
  supplementary_purchase_data: nil
)
  @capture_method = capture_method
  @on_demand = on_demand
  @preferred_locale = preferred_locale
  @setup_future_usage = setup_future_usage
  @subscriptions = subscriptions
  @supplementary_purchase_data = supplementary_purchase_data
end

Instance Attribute Details

#capture_methodObject

Controls when the funds are captured from the customer's account.

If provided, this parameter overrides the behavior of the top-level capture_method for this payment method type when finalizing the payment with this payment method type.

If capture_method is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.



4432
4433
4434
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4432

def capture_method
  @capture_method
end

#on_demandObject

On-demand details if setting up or charging an on-demand payment.



4434
4435
4436
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4434

def on_demand
  @on_demand
end

#preferred_localeObject

Preferred language of the Klarna authorization page that the customer is redirected to



4436
4437
4438
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4436

def preferred_locale
  @preferred_locale
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.

If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.



4446
4447
4448
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4446

def setup_future_usage
  @setup_future_usage
end

#subscriptionsObject

Subscription details if setting up or charging a subscription.



4448
4449
4450
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4448

def subscriptions
  @subscriptions
end

#supplementary_purchase_dataObject

Supplementary Purchase Data for the corresponding Klarna payment



4450
4451
4452
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4450

def supplementary_purchase_data
  @supplementary_purchase_data
end