Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



3964
3965
3966
3967
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3964

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



3960
3961
3962
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3960

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



3962
3963
3964
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3962

def date
  @date
end