Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



1633
1634
1635
1636
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1633

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



1629
1630
1631
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1629

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



1631
1632
1633
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1631

def date
  @date
end