Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



3440
3441
3442
3443
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3440

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



3436
3437
3438
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3436

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



3438
3439
3440
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3438

def date
  @date
end