Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: BusReservationDetail, EventReservationDetail, FerryReservationDetail, Insurance, MarketplaceSeller, RoundTripReservationDetail, TrainReservationDetail, Voucher
Instance Attribute Summary collapse
-
#bus_reservation_details ⇒ Object
Supplementary bus reservation details.
-
#event_reservation_details ⇒ Object
Supplementary event reservation details.
-
#ferry_reservation_details ⇒ Object
Supplementary ferry reservation details.
-
#insurances ⇒ Object
Supplementary insurance details.
-
#marketplace_sellers ⇒ Object
Supplementary marketplace seller details.
-
#round_trip_reservation_details ⇒ Object
Supplementary round trip reservation details.
-
#train_reservation_details ⇒ Object
Supplementary train reservation details.
-
#vouchers ⇒ Object
Voucher details, such as a gift card or discount code.
Instance Method Summary collapse
-
#initialize(bus_reservation_details: nil, event_reservation_details: nil, ferry_reservation_details: nil, insurances: nil, marketplace_sellers: nil, round_trip_reservation_details: nil, train_reservation_details: nil, vouchers: nil) ⇒ SupplementaryPurchaseData
constructor
A new instance of SupplementaryPurchaseData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bus_reservation_details: nil, event_reservation_details: nil, ferry_reservation_details: nil, insurances: nil, marketplace_sellers: nil, round_trip_reservation_details: nil, train_reservation_details: nil, vouchers: nil) ⇒ SupplementaryPurchaseData
Returns a new instance of SupplementaryPurchaseData.
4395 4396 4397 4398 4399 4400 4401 4402 4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4395 def initialize( bus_reservation_details: nil, event_reservation_details: nil, ferry_reservation_details: nil, insurances: nil, marketplace_sellers: nil, round_trip_reservation_details: nil, train_reservation_details: nil, vouchers: nil ) @bus_reservation_details = bus_reservation_details @event_reservation_details = event_reservation_details @ferry_reservation_details = ferry_reservation_details @insurances = insurances @marketplace_sellers = marketplace_sellers @round_trip_reservation_details = round_trip_reservation_details @train_reservation_details = train_reservation_details @vouchers = vouchers end |
Instance Attribute Details
#bus_reservation_details ⇒ Object
Supplementary bus reservation details.
4379 4380 4381 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4379 def bus_reservation_details @bus_reservation_details end |
#event_reservation_details ⇒ Object
Supplementary event reservation details.
4381 4382 4383 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4381 def event_reservation_details @event_reservation_details end |
#ferry_reservation_details ⇒ Object
Supplementary ferry reservation details.
4383 4384 4385 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4383 def ferry_reservation_details @ferry_reservation_details end |
#insurances ⇒ Object
Supplementary insurance details.
4385 4386 4387 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4385 def insurances @insurances end |
#marketplace_sellers ⇒ Object
Supplementary marketplace seller details.
4387 4388 4389 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4387 def marketplace_sellers @marketplace_sellers end |
#round_trip_reservation_details ⇒ Object
Supplementary round trip reservation details.
4389 4390 4391 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4389 def round_trip_reservation_details @round_trip_reservation_details end |
#train_reservation_details ⇒ Object
Supplementary train reservation details.
4391 4392 4393 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4391 def train_reservation_details @train_reservation_details end |
#vouchers ⇒ Object
Voucher details, such as a gift card or discount code.
4393 4394 4395 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4393 def vouchers @vouchers end |