Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail::Departure::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail::Departure::Address
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 3523 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3509 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3497 3498 3499 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3497 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3499 3500 3501 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3499 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3501 3502 3503 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3501 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3503 3504 3505 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3503 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3505 3506 3507 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3505 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3507 3508 3509 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3507 def street_address2 @street_address2 end |