Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Address, Insurance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail

Returns a new instance of EventReservationDetail.



3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
3741
3742
3743
3744
3745
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3723

def initialize(
  access_controlled_venue: nil,
  address: nil,
  affiliate_name: nil,
  ends_at: nil,
  event_company_name: nil,
  event_name: nil,
  event_type: nil,
  insurances: nil,
  starts_at: nil,
  venue_name: nil
)
  @access_controlled_venue = access_controlled_venue
  @address = address
  @affiliate_name = affiliate_name
  @ends_at = ends_at
  @event_company_name = event_company_name
  @event_name = event_name
  @event_type = event_type
  @insurances = insurances
  @starts_at = starts_at
  @venue_name = venue_name
end

Instance Attribute Details

#access_controlled_venueObject

Indicates if the tickets are digitally checked when entering the venue.



3703
3704
3705
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3703

def access_controlled_venue
  @access_controlled_venue
end

#addressObject

Address of the event.



3705
3706
3707
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3705

def address
  @address
end

#affiliate_nameObject

Name of associated or partner company for the service.



3707
3708
3709
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3707

def affiliate_name
  @affiliate_name
end

#ends_atObject

End timestamp of the event.



3709
3710
3711
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3709

def ends_at
  @ends_at
end

#event_company_nameObject

Company selling the ticket.



3711
3712
3713
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3711

def event_company_name
  @event_company_name
end

#event_nameObject

Name of the event.



3713
3714
3715
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3713

def event_name
  @event_name
end

#event_typeObject

Type of the event.



3715
3716
3717
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3715

def event_type
  @event_type
end

#insurancesObject

List of insurances for this event.



3717
3718
3719
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3717

def insurances
  @insurances
end

#starts_atObject

Start timestamp of the event.



3719
3720
3721
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3719

def starts_at
  @starts_at
end

#venue_nameObject

Name of the venue where the event takes place.



3721
3722
3723
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3721

def venue_name
  @venue_name
end