Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Address, Insurance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail

Returns a new instance of EventReservationDetail.



3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3766

def initialize(
  access_controlled_venue: nil,
  address: nil,
  affiliate_name: nil,
  ends_at: nil,
  event_company_name: nil,
  event_name: nil,
  event_type: nil,
  insurances: nil,
  starts_at: nil,
  venue_name: nil
)
  @access_controlled_venue = access_controlled_venue
  @address = address
  @affiliate_name = affiliate_name
  @ends_at = ends_at
  @event_company_name = event_company_name
  @event_name = event_name
  @event_type = event_type
  @insurances = insurances
  @starts_at = starts_at
  @venue_name = venue_name
end

Instance Attribute Details

#access_controlled_venueObject

Indicates if the tickets are digitally checked when entering the venue.



3746
3747
3748
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3746

def access_controlled_venue
  @access_controlled_venue
end

#addressObject

Address of the event.



3748
3749
3750
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3748

def address
  @address
end

#affiliate_nameObject

Name of associated or partner company for the service.



3750
3751
3752
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3750

def affiliate_name
  @affiliate_name
end

#ends_atObject

End timestamp of the event.



3752
3753
3754
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3752

def ends_at
  @ends_at
end

#event_company_nameObject

Company selling the ticket.



3754
3755
3756
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3754

def event_company_name
  @event_company_name
end

#event_nameObject

Name of the event.



3756
3757
3758
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3756

def event_name
  @event_name
end

#event_typeObject

Type of the event.



3758
3759
3760
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3758

def event_type
  @event_type
end

#insurancesObject

List of insurances for this event.



3760
3761
3762
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3760

def insurances
  @insurances
end

#starts_atObject

Start timestamp of the event.



3762
3763
3764
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3762

def starts_at
  @starts_at
end

#venue_nameObject

Name of the venue where the event takes place.



3764
3765
3766
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3764

def venue_name
  @venue_name
end