Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail::Address
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
3706 3707 3708 3709 3710 3711 3712 3713 3714 3715 3716 3717 3718 3719 3720 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3706 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3694 3695 3696 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3694 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3696 3697 3698 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3696 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3698 3699 3700 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3698 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3700 3701 3702 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3700 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3702 3703 3704 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3702 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3704 3705 3706 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3704 def street_address2 @street_address2 end |