Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail::Address
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 3626 3627 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3613 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3601 3602 3603 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3601 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3603 3604 3605 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3603 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3605 3606 3607 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3605 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3607 3608 3609 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3607 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3609 3610 3611 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3609 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3611 3612 3613 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3611 def street_address2 @street_address2 end |