Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
constructor
A new instance of FerryReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
Returns a new instance of FerryReservationDetail.
4421 4422 4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4421 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
4403 4404 4405 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4403 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
4405 4406 4407 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4405 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
4407 4408 4409 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4407 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
4409 4410 4411 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4409 def currency @currency end |
#departure ⇒ Object
Departure details.
4411 4412 4413 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4411 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
4413 4414 4415 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4413 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
4415 4416 4417 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4415 def passengers @passengers end |
#price ⇒ Object
Price in cents.
4417 4418 4419 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4417 def price @price end |
#ticket_class ⇒ Object
Ticket class.
4419 4420 4421 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4419 def ticket_class @ticket_class end |