Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
constructor
A new instance of FerryReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
Returns a new instance of FerryReservationDetail.
3993 3994 3995 3996 3997 3998 3999 4000 4001 4002 4003 4004 4005 4006 4007 4008 4009 4010 4011 4012 4013 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3993 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
3975 3976 3977 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3975 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
3977 3978 3979 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3977 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
3979 3980 3981 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3979 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
3981 3982 3983 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3981 def currency @currency end |
#departure ⇒ Object
Departure details.
3983 3984 3985 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3983 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
3985 3986 3987 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3985 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
3987 3988 3989 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3987 def passengers @passengers end |
#price ⇒ Object
Price in cents.
3989 3990 3991 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3989 def price @price end |
#ticket_class ⇒ Object
Ticket class.
3991 3992 3993 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3991 def ticket_class @ticket_class end |