Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
constructor
A new instance of FerryReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
Returns a new instance of FerryReservationDetail.
3932 3933 3934 3935 3936 3937 3938 3939 3940 3941 3942 3943 3944 3945 3946 3947 3948 3949 3950 3951 3952 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3932 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
3914 3915 3916 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3914 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
3916 3917 3918 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3916 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
3918 3919 3920 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3918 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
3920 3921 3922 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3920 def currency @currency end |
#departure ⇒ Object
Departure details.
3922 3923 3924 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3922 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
3924 3925 3926 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3924 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
3926 3927 3928 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3926 def passengers @passengers end |
#price ⇒ Object
Price in cents.
3928 3929 3930 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3928 def price @price end |
#ticket_class ⇒ Object
Ticket class.
3930 3931 3932 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3930 def ticket_class @ticket_class end |