Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
constructor
A new instance of FerryReservationDetail.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
Returns a new instance of FerryReservationDetail.
3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3839 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
3821 3822 3823 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3821 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
3823 3824 3825 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3823 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
3825 3826 3827 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3825 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
3827 3828 3829 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3827 def currency @currency end |
#departure ⇒ Object
Departure details.
3829 3830 3831 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3829 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
3831 3832 3833 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3831 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
3833 3834 3835 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3833 def passengers @passengers end |
#price ⇒ Object
Price in cents.
3835 3836 3837 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3835 def price @price end |
#ticket_class ⇒ Object
Ticket class.
3837 3838 3839 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3837 def ticket_class @ticket_class end |