Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
constructor
A new instance of FerryReservationDetail.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
Returns a new instance of FerryReservationDetail.
3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 3874 3875 3876 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3856 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
3838 3839 3840 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3838 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
3840 3841 3842 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3840 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
3842 3843 3844 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3842 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
3844 3845 3846 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3844 def currency @currency end |
#departure ⇒ Object
Departure details.
3846 3847 3848 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3846 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
3848 3849 3850 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3848 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
3850 3851 3852 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3850 def passengers @passengers end |
#price ⇒ Object
Price in cents.
3852 3853 3854 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3852 def price @price end |
#ticket_class ⇒ Object
Ticket class.
3854 3855 3856 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3854 def ticket_class @ticket_class end |