Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4271 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4259 4260 4261 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4259 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4261 4262 4263 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4261 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4263 4264 4265 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4263 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4265 4266 4267 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4265 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4267 4268 4269 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4267 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4269 4270 4271 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4269 def street_address2 @street_address2 end |