Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
3731 3732 3733 3734 3735 3736 3737 3738 3739 3740 3741 3742 3743 3744 3745 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3731 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3719 3720 3721 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3719 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3721 3722 3723 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3721 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3723 3724 3725 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3723 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3725 3726 3727 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3725 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3727 3728 3729 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3727 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3729 3730 3731 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3729 def street_address2 @street_address2 end |