Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: MarketplaceSellerAddress
Instance Attribute Summary collapse
-
#line_item_references ⇒ Object
The references to line items for purchases with multiple associated sub-sellers.
-
#marketplace_seller_address ⇒ Object
The address of the selling or delivering merchant.
-
#marketplace_seller_name ⇒ Object
The name of the marketplace seller.
-
#marketplace_seller_reference ⇒ Object
The unique identifier for the marketplace seller.
-
#number_of_transactions ⇒ Object
The number of transactions the sub-seller completed in the last 12 months.
-
#product_category ⇒ Object
The category of the product.
-
#seller_last_login_at ⇒ Object
The date when the seller’s account with the marketplace was last logged in.
-
#seller_rating ⇒ Object
The current rating of the marketplace seller.
-
#seller_registered_at ⇒ Object
The date when the seller’s account with the marketplace was created.
-
#seller_updated_at ⇒ Object
The date when the seller’s account with the marketplace was last updated.
-
#shipping_references ⇒ Object
The references to shipping addresses for purchases with multiple associated sub-sellers.
-
#volume_of_transactions ⇒ Object
The accumulated amount of sales transactions made by the sub-merchant or sub-seller within the past 12 months in the payment currency.
Instance Method Summary collapse
-
#initialize(line_item_references: nil, marketplace_seller_address: nil, marketplace_seller_name: nil, marketplace_seller_reference: nil, number_of_transactions: nil, product_category: nil, seller_last_login_at: nil, seller_rating: nil, seller_registered_at: nil, seller_updated_at: nil, shipping_references: nil, volume_of_transactions: nil) ⇒ MarketplaceSeller
constructor
A new instance of MarketplaceSeller.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(line_item_references: nil, marketplace_seller_address: nil, marketplace_seller_name: nil, marketplace_seller_reference: nil, number_of_transactions: nil, product_category: nil, seller_last_login_at: nil, seller_rating: nil, seller_registered_at: nil, seller_updated_at: nil, shipping_references: nil, volume_of_transactions: nil) ⇒ MarketplaceSeller
Returns a new instance of MarketplaceSeller.
4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4095 def initialize( line_item_references: nil, marketplace_seller_address: nil, marketplace_seller_name: nil, marketplace_seller_reference: nil, number_of_transactions: nil, product_category: nil, seller_last_login_at: nil, seller_rating: nil, seller_registered_at: nil, seller_updated_at: nil, shipping_references: nil, volume_of_transactions: nil ) @line_item_references = line_item_references @marketplace_seller_address = marketplace_seller_address @marketplace_seller_name = marketplace_seller_name @marketplace_seller_reference = marketplace_seller_reference @number_of_transactions = number_of_transactions @product_category = product_category @seller_last_login_at = seller_last_login_at @seller_rating = @seller_registered_at = seller_registered_at @seller_updated_at = seller_updated_at @shipping_references = shipping_references @volume_of_transactions = volume_of_transactions end |
Instance Attribute Details
#line_item_references ⇒ Object
The references to line items for purchases with multiple associated sub-sellers.
4071 4072 4073 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4071 def line_item_references @line_item_references end |
#marketplace_seller_address ⇒ Object
The address of the selling or delivering merchant.
4073 4074 4075 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4073 def marketplace_seller_address @marketplace_seller_address end |
#marketplace_seller_name ⇒ Object
The name of the marketplace seller.
4075 4076 4077 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4075 def marketplace_seller_name @marketplace_seller_name end |
#marketplace_seller_reference ⇒ Object
The unique identifier for the marketplace seller.
4077 4078 4079 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4077 def marketplace_seller_reference @marketplace_seller_reference end |
#number_of_transactions ⇒ Object
The number of transactions the sub-seller completed in the last 12 months.
4079 4080 4081 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4079 def number_of_transactions @number_of_transactions end |
#product_category ⇒ Object
The category of the product.
4081 4082 4083 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4081 def product_category @product_category end |
#seller_last_login_at ⇒ Object
The date when the seller’s account with the marketplace was last logged in.
4083 4084 4085 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4083 def seller_last_login_at @seller_last_login_at end |
#seller_rating ⇒ Object
The current rating of the marketplace seller. If the marketplace uses numeric ranking, map these to the enum values.
4085 4086 4087 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4085 def @seller_rating end |
#seller_registered_at ⇒ Object
The date when the seller’s account with the marketplace was created.
4087 4088 4089 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4087 def seller_registered_at @seller_registered_at end |
#seller_updated_at ⇒ Object
The date when the seller’s account with the marketplace was last updated.
4089 4090 4091 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4089 def seller_updated_at @seller_updated_at end |
#shipping_references ⇒ Object
The references to shipping addresses for purchases with multiple associated sub-sellers.
4091 4092 4093 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4091 def shipping_references @shipping_references end |
#volume_of_transactions ⇒ Object
The accumulated amount of sales transactions made by the sub-merchant or sub-seller within the past 12 months in the payment currency. These transactions are in minor currency units.
4093 4094 4095 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4093 def volume_of_transactions @volume_of_transactions end |