Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: MarketplaceSellerAddress
Instance Attribute Summary collapse
-
#line_item_references ⇒ Object
The references to line items for purchases with multiple associated sub-sellers.
-
#marketplace_seller_address ⇒ Object
The address of the selling or delivering merchant.
-
#marketplace_seller_name ⇒ Object
The name of the marketplace seller.
-
#marketplace_seller_reference ⇒ Object
The unique identifier for the marketplace seller.
-
#number_of_transactions ⇒ Object
The number of transactions the sub-seller completed in the last 12 months.
-
#product_category ⇒ Object
The category of the product.
-
#seller_last_login_at ⇒ Object
The date when the seller’s account with the marketplace was last logged in.
-
#seller_rating ⇒ Object
The current rating of the marketplace seller.
-
#seller_registered_at ⇒ Object
The date when the seller’s account with the marketplace was created.
-
#seller_updated_at ⇒ Object
The date when the seller’s account with the marketplace was last updated.
-
#shipping_references ⇒ Object
The references to shipping addresses for purchases with multiple associated sub-sellers.
-
#volume_of_transactions ⇒ Object
The accumulated amount of sales transactions made by the sub-merchant or sub-seller within the past 12 months in the payment currency.
Instance Method Summary collapse
-
#initialize(line_item_references: nil, marketplace_seller_address: nil, marketplace_seller_name: nil, marketplace_seller_reference: nil, number_of_transactions: nil, product_category: nil, seller_last_login_at: nil, seller_rating: nil, seller_registered_at: nil, seller_updated_at: nil, shipping_references: nil, volume_of_transactions: nil) ⇒ MarketplaceSeller
constructor
A new instance of MarketplaceSeller.
Methods inherited from RequestParams
Constructor Details
#initialize(line_item_references: nil, marketplace_seller_address: nil, marketplace_seller_name: nil, marketplace_seller_reference: nil, number_of_transactions: nil, product_category: nil, seller_last_login_at: nil, seller_rating: nil, seller_registered_at: nil, seller_updated_at: nil, shipping_references: nil, volume_of_transactions: nil) ⇒ MarketplaceSeller
Returns a new instance of MarketplaceSeller.
3941 3942 3943 3944 3945 3946 3947 3948 3949 3950 3951 3952 3953 3954 3955 3956 3957 3958 3959 3960 3961 3962 3963 3964 3965 3966 3967 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3941 def initialize( line_item_references: nil, marketplace_seller_address: nil, marketplace_seller_name: nil, marketplace_seller_reference: nil, number_of_transactions: nil, product_category: nil, seller_last_login_at: nil, seller_rating: nil, seller_registered_at: nil, seller_updated_at: nil, shipping_references: nil, volume_of_transactions: nil ) @line_item_references = line_item_references @marketplace_seller_address = marketplace_seller_address @marketplace_seller_name = marketplace_seller_name @marketplace_seller_reference = marketplace_seller_reference @number_of_transactions = number_of_transactions @product_category = product_category @seller_last_login_at = seller_last_login_at @seller_rating = @seller_registered_at = seller_registered_at @seller_updated_at = seller_updated_at @shipping_references = shipping_references @volume_of_transactions = volume_of_transactions end |
Instance Attribute Details
#line_item_references ⇒ Object
The references to line items for purchases with multiple associated sub-sellers.
3917 3918 3919 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3917 def line_item_references @line_item_references end |
#marketplace_seller_address ⇒ Object
The address of the selling or delivering merchant.
3919 3920 3921 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3919 def marketplace_seller_address @marketplace_seller_address end |
#marketplace_seller_name ⇒ Object
The name of the marketplace seller.
3921 3922 3923 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3921 def marketplace_seller_name @marketplace_seller_name end |
#marketplace_seller_reference ⇒ Object
The unique identifier for the marketplace seller.
3923 3924 3925 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3923 def marketplace_seller_reference @marketplace_seller_reference end |
#number_of_transactions ⇒ Object
The number of transactions the sub-seller completed in the last 12 months.
3925 3926 3927 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3925 def number_of_transactions @number_of_transactions end |
#product_category ⇒ Object
The category of the product.
3927 3928 3929 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3927 def product_category @product_category end |
#seller_last_login_at ⇒ Object
The date when the seller’s account with the marketplace was last logged in.
3929 3930 3931 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3929 def seller_last_login_at @seller_last_login_at end |
#seller_rating ⇒ Object
The current rating of the marketplace seller. If the marketplace uses numeric ranking, map these to the enum values.
3931 3932 3933 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3931 def @seller_rating end |
#seller_registered_at ⇒ Object
The date when the seller’s account with the marketplace was created.
3933 3934 3935 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3933 def seller_registered_at @seller_registered_at end |
#seller_updated_at ⇒ Object
The date when the seller’s account with the marketplace was last updated.
3935 3936 3937 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3935 def seller_updated_at @seller_updated_at end |
#shipping_references ⇒ Object
The references to shipping addresses for purchases with multiple associated sub-sellers.
3937 3938 3939 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3937 def shipping_references @shipping_references end |
#volume_of_transactions ⇒ Object
The accumulated amount of sales transactions made by the sub-merchant or sub-seller within the past 12 months in the payment currency. These transactions are in minor currency units.
3939 3940 3941 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3939 def volume_of_transactions @volume_of_transactions end |