Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller::MarketplaceSellerAddress
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller::MarketplaceSellerAddress
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ MarketplaceSellerAddress
constructor
A new instance of MarketplaceSellerAddress.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ MarketplaceSellerAddress
Returns a new instance of MarketplaceSellerAddress.
3950 3951 3952 3953 3954 3955 3956 3957 3958 3959 3960 3961 3962 3963 3964 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3950 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3938 3939 3940 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3938 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3940 3941 3942 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3940 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3942 3943 3944 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3942 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3944 3945 3946 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3944 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3946 3947 3948 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3946 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3948 3949 3950 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3948 def street_address2 @street_address2 end |