Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4140 4141 4142 4143 4144 4145 4146 4147 4148 4149 4150 4151 4152 4153 4154 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4140 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4128 4129 4130 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4128 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4130 4131 4132 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4130 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4132 4133 4134 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4132 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4134 4135 4136 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4134 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4136 4137 4138 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4136 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4138 4139 4140 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4138 def street_address2 @street_address2 end |