Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
3986 3987 3988 3989 3990 3991 3992 3993 3994 3995 3996 3997 3998 3999 4000 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3986 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3974 3975 3976 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3974 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3976 3977 3978 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3976 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3978 3979 3980 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3978 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3980 3981 3982 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3980 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3982 3983 3984 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3982 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3984 3985 3986 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3984 def street_address2 @street_address2 end |