Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Departure::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Departure::Address
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4121 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4109 4110 4111 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4109 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4111 4112 4113 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4111 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4113 4114 4115 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4113 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4115 4116 4117 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4115 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4117 4118 4119 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4117 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4119 4120 4121 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4119 def street_address2 @street_address2 end |