Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ TrainReservationDetail
constructor
A new instance of TrainReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ TrainReservationDetail
Returns a new instance of TrainReservationDetail.
4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 4335 4336 4337 4338 4339 4340 4341 4342 4343 4344 4345 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4325 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
4307 4308 4309 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4307 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
4309 4310 4311 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4309 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
4311 4312 4313 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4311 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
4313 4314 4315 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4313 def currency @currency end |
#departure ⇒ Object
Departure details.
4315 4316 4317 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4315 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
4317 4318 4319 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4317 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
4319 4320 4321 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4319 def passengers @passengers end |
#price ⇒ Object
Price in cents.
4321 4322 4323 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4321 def price @price end |
#ticket_class ⇒ Object
Ticket class.
4323 4324 4325 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4323 def ticket_class @ticket_class end |