Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ TrainReservationDetail
constructor
A new instance of TrainReservationDetail.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ TrainReservationDetail
Returns a new instance of TrainReservationDetail.
4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4275 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
4257 4258 4259 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4257 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
4259 4260 4261 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4259 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
4261 4262 4263 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4261 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
4263 4264 4265 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4263 def currency @currency end |
#departure ⇒ Object
Departure details.
4265 4266 4267 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4265 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
4267 4268 4269 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4267 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
4269 4270 4271 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4269 def passengers @passengers end |
#price ⇒ Object
Price in cents.
4271 4272 4273 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4271 def price @price end |
#ticket_class ⇒ Object
Ticket class.
4273 4274 4275 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4273 def ticket_class @ticket_class end |