Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4712 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4700 4701 4702 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4700 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4702 4703 4704 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4702 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4704 4705 4706 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4704 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4706 4707 4708 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4706 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4708 4709 4710 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4708 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4710 4711 4712 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4710 def street_address2 @street_address2 end |