Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4200 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4188 4189 4190 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4188 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4190 4191 4192 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4190 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4192 4193 4194 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4192 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4194 4195 4196 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4194 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4196 4197 4198 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4196 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4198 4199 4200 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4198 def street_address2 @street_address2 end |