Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Departure::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Departure::Address
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4797 4798 4799 4800 4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4797 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4785 4786 4787 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4785 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4787 4788 4789 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4787 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4789 4790 4791 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4789 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4791 4792 4793 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4791 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4793 4794 4795 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4793 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4795 4796 4797 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4795 def street_address2 @street_address2 end |