Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Departure::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Departure::Address
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4242 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4230 4231 4232 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4230 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4232 4233 4234 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4232 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4234 4235 4236 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4234 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4236 4237 4238 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4236 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4238 4239 4240 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4238 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4240 4241 4242 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4240 def street_address2 @street_address2 end |