Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::Voucher
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::Voucher
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for this voucher.
-
#ends_at ⇒ Object
The voucher validity end time.
-
#starts_at ⇒ Object
The voucher validity start time.
-
#voucher_company ⇒ Object
The issuer or provider of this voucher.
-
#voucher_name ⇒ Object
The name or reference to identify the voucher.
-
#voucher_type ⇒ Object
The type of this voucher.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil) ⇒ Voucher
constructor
A new instance of Voucher.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil) ⇒ Voucher
Returns a new instance of Voucher.
4894 4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4894 def initialize( affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil ) @affiliate_name = affiliate_name @ends_at = ends_at @starts_at = starts_at @voucher_company = voucher_company @voucher_name = voucher_name @voucher_type = voucher_type end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for this voucher.
4882 4883 4884 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4882 def affiliate_name @affiliate_name end |
#ends_at ⇒ Object
The voucher validity end time.
4884 4885 4886 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4884 def ends_at @ends_at end |
#starts_at ⇒ Object
The voucher validity start time.
4886 4887 4888 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4886 def starts_at @starts_at end |
#voucher_company ⇒ Object
The issuer or provider of this voucher.
4888 4889 4890 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4888 def voucher_company @voucher_company end |
#voucher_name ⇒ Object
The name or reference to identify the voucher.
4890 4891 4892 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4890 def voucher_name @voucher_name end |
#voucher_type ⇒ Object
The type of this voucher.
4892 4893 4894 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4892 def voucher_type @voucher_type end |