Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::Voucher
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::Voucher
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for this voucher.
-
#ends_at ⇒ Object
The voucher validity end time.
-
#starts_at ⇒ Object
The voucher validity start time.
-
#voucher_company ⇒ Object
The issuer or provider of this voucher.
-
#voucher_name ⇒ Object
The name or reference to identify the voucher.
-
#voucher_type ⇒ Object
The type of this voucher.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil) ⇒ Voucher
constructor
A new instance of Voucher.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil) ⇒ Voucher
Returns a new instance of Voucher.
4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4405 def initialize( affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil ) @affiliate_name = affiliate_name @ends_at = ends_at @starts_at = starts_at @voucher_company = voucher_company @voucher_name = voucher_name @voucher_type = voucher_type end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for this voucher.
4393 4394 4395 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4393 def affiliate_name @affiliate_name end |
#ends_at ⇒ Object
The voucher validity end time.
4395 4396 4397 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4395 def ends_at @ends_at end |
#starts_at ⇒ Object
The voucher validity start time.
4397 4398 4399 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4397 def starts_at @starts_at end |
#voucher_company ⇒ Object
The issuer or provider of this voucher.
4399 4400 4401 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4399 def voucher_company @voucher_company end |
#voucher_name ⇒ Object
The name or reference to identify the voucher.
4401 4402 4403 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4401 def voucher_name @voucher_name end |
#voucher_type ⇒ Object
The type of this voucher.
4403 4404 4405 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4403 def voucher_type @voucher_type end |