Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Konbini

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(confirmation_number: nil, expires_after_days: nil, expires_at: nil, product_description: nil, setup_future_usage: nil) ⇒ Konbini

Returns a new instance of Konbini.



4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
4437
4438
4439
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4427

def initialize(
  confirmation_number: nil,
  expires_after_days: nil,
  expires_at: nil,
  product_description: nil,
  setup_future_usage: nil
)
  @confirmation_number = confirmation_number
  @expires_after_days = expires_after_days
  @expires_at = expires_at
  @product_description = product_description
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#confirmation_numberObject

An optional 10 to 11 digit numeric-only string determining the confirmation code at applicable convenience stores. Must not consist of only zeroes and could be rejected in case of insufficient uniqueness. We recommend to use the customer’s phone number.



4409
4410
4411
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4409

def confirmation_number
  @confirmation_number
end

#expires_after_daysObject

The number of calendar days (between 1 and 60) after which Konbini payment instructions will expire. For example, if a PaymentIntent is confirmed with Konbini and ‘expires_after_days` set to 2 on Monday JST, the instructions will expire on Wednesday 23:59:59 JST. Defaults to 3 days.



4411
4412
4413
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4411

def expires_after_days
  @expires_after_days
end

#expires_atObject

The timestamp at which the Konbini payment instructions will expire. Only one of ‘expires_after_days` or `expires_at` may be set.



4413
4414
4415
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4413

def expires_at
  @expires_at
end

#product_descriptionObject

A product descriptor of up to 22 characters, which will appear to customers at the convenience store.



4415
4416
4417
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4415

def product_description
  @product_description
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



4425
4426
4427
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4425

def setup_future_usage
  @setup_future_usage
end