Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



5289
5290
5291
5292
5293
5294
5295
5296
5297
5298
5299
5300
5301
5302
5303
5304
5305
5306
5307
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5289

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



5273
5274
5275
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5273

def category
  @category
end

#descriptionObject

Description of the line item.



5275
5276
5277
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5275

def description
  @description
end

#nameObject

Descriptive name of the line item.



5277
5278
5279
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5277

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



5279
5280
5281
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5279

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



5281
5282
5283
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5281

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



5283
5284
5285
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5283

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



5285
5286
5287
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5285

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



5287
5288
5289
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5287

def unit_amount
  @unit_amount
end