Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
5255 5256 5257 5258 5259 5260 5261 5262 5263 5264 5265 5266 5267 5268 5269 5270 5271 5272 5273 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5255 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
5239 5240 5241 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5239 def category @category end |
#description ⇒ Object
Description of the line item.
5241 5242 5243 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5241 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
5243 5244 5245 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5243 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
5245 5246 5247 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5245 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
5247 5248 5249 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5247 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
5249 5250 5251 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5249 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
5251 5252 5253 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5251 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
5253 5254 5255 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5253 def unit_amount @unit_amount end |