Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
5275 5276 5277 5278 5279 5280 5281 5282 5283 5284 5285 5286 5287 5288 5289 5290 5291 5292 5293 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5275 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
5259 5260 5261 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5259 def category @category end |
#description ⇒ Object
Description of the line item.
5261 5262 5263 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5261 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
5263 5264 5265 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5263 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
5265 5266 5267 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5265 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
5267 5268 5269 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5267 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
5269 5270 5271 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5269 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
5271 5272 5273 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5271 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
5273 5274 5275 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5273 def unit_amount @unit_amount end |