Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



4743
4744
4745
4746
4747
4748
4749
4750
4751
4752
4753
4754
4755
4756
4757
4758
4759
4760
4761
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4743

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



4727
4728
4729
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4727

def category
  @category
end

#descriptionObject

Description of the line item.



4729
4730
4731
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4729

def description
  @description
end

#nameObject

Descriptive name of the line item.



4731
4732
4733
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4731

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



4733
4734
4735
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4733

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



4735
4736
4737
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4735

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



4737
4738
4739
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4737

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



4739
4740
4741
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4739

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



4741
4742
4743
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4741

def unit_amount
  @unit_amount
end