Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



4847
4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
4861
4862
4863
4864
4865
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4847

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



4831
4832
4833
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4831

def category
  @category
end

#descriptionObject

Description of the line item.



4833
4834
4835
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4833

def description
  @description
end

#nameObject

Descriptive name of the line item.



4835
4836
4837
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4835

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



4837
4838
4839
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4837

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



4839
4840
4841
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4839

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



4841
4842
4843
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4841

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



4843
4844
4845
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4843

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



4845
4846
4847
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4845

def unit_amount
  @unit_amount
end