Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



4786
4787
4788
4789
4790
4791
4792
4793
4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4786

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



4770
4771
4772
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4770

def category
  @category
end

#descriptionObject

Description of the line item.



4772
4773
4774
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4772

def description
  @description
end

#nameObject

Descriptive name of the line item.



4774
4775
4776
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4774

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



4776
4777
4778
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4776

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



4778
4779
4780
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4778

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



4780
4781
4782
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4780

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



4782
4783
4784
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4782

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



4784
4785
4786
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4784

def unit_amount
  @unit_amount
end