Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
2778 2779 2780 2781 2782 2783 2784 2785 2786 2787 2788 2789 2790 2791 2792 2793 2794 2795 2796 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2778 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
2762 2763 2764 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2762 def category @category end |
#description ⇒ Object
Description of the line item.
2764 2765 2766 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2764 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
2766 2767 2768 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2766 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
2768 2769 2770 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2768 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
2770 2771 2772 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2770 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
2772 2773 2774 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2772 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
2774 2775 2776 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2774 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
2776 2777 2778 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2776 def unit_amount @unit_amount end |