Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The tax for a single unit of the line item in minor units.
-
#behavior ⇒ Object
The tax behavior for the line item.
Instance Method Summary collapse
-
#initialize(amount: nil, behavior: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, behavior: nil) ⇒ Tax
Returns a new instance of Tax.
4709 4710 4711 4712 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4709 def initialize(amount: nil, behavior: nil) @amount = amount @behavior = behavior end |
Instance Attribute Details
#amount ⇒ Object
The tax for a single unit of the line item in minor units. Cannot be a negative number.
4705 4706 4707 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4705 def amount @amount end |
#behavior ⇒ Object
The tax behavior for the line item.
4707 4708 4709 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4707 def behavior @behavior end |