Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The tax for a single unit of the line item in minor units.
-
#behavior ⇒ Object
The tax behavior for the line item.
Instance Method Summary collapse
-
#initialize(amount: nil, behavior: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, behavior: nil) ⇒ Tax
Returns a new instance of Tax.
2756 2757 2758 2759 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2756 def initialize(amount: nil, behavior: nil) @amount = amount @behavior = behavior end |
Instance Attribute Details
#amount ⇒ Object
The tax for a single unit of the line item in minor units. Cannot be a negative number.
2752 2753 2754 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2752 def amount @amount end |
#behavior ⇒ Object
The tax behavior for the line item.
2754 2755 2756 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2754 def behavior @behavior end |