Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Pix
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Pix
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: MandateOptions
Instance Attribute Summary collapse
-
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax.
-
#expires_after_seconds ⇒ Object
The number of seconds (between 10 and 1209600) after which Pix payment will expire.
-
#expires_at ⇒ Object
The timestamp at which the Pix expires (between 10 and 1209600 seconds in the future).
-
#mandate_options ⇒ Object
Additional fields for mandate creation.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Instance Method Summary collapse
-
#initialize(amount_includes_iof: nil, expires_after_seconds: nil, expires_at: nil, mandate_options: nil, setup_future_usage: nil) ⇒ Pix
constructor
A new instance of Pix.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount_includes_iof: nil, expires_after_seconds: nil, expires_at: nil, mandate_options: nil, setup_future_usage: nil) ⇒ Pix
Returns a new instance of Pix.
2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2124 def initialize( amount_includes_iof: nil, expires_after_seconds: nil, expires_at: nil, mandate_options: nil, setup_future_usage: nil ) @amount_includes_iof = amount_includes_iof @expires_after_seconds = expires_after_seconds @expires_at = expires_at @mandate_options = @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax. Defaults to never.
2108 2109 2110 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2108 def amount_includes_iof @amount_includes_iof end |
#expires_after_seconds ⇒ Object
The number of seconds (between 10 and 1209600) after which Pix payment will expire. Defaults to 86400 seconds.
2110 2111 2112 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2110 def expires_after_seconds @expires_after_seconds end |
#expires_at ⇒ Object
The timestamp at which the Pix expires (between 10 and 1209600 seconds in the future). Defaults to 1 day in the future.
2112 2113 2114 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2112 def expires_at @expires_at end |
#mandate_options ⇒ Object
Additional fields for mandate creation. Only applicable when setup_future_usage=off_session.
2114 2115 2116 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2114 def @mandate_options end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
2122 2123 2124 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2122 def setup_future_usage @setup_future_usage end |