Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Pix::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Pix::MandateOptions
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments.
-
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax.
-
#amount_type ⇒ Object
Type of amount.
-
#currency ⇒ Object
Three-letter ISO currency code, in lowercase.
-
#end_date ⇒ Object
Date when the mandate expires and no further payments will be charged, in
YYYY-MM-DD. -
#payment_schedule ⇒ Object
Schedule at which the future payments will be charged.
-
#reference ⇒ Object
Subscription name displayed to buyers in their bank app.
-
#start_date ⇒ Object
Start date of the mandate, in
YYYY-MM-DD.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
4912 4913 4914 4915 4916 4917 4918 4919 4920 4921 4922 4923 4924 4925 4926 4927 4928 4929 4930 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4912 def initialize( amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil ) @amount = amount @amount_includes_iof = amount_includes_iof @amount_type = amount_type @currency = currency @end_date = end_date @payment_schedule = payment_schedule @reference = reference @start_date = start_date end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments. Required when amount_type=fixed. If not provided for amount_type=maximum, defaults to 40000.
4896 4897 4898 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4896 def amount @amount end |
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax. Defaults to never.
4898 4899 4900 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4898 def amount_includes_iof @amount_includes_iof end |
#amount_type ⇒ Object
Type of amount. Defaults to maximum.
4900 4901 4902 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4900 def amount_type @amount_type end |
#currency ⇒ Object
Three-letter ISO currency code, in lowercase. Only brl is supported currently.
4902 4903 4904 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4902 def currency @currency end |
#end_date ⇒ Object
Date when the mandate expires and no further payments will be charged, in YYYY-MM-DD. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.
4904 4905 4906 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4904 def end_date @end_date end |
#payment_schedule ⇒ Object
Schedule at which the future payments will be charged. Defaults to monthly.
4906 4907 4908 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4906 def payment_schedule @payment_schedule end |
#reference ⇒ Object
Subscription name displayed to buyers in their bank app. Defaults to the displayable business name.
4908 4909 4910 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4908 def reference @reference end |
#start_date ⇒ Object
Start date of the mandate, in YYYY-MM-DD. Start date should be at least 3 days in the future. Defaults to 3 days after the current date.
4910 4911 4912 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 4910 def start_date @start_date end |