Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::StripeBalance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: MandateOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(setup_future_usage: nil, mandate_options: nil) ⇒ StripeBalance

Returns a new instance of StripeBalance.



5162
5163
5164
5165
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5162

def initialize(setup_future_usage: nil, mandate_options: nil)
  @setup_future_usage = setup_future_usage
  @mandate_options = mandate_options
end

Instance Attribute Details

#mandate_optionsObject

Additional fields for mandate creation.



5160
5161
5162
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5160

def mandate_options
  @mandate_options
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



5158
5159
5160
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5158

def setup_future_usage
  @setup_future_usage
end