Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Swish
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Swish
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#reference ⇒ Object
A reference for this payment to be displayed in the Swish app.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Instance Method Summary collapse
-
#initialize(reference: nil, setup_future_usage: nil) ⇒ Swish
constructor
A new instance of Swish.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(reference: nil, setup_future_usage: nil) ⇒ Swish
Returns a new instance of Swish.
5200 5201 5202 5203 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5200 def initialize(reference: nil, setup_future_usage: nil) @reference = reference @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#reference ⇒ Object
A reference for this payment to be displayed in the Swish app.
5188 5189 5190 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5188 def reference @reference end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.
5198 5199 5200 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5198 def setup_future_usage @setup_future_usage end |