Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2356
2357
2358
2359
2360
2361
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2356

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



2348
2349
2350
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2348

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



2350
2351
2352
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2350

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



2352
2353
2354
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2352

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



2354
2355
2356
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2354

def end_date
  @end_date
end