Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Upi::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Upi::MandateOptions
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments.
-
#amount_type ⇒ Object
One of
fixedormaximum. -
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
-
#end_date ⇒ Object
End date of the mandate or subscription.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
5234 5235 5236 5237 5238 5239 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5234 def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) @amount = amount @amount_type = amount_type @description = description @end_date = end_date end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments.
5226 5227 5228 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5226 def amount @amount end |
#amount_type ⇒ Object
One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.
5228 5229 5230 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5228 def amount_type @amount_type end |
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
5230 5231 5232 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5230 def description @description end |
#end_date ⇒ Object
End date of the mandate or subscription.
5232 5233 5234 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5232 def end_date @end_date end |