Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



5160
5161
5162
5163
5164
5165
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5160

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



5152
5153
5154
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5152

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



5154
5155
5156
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5154

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



5156
5157
5158
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5156

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



5158
5159
5160
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5158

def end_date
  @end_date
end