Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



5277
5278
5279
5280
5281
5282
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5277

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



5269
5270
5271
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5269

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



5271
5272
5273
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5271

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



5273
5274
5275
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5273

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



5275
5276
5277
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5275

def end_date
  @end_date
end