Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
5246
5247
5248
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5236

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



5226
5227
5228
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5226

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



5228
5229
5230
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5228

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



5230
5231
5232
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5230

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



5232
5233
5234
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5232

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



5234
5235
5236
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5234

def return_url
  @return_url
end