Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



5211
5212
5213
5214
5215
5216
5217
5218
5219
5220
5221
5222
5223
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5211

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



5201
5202
5203
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5201

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



5203
5204
5205
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5203

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



5205
5206
5207
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5205

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



5207
5208
5209
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5207

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



5209
5210
5211
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5209

def return_url
  @return_url
end