Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Filters, ManualEntry
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#manual_entry ⇒ Object
Customize manual entry behavior.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
5172 5173 5174 5175 5176 5177 5178 5179 5180 5181 5182 5183 5184 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5172 def initialize( filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil ) @filters = filters @manual_entry = manual_entry @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
5162 5163 5164 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5162 def filters @filters end |
#manual_entry ⇒ Object
Customize manual entry behavior
5164 5165 5166 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5164 def manual_entry @manual_entry end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
5166 5167 5168 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5166 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
5168 5169 5170 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5168 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
5170 5171 5172 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5170 def return_url @return_url end |