Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Filters
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(filters: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
2217 2218 2219 2220 2221 2222 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2217 def initialize(filters: nil, permissions: nil, prefetch: nil, return_url: nil) @filters = filters @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
2209 2210 2211 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2209 def filters @filters end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
2211 2212 2213 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2211 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
2213 2214 2215 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2213 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
2215 2216 2217 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2215 def return_url @return_url end |