Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Filters

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



1912
1913
1914
1915
1916
1917
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1912

def initialize(filters: nil, permissions: nil, prefetch: nil, return_url: nil)
  @filters = filters
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



1904
1905
1906
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1904

def filters
  @filters
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



1906
1907
1908
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1906

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



1908
1909
1910
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1908

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



1910
1911
1912
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 1910

def return_url
  @return_url
end