Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Filters, ManualEntry
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#manual_entry ⇒ Object
Customize manual entry behavior.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
3219 3220 3221 3222 3223 3224 3225 3226 3227 3228 3229 3230 3231 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3219 def initialize( filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil ) @filters = filters @manual_entry = manual_entry @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
3209 3210 3211 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3209 def filters @filters end |
#manual_entry ⇒ Object
Customize manual entry behavior
3211 3212 3213 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3211 def manual_entry @manual_entry end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
3213 3214 3215 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3213 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
3215 3216 3217 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3215 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
3217 3218 3219 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3217 def return_url @return_url end |