Class: Stripe::PaymentIntentConfirmParams::PaymentMethodOptions::WechatPay

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(app_id: nil, client: nil, setup_future_usage: nil) ⇒ WechatPay

Returns a new instance of WechatPay.



5224
5225
5226
5227
5228
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5224

def initialize(app_id: nil, client: nil, setup_future_usage: nil)
  @app_id = app_id
  @client = client
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#app_idObject

The app ID registered with WeChat Pay. Only required when client is ios or android.



5210
5211
5212
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5210

def app_id
  @app_id
end

#clientObject

The client type that the end customer will pay from



5212
5213
5214
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5212

def client
  @client
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



5222
5223
5224
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5222

def setup_future_usage
  @setup_future_usage
end