Class: Stripe::PaymentIntentConfirmParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



2783
2784
2785
2786
2787
2788
2789
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2783

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



2773
2774
2775
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2773

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



2775
2776
2777
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2775

def carrier
  @carrier
end

#nameObject

Recipient name.



2777
2778
2779
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2777

def name
  @name
end

#phoneObject

Recipient phone (including extension).



2779
2780
2781
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2779

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



2781
2782
2783
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2781

def tracking_number
  @tracking_number
end