Class: Stripe::PaymentIntentConfirmParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



5689
5690
5691
5692
5693
5694
5695
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5689

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



5679
5680
5681
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5679

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



5681
5682
5683
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5681

def carrier
  @carrier
end

#nameObject

Recipient name.



5683
5684
5685
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5683

def name
  @name
end

#phoneObject

Recipient phone (including extension).



5685
5686
5687
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5685

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



5687
5688
5689
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5687

def tracking_number
  @tracking_number
end