Class: Stripe::PaymentIntentConfirmParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



6203
6204
6205
6206
6207
6208
6209
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6203

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



6193
6194
6195
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6193

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



6195
6196
6197
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6195

def carrier
  @carrier
end

#nameObject

Recipient name.



6197
6198
6199
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6197

def name
  @name
end

#phoneObject

Recipient phone (including extension).



6199
6200
6201
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6199

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



6201
6202
6203
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6201

def tracking_number
  @tracking_number
end