Class: Stripe::PaymentIntentConfirmParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::Shipping
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
6212 6213 6214 6215 6216 6217 6218 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6212 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
6202 6203 6204 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6202 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
6204 6205 6206 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6204 def carrier @carrier end |
#name ⇒ Object
Recipient name.
6206 6207 6208 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6206 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
6208 6209 6210 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6208 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
6210 6211 6212 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6210 def tracking_number @tracking_number end |