Class: Stripe::PaymentIntentConfirmParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::Shipping
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
5654 5655 5656 5657 5658 5659 5660 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5654 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
5644 5645 5646 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5644 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
5646 5647 5648 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5646 def carrier @carrier end |
#name ⇒ Object
Recipient name.
5648 5649 5650 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5648 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
5650 5651 5652 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5650 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
5652 5653 5654 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5652 def tracking_number @tracking_number end |