Class: Stripe::PaymentIntentConfirmParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



6144
6145
6146
6147
6148
6149
6150
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6144

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



6134
6135
6136
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6134

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



6136
6137
6138
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6136

def carrier
  @carrier
end

#nameObject

Recipient name.



6138
6139
6140
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6138

def name
  @name
end

#phoneObject

Recipient phone (including extension).



6140
6141
6142
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6140

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



6142
6143
6144
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6142

def tracking_number
  @tracking_number
end