Class: Stripe::PaymentIntentConfirmParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::Shipping
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
6161 6162 6163 6164 6165 6166 6167 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6161 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
6151 6152 6153 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6151 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
6153 6154 6155 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6153 def carrier @carrier end |
#name ⇒ Object
Recipient name.
6155 6156 6157 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6155 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
6157 6158 6159 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6157 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
6159 6160 6161 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 6159 def tracking_number @tracking_number end |