Class: Stripe::PaymentIntentConfirmParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



5621
5622
5623
5624
5625
5626
5627
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5621

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



5611
5612
5613
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5611

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



5613
5614
5615
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5613

def carrier
  @carrier
end

#nameObject

Recipient name.



5615
5616
5617
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5615

def name
  @name
end

#phoneObject

Recipient phone (including extension).



5617
5618
5619
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5617

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



5619
5620
5621
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5619

def tracking_number
  @tracking_number
end