Class: Stripe::PaymentIntentConfirmParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



5738
5739
5740
5741
5742
5743
5744
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5738

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



5728
5729
5730
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5728

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



5730
5731
5732
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5730

def carrier
  @carrier
end

#nameObject

Recipient name.



5732
5733
5734
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5732

def name
  @name
end

#phoneObject

Recipient phone (including extension).



5734
5735
5736
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5734

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



5736
5737
5738
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5736

def tracking_number
  @tracking_number
end