Class: Stripe::PaymentIntentConfirmParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::Shipping
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5677 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
5667 5668 5669 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5667 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
5669 5670 5671 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5669 def carrier @carrier end |
#name ⇒ Object
Recipient name.
5671 5672 5673 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5671 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
5673 5674 5675 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5673 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
5675 5676 5677 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5675 def tracking_number @tracking_number end |