Class: Stripe::PaymentIntentConfirmParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



5582
5583
5584
5585
5586
5587
5588
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5582

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



5572
5573
5574
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5572

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



5574
5575
5576
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5574

def carrier
  @carrier
end

#nameObject

Recipient name.



5576
5577
5578
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5576

def name
  @name
end

#phoneObject

Recipient phone (including extension).



5578
5579
5580
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5578

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



5580
5581
5582
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5580

def tracking_number
  @tracking_number
end