Class: Stripe::PaymentIntentConfirmParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::Shipping
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
5596 5597 5598 5599 5600 5601 5602 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5596 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
5586 5587 5588 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5586 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
5588 5589 5590 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5588 def carrier @carrier end |
#name ⇒ Object
Recipient name.
5590 5591 5592 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5590 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
5592 5593 5594 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5592 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
5594 5595 5596 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5594 def tracking_number @tracking_number end |