Class: Stripe::PaymentIntentConfirmParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



5570
5571
5572
5573
5574
5575
5576
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5570

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



5560
5561
5562
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5560

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



5562
5563
5564
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5562

def carrier
  @carrier
end

#nameObject

Recipient name.



5564
5565
5566
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5564

def name
  @name
end

#phoneObject

Recipient phone (including extension).



5566
5567
5568
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5566

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



5568
5569
5570
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5568

def tracking_number
  @tracking_number
end