Class: Stripe::PaymentIntentConfirmParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::Shipping
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
5557 5558 5559 5560 5561 5562 5563 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5557 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
5547 5548 5549 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5547 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
5549 5550 5551 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5549 def carrier @carrier end |
#name ⇒ Object
Recipient name.
5551 5552 5553 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5551 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
5553 5554 5555 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5553 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
5555 5556 5557 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 5555 def tracking_number @tracking_number end |