Class: Stripe::PaymentIntentConfirmParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



3646
3647
3648
3649
3650
3651
3652
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3646

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



3636
3637
3638
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3636

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



3638
3639
3640
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3638

def carrier
  @carrier
end

#nameObject

Recipient name.



3640
3641
3642
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3640

def name
  @name
end

#phoneObject

Recipient phone (including extension).



3642
3643
3644
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3642

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



3644
3645
3646
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3644

def tracking_number
  @tracking_number
end