Class: Stripe::PaymentIntentConfirmParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentConfirmParams::Shipping
- Defined in:
- lib/stripe/params/payment_intent_confirm_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
3646 3647 3648 3649 3650 3651 3652 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3646 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
3636 3637 3638 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3636 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
3638 3639 3640 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3638 def carrier @carrier end |
#name ⇒ Object
Recipient name.
3640 3641 3642 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3640 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
3642 3643 3644 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3642 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
3644 3645 3646 |
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 3644 def tracking_number @tracking_number end |