Class: Stripe::PaymentIntentConfirmParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_confirm_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



2279
2280
2281
2282
2283
2284
2285
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2279

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



2269
2270
2271
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2269

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



2271
2272
2273
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2271

def carrier
  @carrier
end

#nameObject

Recipient name.



2273
2274
2275
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2273

def name
  @name
end

#phoneObject

Recipient phone (including extension).



2275
2276
2277
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2275

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



2277
2278
2279
# File 'lib/stripe/params/payment_intent_confirm_params.rb', line 2277

def tracking_number
  @tracking_number
end