Class: Stripe::PaymentIntentCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: AmountDetails, AutomaticPaymentMethods, Hooks, MandateData, PaymentDetails, PaymentMethodData, PaymentMethodOptions, RadarOptions, Shipping, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(allowed_payment_method_types: nil, amount: nil, amount_details: nil, application_fee_amount: nil, automatic_payment_methods: nil, capture_method: nil, confirm: nil, confirmation_method: nil, confirmation_token: nil, currency: nil, customer: nil, customer_account: nil, description: nil, error_on_requires_action: nil, excluded_payment_method_types: nil, expand: nil, fx_quote: nil, hooks: nil, mandate: nil, mandate_data: nil, metadata: nil, off_session: nil, on_behalf_of: nil, payment_details: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, radar_options: nil, receipt_email: nil, return_url: nil, secret_key_confirmation: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil, use_stripe_sdk: nil) ⇒ PaymentIntentCreateParams

Returns a new instance of PaymentIntentCreateParams.



5885
5886
5887
5888
5889
5890
5891
5892
5893
5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
5919
5920
5921
5922
5923
5924
5925
5926
5927
5928
5929
5930
5931
5932
5933
5934
5935
5936
5937
5938
5939
5940
5941
5942
5943
5944
5945
5946
5947
5948
5949
5950
5951
5952
5953
5954
5955
5956
5957
5958
5959
5960
5961
5962
5963
5964
5965
5966
5967
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5885

def initialize(
  allowed_payment_method_types: nil,
  amount: nil,
  amount_details: nil,
  application_fee_amount: nil,
  automatic_payment_methods: nil,
  capture_method: nil,
  confirm: nil,
  confirmation_method: nil,
  confirmation_token: nil,
  currency: nil,
  customer: nil,
  customer_account: nil,
  description: nil,
  error_on_requires_action: nil,
  excluded_payment_method_types: nil,
  expand: nil,
  fx_quote: nil,
  hooks: nil,
  mandate: nil,
  mandate_data: nil,
  metadata: nil,
  off_session: nil,
  on_behalf_of: nil,
  payment_details: nil,
  payment_method: nil,
  payment_method_configuration: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  radar_options: nil,
  receipt_email: nil,
  return_url: nil,
  secret_key_confirmation: nil,
  setup_future_usage: nil,
  shipping: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil,
  transfer_group: nil,
  use_stripe_sdk: nil
)
  @allowed_payment_method_types = allowed_payment_method_types
  @amount = amount
  @amount_details = amount_details
  @application_fee_amount = application_fee_amount
  @automatic_payment_methods = automatic_payment_methods
  @capture_method = capture_method
  @confirm = confirm
  @confirmation_method = confirmation_method
  @confirmation_token = confirmation_token
  @currency = currency
  @customer = customer
  @customer_account = 
  @description = description
  @error_on_requires_action = error_on_requires_action
  @excluded_payment_method_types = excluded_payment_method_types
  @expand = expand
  @fx_quote = fx_quote
  @hooks = hooks
  @mandate = mandate
  @mandate_data = mandate_data
  @metadata = 
  @off_session = off_session
  @on_behalf_of = on_behalf_of
  @payment_details = payment_details
  @payment_method = payment_method
  @payment_method_configuration = payment_method_configuration
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @radar_options = radar_options
  @receipt_email = receipt_email
  @return_url = return_url
  @secret_key_confirmation = secret_key_confirmation
  @setup_future_usage = setup_future_usage
  @shipping = shipping
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
  @transfer_group = transfer_group
  @use_stripe_sdk = use_stripe_sdk
end

Instance Attribute Details

#allowed_payment_method_typesObject

The list of payment method types allowed for use with this payment. Stripe automatically returns compatible payment methods from this list in the payment_method_types field of the response, based on the other PaymentIntent parameters, such as currency, amount, and customer.



5780
5781
5782
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5780

def allowed_payment_method_types
  @allowed_payment_method_types
end

#amountObject

Amount intended to be collected by this PaymentIntent. A positive integer representing how much to charge in the smallest currency unit (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or equivalent in charge currency. The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).



5782
5783
5784
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5782

def amount
  @amount
end

#amount_detailsObject

Provides industry-specific information about the amount.



5784
5785
5786
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5784

def amount_details
  @amount_details
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents use case for connected accounts.



5786
5787
5788
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5786

def application_fee_amount
  @application_fee_amount
end

#automatic_payment_methodsObject

When you enable this parameter, this PaymentIntent accepts payment methods that you enable in the Dashboard and that are compatible with this PaymentIntent's other parameters.



5788
5789
5790
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5788

def automatic_payment_methods
  @automatic_payment_methods
end

#capture_methodObject

Controls when the funds will be captured from the customer's account.



5790
5791
5792
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5790

def capture_method
  @capture_method
end

#confirmObject

Set to true to attempt to confirm this PaymentIntent immediately. This parameter defaults to false. When creating and confirming a PaymentIntent at the same time, you can also provide the parameters available in the Confirm API.



5792
5793
5794
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5792

def confirm
  @confirm
end

#confirmation_methodObject

Describes whether we can confirm this PaymentIntent automatically, or if it requires customer action to confirm the payment.



5794
5795
5796
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5794

def confirmation_method
  @confirmation_method
end

#confirmation_tokenObject

ID of the ConfirmationToken used to confirm this PaymentIntent.

If the provided ConfirmationToken contains properties that are also being provided in this request, such as payment_method, then the values in this request will take precedence.



5798
5799
5800
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5798

def confirmation_token
  @confirmation_token
end

#currencyObject

Three-letter ISO currency code, in lowercase. Must be a supported currency.



5800
5801
5802
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5800

def currency
  @currency
end

#customerObject

ID of the Customer this PaymentIntent belongs to, if one exists.

Payment methods attached to other Customers cannot be used with this PaymentIntent.

If setup_future_usage is set and this PaymentIntent's payment method is not card_present, then the payment method attaches to the Customer after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is card_present and isn't a digital wallet, then a generated_card payment method representing the card is created and attached to the Customer instead.



5806
5807
5808
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5806

def customer
  @customer
end

#customer_accountObject

ID of the Account representing the customer that this PaymentIntent belongs to, if one exists.

Payment methods attached to other Accounts cannot be used with this PaymentIntent.

If setup_future_usage is set and this PaymentIntent's payment method is not card_present, then the payment method attaches to the Account after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is card_present and isn't a digital wallet, then a generated_card payment method representing the card is created and attached to the Account instead.



5812
5813
5814
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5812

def 
  @customer_account
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



5814
5815
5816
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5814

def description
  @description
end

#error_on_requires_actionObject

Set to true to fail the payment attempt if the PaymentIntent transitions into requires_action. Use this parameter for simpler integrations that don't handle customer actions, such as saving cards without authentication. This parameter can only be used with confirm=true.



5816
5817
5818
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5816

def error_on_requires_action
  @error_on_requires_action
end

#excluded_payment_method_typesObject

The list of payment method types to exclude from use with this payment.



5818
5819
5820
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5818

def excluded_payment_method_types
  @excluded_payment_method_types
end

#expandObject

Specifies which fields in the response should be expanded.



5820
5821
5822
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5820

def expand
  @expand
end

#fx_quoteObject

The FX rate in the quote is validated and used to convert the presentment amount to the settlement amount.



5822
5823
5824
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5822

def fx_quote
  @fx_quote
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



5824
5825
5826
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5824

def hooks
  @hooks
end

#mandateObject

ID of the mandate that's used for this payment. This parameter can only be used with confirm=true.



5826
5827
5828
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5826

def mandate
  @mandate
end

#mandate_dataObject

This hash contains details about the Mandate to create. This parameter can only be used with confirm=true.



5828
5829
5830
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5828

def mandate_data
  @mandate_data
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



5830
5831
5832
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5830

def 
  @metadata
end

#off_sessionObject

Set to true to indicate that the customer isn't in your checkout flow during this payment attempt and can't authenticate. Use this parameter in scenarios where you collect payment method details and charge them later. This parameter can only be used with confirm=true.



5832
5833
5834
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5832

def off_session
  @off_session
end

#on_behalf_ofObject

The Stripe account ID that these funds are intended for. Learn more about the use case for connected accounts.



5834
5835
5836
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5834

def on_behalf_of
  @on_behalf_of
end

#payment_detailsObject

Provides industry-specific information about the charge.



5836
5837
5838
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5836

def payment_details
  @payment_details
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or compatible Source object) to attach to this PaymentIntent.

If you don't provide the payment_method parameter or the source parameter with confirm=true, source automatically populates with customer.default_source to improve migration for users of the Charges API. We recommend that you explicitly provide the payment_method moving forward. If the payment method is attached to a Customer, you must also provide the ID of that Customer as the customer parameter of this PaymentIntent. end



5842
5843
5844
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5842

def payment_method
  @payment_method
end

#payment_method_configurationObject

The ID of the payment method configuration to use with this PaymentIntent.



5844
5845
5846
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5844

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the payment_method property on the PaymentIntent.



5848
5849
5850
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5848

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this PaymentIntent.



5850
5851
5852
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5850

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, a card) that this PaymentIntent can use. If you don't provide this, Stripe will dynamically show relevant payment methods from your payment method settings. A list of valid payment method types can be found here.



5852
5853
5854
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5852

def payment_method_types
  @payment_method_types
end

#radar_optionsObject

Options to configure Radar. Learn more about Radar Sessions.



5854
5855
5856
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5854

def radar_options
  @radar_options
end

#receipt_emailObject

Email address to send the receipt to. If you specify receipt_email for a payment in live mode, you send a receipt regardless of your email settings.



5856
5857
5858
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5856

def receipt_email
  @receipt_email
end

#return_urlObject

The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method's app or site. If you'd prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter can only be used with confirm=true.



5858
5859
5860
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5858

def return_url
  @return_url
end

#secret_key_confirmationObject

Indicates whether confirmation for this PaymentIntent using a secret key is required or optional.



5860
5861
5862
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5860

def secret_key_confirmation
  @secret_key_confirmation
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.



5868
5869
5870
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5868

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this PaymentIntent.



5870
5871
5872
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5870

def shipping
  @shipping
end

#statement_descriptorObject

Text that appears on the customer's statement as the statement descriptor for a non-card charge. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see the Statement Descriptor docs.

Setting this value for a card charge returns an error. For card charges, set the statement_descriptor_suffix instead.



5874
5875
5876
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5874

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account's statement descriptor prefix to form the complete statement descriptor that appears on the customer's statement.



5876
5877
5878
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5876

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

The parameters that you can use to automatically create a Transfer. Learn more about the use case for connected accounts.



5879
5880
5881
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5879

def transfer_data
  @transfer_data
end

#transfer_groupObject

A string that identifies the resulting payment as part of a group. Learn more about the use case for connected accounts.



5881
5882
5883
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5881

def transfer_group
  @transfer_group
end

#use_stripe_sdkObject

Set to true when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.



5883
5884
5885
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5883

def use_stripe_sdk
  @use_stripe_sdk
end