Class: Stripe::PaymentIntentCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: AmountDetails, AutomaticPaymentMethods, Hooks, MandateData, PaymentDetails, PaymentMethodData, PaymentMethodOptions, RadarOptions, Shipping, TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount intended to be collected by this PaymentIntent.
-
#amount_details ⇒ Object
Provides industry-specific information about the amount.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#automatic_payment_methods ⇒ Object
When you enable this parameter, this PaymentIntent accepts payment methods that you enable in the Dashboard and that are compatible with this PaymentIntent’s other parameters.
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
-
#confirm ⇒ Object
Set to ‘true` to attempt to [confirm this PaymentIntent](docs.stripe.com/api/payment_intents/confirm) immediately.
-
#confirmation_method ⇒ Object
Describes whether we can confirm this PaymentIntent automatically, or if it requires customer action to confirm the payment.
-
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this PaymentIntent.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
ID of the Customer this PaymentIntent belongs to, if one exists.
-
#customer_account ⇒ Object
ID of the Account representing the customer that this PaymentIntent belongs to, if one exists.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#error_on_requires_action ⇒ Object
Set to ‘true` to fail the payment attempt if the PaymentIntent transitions into `requires_action`.
-
#excluded_payment_method_types ⇒ Object
The list of payment method types to exclude from use with this payment.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle.
-
#mandate ⇒ Object
ID of the mandate that’s used for this payment.
-
#mandate_data ⇒ Object
This hash contains details about the Mandate to create.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#off_session ⇒ Object
Set to ‘true` to indicate that the customer isn’t in your checkout flow during this payment attempt and can’t authenticate.
-
#on_behalf_of ⇒ Object
The Stripe account ID that these funds are intended for.
-
#payment_details ⇒ Object
Provides industry-specific information about the charge.
-
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or [compatible Source](docs.stripe.com/payments/payment-methods#compatibility) object) to attach to this PaymentIntent.
-
#payment_method_configuration ⇒ Object
The ID of the [payment method configuration](docs.stripe.com/api/payment_method_configurations) to use with this PaymentIntent.
-
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod.
-
#payment_method_options ⇒ Object
Payment method-specific configuration for this PaymentIntent.
-
#payment_method_types ⇒ Object
The list of payment method types (for example, a card) that this PaymentIntent can use.
-
#radar_options ⇒ Object
Options to configure Radar.
-
#receipt_email ⇒ Object
Email address to send the receipt to.
-
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#shipping ⇒ Object
Shipping information for this PaymentIntent.
-
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card charge.
-
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge.
-
#transfer_data ⇒ Object
The parameters that you can use to automatically create a Transfer.
-
#transfer_group ⇒ Object
A string that identifies the resulting payment as part of a group.
-
#use_stripe_sdk ⇒ Object
Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_details: nil, application_fee_amount: nil, automatic_payment_methods: nil, capture_method: nil, confirm: nil, confirmation_method: nil, confirmation_token: nil, currency: nil, customer: nil, customer_account: nil, description: nil, error_on_requires_action: nil, excluded_payment_method_types: nil, expand: nil, hooks: nil, mandate: nil, mandate_data: nil, metadata: nil, off_session: nil, on_behalf_of: nil, payment_details: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil, use_stripe_sdk: nil) ⇒ PaymentIntentCreateParams
Returns a new instance of PaymentIntentCreateParams.
2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2896 def initialize( amount: nil, amount_details: nil, application_fee_amount: nil, automatic_payment_methods: nil, capture_method: nil, confirm: nil, confirmation_method: nil, confirmation_token: nil, currency: nil, customer: nil, customer_account: nil, description: nil, error_on_requires_action: nil, excluded_payment_method_types: nil, expand: nil, hooks: nil, mandate: nil, mandate_data: nil, metadata: nil, off_session: nil, on_behalf_of: nil, payment_details: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil, use_stripe_sdk: nil ) @amount = amount @amount_details = amount_details @application_fee_amount = application_fee_amount @automatic_payment_methods = automatic_payment_methods @capture_method = capture_method @confirm = confirm @confirmation_method = confirmation_method @confirmation_token = confirmation_token @currency = currency @customer = customer @customer_account = customer_account @description = description @error_on_requires_action = error_on_requires_action @excluded_payment_method_types = excluded_payment_method_types @expand = @hooks = hooks @mandate = mandate @mandate_data = mandate_data @metadata = @off_session = off_session @on_behalf_of = on_behalf_of @payment_details = payment_details @payment_method = payment_method @payment_method_configuration = payment_method_configuration @payment_method_data = payment_method_data @payment_method_options = @payment_method_types = payment_method_types @radar_options = @receipt_email = receipt_email @return_url = return_url @setup_future_usage = setup_future_usage @shipping = shipping @statement_descriptor = statement_descriptor @statement_descriptor_suffix = statement_descriptor_suffix @transfer_data = transfer_data @transfer_group = transfer_group @use_stripe_sdk = use_stripe_sdk end |
Instance Attribute Details
#amount ⇒ Object
Amount intended to be collected by this PaymentIntent. A positive integer representing how much to charge in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge currency](docs.stripe.com/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).
2797 2798 2799 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2797 def amount @amount end |
#amount_details ⇒ Object
Provides industry-specific information about the amount.
2799 2800 2801 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2799 def amount_details @amount_details end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](docs.stripe.com/payments/connected-accounts).
2801 2802 2803 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2801 def application_fee_amount @application_fee_amount end |
#automatic_payment_methods ⇒ Object
When you enable this parameter, this PaymentIntent accepts payment methods that you enable in the Dashboard and that are compatible with this PaymentIntent’s other parameters.
2803 2804 2805 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2803 def automatic_payment_methods @automatic_payment_methods end |
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
2805 2806 2807 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2805 def capture_method @capture_method end |
#confirm ⇒ Object
Set to ‘true` to attempt to [confirm this PaymentIntent](docs.stripe.com/api/payment_intents/confirm) immediately. This parameter defaults to `false`. When creating and confirming a PaymentIntent at the same time, you can also provide the parameters available in the [Confirm API](docs.stripe.com/api/payment_intents/confirm).
2807 2808 2809 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2807 def confirm @confirm end |
#confirmation_method ⇒ Object
Describes whether we can confirm this PaymentIntent automatically, or if it requires customer action to confirm the payment.
2809 2810 2811 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2809 def confirmation_method @confirmation_method end |
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this PaymentIntent.
If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.
2813 2814 2815 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2813 def confirmation_token @confirmation_token end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
2815 2816 2817 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2815 def currency @currency end |
#customer ⇒ Object
ID of the Customer this PaymentIntent belongs to, if one exists.
Payment methods attached to other Customers cannot be used with this PaymentIntent.
If [setup_future_usage](api.stripe.com#payment_intent_object-setup_future_usage) is set and this PaymentIntent’s payment method is not ‘card_present`, then the payment method attaches to the Customer after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is `card_present` and isn’t a digital wallet, then a [generated_card](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Customer instead.
2821 2822 2823 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2821 def customer @customer end |
#customer_account ⇒ Object
ID of the Account representing the customer that this PaymentIntent belongs to, if one exists.
Payment methods attached to other Accounts cannot be used with this PaymentIntent.
If [setup_future_usage](api.stripe.com#payment_intent_object-setup_future_usage) is set and this PaymentIntent’s payment method is not ‘card_present`, then the payment method attaches to the Account after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is `card_present` and isn’t a digital wallet, then a [generated_card](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Account instead.
2827 2828 2829 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2827 def customer_account @customer_account end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
2829 2830 2831 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2829 def description @description end |
#error_on_requires_action ⇒ Object
Set to ‘true` to fail the payment attempt if the PaymentIntent transitions into `requires_action`. Use this parameter for simpler integrations that don’t handle customer actions, such as [saving cards without authentication](docs.stripe.com/payments/save-card-without-authentication). This parameter can only be used with [‘confirm=true`](docs.stripe.com/api/payment_intents/create#create_payment_intent-confirm).
2831 2832 2833 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2831 def error_on_requires_action @error_on_requires_action end |
#excluded_payment_method_types ⇒ Object
The list of payment method types to exclude from use with this payment.
2833 2834 2835 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2833 def excluded_payment_method_types @excluded_payment_method_types end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2835 2836 2837 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2835 def @expand end |
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle
2837 2838 2839 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2837 def hooks @hooks end |
#mandate ⇒ Object
ID of the mandate that’s used for this payment. This parameter can only be used with [‘confirm=true`](docs.stripe.com/api/payment_intents/create#create_payment_intent-confirm).
2839 2840 2841 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2839 def mandate @mandate end |
#mandate_data ⇒ Object
This hash contains details about the Mandate to create. This parameter can only be used with [‘confirm=true`](docs.stripe.com/api/payment_intents/create#create_payment_intent-confirm).
2841 2842 2843 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2841 def mandate_data @mandate_data end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2843 2844 2845 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2843 def @metadata end |
#off_session ⇒ Object
Set to ‘true` to indicate that the customer isn’t in your checkout flow during this payment attempt and can’t authenticate. Use this parameter in scenarios where you collect payment method details and [charge them later](docs.stripe.com/payments/save-during-payment). This parameter can only be used with [‘confirm=true`](docs.stripe.com/api/payment_intents/create#create_payment_intent-confirm).
2845 2846 2847 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2845 def off_session @off_session end |
#on_behalf_of ⇒ Object
The Stripe account ID that these funds are intended for. Learn more about the [use case for connected accounts](docs.stripe.com/payments/connected-accounts).
2847 2848 2849 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2847 def on_behalf_of @on_behalf_of end |
#payment_details ⇒ Object
Provides industry-specific information about the charge.
2849 2850 2851 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2849 def payment_details @payment_details end |
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or [compatible Source](docs.stripe.com/payments/payment-methods#compatibility) object) to attach to this PaymentIntent.
If you don’t provide the ‘payment_method` parameter or the `source` parameter with `confirm=true`, `source` automatically populates with `customer.default_source` to improve migration for users of the Charges API. We recommend that you explicitly provide the `payment_method` moving forward. If the payment method is attached to a Customer, you must also provide the ID of that Customer as the [customer](api.stripe.com#create_payment_intent-customer) parameter of this PaymentIntent. end
2855 2856 2857 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2855 def payment_method @payment_method end |
#payment_method_configuration ⇒ Object
The ID of the [payment method configuration](docs.stripe.com/api/payment_method_configurations) to use with this PaymentIntent.
2857 2858 2859 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2857 def payment_method_configuration @payment_method_configuration end |
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the [payment_method](docs.stripe.com/api/payment_intents/object#payment_intent_object-payment_method) property on the PaymentIntent.
2861 2862 2863 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2861 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment method-specific configuration for this PaymentIntent.
2863 2864 2865 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2863 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types (for example, a card) that this PaymentIntent can use. If you don’t provide this, Stripe will dynamically show relevant payment methods from your [payment method settings](dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).
2865 2866 2867 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2865 def payment_method_types @payment_method_types end |
#radar_options ⇒ Object
Options to configure Radar. Learn more about [Radar Sessions](docs.stripe.com/radar/radar-session).
2867 2868 2869 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2867 def @radar_options end |
#receipt_email ⇒ Object
Email address to send the receipt to. If you specify ‘receipt_email` for a payment in live mode, you send a receipt regardless of your [email settings](dashboard.stripe.com/account/emails).
2869 2870 2871 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2869 def receipt_email @receipt_email end |
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter can only be used with [‘confirm=true`](docs.stripe.com/api/payment_intents/create#create_payment_intent-confirm).
2871 2872 2873 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2871 def return_url @return_url end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
2879 2880 2881 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2879 def setup_future_usage @setup_future_usage end |
#shipping ⇒ Object
Shipping information for this PaymentIntent.
2881 2882 2883 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2881 def shipping @shipping end |
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.
2885 2886 2887 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2885 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.
2887 2888 2889 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2887 def statement_descriptor_suffix @statement_descriptor_suffix end |
#transfer_data ⇒ Object
The parameters that you can use to automatically create a Transfer. Learn more about the [use case for connected accounts](docs.stripe.com/payments/connected-accounts).
2890 2891 2892 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2890 def transfer_data @transfer_data end |
#transfer_group ⇒ Object
A string that identifies the resulting payment as part of a group. Learn more about the [use case for connected accounts](docs.stripe.com/connect/separate-charges-and-transfers).
2892 2893 2894 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2892 def transfer_group @transfer_group end |
#use_stripe_sdk ⇒ Object
Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
2894 2895 2896 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2894 def use_stripe_sdk @use_stripe_sdk end |