Class: Stripe::PaymentIntentCreateParams::AmountDetails::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::AmountDetails::LineItem
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The discount applied on this line item represented in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal).
-
#payment_method_options ⇒ Object
Payment method-specific information for line items.
-
#product_code ⇒ Object
The product code of the line item, such as an SKU.
-
#product_name ⇒ Object
The product name of the line item.
-
#quantity ⇒ Object
The quantity of items.
-
#tax ⇒ Object
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
The unit cost of the line item represented in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal).
-
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
Returns a new instance of LineItem.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 121 def initialize( discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil ) @discount_amount = discount_amount @payment_method_options = @product_code = product_code @product_name = product_name @quantity = quantity @tax = tax @unit_cost = unit_cost @unit_of_measure = unit_of_measure end |
Instance Attribute Details
#discount_amount ⇒ Object
The discount applied on this line item represented in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal). An integer greater than 0.
This field is mutually exclusive with the ‘amount_details` field.
103 104 105 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 103 def discount_amount @discount_amount end |
#payment_method_options ⇒ Object
Payment method-specific information for line items.
105 106 107 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 105 def @payment_method_options end |
#product_code ⇒ Object
The product code of the line item, such as an SKU. Required for L3 rates. At most 12 characters long.
107 108 109 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 107 def product_code @product_code end |
#product_name ⇒ Object
The product name of the line item. Required for L3 rates. At most 1024 characters long.
For Cards, this field is truncated to 26 alphanumeric characters before being sent to the card networks. For PayPal, this field is truncated to 127 characters.
111 112 113 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 111 def product_name @product_name end |
#quantity ⇒ Object
The quantity of items. Required for L3 rates. An integer greater than 0.
113 114 115 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 113 def quantity @quantity end |
#tax ⇒ Object
Contains information about the tax on the item.
115 116 117 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 115 def tax @tax end |
#unit_cost ⇒ Object
The unit cost of the line item represented in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal). Required for L3 rates. An integer greater than or equal to 0.
117 118 119 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 117 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
119 120 121 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 119 def unit_of_measure @unit_of_measure end |