Class: Stripe::PaymentIntentCreateParams::AmountDetails::Surcharge

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, enforce_validation: nil) ⇒ Surcharge

Returns a new instance of Surcharge.



163
164
165
166
# File 'lib/stripe/params/payment_intent_create_params.rb', line 163

def initialize(amount: nil, enforce_validation: nil)
  @amount = amount
  @enforce_validation = enforce_validation
end

Instance Attribute Details

#amountObject

Portion of the amount that corresponds to a surcharge.



159
160
161
# File 'lib/stripe/params/payment_intent_create_params.rb', line 159

def amount
  @amount
end

#enforce_validationObject

Indicate whether to enforce validations on the surcharge amount.



161
162
163
# File 'lib/stripe/params/payment_intent_create_params.rb', line 161

def enforce_validation
  @enforce_validation
end