Class: Stripe::PaymentIntentCreateParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



262
263
264
265
266
267
# File 'lib/stripe/params/payment_intent_create_params.rb', line 262

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



254
255
256
# File 'lib/stripe/params/payment_intent_create_params.rb', line 254

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



256
257
258
# File 'lib/stripe/params/payment_intent_create_params.rb', line 256

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



258
259
260
# File 'lib/stripe/params/payment_intent_create_params.rb', line 258

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



260
261
262
# File 'lib/stripe/params/payment_intent_create_params.rb', line 260

def type
  @type
end