Class: Stripe::PaymentIntentCreateParams::MandateData::CustomerAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::MandateData::CustomerAcceptance
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#accepted_at ⇒ Object
The time at which the customer accepted the Mandate.
-
#offline ⇒ Object
If this is a Mandate accepted offline, this hash contains details about the offline acceptance.
-
#online ⇒ Object
If this is a Mandate accepted online, this hash contains details about the online acceptance.
-
#type ⇒ Object
The type of customer acceptance information included with the Mandate.
Instance Method Summary collapse
-
#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance
constructor
A new instance of CustomerAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance
Returns a new instance of CustomerAcceptance.
215 216 217 218 219 220 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 215 def initialize(accepted_at: nil, offline: nil, online: nil, type: nil) @accepted_at = accepted_at @offline = offline @online = online @type = type end |
Instance Attribute Details
#accepted_at ⇒ Object
The time at which the customer accepted the Mandate.
207 208 209 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 207 def accepted_at @accepted_at end |
#offline ⇒ Object
If this is a Mandate accepted offline, this hash contains details about the offline acceptance.
209 210 211 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 209 def offline @offline end |
#online ⇒ Object
If this is a Mandate accepted online, this hash contains details about the online acceptance.
211 212 213 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 211 def online @online end |
#type ⇒ Object
The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.
213 214 215 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 213 def type @type end |