Class: Stripe::PaymentIntentCreateParams::MandateData::CustomerAcceptance::Online

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ip_address: nil, user_agent: nil) ⇒ Online

Returns a new instance of Online.



248
249
250
251
# File 'lib/stripe/params/payment_intent_create_params.rb', line 248

def initialize(ip_address: nil, user_agent: nil)
  @ip_address = ip_address
  @user_agent = user_agent
end

Instance Attribute Details

#ip_addressObject

The IP address from which the Mandate was accepted by the customer.



244
245
246
# File 'lib/stripe/params/payment_intent_create_params.rb', line 244

def ip_address
  @ip_address
end

#user_agentObject

The user agent of the browser from which the Mandate was accepted by the customer.



246
247
248
# File 'lib/stripe/params/payment_intent_create_params.rb', line 246

def user_agent
  @user_agent
end