Class: Stripe::PaymentIntentCreateParams::MandateData::CustomerAcceptance::Online

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ip_address: nil, user_agent: nil) ⇒ Online

Returns a new instance of Online.



235
236
237
238
# File 'lib/stripe/params/payment_intent_create_params.rb', line 235

def initialize(ip_address: nil, user_agent: nil)
  @ip_address = ip_address
  @user_agent = user_agent
end

Instance Attribute Details

#ip_addressObject

The IP address from which the Mandate was accepted by the customer.



231
232
233
# File 'lib/stripe/params/payment_intent_create_params.rb', line 231

def ip_address
  @ip_address
end

#user_agentObject

The user agent of the browser from which the Mandate was accepted by the customer.



233
234
235
# File 'lib/stripe/params/payment_intent_create_params.rb', line 233

def user_agent
  @user_agent
end