Class: Stripe::PaymentIntentCreateParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Benefit, CarRental, CarRentalDatum, EventDetails, FleetDatum, Flight, FlightDatum, Lodging, LodgingDatum, MoneyServices, Subscription
Instance Attribute Summary collapse
-
#benefit ⇒ Object
Benefit details for this PaymentIntent.
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#car_rental_data ⇒ Object
Car rental data for this PaymentIntent.
-
#customer_reference ⇒ Object
A unique value to identify the customer.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#fleet_data ⇒ Object
Fleet data for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#flight_data ⇒ Object
Flight data for this PaymentIntent.
-
#location ⇒ Object
The ID of the Payment Location for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#lodging_data ⇒ Object
Lodging data for this PaymentIntent.
-
#money_services ⇒ Object
Money services details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(benefit: nil, car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, fleet_data: nil, flight: nil, flight_data: nil, location: nil, lodging: nil, lodging_data: nil, money_services: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(benefit: nil, car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, fleet_data: nil, flight: nil, flight_data: nil, location: nil, lodging: nil, lodging_data: nil, money_services: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2282 def initialize( benefit: nil, car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, fleet_data: nil, flight: nil, flight_data: nil, location: nil, lodging: nil, lodging_data: nil, money_services: nil, order_reference: nil, subscription: nil ) @benefit = benefit @car_rental = car_rental @car_rental_data = car_rental_data @customer_reference = customer_reference @event_details = event_details @fleet_data = fleet_data @flight = flight @flight_data = flight_data @location = location @lodging = lodging @lodging_data = lodging_data @money_services = money_services @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#benefit ⇒ Object
Benefit details for this PaymentIntent
2250 2251 2252 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2250 def benefit @benefit end |
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
2252 2253 2254 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2252 def car_rental @car_rental end |
#car_rental_data ⇒ Object
Car rental data for this PaymentIntent.
2254 2255 2256 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2254 def car_rental_data @car_rental_data end |
#customer_reference ⇒ Object
A unique value to identify the customer. This field is available only for card payments.
This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.
2258 2259 2260 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2258 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
2260 2261 2262 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2260 def event_details @event_details end |
#fleet_data ⇒ Object
Fleet data for this PaymentIntent.
2262 2263 2264 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2262 def fleet_data @fleet_data end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
2264 2265 2266 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2264 def flight @flight end |
#flight_data ⇒ Object
Flight data for this PaymentIntent.
2266 2267 2268 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2266 def flight_data @flight_data end |
#location ⇒ Object
The ID of the Payment Location for this PaymentIntent.
2268 2269 2270 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2268 def location @location end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
2270 2271 2272 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2270 def lodging @lodging end |
#lodging_data ⇒ Object
Lodging data for this PaymentIntent.
2272 2273 2274 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2272 def lodging_data @lodging_data end |
#money_services ⇒ Object
Money services details for this PaymentIntent.
2274 2275 2276 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2274 def money_services @money_services end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.
For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.
2278 2279 2280 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2278 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
2280 2281 2282 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2280 def subscription @subscription end |