Class: Stripe::PaymentIntentCreateParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Benefit, CarRental, CarRentalDatum, EventDetails, FleetDatum, Flight, FlightDatum, Lodging, LodgingDatum, MoneyServices, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(benefit: nil, car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, fleet_data: nil, flight: nil, flight_data: nil, location: nil, lodging: nil, lodging_data: nil, money_services: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
2244
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2214

def initialize(
  benefit: nil,
  car_rental: nil,
  car_rental_data: nil,
  customer_reference: nil,
  event_details: nil,
  fleet_data: nil,
  flight: nil,
  flight_data: nil,
  location: nil,
  lodging: nil,
  lodging_data: nil,
  money_services: nil,
  order_reference: nil,
  subscription: nil
)
  @benefit = benefit
  @car_rental = car_rental
  @car_rental_data = car_rental_data
  @customer_reference = customer_reference
  @event_details = event_details
  @fleet_data = fleet_data
  @flight = flight
  @flight_data = flight_data
  @location = location
  @lodging = lodging
  @lodging_data = lodging_data
  @money_services = money_services
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#benefitObject

Benefit details for this PaymentIntent



2182
2183
2184
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2182

def benefit
  @benefit
end

#car_rentalObject

Car rental details for this PaymentIntent.



2184
2185
2186
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2184

def car_rental
  @car_rental
end

#car_rental_dataObject

Car rental data for this PaymentIntent.



2186
2187
2188
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2186

def car_rental_data
  @car_rental_data
end

#customer_referenceObject

A unique value to identify the customer. This field is available only for card payments.

This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.



2190
2191
2192
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2190

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



2192
2193
2194
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2192

def event_details
  @event_details
end

#fleet_dataObject

Fleet data for this PaymentIntent.



2194
2195
2196
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2194

def fleet_data
  @fleet_data
end

#flightObject

Flight reservation details for this PaymentIntent



2196
2197
2198
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2196

def flight
  @flight
end

#flight_dataObject

Flight data for this PaymentIntent.



2198
2199
2200
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2198

def flight_data
  @flight_data
end

#locationObject

The ID of the Payment Location for this PaymentIntent.



2200
2201
2202
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2200

def location
  @location
end

#lodgingObject

Lodging reservation details for this PaymentIntent



2202
2203
2204
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2202

def lodging
  @lodging
end

#lodging_dataObject

Lodging data for this PaymentIntent.



2204
2205
2206
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2204

def lodging_data
  @lodging_data
end

#money_servicesObject

Money services details for this PaymentIntent.



2206
2207
2208
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2206

def money_services
  @money_services
end

#order_referenceObject

A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.

For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.



2210
2211
2212
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2210

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



2212
2213
2214
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2212

def subscription
  @subscription
end