Class: Stripe::PaymentIntentCreateParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Benefit, CarRental, CarRentalDatum, EventDetails, FleetDatum, Flight, FlightDatum, Lodging, LodgingDatum, MoneyServices, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(benefit: nil, car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, fleet_data: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, money_services: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2209

def initialize(
  benefit: nil,
  car_rental: nil,
  car_rental_data: nil,
  customer_reference: nil,
  event_details: nil,
  fleet_data: nil,
  flight: nil,
  flight_data: nil,
  lodging: nil,
  lodging_data: nil,
  money_services: nil,
  order_reference: nil,
  subscription: nil
)
  @benefit = benefit
  @car_rental = car_rental
  @car_rental_data = car_rental_data
  @customer_reference = customer_reference
  @event_details = event_details
  @fleet_data = fleet_data
  @flight = flight
  @flight_data = flight_data
  @lodging = lodging
  @lodging_data = lodging_data
  @money_services = money_services
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#benefitObject

Benefit details for this PaymentIntent



2179
2180
2181
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2179

def benefit
  @benefit
end

#car_rentalObject

Car rental details for this PaymentIntent.



2181
2182
2183
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2181

def car_rental
  @car_rental
end

#car_rental_dataObject

Car rental data for this PaymentIntent.



2183
2184
2185
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2183

def car_rental_data
  @car_rental_data
end

#customer_referenceObject

A unique value to identify the customer. This field is available only for card payments.

This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.



2187
2188
2189
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2187

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



2189
2190
2191
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2189

def event_details
  @event_details
end

#fleet_dataObject

Fleet data for this PaymentIntent.



2191
2192
2193
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2191

def fleet_data
  @fleet_data
end

#flightObject

Flight reservation details for this PaymentIntent



2193
2194
2195
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2193

def flight
  @flight
end

#flight_dataObject

Flight data for this PaymentIntent.



2195
2196
2197
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2195

def flight_data
  @flight_data
end

#lodgingObject

Lodging reservation details for this PaymentIntent



2197
2198
2199
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2197

def lodging
  @lodging
end

#lodging_dataObject

Lodging data for this PaymentIntent.



2199
2200
2201
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2199

def lodging_data
  @lodging_data
end

#money_servicesObject

Money services details for this PaymentIntent.



2201
2202
2203
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2201

def money_services
  @money_services
end

#order_referenceObject

A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.

For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.



2205
2206
2207
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2205

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



2207
2208
2209
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2207

def subscription
  @subscription
end