Class: Stripe::PaymentIntentCreateParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Benefit, CarRental, CarRentalDatum, EventDetails, Flight, FlightDatum, Lodging, LodgingDatum, MoneyServices, Subscription
Instance Attribute Summary collapse
-
#benefit ⇒ Object
Benefit details for this PaymentIntent.
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#car_rental_data ⇒ Object
Car rental data for this PaymentIntent.
-
#customer_reference ⇒ Object
A unique value to identify the customer.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#flight_data ⇒ Object
Flight data for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#lodging_data ⇒ Object
Lodging data for this PaymentIntent.
-
#money_services ⇒ Object
Money services details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(benefit: nil, car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil, money_services: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(benefit: nil, car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil, money_services: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1944 def initialize( benefit: nil, car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil, money_services: nil ) @benefit = benefit @car_rental = car_rental @car_rental_data = car_rental_data @customer_reference = customer_reference @event_details = event_details @flight = flight @flight_data = flight_data @lodging = lodging @lodging_data = lodging_data @order_reference = order_reference @subscription = subscription @money_services = money_services end |
Instance Attribute Details
#benefit ⇒ Object
Benefit details for this PaymentIntent
1916 1917 1918 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1916 def benefit @benefit end |
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
1918 1919 1920 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1918 def car_rental @car_rental end |
#car_rental_data ⇒ Object
Car rental data for this PaymentIntent.
1920 1921 1922 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1920 def car_rental_data @car_rental_data end |
#customer_reference ⇒ Object
A unique value to identify the customer. This field is available only for card payments.
This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.
1924 1925 1926 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1924 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
1926 1927 1928 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1926 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
1928 1929 1930 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1928 def flight @flight end |
#flight_data ⇒ Object
Flight data for this PaymentIntent.
1930 1931 1932 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1930 def flight_data @flight_data end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
1932 1933 1934 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1932 def lodging @lodging end |
#lodging_data ⇒ Object
Lodging data for this PaymentIntent.
1934 1935 1936 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1934 def lodging_data @lodging_data end |
#money_services ⇒ Object
Money services details for this PaymentIntent.
1942 1943 1944 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1942 def money_services @money_services end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.
For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.
1938 1939 1940 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1938 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
1940 1941 1942 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1940 def subscription @subscription end |