Class: Stripe::PaymentIntentCreateParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Benefit, CarRental, CarRentalDatum, EventDetails, Flight, FlightDatum, Lodging, LodgingDatum, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(benefit: nil, car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1915

def initialize(
  benefit: nil,
  car_rental: nil,
  car_rental_data: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  flight_data: nil,
  lodging: nil,
  lodging_data: nil,
  order_reference: nil,
  subscription: nil
)
  @benefit = benefit
  @car_rental = car_rental
  @car_rental_data = car_rental_data
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @flight_data = flight_data
  @lodging = lodging
  @lodging_data = lodging_data
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#benefitObject

Benefit details for this PaymentIntent



1887
1888
1889
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1887

def benefit
  @benefit
end

#car_rentalObject

Car rental details for this PaymentIntent.



1889
1890
1891
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1889

def car_rental
  @car_rental
end

#car_rental_dataObject

Car rental data for this PaymentIntent.



1891
1892
1893
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1891

def car_rental_data
  @car_rental_data
end

#customer_referenceObject

A unique value to identify the customer. This field is available only for card payments.

This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.



1895
1896
1897
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1895

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



1897
1898
1899
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1897

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



1899
1900
1901
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1899

def flight
  @flight
end

#flight_dataObject

Flight data for this PaymentIntent.



1901
1902
1903
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1901

def flight_data
  @flight_data
end

#lodgingObject

Lodging reservation details for this PaymentIntent



1903
1904
1905
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1903

def lodging
  @lodging
end

#lodging_dataObject

Lodging data for this PaymentIntent.



1905
1906
1907
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1905

def lodging_data
  @lodging_data
end

#order_referenceObject

A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.

Required when the Payment Method Types array contains ‘card`, including when [automatic_payment_methods.enabled](/api/payment_intents/create#create_payment_intent-automatic_payment_methods-enabled) is set to `true`.

For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.



1911
1912
1913
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1911

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



1913
1914
1915
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1913

def subscription
  @subscription
end