Class: Stripe::PaymentIntentCreateParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Benefit, CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#benefit ⇒ Object
Benefit details for this PaymentIntent.
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(benefit: nil, car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(benefit: nil, car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 950 def initialize( benefit: nil, car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @benefit = benefit @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#benefit ⇒ Object
Benefit details for this PaymentIntent
934 935 936 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 934 def benefit @benefit end |
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
936 937 938 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 936 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
938 939 940 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 938 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
940 941 942 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 940 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
942 943 944 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 942 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
944 945 946 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 944 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
946 947 948 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 946 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
948 949 950 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 948 def subscription @subscription end |