Class: Stripe::PaymentIntentCreateParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 923 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
909 910 911 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 909 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
911 912 913 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 911 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
913 914 915 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 913 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
915 916 917 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 915 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
917 918 919 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 917 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
919 920 921 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 919 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
921 922 923 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 921 def subscription @subscription end |