Class: Stripe::PaymentIntentCreateParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#distance ⇒ Object
The details of the distance traveled during the rental period.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#pickup_location_name ⇒ Object
Name of the pickup location.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#return_location_name ⇒ Object
Name of the return location.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
The vehicle identification number.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental
Returns a new instance of CarRental.
458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 458 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @distance = distance @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @pickup_location_name = pickup_location_name @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @return_location_name = return_location_name @tax_exempt = tax_exempt @vehicle_identification_number = vehicle_identification_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
410 411 412 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 410 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
412 413 414 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 412 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
414 415 416 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 414 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
416 417 418 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 416 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
418 419 420 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 418 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
420 421 422 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 420 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
422 423 424 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 422 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
424 425 426 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 424 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
426 427 428 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 426 def delivery @delivery end |
#distance ⇒ Object
The details of the distance traveled during the rental period.
428 429 430 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 428 def distance @distance end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
430 431 432 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 430 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
432 433 434 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 432 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
434 435 436 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 434 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
436 437 438 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 436 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
438 439 440 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 438 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object
Name of the pickup location.
440 441 442 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 440 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object
Rental rate.
442 443 444 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 442 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
444 445 446 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 444 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
446 447 448 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 446 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
448 449 450 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 448 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
450 451 452 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 450 def return_at @return_at end |
#return_location_name ⇒ Object
Name of the return location.
452 453 454 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 452 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
454 455 456 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 454 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object
The vehicle identification number.
456 457 458 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 456 def vehicle_identification_number @vehicle_identification_number end |