Class: Stripe::PaymentIntentCreateParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



304
305
306
307
308
# File 'lib/stripe/params/payment_intent_create_params.rb', line 304

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



298
299
300
# File 'lib/stripe/params/payment_intent_create_params.rb', line 298

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



300
301
302
# File 'lib/stripe/params/payment_intent_create_params.rb', line 300

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



302
303
304
# File 'lib/stripe/params/payment_intent_create_params.rb', line 302

def phone
  @phone
end