Class: Stripe::PaymentIntentCreateParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
257 258 259 260 261 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 257 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
251 252 253 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 251 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
253 254 255 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 253 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
255 256 257 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 255 def phone @phone end |