Class: Stripe::PaymentIntentCreateParams::PaymentDetails::CarRental::Driver
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::CarRental::Driver
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#driver_identification_number ⇒ Object
Driver’s identification number.
-
#driver_tax_number ⇒ Object
Driver’s tax number.
-
#name ⇒ Object
Full name of the person or entity on the car reservation.
Instance Method Summary collapse
-
#initialize(driver_identification_number: nil, driver_tax_number: nil, name: nil) ⇒ Driver
constructor
A new instance of Driver.
Methods inherited from RequestParams
Constructor Details
#initialize(driver_identification_number: nil, driver_tax_number: nil, name: nil) ⇒ Driver
Returns a new instance of Driver.
338 339 340 341 342 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 338 def initialize(driver_identification_number: nil, driver_tax_number: nil, name: nil) @driver_identification_number = driver_identification_number @driver_tax_number = driver_tax_number @name = name end |
Instance Attribute Details
#driver_identification_number ⇒ Object
Driver’s identification number.
332 333 334 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 332 def driver_identification_number @driver_identification_number end |
#driver_tax_number ⇒ Object
Driver’s tax number.
334 335 336 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 334 def driver_tax_number @driver_tax_number end |
#name ⇒ Object
Full name of the person or entity on the car reservation.
336 337 338 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 336 def name @name end |