Class: Stripe::PaymentIntentCreateParams::PaymentDetails::CarRentalDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::CarRentalDatum
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Affiliate, Distance, Driver, DropOff, Insurance, Pickup, Total, Vehicle
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate (such as travel agency) details for the rental.
-
#booking_number ⇒ Object
Booking confirmation number for the car rental.
-
#carrier_name ⇒ Object
Name of the car rental company.
-
#customer_service_phone_number ⇒ Object
Customer service phone number for the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#distance ⇒ Object
Distance details for the rental.
-
#drivers ⇒ Object
List of drivers for the rental.
-
#drop_off ⇒ Object
Drop-off location details.
-
#insurances ⇒ Object
Insurance details for the rental.
-
#no_show_indicator ⇒ Object
Indicates if the customer was a no-show.
-
#pickup ⇒ Object
Pickup location details.
-
#renter_name ⇒ Object
Name of the person renting the vehicle.
-
#total ⇒ Object
Total cost breakdown for the rental.
-
#vehicle ⇒ Object
Vehicle details for the rental.
Instance Method Summary collapse
-
#initialize(affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil) ⇒ CarRentalDatum
constructor
A new instance of CarRentalDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil) ⇒ CarRentalDatum
Returns a new instance of CarRentalDatum.
880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 880 def initialize( affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil ) @affiliate = affiliate @booking_number = booking_number @carrier_name = carrier_name @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @distance = distance @drivers = drivers @drop_off = drop_off @insurances = insurances @no_show_indicator = no_show_indicator @pickup = pickup @renter_name = renter_name @total = total @vehicle = vehicle end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate (such as travel agency) details for the rental.
852 853 854 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 852 def affiliate @affiliate end |
#booking_number ⇒ Object
Booking confirmation number for the car rental.
854 855 856 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 854 def booking_number @booking_number end |
#carrier_name ⇒ Object
Name of the car rental company.
856 857 858 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 856 def carrier_name @carrier_name end |
#customer_service_phone_number ⇒ Object
Customer service phone number for the car rental company.
858 859 860 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 858 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
860 861 862 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 860 def days_rented @days_rented end |
#distance ⇒ Object
Distance details for the rental.
862 863 864 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 862 def distance @distance end |
#drivers ⇒ Object
List of drivers for the rental.
864 865 866 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 864 def drivers @drivers end |
#drop_off ⇒ Object
Drop-off location details.
866 867 868 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 866 def drop_off @drop_off end |
#insurances ⇒ Object
Insurance details for the rental.
868 869 870 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 868 def insurances @insurances end |
#no_show_indicator ⇒ Object
Indicates if the customer was a no-show.
870 871 872 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 870 def no_show_indicator @no_show_indicator end |
#pickup ⇒ Object
Pickup location details.
872 873 874 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 872 def pickup @pickup end |
#renter_name ⇒ Object
Name of the person renting the vehicle.
874 875 876 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 874 def renter_name @renter_name end |
#total ⇒ Object
Total cost breakdown for the rental.
876 877 878 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 876 def total @total end |
#vehicle ⇒ Object
Vehicle details for the rental.
878 879 880 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 878 def vehicle @vehicle end |