Class: Stripe::PaymentIntentCreateParams::PaymentDetails::CarRentalDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::CarRentalDatum
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Affiliate, Distance, Driver, DropOff, Insurance, Pickup, Total, Vehicle
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate (such as travel agency) details for the rental.
-
#booking_number ⇒ Object
Booking confirmation number for the car rental.
-
#carrier_name ⇒ Object
Name of the car rental company.
-
#customer_service_phone_number ⇒ Object
Customer service phone number for the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#distance ⇒ Object
Distance details for the rental.
-
#drivers ⇒ Object
List of drivers for the rental.
-
#drop_off ⇒ Object
Drop-off location details.
-
#insurances ⇒ Object
Insurance details for the rental.
-
#no_show_indicator ⇒ Object
Indicates if the customer was a no-show.
-
#pickup ⇒ Object
Pickup location details.
-
#renter_name ⇒ Object
Name of the person renting the vehicle.
-
#total ⇒ Object
Total cost breakdown for the rental.
-
#vehicle ⇒ Object
Vehicle details for the rental.
Instance Method Summary collapse
-
#initialize(affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil) ⇒ CarRentalDatum
constructor
A new instance of CarRentalDatum.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil) ⇒ CarRentalDatum
Returns a new instance of CarRentalDatum.
833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 833 def initialize( affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil ) @affiliate = affiliate @booking_number = booking_number @carrier_name = carrier_name @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @distance = distance @drivers = drivers @drop_off = drop_off @insurances = insurances @no_show_indicator = no_show_indicator @pickup = pickup @renter_name = renter_name @total = total @vehicle = vehicle end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate (such as travel agency) details for the rental.
805 806 807 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 805 def affiliate @affiliate end |
#booking_number ⇒ Object
Booking confirmation number for the car rental.
807 808 809 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 807 def booking_number @booking_number end |
#carrier_name ⇒ Object
Name of the car rental company.
809 810 811 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 809 def carrier_name @carrier_name end |
#customer_service_phone_number ⇒ Object
Customer service phone number for the car rental company.
811 812 813 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 811 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
813 814 815 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 813 def days_rented @days_rented end |
#distance ⇒ Object
Distance details for the rental.
815 816 817 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 815 def distance @distance end |
#drivers ⇒ Object
List of drivers for the rental.
817 818 819 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 817 def drivers @drivers end |
#drop_off ⇒ Object
Drop-off location details.
819 820 821 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 819 def drop_off @drop_off end |
#insurances ⇒ Object
Insurance details for the rental.
821 822 823 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 821 def insurances @insurances end |
#no_show_indicator ⇒ Object
Indicates if the customer was a no-show.
823 824 825 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 823 def no_show_indicator @no_show_indicator end |
#pickup ⇒ Object
Pickup location details.
825 826 827 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 825 def pickup @pickup end |
#renter_name ⇒ Object
Name of the person renting the vehicle.
827 828 829 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 827 def renter_name @renter_name end |
#total ⇒ Object
Total cost breakdown for the rental.
829 830 831 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 829 def total @total end |
#vehicle ⇒ Object
Vehicle details for the rental.
831 832 833 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 831 def vehicle @vehicle end |