Class: Stripe::PaymentIntentCreateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 998 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
980 981 982 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 980 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
982 983 984 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 982 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
984 985 986 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 984 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
986 987 988 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 986 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
988 989 990 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 988 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
990 991 992 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 990 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
992 993 994 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 992 def genre @genre end |
#name ⇒ Object
The name of the event.
994 995 996 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 994 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
996 997 998 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 996 def starts_at @starts_at end |