Class: Stripe::PaymentIntentCreateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 980 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
962 963 964 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 962 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
964 965 966 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 964 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
966 967 968 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 966 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
968 969 970 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 968 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
970 971 972 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 970 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
972 973 974 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 972 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
974 975 976 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 974 def genre @genre end |
#name ⇒ Object
The name of the event.
976 977 978 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 976 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
978 979 980 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 978 def starts_at @starts_at end |