Class: Stripe::PaymentIntentCreateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 951 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
933 934 935 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 933 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
935 936 937 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 935 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
937 938 939 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 937 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
939 940 941 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 939 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
941 942 943 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 941 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
943 944 945 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 943 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
945 946 947 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 945 def genre @genre end |
#name ⇒ Object
The name of the event.
947 948 949 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 947 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
949 950 951 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 949 def starts_at @starts_at end |