Class: Stripe::PaymentIntentCreateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 566 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
548 549 550 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 548 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
550 551 552 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 550 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
552 553 554 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 552 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
554 555 556 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 554 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
556 557 558 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 556 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
558 559 560 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 558 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
560 561 562 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 560 def genre @genre end |
#name ⇒ Object
The name of the event.
562 563 564 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 562 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
564 565 566 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 564 def starts_at @starts_at end |