Class: Stripe::PaymentIntentCreateParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
966 967 968 969 970 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 966 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
960 961 962 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 960 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
962 963 964 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 962 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
964 965 966 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 964 def phone @phone end |