Class: Stripe::PaymentIntentCreateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



903
904
905
906
907
# File 'lib/stripe/params/payment_intent_create_params.rb', line 903

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



897
898
899
# File 'lib/stripe/params/payment_intent_create_params.rb', line 897

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



899
900
901
# File 'lib/stripe/params/payment_intent_create_params.rb', line 899

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



901
902
903
# File 'lib/stripe/params/payment_intent_create_params.rb', line 901

def phone
  @phone
end