Class: Stripe::PaymentIntentCreateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



916
917
918
919
920
# File 'lib/stripe/params/payment_intent_create_params.rb', line 916

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



910
911
912
# File 'lib/stripe/params/payment_intent_create_params.rb', line 910

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



912
913
914
# File 'lib/stripe/params/payment_intent_create_params.rb', line 912

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



914
915
916
# File 'lib/stripe/params/payment_intent_create_params.rb', line 914

def phone
  @phone
end