Class: Stripe::PaymentIntentCreateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



539
540
541
542
543
# File 'lib/stripe/params/payment_intent_create_params.rb', line 539

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



533
534
535
# File 'lib/stripe/params/payment_intent_create_params.rb', line 533

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



535
536
537
# File 'lib/stripe/params/payment_intent_create_params.rb', line 535

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



537
538
539
# File 'lib/stripe/params/payment_intent_create_params.rb', line 537

def phone
  @phone
end