Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1214 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
1198 1199 1200 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1198 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
1200 1201 1202 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1200 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
1202 1203 1204 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1202 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
1204 1205 1206 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1204 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
1206 1207 1208 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1206 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
1208 1209 1210 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1208 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
1210 1211 1212 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1210 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
1212 1213 1214 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1212 def ticket_number @ticket_number end |