Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1077 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
1061 1062 1063 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1061 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
1063 1064 1065 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1063 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
1065 1066 1067 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1065 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
1067 1068 1069 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1067 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
1069 1070 1071 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1069 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
1071 1072 1073 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1071 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
1073 1074 1075 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1073 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
1075 1076 1077 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1075 def ticket_number @ticket_number end |