Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1103 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
1087 1088 1089 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1087 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
1089 1090 1091 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1089 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
1091 1092 1093 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1091 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
1093 1094 1095 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1093 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
1095 1096 1097 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1095 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
1097 1098 1099 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1097 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
1099 1100 1101 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1099 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
1101 1102 1103 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1101 def ticket_number @ticket_number end |