Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 689 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
673 674 675 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 673 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
675 676 677 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 675 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
677 678 679 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 677 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
679 680 681 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 679 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
681 682 683 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 681 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
683 684 685 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 683 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
685 686 687 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 685 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
687 688 689 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 687 def ticket_number @ticket_number end |