Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
1136 1137 1138 1139 1140 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1136 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
1130 1131 1132 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1130 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
1132 1133 1134 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1132 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
1134 1135 1136 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1134 def phone @phone end |