Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1133
1134
1135
1136
1137
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1133

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1127
1128
1129
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1127

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1129
1130
1131
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1129

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1131
1132
1133
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1131

def phone
  @phone
end