Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



996
997
998
999
1000
# File 'lib/stripe/params/payment_intent_create_params.rb', line 996

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



990
991
992
# File 'lib/stripe/params/payment_intent_create_params.rb', line 990

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



992
993
994
# File 'lib/stripe/params/payment_intent_create_params.rb', line 992

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



994
995
996
# File 'lib/stripe/params/payment_intent_create_params.rb', line 994

def phone
  @phone
end