Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
1022 1023 1024 1025 1026 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1022 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
1016 1017 1018 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1016 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
1018 1019 1020 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1018 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
1020 1021 1022 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1020 def phone @phone end |