Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
993 994 995 996 997 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 993 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
987 988 989 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 987 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
989 990 991 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 989 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
991 992 993 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 991 def phone @phone end |