Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Flight::Segment
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::Flight::Segment
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The flight segment amount.
-
#arrival_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the arrival airport.
-
#arrives_at ⇒ Object
The arrival time for the flight segment.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier operating the flight segment.
-
#departs_at ⇒ Object
The departure time for the flight segment.
-
#departure_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the departure airport.
-
#flight_number ⇒ Object
The flight number associated with the segment.
-
#service_class ⇒ Object
The fare class for the segment.
Instance Method Summary collapse
-
#initialize(amount: nil, arrival_airport: nil, arrives_at: nil, carrier: nil, departs_at: nil, departure_airport: nil, flight_number: nil, service_class: nil) ⇒ Segment
constructor
A new instance of Segment.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, arrival_airport: nil, arrives_at: nil, carrier: nil, departs_at: nil, departure_airport: nil, flight_number: nil, service_class: nil) ⇒ Segment
Returns a new instance of Segment.
1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1177 def initialize( amount: nil, arrival_airport: nil, arrives_at: nil, carrier: nil, departs_at: nil, departure_airport: nil, flight_number: nil, service_class: nil ) @amount = amount @arrival_airport = arrival_airport @arrives_at = arrives_at @carrier = carrier @departs_at = departs_at @departure_airport = departure_airport @flight_number = flight_number @service_class = service_class end |
Instance Attribute Details
#amount ⇒ Object
The flight segment amount.
1161 1162 1163 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1161 def amount @amount end |
#arrival_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the arrival airport.
1163 1164 1165 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1163 def arrival_airport @arrival_airport end |
#arrives_at ⇒ Object
The arrival time for the flight segment. Measured in seconds since the Unix epoch.
1165 1166 1167 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1165 def arrives_at @arrives_at end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier operating the flight segment.
1167 1168 1169 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1167 def carrier @carrier end |
#departs_at ⇒ Object
The departure time for the flight segment. Measured in seconds since the Unix epoch.
1169 1170 1171 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1169 def departs_at @departs_at end |
#departure_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the departure airport.
1171 1172 1173 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1171 def departure_airport @departure_airport end |
#flight_number ⇒ Object
The flight number associated with the segment
1173 1174 1175 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1173 def flight_number @flight_number end |
#service_class ⇒ Object
The fare class for the segment.
1175 1176 1177 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1175 def service_class @service_class end |