Class: Stripe::PaymentIntentCreateParams::PaymentDetails::FlightDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::FlightDatum
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Affiliate, Insurance, Passenger, Segment, Total
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details if applicable.
-
#booking_number ⇒ Object
Reservation reference.
-
#computerized_reservation_system ⇒ Object
Computerized reservation system used to make the reservation and purchase the ticket.
-
#endorsements_and_restrictions ⇒ Object
Ticket restrictions.
-
#insurances ⇒ Object
List of insurances.
-
#passengers ⇒ Object
List of passengers.
-
#segments ⇒ Object
List of flight segments.
-
#ticket_electronically_issued_indicator ⇒ Object
Electronic ticket indicator.
-
#total ⇒ Object
Total cost breakdown.
-
#transaction_type ⇒ Object
Type of flight transaction.
Instance Method Summary collapse
-
#initialize(affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil) ⇒ FlightDatum
constructor
A new instance of FlightDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil) ⇒ FlightDatum
Returns a new instance of FlightDatum.
1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1482 def initialize( affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil ) @affiliate = affiliate @booking_number = booking_number @computerized_reservation_system = computerized_reservation_system @endorsements_and_restrictions = endorsements_and_restrictions @insurances = insurances @passengers = passengers @segments = segments @ticket_electronically_issued_indicator = ticket_electronically_issued_indicator @total = total @transaction_type = transaction_type end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details if applicable.
1462 1463 1464 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1462 def affiliate @affiliate end |
#booking_number ⇒ Object
Reservation reference.
1464 1465 1466 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1464 def booking_number @booking_number end |
#computerized_reservation_system ⇒ Object
Computerized reservation system used to make the reservation and purchase the ticket.
1466 1467 1468 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1466 def computerized_reservation_system @computerized_reservation_system end |
#endorsements_and_restrictions ⇒ Object
Ticket restrictions.
1468 1469 1470 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1468 def endorsements_and_restrictions @endorsements_and_restrictions end |
#insurances ⇒ Object
List of insurances.
1470 1471 1472 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1470 def insurances @insurances end |
#passengers ⇒ Object
List of passengers.
1472 1473 1474 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1472 def passengers @passengers end |
#segments ⇒ Object
List of flight segments.
1474 1475 1476 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1474 def segments @segments end |
#ticket_electronically_issued_indicator ⇒ Object
Electronic ticket indicator.
1476 1477 1478 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1476 def ticket_electronically_issued_indicator @ticket_electronically_issued_indicator end |
#total ⇒ Object
Total cost breakdown.
1478 1479 1480 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1478 def total @total end |
#transaction_type ⇒ Object
Type of flight transaction.
1480 1481 1482 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1480 def transaction_type @transaction_type end |