Class: Stripe::PaymentIntentCreateParams::PaymentDetails::FlightDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::FlightDatum
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Affiliate, Insurance, Passenger, Segment, Total
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details if applicable.
-
#booking_number ⇒ Object
Reservation reference.
-
#computerized_reservation_system ⇒ Object
Computerized reservation system used to make the reservation and purchase the ticket.
-
#endorsements_and_restrictions ⇒ Object
Ticket restrictions.
-
#insurances ⇒ Object
List of insurances.
-
#passengers ⇒ Object
List of passengers.
-
#segments ⇒ Object
List of flight segments.
-
#ticket_electronically_issued_indicator ⇒ Object
Electronic ticket indicator.
-
#total ⇒ Object
Total cost breakdown.
-
#transaction_type ⇒ Object
Type of flight transaction.
Instance Method Summary collapse
-
#initialize(affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil) ⇒ FlightDatum
constructor
A new instance of FlightDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil) ⇒ FlightDatum
Returns a new instance of FlightDatum.
1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1368 def initialize( affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil ) @affiliate = affiliate @booking_number = booking_number @computerized_reservation_system = computerized_reservation_system @endorsements_and_restrictions = endorsements_and_restrictions @insurances = insurances @passengers = passengers @segments = segments @ticket_electronically_issued_indicator = ticket_electronically_issued_indicator @total = total @transaction_type = transaction_type end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details if applicable.
1348 1349 1350 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1348 def affiliate @affiliate end |
#booking_number ⇒ Object
Reservation reference.
1350 1351 1352 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1350 def booking_number @booking_number end |
#computerized_reservation_system ⇒ Object
Computerized reservation system used to make the reservation and purchase the ticket.
1352 1353 1354 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1352 def computerized_reservation_system @computerized_reservation_system end |
#endorsements_and_restrictions ⇒ Object
Ticket restrictions.
1354 1355 1356 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1354 def endorsements_and_restrictions @endorsements_and_restrictions end |
#insurances ⇒ Object
List of insurances.
1356 1357 1358 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1356 def insurances @insurances end |
#passengers ⇒ Object
List of passengers.
1358 1359 1360 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1358 def passengers @passengers end |
#segments ⇒ Object
List of flight segments.
1360 1361 1362 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1360 def segments @segments end |
#ticket_electronically_issued_indicator ⇒ Object
Electronic ticket indicator.
1362 1363 1364 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1362 def ticket_electronically_issued_indicator @ticket_electronically_issued_indicator end |
#total ⇒ Object
Total cost breakdown.
1364 1365 1366 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1364 def total @total end |
#transaction_type ⇒ Object
Type of flight transaction.
1366 1367 1368 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1366 def transaction_type @transaction_type end |