Class: Stripe::PaymentIntentCreateParams::PaymentDetails::FlightDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::FlightDatum
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Affiliate, Insurance, Passenger, Segment, Total
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details if applicable.
-
#booking_number ⇒ Object
Reservation reference.
-
#computerized_reservation_system ⇒ Object
Computerized reservation system used to make the reservation and purchase the ticket.
-
#endorsements_and_restrictions ⇒ Object
Ticket restrictions.
-
#insurances ⇒ Object
List of insurances.
-
#passengers ⇒ Object
List of passengers.
-
#segments ⇒ Object
List of flight segments.
-
#ticket_electronically_issued_indicator ⇒ Object
Electronic ticket indicator.
-
#total ⇒ Object
Total cost breakdown.
-
#transaction_type ⇒ Object
Type of flight transaction.
Instance Method Summary collapse
-
#initialize(affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil) ⇒ FlightDatum
constructor
A new instance of FlightDatum.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil) ⇒ FlightDatum
Returns a new instance of FlightDatum.
1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1352 def initialize( affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil ) @affiliate = affiliate @booking_number = booking_number @computerized_reservation_system = computerized_reservation_system @endorsements_and_restrictions = endorsements_and_restrictions @insurances = insurances @passengers = passengers @segments = segments @ticket_electronically_issued_indicator = ticket_electronically_issued_indicator @total = total @transaction_type = transaction_type end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details if applicable.
1332 1333 1334 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1332 def affiliate @affiliate end |
#booking_number ⇒ Object
Reservation reference.
1334 1335 1336 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1334 def booking_number @booking_number end |
#computerized_reservation_system ⇒ Object
Computerized reservation system used to make the reservation and purchase the ticket.
1336 1337 1338 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1336 def computerized_reservation_system @computerized_reservation_system end |
#endorsements_and_restrictions ⇒ Object
Ticket restrictions.
1338 1339 1340 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1338 def endorsements_and_restrictions @endorsements_and_restrictions end |
#insurances ⇒ Object
List of insurances.
1340 1341 1342 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1340 def insurances @insurances end |
#passengers ⇒ Object
List of passengers.
1342 1343 1344 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1342 def passengers @passengers end |
#segments ⇒ Object
List of flight segments.
1344 1345 1346 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1344 def segments @segments end |
#ticket_electronically_issued_indicator ⇒ Object
Electronic ticket indicator.
1346 1347 1348 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1346 def ticket_electronically_issued_indicator @ticket_electronically_issued_indicator end |
#total ⇒ Object
Total cost breakdown.
1348 1349 1350 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1348 def total @total end |
#transaction_type ⇒ Object
Type of flight transaction.
1350 1351 1352 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1350 def transaction_type @transaction_type end |