Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1625 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
1583 1584 1585 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1583 def address @address end |
#adults ⇒ Object
The number of adults on the booking
1585 1586 1587 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1585 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
1587 1588 1589 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1587 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
1589 1590 1591 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1589 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
1591 1592 1593 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1591 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
1593 1594 1595 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1593 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
1595 1596 1597 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1595 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
1597 1598 1599 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1597 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
1599 1600 1601 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1599 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
1601 1602 1603 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1601 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
1603 1604 1605 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1603 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
1605 1606 1607 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1605 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
1607 1608 1609 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1607 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
1609 1610 1611 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1609 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
1611 1612 1613 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1611 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
1613 1614 1615 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1613 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
1615 1616 1617 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1615 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
1617 1618 1619 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1617 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
1619 1620 1621 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1619 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
1621 1622 1623 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1621 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
1623 1624 1625 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1623 def total_tax_amount @total_tax_amount end |