Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1485 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
1443 1444 1445 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1443 def address @address end |
#adults ⇒ Object
The number of adults on the booking
1445 1446 1447 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1445 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
1447 1448 1449 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1447 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
1449 1450 1451 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1449 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
1451 1452 1453 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1451 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
1453 1454 1455 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1453 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
1455 1456 1457 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1455 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
1457 1458 1459 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1457 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
1459 1460 1461 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1459 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
1461 1462 1463 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1461 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
1463 1464 1465 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1463 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
1465 1466 1467 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1465 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
1467 1468 1469 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1467 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
1469 1470 1471 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1469 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
1471 1472 1473 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1471 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
1473 1474 1475 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1473 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
1475 1476 1477 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1475 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
1477 1478 1479 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1477 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
1479 1480 1481 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1479 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
1481 1482 1483 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1481 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
1483 1484 1485 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1483 def total_tax_amount @total_tax_amount end |