Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
# File 'lib/stripe/params/payment_intent_create_params.rb', line 828

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



786
787
788
# File 'lib/stripe/params/payment_intent_create_params.rb', line 786

def address
  @address
end

#adultsObject

The number of adults on the booking



788
789
790
# File 'lib/stripe/params/payment_intent_create_params.rb', line 788

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



790
791
792
# File 'lib/stripe/params/payment_intent_create_params.rb', line 790

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



792
793
794
# File 'lib/stripe/params/payment_intent_create_params.rb', line 792

def booking_number
  @booking_number
end

#categoryObject

The lodging category



794
795
796
# File 'lib/stripe/params/payment_intent_create_params.rb', line 794

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



796
797
798
# File 'lib/stripe/params/payment_intent_create_params.rb', line 796

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



798
799
800
# File 'lib/stripe/params/payment_intent_create_params.rb', line 798

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



800
801
802
# File 'lib/stripe/params/payment_intent_create_params.rb', line 800

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



802
803
804
# File 'lib/stripe/params/payment_intent_create_params.rb', line 802

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



804
805
806
# File 'lib/stripe/params/payment_intent_create_params.rb', line 804

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



806
807
808
# File 'lib/stripe/params/payment_intent_create_params.rb', line 806

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



808
809
810
# File 'lib/stripe/params/payment_intent_create_params.rb', line 808

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



810
811
812
# File 'lib/stripe/params/payment_intent_create_params.rb', line 810

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



812
813
814
# File 'lib/stripe/params/payment_intent_create_params.rb', line 812

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



814
815
816
# File 'lib/stripe/params/payment_intent_create_params.rb', line 814

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



816
817
818
# File 'lib/stripe/params/payment_intent_create_params.rb', line 816

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



818
819
820
# File 'lib/stripe/params/payment_intent_create_params.rb', line 818

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



820
821
822
# File 'lib/stripe/params/payment_intent_create_params.rb', line 820

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



822
823
824
# File 'lib/stripe/params/payment_intent_create_params.rb', line 822

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



824
825
826
# File 'lib/stripe/params/payment_intent_create_params.rb', line 824

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



826
827
828
# File 'lib/stripe/params/payment_intent_create_params.rb', line 826

def total_tax_amount
  @total_tax_amount
end