Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 811 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
769 770 771 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 769 def address @address end |
#adults ⇒ Object
The number of adults on the booking
771 772 773 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 771 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
773 774 775 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 773 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
775 776 777 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 775 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
777 778 779 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 777 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
779 780 781 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 779 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
781 782 783 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 781 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
783 784 785 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 783 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
785 786 787 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 785 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
787 788 789 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 787 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
789 790 791 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 789 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
791 792 793 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 791 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
793 794 795 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 793 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
795 796 797 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 795 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
797 798 799 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 797 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
799 800 801 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 799 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
801 802 803 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 801 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
803 804 805 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 803 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
805 806 807 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 805 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
807 808 809 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 807 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
809 810 811 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 809 def total_tax_amount @total_tax_amount end |