Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1554
1555
1556
1557
1558
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1554

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1548
1549
1550
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1548

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1550
1551
1552
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1550

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1552
1553
1554
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1552

def phone
  @phone
end