Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
1417 1418 1419 1420 1421 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1417 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
1411 1412 1413 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1411 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
1413 1414 1415 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1413 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
1415 1416 1417 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1415 def phone @phone end |