Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
1443 1444 1445 1446 1447 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1443 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
1437 1438 1439 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1437 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
1439 1440 1441 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1439 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
1441 1442 1443 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1441 def phone @phone end |