Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
1427 1428 1429 1430 1431 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1427 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
1421 1422 1423 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1421 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
1423 1424 1425 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1423 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
1425 1426 1427 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1425 def phone @phone end |