Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1414
1415
1416
1417
1418
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1414

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1408
1409
1410
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1408

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1410
1411
1412
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1410

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1412
1413
1414
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1412

def phone
  @phone
end