Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



768
769
770
771
772
# File 'lib/stripe/params/payment_intent_create_params.rb', line 768

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



762
763
764
# File 'lib/stripe/params/payment_intent_create_params.rb', line 762

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



764
765
766
# File 'lib/stripe/params/payment_intent_create_params.rb', line 764

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



766
767
768
# File 'lib/stripe/params/payment_intent_create_params.rb', line 766

def phone
  @phone
end