Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
768 769 770 771 772 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 768 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
762 763 764 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 762 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
764 765 766 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 764 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
766 767 768 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 766 def phone @phone end |