Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



743
744
745
746
747
# File 'lib/stripe/params/payment_intent_create_params.rb', line 743

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



737
738
739
# File 'lib/stripe/params/payment_intent_create_params.rb', line 737

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



739
740
741
# File 'lib/stripe/params/payment_intent_create_params.rb', line 739

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



741
742
743
# File 'lib/stripe/params/payment_intent_create_params.rb', line 741

def phone
  @phone
end