Class: Stripe::PaymentIntentCreateParams::PaymentDetails::LodgingDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::LodgingDatum
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Accommodation, Affiliate, Guest, Host, Insurance, Total
Instance Attribute Summary collapse
-
#accommodation ⇒ Object
Accommodation details for the lodging.
-
#affiliate ⇒ Object
Affiliate details if applicable.
-
#booking_number ⇒ Object
Booking confirmation number for the lodging.
-
#checkin_at ⇒ Object
Check-in date.
-
#checkout_at ⇒ Object
Check-out date.
-
#customer_service_phone_number ⇒ Object
Customer service phone number for the lodging company.
-
#fire_safety_act_compliance_indicator ⇒ Object
Whether the lodging is compliant with any hotel fire safety regulations.
-
#guests ⇒ Object
List of guests for the lodging.
-
#host ⇒ Object
Host details for the lodging.
-
#insurances ⇒ Object
List of insurances for the lodging.
-
#no_show_indicator ⇒ Object
Whether the renter is a no-show.
-
#renter_id_number ⇒ Object
Renter ID number for the lodging.
-
#renter_name ⇒ Object
Renter name for the lodging.
-
#total ⇒ Object
Total details for the lodging.
Instance Method Summary collapse
-
#initialize(accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil) ⇒ LodgingDatum
constructor
A new instance of LodgingDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil) ⇒ LodgingDatum
Returns a new instance of LodgingDatum.
1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1933 def initialize( accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil ) @accommodation = accommodation @affiliate = affiliate @booking_number = booking_number @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @fire_safety_act_compliance_indicator = fire_safety_act_compliance_indicator @guests = guests @host = host @insurances = insurances @no_show_indicator = no_show_indicator @renter_id_number = renter_id_number @renter_name = renter_name @total = total end |
Instance Attribute Details
#accommodation ⇒ Object
Accommodation details for the lodging.
1905 1906 1907 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1905 def accommodation @accommodation end |
#affiliate ⇒ Object
Affiliate details if applicable.
1907 1908 1909 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1907 def affiliate @affiliate end |
#booking_number ⇒ Object
Booking confirmation number for the lodging.
1909 1910 1911 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1909 def booking_number @booking_number end |
#checkin_at ⇒ Object
Check-in date.
1911 1912 1913 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1911 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Check-out date.
1913 1914 1915 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1913 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
Customer service phone number for the lodging company.
1915 1916 1917 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1915 def customer_service_phone_number @customer_service_phone_number end |
#fire_safety_act_compliance_indicator ⇒ Object
Whether the lodging is compliant with any hotel fire safety regulations.
1917 1918 1919 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1917 def fire_safety_act_compliance_indicator @fire_safety_act_compliance_indicator end |
#guests ⇒ Object
List of guests for the lodging.
1919 1920 1921 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1919 def guests @guests end |
#host ⇒ Object
Host details for the lodging.
1921 1922 1923 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1921 def host @host end |
#insurances ⇒ Object
List of insurances for the lodging.
1923 1924 1925 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1923 def insurances @insurances end |
#no_show_indicator ⇒ Object
Whether the renter is a no-show.
1925 1926 1927 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1925 def no_show_indicator @no_show_indicator end |
#renter_id_number ⇒ Object
Renter ID number for the lodging.
1927 1928 1929 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1927 def renter_id_number @renter_id_number end |
#renter_name ⇒ Object
Renter name for the lodging.
1929 1930 1931 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1929 def renter_name @renter_name end |
#total ⇒ Object
Total details for the lodging.
1931 1932 1933 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1931 def total @total end |