Class: Stripe::PaymentIntentCreateParams::PaymentDetails::LodgingDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::LodgingDatum
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Accommodation, Affiliate, Guest, Host, Insurance, Total
Instance Attribute Summary collapse
-
#accommodation ⇒ Object
Accommodation details for the lodging.
-
#affiliate ⇒ Object
Affiliate details if applicable.
-
#booking_number ⇒ Object
Booking confirmation number for the lodging.
-
#checkin_at ⇒ Object
Check-in date.
-
#checkout_at ⇒ Object
Check-out date.
-
#customer_service_phone_number ⇒ Object
Customer service phone number for the lodging company.
-
#fire_safety_act_compliance_indicator ⇒ Object
Whether the lodging is compliant with any hotel fire safety regulations.
-
#guests ⇒ Object
List of guests for the lodging.
-
#host ⇒ Object
Host details for the lodging.
-
#insurances ⇒ Object
List of insurances for the lodging.
-
#no_show_indicator ⇒ Object
Whether the renter is a no-show.
-
#renter_id_number ⇒ Object
Renter ID number for the lodging.
-
#renter_name ⇒ Object
Renter name for the lodging.
-
#total ⇒ Object
Total details for the lodging.
Instance Method Summary collapse
-
#initialize(accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil) ⇒ LodgingDatum
constructor
A new instance of LodgingDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil) ⇒ LodgingDatum
Returns a new instance of LodgingDatum.
1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1793 def initialize( accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil ) @accommodation = accommodation @affiliate = affiliate @booking_number = booking_number @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @fire_safety_act_compliance_indicator = fire_safety_act_compliance_indicator @guests = guests @host = host @insurances = insurances @no_show_indicator = no_show_indicator @renter_id_number = renter_id_number @renter_name = renter_name @total = total end |
Instance Attribute Details
#accommodation ⇒ Object
Accommodation details for the lodging.
1765 1766 1767 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1765 def accommodation @accommodation end |
#affiliate ⇒ Object
Affiliate details if applicable.
1767 1768 1769 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1767 def affiliate @affiliate end |
#booking_number ⇒ Object
Booking confirmation number for the lodging.
1769 1770 1771 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1769 def booking_number @booking_number end |
#checkin_at ⇒ Object
Check-in date.
1771 1772 1773 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1771 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Check-out date.
1773 1774 1775 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1773 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
Customer service phone number for the lodging company.
1775 1776 1777 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1775 def customer_service_phone_number @customer_service_phone_number end |
#fire_safety_act_compliance_indicator ⇒ Object
Whether the lodging is compliant with any hotel fire safety regulations.
1777 1778 1779 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1777 def fire_safety_act_compliance_indicator @fire_safety_act_compliance_indicator end |
#guests ⇒ Object
List of guests for the lodging.
1779 1780 1781 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1779 def guests @guests end |
#host ⇒ Object
Host details for the lodging.
1781 1782 1783 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1781 def host @host end |
#insurances ⇒ Object
List of insurances for the lodging.
1783 1784 1785 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1783 def insurances @insurances end |
#no_show_indicator ⇒ Object
Whether the renter is a no-show.
1785 1786 1787 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1785 def no_show_indicator @no_show_indicator end |
#renter_id_number ⇒ Object
Renter ID number for the lodging.
1787 1788 1789 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1787 def renter_id_number @renter_id_number end |
#renter_name ⇒ Object
Renter name for the lodging.
1789 1790 1791 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1789 def renter_name @renter_name end |
#total ⇒ Object
Total details for the lodging.
1791 1792 1793 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1791 def total @total end |