Class: Stripe::PaymentIntentCreateParams::PaymentDetails::MoneyServices
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::MoneyServices
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: AccountFunding
Instance Attribute Summary collapse
-
#account_funding ⇒ Object
Account funding transaction details including sender and beneficiary information.
-
#transaction_type ⇒ Object
The type of money services transaction.
Instance Method Summary collapse
-
#initialize(account_funding: nil, transaction_type: nil) ⇒ MoneyServices
constructor
A new instance of MoneyServices.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_funding: nil, transaction_type: nil) ⇒ MoneyServices
Returns a new instance of MoneyServices.
2125 2126 2127 2128 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2125 def initialize(account_funding: nil, transaction_type: nil) @account_funding = account_funding @transaction_type = transaction_type end |
Instance Attribute Details
#account_funding ⇒ Object
Account funding transaction details including sender and beneficiary information.
2121 2122 2123 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2121 def account_funding @account_funding end |
#transaction_type ⇒ Object
The type of money services transaction.
2123 2124 2125 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2123 def transaction_type @transaction_type end |