Class: Stripe::PaymentIntentCreateParams::PaymentDetails::MoneyServices::AccountFunding
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentDetails::MoneyServices::AccountFunding
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: BeneficiaryDetails, SenderDetails
Instance Attribute Summary collapse
-
#beneficiary_account ⇒ Object
ID of the Account representing the beneficiary in this account funding transaction.
-
#beneficiary_details ⇒ Object
Inline identity details for the beneficiary of this account funding transaction.
-
#sender_account ⇒ Object
ID of the Account representing the sender in this account funding transaction.
-
#sender_details ⇒ Object
Inline identity details for the sender of this account funding transaction.
Instance Method Summary collapse
-
#initialize(beneficiary_account: nil, beneficiary_details: nil, sender_account: nil, sender_details: nil) ⇒ AccountFunding
constructor
A new instance of AccountFunding.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(beneficiary_account: nil, beneficiary_details: nil, sender_account: nil, sender_details: nil) ⇒ AccountFunding
Returns a new instance of AccountFunding.
2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2105 def initialize( beneficiary_account: nil, beneficiary_details: nil, sender_account: nil, sender_details: nil ) @beneficiary_account = beneficiary_account @beneficiary_details = beneficiary_details @sender_account = sender_account @sender_details = sender_details end |
Instance Attribute Details
#beneficiary_account ⇒ Object
ID of the Account representing the beneficiary in this account funding transaction.
2097 2098 2099 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2097 def beneficiary_account @beneficiary_account end |
#beneficiary_details ⇒ Object
Inline identity details for the beneficiary of this account funding transaction.
2099 2100 2101 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2099 def beneficiary_details @beneficiary_details end |
#sender_account ⇒ Object
ID of the Account representing the sender in this account funding transaction.
2101 2102 2103 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2101 def sender_account @sender_account end |
#sender_details ⇒ Object
Inline identity details for the sender of this account funding transaction.
2103 2104 2105 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2103 def sender_details @sender_details end |