Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



1881
1882
1883
1884
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1881

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1877
1878
1879
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1877

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1879
1880
1881
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1879

def interval
  @interval
end