Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



1826
1827
1828
1829
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1826

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1822
1823
1824
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1822

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1824
1825
1826
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1824

def interval
  @interval
end