Class: Stripe::PaymentIntentCreateParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



874
875
876
877
# File 'lib/stripe/params/payment_intent_create_params.rb', line 874

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



870
871
872
# File 'lib/stripe/params/payment_intent_create_params.rb', line 870

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



872
873
874
# File 'lib/stripe/params/payment_intent_create_params.rb', line 872

def interval
  @interval
end