Class: Stripe::PaymentIntentCreateParams::PaymentMethodData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, RadarOptions, Rechnung, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, StripeBalance, Sunbit, Swish, Twint, Upi, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, billing_details: nil, blik: nil, boleto: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, paypay: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, radar_options: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, shared_payment_granted_token: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, sunbit: nil, swish: nil, twint: nil, type: nil, upi: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodData

Returns a new instance of PaymentMethodData.



2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2448

def initialize(
  acss_debit: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  allow_redisplay: nil,
  alma: nil,
  amazon_pay: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  billie: nil,
  billing_details: nil,
  blik: nil,
  boleto: nil,
  cashapp: nil,
  crypto: nil,
  customer_balance: nil,
  eps: nil,
  fpx: nil,
  giropay: nil,
  gopay: nil,
  grabpay: nil,
  id_bank_transfer: nil,
  ideal: nil,
  interac_present: nil,
  kakao_pay: nil,
  klarna: nil,
  konbini: nil,
  kr_card: nil,
  link: nil,
  mb_way: nil,
  metadata: nil,
  mobilepay: nil,
  multibanco: nil,
  naver_pay: nil,
  nz_bank_account: nil,
  oxxo: nil,
  p24: nil,
  pay_by_bank: nil,
  payco: nil,
  paynow: nil,
  paypal: nil,
  paypay: nil,
  payto: nil,
  pix: nil,
  promptpay: nil,
  qris: nil,
  radar_options: nil,
  rechnung: nil,
  revolut_pay: nil,
  samsung_pay: nil,
  satispay: nil,
  sepa_debit: nil,
  shared_payment_granted_token: nil,
  shopeepay: nil,
  sofort: nil,
  stripe_balance: nil,
  sunbit: nil,
  swish: nil,
  twint: nil,
  type: nil,
  upi: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @allow_redisplay = allow_redisplay
  @alma = alma
  @amazon_pay = amazon_pay
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @billie = billie
  @billing_details = billing_details
  @blik = blik
  @boleto = boleto
  @cashapp = cashapp
  @crypto = crypto
  @customer_balance = customer_balance
  @eps = eps
  @fpx = fpx
  @giropay = giropay
  @gopay = gopay
  @grabpay = grabpay
  @id_bank_transfer = id_bank_transfer
  @ideal = ideal
  @interac_present = interac_present
  @kakao_pay = kakao_pay
  @klarna = klarna
  @konbini = konbini
  @kr_card = kr_card
  @link = link
  @mb_way = mb_way
  @metadata = 
  @mobilepay = mobilepay
  @multibanco = multibanco
  @naver_pay = naver_pay
  @nz_bank_account = 
  @oxxo = oxxo
  @p24 = p24
  @pay_by_bank = pay_by_bank
  @payco = payco
  @paynow = paynow
  @paypal = paypal
  @paypay = paypay
  @payto = payto
  @pix = pix
  @promptpay = promptpay
  @qris = qris
  @radar_options = radar_options
  @rechnung = rechnung
  @revolut_pay = revolut_pay
  @samsung_pay = samsung_pay
  @satispay = satispay
  @sepa_debit = sepa_debit
  @shared_payment_granted_token = shared_payment_granted_token
  @shopeepay = shopeepay
  @sofort = sofort
  @stripe_balance = stripe_balance
  @sunbit = sunbit
  @swish = swish
  @twint = twint
  @type = type
  @upi = upi
  @us_bank_account = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

If this is an ‘acss_debit` PaymentMethod, this hash contains details about the ACSS Debit payment method.



2318
2319
2320
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2318

def acss_debit
  @acss_debit
end

#affirmObject

If this is an ‘affirm` PaymentMethod, this hash contains details about the Affirm payment method.



2320
2321
2322
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2320

def affirm
  @affirm
end

#afterpay_clearpayObject

If this is an ‘AfterpayClearpay` PaymentMethod, this hash contains details about the AfterpayClearpay payment method.



2322
2323
2324
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2322

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If this is an ‘Alipay` PaymentMethod, this hash contains details about the Alipay payment method.



2324
2325
2326
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2324

def alipay
  @alipay
end

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.



2326
2327
2328
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2326

def allow_redisplay
  @allow_redisplay
end

#almaObject

If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.



2328
2329
2330
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2328

def alma
  @alma
end

#amazon_payObject

If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.



2330
2331
2332
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2330

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject

If this is an ‘au_becs_debit` PaymentMethod, this hash contains details about the bank account.



2332
2333
2334
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2332

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

If this is a ‘bacs_debit` PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.



2334
2335
2336
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2334

def bacs_debit
  @bacs_debit
end

#bancontactObject

If this is a ‘bancontact` PaymentMethod, this hash contains details about the Bancontact payment method.



2336
2337
2338
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2336

def bancontact
  @bancontact
end

#billieObject

If this is a ‘billie` PaymentMethod, this hash contains details about the Billie payment method.



2338
2339
2340
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2338

def billie
  @billie
end

#billing_detailsObject

Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.



2340
2341
2342
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2340

def billing_details
  @billing_details
end

#blikObject

If this is a ‘blik` PaymentMethod, this hash contains details about the BLIK payment method.



2342
2343
2344
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2342

def blik
  @blik
end

#boletoObject

If this is a ‘boleto` PaymentMethod, this hash contains details about the Boleto payment method.



2344
2345
2346
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2344

def boleto
  @boleto
end

#cashappObject

If this is a ‘cashapp` PaymentMethod, this hash contains details about the Cash App Pay payment method.



2346
2347
2348
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2346

def cashapp
  @cashapp
end

#cryptoObject

If this is a Crypto PaymentMethod, this hash contains details about the Crypto payment method.



2348
2349
2350
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2348

def crypto
  @crypto
end

#customer_balanceObject

If this is a ‘customer_balance` PaymentMethod, this hash contains details about the CustomerBalance payment method.



2350
2351
2352
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2350

def customer_balance
  @customer_balance
end

#epsObject

If this is an ‘eps` PaymentMethod, this hash contains details about the EPS payment method.



2352
2353
2354
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2352

def eps
  @eps
end

#fpxObject

If this is an ‘fpx` PaymentMethod, this hash contains details about the FPX payment method.



2354
2355
2356
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2354

def fpx
  @fpx
end

#giropayObject

If this is a ‘giropay` PaymentMethod, this hash contains details about the Giropay payment method.



2356
2357
2358
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2356

def giropay
  @giropay
end

#gopayObject

If this is a Gopay PaymentMethod, this hash contains details about the Gopay payment method.



2358
2359
2360
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2358

def gopay
  @gopay
end

#grabpayObject

If this is a ‘grabpay` PaymentMethod, this hash contains details about the GrabPay payment method.



2360
2361
2362
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2360

def grabpay
  @grabpay
end

#id_bank_transferObject

If this is an ‘IdBankTransfer` PaymentMethod, this hash contains details about the IdBankTransfer payment method.



2362
2363
2364
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2362

def id_bank_transfer
  @id_bank_transfer
end

#idealObject

If this is an ‘ideal` PaymentMethod, this hash contains details about the iDEAL payment method.



2364
2365
2366
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2364

def ideal
  @ideal
end

#interac_presentObject

If this is an ‘interac_present` PaymentMethod, this hash contains details about the Interac Present payment method.



2366
2367
2368
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2366

def interac_present
  @interac_present
end

#kakao_payObject

If this is a ‘kakao_pay` PaymentMethod, this hash contains details about the Kakao Pay payment method.



2368
2369
2370
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2368

def kakao_pay
  @kakao_pay
end

#klarnaObject

If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method.



2370
2371
2372
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2370

def klarna
  @klarna
end

#konbiniObject

If this is a ‘konbini` PaymentMethod, this hash contains details about the Konbini payment method.



2372
2373
2374
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2372

def konbini
  @konbini
end

#kr_cardObject

If this is a ‘kr_card` PaymentMethod, this hash contains details about the Korean Card payment method.



2374
2375
2376
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2374

def kr_card
  @kr_card
end

If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.



2376
2377
2378
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2376

def link
  @link
end

#mb_wayObject

If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.



2378
2379
2380
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2378

def mb_way
  @mb_way
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2380
2381
2382
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2380

def 
  @metadata
end

#mobilepayObject

If this is a ‘mobilepay` PaymentMethod, this hash contains details about the MobilePay payment method.



2382
2383
2384
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2382

def mobilepay
  @mobilepay
end

#multibancoObject

If this is a ‘multibanco` PaymentMethod, this hash contains details about the Multibanco payment method.



2384
2385
2386
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2384

def multibanco
  @multibanco
end

If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.



2386
2387
2388
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2386

def naver_pay
  @naver_pay
end

#nz_bank_accountObject

If this is an nz_bank_account PaymentMethod, this hash contains details about the nz_bank_account payment method.



2388
2389
2390
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2388

def 
  @nz_bank_account
end

#oxxoObject

If this is an ‘oxxo` PaymentMethod, this hash contains details about the OXXO payment method.



2390
2391
2392
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2390

def oxxo
  @oxxo
end

#p24Object

If this is a ‘p24` PaymentMethod, this hash contains details about the P24 payment method.



2392
2393
2394
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2392

def p24
  @p24
end

#pay_by_bankObject

If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.



2394
2395
2396
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2394

def pay_by_bank
  @pay_by_bank
end

#paycoObject

If this is a ‘payco` PaymentMethod, this hash contains details about the PAYCO payment method.



2396
2397
2398
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2396

def payco
  @payco
end

#paynowObject

If this is a ‘paynow` PaymentMethod, this hash contains details about the PayNow payment method.



2398
2399
2400
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2398

def paynow
  @paynow
end

#paypalObject

If this is a ‘paypal` PaymentMethod, this hash contains details about the PayPal payment method.



2400
2401
2402
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2400

def paypal
  @paypal
end

#paypayObject

If this is a ‘paypay` PaymentMethod, this hash contains details about the PayPay payment method.



2402
2403
2404
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2402

def paypay
  @paypay
end

#paytoObject

If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.



2404
2405
2406
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2404

def payto
  @payto
end

#pixObject

If this is a ‘pix` PaymentMethod, this hash contains details about the Pix payment method.



2406
2407
2408
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2406

def pix
  @pix
end

#promptpayObject

If this is a ‘promptpay` PaymentMethod, this hash contains details about the PromptPay payment method.



2408
2409
2410
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2408

def promptpay
  @promptpay
end

#qrisObject

If this is a ‘qris` PaymentMethod, this hash contains details about the QRIS payment method.



2410
2411
2412
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2410

def qris
  @qris
end

#radar_optionsObject

Options to configure Radar. See [Radar Session](docs.stripe.com/radar/radar-session) for more information.



2412
2413
2414
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2412

def radar_options
  @radar_options
end

#rechnungObject

If this is a ‘rechnung` PaymentMethod, this hash contains details about the Rechnung payment method.



2414
2415
2416
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2414

def rechnung
  @rechnung
end

#revolut_payObject

If this is a ‘revolut_pay` PaymentMethod, this hash contains details about the Revolut Pay payment method.



2416
2417
2418
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2416

def revolut_pay
  @revolut_pay
end

#samsung_payObject

If this is a ‘samsung_pay` PaymentMethod, this hash contains details about the SamsungPay payment method.



2418
2419
2420
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2418

def samsung_pay
  @samsung_pay
end

#satispayObject

If this is a ‘satispay` PaymentMethod, this hash contains details about the Satispay payment method.



2420
2421
2422
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2420

def satispay
  @satispay
end

#sepa_debitObject

If this is a ‘sepa_debit` PaymentMethod, this hash contains details about the SEPA debit bank account.



2422
2423
2424
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2422

def sepa_debit
  @sepa_debit
end

#shared_payment_granted_tokenObject

ID of the SharedPaymentGrantedToken used to confirm this PaymentIntent.



2424
2425
2426
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2424

def shared_payment_granted_token
  @shared_payment_granted_token
end

#shopeepayObject

If this is a Shopeepay PaymentMethod, this hash contains details about the Shopeepay payment method.



2426
2427
2428
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2426

def shopeepay
  @shopeepay
end

#sofortObject

If this is a ‘sofort` PaymentMethod, this hash contains details about the SOFORT payment method.



2428
2429
2430
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2428

def sofort
  @sofort
end

#stripe_balanceObject

This hash contains details about the Stripe balance payment method.



2430
2431
2432
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2430

def stripe_balance
  @stripe_balance
end

#sunbitObject

If this is a Sunbit PaymentMethod, this hash contains details about the Sunbit payment method.



2432
2433
2434
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2432

def sunbit
  @sunbit
end

#swishObject

If this is a ‘swish` PaymentMethod, this hash contains details about the Swish payment method.



2434
2435
2436
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2434

def swish
  @swish
end

#twintObject

If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.



2436
2437
2438
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2436

def twint
  @twint
end

#typeObject

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



2438
2439
2440
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2438

def type
  @type
end

#upiObject

If this is a ‘upi` PaymentMethod, this hash contains details about the UPI payment method.



2440
2441
2442
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2440

def upi
  @upi
end

#us_bank_accountObject

If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.



2442
2443
2444
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2442

def 
  @us_bank_account
end

#wechat_payObject

If this is an ‘wechat_pay` PaymentMethod, this hash contains details about the wechat_pay payment method.



2444
2445
2446
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2444

def wechat_pay
  @wechat_pay
end

#zipObject

If this is a ‘zip` PaymentMethod, this hash contains details about the Zip payment method.



2446
2447
2448
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2446

def zip
  @zip
end