Class: Stripe::PaymentIntentCreateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
2471 2472 2473 2474 2475 2476 2477 2478 2479 2480 2481 2482 2483 2484 2485 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2471 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
2459 2460 2461 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2459 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
2461 2462 2463 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2461 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
2463 2464 2465 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2463 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
2465 2466 2467 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2465 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
2467 2468 2469 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2467 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
2469 2470 2471 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2469 def suffix @suffix end |