Class: Stripe::PaymentIntentCreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
# File 'lib/stripe/params/payment_intent_create_params.rb', line 489

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



477
478
479
# File 'lib/stripe/params/payment_intent_create_params.rb', line 477

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



479
480
481
# File 'lib/stripe/params/payment_intent_create_params.rb', line 479

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



481
482
483
# File 'lib/stripe/params/payment_intent_create_params.rb', line 481

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



483
484
485
# File 'lib/stripe/params/payment_intent_create_params.rb', line 483

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



485
486
487
# File 'lib/stripe/params/payment_intent_create_params.rb', line 485

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



487
488
489
# File 'lib/stripe/params/payment_intent_create_params.rb', line 487

def suffix
  @suffix
end