Class: Stripe::PaymentIntentCreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
2483
2484
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2470

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



2458
2459
2460
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2458

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



2460
2461
2462
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2460

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



2462
2463
2464
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2462

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



2464
2465
2466
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2464

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



2466
2467
2468
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2466

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



2468
2469
2470
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2468

def suffix
  @suffix
end