Class: Stripe::PaymentIntentCreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2140

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



2128
2129
2130
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2128

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



2130
2131
2132
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2130

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



2132
2133
2134
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2132

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



2134
2135
2136
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2134

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



2136
2137
2138
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2136

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



2138
2139
2140
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2138

def suffix
  @suffix
end