Class: Stripe::PaymentIntentCreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2187

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



2175
2176
2177
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2175

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



2177
2178
2179
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2177

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



2179
2180
2181
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2179

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



2181
2182
2183
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2181

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



2183
2184
2185
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2183

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



2185
2186
2187
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2185

def suffix
  @suffix
end