Class: Stripe::PaymentIntentCreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
# File 'lib/stripe/params/payment_intent_create_params.rb', line 452

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



440
441
442
# File 'lib/stripe/params/payment_intent_create_params.rb', line 440

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



442
443
444
# File 'lib/stripe/params/payment_intent_create_params.rb', line 442

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



444
445
446
# File 'lib/stripe/params/payment_intent_create_params.rb', line 444

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



446
447
448
# File 'lib/stripe/params/payment_intent_create_params.rb', line 446

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



448
449
450
# File 'lib/stripe/params/payment_intent_create_params.rb', line 448

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



450
451
452
# File 'lib/stripe/params/payment_intent_create_params.rb', line 450

def suffix
  @suffix
end