Class: Stripe::PaymentIntentCreateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 452 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
440 441 442 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 440 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
442 443 444 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 442 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
444 445 446 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 444 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
446 447 448 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 446 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
448 449 450 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 448 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
450 451 452 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 450 def suffix @suffix end |