Class: Stripe::PaymentIntentCreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1177

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1165
1166
1167
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1165

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



1167
1168
1169
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1167

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



1169
1170
1171
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1169

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



1171
1172
1173
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1171

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



1173
1174
1175
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1173

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



1175
1176
1177
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1175

def suffix
  @suffix
end