Class: Stripe::PaymentIntentCreateParams::PaymentMethodData::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2603
2604
2605
2606
2607
2608
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2603

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



2595
2596
2597
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2595

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



2597
2598
2599
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2597

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



2599
2600
2601
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2599

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



2601
2602
2603
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2601

def end_date
  @end_date
end