Class: Stripe::PaymentIntentCreateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2346 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
2336 2337 2338 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2336 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
2338 2339 2340 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2338 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
2340 2341 2342 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2340 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
2342 2343 2344 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2342 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
2344 2345 2346 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2344 def routing_number @routing_number end |