Class: Stripe::PaymentIntentCreateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1313 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
1303 1304 1305 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1303 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
1305 1306 1307 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1305 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
1307 1308 1309 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1307 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
1309 1310 1311 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1309 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
1311 1312 1313 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1311 def routing_number @routing_number end |