Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, StripeBalance, Swish, Twint, UsBankAccount, WechatPay, Zip
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If this is a ‘acss_debit` PaymentMethod, this sub-hash contains details about the ACSS Debit payment method options.
-
#affirm ⇒ Object
If this is an ‘affirm` PaymentMethod, this sub-hash contains details about the Affirm payment method options.
-
#afterpay_clearpay ⇒ Object
If this is a ‘afterpay_clearpay` PaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options.
-
#alipay ⇒ Object
If this is a ‘alipay` PaymentMethod, this sub-hash contains details about the Alipay payment method options.
-
#alma ⇒ Object
If this is a ‘alma` PaymentMethod, this sub-hash contains details about the Alma payment method options.
-
#amazon_pay ⇒ Object
If this is a ‘amazon_pay` PaymentMethod, this sub-hash contains details about the Amazon Pay payment method options.
-
#au_becs_debit ⇒ Object
If this is a ‘au_becs_debit` PaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options.
-
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` PaymentMethod, this sub-hash contains details about the BACS Debit payment method options.
-
#bancontact ⇒ Object
If this is a ‘bancontact` PaymentMethod, this sub-hash contains details about the Bancontact payment method options.
-
#billie ⇒ Object
If this is a ‘billie` PaymentMethod, this sub-hash contains details about the Billie payment method options.
-
#blik ⇒ Object
If this is a ‘blik` PaymentMethod, this sub-hash contains details about the BLIK payment method options.
-
#boleto ⇒ Object
If this is a ‘boleto` PaymentMethod, this sub-hash contains details about the Boleto payment method options.
-
#card ⇒ Object
Configuration for any card payments attempted on this PaymentIntent.
-
#card_present ⇒ Object
If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.
-
#cashapp ⇒ Object
If this is a ‘cashapp` PaymentMethod, this sub-hash contains details about the Cash App Pay payment method options.
-
#crypto ⇒ Object
If this is a ‘crypto` PaymentMethod, this sub-hash contains details about the Crypto payment method options.
-
#customer_balance ⇒ Object
If this is a ‘customer balance` PaymentMethod, this sub-hash contains details about the customer balance payment method options.
-
#eps ⇒ Object
If this is a ‘eps` PaymentMethod, this sub-hash contains details about the EPS payment method options.
-
#fpx ⇒ Object
If this is a ‘fpx` PaymentMethod, this sub-hash contains details about the FPX payment method options.
-
#giropay ⇒ Object
If this is a ‘giropay` PaymentMethod, this sub-hash contains details about the Giropay payment method options.
-
#gopay ⇒ Object
If this is a ‘gopay` PaymentMethod, this sub-hash contains details about the Gopay payment method options.
-
#grabpay ⇒ Object
If this is a ‘grabpay` PaymentMethod, this sub-hash contains details about the Grabpay payment method options.
-
#id_bank_transfer ⇒ Object
If this is a ‘id_bank_transfer` PaymentMethod, this sub-hash contains details about the Indonesia Bank Transfer payment method options.
-
#ideal ⇒ Object
If this is a ‘ideal` PaymentMethod, this sub-hash contains details about the Ideal payment method options.
-
#interac_present ⇒ Object
If this is a ‘interac_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.
-
#kakao_pay ⇒ Object
If this is a ‘kakao_pay` PaymentMethod, this sub-hash contains details about the Kakao Pay payment method options.
-
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this sub-hash contains details about the Klarna payment method options.
-
#konbini ⇒ Object
If this is a ‘konbini` PaymentMethod, this sub-hash contains details about the Konbini payment method options.
-
#kr_card ⇒ Object
If this is a ‘kr_card` PaymentMethod, this sub-hash contains details about the KR Card payment method options.
-
#link ⇒ Object
If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options.
-
#mb_way ⇒ Object
If this is a ‘mb_way` PaymentMethod, this sub-hash contains details about the MB WAY payment method options.
-
#mobilepay ⇒ Object
If this is a ‘MobilePay` PaymentMethod, this sub-hash contains details about the MobilePay payment method options.
-
#multibanco ⇒ Object
If this is a ‘multibanco` PaymentMethod, this sub-hash contains details about the Multibanco payment method options.
-
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this sub-hash contains details about the Naver Pay payment method options.
-
#nz_bank_account ⇒ Object
If this is a ‘nz_bank_account` PaymentMethod, this sub-hash contains details about the NZ BECS Direct Debit payment method options.
-
#oxxo ⇒ Object
If this is a ‘oxxo` PaymentMethod, this sub-hash contains details about the OXXO payment method options.
-
#p24 ⇒ Object
If this is a ‘p24` PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options.
-
#pay_by_bank ⇒ Object
If this is a ‘pay_by_bank` PaymentMethod, this sub-hash contains details about the PayByBank payment method options.
-
#payco ⇒ Object
If this is a ‘payco` PaymentMethod, this sub-hash contains details about the PAYCO payment method options.
-
#paynow ⇒ Object
If this is a ‘paynow` PaymentMethod, this sub-hash contains details about the PayNow payment method options.
-
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.
-
#paypay ⇒ Object
If this is a ‘paypay` PaymentMethod, this sub-hash contains details about the PayPay payment method options.
-
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this sub-hash contains details about the PayTo payment method options.
-
#pix ⇒ Object
If this is a ‘pix` PaymentMethod, this sub-hash contains details about the Pix payment method options.
-
#promptpay ⇒ Object
If this is a ‘promptpay` PaymentMethod, this sub-hash contains details about the PromptPay payment method options.
-
#qris ⇒ Object
If this is a ‘qris` PaymentMethod, this sub-hash contains details about the QRIS payment method options.
-
#rechnung ⇒ Object
If this is a ‘rechnung` PaymentMethod, this sub-hash contains details about the Rechnung payment method options.
-
#revolut_pay ⇒ Object
If this is a ‘revolut_pay` PaymentMethod, this sub-hash contains details about the Revolut Pay payment method options.
-
#samsung_pay ⇒ Object
If this is a ‘samsung_pay` PaymentMethod, this sub-hash contains details about the Samsung Pay payment method options.
-
#satispay ⇒ Object
If this is a ‘satispay` PaymentMethod, this sub-hash contains details about the Satispay payment method options.
-
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` PaymentIntent, this sub-hash contains details about the SEPA Debit payment method options.
-
#shopeepay ⇒ Object
If this is a ‘shopeepay` PaymentMethod, this sub-hash contains details about the ShopeePay payment method options.
-
#sofort ⇒ Object
If this is a ‘sofort` PaymentMethod, this sub-hash contains details about the SOFORT payment method options.
-
#stripe_balance ⇒ Object
If this is a ‘stripe_balance` PaymentMethod, this sub-hash contains details about the Stripe Balance payment method options.
-
#swish ⇒ Object
If this is a ‘Swish` PaymentMethod, this sub-hash contains details about the Swish payment method options.
-
#twint ⇒ Object
If this is a ‘twint` PaymentMethod, this sub-hash contains details about the TWINT payment method options.
-
#us_bank_account ⇒ Object
If this is a ‘us_bank_account` PaymentMethod, this sub-hash contains details about the US bank account payment method options.
-
#wechat_pay ⇒ Object
If this is a ‘wechat_pay` PaymentMethod, this sub-hash contains details about the WeChat Pay payment method options.
-
#zip ⇒ Object
If this is a ‘zip` PaymentMethod, this sub-hash contains details about the Zip payment method options.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, blik: nil, boleto: nil, card: nil, card_present: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, paypay: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
5422 5423 5424 5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 5445 5446 5447 5448 5449 5450 5451 5452 5453 5454 5455 5456 5457 5458 5459 5460 5461 5462 5463 5464 5465 5466 5467 5468 5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 5507 5508 5509 5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 5542 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5422 def initialize( acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, blik: nil, boleto: nil, card: nil, card_present: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, paypay: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil ) @acss_debit = acss_debit @affirm = affirm @afterpay_clearpay = afterpay_clearpay @alipay = alipay @alma = alma @amazon_pay = amazon_pay @au_becs_debit = au_becs_debit @bacs_debit = bacs_debit @bancontact = bancontact @billie = billie @blik = blik @boleto = boleto @card = card @card_present = card_present @cashapp = cashapp @crypto = crypto @customer_balance = customer_balance @eps = eps @fpx = fpx @giropay = giropay @gopay = gopay @grabpay = grabpay @id_bank_transfer = id_bank_transfer @ideal = ideal @interac_present = interac_present @kakao_pay = kakao_pay @klarna = klarna @konbini = konbini @kr_card = kr_card @link = link @mb_way = mb_way @mobilepay = mobilepay @multibanco = multibanco @naver_pay = naver_pay @nz_bank_account = nz_bank_account @oxxo = oxxo @p24 = p24 @pay_by_bank = pay_by_bank @payco = payco @paynow = paynow @paypal = paypal @paypay = paypay @payto = payto @pix = pix @promptpay = promptpay @qris = qris @rechnung = rechnung @revolut_pay = revolut_pay @samsung_pay = samsung_pay @satispay = satispay @sepa_debit = sepa_debit @shopeepay = shopeepay @sofort = sofort @stripe_balance = stripe_balance @swish = swish @twint = twint @us_bank_account = us_bank_account @wechat_pay = wechat_pay @zip = zip end |
Instance Attribute Details
#acss_debit ⇒ Object
If this is a ‘acss_debit` PaymentMethod, this sub-hash contains details about the ACSS Debit payment method options.
5304 5305 5306 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5304 def acss_debit @acss_debit end |
#affirm ⇒ Object
If this is an ‘affirm` PaymentMethod, this sub-hash contains details about the Affirm payment method options.
5306 5307 5308 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5306 def affirm @affirm end |
#afterpay_clearpay ⇒ Object
If this is a ‘afterpay_clearpay` PaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options.
5308 5309 5310 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5308 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
If this is a ‘alipay` PaymentMethod, this sub-hash contains details about the Alipay payment method options.
5310 5311 5312 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5310 def alipay @alipay end |
#alma ⇒ Object
If this is a ‘alma` PaymentMethod, this sub-hash contains details about the Alma payment method options.
5312 5313 5314 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5312 def alma @alma end |
#amazon_pay ⇒ Object
If this is a ‘amazon_pay` PaymentMethod, this sub-hash contains details about the Amazon Pay payment method options.
5314 5315 5316 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5314 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object
If this is a ‘au_becs_debit` PaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options.
5316 5317 5318 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5316 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` PaymentMethod, this sub-hash contains details about the BACS Debit payment method options.
5318 5319 5320 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5318 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object
If this is a ‘bancontact` PaymentMethod, this sub-hash contains details about the Bancontact payment method options.
5320 5321 5322 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5320 def bancontact @bancontact end |
#billie ⇒ Object
If this is a ‘billie` PaymentMethod, this sub-hash contains details about the Billie payment method options.
5322 5323 5324 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5322 def billie @billie end |
#blik ⇒ Object
If this is a ‘blik` PaymentMethod, this sub-hash contains details about the BLIK payment method options.
5324 5325 5326 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5324 def blik @blik end |
#boleto ⇒ Object
If this is a ‘boleto` PaymentMethod, this sub-hash contains details about the Boleto payment method options.
5326 5327 5328 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5326 def boleto @boleto end |
#card ⇒ Object
Configuration for any card payments attempted on this PaymentIntent.
5328 5329 5330 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5328 def card @card end |
#card_present ⇒ Object
If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.
5330 5331 5332 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5330 def card_present @card_present end |
#cashapp ⇒ Object
If this is a ‘cashapp` PaymentMethod, this sub-hash contains details about the Cash App Pay payment method options.
5332 5333 5334 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5332 def cashapp @cashapp end |
#crypto ⇒ Object
If this is a ‘crypto` PaymentMethod, this sub-hash contains details about the Crypto payment method options.
5334 5335 5336 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5334 def crypto @crypto end |
#customer_balance ⇒ Object
If this is a ‘customer balance` PaymentMethod, this sub-hash contains details about the customer balance payment method options.
5336 5337 5338 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5336 def customer_balance @customer_balance end |
#eps ⇒ Object
If this is a ‘eps` PaymentMethod, this sub-hash contains details about the EPS payment method options.
5338 5339 5340 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5338 def eps @eps end |
#fpx ⇒ Object
If this is a ‘fpx` PaymentMethod, this sub-hash contains details about the FPX payment method options.
5340 5341 5342 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5340 def fpx @fpx end |
#giropay ⇒ Object
If this is a ‘giropay` PaymentMethod, this sub-hash contains details about the Giropay payment method options.
5342 5343 5344 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5342 def giropay @giropay end |
#gopay ⇒ Object
If this is a ‘gopay` PaymentMethod, this sub-hash contains details about the Gopay payment method options.
5344 5345 5346 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5344 def gopay @gopay end |
#grabpay ⇒ Object
If this is a ‘grabpay` PaymentMethod, this sub-hash contains details about the Grabpay payment method options.
5346 5347 5348 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5346 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object
If this is a ‘id_bank_transfer` PaymentMethod, this sub-hash contains details about the Indonesia Bank Transfer payment method options.
5348 5349 5350 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5348 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object
If this is a ‘ideal` PaymentMethod, this sub-hash contains details about the Ideal payment method options.
5350 5351 5352 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5350 def ideal @ideal end |
#interac_present ⇒ Object
If this is a ‘interac_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.
5352 5353 5354 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5352 def interac_present @interac_present end |
#kakao_pay ⇒ Object
If this is a ‘kakao_pay` PaymentMethod, this sub-hash contains details about the Kakao Pay payment method options.
5354 5355 5356 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5354 def kakao_pay @kakao_pay end |
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this sub-hash contains details about the Klarna payment method options.
5356 5357 5358 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5356 def klarna @klarna end |
#konbini ⇒ Object
If this is a ‘konbini` PaymentMethod, this sub-hash contains details about the Konbini payment method options.
5358 5359 5360 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5358 def konbini @konbini end |
#kr_card ⇒ Object
If this is a ‘kr_card` PaymentMethod, this sub-hash contains details about the KR Card payment method options.
5360 5361 5362 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5360 def kr_card @kr_card end |
#link ⇒ Object
If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options.
5362 5363 5364 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5362 def link @link end |
#mb_way ⇒ Object
If this is a ‘mb_way` PaymentMethod, this sub-hash contains details about the MB WAY payment method options.
5364 5365 5366 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5364 def mb_way @mb_way end |
#mobilepay ⇒ Object
If this is a ‘MobilePay` PaymentMethod, this sub-hash contains details about the MobilePay payment method options.
5366 5367 5368 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5366 def mobilepay @mobilepay end |
#multibanco ⇒ Object
If this is a ‘multibanco` PaymentMethod, this sub-hash contains details about the Multibanco payment method options.
5368 5369 5370 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5368 def multibanco @multibanco end |
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this sub-hash contains details about the Naver Pay payment method options.
5370 5371 5372 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5370 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object
If this is a ‘nz_bank_account` PaymentMethod, this sub-hash contains details about the NZ BECS Direct Debit payment method options.
5372 5373 5374 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5372 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object
If this is a ‘oxxo` PaymentMethod, this sub-hash contains details about the OXXO payment method options.
5374 5375 5376 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5374 def oxxo @oxxo end |
#p24 ⇒ Object
If this is a ‘p24` PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options.
5376 5377 5378 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5376 def p24 @p24 end |
#pay_by_bank ⇒ Object
If this is a ‘pay_by_bank` PaymentMethod, this sub-hash contains details about the PayByBank payment method options.
5378 5379 5380 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5378 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object
If this is a ‘payco` PaymentMethod, this sub-hash contains details about the PAYCO payment method options.
5380 5381 5382 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5380 def payco @payco end |
#paynow ⇒ Object
If this is a ‘paynow` PaymentMethod, this sub-hash contains details about the PayNow payment method options.
5382 5383 5384 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5382 def paynow @paynow end |
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.
5384 5385 5386 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5384 def paypal @paypal end |
#paypay ⇒ Object
If this is a ‘paypay` PaymentMethod, this sub-hash contains details about the PayPay payment method options.
5386 5387 5388 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5386 def paypay @paypay end |
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this sub-hash contains details about the PayTo payment method options.
5388 5389 5390 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5388 def payto @payto end |
#pix ⇒ Object
If this is a ‘pix` PaymentMethod, this sub-hash contains details about the Pix payment method options.
5390 5391 5392 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5390 def pix @pix end |
#promptpay ⇒ Object
If this is a ‘promptpay` PaymentMethod, this sub-hash contains details about the PromptPay payment method options.
5392 5393 5394 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5392 def promptpay @promptpay end |
#qris ⇒ Object
If this is a ‘qris` PaymentMethod, this sub-hash contains details about the QRIS payment method options.
5394 5395 5396 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5394 def qris @qris end |
#rechnung ⇒ Object
If this is a ‘rechnung` PaymentMethod, this sub-hash contains details about the Rechnung payment method options.
5396 5397 5398 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5396 def rechnung @rechnung end |
#revolut_pay ⇒ Object
If this is a ‘revolut_pay` PaymentMethod, this sub-hash contains details about the Revolut Pay payment method options.
5398 5399 5400 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5398 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object
If this is a ‘samsung_pay` PaymentMethod, this sub-hash contains details about the Samsung Pay payment method options.
5400 5401 5402 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5400 def samsung_pay @samsung_pay end |
#satispay ⇒ Object
If this is a ‘satispay` PaymentMethod, this sub-hash contains details about the Satispay payment method options.
5402 5403 5404 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5402 def satispay @satispay end |
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` PaymentIntent, this sub-hash contains details about the SEPA Debit payment method options.
5404 5405 5406 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5404 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object
If this is a ‘shopeepay` PaymentMethod, this sub-hash contains details about the ShopeePay payment method options.
5406 5407 5408 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5406 def shopeepay @shopeepay end |
#sofort ⇒ Object
If this is a ‘sofort` PaymentMethod, this sub-hash contains details about the SOFORT payment method options.
5408 5409 5410 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5408 def sofort @sofort end |
#stripe_balance ⇒ Object
If this is a ‘stripe_balance` PaymentMethod, this sub-hash contains details about the Stripe Balance payment method options.
5410 5411 5412 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5410 def stripe_balance @stripe_balance end |
#swish ⇒ Object
If this is a ‘Swish` PaymentMethod, this sub-hash contains details about the Swish payment method options.
5412 5413 5414 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5412 def swish @swish end |
#twint ⇒ Object
If this is a ‘twint` PaymentMethod, this sub-hash contains details about the TWINT payment method options.
5414 5415 5416 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5414 def twint @twint end |
#us_bank_account ⇒ Object
If this is a ‘us_bank_account` PaymentMethod, this sub-hash contains details about the US bank account payment method options.
5416 5417 5418 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5416 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
If this is a ‘wechat_pay` PaymentMethod, this sub-hash contains details about the WeChat Pay payment method options.
5418 5419 5420 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5418 def wechat_pay @wechat_pay end |
#zip ⇒ Object
If this is a ‘zip` PaymentMethod, this sub-hash contains details about the Zip payment method options.
5420 5421 5422 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5420 def zip @zip end |