Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Installments, MandateOptions, PaymentDetails, StatementDetails, ThreeDSecure
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
-
#cvc_token ⇒ Object
A single-use ‘cvc_update` Token that represents a card CVC value.
-
#installments ⇒ Object
Installment configuration for payments attempted on this PaymentIntent.
-
#mandate_options ⇒ Object
Configuration options for setting up an eMandate for cards issued in India.
-
#moto ⇒ Object
When specified, this parameter indicates that a transaction will be marked as MOTO (Mail Order Telephone Order) and thus out of scope for SCA.
-
#network ⇒ Object
Selected network to process this PaymentIntent on.
-
#payment_details ⇒ Object
Payment details for payment method specific funding fields.
-
#request_decremental_authorization ⇒ Object
Request ability to [decrement the authorization](docs.stripe.com/payments/decremental-authorization) for this PaymentIntent.
-
#request_extended_authorization ⇒ Object
Request ability to [capture beyond the standard authorization validity window](docs.stripe.com/payments/extended-authorization) for this PaymentIntent.
-
#request_incremental_authorization ⇒ Object
Request ability to [increment the authorization](docs.stripe.com/payments/incremental-authorization) for this PaymentIntent.
-
#request_multicapture ⇒ Object
Request ability to make [multiple captures](docs.stripe.com/payments/multicapture) for this PaymentIntent.
-
#request_overcapture ⇒ Object
Request ability to [overcapture](docs.stripe.com/payments/overcapture) for this PaymentIntent.
-
#request_partial_authorization ⇒ Object
Request partial authorization on this PaymentIntent.
-
#request_reauthorization ⇒ Object
Request ability to [reauthorize](docs.stripe.com/payments/reauthorization) for this PaymentIntent.
-
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](docs.stripe.com/strong-customer-authentication).
-
#require_cvc_recollection ⇒ Object
When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#statement_descriptor_suffix_kana ⇒ Object
Provides information about a card payment that customers see on their statements.
-
#statement_descriptor_suffix_kanji ⇒ Object
Provides information about a card payment that customers see on their statements.
-
#statement_details ⇒ Object
Statement details for this payment intent.
-
#three_d_secure ⇒ Object
If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this payment.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(capture_method: nil, cvc_token: nil, installments: nil, mandate_options: nil, moto: nil, network: nil, request_decremental_authorization: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_partial_authorization: nil, request_reauthorization: nil, request_three_d_secure: nil, require_cvc_recollection: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil, statement_details: nil, three_d_secure: nil, payment_details: nil) ⇒ Card
Returns a new instance of Card.
3176 3177 3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 3196 3197 3198 3199 3200 3201 3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 3213 3214 3215 3216 3217 3218 3219 3220 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3176 def initialize( capture_method: nil, cvc_token: nil, installments: nil, mandate_options: nil, moto: nil, network: nil, request_decremental_authorization: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_partial_authorization: nil, request_reauthorization: nil, request_three_d_secure: nil, require_cvc_recollection: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil, statement_details: nil, three_d_secure: nil, payment_details: nil ) @capture_method = capture_method @cvc_token = cvc_token @installments = installments @mandate_options = @moto = moto @network = network @request_decremental_authorization = @request_extended_authorization = @request_incremental_authorization = @request_multicapture = request_multicapture @request_overcapture = request_overcapture @request_partial_authorization = @request_reauthorization = @request_three_d_secure = request_three_d_secure @require_cvc_recollection = require_cvc_recollection @setup_future_usage = setup_future_usage @statement_descriptor_suffix_kana = statement_descriptor_suffix_kana @statement_descriptor_suffix_kanji = statement_descriptor_suffix_kanji @statement_details = statement_details @three_d_secure = three_d_secure @payment_details = payment_details end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.
If ‘capture_method` is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.
3121 3122 3123 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3121 def capture_method @capture_method end |
#cvc_token ⇒ Object
A single-use ‘cvc_update` Token that represents a card CVC value. When provided, the CVC value will be verified during the card payment attempt. This parameter can only be provided during confirmation.
3123 3124 3125 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3123 def cvc_token @cvc_token end |
#installments ⇒ Object
Installment configuration for payments attempted on this PaymentIntent.
For more information, see the [installments integration guide](docs.stripe.com/payments/installments).
3127 3128 3129 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3127 def installments @installments end |
#mandate_options ⇒ Object
Configuration options for setting up an eMandate for cards issued in India.
3129 3130 3131 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3129 def @mandate_options end |
#moto ⇒ Object
When specified, this parameter indicates that a transaction will be marked as MOTO (Mail Order Telephone Order) and thus out of scope for SCA. This parameter can only be provided during confirmation.
3133 3134 3135 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3133 def moto @moto end |
#network ⇒ Object
Selected network to process this PaymentIntent on. Depends on the available networks of the card attached to the PaymentIntent. Can be only set confirm-time.
3135 3136 3137 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3135 def network @network end |
#payment_details ⇒ Object
Payment details for payment method specific funding fields.
3174 3175 3176 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3174 def payment_details @payment_details end |
#request_decremental_authorization ⇒ Object
Request ability to [decrement the authorization](docs.stripe.com/payments/decremental-authorization) for this PaymentIntent.
3137 3138 3139 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3137 def @request_decremental_authorization end |
#request_extended_authorization ⇒ Object
Request ability to [capture beyond the standard authorization validity window](docs.stripe.com/payments/extended-authorization) for this PaymentIntent.
3139 3140 3141 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3139 def @request_extended_authorization end |
#request_incremental_authorization ⇒ Object
Request ability to [increment the authorization](docs.stripe.com/payments/incremental-authorization) for this PaymentIntent.
3141 3142 3143 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3141 def @request_incremental_authorization end |
#request_multicapture ⇒ Object
Request ability to make [multiple captures](docs.stripe.com/payments/multicapture) for this PaymentIntent.
3143 3144 3145 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3143 def request_multicapture @request_multicapture end |
#request_overcapture ⇒ Object
Request ability to [overcapture](docs.stripe.com/payments/overcapture) for this PaymentIntent.
3145 3146 3147 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3145 def request_overcapture @request_overcapture end |
#request_partial_authorization ⇒ Object
Request partial authorization on this PaymentIntent.
3147 3148 3149 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3147 def @request_partial_authorization end |
#request_reauthorization ⇒ Object
Request ability to [reauthorize](docs.stripe.com/payments/reauthorization) for this PaymentIntent.
3149 3150 3151 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3149 def @request_reauthorization end |
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](docs.stripe.com/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](docs.stripe.com/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.
3151 3152 3153 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3151 def request_three_d_secure @request_three_d_secure end |
#require_cvc_recollection ⇒ Object
When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).
3153 3154 3155 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3153 def require_cvc_recollection @require_cvc_recollection end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.
3163 3164 3165 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3163 def setup_future_usage @setup_future_usage end |
#statement_descriptor_suffix_kana ⇒ Object
Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.
3165 3166 3167 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3165 def statement_descriptor_suffix_kana @statement_descriptor_suffix_kana end |
#statement_descriptor_suffix_kanji ⇒ Object
Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.
3167 3168 3169 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3167 def statement_descriptor_suffix_kanji @statement_descriptor_suffix_kanji end |
#statement_details ⇒ Object
Statement details for this payment intent. You can use this to override the merchant details shown on your customers’ statements.
3169 3170 3171 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3169 def statement_details @statement_details end |
#three_d_secure ⇒ Object
If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this payment.
3172 3173 3174 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3172 def three_d_secure @three_d_secure end |