Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Installments, MandateOptions, ThreeDSecure
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
-
#cvc_token ⇒ Object
A single-use
cvc_updateToken that represents a card CVC value. -
#installments ⇒ Object
Installment configuration for payments attempted on this PaymentIntent.
-
#mandate_options ⇒ Object
Configuration options for setting up an eMandate for cards issued in India.
-
#moto ⇒ Object
When specified, this parameter indicates that a transaction will be marked as MOTO (Mail Order Telephone Order) and thus out of scope for SCA.
-
#network ⇒ Object
Selected network to process this PaymentIntent on.
-
#request_extended_authorization ⇒ Object
Request ability to [capture beyond the standard authorization validity window](docs.stripe.com/payments/extended-authorization) for this PaymentIntent.
-
#request_incremental_authorization ⇒ Object
Request ability to [increment the authorization](docs.stripe.com/payments/incremental-authorization) for this PaymentIntent.
-
#request_multicapture ⇒ Object
Request ability to make [multiple captures](docs.stripe.com/payments/multicapture) for this PaymentIntent.
-
#request_overcapture ⇒ Object
Request ability to [overcapture](docs.stripe.com/payments/overcapture) for this PaymentIntent.
-
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](docs.stripe.com/strong-customer-authentication).
-
#require_cvc_recollection ⇒ Object
When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#statement_descriptor_suffix_kana ⇒ Object
Provides information about a card payment that customers see on their statements.
-
#statement_descriptor_suffix_kanji ⇒ Object
Provides information about a card payment that customers see on their statements.
-
#three_d_secure ⇒ Object
If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this payment.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(capture_method: nil, cvc_token: nil, installments: nil, mandate_options: nil, moto: nil, network: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_three_d_secure: nil, require_cvc_recollection: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil, three_d_secure: nil) ⇒ Card
Returns a new instance of Card.
1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1343 def initialize( capture_method: nil, cvc_token: nil, installments: nil, mandate_options: nil, moto: nil, network: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_three_d_secure: nil, require_cvc_recollection: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil, three_d_secure: nil ) @capture_method = capture_method @cvc_token = cvc_token @installments = installments = @moto = moto @network = network = = @request_multicapture = request_multicapture @request_overcapture = request_overcapture @request_three_d_secure = request_three_d_secure @require_cvc_recollection = require_cvc_recollection @setup_future_usage = setup_future_usage @statement_descriptor_suffix_kana = statement_descriptor_suffix_kana @statement_descriptor_suffix_kanji = statement_descriptor_suffix_kanji @three_d_secure = three_d_secure end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.
If capture_method is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.
1298 1299 1300 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1298 def capture_method @capture_method end |
#cvc_token ⇒ Object
A single-use cvc_update Token that represents a card CVC value. When provided, the CVC value will be verified during the card payment attempt. This parameter can only be provided during confirmation.
1300 1301 1302 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1300 def cvc_token @cvc_token end |
#installments ⇒ Object
Installment configuration for payments attempted on this PaymentIntent.
For more information, see the [installments integration guide](docs.stripe.com/payments/installments).
1304 1305 1306 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1304 def installments @installments end |
#mandate_options ⇒ Object
Configuration options for setting up an eMandate for cards issued in India.
1306 1307 1308 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1306 def end |
#moto ⇒ Object
When specified, this parameter indicates that a transaction will be marked as MOTO (Mail Order Telephone Order) and thus out of scope for SCA. This parameter can only be provided during confirmation.
1310 1311 1312 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1310 def moto @moto end |
#network ⇒ Object
Selected network to process this PaymentIntent on. Depends on the available networks of the card attached to the PaymentIntent. Can be only set confirm-time.
1312 1313 1314 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1312 def network @network end |
#request_extended_authorization ⇒ Object
Request ability to [capture beyond the standard authorization validity window](docs.stripe.com/payments/extended-authorization) for this PaymentIntent.
1314 1315 1316 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1314 def end |
#request_incremental_authorization ⇒ Object
Request ability to [increment the authorization](docs.stripe.com/payments/incremental-authorization) for this PaymentIntent.
1316 1317 1318 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1316 def end |
#request_multicapture ⇒ Object
Request ability to make [multiple captures](docs.stripe.com/payments/multicapture) for this PaymentIntent.
1318 1319 1320 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1318 def request_multicapture @request_multicapture end |
#request_overcapture ⇒ Object
Request ability to [overcapture](docs.stripe.com/payments/overcapture) for this PaymentIntent.
1320 1321 1322 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1320 def request_overcapture @request_overcapture end |
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](docs.stripe.com/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to automatic. Read our guide on [manually requesting 3D Secure](docs.stripe.com/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.
1322 1323 1324 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1322 def request_three_d_secure @request_three_d_secure end |
#require_cvc_recollection ⇒ Object
When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).
1324 1325 1326 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1324 def require_cvc_recollection @require_cvc_recollection end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set setup_future_usage and you’re performing a request using a publishable key, you can only update the value from on_session to off_session.
1334 1335 1336 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1334 def setup_future_usage @setup_future_usage end |
#statement_descriptor_suffix_kana ⇒ Object
Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.
1336 1337 1338 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1336 def statement_descriptor_suffix_kana @statement_descriptor_suffix_kana end |
#statement_descriptor_suffix_kanji ⇒ Object
Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.
1338 1339 1340 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1338 def statement_descriptor_suffix_kanji @statement_descriptor_suffix_kanji end |
#three_d_secure ⇒ Object
If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this payment.
1341 1342 1343 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1341 def three_d_secure @three_d_secure end |