Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Card::Installments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Plan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(enabled: nil, plan: nil) ⇒ Installments

Returns a new instance of Installments.



3241
3242
3243
3244
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3241

def initialize(enabled: nil, plan: nil)
  @enabled = enabled
  @plan = plan
end

Instance Attribute Details

#enabledObject

Setting to true enables installments for this PaymentIntent. This will cause the response to contain a list of available installment plans. Setting to false will prevent any selected plan from applying to a charge.



3236
3237
3238
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3236

def enabled
  @enabled
end

#planObject

The selected installment plan to use for this payment attempt. This parameter can only be provided during confirmation.



3239
3240
3241
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3239

def plan
  @plan
end