Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Card::Installments::Plan
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Card::Installments::Plan
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#count ⇒ Object
For
fixed_countinstallment plans, this is required. -
#interval ⇒ Object
For
fixed_countinstallment plans, this is required. -
#type ⇒ Object
Type of installment plan, one of
fixed_count,bonus, orrevolving.
Instance Method Summary collapse
-
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
constructor
A new instance of Plan.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
Returns a new instance of Plan.
1173 1174 1175 1176 1177 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1173 def initialize(count: nil, interval: nil, type: nil) @count = count @interval = interval @type = type end |
Instance Attribute Details
#count ⇒ Object
For fixed_count installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.
1166 1167 1168 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1166 def count @count end |
#interval ⇒ Object
For fixed_count installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card.
One of month.
1169 1170 1171 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1169 def interval @interval end |
#type ⇒ Object
Type of installment plan, one of fixed_count, bonus, or revolving.
1171 1172 1173 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1171 def type @type end |