Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



2919
2920
2921
2922
2923
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2919

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



2912
2913
2914
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2912

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



2915
2916
2917
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2915

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



2917
2918
2919
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2917

def type
  @type
end