Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



2861
2862
2863
2864
2865
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2861

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



2854
2855
2856
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2854

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



2857
2858
2859
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2857

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



2859
2860
2861
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2859

def type
  @type
end