Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Card::Installments::Plan
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Card::Installments::Plan
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#count ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.
Instance Method Summary collapse
-
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
constructor
A new instance of Plan.
Methods inherited from RequestParams
Constructor Details
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
Returns a new instance of Plan.
2831 2832 2833 2834 2835 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2831 def initialize(count: nil, interval: nil, type: nil) @count = count @interval = interval @type = type end |
Instance Attribute Details
#count ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.
2824 2825 2826 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2824 def count @count end |
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.
2827 2828 2829 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2827 def interval @interval end |
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.
2829 2830 2831 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2829 def type @type end |