Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



1070
1071
1072
1073
1074
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1070

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



1063
1064
1065
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1063

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



1066
1067
1068
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1066

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



1068
1069
1070
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1068

def type
  @type
end