Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Card::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Card::MandateOptions
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments, specified in the presentment currency.
-
#amount_type ⇒ Object
One of
fixedormaximum. -
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
-
#end_date ⇒ Object
End date of the mandate or subscription.
-
#interval ⇒ Object
Specifies payment frequency.
-
#interval_count ⇒ Object
The number of intervals between payments.
-
#reference ⇒ Object
Unique identifier for the mandate or subscription.
-
#start_date ⇒ Object
Start date of the mandate or subscription.
-
#supported_types ⇒ Object
Specifies the type of mandates supported.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
3357 3358 3359 3360 3361 3362 3363 3364 3365 3366 3367 3368 3369 3370 3371 3372 3373 3374 3375 3376 3377 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3357 def initialize( amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil ) @amount = amount @amount_type = amount_type @description = description @end_date = end_date @interval = interval @interval_count = interval_count @reference = reference @start_date = start_date @supported_types = supported_types end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments, specified in the presentment currency.
3339 3340 3341 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3339 def amount @amount end |
#amount_type ⇒ Object
One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.
3341 3342 3343 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3341 def amount_type @amount_type end |
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
3343 3344 3345 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3343 def description @description end |
#end_date ⇒ Object
End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.
3345 3346 3347 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3345 def end_date @end_date end |
#interval ⇒ Object
Specifies payment frequency. One of day, week, month, year, or sporadic.
3347 3348 3349 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3347 def interval @interval end |
#interval_count ⇒ Object
The number of intervals between payments. For example, interval=month and interval_count=3 indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when interval=sporadic.
3349 3350 3351 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3349 def interval_count @interval_count end |
#reference ⇒ Object
Unique identifier for the mandate or subscription.
3351 3352 3353 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3351 def reference @reference end |
#start_date ⇒ Object
Start date of the mandate or subscription. Start date should not be lesser than yesterday.
3353 3354 3355 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3353 def start_date @start_date end |
#supported_types ⇒ Object
Specifies the type of mandates supported. Possible values are india.
3355 3356 3357 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3355 def supported_types @supported_types end |