Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



3248
3249
3250
3251
3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
3264
3265
3266
3267
3268
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3248

def initialize(
  amount: nil,
  amount_type: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments, specified in the presentment currency.



3230
3231
3232
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3230

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



3232
3233
3234
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3232

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



3234
3235
3236
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3234

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



3236
3237
3238
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3236

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



3238
3239
3240
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3238

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



3240
3241
3242
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3240

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



3242
3243
3244
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3242

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



3244
3245
3246
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3244

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are ‘india`.



3246
3247
3248
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3246

def supported_types
  @supported_types
end