Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Card::StatementDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Card::StatementDetails
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Please pass in an address that is within your Stripe user account country.
-
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call).
Instance Method Summary collapse
-
#initialize(address: nil, phone: nil) ⇒ StatementDetails
constructor
A new instance of StatementDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, phone: nil) ⇒ StatementDetails
Returns a new instance of StatementDetails.
2980 2981 2982 2983 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2980 def initialize(address: nil, phone: nil) @address = address @phone = phone end |
Instance Attribute Details
#address ⇒ Object
Please pass in an address that is within your Stripe user account country
2976 2977 2978 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2976 def address @address end |
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call)
2978 2979 2980 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2978 def phone @phone end |