Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Card::StatementDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Card::StatementDetails
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Please pass in an address that is within your Stripe user account country.
-
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call).
Instance Method Summary collapse
-
#initialize(address: nil, phone: nil) ⇒ StatementDetails
constructor
A new instance of StatementDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, phone: nil) ⇒ StatementDetails
Returns a new instance of StatementDetails.
2947 2948 2949 2950 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2947 def initialize(address: nil, phone: nil) @address = address @phone = phone end |
Instance Attribute Details
#address ⇒ Object
Please pass in an address that is within your Stripe user account country
2943 2944 2945 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2943 def address @address end |
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call)
2945 2946 2947 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2945 def phone @phone end |