Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::CardPresent
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::CardPresent
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: CaptureDelay, PaymentDetails, Routing
Instance Attribute Summary collapse
-
#capture_by ⇒ Object
Controls when funds are captured from the customer's account when
capture_methodisautomatic_delayed. -
#capture_delay ⇒ Object
The number of days or hours to delay the capture of the funds.
-
#capture_method ⇒ Object
Controls when the funds are captured from the customer's account.
-
#payment_details ⇒ Object
Payment details for payment method specific funding transaction fields.
-
#request_extended_authorization ⇒ Object
Request ability to capture this payment beyond the standard authorization validity window.
-
#request_incremental_authorization_support ⇒ Object
Request ability to increment this PaymentIntent if the combination of MCC and card brand is eligible.
-
#request_multicapture ⇒ Object
Request ability to make multiple captures for this PaymentIntent.
-
#request_reauthorization ⇒ Object
Request ability to reauthorize for this PaymentIntent.
-
#routing ⇒ Object
Network routing priority on co-branded EMV cards supporting domestic debit and international card schemes.
Instance Method Summary collapse
-
#initialize(capture_by: nil, capture_delay: nil, capture_method: nil, payment_details: nil, request_extended_authorization: nil, request_incremental_authorization_support: nil, request_multicapture: nil, request_reauthorization: nil, routing: nil) ⇒ CardPresent
constructor
A new instance of CardPresent.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(capture_by: nil, capture_delay: nil, capture_method: nil, payment_details: nil, request_extended_authorization: nil, request_incremental_authorization_support: nil, request_multicapture: nil, request_reauthorization: nil, routing: nil) ⇒ CardPresent
Returns a new instance of CardPresent.
3713 3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3713 def initialize( capture_by: nil, capture_delay: nil, capture_method: nil, payment_details: nil, request_extended_authorization: nil, request_incremental_authorization_support: nil, request_multicapture: nil, request_reauthorization: nil, routing: nil ) @capture_by = capture_by @capture_delay = capture_delay @capture_method = capture_method @payment_details = payment_details @request_extended_authorization = @request_incremental_authorization_support = @request_multicapture = request_multicapture @request_reauthorization = @routing = routing end |
Instance Attribute Details
#capture_by ⇒ Object
Controls when funds are captured from the customer's account when capture_method is automatic_delayed.
If omitted, funds are captured before the authorization expires.
3689 3690 3691 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3689 def capture_by @capture_by end |
#capture_delay ⇒ Object
The number of days or hours to delay the capture of the funds. You can set both days and hours as long as the total delay does not exceed 30 days.
You can only set this if capture_method is automatic_delayed and capture_by is target_delay.
3693 3694 3695 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3693 def capture_delay @capture_delay end |
#capture_method ⇒ Object
Controls when the funds are captured from the customer's account.
If provided, this parameter overrides the behavior of the top-level capture_method for this payment method type when finalizing the payment with this payment method type.
If capture_method is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.
3699 3700 3701 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3699 def capture_method @capture_method end |
#payment_details ⇒ Object
Payment details for payment method specific funding transaction fields.
3701 3702 3703 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3701 def payment_details @payment_details end |
#request_extended_authorization ⇒ Object
Request ability to capture this payment beyond the standard authorization validity window
3703 3704 3705 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3703 def @request_extended_authorization end |
#request_incremental_authorization_support ⇒ Object
Request ability to increment this PaymentIntent if the combination of MCC and card brand is eligible. Check incremental_authorization_supported in the Confirm response to verify support.
3705 3706 3707 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3705 def @request_incremental_authorization_support end |
#request_multicapture ⇒ Object
Request ability to make multiple captures for this PaymentIntent.
3707 3708 3709 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3707 def request_multicapture @request_multicapture end |
#request_reauthorization ⇒ Object
Request ability to reauthorize for this PaymentIntent.
3709 3710 3711 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3709 def @request_reauthorization end |
#routing ⇒ Object
Network routing priority on co-branded EMV cards supporting domestic debit and international card schemes.
3711 3712 3713 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3711 def routing @routing end |