Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::CardPresent
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::CardPresent
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: PaymentDetails, Routing
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
-
#payment_details ⇒ Object
Payment details for payment method specific funding transaction fields.
-
#request_extended_authorization ⇒ Object
Request ability to capture this payment beyond the standard [authorization validity window](docs.stripe.com/terminal/features/extended-authorizations#authorization-validity).
-
#request_incremental_authorization_support ⇒ Object
Request ability to [increment](docs.stripe.com/terminal/features/incremental-authorizations) this PaymentIntent if the combination of MCC and card brand is eligible.
-
#request_reauthorization ⇒ Object
Request ability to [reauthorize](docs.stripe.com/payments/reauthorization) for this PaymentIntent.
-
#routing ⇒ Object
Network routing priority on co-branded EMV cards supporting domestic debit and international card schemes.
Instance Method Summary collapse
-
#initialize(capture_method: nil, payment_details: nil, request_extended_authorization: nil, request_incremental_authorization_support: nil, request_reauthorization: nil, routing: nil) ⇒ CardPresent
constructor
A new instance of CardPresent.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(capture_method: nil, payment_details: nil, request_extended_authorization: nil, request_incremental_authorization_support: nil, request_reauthorization: nil, routing: nil) ⇒ CardPresent
Returns a new instance of CardPresent.
3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3692 def initialize( capture_method: nil, payment_details: nil, request_extended_authorization: nil, request_incremental_authorization_support: nil, request_reauthorization: nil, routing: nil ) @capture_method = capture_method @payment_details = payment_details @request_extended_authorization = @request_incremental_authorization_support = @request_reauthorization = @routing = routing end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.
If ‘capture_method` is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.
3680 3681 3682 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3680 def capture_method @capture_method end |
#payment_details ⇒ Object
Payment details for payment method specific funding transaction fields.
3682 3683 3684 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3682 def payment_details @payment_details end |
#request_extended_authorization ⇒ Object
Request ability to capture this payment beyond the standard [authorization validity window](docs.stripe.com/terminal/features/extended-authorizations#authorization-validity)
3684 3685 3686 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3684 def @request_extended_authorization end |
#request_incremental_authorization_support ⇒ Object
Request ability to [increment](docs.stripe.com/terminal/features/incremental-authorizations) this PaymentIntent if the combination of MCC and card brand is eligible. Check [incremental_authorization_supported](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-incremental_authorization_supported) in the [Confirm](docs.stripe.com/api/payment_intents/confirm) response to verify support.
3686 3687 3688 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3686 def @request_incremental_authorization_support end |
#request_reauthorization ⇒ Object
Request ability to [reauthorize](docs.stripe.com/payments/reauthorization) for this PaymentIntent.
3688 3689 3690 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3688 def @request_reauthorization end |
#routing ⇒ Object
Network routing priority on co-branded EMV cards supporting domestic debit and international card schemes.
3690 3691 3692 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3690 def routing @routing end |