Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::CardPresent
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::CardPresent
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Routing
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
-
#request_extended_authorization ⇒ Object
Request ability to capture this payment beyond the standard [authorization validity window](docs.stripe.com/terminal/features/extended-authorizations#authorization-validity).
-
#request_incremental_authorization_support ⇒ Object
Request ability to [increment](docs.stripe.com/terminal/features/incremental-authorizations) this PaymentIntent if the combination of MCC and card brand is eligible.
-
#routing ⇒ Object
Network routing priority on co-branded EMV cards supporting domestic debit and international card schemes.
Instance Method Summary collapse
-
#initialize(capture_method: nil, request_extended_authorization: nil, request_incremental_authorization_support: nil, routing: nil) ⇒ CardPresent
constructor
A new instance of CardPresent.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(capture_method: nil, request_extended_authorization: nil, request_incremental_authorization_support: nil, routing: nil) ⇒ CardPresent
Returns a new instance of CardPresent.
3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3181 def initialize( capture_method: nil, request_extended_authorization: nil, request_incremental_authorization_support: nil, routing: nil ) @capture_method = capture_method @request_extended_authorization = @request_incremental_authorization_support = @routing = routing end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.
If ‘capture_method` is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.
3173 3174 3175 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3173 def capture_method @capture_method end |
#request_extended_authorization ⇒ Object
Request ability to capture this payment beyond the standard [authorization validity window](docs.stripe.com/terminal/features/extended-authorizations#authorization-validity)
3175 3176 3177 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3175 def @request_extended_authorization end |
#request_incremental_authorization_support ⇒ Object
Request ability to [increment](docs.stripe.com/terminal/features/incremental-authorizations) this PaymentIntent if the combination of MCC and card brand is eligible. Check [incremental_authorization_supported](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-incremental_authorization_supported) in the [Confirm](docs.stripe.com/api/payment_intents/confirm) response to verify support.
3177 3178 3179 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3177 def @request_incremental_authorization_support end |
#routing ⇒ Object
Network routing priority on co-branded EMV cards supporting domestic debit and international card schemes.
3179 3180 3181 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3179 def routing @routing end |