Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Crypto

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: DepositOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(deposit_options: nil, mode: nil, setup_future_usage: nil) ⇒ Crypto

Returns a new instance of Crypto.



3760
3761
3762
3763
3764
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3760

def initialize(deposit_options: nil, mode: nil, setup_future_usage: nil)
  @deposit_options = deposit_options
  @mode = mode
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#deposit_optionsObject

Specific configuration for this PaymentIntent when the mode is ‘deposit`.



3746
3747
3748
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3746

def deposit_options
  @deposit_options
end

#modeObject

The mode of the crypto payment.



3748
3749
3750
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3748

def mode
  @mode
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



3758
3759
3760
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3758

def setup_future_usage
  @setup_future_usage
end