Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Crypto
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Crypto
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: DepositOptions
Instance Attribute Summary collapse
-
#deposit_options ⇒ Object
Specific configuration for this PaymentIntent when the mode is ‘deposit`.
-
#mode ⇒ Object
The mode of the crypto payment.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
Instance Method Summary collapse
-
#initialize(deposit_options: nil, mode: nil, setup_future_usage: nil) ⇒ Crypto
constructor
A new instance of Crypto.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(deposit_options: nil, mode: nil, setup_future_usage: nil) ⇒ Crypto
Returns a new instance of Crypto.
3271 3272 3273 3274 3275 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3271 def initialize(deposit_options: nil, mode: nil, setup_future_usage: nil) @deposit_options = @mode = mode @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#deposit_options ⇒ Object
Specific configuration for this PaymentIntent when the mode is ‘deposit`.
3257 3258 3259 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3257 def @deposit_options end |
#mode ⇒ Object
The mode of the crypto payment.
3259 3260 3261 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3259 def mode @mode end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.
3269 3270 3271 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3269 def setup_future_usage @setup_future_usage end |