Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::IdBankTransfer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(expires_after: nil, expires_at: nil, setup_future_usage: nil) ⇒ IdBankTransfer

Returns a new instance of IdBankTransfer.



3383
3384
3385
3386
3387
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3383

def initialize(expires_after: nil, expires_at: nil, setup_future_usage: nil)
  @expires_after = expires_after
  @expires_at = expires_at
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#expires_afterObject

The UNIX timestamp until which the virtual bank account is valid. Permitted range is from 5 minutes from now until 31 days from now. If unset, it defaults to 3 days from now.



3369
3370
3371
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3369

def expires_after
  @expires_after
end

#expires_atObject

The UNIX timestamp until which the virtual bank account is valid. Permitted range is from now until 30 days from now. If unset, it defaults to 1 days from now.



3371
3372
3373
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3371

def expires_at
  @expires_at
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



3381
3382
3383
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3381

def setup_future_usage
  @setup_future_usage
end