Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::OnDemand

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand

Returns a new instance of OnDemand.



3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3999

def initialize(
  average_amount: nil,
  maximum_amount: nil,
  minimum_amount: nil,
  purchase_interval: nil,
  purchase_interval_count: nil
)
  @average_amount = average_amount
  @maximum_amount = maximum_amount
  @minimum_amount = minimum_amount
  @purchase_interval = purchase_interval
  @purchase_interval_count = purchase_interval_count
end

Instance Attribute Details

#average_amountObject

Your average amount value. You can use a value across your customer base, or segment based on customer type, country, etc.



3989
3990
3991
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3989

def average_amount
  @average_amount
end

#maximum_amountObject

The maximum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



3991
3992
3993
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3991

def maximum_amount
  @maximum_amount
end

#minimum_amountObject

The lowest or minimum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



3993
3994
3995
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3993

def minimum_amount
  @minimum_amount
end

#purchase_intervalObject

Interval at which the customer is making purchases



3995
3996
3997
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3995

def purchase_interval
  @purchase_interval
end

#purchase_interval_countObject

The number of ‘purchase_interval` between charges



3997
3998
3999
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3997

def purchase_interval_count
  @purchase_interval_count
end