Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
3482 3483 3484 3485 3486 3487 3488 3489 3490 3491 3492 3493 3494 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3482 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
3472 3473 3474 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3472 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
3474 3475 3476 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3474 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
3476 3477 3478 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3476 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
3478 3479 3480 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3478 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
3480 3481 3482 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3480 def reference @reference end |