Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
3525 3526 3527 3528 3529 3530 3531 3532 3533 3534 3535 3536 3537 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3525 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
3515 3516 3517 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3515 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
3517 3518 3519 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3517 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
3519 3520 3521 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3519 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
3521 3522 3523 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3521 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
3523 3524 3525 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3523 def reference @reference end |