Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount of the next charge for the subscription.
-
#date ⇒ Object
The date of the next charge for the subscription in YYYY-MM-DD format.
Instance Method Summary collapse
-
#initialize(amount: nil, date: nil) ⇒ NextBilling
constructor
A new instance of NextBilling.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, date: nil) ⇒ NextBilling
Returns a new instance of NextBilling.
3478 3479 3480 3481 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3478 def initialize(amount: nil, date: nil) @amount = amount @date = date end |
Instance Attribute Details
#amount ⇒ Object
The amount of the next charge for the subscription.
3474 3475 3476 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3474 def amount @amount end |
#date ⇒ Object
The date of the next charge for the subscription in YYYY-MM-DD format.
3476 3477 3478 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3476 def date @date end |