Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



3446
3447
3448
3449
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3446

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



3442
3443
3444
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3442

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



3444
3445
3446
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3444

def date
  @date
end