Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



1619
1620
1621
1622
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1619

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



1615
1616
1617
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1615

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



1617
1618
1619
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1617

def date
  @date
end