Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: BusReservationDetail, EventReservationDetail, FerryReservationDetail, Insurance, MarketplaceSeller, RoundTripReservationDetail, TrainReservationDetail, Voucher
Instance Attribute Summary collapse
-
#bus_reservation_details ⇒ Object
Supplementary bus reservation details.
-
#event_reservation_details ⇒ Object
Supplementary event reservation details.
-
#ferry_reservation_details ⇒ Object
Supplementary ferry reservation details.
-
#insurances ⇒ Object
Supplementary insurance details.
-
#marketplace_sellers ⇒ Object
Supplementary marketplace seller details.
-
#round_trip_reservation_details ⇒ Object
Supplementary round trip reservation details.
-
#train_reservation_details ⇒ Object
Supplementary train reservation details.
-
#vouchers ⇒ Object
Voucher details, such as a gift card or discount code.
Instance Method Summary collapse
-
#initialize(bus_reservation_details: nil, event_reservation_details: nil, ferry_reservation_details: nil, insurances: nil, marketplace_sellers: nil, round_trip_reservation_details: nil, train_reservation_details: nil, vouchers: nil) ⇒ SupplementaryPurchaseData
constructor
A new instance of SupplementaryPurchaseData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bus_reservation_details: nil, event_reservation_details: nil, ferry_reservation_details: nil, insurances: nil, marketplace_sellers: nil, round_trip_reservation_details: nil, train_reservation_details: nil, vouchers: nil) ⇒ SupplementaryPurchaseData
Returns a new instance of SupplementaryPurchaseData.
4421 4422 4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 4433 4434 4435 4436 4437 4438 4439 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4421 def initialize( bus_reservation_details: nil, event_reservation_details: nil, ferry_reservation_details: nil, insurances: nil, marketplace_sellers: nil, round_trip_reservation_details: nil, train_reservation_details: nil, vouchers: nil ) @bus_reservation_details = bus_reservation_details @event_reservation_details = event_reservation_details @ferry_reservation_details = ferry_reservation_details @insurances = insurances @marketplace_sellers = marketplace_sellers @round_trip_reservation_details = round_trip_reservation_details @train_reservation_details = train_reservation_details @vouchers = vouchers end |
Instance Attribute Details
#bus_reservation_details ⇒ Object
Supplementary bus reservation details.
4405 4406 4407 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4405 def bus_reservation_details @bus_reservation_details end |
#event_reservation_details ⇒ Object
Supplementary event reservation details.
4407 4408 4409 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4407 def event_reservation_details @event_reservation_details end |
#ferry_reservation_details ⇒ Object
Supplementary ferry reservation details.
4409 4410 4411 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4409 def ferry_reservation_details @ferry_reservation_details end |
#insurances ⇒ Object
Supplementary insurance details.
4411 4412 4413 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4411 def insurances @insurances end |
#marketplace_sellers ⇒ Object
Supplementary marketplace seller details.
4413 4414 4415 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4413 def marketplace_sellers @marketplace_sellers end |
#round_trip_reservation_details ⇒ Object
Supplementary round trip reservation details.
4415 4416 4417 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4415 def round_trip_reservation_details @round_trip_reservation_details end |
#train_reservation_details ⇒ Object
Supplementary train reservation details.
4417 4418 4419 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4417 def train_reservation_details @train_reservation_details end |
#vouchers ⇒ Object
Voucher details, such as a gift card or discount code.
4419 4420 4421 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4419 def vouchers @vouchers end |