Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: BusReservationDetail, EventReservationDetail, FerryReservationDetail, Insurance, MarketplaceSeller, RoundTripReservationDetail, TrainReservationDetail, Voucher
Instance Attribute Summary collapse
-
#bus_reservation_details ⇒ Object
Supplementary bus reservation details.
-
#event_reservation_details ⇒ Object
Supplementary event reservation details.
-
#ferry_reservation_details ⇒ Object
Supplementary ferry reservation details.
-
#insurances ⇒ Object
Supplementary insurance details.
-
#marketplace_sellers ⇒ Object
Supplementary marketplace seller details.
-
#round_trip_reservation_details ⇒ Object
Supplementary round trip reservation details.
-
#train_reservation_details ⇒ Object
Supplementary train reservation details.
-
#vouchers ⇒ Object
Voucher details, such as a gift card or discount code.
Instance Method Summary collapse
-
#initialize(bus_reservation_details: nil, event_reservation_details: nil, ferry_reservation_details: nil, insurances: nil, marketplace_sellers: nil, round_trip_reservation_details: nil, train_reservation_details: nil, vouchers: nil) ⇒ SupplementaryPurchaseData
constructor
A new instance of SupplementaryPurchaseData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bus_reservation_details: nil, event_reservation_details: nil, ferry_reservation_details: nil, insurances: nil, marketplace_sellers: nil, round_trip_reservation_details: nil, train_reservation_details: nil, vouchers: nil) ⇒ SupplementaryPurchaseData
Returns a new instance of SupplementaryPurchaseData.
4941 4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 4953 4954 4955 4956 4957 4958 4959 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4941 def initialize( bus_reservation_details: nil, event_reservation_details: nil, ferry_reservation_details: nil, insurances: nil, marketplace_sellers: nil, round_trip_reservation_details: nil, train_reservation_details: nil, vouchers: nil ) @bus_reservation_details = bus_reservation_details @event_reservation_details = event_reservation_details @ferry_reservation_details = ferry_reservation_details @insurances = insurances @marketplace_sellers = marketplace_sellers @round_trip_reservation_details = round_trip_reservation_details @train_reservation_details = train_reservation_details @vouchers = vouchers end |
Instance Attribute Details
#bus_reservation_details ⇒ Object
Supplementary bus reservation details.
4925 4926 4927 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4925 def bus_reservation_details @bus_reservation_details end |
#event_reservation_details ⇒ Object
Supplementary event reservation details.
4927 4928 4929 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4927 def event_reservation_details @event_reservation_details end |
#ferry_reservation_details ⇒ Object
Supplementary ferry reservation details.
4929 4930 4931 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4929 def ferry_reservation_details @ferry_reservation_details end |
#insurances ⇒ Object
Supplementary insurance details.
4931 4932 4933 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4931 def insurances @insurances end |
#marketplace_sellers ⇒ Object
Supplementary marketplace seller details.
4933 4934 4935 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4933 def marketplace_sellers @marketplace_sellers end |
#round_trip_reservation_details ⇒ Object
Supplementary round trip reservation details.
4935 4936 4937 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4935 def round_trip_reservation_details @round_trip_reservation_details end |
#train_reservation_details ⇒ Object
Supplementary train reservation details.
4937 4938 4939 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4937 def train_reservation_details @train_reservation_details end |
#vouchers ⇒ Object
Voucher details, such as a gift card or discount code.
4939 4940 4941 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4939 def vouchers @vouchers end |