Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: BusReservationDetail, EventReservationDetail, FerryReservationDetail, Insurance, MarketplaceSeller, RoundTripReservationDetail, TrainReservationDetail, Voucher
Instance Attribute Summary collapse
-
#bus_reservation_details ⇒ Object
Supplementary bus reservation details.
-
#event_reservation_details ⇒ Object
Supplementary event reservation details.
-
#ferry_reservation_details ⇒ Object
Supplementary ferry reservation details.
-
#insurances ⇒ Object
Supplementary insurance details.
-
#marketplace_sellers ⇒ Object
Supplementary marketplace seller details.
-
#round_trip_reservation_details ⇒ Object
Supplementary round trip reservation details.
-
#train_reservation_details ⇒ Object
Supplementary train reservation details.
-
#vouchers ⇒ Object
Voucher details, such as a gift card or discount code.
Instance Method Summary collapse
-
#initialize(bus_reservation_details: nil, event_reservation_details: nil, ferry_reservation_details: nil, insurances: nil, marketplace_sellers: nil, round_trip_reservation_details: nil, train_reservation_details: nil, vouchers: nil) ⇒ SupplementaryPurchaseData
constructor
A new instance of SupplementaryPurchaseData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bus_reservation_details: nil, event_reservation_details: nil, ferry_reservation_details: nil, insurances: nil, marketplace_sellers: nil, round_trip_reservation_details: nil, train_reservation_details: nil, vouchers: nil) ⇒ SupplementaryPurchaseData
Returns a new instance of SupplementaryPurchaseData.
4452 4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4452 def initialize( bus_reservation_details: nil, event_reservation_details: nil, ferry_reservation_details: nil, insurances: nil, marketplace_sellers: nil, round_trip_reservation_details: nil, train_reservation_details: nil, vouchers: nil ) @bus_reservation_details = bus_reservation_details @event_reservation_details = event_reservation_details @ferry_reservation_details = ferry_reservation_details @insurances = insurances @marketplace_sellers = marketplace_sellers @round_trip_reservation_details = round_trip_reservation_details @train_reservation_details = train_reservation_details @vouchers = vouchers end |
Instance Attribute Details
#bus_reservation_details ⇒ Object
Supplementary bus reservation details.
4436 4437 4438 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4436 def bus_reservation_details @bus_reservation_details end |
#event_reservation_details ⇒ Object
Supplementary event reservation details.
4438 4439 4440 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4438 def event_reservation_details @event_reservation_details end |
#ferry_reservation_details ⇒ Object
Supplementary ferry reservation details.
4440 4441 4442 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4440 def ferry_reservation_details @ferry_reservation_details end |
#insurances ⇒ Object
Supplementary insurance details.
4442 4443 4444 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4442 def insurances @insurances end |
#marketplace_sellers ⇒ Object
Supplementary marketplace seller details.
4444 4445 4446 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4444 def marketplace_sellers @marketplace_sellers end |
#round_trip_reservation_details ⇒ Object
Supplementary round trip reservation details.
4446 4447 4448 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4446 def round_trip_reservation_details @round_trip_reservation_details end |
#train_reservation_details ⇒ Object
Supplementary train reservation details.
4448 4449 4450 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4448 def train_reservation_details @train_reservation_details end |
#vouchers ⇒ Object
Voucher details, such as a gift card or discount code.
4450 4451 4452 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4450 def vouchers @vouchers end |