Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ BusReservationDetail
constructor
A new instance of BusReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ BusReservationDetail
Returns a new instance of BusReservationDetail.
3651 3652 3653 3654 3655 3656 3657 3658 3659 3660 3661 3662 3663 3664 3665 3666 3667 3668 3669 3670 3671 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3651 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
3633 3634 3635 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3633 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
3635 3636 3637 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3635 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
3637 3638 3639 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3637 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
3639 3640 3641 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3639 def currency @currency end |
#departure ⇒ Object
Departure details.
3641 3642 3643 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3641 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
3643 3644 3645 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3643 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
3645 3646 3647 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3645 def passengers @passengers end |
#price ⇒ Object
Price in cents.
3647 3648 3649 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3647 def price @price end |
#ticket_class ⇒ Object
Ticket class.
3649 3650 3651 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3649 def ticket_class @ticket_class end |