Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ BusReservationDetail
constructor
A new instance of BusReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ BusReservationDetail
Returns a new instance of BusReservationDetail.
3743 3744 3745 3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3743 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
3725 3726 3727 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3725 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
3727 3728 3729 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3727 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
3729 3730 3731 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3729 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
3731 3732 3733 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3731 def currency @currency end |
#departure ⇒ Object
Departure details.
3733 3734 3735 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3733 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
3735 3736 3737 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3735 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
3737 3738 3739 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3737 def passengers @passengers end |
#price ⇒ Object
Price in cents.
3739 3740 3741 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3739 def price @price end |
#ticket_class ⇒ Object
Ticket class.
3741 3742 3743 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3741 def ticket_class @ticket_class end |