Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ BusReservationDetail
constructor
A new instance of BusReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ BusReservationDetail
Returns a new instance of BusReservationDetail.
3682 3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3682 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
3664 3665 3666 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3664 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
3666 3667 3668 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3666 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
3668 3669 3670 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3668 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
3670 3671 3672 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3670 def currency @currency end |
#departure ⇒ Object
Departure details.
3672 3673 3674 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3672 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
3674 3675 3676 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3674 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
3676 3677 3678 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3676 def passengers @passengers end |
#price ⇒ Object
Price in cents.
3678 3679 3680 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3678 def price @price end |
#ticket_class ⇒ Object
Ticket class.
3680 3681 3682 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3680 def ticket_class @ticket_class end |