Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ BusReservationDetail
constructor
A new instance of BusReservationDetail.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ BusReservationDetail
Returns a new instance of BusReservationDetail.
3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 3626 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3606 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
3588 3589 3590 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3588 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
3590 3591 3592 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3590 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
3592 3593 3594 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3592 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
3594 3595 3596 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3594 def currency @currency end |
#departure ⇒ Object
Departure details.
3596 3597 3598 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3596 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
3598 3599 3600 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3598 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
3600 3601 3602 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3600 def passengers @passengers end |
#price ⇒ Object
Price in cents.
3602 3603 3604 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3602 def price @price end |
#ticket_class ⇒ Object
Ticket class.
3604 3605 3606 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3604 def ticket_class @ticket_class end |