Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3464 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3452 3453 3454 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3452 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3454 3455 3456 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3454 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3456 3457 3458 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3456 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3458 3459 3460 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3458 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3460 3461 3462 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3460 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3462 3463 3464 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3462 def street_address2 @street_address2 end |