Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail::Departure::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail::Departure::Address
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3556 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3544 3545 3546 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3544 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3546 3547 3548 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3546 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3548 3549 3550 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3548 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3550 3551 3552 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3550 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3552 3553 3554 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3552 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3554 3555 3556 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3554 def street_address2 @street_address2 end |