Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
Address of the event.
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#ends_at ⇒ Object
End timestamp of the event.
-
#event_company_name ⇒ Object
Company selling the ticket.
-
#event_name ⇒ Object
Name of the event.
-
#event_type ⇒ Object
Type of the event.
-
#insurances ⇒ Object
List of insurances for this event.
-
#starts_at ⇒ Object
Start timestamp of the event.
-
#venue_name ⇒ Object
Name of the venue where the event takes place.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail
constructor
A new instance of EventReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail
Returns a new instance of EventReservationDetail.
4292 4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 4310 4311 4312 4313 4314 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4292 def initialize( access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate_name = affiliate_name @ends_at = ends_at @event_company_name = event_company_name @event_name = event_name @event_type = event_type @insurances = insurances @starts_at = starts_at @venue_name = venue_name end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
4272 4273 4274 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4272 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
Address of the event.
4274 4275 4276 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4274 def address @address end |
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
4276 4277 4278 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4276 def affiliate_name @affiliate_name end |
#ends_at ⇒ Object
End timestamp of the event.
4278 4279 4280 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4278 def ends_at @ends_at end |
#event_company_name ⇒ Object
Company selling the ticket.
4280 4281 4282 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4280 def event_company_name @event_company_name end |
#event_name ⇒ Object
Name of the event.
4282 4283 4284 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4282 def event_name @event_name end |
#event_type ⇒ Object
Type of the event.
4284 4285 4286 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4284 def event_type @event_type end |
#insurances ⇒ Object
List of insurances for this event.
4286 4287 4288 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4286 def insurances @insurances end |
#starts_at ⇒ Object
Start timestamp of the event.
4288 4289 4290 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4288 def starts_at @starts_at end |
#venue_name ⇒ Object
Name of the venue where the event takes place.
4290 4291 4292 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4290 def venue_name @venue_name end |