Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
Address of the event.
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#ends_at ⇒ Object
End timestamp of the event.
-
#event_company_name ⇒ Object
Company selling the ticket.
-
#event_name ⇒ Object
Name of the event.
-
#event_type ⇒ Object
Type of the event.
-
#insurances ⇒ Object
List of insurances for this event.
-
#starts_at ⇒ Object
Start timestamp of the event.
-
#venue_name ⇒ Object
Name of the venue where the event takes place.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail
constructor
A new instance of EventReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail
Returns a new instance of EventReservationDetail.
3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3749 def initialize( access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate_name = affiliate_name @ends_at = ends_at @event_company_name = event_company_name @event_name = event_name @event_type = event_type @insurances = insurances @starts_at = starts_at @venue_name = venue_name end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
3729 3730 3731 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3729 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
Address of the event.
3731 3732 3733 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3731 def address @address end |
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
3733 3734 3735 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3733 def affiliate_name @affiliate_name end |
#ends_at ⇒ Object
End timestamp of the event.
3735 3736 3737 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3735 def ends_at @ends_at end |
#event_company_name ⇒ Object
Company selling the ticket.
3737 3738 3739 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3737 def event_company_name @event_company_name end |
#event_name ⇒ Object
Name of the event.
3739 3740 3741 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3739 def event_name @event_name end |
#event_type ⇒ Object
Type of the event.
3741 3742 3743 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3741 def event_type @event_type end |
#insurances ⇒ Object
List of insurances for this event.
3743 3744 3745 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3743 def insurances @insurances end |
#starts_at ⇒ Object
Start timestamp of the event.
3745 3746 3747 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3745 def starts_at @starts_at end |
#venue_name ⇒ Object
Name of the venue where the event takes place.
3747 3748 3749 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3747 def venue_name @venue_name end |