Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Address, Insurance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail

Returns a new instance of EventReservationDetail.



4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4266

def initialize(
  access_controlled_venue: nil,
  address: nil,
  affiliate_name: nil,
  ends_at: nil,
  event_company_name: nil,
  event_name: nil,
  event_type: nil,
  insurances: nil,
  starts_at: nil,
  venue_name: nil
)
  @access_controlled_venue = access_controlled_venue
  @address = address
  @affiliate_name = affiliate_name
  @ends_at = ends_at
  @event_company_name = event_company_name
  @event_name = event_name
  @event_type = event_type
  @insurances = insurances
  @starts_at = starts_at
  @venue_name = venue_name
end

Instance Attribute Details

#access_controlled_venueObject

Indicates if the tickets are digitally checked when entering the venue.



4246
4247
4248
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4246

def access_controlled_venue
  @access_controlled_venue
end

#addressObject

Address of the event.



4248
4249
4250
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4248

def address
  @address
end

#affiliate_nameObject

Name of associated or partner company for the service.



4250
4251
4252
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4250

def affiliate_name
  @affiliate_name
end

#ends_atObject

End timestamp of the event.



4252
4253
4254
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4252

def ends_at
  @ends_at
end

#event_company_nameObject

Company selling the ticket.



4254
4255
4256
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4254

def event_company_name
  @event_company_name
end

#event_nameObject

Name of the event.



4256
4257
4258
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4256

def event_name
  @event_name
end

#event_typeObject

Type of the event.



4258
4259
4260
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4258

def event_type
  @event_type
end

#insurancesObject

List of insurances for this event.



4260
4261
4262
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4260

def insurances
  @insurances
end

#starts_atObject

Start timestamp of the event.



4262
4263
4264
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4262

def starts_at
  @starts_at
end

#venue_nameObject

Name of the venue where the event takes place.



4264
4265
4266
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4264

def venue_name
  @venue_name
end