Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
Address of the event.
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#ends_at ⇒ Object
End timestamp of the event.
-
#event_company_name ⇒ Object
Company selling the ticket.
-
#event_name ⇒ Object
Name of the event.
-
#event_type ⇒ Object
Type of the event.
-
#insurances ⇒ Object
List of insurances for this event.
-
#starts_at ⇒ Object
Start timestamp of the event.
-
#venue_name ⇒ Object
Name of the venue where the event takes place.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail
constructor
A new instance of EventReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail
Returns a new instance of EventReservationDetail.
3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3780 def initialize( access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate_name = affiliate_name @ends_at = ends_at @event_company_name = event_company_name @event_name = event_name @event_type = event_type @insurances = insurances @starts_at = starts_at @venue_name = venue_name end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
3760 3761 3762 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3760 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
Address of the event.
3762 3763 3764 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3762 def address @address end |
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
3764 3765 3766 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3764 def affiliate_name @affiliate_name end |
#ends_at ⇒ Object
End timestamp of the event.
3766 3767 3768 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3766 def ends_at @ends_at end |
#event_company_name ⇒ Object
Company selling the ticket.
3768 3769 3770 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3768 def event_company_name @event_company_name end |
#event_name ⇒ Object
Name of the event.
3770 3771 3772 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3770 def event_name @event_name end |
#event_type ⇒ Object
Type of the event.
3772 3773 3774 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3772 def event_type @event_type end |
#insurances ⇒ Object
List of insurances for this event.
3774 3775 3776 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3774 def insurances @insurances end |
#starts_at ⇒ Object
Start timestamp of the event.
3776 3777 3778 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3776 def starts_at @starts_at end |
#venue_name ⇒ Object
Name of the venue where the event takes place.
3778 3779 3780 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3778 def venue_name @venue_name end |