Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Address, Insurance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail

Returns a new instance of EventReservationDetail.



3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
3855
3856
3857
3858
3859
3860
3861
3862
3863
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3841

def initialize(
  access_controlled_venue: nil,
  address: nil,
  affiliate_name: nil,
  ends_at: nil,
  event_company_name: nil,
  event_name: nil,
  event_type: nil,
  insurances: nil,
  starts_at: nil,
  venue_name: nil
)
  @access_controlled_venue = access_controlled_venue
  @address = address
  @affiliate_name = affiliate_name
  @ends_at = ends_at
  @event_company_name = event_company_name
  @event_name = event_name
  @event_type = event_type
  @insurances = insurances
  @starts_at = starts_at
  @venue_name = venue_name
end

Instance Attribute Details

#access_controlled_venueObject

Indicates if the tickets are digitally checked when entering the venue.



3821
3822
3823
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3821

def access_controlled_venue
  @access_controlled_venue
end

#addressObject

Address of the event.



3823
3824
3825
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3823

def address
  @address
end

#affiliate_nameObject

Name of associated or partner company for the service.



3825
3826
3827
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3825

def affiliate_name
  @affiliate_name
end

#ends_atObject

End timestamp of the event.



3827
3828
3829
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3827

def ends_at
  @ends_at
end

#event_company_nameObject

Company selling the ticket.



3829
3830
3831
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3829

def event_company_name
  @event_company_name
end

#event_nameObject

Name of the event.



3831
3832
3833
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3831

def event_name
  @event_name
end

#event_typeObject

Type of the event.



3833
3834
3835
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3833

def event_type
  @event_type
end

#insurancesObject

List of insurances for this event.



3835
3836
3837
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3835

def insurances
  @insurances
end

#starts_atObject

Start timestamp of the event.



3837
3838
3839
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3837

def starts_at
  @starts_at
end

#venue_nameObject

Name of the venue where the event takes place.



3839
3840
3841
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3839

def venue_name
  @venue_name
end