Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
Address of the event.
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#ends_at ⇒ Object
End timestamp of the event.
-
#event_company_name ⇒ Object
Company selling the ticket.
-
#event_name ⇒ Object
Name of the event.
-
#event_type ⇒ Object
Type of the event.
-
#insurances ⇒ Object
List of insurances for this event.
-
#starts_at ⇒ Object
Start timestamp of the event.
-
#venue_name ⇒ Object
Name of the venue where the event takes place.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail
constructor
A new instance of EventReservationDetail.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail
Returns a new instance of EventReservationDetail.
3704 3705 3706 3707 3708 3709 3710 3711 3712 3713 3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3704 def initialize( access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate_name = affiliate_name @ends_at = ends_at @event_company_name = event_company_name @event_name = event_name @event_type = event_type @insurances = insurances @starts_at = starts_at @venue_name = venue_name end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
3684 3685 3686 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3684 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
Address of the event.
3686 3687 3688 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3686 def address @address end |
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
3688 3689 3690 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3688 def affiliate_name @affiliate_name end |
#ends_at ⇒ Object
End timestamp of the event.
3690 3691 3692 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3690 def ends_at @ends_at end |
#event_company_name ⇒ Object
Company selling the ticket.
3692 3693 3694 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3692 def event_company_name @event_company_name end |
#event_name ⇒ Object
Name of the event.
3694 3695 3696 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3694 def event_name @event_name end |
#event_type ⇒ Object
Type of the event.
3696 3697 3698 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3696 def event_type @event_type end |
#insurances ⇒ Object
List of insurances for this event.
3698 3699 3700 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3698 def insurances @insurances end |
#starts_at ⇒ Object
Start timestamp of the event.
3700 3701 3702 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3700 def starts_at @starts_at end |
#venue_name ⇒ Object
Name of the venue where the event takes place.
3702 3703 3704 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3702 def venue_name @venue_name end |