Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail::Address
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
3677 3678 3679 3680 3681 3682 3683 3684 3685 3686 3687 3688 3689 3690 3691 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3677 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3665 3666 3667 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3665 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3667 3668 3669 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3667 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3669 3670 3671 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3669 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3671 3672 3673 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3671 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3673 3674 3675 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3673 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3675 3676 3677 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3675 def street_address2 @street_address2 end |