Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
constructor
A new instance of FerryReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
Returns a new instance of FerryReservationDetail.
3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3903 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
3885 3886 3887 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3885 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
3887 3888 3889 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3887 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
3889 3890 3891 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3889 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
3891 3892 3893 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3891 def currency @currency end |
#departure ⇒ Object
Departure details.
3893 3894 3895 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3893 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
3895 3896 3897 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3895 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
3897 3898 3899 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3897 def passengers @passengers end |
#price ⇒ Object
Price in cents.
3899 3900 3901 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3899 def price @price end |
#ticket_class ⇒ Object
Ticket class.
3901 3902 3903 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3901 def ticket_class @ticket_class end |