Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
constructor
A new instance of FerryReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
Returns a new instance of FerryReservationDetail.
4007 4008 4009 4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4007 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
3989 3990 3991 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3989 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
3991 3992 3993 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3991 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
3993 3994 3995 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3993 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
3995 3996 3997 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3995 def currency @currency end |
#departure ⇒ Object
Departure details.
3997 3998 3999 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3997 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
3999 4000 4001 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3999 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
4001 4002 4003 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4001 def passengers @passengers end |
#price ⇒ Object
Price in cents.
4003 4004 4005 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4003 def price @price end |
#ticket_class ⇒ Object
Ticket class.
4005 4006 4007 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4005 def ticket_class @ticket_class end |