Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
constructor
A new instance of FerryReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
Returns a new instance of FerryReservationDetail.
4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 4425 4426 4427 4428 4429 4430 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4410 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
4392 4393 4394 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4392 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
4394 4395 4396 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4394 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
4396 4397 4398 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4396 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
4398 4399 4400 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4398 def currency @currency end |
#departure ⇒ Object
Departure details.
4400 4401 4402 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4400 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
4402 4403 4404 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4402 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
4404 4405 4406 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4404 def passengers @passengers end |
#price ⇒ Object
Price in cents.
4406 4407 4408 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4406 def price @price end |
#ticket_class ⇒ Object
Ticket class.
4408 4409 4410 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4408 def ticket_class @ticket_class end |