Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
constructor
A new instance of FerryReservationDetail.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ FerryReservationDetail
Returns a new instance of FerryReservationDetail.
3870 3871 3872 3873 3874 3875 3876 3877 3878 3879 3880 3881 3882 3883 3884 3885 3886 3887 3888 3889 3890 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3870 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
3852 3853 3854 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3852 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
3854 3855 3856 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3854 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
3856 3857 3858 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3856 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
3858 3859 3860 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3858 def currency @currency end |
#departure ⇒ Object
Departure details.
3860 3861 3862 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3860 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
3862 3863 3864 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3862 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
3864 3865 3866 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3864 def passengers @passengers end |
#price ⇒ Object
Price in cents.
3866 3867 3868 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3866 def price @price end |
#ticket_class ⇒ Object
Ticket class.
3868 3869 3870 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3868 def ticket_class @ticket_class end |