Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
3790 3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3790 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3778 3779 3780 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3778 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3780 3781 3782 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3780 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3782 3783 3784 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3782 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3784 3785 3786 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3784 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3786 3787 3788 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3786 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3788 3789 3790 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3788 def street_address2 @street_address2 end |