Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Departure::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Departure::Address
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 4385 4386 4387 4388 4389 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4375 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4363 4364 4365 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4363 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4365 4366 4367 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4365 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4367 4368 4369 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4367 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4369 4370 4371 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4369 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4371 4372 4373 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4371 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4373 4374 4375 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4373 def street_address2 @street_address2 end |