Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Departure::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Departure::Address
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
3820 3821 3822 3823 3824 3825 3826 3827 3828 3829 3830 3831 3832 3833 3834 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3820 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3808 3809 3810 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3808 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3810 3811 3812 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3810 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3812 3813 3814 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3812 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3814 3815 3816 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3814 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3816 3817 3818 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3816 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3818 3819 3820 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3818 def street_address2 @street_address2 end |