Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: MarketplaceSellerAddress
Instance Attribute Summary collapse
-
#line_item_references ⇒ Object
The references to line items for purchases with multiple associated sub-sellers.
-
#marketplace_seller_address ⇒ Object
The address of the selling or delivering merchant.
-
#marketplace_seller_name ⇒ Object
The name of the marketplace seller.
-
#marketplace_seller_reference ⇒ Object
The unique identifier for the marketplace seller.
-
#number_of_transactions ⇒ Object
The number of transactions the sub-seller completed in the last 12 months.
-
#product_category ⇒ Object
The category of the product.
-
#seller_last_login_at ⇒ Object
The date when the seller’s account with the marketplace was last logged in.
-
#seller_rating ⇒ Object
The current rating of the marketplace seller.
-
#seller_registered_at ⇒ Object
The date when the seller’s account with the marketplace was created.
-
#seller_updated_at ⇒ Object
The date when the seller’s account with the marketplace was last updated.
-
#shipping_references ⇒ Object
The references to shipping addresses for purchases with multiple associated sub-sellers.
-
#volume_of_transactions ⇒ Object
The accumulated amount of sales transactions made by the sub-merchant or sub-seller within the past 12 months in the payment currency.
Instance Method Summary collapse
-
#initialize(line_item_references: nil, marketplace_seller_address: nil, marketplace_seller_name: nil, marketplace_seller_reference: nil, number_of_transactions: nil, product_category: nil, seller_last_login_at: nil, seller_rating: nil, seller_registered_at: nil, seller_updated_at: nil, shipping_references: nil, volume_of_transactions: nil) ⇒ MarketplaceSeller
constructor
A new instance of MarketplaceSeller.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(line_item_references: nil, marketplace_seller_address: nil, marketplace_seller_name: nil, marketplace_seller_reference: nil, number_of_transactions: nil, product_category: nil, seller_last_login_at: nil, seller_rating: nil, seller_registered_at: nil, seller_updated_at: nil, shipping_references: nil, volume_of_transactions: nil) ⇒ MarketplaceSeller
Returns a new instance of MarketplaceSeller.
4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4560 def initialize( line_item_references: nil, marketplace_seller_address: nil, marketplace_seller_name: nil, marketplace_seller_reference: nil, number_of_transactions: nil, product_category: nil, seller_last_login_at: nil, seller_rating: nil, seller_registered_at: nil, seller_updated_at: nil, shipping_references: nil, volume_of_transactions: nil ) @line_item_references = line_item_references @marketplace_seller_address = marketplace_seller_address @marketplace_seller_name = marketplace_seller_name @marketplace_seller_reference = marketplace_seller_reference @number_of_transactions = number_of_transactions @product_category = product_category @seller_last_login_at = seller_last_login_at @seller_rating = @seller_registered_at = seller_registered_at @seller_updated_at = seller_updated_at @shipping_references = shipping_references @volume_of_transactions = volume_of_transactions end |
Instance Attribute Details
#line_item_references ⇒ Object
The references to line items for purchases with multiple associated sub-sellers.
4536 4537 4538 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4536 def line_item_references @line_item_references end |
#marketplace_seller_address ⇒ Object
The address of the selling or delivering merchant.
4538 4539 4540 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4538 def marketplace_seller_address @marketplace_seller_address end |
#marketplace_seller_name ⇒ Object
The name of the marketplace seller.
4540 4541 4542 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4540 def marketplace_seller_name @marketplace_seller_name end |
#marketplace_seller_reference ⇒ Object
The unique identifier for the marketplace seller.
4542 4543 4544 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4542 def marketplace_seller_reference @marketplace_seller_reference end |
#number_of_transactions ⇒ Object
The number of transactions the sub-seller completed in the last 12 months.
4544 4545 4546 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4544 def number_of_transactions @number_of_transactions end |
#product_category ⇒ Object
The category of the product.
4546 4547 4548 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4546 def product_category @product_category end |
#seller_last_login_at ⇒ Object
The date when the seller’s account with the marketplace was last logged in.
4548 4549 4550 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4548 def seller_last_login_at @seller_last_login_at end |
#seller_rating ⇒ Object
The current rating of the marketplace seller. If the marketplace uses numeric ranking, map these to the enum values.
4550 4551 4552 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4550 def @seller_rating end |
#seller_registered_at ⇒ Object
The date when the seller’s account with the marketplace was created.
4552 4553 4554 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4552 def seller_registered_at @seller_registered_at end |
#seller_updated_at ⇒ Object
The date when the seller’s account with the marketplace was last updated.
4554 4555 4556 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4554 def seller_updated_at @seller_updated_at end |
#shipping_references ⇒ Object
The references to shipping addresses for purchases with multiple associated sub-sellers.
4556 4557 4558 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4556 def shipping_references @shipping_references end |
#volume_of_transactions ⇒ Object
The accumulated amount of sales transactions made by the sub-merchant or sub-seller within the past 12 months in the payment currency. These transactions are in minor currency units.
4558 4559 4560 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4558 def volume_of_transactions @volume_of_transactions end |