Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: MarketplaceSellerAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(line_item_references: nil, marketplace_seller_address: nil, marketplace_seller_name: nil, marketplace_seller_reference: nil, number_of_transactions: nil, product_category: nil, seller_last_login_at: nil, seller_rating: nil, seller_registered_at: nil, seller_updated_at: nil, shipping_references: nil, volume_of_transactions: nil) ⇒ MarketplaceSeller

Returns a new instance of MarketplaceSeller.



3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3972

def initialize(
  line_item_references: nil,
  marketplace_seller_address: nil,
  marketplace_seller_name: nil,
  marketplace_seller_reference: nil,
  number_of_transactions: nil,
  product_category: nil,
  seller_last_login_at: nil,
  seller_rating: nil,
  seller_registered_at: nil,
  seller_updated_at: nil,
  shipping_references: nil,
  volume_of_transactions: nil
)
  @line_item_references = line_item_references
  @marketplace_seller_address = marketplace_seller_address
  @marketplace_seller_name = marketplace_seller_name
  @marketplace_seller_reference = marketplace_seller_reference
  @number_of_transactions = number_of_transactions
  @product_category = product_category
  @seller_last_login_at = 
  @seller_rating = seller_rating
  @seller_registered_at = seller_registered_at
  @seller_updated_at = seller_updated_at
  @shipping_references = shipping_references
  @volume_of_transactions = volume_of_transactions
end

Instance Attribute Details

#line_item_referencesObject

The references to line items for purchases with multiple associated sub-sellers.



3948
3949
3950
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3948

def line_item_references
  @line_item_references
end

#marketplace_seller_addressObject

The address of the selling or delivering merchant.



3950
3951
3952
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3950

def marketplace_seller_address
  @marketplace_seller_address
end

#marketplace_seller_nameObject

The name of the marketplace seller.



3952
3953
3954
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3952

def marketplace_seller_name
  @marketplace_seller_name
end

#marketplace_seller_referenceObject

The unique identifier for the marketplace seller.



3954
3955
3956
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3954

def marketplace_seller_reference
  @marketplace_seller_reference
end

#number_of_transactionsObject

The number of transactions the sub-seller completed in the last 12 months.



3956
3957
3958
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3956

def number_of_transactions
  @number_of_transactions
end

#product_categoryObject

The category of the product.



3958
3959
3960
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3958

def product_category
  @product_category
end

#seller_last_login_atObject

The date when the seller’s account with the marketplace was last logged in.



3960
3961
3962
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3960

def 
  @seller_last_login_at
end

#seller_ratingObject

The current rating of the marketplace seller. If the marketplace uses numeric ranking, map these to the enum values.



3962
3963
3964
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3962

def seller_rating
  @seller_rating
end

#seller_registered_atObject

The date when the seller’s account with the marketplace was created.



3964
3965
3966
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3964

def seller_registered_at
  @seller_registered_at
end

#seller_updated_atObject

The date when the seller’s account with the marketplace was last updated.



3966
3967
3968
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3966

def seller_updated_at
  @seller_updated_at
end

#shipping_referencesObject

The references to shipping addresses for purchases with multiple associated sub-sellers.



3968
3969
3970
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3968

def shipping_references
  @shipping_references
end

#volume_of_transactionsObject

The accumulated amount of sales transactions made by the sub-merchant or sub-seller within the past 12 months in the payment currency. These transactions are in minor currency units.



3970
3971
3972
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3970

def volume_of_transactions
  @volume_of_transactions
end