Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller::MarketplaceSellerAddress
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller::MarketplaceSellerAddress
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ MarketplaceSellerAddress
constructor
A new instance of MarketplaceSellerAddress.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ MarketplaceSellerAddress
Returns a new instance of MarketplaceSellerAddress.
3976 3977 3978 3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3976 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3964 3965 3966 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3964 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3966 3967 3968 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3966 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3968 3969 3970 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3968 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3970 3971 3972 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3970 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3972 3973 3974 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3972 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3974 3975 3976 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3974 def street_address2 @street_address2 end |