Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller::MarketplaceSellerAddress
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller::MarketplaceSellerAddress
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ MarketplaceSellerAddress
constructor
A new instance of MarketplaceSellerAddress.
Methods inherited from RequestParams
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ MarketplaceSellerAddress
Returns a new instance of MarketplaceSellerAddress.
3931 3932 3933 3934 3935 3936 3937 3938 3939 3940 3941 3942 3943 3944 3945 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3931 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3919 3920 3921 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3919 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3921 3922 3923 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3921 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3923 3924 3925 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3923 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3925 3926 3927 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3925 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3927 3928 3929 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3927 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3929 3930 3931 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3929 def street_address2 @street_address2 end |