Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ RoundTripReservationDetail
constructor
A new instance of RoundTripReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ RoundTripReservationDetail
Returns a new instance of RoundTripReservationDetail.
4175 4176 4177 4178 4179 4180 4181 4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4175 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
4157 4158 4159 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4157 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
4159 4160 4161 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4159 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
4161 4162 4163 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4161 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
4163 4164 4165 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4163 def currency @currency end |
#departure ⇒ Object
Departure details.
4165 4166 4167 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4165 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
4167 4168 4169 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4167 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
4169 4170 4171 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4169 def passengers @passengers end |
#price ⇒ Object
Price in cents.
4171 4172 4173 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4171 def price @price end |
#ticket_class ⇒ Object
Ticket class.
4173 4174 4175 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4173 def ticket_class @ticket_class end |