Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4062 4063 4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4062 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4050 4051 4052 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4050 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4052 4053 4054 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4052 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4054 4055 4056 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4054 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4056 4057 4058 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4056 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4058 4059 4060 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4058 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4060 4061 4062 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4060 def street_address2 @street_address2 end |