Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Departure::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Departure::Address
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4092 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4080 4081 4082 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4080 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4082 4083 4084 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4082 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4084 4085 4086 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4084 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4086 4087 4088 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4086 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4088 4089 4090 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4088 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4090 4091 4092 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4090 def street_address2 @street_address2 end |