Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ TrainReservationDetail
constructor
A new instance of TrainReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ TrainReservationDetail
Returns a new instance of TrainReservationDetail.
4351 4352 4353 4354 4355 4356 4357 4358 4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 4369 4370 4371 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4351 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
4333 4334 4335 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4333 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
4335 4336 4337 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4335 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
4337 4338 4339 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4337 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
4339 4340 4341 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4339 def currency @currency end |
#departure ⇒ Object
Departure details.
4341 4342 4343 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4341 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
4343 4344 4345 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4343 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
4345 4346 4347 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4345 def passengers @passengers end |
#price ⇒ Object
Price in cents.
4347 4348 4349 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4347 def price @price end |
#ticket_class ⇒ Object
Ticket class.
4349 4350 4351 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4349 def ticket_class @ticket_class end |