Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ TrainReservationDetail
constructor
A new instance of TrainReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ TrainReservationDetail
Returns a new instance of TrainReservationDetail.
4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4851 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
4833 4834 4835 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4833 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
4835 4836 4837 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4835 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
4837 4838 4839 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4837 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
4839 4840 4841 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4839 def currency @currency end |
#departure ⇒ Object
Departure details.
4841 4842 4843 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4841 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
4843 4844 4845 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4843 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
4845 4846 4847 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4845 def passengers @passengers end |
#price ⇒ Object
Price in cents.
4847 4848 4849 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4847 def price @price end |
#ticket_class ⇒ Object
Ticket class.
4849 4850 4851 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4849 def ticket_class @ticket_class end |