Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ TrainReservationDetail
constructor
A new instance of TrainReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ TrainReservationDetail
Returns a new instance of TrainReservationDetail.
4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4443 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
4425 4426 4427 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4425 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
4427 4428 4429 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4427 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
4429 4430 4431 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4429 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
4431 4432 4433 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4431 def currency @currency end |
#departure ⇒ Object
Departure details.
4433 4434 4435 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4433 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
4435 4436 4437 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4435 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
4437 4438 4439 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4437 def passengers @passengers end |
#price ⇒ Object
Price in cents.
4439 4440 4441 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4439 def price @price end |
#ticket_class ⇒ Object
Ticket class.
4441 4442 4443 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4441 def ticket_class @ticket_class end |