Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ TrainReservationDetail
constructor
A new instance of TrainReservationDetail.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ TrainReservationDetail
Returns a new instance of TrainReservationDetail.
4289 4290 4291 4292 4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4289 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
4271 4272 4273 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4271 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
4273 4274 4275 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4273 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
4275 4276 4277 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4275 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
4277 4278 4279 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4277 def currency @currency end |
#departure ⇒ Object
Departure details.
4279 4280 4281 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4279 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
4281 4282 4283 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4281 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
4283 4284 4285 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4283 def passengers @passengers end |
#price ⇒ Object
Price in cents.
4285 4286 4287 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4285 def price @price end |
#ticket_class ⇒ Object
Ticket class.
4287 4288 4289 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4287 def ticket_class @ticket_class end |