Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Departure::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Departure::Address
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4788 4789 4790 4791 4792 4793 4794 4795 4796 4797 4798 4799 4800 4801 4802 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4788 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4776 4777 4778 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4776 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4778 4779 4780 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4778 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4780 4781 4782 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4780 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4782 4783 4784 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4782 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4784 4785 4786 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4784 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4786 4787 4788 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4786 def street_address2 @street_address2 end |