Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Departure::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Departure::Address
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 4270 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4256 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4244 4245 4246 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4244 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4246 4247 4248 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4246 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4248 4249 4250 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4248 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4250 4251 4252 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4250 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4252 4253 4254 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4252 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4254 4255 4256 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4254 def street_address2 @street_address2 end |