Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::Voucher
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::Voucher
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for this voucher.
-
#ends_at ⇒ Object
The voucher validity end time.
-
#starts_at ⇒ Object
The voucher validity start time.
-
#voucher_company ⇒ Object
The issuer or provider of this voucher.
-
#voucher_name ⇒ Object
The name or reference to identify the voucher.
-
#voucher_type ⇒ Object
The type of this voucher.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil) ⇒ Voucher
constructor
A new instance of Voucher.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil) ⇒ Voucher
Returns a new instance of Voucher.
4931 4932 4933 4934 4935 4936 4937 4938 4939 4940 4941 4942 4943 4944 4945 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4931 def initialize( affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil ) @affiliate_name = affiliate_name @ends_at = ends_at @starts_at = starts_at @voucher_company = voucher_company @voucher_name = voucher_name @voucher_type = voucher_type end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for this voucher.
4919 4920 4921 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4919 def affiliate_name @affiliate_name end |
#ends_at ⇒ Object
The voucher validity end time.
4921 4922 4923 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4921 def ends_at @ends_at end |
#starts_at ⇒ Object
The voucher validity start time.
4923 4924 4925 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4923 def starts_at @starts_at end |
#voucher_company ⇒ Object
The issuer or provider of this voucher.
4925 4926 4927 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4925 def voucher_company @voucher_company end |
#voucher_name ⇒ Object
The name or reference to identify the voucher.
4927 4928 4929 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4927 def voucher_name @voucher_name end |
#voucher_type ⇒ Object
The type of this voucher.
4929 4930 4931 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4929 def voucher_type @voucher_type end |