Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::Voucher
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::Voucher
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for this voucher.
-
#ends_at ⇒ Object
The voucher validity end time.
-
#starts_at ⇒ Object
The voucher validity start time.
-
#voucher_company ⇒ Object
The issuer or provider of this voucher.
-
#voucher_name ⇒ Object
The name or reference to identify the voucher.
-
#voucher_type ⇒ Object
The type of this voucher.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil) ⇒ Voucher
constructor
A new instance of Voucher.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil) ⇒ Voucher
Returns a new instance of Voucher.
4376 4377 4378 4379 4380 4381 4382 4383 4384 4385 4386 4387 4388 4389 4390 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4376 def initialize( affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil ) @affiliate_name = affiliate_name @ends_at = ends_at @starts_at = starts_at @voucher_company = voucher_company @voucher_name = voucher_name @voucher_type = voucher_type end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for this voucher.
4364 4365 4366 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4364 def affiliate_name @affiliate_name end |
#ends_at ⇒ Object
The voucher validity end time.
4366 4367 4368 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4366 def ends_at @ends_at end |
#starts_at ⇒ Object
The voucher validity start time.
4368 4369 4370 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4368 def starts_at @starts_at end |
#voucher_company ⇒ Object
The issuer or provider of this voucher.
4370 4371 4372 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4370 def voucher_company @voucher_company end |
#voucher_name ⇒ Object
The name or reference to identify the voucher.
4372 4373 4374 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4372 def voucher_name @voucher_name end |
#voucher_type ⇒ Object
The type of this voucher.
4374 4375 4376 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4374 def voucher_type @voucher_type end |