Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::Voucher
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::Voucher
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for this voucher.
-
#ends_at ⇒ Object
The voucher validity end time.
-
#starts_at ⇒ Object
The voucher validity start time.
-
#voucher_company ⇒ Object
The issuer or provider of this voucher.
-
#voucher_name ⇒ Object
The name or reference to identify the voucher.
-
#voucher_type ⇒ Object
The type of this voucher.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil) ⇒ Voucher
constructor
A new instance of Voucher.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil) ⇒ Voucher
Returns a new instance of Voucher.
4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4480 def initialize( affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil ) @affiliate_name = affiliate_name @ends_at = ends_at @starts_at = starts_at @voucher_company = voucher_company @voucher_name = voucher_name @voucher_type = voucher_type end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for this voucher.
4468 4469 4470 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4468 def affiliate_name @affiliate_name end |
#ends_at ⇒ Object
The voucher validity end time.
4470 4471 4472 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4470 def ends_at @ends_at end |
#starts_at ⇒ Object
The voucher validity start time.
4472 4473 4474 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4472 def starts_at @starts_at end |
#voucher_company ⇒ Object
The issuer or provider of this voucher.
4474 4475 4476 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4474 def voucher_company @voucher_company end |
#voucher_name ⇒ Object
The name or reference to identify the voucher.
4476 4477 4478 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4476 def voucher_name @voucher_name end |
#voucher_type ⇒ Object
The type of this voucher.
4478 4479 4480 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4478 def voucher_type @voucher_type end |