Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::Voucher
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::Voucher
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for this voucher.
-
#ends_at ⇒ Object
The voucher validity end time.
-
#starts_at ⇒ Object
The voucher validity start time.
-
#voucher_company ⇒ Object
The issuer or provider of this voucher.
-
#voucher_name ⇒ Object
The name or reference to identify the voucher.
-
#voucher_type ⇒ Object
The type of this voucher.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil) ⇒ Voucher
constructor
A new instance of Voucher.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil) ⇒ Voucher
Returns a new instance of Voucher.
4419 4420 4421 4422 4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 4433 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4419 def initialize( affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil ) @affiliate_name = affiliate_name @ends_at = ends_at @starts_at = starts_at @voucher_company = voucher_company @voucher_name = voucher_name @voucher_type = voucher_type end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for this voucher.
4407 4408 4409 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4407 def affiliate_name @affiliate_name end |
#ends_at ⇒ Object
The voucher validity end time.
4409 4410 4411 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4409 def ends_at @ends_at end |
#starts_at ⇒ Object
The voucher validity start time.
4411 4412 4413 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4411 def starts_at @starts_at end |
#voucher_company ⇒ Object
The issuer or provider of this voucher.
4413 4414 4415 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4413 def voucher_company @voucher_company end |
#voucher_name ⇒ Object
The name or reference to identify the voucher.
4415 4416 4417 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4415 def voucher_name @voucher_name end |
#voucher_type ⇒ Object
The type of this voucher.
4417 4418 4419 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4417 def voucher_type @voucher_type end |