Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Paypal
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Paypal
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer's account.
-
#preferred_locale ⇒ Object
Preferred locale of the PayPal checkout page that the customer is redirected to.
-
#reference ⇒ Object
A reference of the PayPal transaction visible to customer which is mapped to PayPal's invoice ID.
-
#risk_correlation_id ⇒ Object
The risk correlation ID for an on-session payment using a saved PayPal payment method.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Instance Method Summary collapse
-
#initialize(capture_method: nil, preferred_locale: nil, reference: nil, risk_correlation_id: nil, setup_future_usage: nil) ⇒ Paypal
constructor
A new instance of Paypal.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(capture_method: nil, preferred_locale: nil, reference: nil, risk_correlation_id: nil, setup_future_usage: nil) ⇒ Paypal
Returns a new instance of Paypal.
2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2017 def initialize( capture_method: nil, preferred_locale: nil, reference: nil, risk_correlation_id: nil, setup_future_usage: nil ) @capture_method = capture_method @preferred_locale = preferred_locale @reference = reference @risk_correlation_id = risk_correlation_id @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds will be captured from the customer's account.
1999 2000 2001 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 1999 def capture_method @capture_method end |
#preferred_locale ⇒ Object
Preferred locale of the PayPal checkout page that the customer is redirected to.
2001 2002 2003 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2001 def preferred_locale @preferred_locale end |
#reference ⇒ Object
A reference of the PayPal transaction visible to customer which is mapped to PayPal's invoice ID. This must be a globally unique ID if you have configured in your PayPal settings to block multiple payments per invoice ID.
2003 2004 2005 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2003 def reference @reference end |
#risk_correlation_id ⇒ Object
The risk correlation ID for an on-session payment using a saved PayPal payment method.
2005 2006 2007 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2005 def risk_correlation_id @risk_correlation_id end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.
2015 2016 2017 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2015 def setup_future_usage @setup_future_usage end |