Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Paypal

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: LineItem

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(capture_method: nil, line_items: nil, preferred_locale: nil, reference: nil, reference_id: nil, risk_correlation_id: nil, setup_future_usage: nil, subsellers: nil) ⇒ Paypal

Returns a new instance of Paypal.



4823
4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4823

def initialize(
  capture_method: nil,
  line_items: nil,
  preferred_locale: nil,
  reference: nil,
  reference_id: nil,
  risk_correlation_id: nil,
  setup_future_usage: nil,
  subsellers: nil
)
  @capture_method = capture_method
  @line_items = line_items
  @preferred_locale = preferred_locale
  @reference = reference
  @reference_id = reference_id
  @risk_correlation_id = risk_correlation_id
  @setup_future_usage = setup_future_usage
  @subsellers = subsellers
end

Instance Attribute Details

#capture_methodObject

Controls when the funds will be captured from the customer's account.



4799
4800
4801
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4799

def capture_method
  @capture_method
end

#line_itemsObject

The line items purchased by the customer.



4801
4802
4803
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4801

def line_items
  @line_items
end

#preferred_localeObject

Preferred locale of the PayPal checkout page that the customer is redirected to.



4803
4804
4805
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4803

def preferred_locale
  @preferred_locale
end

#referenceObject

A reference of the PayPal transaction visible to customer which is mapped to PayPal's invoice ID. This must be a globally unique ID if you have configured in your PayPal settings to block multiple payments per invoice ID.



4805
4806
4807
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4805

def reference
  @reference
end

#reference_idObject

A reference of the PayPal transaction visible to customer which is mapped to PayPal's invoice ID. This must be a globally unique ID if you have configured in your PayPal settings to block multiple payments per invoice ID.



4807
4808
4809
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4807

def reference_id
  @reference_id
end

#risk_correlation_idObject

The risk correlation ID for an on-session payment using a saved PayPal payment method.



4809
4810
4811
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4809

def risk_correlation_id
  @risk_correlation_id
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.

If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.



4819
4820
4821
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4819

def setup_future_usage
  @setup_future_usage
end

#subsellersObject

The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when separate charges and transfers are used.



4821
4822
4823
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4821

def subsellers
  @subsellers
end