Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



5312
5313
5314
5315
5316
5317
5318
5319
5320
5321
5322
5323
5324
5325
5326
5327
5328
5329
5330
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5312

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



5296
5297
5298
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5296

def category
  @category
end

#descriptionObject

Description of the line item.



5298
5299
5300
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5298

def description
  @description
end

#nameObject

Descriptive name of the line item.



5300
5301
5302
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5300

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



5302
5303
5304
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5302

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



5304
5305
5306
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5304

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



5306
5307
5308
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5306

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



5308
5309
5310
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5308

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



5310
5311
5312
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5310

def unit_amount
  @unit_amount
end