Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
4769 4770 4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4769 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
4753 4754 4755 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4753 def category @category end |
#description ⇒ Object
Description of the line item.
4755 4756 4757 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4755 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
4757 4758 4759 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4757 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
4759 4760 4761 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4759 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
4761 4762 4763 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4761 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
4763 4764 4765 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4763 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
4765 4766 4767 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4765 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
4767 4768 4769 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4767 def unit_amount @unit_amount end |