Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



5269
5270
5271
5272
5273
5274
5275
5276
5277
5278
5279
5280
5281
5282
5283
5284
5285
5286
5287
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5269

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



5253
5254
5255
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5253

def category
  @category
end

#descriptionObject

Description of the line item.



5255
5256
5257
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5255

def description
  @description
end

#nameObject

Descriptive name of the line item.



5257
5258
5259
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5257

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



5259
5260
5261
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5259

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



5261
5262
5263
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5261

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



5263
5264
5265
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5263

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



5265
5266
5267
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5265

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



5267
5268
5269
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5267

def unit_amount
  @unit_amount
end