Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



4757
4758
4759
4760
4761
4762
4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4757

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



4741
4742
4743
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4741

def category
  @category
end

#descriptionObject

Description of the line item.



4743
4744
4745
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4743

def description
  @description
end

#nameObject

Descriptive name of the line item.



4745
4746
4747
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4745

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



4747
4748
4749
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4747

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



4749
4750
4751
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4749

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



4751
4752
4753
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4751

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



4753
4754
4755
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4753

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



4755
4756
4757
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4755

def unit_amount
  @unit_amount
end