Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
4811
4812
4813
4814
4815
4816
4817
4818
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4800

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



4784
4785
4786
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4784

def category
  @category
end

#descriptionObject

Description of the line item.



4786
4787
4788
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4786

def description
  @description
end

#nameObject

Descriptive name of the line item.



4788
4789
4790
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4788

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



4790
4791
4792
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4790

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



4792
4793
4794
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4792

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



4794
4795
4796
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4794

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



4796
4797
4798
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4796

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



4798
4799
4800
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4798

def unit_amount
  @unit_amount
end