Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4861 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
4845 4846 4847 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4845 def category @category end |
#description ⇒ Object
Description of the line item.
4847 4848 4849 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4847 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
4849 4850 4851 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4849 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
4851 4852 4853 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4851 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
4853 4854 4855 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4853 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
4855 4856 4857 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4855 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
4857 4858 4859 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4857 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
4859 4860 4861 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4859 def unit_amount @unit_amount end |