Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
4707 4708 4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 4723 4724 4725 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4707 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
4691 4692 4693 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4691 def category @category end |
#description ⇒ Object
Description of the line item.
4693 4694 4695 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4693 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
4695 4696 4697 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4695 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
4697 4698 4699 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4697 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
4699 4700 4701 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4699 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
4701 4702 4703 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4701 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
4703 4704 4705 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4703 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
4705 4706 4707 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4705 def unit_amount @unit_amount end |