Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4724 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
4708 4709 4710 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4708 def category @category end |
#description ⇒ Object
Description of the line item.
4710 4711 4712 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4710 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
4712 4713 4714 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4712 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
4714 4715 4716 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4714 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
4716 4717 4718 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4716 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
4718 4719 4720 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4718 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
4720 4721 4722 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4720 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
4722 4723 4724 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4722 def unit_amount @unit_amount end |