Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2813

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



2797
2798
2799
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2797

def category
  @category
end

#descriptionObject

Description of the line item.



2799
2800
2801
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2799

def description
  @description
end

#nameObject

Descriptive name of the line item.



2801
2802
2803
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2801

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



2803
2804
2805
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2803

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



2805
2806
2807
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2805

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



2807
2808
2809
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2807

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



2809
2810
2811
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2809

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



2811
2812
2813
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2811

def unit_amount
  @unit_amount
end