Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The tax for a single unit of the line item in minor units.
-
#behavior ⇒ Object
The tax behavior for the line item.
Instance Method Summary collapse
-
#initialize(amount: nil, behavior: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, behavior: nil) ⇒ Tax
Returns a new instance of Tax.
4735 4736 4737 4738 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4735 def initialize(amount: nil, behavior: nil) @amount = amount @behavior = behavior end |
Instance Attribute Details
#amount ⇒ Object
The tax for a single unit of the line item in minor units. Cannot be a negative number.
4731 4732 4733 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4731 def amount @amount end |
#behavior ⇒ Object
The tax behavior for the line item.
4733 4734 4735 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4733 def behavior @behavior end |