Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The tax for a single unit of the line item in minor units.
-
#behavior ⇒ Object
The tax behavior for the line item.
Instance Method Summary collapse
-
#initialize(amount: nil, behavior: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, behavior: nil) ⇒ Tax
Returns a new instance of Tax.
4778 4779 4780 4781 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4778 def initialize(amount: nil, behavior: nil) @amount = amount @behavior = behavior end |
Instance Attribute Details
#amount ⇒ Object
The tax for a single unit of the line item in minor units. Cannot be a negative number.
4774 4775 4776 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4774 def amount @amount end |
#behavior ⇒ Object
The tax behavior for the line item.
4776 4777 4778 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 4776 def behavior @behavior end |