Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Payto::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Payto::MandateOptions
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount that will be collected.
-
#amount_type ⇒ Object
The type of amount that will be collected.
-
#end_date ⇒ Object
Date, in YYYY-MM-DD format, after which payments will not be collected.
-
#payment_schedule ⇒ Object
The periodicity at which payments will be collected.
-
#payments_per_period ⇒ Object
The number of payments that will be made during a payment period.
-
#purpose ⇒ Object
The purpose for which payments are made.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 2061 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2047 def initialize( amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil ) @amount = amount @amount_type = amount_type @end_date = end_date @payment_schedule = payment_schedule @payments_per_period = payments_per_period @purpose = purpose end |
Instance Attribute Details
#amount ⇒ Object
Amount that will be collected. It is required when amount_type is fixed.
2035 2036 2037 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2035 def amount @amount end |
#amount_type ⇒ Object
The type of amount that will be collected. The amount charged must be exact or up to the value of amount param for fixed or maximum type respectively. Defaults to maximum.
2037 2038 2039 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2037 def amount_type @amount_type end |
#end_date ⇒ Object
Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.
2039 2040 2041 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2039 def end_date @end_date end |
#payment_schedule ⇒ Object
The periodicity at which payments will be collected. Defaults to adhoc.
2041 2042 2043 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2041 def payment_schedule @payment_schedule end |
#payments_per_period ⇒ Object
The number of payments that will be made during a payment period. Defaults to 1 except for when payment_schedule is adhoc. In that case, it defaults to no limit.
2043 2044 2045 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2043 def payments_per_period @payments_per_period end |
#purpose ⇒ Object
The purpose for which payments are made. Has a default value based on your merchant category code.
2045 2046 2047 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2045 def purpose @purpose end |