Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Pix::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2940
2941
2942
2943
2944
2945
2946
2947
2948
2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2940

def initialize(
  amount: nil,
  amount_includes_iof: nil,
  amount_type: nil,
  currency: nil,
  end_date: nil,
  payment_schedule: nil,
  reference: nil,
  start_date: nil
)
  @amount = amount
  @amount_includes_iof = amount_includes_iof
  @amount_type = amount_type
  @currency = currency
  @end_date = end_date
  @payment_schedule = payment_schedule
  @reference = reference
  @start_date = start_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments. Required when ‘amount_type=fixed`. If not provided for `amount_type=maximum`, defaults to 40000.



2924
2925
2926
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2924

def amount
  @amount
end

#amount_includes_iofObject

Determines if the amount includes the IOF tax. Defaults to ‘never`.



2926
2927
2928
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2926

def amount_includes_iof
  @amount_includes_iof
end

#amount_typeObject

Type of amount. Defaults to ‘maximum`.



2928
2929
2930
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2928

def amount_type
  @amount_type
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Only ‘brl` is supported currently.



2930
2931
2932
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2930

def currency
  @currency
end

#end_dateObject

Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



2932
2933
2934
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2932

def end_date
  @end_date
end

#payment_scheduleObject

Schedule at which the future payments will be charged. Defaults to ‘weekly`.



2934
2935
2936
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2934

def payment_schedule
  @payment_schedule
end

#referenceObject

Subscription name displayed to buyers in their bank app. Defaults to the displayable business name.



2936
2937
2938
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2936

def reference
  @reference
end

#start_dateObject

Start date of the mandate, in ‘YYYY-MM-DD`. Start date should be at least 3 days in the future. Defaults to 3 days after the current date.



2938
2939
2940
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2938

def start_date
  @start_date
end