Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2370
2371
2372
2373
2374
2375
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2370

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



2362
2363
2364
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2362

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



2364
2365
2366
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2364

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



2366
2367
2368
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2366

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



2368
2369
2370
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2368

def end_date
  @end_date
end