Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Upi::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Upi::MandateOptions
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments.
-
#amount_type ⇒ Object
One of
fixedormaximum. -
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
-
#end_date ⇒ Object
End date of the mandate or subscription.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
5248 5249 5250 5251 5252 5253 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5248 def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) @amount = amount @amount_type = amount_type @description = description @end_date = end_date end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments.
5240 5241 5242 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5240 def amount @amount end |
#amount_type ⇒ Object
One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.
5242 5243 5244 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5242 def amount_type @amount_type end |
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
5244 5245 5246 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5244 def description @description end |
#end_date ⇒ Object
End date of the mandate or subscription.
5246 5247 5248 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5246 def end_date @end_date end |