Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



5744
5745
5746
5747
5748
5749
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5744

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



5736
5737
5738
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5736

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



5738
5739
5740
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5738

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



5740
5741
5742
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5740

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



5742
5743
5744
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5742

def end_date
  @end_date
end