Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



5199
5200
5201
5202
5203
5204
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5199

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



5191
5192
5193
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5191

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



5193
5194
5195
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5193

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



5195
5196
5197
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5195

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



5197
5198
5199
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5197

def end_date
  @end_date
end