Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



5174
5175
5176
5177
5178
5179
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5174

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



5166
5167
5168
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5166

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



5168
5169
5170
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5168

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



5170
5171
5172
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5170

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



5172
5173
5174
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5172

def end_date
  @end_date
end