Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2296
2297
2298
2299
2300
2301
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2296

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



2288
2289
2290
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2288

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



2290
2291
2292
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2290

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



2292
2293
2294
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2292

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



2294
2295
2296
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2294

def end_date
  @end_date
end