Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::UsBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: FinancialConnections, MandateOptions, Networks

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(financial_connections: nil, mandate_options: nil, networks: nil, setup_future_usage: nil, target_date: nil, transaction_purpose: nil, verification_method: nil) ⇒ UsBankAccount

Returns a new instance of UsBankAccount.



2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2455

def initialize(
  financial_connections: nil,
  mandate_options: nil,
  networks: nil,
  setup_future_usage: nil,
  target_date: nil,
  transaction_purpose: nil,
  verification_method: nil
)
  @financial_connections = financial_connections
  @mandate_options = mandate_options
  @networks = networks
  @setup_future_usage = setup_future_usage
  @target_date = target_date
  @transaction_purpose = transaction_purpose
  @verification_method = verification_method
end

Instance Attribute Details

#financial_connectionsObject

Additional fields for Financial Connections Session creation



2433
2434
2435
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2433

def financial_connections
  @financial_connections
end

#mandate_optionsObject

Additional fields for Mandate creation



2435
2436
2437
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2435

def mandate_options
  @mandate_options
end

#networksObject

Additional fields for network related functions



2437
2438
2439
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2437

def networks
  @networks
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.

If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.



2447
2448
2449
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2447

def setup_future_usage
  @setup_future_usage
end

#target_dateObject

Controls when Stripe will attempt to debit the funds from the customer's account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.



2449
2450
2451
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2449

def target_date
  @target_date
end

#transaction_purposeObject

The purpose of the transaction.



2451
2452
2453
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2451

def transaction_purpose
  @transaction_purpose
end

#verification_methodObject

Bank account verification method. The default value is automatic.



2453
2454
2455
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2453

def verification_method
  @verification_method
end