Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::UsBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: FinancialConnections, MandateOptions, Networks

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(financial_connections: nil, mandate_options: nil, networks: nil, setup_future_usage: nil, target_date: nil, transaction_purpose: nil, verification_method: nil) ⇒ UsBankAccount

Returns a new instance of UsBankAccount.



5354
5355
5356
5357
5358
5359
5360
5361
5362
5363
5364
5365
5366
5367
5368
5369
5370
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5354

def initialize(
  financial_connections: nil,
  mandate_options: nil,
  networks: nil,
  setup_future_usage: nil,
  target_date: nil,
  transaction_purpose: nil,
  verification_method: nil
)
  @financial_connections = financial_connections
  @mandate_options = mandate_options
  @networks = networks
  @setup_future_usage = setup_future_usage
  @target_date = target_date
  @transaction_purpose = transaction_purpose
  @verification_method = verification_method
end

Instance Attribute Details

#financial_connectionsObject

Additional fields for Financial Connections Session creation



5332
5333
5334
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5332

def financial_connections
  @financial_connections
end

#mandate_optionsObject

Additional fields for Mandate creation



5334
5335
5336
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5334

def mandate_options
  @mandate_options
end

#networksObject

Additional fields for network related functions



5336
5337
5338
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5336

def networks
  @networks
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.

If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.



5346
5347
5348
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5346

def setup_future_usage
  @setup_future_usage
end

#target_dateObject

Controls when Stripe will attempt to debit the funds from the customer's account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.



5348
5349
5350
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5348

def target_date
  @target_date
end

#transaction_purposeObject

The purpose of the transaction.



5350
5351
5352
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5350

def transaction_purpose
  @transaction_purpose
end

#verification_methodObject

Bank account verification method. The default value is automatic.



5352
5353
5354
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5352

def verification_method
  @verification_method
end