Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::UsBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: FinancialConnections, MandateOptions, Networks

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(financial_connections: nil, mandate_options: nil, networks: nil, setup_future_usage: nil, target_date: nil, transaction_purpose: nil, verification_method: nil) ⇒ UsBankAccount

Returns a new instance of UsBankAccount.



5397
5398
5399
5400
5401
5402
5403
5404
5405
5406
5407
5408
5409
5410
5411
5412
5413
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5397

def initialize(
  financial_connections: nil,
  mandate_options: nil,
  networks: nil,
  setup_future_usage: nil,
  target_date: nil,
  transaction_purpose: nil,
  verification_method: nil
)
  @financial_connections = financial_connections
  @mandate_options = mandate_options
  @networks = networks
  @setup_future_usage = setup_future_usage
  @target_date = target_date
  @transaction_purpose = transaction_purpose
  @verification_method = verification_method
end

Instance Attribute Details

#financial_connectionsObject

Additional fields for Financial Connections Session creation



5375
5376
5377
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5375

def financial_connections
  @financial_connections
end

#mandate_optionsObject

Additional fields for Mandate creation



5377
5378
5379
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5377

def mandate_options
  @mandate_options
end

#networksObject

Additional fields for network related functions



5379
5380
5381
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5379

def networks
  @networks
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



5389
5390
5391
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5389

def setup_future_usage
  @setup_future_usage
end

#target_dateObject

Controls when Stripe will attempt to debit the funds from the customer’s account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.



5391
5392
5393
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5391

def target_date
  @target_date
end

#transaction_purposeObject

The purpose of the transaction.



5393
5394
5395
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5393

def transaction_purpose
  @transaction_purpose
end

#verification_methodObject

Bank account verification method. The default value is ‘automatic`.



5395
5396
5397
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5395

def verification_method
  @verification_method
end