Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::UsBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: FinancialConnections, MandateOptions, Networks

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(financial_connections: nil, mandate_options: nil, networks: nil, preferred_settlement_speed: nil, setup_future_usage: nil, target_date: nil, verification_method: nil) ⇒ UsBankAccount

Returns a new instance of UsBankAccount.



3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
3323
3324
3325
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3309

def initialize(
  financial_connections: nil,
  mandate_options: nil,
  networks: nil,
  preferred_settlement_speed: nil,
  setup_future_usage: nil,
  target_date: nil,
  verification_method: nil
)
  @financial_connections = financial_connections
  @mandate_options = mandate_options
  @networks = networks
  @preferred_settlement_speed = preferred_settlement_speed
  @setup_future_usage = setup_future_usage
  @target_date = target_date
  @verification_method = verification_method
end

Instance Attribute Details

#financial_connectionsObject

Additional fields for Financial Connections Session creation



3287
3288
3289
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3287

def financial_connections
  @financial_connections
end

#mandate_optionsObject

Additional fields for Mandate creation



3289
3290
3291
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3289

def mandate_options
  @mandate_options
end

#networksObject

Additional fields for network related functions



3291
3292
3293
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3291

def networks
  @networks
end

#preferred_settlement_speedObject

Preferred transaction settlement speed



3293
3294
3295
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3293

def preferred_settlement_speed
  @preferred_settlement_speed
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



3303
3304
3305
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3303

def setup_future_usage
  @setup_future_usage
end

#target_dateObject

Controls when Stripe will attempt to debit the funds from the customer’s account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.



3305
3306
3307
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3305

def target_date
  @target_date
end

#verification_methodObject

Bank account verification method.



3307
3308
3309
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3307

def verification_method
  @verification_method
end