Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



5299
5300
5301
5302
5303
5304
5305
5306
5307
5308
5309
5310
5311
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5299

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



5289
5290
5291
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5289

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



5291
5292
5293
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5291

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the payment_method permission must be included. Valid permissions include: balances, ownership, payment_method, and transactions.



5293
5294
5295
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5293

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



5295
5296
5297
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5295

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



5297
5298
5299
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5297

def return_url
  @return_url
end