Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



5804
5805
5806
5807
5808
5809
5810
5811
5812
5813
5814
5815
5816
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5804

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



5794
5795
5796
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5794

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



5796
5797
5798
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5796

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



5798
5799
5800
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5798

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



5800
5801
5802
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5800

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



5802
5803
5804
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5802

def return_url
  @return_url
end