Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5250

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



5240
5241
5242
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5240

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



5242
5243
5244
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5242

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



5244
5245
5246
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5244

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



5246
5247
5248
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5246

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



5248
5249
5250
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5248

def return_url
  @return_url
end