Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



5748
5749
5750
5751
5752
5753
5754
5755
5756
5757
5758
5759
5760
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5748

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



5738
5739
5740
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5738

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



5740
5741
5742
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5740

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



5742
5743
5744
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5742

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



5744
5745
5746
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5744

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



5746
5747
5748
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5746

def return_url
  @return_url
end