Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5225

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



5215
5216
5217
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5215

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



5217
5218
5219
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5217

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



5219
5220
5221
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5219

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



5221
5222
5223
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5221

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



5223
5224
5225
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5223

def return_url
  @return_url
end