Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



5281
5282
5283
5284
5285
5286
5287
5288
5289
5290
5291
5292
5293
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5281

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



5271
5272
5273
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5271

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



5273
5274
5275
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5273

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



5275
5276
5277
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5275

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



5277
5278
5279
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5277

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



5279
5280
5281
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5279

def return_url
  @return_url
end