Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Filters

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(filters: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



2288
2289
2290
2291
2292
2293
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2288

def initialize(filters: nil, permissions: nil, prefetch: nil, return_url: nil)
  @filters = filters
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



2280
2281
2282
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2280

def filters
  @filters
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



2282
2283
2284
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2282

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



2284
2285
2286
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2284

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



2286
2287
2288
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2286

def return_url
  @return_url
end