Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



5178
5179
5180
5181
5182
5183
5184
5185
5186
5187
5188
5189
5190
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5178

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



5168
5169
5170
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5168

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



5170
5171
5172
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5170

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



5172
5173
5174
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5172

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



5174
5175
5176
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5174

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



5176
5177
5178
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5176

def return_url
  @return_url
end