Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Filters, ManualEntry
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#manual_entry ⇒ Object
Customize manual entry behavior.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 5159 5160 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5148 def initialize( filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil ) @filters = filters @manual_entry = manual_entry @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
5138 5139 5140 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5138 def filters @filters end |
#manual_entry ⇒ Object
Customize manual entry behavior
5140 5141 5142 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5140 def manual_entry @manual_entry end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
5142 5143 5144 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5142 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
5144 5145 5146 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5144 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
5146 5147 5148 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5146 def return_url @return_url end |