Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



3233
3234
3235
3236
3237
3238
3239
3240
3241
3242
3243
3244
3245
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3233

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



3223
3224
3225
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3223

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



3225
3226
3227
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3225

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



3227
3228
3229
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3227

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



3229
3230
3231
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3229

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



3231
3232
3233
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3231

def return_url
  @return_url
end