Class: Stripe::PaymentIntentCreateParams::PaymentMethodOptions::WechatPay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::PaymentMethodOptions::WechatPay
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#app_id ⇒ Object
The app ID registered with WeChat Pay.
-
#buyer_id ⇒ Object
The unique buyer ID for the app ID registered with WeChat Pay.
-
#client ⇒ Object
The client type that the end customer will pay from.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Instance Method Summary collapse
-
#initialize(app_id: nil, buyer_id: nil, client: nil, setup_future_usage: nil) ⇒ WechatPay
constructor
A new instance of WechatPay.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(app_id: nil, buyer_id: nil, client: nil, setup_future_usage: nil) ⇒ WechatPay
Returns a new instance of WechatPay.
6061 6062 6063 6064 6065 6066 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6061 def initialize(app_id: nil, buyer_id: nil, client: nil, setup_future_usage: nil) @app_id = app_id @buyer_id = buyer_id @client = client @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#app_id ⇒ Object
The app ID registered with WeChat Pay. Only required when client is ios, android, or mini_program.
6045 6046 6047 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6045 def app_id @app_id end |
#buyer_id ⇒ Object
The unique buyer ID for the app ID registered with WeChat Pay. Only required when client is mini_program.
6047 6048 6049 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6047 def buyer_id @buyer_id end |
#client ⇒ Object
The client type that the end customer will pay from
6049 6050 6051 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6049 def client @client end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.
6059 6060 6061 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6059 def setup_future_usage @setup_future_usage end |