Class: Stripe::PaymentIntentCreateParams::RadarOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::RadarOptions
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#referrer ⇒ Object
The referrer URL of the current checkout session.
-
#session ⇒ Object
A Radar Session is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments.
Instance Method Summary collapse
-
#initialize(referrer: nil, session: nil) ⇒ RadarOptions
constructor
A new instance of RadarOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(referrer: nil, session: nil) ⇒ RadarOptions
Returns a new instance of RadarOptions.
2749 2750 2751 2752 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2749 def initialize(referrer: nil, session: nil) @referrer = referrer @session = session end |
Instance Attribute Details
#referrer ⇒ Object
The referrer URL of the current checkout session. You can use this to supply session-level referrer data when a Radar Session isn't available or doesn't contain a referrer.
2745 2746 2747 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2745 def referrer @referrer end |
#session ⇒ Object
A Radar Session is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments.
2747 2748 2749 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2747 def session @session end |