Class: Stripe::PaymentIntentCreateParams::RadarOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(referrer: nil, session: nil) ⇒ RadarOptions

Returns a new instance of RadarOptions.



5676
5677
5678
5679
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5676

def initialize(referrer: nil, session: nil)
  @referrer = referrer
  @session = session
end

Instance Attribute Details

#referrerObject

The referrer URL of the current checkout session. You can use this to supply session-level referrer data when a Radar Session isn't available or doesn't contain a referrer.



5672
5673
5674
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5672

def referrer
  @referrer
end

#sessionObject

A Radar Session is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments.



5674
5675
5676
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5674

def session
  @session
end