Class: Stripe::PaymentIntentCreateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



6417
6418
6419
6420
6421
6422
6423
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6417

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



6407
6408
6409
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6407

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



6409
6410
6411
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6409

def carrier
  @carrier
end

#nameObject

Recipient name.



6411
6412
6413
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6411

def name
  @name
end

#phoneObject

Recipient phone (including extension).



6413
6414
6415
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6413

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



6415
6416
6417
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6415

def tracking_number
  @tracking_number
end