Class: Stripe::PaymentIntentCreateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::Shipping
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
2797 2798 2799 2800 2801 2802 2803 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2797 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
2787 2788 2789 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2787 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
2789 2790 2791 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2789 def carrier @carrier end |
#name ⇒ Object
Recipient name.
2791 2792 2793 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2791 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
2793 2794 2795 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2793 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
2795 2796 2797 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2795 def tracking_number @tracking_number end |