Class: Stripe::PaymentIntentCreateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



5724
5725
5726
5727
5728
5729
5730
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5724

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



5714
5715
5716
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5714

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



5716
5717
5718
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5716

def carrier
  @carrier
end

#nameObject

Recipient name.



5718
5719
5720
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5718

def name
  @name
end

#phoneObject

Recipient phone (including extension).



5720
5721
5722
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5720

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



5722
5723
5724
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5722

def tracking_number
  @tracking_number
end