Class: Stripe::PaymentIntentCreateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::Shipping
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
5703 5704 5705 5706 5707 5708 5709 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5703 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
5693 5694 5695 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5693 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
5695 5696 5697 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5695 def carrier @carrier end |
#name ⇒ Object
Recipient name.
5697 5698 5699 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5697 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
5699 5700 5701 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5699 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
5701 5702 5703 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5701 def tracking_number @tracking_number end |