Class: Stripe::PaymentIntentCreateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



6238
6239
6240
6241
6242
6243
6244
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6238

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



6228
6229
6230
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6228

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



6230
6231
6232
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6230

def carrier
  @carrier
end

#nameObject

Recipient name.



6232
6233
6234
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6232

def name
  @name
end

#phoneObject

Recipient phone (including extension).



6234
6235
6236
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6234

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



6236
6237
6238
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6236

def tracking_number
  @tracking_number
end