Class: Stripe::PaymentIntentCreateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



5668
5669
5670
5671
5672
5673
5674
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5668

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



5658
5659
5660
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5658

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



5660
5661
5662
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5660

def carrier
  @carrier
end

#nameObject

Recipient name.



5662
5663
5664
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5662

def name
  @name
end

#phoneObject

Recipient phone (including extension).



5664
5665
5666
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5664

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



5666
5667
5668
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5666

def tracking_number
  @tracking_number
end