Class: Stripe::PaymentIntentCreateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



2741
2742
2743
2744
2745
2746
2747
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2741

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



2731
2732
2733
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2731

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



2733
2734
2735
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2733

def carrier
  @carrier
end

#nameObject

Recipient name.



2735
2736
2737
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2735

def name
  @name
end

#phoneObject

Recipient phone (including extension).



2737
2738
2739
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2737

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



2739
2740
2741
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2739

def tracking_number
  @tracking_number
end