Class: Stripe::PaymentIntentCreateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



6167
6168
6169
6170
6171
6172
6173
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6167

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



6157
6158
6159
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6157

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



6159
6160
6161
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6159

def carrier
  @carrier
end

#nameObject

Recipient name.



6161
6162
6163
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6161

def name
  @name
end

#phoneObject

Recipient phone (including extension).



6163
6164
6165
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6163

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



6165
6166
6167
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6165

def tracking_number
  @tracking_number
end