Class: Stripe::PaymentIntentCreateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



6187
6188
6189
6190
6191
6192
6193
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6187

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



6177
6178
6179
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6177

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



6179
6180
6181
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6179

def carrier
  @carrier
end

#nameObject

Recipient name.



6181
6182
6183
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6181

def name
  @name
end

#phoneObject

Recipient phone (including extension).



6183
6184
6185
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6183

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



6185
6186
6187
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6185

def tracking_number
  @tracking_number
end