Class: Stripe::PaymentIntentCreateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



6184
6185
6186
6187
6188
6189
6190
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6184

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



6174
6175
6176
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6174

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



6176
6177
6178
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6176

def carrier
  @carrier
end

#nameObject

Recipient name.



6178
6179
6180
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6178

def name
  @name
end

#phoneObject

Recipient phone (including extension).



6180
6181
6182
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6180

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



6182
6183
6184
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6182

def tracking_number
  @tracking_number
end