Class: Stripe::PaymentIntentCreateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::Shipping
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
6180 6181 6182 6183 6184 6185 6186 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6180 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
6170 6171 6172 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6170 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
6172 6173 6174 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6172 def carrier @carrier end |
#name ⇒ Object
Recipient name.
6174 6175 6176 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6174 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
6176 6177 6178 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6176 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
6178 6179 6180 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6178 def tracking_number @tracking_number end |