Class: Stripe::PaymentIntentCreateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



5635
5636
5637
5638
5639
5640
5641
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5635

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



5625
5626
5627
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5625

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



5627
5628
5629
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5627

def carrier
  @carrier
end

#nameObject

Recipient name.



5629
5630
5631
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5629

def name
  @name
end

#phoneObject

Recipient phone (including extension).



5631
5632
5633
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5631

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



5633
5634
5635
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5633

def tracking_number
  @tracking_number
end