Class: Stripe::PaymentIntentCreateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



5593
5594
5595
5596
5597
5598
5599
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5593

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



5583
5584
5585
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5583

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



5585
5586
5587
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5585

def carrier
  @carrier
end

#nameObject

Recipient name.



5587
5588
5589
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5587

def name
  @name
end

#phoneObject

Recipient phone (including extension).



5589
5590
5591
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5589

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



5591
5592
5593
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5591

def tracking_number
  @tracking_number
end