Class: Stripe::PaymentIntentCreateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



5554
5555
5556
5557
5558
5559
5560
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5554

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



5544
5545
5546
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5544

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



5546
5547
5548
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5546

def carrier
  @carrier
end

#nameObject

Recipient name.



5548
5549
5550
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5548

def name
  @name
end

#phoneObject

Recipient phone (including extension).



5550
5551
5552
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5550

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



5552
5553
5554
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5552

def tracking_number
  @tracking_number
end