Class: Stripe::PaymentIntentCreateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::Shipping
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
2602 2603 2604 2605 2606 2607 2608 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2602 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
2592 2593 2594 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2592 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
2594 2595 2596 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2594 def carrier @carrier end |
#name ⇒ Object
Recipient name.
2596 2597 2598 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2596 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
2598 2599 2600 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2598 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
2600 2601 2602 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2600 def tracking_number @tracking_number end |