Class: Stripe::PaymentIntentCreateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::Shipping
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
5571 5572 5573 5574 5575 5576 5577 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5571 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
5561 5562 5563 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5561 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
5563 5564 5565 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5563 def carrier @carrier end |
#name ⇒ Object
Recipient name.
5565 5566 5567 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5565 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
5567 5568 5569 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5567 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
5569 5570 5571 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5569 def tracking_number @tracking_number end |