Class: Stripe::PaymentIntentCreateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



2482
2483
2484
2485
2486
2487
2488
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2482

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



2472
2473
2474
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2472

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



2474
2475
2476
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2474

def carrier
  @carrier
end

#nameObject

Recipient name.



2476
2477
2478
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2476

def name
  @name
end

#phoneObject

Recipient phone (including extension).



2478
2479
2480
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2478

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



2480
2481
2482
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2480

def tracking_number
  @tracking_number
end