Class: Stripe::PaymentIntentCreateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::Shipping
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
3660 3661 3662 3663 3664 3665 3666 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3660 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
3650 3651 3652 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3650 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
3652 3653 3654 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3652 def carrier @carrier end |
#name ⇒ Object
Recipient name.
3654 3655 3656 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3654 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
3656 3657 3658 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3656 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
3658 3659 3660 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3658 def tracking_number @tracking_number end |