Class: Stripe::PaymentIntentCreateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



2293
2294
2295
2296
2297
2298
2299
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2293

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



2283
2284
2285
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2283

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



2285
2286
2287
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2285

def carrier
  @carrier
end

#nameObject

Recipient name.



2287
2288
2289
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2287

def name
  @name
end

#phoneObject

Recipient phone (including extension).



2289
2290
2291
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2289

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



2291
2292
2293
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2291

def tracking_number
  @tracking_number
end