Class: Stripe::PaymentIntentCreateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::Shipping
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
2293 2294 2295 2296 2297 2298 2299 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2293 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
2283 2284 2285 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2283 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
2285 2286 2287 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2285 def carrier @carrier end |
#name ⇒ Object
Recipient name.
2287 2288 2289 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2287 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
2289 2290 2291 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2289 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
2291 2292 2293 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2291 def tracking_number @tracking_number end |