Class: Stripe::PaymentIntentCreateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::Shipping
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
3639 3640 3641 3642 3643 3644 3645 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3639 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
3629 3630 3631 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3629 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
3631 3632 3633 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3631 def carrier @carrier end |
#name ⇒ Object
Recipient name.
3633 3634 3635 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3633 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
3635 3636 3637 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3635 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
3637 3638 3639 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 3637 def tracking_number @tracking_number end |