Class: Stripe::PaymentIntentCreateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::Shipping
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
2663 2664 2665 2666 2667 2668 2669 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2663 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
2653 2654 2655 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2653 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
2655 2656 2657 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2655 def carrier @carrier end |
#name ⇒ Object
Recipient name.
2657 2658 2659 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2657 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
2659 2660 2661 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2659 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
2661 2662 2663 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2661 def tracking_number @tracking_number end |