Class: Stripe::PaymentIntentCreateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



2606
2607
2608
2609
2610
2611
2612
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2606

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



2596
2597
2598
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2596

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



2598
2599
2600
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2598

def carrier
  @carrier
end

#nameObject

Recipient name.



2600
2601
2602
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2600

def name
  @name
end

#phoneObject

Recipient phone (including extension).



2602
2603
2604
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2602

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



2604
2605
2606
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2604

def tracking_number
  @tracking_number
end