Class: Stripe::PaymentIntentCreateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: PaymentData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, description: nil, destination: nil, metadata: nil, payment_data: nil) ⇒ TransferData

Returns a new instance of TransferData.



6458
6459
6460
6461
6462
6463
6464
6465
6466
6467
6468
6469
6470
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6458

def initialize(
  amount: nil,
  description: nil,
  destination: nil,
  metadata: nil,
  payment_data: nil
)
  @amount = amount
  @description = description
  @destination = destination
  @metadata = 
  @payment_data = payment_data
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when a charge succeeds. The amount is capped at the total transaction amount and if no amount is set, the full amount is transferred.

If you intend to collect a fee and you need a more robust reporting experience, using application_fee_amount might be a better fit for your integration.



6445
6446
6447
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6445

def amount
  @amount
end

#descriptionObject

An arbitrary string attached to the transfer. Often useful for displaying to users.



6447
6448
6449
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6447

def description
  @description
end

#destinationObject

If specified, successful charges will be attributed to the destination account for tax reporting, and the funds from charges will be transferred to the destination account. The ID of the resulting transfer will be returned on the successful charge's transfer field.



6452
6453
6454
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6452

def destination
  @destination
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



6454
6455
6456
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6454

def 
  @metadata
end

#payment_dataObject

The data with which to populate the destination payment.



6456
6457
6458
# File 'lib/stripe/params/payment_intent_create_params.rb', line 6456

def payment_data
  @payment_data
end