Class: Stripe::PaymentIntentCreateParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::TransferData
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Defined Under Namespace
Classes: PaymentData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds.
-
#description ⇒ Object
An arbitrary string attached to the transfer.
-
#destination ⇒ Object
If specified, successful charges will be attributed to the destination account for tax reporting, and the funds from charges will be transferred to the destination account.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#payment_data ⇒ Object
The data with which to populate the destination payment.
Instance Method Summary collapse
-
#initialize(amount: nil, description: nil, destination: nil, metadata: nil, payment_data: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, description: nil, destination: nil, metadata: nil, payment_data: nil) ⇒ TransferData
Returns a new instance of TransferData.
5765 5766 5767 5768 5769 5770 5771 5772 5773 5774 5775 5776 5777 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5765 def initialize( amount: nil, description: nil, destination: nil, metadata: nil, payment_data: nil ) @amount = amount @description = description @destination = destination @metadata = @payment_data = payment_data end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds. The amount is capped at the total transaction amount and if no amount is set, the full amount is transferred.
If you intend to collect a fee and you need a more robust reporting experience, using application_fee_amount might be a better fit for your integration.
5752 5753 5754 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5752 def amount @amount end |
#description ⇒ Object
An arbitrary string attached to the transfer. Often useful for displaying to users.
5754 5755 5756 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5754 def description @description end |
#destination ⇒ Object
If specified, successful charges will be attributed to the destination
account for tax reporting, and the funds from charges will be transferred
to the destination account. The ID of the resulting transfer will be
returned on the successful charge's transfer field.
5759 5760 5761 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5759 def destination @destination end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
5761 5762 5763 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5761 def @metadata end |
#payment_data ⇒ Object
The data with which to populate the destination payment.
5763 5764 5765 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5763 def payment_data @payment_data end |