Class: Stripe::PaymentIntentCreateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Defined Under Namespace

Classes: PaymentData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, description: nil, destination: nil, metadata: nil, payment_data: nil) ⇒ TransferData

Returns a new instance of TransferData.



5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
5719
5720
5721
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5709

def initialize(
  amount: nil,
  description: nil,
  destination: nil,
  metadata: nil,
  payment_data: nil
)
  @amount = amount
  @description = description
  @destination = destination
  @metadata = 
  @payment_data = payment_data
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when a charge succeeds. The amount is capped at the total transaction amount and if no amount is set, the full amount is transferred.

If you intend to collect a fee and you need a more robust reporting experience, using [application_fee_amount](docs.stripe.com/api/payment_intents/create#create_payment_intent-application_fee_amount) might be a better fit for your integration.



5696
5697
5698
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5696

def amount
  @amount
end

#descriptionObject

An arbitrary string attached to the transfer. Often useful for displaying to users.



5698
5699
5700
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5698

def description
  @description
end

#destinationObject

If specified, successful charges will be attributed to the destination account for tax reporting, and the funds from charges will be transferred to the destination account. The ID of the resulting transfer will be returned on the successful charge’s ‘transfer` field.



5703
5704
5705
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5703

def destination
  @destination
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



5705
5706
5707
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5705

def 
  @metadata
end

#payment_dataObject

The data with which to populate the destination payment.



5707
5708
5709
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5707

def payment_data
  @payment_data
end