Class: Stripe::PaymentIntentCreateParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::TransferData
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds.
-
#destination ⇒ Object
If specified, successful charges will be attributed to the destination account for tax reporting, and the funds from charges will be transferred to the destination account.
Instance Method Summary collapse
-
#initialize(amount: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
5785 5786 5787 5788 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5785 def initialize(amount: nil, destination: nil) @amount = amount @destination = destination end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds. The amount is capped at the total transaction amount and if no amount is set, the full amount is transferred.
If you intend to collect a fee and you need a more robust reporting experience, using [application_fee_amount](docs.stripe.com/api/payment_intents/create#create_payment_intent-application_fee_amount) might be a better fit for your integration.
5778 5779 5780 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5778 def amount @amount end |
#destination ⇒ Object
If specified, successful charges will be attributed to the destination account for tax reporting, and the funds from charges will be transferred to the destination account. The ID of the resulting transfer will be returned on the successful charge’s ‘transfer` field.
5783 5784 5785 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5783 def destination @destination end |