Class: Stripe::PaymentIntentCreateParams::TransferData::PaymentData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentCreateParams::TransferData::PaymentData
- Defined in:
- lib/stripe/params/payment_intent_create_params.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
An arbitrary string attached to the destination payment.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Instance Method Summary collapse
-
#initialize(description: nil, metadata: nil) ⇒ PaymentData
constructor
A new instance of PaymentData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(description: nil, metadata: nil) ⇒ PaymentData
Returns a new instance of PaymentData.
2813 2814 2815 2816 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2813 def initialize(description: nil, metadata: nil) @description = description @metadata = end |
Instance Attribute Details
#description ⇒ Object
An arbitrary string attached to the destination payment. Often useful for displaying to users.
2809 2810 2811 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2809 def description @description end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2811 2812 2813 |
# File 'lib/stripe/params/payment_intent_create_params.rb', line 2811 def @metadata end |