Class: Stripe::PaymentIntentCreateParams::TransferData::PaymentData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(description: nil, metadata: nil) ⇒ PaymentData

Returns a new instance of PaymentData.



5740
5741
5742
5743
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5740

def initialize(description: nil, metadata: nil)
  @description = description
  @metadata = 
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the destination payment. Often useful for displaying to users.



5736
5737
5738
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5736

def description
  @description
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



5738
5739
5740
# File 'lib/stripe/params/payment_intent_create_params.rb', line 5738

def 
  @metadata
end