Class: Stripe::PaymentIntentDecrementAuthorizationParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentDecrementAuthorizationParams
- Defined in:
- lib/stripe/params/payment_intent_decrement_authorization_params.rb
Defined Under Namespace
Classes: AmountDetails, Hooks, PaymentDetails, TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder.
-
#amount_details ⇒ Object
Provides industry-specific information about the amount.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#payment_details ⇒ Object
Provides industry-specific information about the charge.
-
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_details: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, payment_details: nil, transfer_data: nil) ⇒ PaymentIntentDecrementAuthorizationParams
constructor
A new instance of PaymentIntentDecrementAuthorizationParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_details: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, payment_details: nil, transfer_data: nil) ⇒ PaymentIntentDecrementAuthorizationParams
Returns a new instance of PaymentIntentDecrementAuthorizationParams.
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 293 def initialize( amount: nil, amount_details: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, payment_details: nil, transfer_data: nil ) @amount = amount @amount_details = amount_details @application_fee_amount = application_fee_amount @description = description @expand = @hooks = hooks @metadata = @payment_details = payment_details @transfer_data = transfer_data end |
Instance Attribute Details
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder. This amount must be smaller than the currently authorized amount and greater than the already captured amount.
274 275 276 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 274 def amount @amount end |
#amount_details ⇒ Object
Provides industry-specific information about the amount.
276 277 278 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 276 def amount_details @amount_details end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](docs.stripe.com/payments/connected-accounts).
278 279 280 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 278 def application_fee_amount @application_fee_amount end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
280 281 282 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 280 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
282 283 284 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 282 def @expand end |
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle
284 285 286 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 284 def hooks @hooks end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
286 287 288 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 286 def @metadata end |
#payment_details ⇒ Object
Provides industry-specific information about the charge.
288 289 290 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 288 def payment_details @payment_details end |
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](docs.stripe.com/payments/connected-accounts).
291 292 293 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 291 def transfer_data @transfer_data end |