Class: Stripe::PaymentIntentDecrementAuthorizationParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_decrement_authorization_params.rb

Defined Under Namespace

Classes: AmountDetails, Hooks, PaymentDetails, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_details: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, payment_details: nil, transfer_data: nil) ⇒ PaymentIntentDecrementAuthorizationParams

Returns a new instance of PaymentIntentDecrementAuthorizationParams.



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 275

def initialize(
  amount: nil,
  amount_details: nil,
  application_fee_amount: nil,
  description: nil,
  expand: nil,
  hooks: nil,
  metadata: nil,
  payment_details: nil,
  transfer_data: nil
)
  @amount = amount
  @amount_details = amount_details
  @application_fee_amount = application_fee_amount
  @description = description
  @expand = expand
  @hooks = hooks
  @metadata = 
  @payment_details = payment_details
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The updated total amount that you intend to collect from the cardholder. This amount must be smaller than the currently authorized amount and greater than the already captured amount.



256
257
258
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 256

def amount
  @amount
end

#amount_detailsObject

Provides industry-specific information about the amount.



258
259
260
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 258

def amount_details
  @amount_details
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](docs.stripe.com/payments/connected-accounts).



260
261
262
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 260

def application_fee_amount
  @application_fee_amount
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



262
263
264
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 262

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



264
265
266
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 264

def expand
  @expand
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



266
267
268
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 266

def hooks
  @hooks
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



268
269
270
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 268

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



270
271
272
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 270

def payment_details
  @payment_details
end

#transfer_dataObject

The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](docs.stripe.com/payments/connected-accounts).



273
274
275
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 273

def transfer_data
  @transfer_data
end