Class: Stripe::PaymentIntentDecrementAuthorizationParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentDecrementAuthorizationParams
- Defined in:
- lib/stripe/params/payment_intent_decrement_authorization_params.rb
Defined Under Namespace
Classes: Hooks, TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured.
Instance Method Summary collapse
-
#initialize(amount: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, transfer_data: nil) ⇒ PaymentIntentDecrementAuthorizationParams
constructor
A new instance of PaymentIntentDecrementAuthorizationParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, transfer_data: nil) ⇒ PaymentIntentDecrementAuthorizationParams
Returns a new instance of PaymentIntentDecrementAuthorizationParams.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 55 def initialize( amount: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, transfer_data: nil ) @amount = amount @application_fee_amount = application_fee_amount @description = description @expand = @hooks = hooks @metadata = @transfer_data = transfer_data end |
Instance Attribute Details
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder. This amount must be smaller than the currently authorized amount and greater than the already captured amount.
40 41 42 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 40 def amount @amount end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](docs.stripe.com/payments/connected-accounts).
42 43 44 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 42 def application_fee_amount @application_fee_amount end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
44 45 46 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 44 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
46 47 48 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 46 def @expand end |
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle
48 49 50 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 48 def hooks @hooks end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
50 51 52 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 50 def @metadata end |
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](docs.stripe.com/payments/connected-accounts).
53 54 55 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 53 def transfer_data @transfer_data end |