Class: Stripe::PaymentIntentDecrementAuthorizationParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentDecrementAuthorizationParams::PaymentDetails
- Defined in:
- lib/stripe/params/payment_intent_decrement_authorization_params.rb
Instance Attribute Summary collapse
-
#customer_reference ⇒ Object
A unique value to identify the customer.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
Instance Method Summary collapse
-
#initialize(customer_reference: nil, order_reference: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(customer_reference: nil, order_reference: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
241 242 243 244 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 241 def initialize(customer_reference: nil, order_reference: nil) @customer_reference = customer_reference @order_reference = order_reference end |
Instance Attribute Details
#customer_reference ⇒ Object
A unique value to identify the customer. This field is available only for card payments.
This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.
235 236 237 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 235 def customer_reference @customer_reference end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.
For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.
239 240 241 |
# File 'lib/stripe/params/payment_intent_decrement_authorization_params.rb', line 239 def order_reference @order_reference end |