Class: Stripe::PaymentIntentIncrementAuthorizationParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentIncrementAuthorizationParams
- Defined in:
- lib/stripe/params/payment_intent_increment_authorization_params.rb
Defined Under Namespace
Classes: AmountDetails, Hooks, PaymentDetails, PaymentMethodOptions, TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder.
-
#amount_details ⇒ Object
Provides industry-specific information about the amount.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#payment_details ⇒ Object
Provides industry-specific information about the charge.
-
#payment_method_options ⇒ Object
Payment method-specific configuration for this PaymentIntent.
-
#statement_descriptor ⇒ Object
Text that appears on the customer's statement as the statement descriptor for a non-card or card charge.
-
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_details: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, payment_details: nil, payment_method_options: nil, statement_descriptor: nil, transfer_data: nil) ⇒ PaymentIntentIncrementAuthorizationParams
constructor
A new instance of PaymentIntentIncrementAuthorizationParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_details: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, payment_details: nil, payment_method_options: nil, statement_descriptor: nil, transfer_data: nil) ⇒ PaymentIntentIncrementAuthorizationParams
Returns a new instance of PaymentIntentIncrementAuthorizationParams.
369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 369 def initialize( amount: nil, amount_details: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, payment_details: nil, payment_method_options: nil, statement_descriptor: nil, transfer_data: nil ) @amount = amount @amount_details = amount_details @application_fee_amount = application_fee_amount @description = description @expand = @hooks = hooks @metadata = @payment_details = payment_details @payment_method_options = @statement_descriptor = statement_descriptor @transfer_data = transfer_data end |
Instance Attribute Details
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder. This amount must be greater than the currently authorized amount.
346 347 348 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 346 def amount @amount end |
#amount_details ⇒ Object
Provides industry-specific information about the amount.
348 349 350 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 348 def amount_details @amount_details end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents use case for connected accounts.
350 351 352 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 350 def application_fee_amount @application_fee_amount end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
352 353 354 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 352 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
354 355 356 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 354 def @expand end |
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle
356 357 358 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 356 def hooks @hooks end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
358 359 360 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 358 def @metadata end |
#payment_details ⇒ Object
Provides industry-specific information about the charge.
360 361 362 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 360 def payment_details @payment_details end |
#payment_method_options ⇒ Object
Payment method-specific configuration for this PaymentIntent.
362 363 364 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 362 def @payment_method_options end |
#statement_descriptor ⇒ Object
Text that appears on the customer's statement as the statement descriptor for a non-card or card charge. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see the Statement Descriptor docs.
364 365 366 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 364 def statement_descriptor @statement_descriptor end |
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured. Learn more about the use case for connected accounts.
367 368 369 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 367 def transfer_data @transfer_data end |