Class: Stripe::PaymentIntentIncrementAuthorizationParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_increment_authorization_params.rb

Defined Under Namespace

Classes: AmountDetails, Hooks, PaymentDetails, PaymentMethodOptions, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_details: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, payment_details: nil, payment_method_options: nil, statement_descriptor: nil, transfer_data: nil) ⇒ PaymentIntentIncrementAuthorizationParams

Returns a new instance of PaymentIntentIncrementAuthorizationParams.



314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 314

def initialize(
  amount: nil,
  amount_details: nil,
  application_fee_amount: nil,
  description: nil,
  expand: nil,
  hooks: nil,
  metadata: nil,
  payment_details: nil,
  payment_method_options: nil,
  statement_descriptor: nil,
  transfer_data: nil
)
  @amount = amount
  @amount_details = amount_details
  @application_fee_amount = application_fee_amount
  @description = description
  @expand = expand
  @hooks = hooks
  @metadata = 
  @payment_details = payment_details
  @payment_method_options = payment_method_options
  @statement_descriptor = statement_descriptor
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The updated total amount that you intend to collect from the cardholder. This amount must be greater than the currently authorized amount.



291
292
293
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 291

def amount
  @amount
end

#amount_detailsObject

Provides industry-specific information about the amount.



293
294
295
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 293

def amount_details
  @amount_details
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](docs.stripe.com/payments/connected-accounts).



295
296
297
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 295

def application_fee_amount
  @application_fee_amount
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



297
298
299
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 297

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



299
300
301
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 299

def expand
  @expand
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



301
302
303
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 301

def hooks
  @hooks
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



303
304
305
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 303

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



305
306
307
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 305

def payment_details
  @payment_details
end

#payment_method_optionsObject

Payment method-specific configuration for this PaymentIntent.



307
308
309
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 307

def payment_method_options
  @payment_method_options
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card or card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).



309
310
311
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 309

def statement_descriptor
  @statement_descriptor
end

#transfer_dataObject

The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](docs.stripe.com/payments/connected-accounts).



312
313
314
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 312

def transfer_data
  @transfer_data
end