Class: Stripe::PaymentIntentIncrementAuthorizationParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentIncrementAuthorizationParams
- Defined in:
- lib/stripe/params/payment_intent_increment_authorization_params.rb
Defined Under Namespace
Classes: AmountDetails, Hooks, PaymentDetails, PaymentMethodOptions, TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder.
-
#amount_details ⇒ Object
Provides industry-specific information about the amount.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment_details ⇒ Object
Provides industry-specific information about the charge.
-
#payment_method_options ⇒ Object
Payment method-specific configuration for this PaymentIntent.
-
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card or card charge.
-
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_details: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, payment_details: nil, payment_method_options: nil, statement_descriptor: nil, transfer_data: nil) ⇒ PaymentIntentIncrementAuthorizationParams
constructor
A new instance of PaymentIntentIncrementAuthorizationParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_details: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, payment_details: nil, payment_method_options: nil, statement_descriptor: nil, transfer_data: nil) ⇒ PaymentIntentIncrementAuthorizationParams
Returns a new instance of PaymentIntentIncrementAuthorizationParams.
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 253 def initialize( amount: nil, amount_details: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, payment_details: nil, payment_method_options: nil, statement_descriptor: nil, transfer_data: nil ) @amount = amount @amount_details = amount_details @application_fee_amount = application_fee_amount @description = description @expand = @hooks = hooks @metadata = @payment_details = payment_details @payment_method_options = @statement_descriptor = statement_descriptor @transfer_data = transfer_data end |
Instance Attribute Details
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder. This amount must be greater than the currently authorized amount.
230 231 232 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 230 def amount @amount end |
#amount_details ⇒ Object
Provides industry-specific information about the amount.
232 233 234 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 232 def amount_details @amount_details end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
234 235 236 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 234 def application_fee_amount @application_fee_amount end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
236 237 238 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 236 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
238 239 240 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 238 def @expand end |
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle
240 241 242 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 240 def hooks @hooks end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
242 243 244 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 242 def @metadata end |
#payment_details ⇒ Object
Provides industry-specific information about the charge.
244 245 246 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 244 def payment_details @payment_details end |
#payment_method_options ⇒ Object
Payment method-specific configuration for this PaymentIntent.
246 247 248 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 246 def @payment_method_options end |
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card or card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
248 249 250 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 248 def statement_descriptor @statement_descriptor end |
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
251 252 253 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 251 def transfer_data @transfer_data end |