Class: Stripe::PaymentIntentIncrementAuthorizationParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_increment_authorization_params.rb

Defined Under Namespace

Classes: AmountDetails, PaymentDetails, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_details: nil, application_fee_amount: nil, description: nil, expand: nil, metadata: nil, payment_details: nil, statement_descriptor: nil, transfer_data: nil) ⇒ PaymentIntentIncrementAuthorizationParams

Returns a new instance of PaymentIntentIncrementAuthorizationParams.



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 223

def initialize(
  amount: nil,
  amount_details: nil,
  application_fee_amount: nil,
  description: nil,
  expand: nil,
  metadata: nil,
  payment_details: nil,
  statement_descriptor: nil,
  transfer_data: nil
)
  @amount = amount
  @amount_details = amount_details
  @application_fee_amount = application_fee_amount
  @description = description
  @expand = expand
  @metadata = 
  @payment_details = payment_details
  @statement_descriptor = statement_descriptor
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The updated total amount that you intend to collect from the cardholder. This amount must be greater than the currently authorized amount.



204
205
206
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 204

def amount
  @amount
end

#amount_detailsObject

Provides industry-specific information about the amount.



206
207
208
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 206

def amount_details
  @amount_details
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



208
209
210
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 208

def application_fee_amount
  @application_fee_amount
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



210
211
212
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 210

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



212
213
214
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 212

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



214
215
216
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 214

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



216
217
218
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 216

def payment_details
  @payment_details
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card or card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).



218
219
220
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 218

def statement_descriptor
  @statement_descriptor
end

#transfer_dataObject

The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



221
222
223
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 221

def transfer_data
  @transfer_data
end