Class: Stripe::PaymentIntentIncrementAuthorizationParams::AmountDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentIncrementAuthorizationParams::AmountDetails
- Defined in:
- lib/stripe/params/payment_intent_increment_authorization_params.rb
Defined Under Namespace
Classes: LineItem, Shipping, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The total discount applied on the transaction.
-
#line_items ⇒ Object
A list of line items, each containing information about a product in the PaymentIntent.
-
#shipping ⇒ Object
Contains information about the shipping portion of the amount.
-
#tax ⇒ Object
Contains information about the tax portion of the amount.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails
constructor
A new instance of AmountDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails
Returns a new instance of AmountDetails.
159 160 161 162 163 164 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 159 def initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) @discount_amount = discount_amount @line_items = line_items @shipping = shipping @tax = tax end |
Instance Attribute Details
#discount_amount ⇒ Object
The total discount applied on the transaction.
151 152 153 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 151 def discount_amount @discount_amount end |
#line_items ⇒ Object
A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.
153 154 155 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 153 def line_items @line_items end |
#shipping ⇒ Object
Contains information about the shipping portion of the amount.
155 156 157 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 155 def shipping @shipping end |
#tax ⇒ Object
Contains information about the tax portion of the amount.
157 158 159 |
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 157 def tax @tax end |