Class: Stripe::PaymentIntentIncrementAuthorizationParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_increment_authorization_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer_reference: nil, order_reference: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



190
191
192
193
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 190

def initialize(customer_reference: nil, order_reference: nil)
  @customer_reference = customer_reference
  @order_reference = order_reference
end

Instance Attribute Details

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



186
187
188
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 186

def customer_reference
  @customer_reference
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



188
189
190
# File 'lib/stripe/params/payment_intent_increment_authorization_params.rb', line 188

def order_reference
  @order_reference
end