Class: Stripe::PaymentIntentService

Inherits:
StripeService show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: ApplyCustomerBalanceParams, CancelParams, CaptureParams, ConfirmParams, CreateParams, DecrementAuthorizationParams, IncrementAuthorizationParams, ListParams, RetrieveParams, SearchParams, TriggerActionParams, UpdateParams, VerifyMicrodepositsParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from StripeService

#request, #request_stream

Constructor Details

#initialize(requestor) ⇒ PaymentIntentService

Returns a new instance of PaymentIntentService.



8
9
10
11
# File 'lib/stripe/services/payment_intent_service.rb', line 8

def initialize(requestor)
  super
  @amount_details_line_items = Stripe::PaymentIntentAmountDetailsLineItemService.new(@requestor)
end

Instance Attribute Details

#amount_details_line_itemsObject (readonly)

Returns the value of attribute amount_details_line_items.



6
7
8
# File 'lib/stripe/services/payment_intent_service.rb', line 6

def amount_details_line_items
  @amount_details_line_items
end

Instance Method Details

#apply_customer_balance(intent, params = {}, opts = {}) ⇒ Object

Manually reconcile the remaining amount for a customer_balance PaymentIntent.



12563
12564
12565
12566
12567
12568
12569
12570
12571
# File 'lib/stripe/services/payment_intent_service.rb', line 12563

def apply_customer_balance(intent, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/apply_customer_balance", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#cancel(intent, params = {}, opts = {}) ⇒ Object

You can cancel a PaymentIntent object when it’s in one of these statuses: requires_payment_method, requires_capture, requires_confirmation, requires_action or, [in rare cases](docs.stripe.com/docs/payments/intents), processing.

After it’s canceled, no additional charges are made by the PaymentIntent and any operations on the PaymentIntent fail with an error. For PaymentIntents with a status of requires_capture, the remaining amount_capturable is automatically refunded.

You can’t cancel the PaymentIntent for a Checkout Session. [Expire the Checkout Session](docs.stripe.com/docs/api/checkout/sessions/expire) instead.



12578
12579
12580
12581
12582
12583
12584
12585
12586
# File 'lib/stripe/services/payment_intent_service.rb', line 12578

def cancel(intent, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/cancel", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#capture(intent, params = {}, opts = {}) ⇒ Object

Capture the funds of an existing uncaptured PaymentIntent when its status is requires_capture.

Uncaptured PaymentIntents are cancelled a set number of days (7 by default) after their creation.

Learn more about [separate authorization and capture](docs.stripe.com/docs/payments/capture-later).



12593
12594
12595
12596
12597
12598
12599
12600
12601
# File 'lib/stripe/services/payment_intent_service.rb', line 12593

def capture(intent, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/capture", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#confirm(intent, params = {}, opts = {}) ⇒ Object

Confirm that your customer intends to pay with current or provided payment method. Upon confirmation, the PaymentIntent will attempt to initiate a payment.

If the selected payment method requires additional authentication steps, the PaymentIntent will transition to the requires_action status and suggest additional actions via next_action. If payment fails, the PaymentIntent transitions to the requires_payment_method status or the canceled status if the confirmation limit is reached. If payment succeeds, the PaymentIntent will transition to the succeeded status (or requires_capture, if capture_method is set to manual).

If the confirmation_method is automatic, payment may be attempted using our [client SDKs](docs.stripe.com/docs/stripe-js/reference#stripe-handle-card-payment) and the PaymentIntent’s [client_secret](docs.stripe.com/api#payment_intent_object-client_secret). After next_actions are handled by the client, no additional confirmation is required to complete the payment.

If the confirmation_method is manual, all payment attempts must be initiated using a secret key.

If any actions are required for the payment, the PaymentIntent will return to the requires_confirmation state after those actions are completed. Your server needs to then explicitly re-confirm the PaymentIntent to initiate the next payment attempt.

There is a variable upper limit on how many times a PaymentIntent can be confirmed. After this limit is reached, any further calls to this endpoint will transition the PaymentIntent to the canceled state.



12633
12634
12635
12636
12637
12638
12639
12640
12641
# File 'lib/stripe/services/payment_intent_service.rb', line 12633

def confirm(intent, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/confirm", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#create(params = {}, opts = {}) ⇒ Object

Creates a PaymentIntent object.

After the PaymentIntent is created, attach a payment method and [confirm](docs.stripe.com/docs/api/payment_intents/confirm) to continue the payment. Learn more about <a href=“/docs/payments/payment-intents”>the available payment flows with the Payment Intents API.

When you use confirm=true during creation, it’s equivalent to creating and confirming the PaymentIntent in the same call. You can use any parameters available in the [confirm API](docs.stripe.com/docs/api/payment_intents/confirm) when you supply confirm=true.



12653
12654
12655
12656
12657
12658
12659
12660
12661
# File 'lib/stripe/services/payment_intent_service.rb', line 12653

def create(params = {}, opts = {})
  request(
    method: :post,
    path: "/v1/payment_intents",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#decrement_authorization(intent, params = {}, opts = {}) ⇒ Object

Perform a decremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object). To be eligible, the PaymentIntent’s status must be requires_capture and [decremental_authorization.status](docs.stripe.com/docs/api/charges/object#charge_object-payment_method_details-card-decremental_authorization) must be available.

Decremental authorizations decrease the authorized amount on your customer’s card to the new, lower amount provided. A single PaymentIntent can call this endpoint multiple times to further decrease the authorized amount.

After decrement, the PaymentIntent object returns with the updated [amount](docs.stripe.com/docs/api/payment_intents/object#payment_intent_object-amount). The PaymentIntent will now be capturable up to the new authorized amount.

Each PaymentIntent can have a maximum of 10 decremental or incremental authorization attempts, including declines. After it’s fully captured, a PaymentIntent can no longer be decremented.



12679
12680
12681
12682
12683
12684
12685
12686
12687
# File 'lib/stripe/services/payment_intent_service.rb', line 12679

def decrement_authorization(intent, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/decrement_authorization", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#increment_authorization(intent, params = {}, opts = {}) ⇒ Object

Perform an incremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object). To be eligible, the PaymentIntent’s status must be requires_capture and [incremental_authorization_supported](docs.stripe.com/docs/api/charges/object#charge_object-payment_method_details-card_present-incremental_authorization_supported) must be true.

Incremental authorizations attempt to increase the authorized amount on your customer’s card to the new, higher amount provided. Similar to the initial authorization, incremental authorizations can be declined. A single PaymentIntent can call this endpoint multiple times to further increase the authorized amount.

If the incremental authorization succeeds, the PaymentIntent object returns with the updated [amount](docs.stripe.com/docs/api/payment_intents/object#payment_intent_object-amount). If the incremental authorization fails, a [card_declined](docs.stripe.com/docs/error-codes#card-declined) error returns, and no other fields on the PaymentIntent or Charge update. The PaymentIntent object remains capturable for the previously authorized amount.

Each PaymentIntent can have a maximum of 10 incremental authorization attempts, including declines. After it’s captured, a PaymentIntent can no longer be incremented.

Learn more about [incremental authorizations](docs.stripe.com/docs/terminal/features/incremental-authorizations).



12713
12714
12715
12716
12717
12718
12719
12720
12721
# File 'lib/stripe/services/payment_intent_service.rb', line 12713

def increment_authorization(intent, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/increment_authorization", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#list(params = {}, opts = {}) ⇒ Object

Returns a list of PaymentIntents.



12724
12725
12726
12727
12728
12729
12730
12731
12732
# File 'lib/stripe/services/payment_intent_service.rb', line 12724

def list(params = {}, opts = {})
  request(
    method: :get,
    path: "/v1/payment_intents",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#retrieve(intent, params = {}, opts = {}) ⇒ Object

Retrieves the details of a PaymentIntent that has previously been created.

You can retrieve a PaymentIntent client-side using a publishable key when the client_secret is in the query string.

If you retrieve a PaymentIntent with a publishable key, it only returns a subset of properties. Refer to the [payment intent](docs.stripe.com/api#payment_intent_object) object reference for more details.



12739
12740
12741
12742
12743
12744
12745
12746
12747
# File 'lib/stripe/services/payment_intent_service.rb', line 12739

def retrieve(intent, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v1/payment_intents/%<intent>s", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#search(params = {}, opts = {}) ⇒ Object

Search for PaymentIntents you’ve previously created using Stripe’s [Search Query Language](docs.stripe.com/docs/search#search-query-language). Don’t use search in read-after-write flows where strict consistency is necessary. Under normal operating conditions, data is searchable in less than a minute. Occasionally, propagation of new or updated data can be up to an hour behind during outages. Search functionality is not available to merchants in India.



12753
12754
12755
12756
12757
12758
12759
12760
12761
# File 'lib/stripe/services/payment_intent_service.rb', line 12753

def search(params = {}, opts = {})
  request(
    method: :get,
    path: "/v1/payment_intents/search",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#trigger_action(intent, params = {}, opts = {}) ⇒ Object

Trigger an external action on a PaymentIntent.



12764
12765
12766
12767
12768
12769
12770
12771
12772
# File 'lib/stripe/services/payment_intent_service.rb', line 12764

def trigger_action(intent, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/test/payment_intents/%<intent>s/trigger_action", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#update(intent, params = {}, opts = {}) ⇒ Object

Updates properties on a PaymentIntent object without confirming.

Depending on which properties you update, you might need to confirm the PaymentIntent again. For example, updating the payment_method always requires you to confirm the PaymentIntent again. If you prefer to update and confirm at the same time, we recommend updating properties through the [confirm API](docs.stripe.com/docs/api/payment_intents/confirm) instead.



12781
12782
12783
12784
12785
12786
12787
12788
12789
# File 'lib/stripe/services/payment_intent_service.rb', line 12781

def update(intent, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#verify_microdeposits(intent, params = {}, opts = {}) ⇒ Object

Verifies microdeposits on a PaymentIntent object.



12792
12793
12794
12795
12796
12797
12798
12799
12800
# File 'lib/stripe/services/payment_intent_service.rb', line 12792

def verify_microdeposits(intent, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end