Class: Stripe::PaymentIntentService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::PaymentIntentService
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: ApplyCustomerBalanceParams, CancelParams, CaptureParams, ConfirmParams, CreateParams, DecrementAuthorizationParams, IncrementAuthorizationParams, ListParams, RetrieveParams, SearchParams, TriggerActionParams, UpdateParams, VerifyMicrodepositsParams
Instance Attribute Summary collapse
-
#amount_details_line_items ⇒ Object
readonly
Returns the value of attribute amount_details_line_items.
Instance Method Summary collapse
-
#apply_customer_balance(intent, params = {}, opts = {}) ⇒ Object
Manually reconcile the remaining amount for a customer_balance PaymentIntent.
-
#cancel(intent, params = {}, opts = {}) ⇒ Object
You can cancel a PaymentIntent object when it’s in one of these statuses: requires_payment_method, requires_capture, requires_confirmation, requires_action or, [in rare cases](docs.stripe.com/docs/payments/intents), processing.
-
#capture(intent, params = {}, opts = {}) ⇒ Object
Capture the funds of an existing uncaptured PaymentIntent when its status is requires_capture.
-
#confirm(intent, params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to pay with current or provided payment method.
-
#create(params = {}, opts = {}) ⇒ Object
Creates a PaymentIntent object.
-
#decrement_authorization(intent, params = {}, opts = {}) ⇒ Object
Perform a decremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object).
-
#increment_authorization(intent, params = {}, opts = {}) ⇒ Object
Perform an incremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object).
-
#initialize(requestor) ⇒ PaymentIntentService
constructor
A new instance of PaymentIntentService.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of PaymentIntents.
-
#retrieve(intent, params = {}, opts = {}) ⇒ Object
Retrieves the details of a PaymentIntent that has previously been created.
-
#search(params = {}, opts = {}) ⇒ Object
Search for PaymentIntents you’ve previously created using Stripe’s [Search Query Language](docs.stripe.com/docs/search#search-query-language).
-
#trigger_action(intent, params = {}, opts = {}) ⇒ Object
Trigger an external action on a PaymentIntent.
-
#update(intent, params = {}, opts = {}) ⇒ Object
Updates properties on a PaymentIntent object without confirming.
-
#verify_microdeposits(intent, params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a PaymentIntent object.
Methods inherited from StripeService
Constructor Details
#initialize(requestor) ⇒ PaymentIntentService
Returns a new instance of PaymentIntentService.
8 9 10 11 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8 def initialize(requestor) super @amount_details_line_items = Stripe::PaymentIntentAmountDetailsLineItemService.new(@requestor) end |
Instance Attribute Details
#amount_details_line_items ⇒ Object (readonly)
Returns the value of attribute amount_details_line_items.
6 7 8 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6 def amount_details_line_items @amount_details_line_items end |
Instance Method Details
#apply_customer_balance(intent, params = {}, opts = {}) ⇒ Object
Manually reconcile the remaining amount for a customer_balance PaymentIntent.
11456 11457 11458 11459 11460 11461 11462 11463 11464 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11456 def apply_customer_balance(intent, params = {}, opts = {}) request( method: :post, path: format("/v1/payment_intents/%<intent>s/apply_customer_balance", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#cancel(intent, params = {}, opts = {}) ⇒ Object
You can cancel a PaymentIntent object when it’s in one of these statuses: requires_payment_method, requires_capture, requires_confirmation, requires_action or, [in rare cases](docs.stripe.com/docs/payments/intents), processing.
After it’s canceled, no additional charges are made by the PaymentIntent and any operations on the PaymentIntent fail with an error. For PaymentIntents with a status of requires_capture, the remaining amount_capturable is automatically refunded.
You can’t cancel the PaymentIntent for a Checkout Session. [Expire the Checkout Session](docs.stripe.com/docs/api/checkout/sessions/expire) instead.
11471 11472 11473 11474 11475 11476 11477 11478 11479 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11471 def cancel(intent, params = {}, opts = {}) request( method: :post, path: format("/v1/payment_intents/%<intent>s/cancel", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#capture(intent, params = {}, opts = {}) ⇒ Object
Capture the funds of an existing uncaptured PaymentIntent when its status is requires_capture.
Uncaptured PaymentIntents are cancelled a set number of days (7 by default) after their creation.
Learn more about [separate authorization and capture](docs.stripe.com/docs/payments/capture-later).
11486 11487 11488 11489 11490 11491 11492 11493 11494 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11486 def capture(intent, params = {}, opts = {}) request( method: :post, path: format("/v1/payment_intents/%<intent>s/capture", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#confirm(intent, params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to pay with current or provided payment method. Upon confirmation, the PaymentIntent will attempt to initiate a payment. If the selected payment method requires additional authentication steps, the PaymentIntent will transition to the requires_action status and suggest additional actions via next_action. If payment fails, the PaymentIntent transitions to the requires_payment_method status or the canceled status if the confirmation limit is reached. If payment succeeds, the PaymentIntent will transition to the succeeded status (or requires_capture, if capture_method is set to manual). If the confirmation_method is automatic, payment may be attempted using our [client SDKs](docs.stripe.com/docs/stripe-js/reference#stripe-handle-card-payment) and the PaymentIntent’s [client_secret](docs.stripe.com/api#payment_intent_object-client_secret). After next_actions are handled by the client, no additional confirmation is required to complete the payment. If the confirmation_method is manual, all payment attempts must be initiated using a secret key. If any actions are required for the payment, the PaymentIntent will return to the requires_confirmation state after those actions are completed. Your server needs to then explicitly re-confirm the PaymentIntent to initiate the next payment attempt. There is a variable upper limit on how many times a PaymentIntent can be confirmed. After this limit is reached, any further calls to this endpoint will transition the PaymentIntent to the canceled state.
11521 11522 11523 11524 11525 11526 11527 11528 11529 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11521 def confirm(intent, params = {}, opts = {}) request( method: :post, path: format("/v1/payment_intents/%<intent>s/confirm", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#create(params = {}, opts = {}) ⇒ Object
Creates a PaymentIntent object.
After the PaymentIntent is created, attach a payment method and [confirm](docs.stripe.com/docs/api/payment_intents/confirm) to continue the payment. Learn more about <a href=“/docs/payments/payment-intents”>the available payment flows with the Payment Intents API.
When you use confirm=true during creation, it’s equivalent to creating and confirming the PaymentIntent in the same call. You can use any parameters available in the [confirm API](docs.stripe.com/docs/api/payment_intents/confirm) when you supply confirm=true.
11541 11542 11543 11544 11545 11546 11547 11548 11549 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11541 def create(params = {}, opts = {}) request( method: :post, path: "/v1/payment_intents", params: params, opts: opts, base_address: :api ) end |
#decrement_authorization(intent, params = {}, opts = {}) ⇒ Object
Perform a decremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object). To be eligible, the PaymentIntent’s status must be requires_capture and [decremental_authorization.status](docs.stripe.com/docs/api/charges/object#charge_object-payment_method_details-card-decremental_authorization) must be available.
Decremental authorizations decrease the authorized amount on your customer’s card to the new, lower amount provided. A single PaymentIntent can call this endpoint multiple times to further decrease the authorized amount.
After decrement, the PaymentIntent object returns with the updated [amount](docs.stripe.com/docs/api/payment_intents/object#payment_intent_object-amount). The PaymentIntent will now be capturable up to the new authorized amount.
Each PaymentIntent can have a maximum of 10 decremental or incremental authorization attempts, including declines. After it’s fully captured, a PaymentIntent can no longer be decremented.
11567 11568 11569 11570 11571 11572 11573 11574 11575 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11567 def (intent, params = {}, opts = {}) request( method: :post, path: format("/v1/payment_intents/%<intent>s/decrement_authorization", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#increment_authorization(intent, params = {}, opts = {}) ⇒ Object
Perform an incremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object). To be eligible, the PaymentIntent’s status must be requires_capture and [incremental_authorization_supported](docs.stripe.com/docs/api/charges/object#charge_object-payment_method_details-card_present-incremental_authorization_supported) must be true.
Incremental authorizations attempt to increase the authorized amount on your customer’s card to the new, higher amount provided. Similar to the initial authorization, incremental authorizations can be declined. A single PaymentIntent can call this endpoint multiple times to further increase the authorized amount.
If the incremental authorization succeeds, the PaymentIntent object returns with the updated [amount](docs.stripe.com/docs/api/payment_intents/object#payment_intent_object-amount). If the incremental authorization fails, a [card_declined](docs.stripe.com/docs/error-codes#card-declined) error returns, and no other fields on the PaymentIntent or Charge update. The PaymentIntent object remains capturable for the previously authorized amount.
Each PaymentIntent can have a maximum of 10 incremental authorization attempts, including declines. After it’s captured, a PaymentIntent can no longer be incremented.
Learn more about [incremental authorizations](docs.stripe.com/docs/terminal/features/incremental-authorizations).
11601 11602 11603 11604 11605 11606 11607 11608 11609 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11601 def (intent, params = {}, opts = {}) request( method: :post, path: format("/v1/payment_intents/%<intent>s/increment_authorization", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of PaymentIntents.
11612 11613 11614 11615 11616 11617 11618 11619 11620 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11612 def list(params = {}, opts = {}) request( method: :get, path: "/v1/payment_intents", params: params, opts: opts, base_address: :api ) end |
#retrieve(intent, params = {}, opts = {}) ⇒ Object
Retrieves the details of a PaymentIntent that has previously been created.
You can retrieve a PaymentIntent client-side using a publishable key when the client_secret is in the query string.
If you retrieve a PaymentIntent with a publishable key, it only returns a subset of properties. Refer to the [payment intent](docs.stripe.com/api#payment_intent_object) object reference for more details.
11627 11628 11629 11630 11631 11632 11633 11634 11635 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11627 def retrieve(intent, params = {}, opts = {}) request( method: :get, path: format("/v1/payment_intents/%<intent>s", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#search(params = {}, opts = {}) ⇒ Object
Search for PaymentIntents you’ve previously created using Stripe’s [Search Query Language](docs.stripe.com/docs/search#search-query-language). Don’t use search in read-after-write flows where strict consistency is necessary. Under normal operating conditions, data is searchable in less than a minute. Occasionally, propagation of new or updated data can be up to an hour behind during outages. Search functionality is not available to merchants in India.
11641 11642 11643 11644 11645 11646 11647 11648 11649 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11641 def search(params = {}, opts = {}) request( method: :get, path: "/v1/payment_intents/search", params: params, opts: opts, base_address: :api ) end |
#trigger_action(intent, params = {}, opts = {}) ⇒ Object
Trigger an external action on a PaymentIntent.
11652 11653 11654 11655 11656 11657 11658 11659 11660 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11652 def trigger_action(intent, params = {}, opts = {}) request( method: :post, path: format("/v1/test/payment_intents/%<intent>s/trigger_action", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#update(intent, params = {}, opts = {}) ⇒ Object
Updates properties on a PaymentIntent object without confirming.
Depending on which properties you update, you might need to confirm the PaymentIntent again. For example, updating the payment_method always requires you to confirm the PaymentIntent again. If you prefer to update and confirm at the same time, we recommend updating properties through the [confirm API](docs.stripe.com/docs/api/payment_intents/confirm) instead.
11669 11670 11671 11672 11673 11674 11675 11676 11677 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11669 def update(intent, params = {}, opts = {}) request( method: :post, path: format("/v1/payment_intents/%<intent>s", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#verify_microdeposits(intent, params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a PaymentIntent object.
11680 11681 11682 11683 11684 11685 11686 11687 11688 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11680 def verify_microdeposits(intent, params = {}, opts = {}) request( method: :post, path: format("/v1/payment_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |