Class: Stripe::PaymentIntentService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::PaymentIntentService
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: ApplyCustomerBalanceParams, CancelParams, CaptureParams, ConfirmParams, CreateParams, IncrementAuthorizationParams, ListParams, RetrieveParams, SearchParams, UpdateParams, VerifyMicrodepositsParams
Instance Method Summary collapse
-
#apply_customer_balance(intent, params = {}, opts = {}) ⇒ Object
Manually reconcile the remaining amount for a customer_balance PaymentIntent.
-
#cancel(intent, params = {}, opts = {}) ⇒ Object
You can cancel a PaymentIntent object when it’s in one of these statuses: requires_payment_method, requires_capture, requires_confirmation, requires_action or, [in rare cases](docs.stripe.com/docs/payments/intents), processing.
-
#capture(intent, params = {}, opts = {}) ⇒ Object
Capture the funds of an existing uncaptured PaymentIntent when its status is requires_capture.
-
#confirm(intent, params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to pay with current or provided payment method.
-
#create(params = {}, opts = {}) ⇒ Object
Creates a PaymentIntent object.
-
#increment_authorization(intent, params = {}, opts = {}) ⇒ Object
Perform an incremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object).
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of PaymentIntents.
-
#retrieve(intent, params = {}, opts = {}) ⇒ Object
Retrieves the details of a PaymentIntent that has previously been created.
-
#search(params = {}, opts = {}) ⇒ Object
Search for PaymentIntents you’ve previously created using Stripe’s [Search Query Language](docs.stripe.com/docs/search#search-query-language).
-
#update(intent, params = {}, opts = {}) ⇒ Object
Updates properties on a PaymentIntent object without confirming.
-
#verify_microdeposits(intent, params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a PaymentIntent object.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#apply_customer_balance(intent, params = {}, opts = {}) ⇒ Object
Manually reconcile the remaining amount for a customer_balance PaymentIntent.
7005 7006 7007 7008 7009 7010 7011 7012 7013 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7005 def apply_customer_balance(intent, params = {}, opts = {}) request( method: :post, path: format("/v1/payment_intents/%<intent>s/apply_customer_balance", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#cancel(intent, params = {}, opts = {}) ⇒ Object
You can cancel a PaymentIntent object when it’s in one of these statuses: requires_payment_method, requires_capture, requires_confirmation, requires_action or, [in rare cases](docs.stripe.com/docs/payments/intents), processing.
After it’s canceled, no additional charges are made by the PaymentIntent and any operations on the PaymentIntent fail with an error. For PaymentIntents with a status of requires_capture, the remaining amount_capturable is automatically refunded.
You can’t cancel the PaymentIntent for a Checkout Session. [Expire the Checkout Session](docs.stripe.com/docs/api/checkout/sessions/expire) instead.
7020 7021 7022 7023 7024 7025 7026 7027 7028 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7020 def cancel(intent, params = {}, opts = {}) request( method: :post, path: format("/v1/payment_intents/%<intent>s/cancel", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#capture(intent, params = {}, opts = {}) ⇒ Object
Capture the funds of an existing uncaptured PaymentIntent when its status is requires_capture.
Uncaptured PaymentIntents are cancelled a set number of days (7 by default) after their creation.
Learn more about [separate authorization and capture](docs.stripe.com/docs/payments/capture-later).
7035 7036 7037 7038 7039 7040 7041 7042 7043 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7035 def capture(intent, params = {}, opts = {}) request( method: :post, path: format("/v1/payment_intents/%<intent>s/capture", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#confirm(intent, params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to pay with current or provided payment method. Upon confirmation, the PaymentIntent will attempt to initiate a payment. If the selected payment method requires additional authentication steps, the PaymentIntent will transition to the requires_action status and suggest additional actions via next_action. If payment fails, the PaymentIntent transitions to the requires_payment_method status or the canceled status if the confirmation limit is reached. If payment succeeds, the PaymentIntent will transition to the succeeded status (or requires_capture, if capture_method is set to manual). If the confirmation_method is automatic, payment may be attempted using our [client SDKs](docs.stripe.com/docs/stripe-js/reference#stripe-handle-card-payment) and the PaymentIntent’s [client_secret](docs.stripe.com/api#payment_intent_object-client_secret). After next_actions are handled by the client, no additional confirmation is required to complete the payment. If the confirmation_method is manual, all payment attempts must be initiated using a secret key. If any actions are required for the payment, the PaymentIntent will return to the requires_confirmation state after those actions are completed. Your server needs to then explicitly re-confirm the PaymentIntent to initiate the next payment attempt. There is a variable upper limit on how many times a PaymentIntent can be confirmed. After this limit is reached, any further calls to this endpoint will transition the PaymentIntent to the canceled state.
7070 7071 7072 7073 7074 7075 7076 7077 7078 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7070 def confirm(intent, params = {}, opts = {}) request( method: :post, path: format("/v1/payment_intents/%<intent>s/confirm", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#create(params = {}, opts = {}) ⇒ Object
Creates a PaymentIntent object.
After the PaymentIntent is created, attach a payment method and [confirm](docs.stripe.com/docs/api/payment_intents/confirm) to continue the payment. Learn more about <a href=“/docs/payments/payment-intents”>the available payment flows with the Payment Intents API.
When you use confirm=true during creation, it’s equivalent to creating and confirming the PaymentIntent in the same call. You can use any parameters available in the [confirm API](docs.stripe.com/docs/api/payment_intents/confirm) when you supply confirm=true.
7090 7091 7092 7093 7094 7095 7096 7097 7098 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7090 def create(params = {}, opts = {}) request( method: :post, path: "/v1/payment_intents", params: params, opts: opts, base_address: :api ) end |
#increment_authorization(intent, params = {}, opts = {}) ⇒ Object
Perform an incremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object). To be eligible, the PaymentIntent’s status must be requires_capture and [incremental_authorization_supported](docs.stripe.com/docs/api/charges/object#charge_object-payment_method_details-card_present-incremental_authorization_supported) must be true.
Incremental authorizations attempt to increase the authorized amount on your customer’s card to the new, higher amount provided. Similar to the initial authorization, incremental authorizations can be declined. A single PaymentIntent can call this endpoint multiple times to further increase the authorized amount.
If the incremental authorization succeeds, the PaymentIntent object returns with the updated [amount](docs.stripe.com/docs/api/payment_intents/object#payment_intent_object-amount). If the incremental authorization fails, a [card_declined](docs.stripe.com/docs/error-codes#card-declined) error returns, and no other fields on the PaymentIntent or Charge update. The PaymentIntent object remains capturable for the previously authorized amount.
Each PaymentIntent can have a maximum of 10 incremental authorization attempts, including declines. After it’s captured, a PaymentIntent can no longer be incremented.
Learn more about [incremental authorizations](docs.stripe.com/docs/terminal/features/incremental-authorizations).
7124 7125 7126 7127 7128 7129 7130 7131 7132 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7124 def (intent, params = {}, opts = {}) request( method: :post, path: format("/v1/payment_intents/%<intent>s/increment_authorization", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of PaymentIntents.
7135 7136 7137 7138 7139 7140 7141 7142 7143 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7135 def list(params = {}, opts = {}) request( method: :get, path: "/v1/payment_intents", params: params, opts: opts, base_address: :api ) end |
#retrieve(intent, params = {}, opts = {}) ⇒ Object
Retrieves the details of a PaymentIntent that has previously been created.
You can retrieve a PaymentIntent client-side using a publishable key when the client_secret is in the query string.
If you retrieve a PaymentIntent with a publishable key, it only returns a subset of properties. Refer to the [payment intent](docs.stripe.com/api#payment_intent_object) object reference for more details.
7150 7151 7152 7153 7154 7155 7156 7157 7158 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7150 def retrieve(intent, params = {}, opts = {}) request( method: :get, path: format("/v1/payment_intents/%<intent>s", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#search(params = {}, opts = {}) ⇒ Object
Search for PaymentIntents you’ve previously created using Stripe’s [Search Query Language](docs.stripe.com/docs/search#search-query-language). Don’t use search in read-after-write flows where strict consistency is necessary. Under normal operating conditions, data is searchable in less than a minute. Occasionally, propagation of new or updated data can be up to an hour behind during outages. Search functionality is not available to merchants in India.
7164 7165 7166 7167 7168 7169 7170 7171 7172 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7164 def search(params = {}, opts = {}) request( method: :get, path: "/v1/payment_intents/search", params: params, opts: opts, base_address: :api ) end |
#update(intent, params = {}, opts = {}) ⇒ Object
Updates properties on a PaymentIntent object without confirming.
Depending on which properties you update, you might need to confirm the PaymentIntent again. For example, updating the payment_method always requires you to confirm the PaymentIntent again. If you prefer to update and confirm at the same time, we recommend updating properties through the [confirm API](docs.stripe.com/docs/api/payment_intents/confirm) instead.
7181 7182 7183 7184 7185 7186 7187 7188 7189 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7181 def update(intent, params = {}, opts = {}) request( method: :post, path: format("/v1/payment_intents/%<intent>s", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#verify_microdeposits(intent, params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a PaymentIntent object.
7192 7193 7194 7195 7196 7197 7198 7199 7200 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7192 def verify_microdeposits(intent, params = {}, opts = {}) request( method: :post, path: format("/v1/payment_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |