Class: Stripe::PaymentIntentService::ApplyCustomerBalanceParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ApplyCustomerBalanceParams
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount that you intend to apply to this PaymentIntent from the customer’s cash balance.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, expand: nil) ⇒ ApplyCustomerBalanceParams
constructor
A new instance of ApplyCustomerBalanceParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, expand: nil) ⇒ ApplyCustomerBalanceParams
Returns a new instance of ApplyCustomerBalanceParams.
7245 7246 7247 7248 7249 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7245 def initialize(amount: nil, currency: nil, expand: nil) @amount = amount @currency = currency @expand = end |
Instance Attribute Details
#amount ⇒ Object
Amount that you intend to apply to this PaymentIntent from the customer’s cash balance. If the PaymentIntent was created by an Invoice, the full amount of the PaymentIntent is applied regardless of this parameter.
A positive integer representing how much to charge in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) (for example, 100 cents to charge 1 USD or 100 to charge 100 JPY, a zero-decimal currency). The maximum amount is the amount of the PaymentIntent.
When you omit the amount, it defaults to the remaining amount requested on the PaymentIntent.
7239 7240 7241 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7239 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
7241 7242 7243 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7241 def currency @currency end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
7243 7244 7245 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7243 def @expand end |