Class: Stripe::PaymentIntentService::ApplyCustomerBalanceParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ApplyCustomerBalanceParams
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount that you intend to apply to this PaymentIntent from the customer’s cash balance.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, expand: nil) ⇒ ApplyCustomerBalanceParams
constructor
A new instance of ApplyCustomerBalanceParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, expand: nil) ⇒ ApplyCustomerBalanceParams
Returns a new instance of ApplyCustomerBalanceParams.
4641 4642 4643 4644 4645 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4641 def initialize(amount: nil, currency: nil, expand: nil) @amount = amount @currency = currency @expand = end |
Instance Attribute Details
#amount ⇒ Object
Amount that you intend to apply to this PaymentIntent from the customer’s cash balance. If the PaymentIntent was created by an Invoice, the full amount of the PaymentIntent is applied regardless of this parameter.
A positive integer representing how much to charge in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) (for example, 100 cents to charge 1 USD or 100 to charge 100 JPY, a zero-decimal currency). The maximum amount is the amount of the PaymentIntent.
When you omit the amount, it defaults to the remaining amount requested on the PaymentIntent.
4635 4636 4637 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4635 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
4637 4638 4639 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4637 def currency @currency end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
4639 4640 4641 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4639 def @expand end |