Class: Stripe::PaymentIntentService::CaptureParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_to_capture: nil, application_fee_amount: nil, expand: nil, final_capture: nil, metadata: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ CaptureParams

Returns a new instance of CaptureParams.



4913
4914
4915
4916
4917
4918
4919
4920
4921
4922
4923
4924
4925
4926
4927
4928
4929
4930
4931
# File 'lib/stripe/services/payment_intent_service.rb', line 4913

def initialize(
  amount_to_capture: nil,
  application_fee_amount: nil,
  expand: nil,
  final_capture: nil,
  metadata: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil
)
  @amount_to_capture = amount_to_capture
  @application_fee_amount = application_fee_amount
  @expand = expand
  @final_capture = final_capture
  @metadata = 
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
end

Instance Attribute Details

#amount_to_captureObject

The amount to capture from the PaymentIntent, which must be less than or equal to the original amount. Defaults to the full ‘amount_capturable` if it’s not provided.



4894
4895
4896
# File 'lib/stripe/services/payment_intent_service.rb', line 4894

def amount_to_capture
  @amount_to_capture
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



4896
4897
4898
# File 'lib/stripe/services/payment_intent_service.rb', line 4896

def application_fee_amount
  @application_fee_amount
end

#expandObject

Specifies which fields in the response should be expanded.



4898
4899
4900
# File 'lib/stripe/services/payment_intent_service.rb', line 4898

def expand
  @expand
end

#final_captureObject

Defaults to ‘true`. When capturing a PaymentIntent, setting `final_capture` to `false` notifies Stripe to not release the remaining uncaptured funds to make sure that they’re captured in future requests. You can only use this setting when [multicapture](stripe.com/docs/payments/multicapture) is available for PaymentIntents.



4900
4901
4902
# File 'lib/stripe/services/payment_intent_service.rb', line 4900

def final_capture
  @final_capture
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



4902
4903
4904
# File 'lib/stripe/services/payment_intent_service.rb', line 4902

def 
  @metadata
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).

Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.



4906
4907
4908
# File 'lib/stripe/services/payment_intent_service.rb', line 4906

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



4908
4909
4910
# File 'lib/stripe/services/payment_intent_service.rb', line 4908

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

The parameters that you can use to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



4911
4912
4913
# File 'lib/stripe/services/payment_intent_service.rb', line 4911

def transfer_data
  @transfer_data
end