Class: Stripe::PaymentIntentService::CaptureParams::AmountDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: LineItem, Shipping, Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails

Returns a new instance of AmountDetails.



7724
7725
7726
7727
7728
7729
# File 'lib/stripe/services/payment_intent_service.rb', line 7724

def initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil)
  @discount_amount = discount_amount
  @line_items = line_items
  @shipping = shipping
  @tax = tax
end

Instance Attribute Details

#discount_amountObject

The amount an item was discounted for.



7716
7717
7718
# File 'lib/stripe/services/payment_intent_service.rb', line 7716

def discount_amount
  @discount_amount
end

#line_itemsObject

A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.



7718
7719
7720
# File 'lib/stripe/services/payment_intent_service.rb', line 7718

def line_items
  @line_items
end

#shippingObject

Contains information about the shipping portion of the amount.



7720
7721
7722
# File 'lib/stripe/services/payment_intent_service.rb', line 7720

def shipping
  @shipping
end

#taxObject

Contains information about the tax portion of the amount.



7722
7723
7724
# File 'lib/stripe/services/payment_intent_service.rb', line 7722

def tax
  @tax
end