Class: Stripe::PaymentIntentService::CaptureParams::AmountDetails::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::AmountDetails::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The amount an item was discounted for.
-
#payment_method_options ⇒ Object
Payment method-specific information for line items.
-
#product_code ⇒ Object
Unique identifier of the product.
-
#product_name ⇒ Object
Name of the product.
-
#quantity ⇒ Object
Number of items of the product.
-
#tax ⇒ Object
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
Cost of the product.
-
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
Returns a new instance of LineItem.
7671 7672 7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 7689 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7671 def initialize( discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil ) @discount_amount = discount_amount @payment_method_options = @product_code = product_code @product_name = product_name @quantity = quantity @tax = tax @unit_cost = unit_cost @unit_of_measure = unit_of_measure end |
Instance Attribute Details
#discount_amount ⇒ Object
The amount an item was discounted for. Positive integer.
7655 7656 7657 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7655 def discount_amount @discount_amount end |
#payment_method_options ⇒ Object
Payment method-specific information for line items.
7657 7658 7659 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7657 def @payment_method_options end |
#product_code ⇒ Object
Unique identifier of the product. At most 12 characters long.
7659 7660 7661 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7659 def product_code @product_code end |
#product_name ⇒ Object
Name of the product. At most 100 characters long.
7661 7662 7663 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7661 def product_name @product_name end |
#quantity ⇒ Object
Number of items of the product. Positive integer.
7663 7664 7665 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7663 def quantity @quantity end |
#tax ⇒ Object
Contains information about the tax on the item.
7665 7666 7667 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7665 def tax @tax end |
#unit_cost ⇒ Object
Cost of the product. Non-negative integer.
7667 7668 7669 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7667 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
7669 7670 7671 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7669 def unit_of_measure @unit_of_measure end |