Class: Stripe::PaymentIntentService::CaptureParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
constructor
A new instance of Paypal.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
Returns a new instance of Paypal.
7623 7624 7625 7626 7627 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7623 def initialize(category: nil, description: nil, sold_by: nil) @category = category @description = description @sold_by = sold_by end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
7617 7618 7619 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7617 def category @category end |
#description ⇒ Object
Description of the line item.
7619 7620 7621 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7619 def description @description end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
7621 7622 7623 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7621 def sold_by @sold_by end |