Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8443 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
8429 8430 8431 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8429 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
8431 8432 8433 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8431 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
8433 8434 8435 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8433 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
8435 8436 8437 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8435 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
8437 8438 8439 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8437 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
8439 8440 8441 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8439 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
8441 8442 8443 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8441 def subscription @subscription end |