Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7976 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
7962 7963 7964 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7962 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
7964 7965 7966 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7964 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
7966 7967 7968 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7966 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
7968 7969 7970 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7968 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
7970 7971 7972 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7970 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
7972 7973 7974 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7972 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
7974 7975 7976 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7974 def subscription @subscription end |