Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



7772
7773
7774
7775
7776
7777
7778
7779
7780
7781
7782
7783
7784
7785
7786
7787
7788
# File 'lib/stripe/services/payment_intent_service.rb', line 7772

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



7758
7759
7760
# File 'lib/stripe/services/payment_intent_service.rb', line 7758

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



7760
7761
7762
# File 'lib/stripe/services/payment_intent_service.rb', line 7760

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



7762
7763
7764
# File 'lib/stripe/services/payment_intent_service.rb', line 7762

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



7764
7765
7766
# File 'lib/stripe/services/payment_intent_service.rb', line 7764

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



7766
7767
7768
# File 'lib/stripe/services/payment_intent_service.rb', line 7766

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



7768
7769
7770
# File 'lib/stripe/services/payment_intent_service.rb', line 7768

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



7770
7771
7772
# File 'lib/stripe/services/payment_intent_service.rb', line 7770

def subscription
  @subscription
end