Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
7772
7773
7774
7775
7776
7777
# File 'lib/stripe/services/payment_intent_service.rb', line 7761

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



7747
7748
7749
# File 'lib/stripe/services/payment_intent_service.rb', line 7747

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



7749
7750
7751
# File 'lib/stripe/services/payment_intent_service.rb', line 7749

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



7751
7752
7753
# File 'lib/stripe/services/payment_intent_service.rb', line 7751

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



7753
7754
7755
# File 'lib/stripe/services/payment_intent_service.rb', line 7753

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



7755
7756
7757
# File 'lib/stripe/services/payment_intent_service.rb', line 7755

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



7757
7758
7759
# File 'lib/stripe/services/payment_intent_service.rb', line 7757

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



7759
7760
7761
# File 'lib/stripe/services/payment_intent_service.rb', line 7759

def subscription
  @subscription
end