Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental

Returns a new instance of CarRental.



7931
7932
7933
7934
7935
7936
7937
7938
7939
7940
7941
7942
7943
7944
7945
7946
7947
7948
7949
7950
7951
7952
7953
7954
7955
7956
7957
7958
7959
7960
7961
7962
7963
7964
7965
7966
7967
7968
7969
7970
7971
7972
7973
7974
7975
7976
7977
7978
7979
7980
7981
# File 'lib/stripe/services/payment_intent_service.rb', line 7931

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  distance: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  pickup_location_name: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  return_location_name: nil,
  tax_exempt: nil,
  vehicle_identification_number: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @distance = distance
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @pickup_location_name = pickup_location_name
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @return_location_name = return_location_name
  @tax_exempt = tax_exempt
  @vehicle_identification_number = vehicle_identification_number
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



7883
7884
7885
# File 'lib/stripe/services/payment_intent_service.rb', line 7883

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



7885
7886
7887
# File 'lib/stripe/services/payment_intent_service.rb', line 7885

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



7887
7888
7889
# File 'lib/stripe/services/payment_intent_service.rb', line 7887

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



7889
7890
7891
# File 'lib/stripe/services/payment_intent_service.rb', line 7889

def car_make
  @car_make
end

#car_modelObject

Model of the car.



7891
7892
7893
# File 'lib/stripe/services/payment_intent_service.rb', line 7891

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



7893
7894
7895
# File 'lib/stripe/services/payment_intent_service.rb', line 7893

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



7895
7896
7897
# File 'lib/stripe/services/payment_intent_service.rb', line 7895

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



7897
7898
7899
# File 'lib/stripe/services/payment_intent_service.rb', line 7897

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



7899
7900
7901
# File 'lib/stripe/services/payment_intent_service.rb', line 7899

def delivery
  @delivery
end

#distanceObject

The details of the distance traveled during the rental period.



7901
7902
7903
# File 'lib/stripe/services/payment_intent_service.rb', line 7901

def distance
  @distance
end

#driversObject

The details of the passengers in the travel reservation



7903
7904
7905
# File 'lib/stripe/services/payment_intent_service.rb', line 7903

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



7905
7906
7907
# File 'lib/stripe/services/payment_intent_service.rb', line 7905

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



7907
7908
7909
# File 'lib/stripe/services/payment_intent_service.rb', line 7907

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



7909
7910
7911
# File 'lib/stripe/services/payment_intent_service.rb', line 7909

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



7911
7912
7913
# File 'lib/stripe/services/payment_intent_service.rb', line 7911

def pickup_at
  @pickup_at
end

#pickup_location_nameObject

Name of the pickup location.



7913
7914
7915
# File 'lib/stripe/services/payment_intent_service.rb', line 7913

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject

Rental rate.



7915
7916
7917
# File 'lib/stripe/services/payment_intent_service.rb', line 7915

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



7917
7918
7919
# File 'lib/stripe/services/payment_intent_service.rb', line 7917

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



7919
7920
7921
# File 'lib/stripe/services/payment_intent_service.rb', line 7919

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



7921
7922
7923
# File 'lib/stripe/services/payment_intent_service.rb', line 7921

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



7923
7924
7925
# File 'lib/stripe/services/payment_intent_service.rb', line 7923

def return_at
  @return_at
end

#return_location_nameObject

Name of the return location.



7925
7926
7927
# File 'lib/stripe/services/payment_intent_service.rb', line 7925

def return_location_name
  @return_location_name
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



7927
7928
7929
# File 'lib/stripe/services/payment_intent_service.rb', line 7927

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject

The vehicle identification number.



7929
7930
7931
# File 'lib/stripe/services/payment_intent_service.rb', line 7929

def vehicle_identification_number
  @vehicle_identification_number
end