Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#distance ⇒ Object
The details of the distance traveled during the rental period.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#pickup_location_name ⇒ Object
Name of the pickup location.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#return_location_name ⇒ Object
Name of the return location.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
The vehicle identification number.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental
Returns a new instance of CarRental.
7464 7465 7466 7467 7468 7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7464 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @distance = distance @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @pickup_location_name = pickup_location_name @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @return_location_name = return_location_name @tax_exempt = tax_exempt @vehicle_identification_number = vehicle_identification_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
7416 7417 7418 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7416 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
7418 7419 7420 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7418 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
7420 7421 7422 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7420 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
7422 7423 7424 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7422 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
7424 7425 7426 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7424 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
7426 7427 7428 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7426 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
7428 7429 7430 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7428 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
7430 7431 7432 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7430 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
7432 7433 7434 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7432 def delivery @delivery end |
#distance ⇒ Object
The details of the distance traveled during the rental period.
7434 7435 7436 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7434 def distance @distance end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
7436 7437 7438 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7436 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
7438 7439 7440 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7438 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
7440 7441 7442 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7440 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
7442 7443 7444 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7442 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
7444 7445 7446 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7444 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object
Name of the pickup location.
7446 7447 7448 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7446 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object
Rental rate.
7448 7449 7450 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7448 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
7450 7451 7452 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7450 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
7452 7453 7454 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7452 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
7454 7455 7456 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7454 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
7456 7457 7458 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7456 def return_at @return_at end |
#return_location_name ⇒ Object
Name of the return location.
7458 7459 7460 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7458 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
7460 7461 7462 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7460 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object
The vehicle identification number.
7462 7463 7464 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7462 def vehicle_identification_number @vehicle_identification_number end |