Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental

Returns a new instance of CarRental.



7220
7221
7222
7223
7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
7237
7238
7239
7240
7241
7242
7243
7244
7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
7256
7257
7258
7259
7260
7261
7262
# File 'lib/stripe/services/payment_intent_service.rb', line 7220

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  tax_exempt: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @tax_exempt = tax_exempt
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



7180
7181
7182
# File 'lib/stripe/services/payment_intent_service.rb', line 7180

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



7182
7183
7184
# File 'lib/stripe/services/payment_intent_service.rb', line 7182

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



7184
7185
7186
# File 'lib/stripe/services/payment_intent_service.rb', line 7184

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



7186
7187
7188
# File 'lib/stripe/services/payment_intent_service.rb', line 7186

def car_make
  @car_make
end

#car_modelObject

Model of the car.



7188
7189
7190
# File 'lib/stripe/services/payment_intent_service.rb', line 7188

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



7190
7191
7192
# File 'lib/stripe/services/payment_intent_service.rb', line 7190

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



7192
7193
7194
# File 'lib/stripe/services/payment_intent_service.rb', line 7192

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



7194
7195
7196
# File 'lib/stripe/services/payment_intent_service.rb', line 7194

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



7196
7197
7198
# File 'lib/stripe/services/payment_intent_service.rb', line 7196

def delivery
  @delivery
end

#driversObject

The details of the passengers in the travel reservation



7198
7199
7200
# File 'lib/stripe/services/payment_intent_service.rb', line 7198

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



7200
7201
7202
# File 'lib/stripe/services/payment_intent_service.rb', line 7200

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



7202
7203
7204
# File 'lib/stripe/services/payment_intent_service.rb', line 7202

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



7204
7205
7206
# File 'lib/stripe/services/payment_intent_service.rb', line 7204

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



7206
7207
7208
# File 'lib/stripe/services/payment_intent_service.rb', line 7206

def pickup_at
  @pickup_at
end

#rate_amountObject

Rental rate.



7208
7209
7210
# File 'lib/stripe/services/payment_intent_service.rb', line 7208

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



7210
7211
7212
# File 'lib/stripe/services/payment_intent_service.rb', line 7210

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



7212
7213
7214
# File 'lib/stripe/services/payment_intent_service.rb', line 7212

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



7214
7215
7216
# File 'lib/stripe/services/payment_intent_service.rb', line 7214

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



7216
7217
7218
# File 'lib/stripe/services/payment_intent_service.rb', line 7216

def return_at
  @return_at
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



7218
7219
7220
# File 'lib/stripe/services/payment_intent_service.rb', line 7218

def tax_exempt
  @tax_exempt
end