Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 7289 7290 7291 7292 7293 7294 7295 7296 7297 7298 7299 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7257 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
7217 7218 7219 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7217 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
7219 7220 7221 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7219 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
7221 7222 7223 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7221 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
7223 7224 7225 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7223 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
7225 7226 7227 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7225 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
7227 7228 7229 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7227 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
7229 7230 7231 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7229 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
7231 7232 7233 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7231 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
7233 7234 7235 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7233 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
7235 7236 7237 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7235 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
7237 7238 7239 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7237 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
7239 7240 7241 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7239 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
7241 7242 7243 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7241 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
7243 7244 7245 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7243 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
7245 7246 7247 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7245 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
7247 7248 7249 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7247 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
7249 7250 7251 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7249 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
7251 7252 7253 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7251 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
7253 7254 7255 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7253 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
7255 7256 7257 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7255 def tax_exempt @tax_exempt end |