Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6928 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
6888 6889 6890 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6888 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
6890 6891 6892 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6890 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
6892 6893 6894 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6892 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
6894 6895 6896 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6894 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
6896 6897 6898 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6896 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
6898 6899 6900 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6898 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
6900 6901 6902 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6900 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
6902 6903 6904 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6902 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
6904 6905 6906 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6904 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
6906 6907 6908 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6906 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
6908 6909 6910 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6908 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
6910 6911 6912 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6910 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
6912 6913 6914 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6912 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
6914 6915 6916 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6914 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
6916 6917 6918 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6916 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
6918 6919 6920 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6918 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
6920 6921 6922 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6920 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
6922 6923 6924 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6922 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
6924 6925 6926 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6924 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
6926 6927 6928 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6926 def tax_exempt @tax_exempt end |