Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental

Returns a new instance of CarRental.



6886
6887
6888
6889
6890
6891
6892
6893
6894
6895
6896
6897
6898
6899
6900
6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
# File 'lib/stripe/services/payment_intent_service.rb', line 6886

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  tax_exempt: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @tax_exempt = tax_exempt
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



6846
6847
6848
# File 'lib/stripe/services/payment_intent_service.rb', line 6846

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



6848
6849
6850
# File 'lib/stripe/services/payment_intent_service.rb', line 6848

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



6850
6851
6852
# File 'lib/stripe/services/payment_intent_service.rb', line 6850

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



6852
6853
6854
# File 'lib/stripe/services/payment_intent_service.rb', line 6852

def car_make
  @car_make
end

#car_modelObject

Model of the car.



6854
6855
6856
# File 'lib/stripe/services/payment_intent_service.rb', line 6854

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



6856
6857
6858
# File 'lib/stripe/services/payment_intent_service.rb', line 6856

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



6858
6859
6860
# File 'lib/stripe/services/payment_intent_service.rb', line 6858

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



6860
6861
6862
# File 'lib/stripe/services/payment_intent_service.rb', line 6860

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



6862
6863
6864
# File 'lib/stripe/services/payment_intent_service.rb', line 6862

def delivery
  @delivery
end

#driversObject

The details of the passengers in the travel reservation



6864
6865
6866
# File 'lib/stripe/services/payment_intent_service.rb', line 6864

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



6866
6867
6868
# File 'lib/stripe/services/payment_intent_service.rb', line 6866

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



6868
6869
6870
# File 'lib/stripe/services/payment_intent_service.rb', line 6868

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



6870
6871
6872
# File 'lib/stripe/services/payment_intent_service.rb', line 6870

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



6872
6873
6874
# File 'lib/stripe/services/payment_intent_service.rb', line 6872

def pickup_at
  @pickup_at
end

#rate_amountObject

Rental rate.



6874
6875
6876
# File 'lib/stripe/services/payment_intent_service.rb', line 6874

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



6876
6877
6878
# File 'lib/stripe/services/payment_intent_service.rb', line 6876

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



6878
6879
6880
# File 'lib/stripe/services/payment_intent_service.rb', line 6878

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



6880
6881
6882
# File 'lib/stripe/services/payment_intent_service.rb', line 6880

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



6882
6883
6884
# File 'lib/stripe/services/payment_intent_service.rb', line 6882

def return_at
  @return_at
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



6884
6885
6886
# File 'lib/stripe/services/payment_intent_service.rb', line 6884

def tax_exempt
  @tax_exempt
end