Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



7777
7778
7779
7780
7781
# File 'lib/stripe/services/payment_intent_service.rb', line 7777

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



7771
7772
7773
# File 'lib/stripe/services/payment_intent_service.rb', line 7771

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



7773
7774
7775
# File 'lib/stripe/services/payment_intent_service.rb', line 7773

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



7775
7776
7777
# File 'lib/stripe/services/payment_intent_service.rb', line 7775

def phone
  @phone
end