Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



6800
6801
6802
6803
6804
# File 'lib/stripe/services/payment_intent_service.rb', line 6800

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



6794
6795
6796
# File 'lib/stripe/services/payment_intent_service.rb', line 6794

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



6796
6797
6798
# File 'lib/stripe/services/payment_intent_service.rb', line 6796

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



6798
6799
6800
# File 'lib/stripe/services/payment_intent_service.rb', line 6798

def phone
  @phone
end