Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
6758 6759 6760 6761 6762 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6758 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
6752 6753 6754 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6752 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
6754 6755 6756 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6754 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
6756 6757 6758 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6756 def phone @phone end |