Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



6730
6731
6732
6733
6734
# File 'lib/stripe/services/payment_intent_service.rb', line 6730

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



6724
6725
6726
# File 'lib/stripe/services/payment_intent_service.rb', line 6724

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



6726
6727
6728
# File 'lib/stripe/services/payment_intent_service.rb', line 6726

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



6728
6729
6730
# File 'lib/stripe/services/payment_intent_service.rb', line 6728

def phone
  @phone
end