Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
7398 7399 7400 7401 7402 7403 7404 7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7398 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
7380 7381 7382 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7380 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
7382 7383 7384 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7382 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
7384 7385 7386 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7384 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
7386 7387 7388 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7386 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
7388 7389 7390 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7388 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
7390 7391 7392 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7390 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
7392 7393 7394 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7392 def genre @genre end |
#name ⇒ Object
The name of the event.
7394 7395 7396 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7394 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
7396 7397 7398 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7396 def starts_at @starts_at end |