Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 7397 7398 7399 7400 7401 7402 7403 7404 7405 7406 7407 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7387 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
7369 7370 7371 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7369 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
7371 7372 7373 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7371 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
7373 7374 7375 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7373 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
7375 7376 7377 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7375 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
7377 7378 7379 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7377 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
7379 7380 7381 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7379 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
7381 7382 7383 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7381 def genre @genre end |
#name ⇒ Object
The name of the event.
7383 7384 7385 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7383 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
7385 7386 7387 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7385 def starts_at @starts_at end |