Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
7350 7351 7352 7353 7354 7355 7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 7370 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7350 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
7332 7333 7334 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7332 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
7334 7335 7336 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7334 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
7336 7337 7338 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7336 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
7338 7339 7340 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7338 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
7340 7341 7342 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7340 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
7342 7343 7344 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7342 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
7344 7345 7346 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7344 def genre @genre end |
#name ⇒ Object
The name of the event.
7346 7347 7348 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7346 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
7348 7349 7350 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7348 def starts_at @starts_at end |