Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7016 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
6998 6999 7000 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6998 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
7000 7001 7002 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7000 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
7002 7003 7004 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7002 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
7004 7005 7006 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7004 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
7006 7007 7008 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7006 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
7008 7009 7010 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7008 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
7010 7011 7012 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7010 def genre @genre end |
#name ⇒ Object
The name of the event.
7012 7013 7014 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7012 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
7014 7015 7016 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7014 def starts_at @starts_at end |