Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
6988 6989 6990 6991 6992 6993 6994 6995 6996 6997 6998 6999 7000 7001 7002 7003 7004 7005 7006 7007 7008 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6988 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
6970 6971 6972 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6970 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
6972 6973 6974 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6972 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
6974 6975 6976 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6974 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
6976 6977 6978 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6976 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
6978 6979 6980 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6978 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
6980 6981 6982 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6980 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
6982 6983 6984 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6982 def genre @genre end |
#name ⇒ Object
The name of the event.
6984 6985 6986 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6984 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
6986 6987 6988 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6986 def starts_at @starts_at end |