Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



7352
7353
7354
7355
7356
# File 'lib/stripe/services/payment_intent_service.rb', line 7352

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



7346
7347
7348
# File 'lib/stripe/services/payment_intent_service.rb', line 7346

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



7348
7349
7350
# File 'lib/stripe/services/payment_intent_service.rb', line 7348

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



7350
7351
7352
# File 'lib/stripe/services/payment_intent_service.rb', line 7350

def phone
  @phone
end