Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
7315 7316 7317 7318 7319 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7315 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
7309 7310 7311 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7309 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
7311 7312 7313 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7311 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
7313 7314 7315 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7313 def phone @phone end |