Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



6981
6982
6983
6984
6985
# File 'lib/stripe/services/payment_intent_service.rb', line 6981

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



6975
6976
6977
# File 'lib/stripe/services/payment_intent_service.rb', line 6975

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



6977
6978
6979
# File 'lib/stripe/services/payment_intent_service.rb', line 6977

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



6979
6980
6981
# File 'lib/stripe/services/payment_intent_service.rb', line 6979

def phone
  @phone
end