Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



7789
7790
7791
7792
7793
# File 'lib/stripe/services/payment_intent_service.rb', line 7789

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



7781
7782
7783
# File 'lib/stripe/services/payment_intent_service.rb', line 7781

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



7784
7785
7786
# File 'lib/stripe/services/payment_intent_service.rb', line 7784

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



7787
7788
7789
# File 'lib/stripe/services/payment_intent_service.rb', line 7787

def phone
  @phone
end