Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



6953
6954
6955
6956
6957
# File 'lib/stripe/services/payment_intent_service.rb', line 6953

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



6947
6948
6949
# File 'lib/stripe/services/payment_intent_service.rb', line 6947

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



6949
6950
6951
# File 'lib/stripe/services/payment_intent_service.rb', line 6949

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



6951
6952
6953
# File 'lib/stripe/services/payment_intent_service.rb', line 6951

def phone
  @phone
end