Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 7736 7737 7738 7739 7740 7741 7742 7743 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7725 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
7709 7710 7711 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7709 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
7711 7712 7713 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7711 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
7713 7714 7715 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7713 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
7715 7716 7717 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7715 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
7717 7718 7719 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7717 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
7719 7720 7721 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7719 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
7721 7722 7723 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7721 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
7723 7724 7725 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7723 def ticket_number @ticket_number end |