Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
7181 7182 7183 7184 7185 7186 7187 7188 7189 7190 7191 7192 7193 7194 7195 7196 7197 7198 7199 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7181 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
7165 7166 7167 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7165 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
7167 7168 7169 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7167 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
7169 7170 7171 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7169 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
7171 7172 7173 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7171 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
7173 7174 7175 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7173 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
7175 7176 7177 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7175 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
7177 7178 7179 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7177 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
7179 7180 7181 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7179 def ticket_number @ticket_number end |