Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
7973 7974 7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7973 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
7950 7951 7952 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7950 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
7953 7954 7955 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7953 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
7956 7957 7958 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7956 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
7959 7960 7961 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7959 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
7962 7963 7964 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7962 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
7965 7966 7967 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7965 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
7968 7969 7970 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7968 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
7971 7972 7973 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7971 def ticket_number @ticket_number end |