Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
7111 7112 7113 7114 7115 7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 7128 7129 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7111 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
7095 7096 7097 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7095 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
7097 7098 7099 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7097 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
7099 7100 7101 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7099 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
7101 7102 7103 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7101 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
7103 7104 7105 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7103 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
7105 7106 7107 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7105 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
7107 7108 7109 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7107 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
7109 7110 7111 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7109 def ticket_number @ticket_number end |