Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



8111
8112
8113
8114
8115
# File 'lib/stripe/services/payment_intent_service.rb', line 8111

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



8105
8106
8107
# File 'lib/stripe/services/payment_intent_service.rb', line 8105

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



8107
8108
8109
# File 'lib/stripe/services/payment_intent_service.rb', line 8107

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



8109
8110
8111
# File 'lib/stripe/services/payment_intent_service.rb', line 8109

def phone
  @phone
end