Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



7429
7430
7431
7432
7433
# File 'lib/stripe/services/payment_intent_service.rb', line 7429

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



7423
7424
7425
# File 'lib/stripe/services/payment_intent_service.rb', line 7423

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



7425
7426
7427
# File 'lib/stripe/services/payment_intent_service.rb', line 7425

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



7427
7428
7429
# File 'lib/stripe/services/payment_intent_service.rb', line 7427

def phone
  @phone
end