Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
7392 7393 7394 7395 7396 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7392 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
7386 7387 7388 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7386 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
7388 7389 7390 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7388 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
7390 7391 7392 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7390 def phone @phone end |