Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



7100
7101
7102
7103
7104
# File 'lib/stripe/services/payment_intent_service.rb', line 7100

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



7094
7095
7096
# File 'lib/stripe/services/payment_intent_service.rb', line 7094

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



7096
7097
7098
# File 'lib/stripe/services/payment_intent_service.rb', line 7096

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



7098
7099
7100
# File 'lib/stripe/services/payment_intent_service.rb', line 7098

def phone
  @phone
end