Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



7030
7031
7032
7033
7034
# File 'lib/stripe/services/payment_intent_service.rb', line 7030

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



7024
7025
7026
# File 'lib/stripe/services/payment_intent_service.rb', line 7024

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



7026
7027
7028
# File 'lib/stripe/services/payment_intent_service.rb', line 7026

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



7028
7029
7030
# File 'lib/stripe/services/payment_intent_service.rb', line 7028

def phone
  @phone
end