Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
8331 8332 8333 8334 8335 8336 8337 8338 8339 8340 8341 8342 8343 8344 8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8364 8365 8366 8367 8368 8369 8370 8371 8372 8373 8374 8375 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8331 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
8289 8290 8291 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8289 def address @address end |
#adults ⇒ Object
The number of adults on the booking
8291 8292 8293 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8291 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
8293 8294 8295 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8293 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
8295 8296 8297 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8295 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
8297 8298 8299 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8297 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
8299 8300 8301 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8299 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
8301 8302 8303 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8301 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
8303 8304 8305 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8303 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
8305 8306 8307 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8305 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
8307 8308 8309 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8307 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
8309 8310 8311 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8309 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
8311 8312 8313 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8311 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
8313 8314 8315 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8313 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
8315 8316 8317 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8315 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
8317 8318 8319 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8317 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
8319 8320 8321 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8319 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
8321 8322 8323 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8321 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
8323 8324 8325 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8323 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
8325 8326 8327 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8325 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
8327 8328 8329 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8327 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
8329 8330 8331 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8329 def total_tax_amount @total_tax_amount end |