Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



7864
7865
7866
7867
7868
7869
7870
7871
7872
7873
7874
7875
7876
7877
7878
7879
7880
7881
7882
7883
7884
7885
7886
7887
7888
7889
7890
7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
# File 'lib/stripe/services/payment_intent_service.rb', line 7864

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



7822
7823
7824
# File 'lib/stripe/services/payment_intent_service.rb', line 7822

def address
  @address
end

#adultsObject

The number of adults on the booking



7824
7825
7826
# File 'lib/stripe/services/payment_intent_service.rb', line 7824

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



7826
7827
7828
# File 'lib/stripe/services/payment_intent_service.rb', line 7826

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



7828
7829
7830
# File 'lib/stripe/services/payment_intent_service.rb', line 7828

def booking_number
  @booking_number
end

#categoryObject

The lodging category



7830
7831
7832
# File 'lib/stripe/services/payment_intent_service.rb', line 7830

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



7832
7833
7834
# File 'lib/stripe/services/payment_intent_service.rb', line 7832

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



7834
7835
7836
# File 'lib/stripe/services/payment_intent_service.rb', line 7834

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



7836
7837
7838
# File 'lib/stripe/services/payment_intent_service.rb', line 7836

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



7838
7839
7840
# File 'lib/stripe/services/payment_intent_service.rb', line 7838

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



7840
7841
7842
# File 'lib/stripe/services/payment_intent_service.rb', line 7840

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



7842
7843
7844
# File 'lib/stripe/services/payment_intent_service.rb', line 7842

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



7844
7845
7846
# File 'lib/stripe/services/payment_intent_service.rb', line 7844

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



7846
7847
7848
# File 'lib/stripe/services/payment_intent_service.rb', line 7846

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



7848
7849
7850
# File 'lib/stripe/services/payment_intent_service.rb', line 7848

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



7850
7851
7852
# File 'lib/stripe/services/payment_intent_service.rb', line 7850

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



7852
7853
7854
# File 'lib/stripe/services/payment_intent_service.rb', line 7852

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



7854
7855
7856
# File 'lib/stripe/services/payment_intent_service.rb', line 7854

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



7856
7857
7858
# File 'lib/stripe/services/payment_intent_service.rb', line 7856

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



7858
7859
7860
# File 'lib/stripe/services/payment_intent_service.rb', line 7858

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



7860
7861
7862
# File 'lib/stripe/services/payment_intent_service.rb', line 7860

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



7862
7863
7864
# File 'lib/stripe/services/payment_intent_service.rb', line 7862

def total_tax_amount
  @total_tax_amount
end