Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



7649
7650
7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
7666
7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
7688
7689
7690
7691
7692
7693
# File 'lib/stripe/services/payment_intent_service.rb', line 7649

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



7607
7608
7609
# File 'lib/stripe/services/payment_intent_service.rb', line 7607

def address
  @address
end

#adultsObject

The number of adults on the booking



7609
7610
7611
# File 'lib/stripe/services/payment_intent_service.rb', line 7609

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



7611
7612
7613
# File 'lib/stripe/services/payment_intent_service.rb', line 7611

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



7613
7614
7615
# File 'lib/stripe/services/payment_intent_service.rb', line 7613

def booking_number
  @booking_number
end

#categoryObject

The lodging category



7615
7616
7617
# File 'lib/stripe/services/payment_intent_service.rb', line 7615

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



7617
7618
7619
# File 'lib/stripe/services/payment_intent_service.rb', line 7617

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



7619
7620
7621
# File 'lib/stripe/services/payment_intent_service.rb', line 7619

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



7621
7622
7623
# File 'lib/stripe/services/payment_intent_service.rb', line 7621

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



7623
7624
7625
# File 'lib/stripe/services/payment_intent_service.rb', line 7623

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



7625
7626
7627
# File 'lib/stripe/services/payment_intent_service.rb', line 7625

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



7627
7628
7629
# File 'lib/stripe/services/payment_intent_service.rb', line 7627

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



7629
7630
7631
# File 'lib/stripe/services/payment_intent_service.rb', line 7629

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



7631
7632
7633
# File 'lib/stripe/services/payment_intent_service.rb', line 7631

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



7633
7634
7635
# File 'lib/stripe/services/payment_intent_service.rb', line 7633

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



7635
7636
7637
# File 'lib/stripe/services/payment_intent_service.rb', line 7635

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



7637
7638
7639
# File 'lib/stripe/services/payment_intent_service.rb', line 7637

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



7639
7640
7641
# File 'lib/stripe/services/payment_intent_service.rb', line 7639

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



7641
7642
7643
# File 'lib/stripe/services/payment_intent_service.rb', line 7641

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



7643
7644
7645
# File 'lib/stripe/services/payment_intent_service.rb', line 7643

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



7645
7646
7647
# File 'lib/stripe/services/payment_intent_service.rb', line 7645

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



7647
7648
7649
# File 'lib/stripe/services/payment_intent_service.rb', line 7647

def total_tax_amount
  @total_tax_amount
end