Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Loding check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 7622 7623 7624 7625 7626 7627 7628 7629 7630 7631 7632 7633 7634 7635 7636 7637 7638 7639 7640 7641 7642 7643 7644 7645 7646 7647 7648 7649 7650 7651 7652 7653 7654 7655 7656 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7612 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
7570 7571 7572 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7570 def address @address end |
#adults ⇒ Object
The number of adults on the booking
7572 7573 7574 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7572 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
7574 7575 7576 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7574 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
7576 7577 7578 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7576 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
7578 7579 7580 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7578 def category @category end |
#checkin_at ⇒ Object
Loding check-in time. Measured in seconds since the Unix epoch.
7580 7581 7582 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7580 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
7582 7583 7584 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7582 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
7584 7585 7586 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7584 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
7586 7587 7588 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7586 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
7588 7589 7590 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7588 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
7590 7591 7592 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7590 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
7592 7593 7594 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7592 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
7594 7595 7596 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7594 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
7596 7597 7598 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7596 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
7598 7599 7600 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7598 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
7600 7601 7602 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7600 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
7602 7603 7604 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7602 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
7604 7605 7606 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7604 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
7606 7607 7608 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7606 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
7608 7609 7610 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7608 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
7610 7611 7612 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7610 def total_tax_amount @total_tax_amount end |