Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



7320
7321
7322
7323
7324
7325
7326
7327
7328
7329
7330
7331
7332
7333
7334
7335
7336
7337
7338
7339
7340
7341
7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
7352
7353
7354
7355
7356
7357
7358
7359
7360
7361
7362
7363
7364
# File 'lib/stripe/services/payment_intent_service.rb', line 7320

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



7278
7279
7280
# File 'lib/stripe/services/payment_intent_service.rb', line 7278

def address
  @address
end

#adultsObject

The number of adults on the booking



7280
7281
7282
# File 'lib/stripe/services/payment_intent_service.rb', line 7280

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



7282
7283
7284
# File 'lib/stripe/services/payment_intent_service.rb', line 7282

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



7284
7285
7286
# File 'lib/stripe/services/payment_intent_service.rb', line 7284

def booking_number
  @booking_number
end

#categoryObject

The lodging category



7286
7287
7288
# File 'lib/stripe/services/payment_intent_service.rb', line 7286

def category
  @category
end

#checkin_atObject

Loding check-in time. Measured in seconds since the Unix epoch.



7288
7289
7290
# File 'lib/stripe/services/payment_intent_service.rb', line 7288

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



7290
7291
7292
# File 'lib/stripe/services/payment_intent_service.rb', line 7290

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



7292
7293
7294
# File 'lib/stripe/services/payment_intent_service.rb', line 7292

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



7294
7295
7296
# File 'lib/stripe/services/payment_intent_service.rb', line 7294

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



7296
7297
7298
# File 'lib/stripe/services/payment_intent_service.rb', line 7296

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



7298
7299
7300
# File 'lib/stripe/services/payment_intent_service.rb', line 7298

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



7300
7301
7302
# File 'lib/stripe/services/payment_intent_service.rb', line 7300

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



7302
7303
7304
# File 'lib/stripe/services/payment_intent_service.rb', line 7302

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



7304
7305
7306
# File 'lib/stripe/services/payment_intent_service.rb', line 7304

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



7306
7307
7308
# File 'lib/stripe/services/payment_intent_service.rb', line 7306

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



7308
7309
7310
# File 'lib/stripe/services/payment_intent_service.rb', line 7308

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



7310
7311
7312
# File 'lib/stripe/services/payment_intent_service.rb', line 7310

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



7312
7313
7314
# File 'lib/stripe/services/payment_intent_service.rb', line 7312

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



7314
7315
7316
# File 'lib/stripe/services/payment_intent_service.rb', line 7314

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



7316
7317
7318
# File 'lib/stripe/services/payment_intent_service.rb', line 7316

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



7318
7319
7320
# File 'lib/stripe/services/payment_intent_service.rb', line 7318

def total_tax_amount
  @total_tax_amount
end