Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



7250
7251
7252
7253
7254
7255
7256
7257
7258
7259
7260
7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
7284
7285
7286
7287
7288
7289
7290
7291
7292
7293
7294
# File 'lib/stripe/services/payment_intent_service.rb', line 7250

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



7208
7209
7210
# File 'lib/stripe/services/payment_intent_service.rb', line 7208

def address
  @address
end

#adultsObject

The number of adults on the booking



7210
7211
7212
# File 'lib/stripe/services/payment_intent_service.rb', line 7210

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



7212
7213
7214
# File 'lib/stripe/services/payment_intent_service.rb', line 7212

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



7214
7215
7216
# File 'lib/stripe/services/payment_intent_service.rb', line 7214

def booking_number
  @booking_number
end

#categoryObject

The lodging category



7216
7217
7218
# File 'lib/stripe/services/payment_intent_service.rb', line 7216

def category
  @category
end

#checkin_atObject

Loding check-in time. Measured in seconds since the Unix epoch.



7218
7219
7220
# File 'lib/stripe/services/payment_intent_service.rb', line 7218

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



7220
7221
7222
# File 'lib/stripe/services/payment_intent_service.rb', line 7220

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



7222
7223
7224
# File 'lib/stripe/services/payment_intent_service.rb', line 7222

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



7224
7225
7226
# File 'lib/stripe/services/payment_intent_service.rb', line 7224

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



7226
7227
7228
# File 'lib/stripe/services/payment_intent_service.rb', line 7226

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



7228
7229
7230
# File 'lib/stripe/services/payment_intent_service.rb', line 7228

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



7230
7231
7232
# File 'lib/stripe/services/payment_intent_service.rb', line 7230

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



7232
7233
7234
# File 'lib/stripe/services/payment_intent_service.rb', line 7232

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



7234
7235
7236
# File 'lib/stripe/services/payment_intent_service.rb', line 7234

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



7236
7237
7238
# File 'lib/stripe/services/payment_intent_service.rb', line 7236

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



7238
7239
7240
# File 'lib/stripe/services/payment_intent_service.rb', line 7238

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



7240
7241
7242
# File 'lib/stripe/services/payment_intent_service.rb', line 7240

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



7242
7243
7244
# File 'lib/stripe/services/payment_intent_service.rb', line 7242

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



7244
7245
7246
# File 'lib/stripe/services/payment_intent_service.rb', line 7244

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



7246
7247
7248
# File 'lib/stripe/services/payment_intent_service.rb', line 7246

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



7248
7249
7250
# File 'lib/stripe/services/payment_intent_service.rb', line 7248

def total_tax_amount
  @total_tax_amount
end