Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



7796
7797
7798
7799
7800
# File 'lib/stripe/services/payment_intent_service.rb', line 7796

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



7790
7791
7792
# File 'lib/stripe/services/payment_intent_service.rb', line 7790

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



7792
7793
7794
# File 'lib/stripe/services/payment_intent_service.rb', line 7792

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



7794
7795
7796
# File 'lib/stripe/services/payment_intent_service.rb', line 7794

def phone
  @phone
end