Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



7592
7593
7594
7595
7596
# File 'lib/stripe/services/payment_intent_service.rb', line 7592

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



7586
7587
7588
# File 'lib/stripe/services/payment_intent_service.rb', line 7586

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



7588
7589
7590
# File 'lib/stripe/services/payment_intent_service.rb', line 7588

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



7590
7591
7592
# File 'lib/stripe/services/payment_intent_service.rb', line 7590

def phone
  @phone
end