Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



7581
7582
7583
7584
7585
# File 'lib/stripe/services/payment_intent_service.rb', line 7581

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



7575
7576
7577
# File 'lib/stripe/services/payment_intent_service.rb', line 7575

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



7577
7578
7579
# File 'lib/stripe/services/payment_intent_service.rb', line 7577

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



7579
7580
7581
# File 'lib/stripe/services/payment_intent_service.rb', line 7579

def phone
  @phone
end