Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



7252
7253
7254
7255
7256
# File 'lib/stripe/services/payment_intent_service.rb', line 7252

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



7246
7247
7248
# File 'lib/stripe/services/payment_intent_service.rb', line 7246

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



7248
7249
7250
# File 'lib/stripe/services/payment_intent_service.rb', line 7248

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



7250
7251
7252
# File 'lib/stripe/services/payment_intent_service.rb', line 7250

def phone
  @phone
end