Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
7182 7183 7184 7185 7186 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7182 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
7176 7177 7178 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7176 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
7178 7179 7180 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7178 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
7180 7181 7182 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7180 def phone @phone end |