Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
8051 8052 8053 8054 8055 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8051 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
8043 8044 8045 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8043 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
8046 8047 8048 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8046 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
8049 8050 8051 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8049 def phone @phone end |