Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



7210
7211
7212
7213
7214
# File 'lib/stripe/services/payment_intent_service.rb', line 7210

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



7204
7205
7206
# File 'lib/stripe/services/payment_intent_service.rb', line 7204

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



7206
7207
7208
# File 'lib/stripe/services/payment_intent_service.rb', line 7206

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



7208
7209
7210
# File 'lib/stripe/services/payment_intent_service.rb', line 7208

def phone
  @phone
end