Class: Stripe::PaymentIntentService::CaptureParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



7927
7928
7929
7930
# File 'lib/stripe/services/payment_intent_service.rb', line 7927

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



7923
7924
7925
# File 'lib/stripe/services/payment_intent_service.rb', line 7923

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



7925
7926
7927
# File 'lib/stripe/services/payment_intent_service.rb', line 7925

def interval
  @interval
end