Class: Stripe::PaymentIntentService::ConfirmParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: MandateData, PaymentMethodData, PaymentMethodOptions, RadarOptions, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capture_method: nil, confirmation_token: nil, error_on_requires_action: nil, expand: nil, mandate: nil, mandate_data: nil, off_session: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shipping: nil, use_stripe_sdk: nil) ⇒ ConfirmParams

Returns a new instance of ConfirmParams.



7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
7042
7043
7044
7045
7046
7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
7057
7058
# File 'lib/stripe/services/payment_intent_service.rb', line 7022

def initialize(
  capture_method: nil,
  confirmation_token: nil,
  error_on_requires_action: nil,
  expand: nil,
  mandate: nil,
  mandate_data: nil,
  off_session: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  radar_options: nil,
  receipt_email: nil,
  return_url: nil,
  setup_future_usage: nil,
  shipping: nil,
  use_stripe_sdk: nil
)
  @capture_method = capture_method
  @confirmation_token = confirmation_token
  @error_on_requires_action = error_on_requires_action
  @expand = expand
  @mandate = mandate
  @mandate_data = mandate_data
  @off_session = off_session
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @radar_options = radar_options
  @receipt_email = receipt_email
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shipping = shipping
  @use_stripe_sdk = use_stripe_sdk
end

Instance Attribute Details

#capture_methodObject

Controls when the funds will be captured from the customer’s account.



6974
6975
6976
# File 'lib/stripe/services/payment_intent_service.rb', line 6974

def capture_method
  @capture_method
end

#confirmation_tokenObject

ID of the ConfirmationToken used to confirm this PaymentIntent.

If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.



6978
6979
6980
# File 'lib/stripe/services/payment_intent_service.rb', line 6978

def confirmation_token
  @confirmation_token
end

#error_on_requires_actionObject

Set to ‘true` to fail the payment attempt if the PaymentIntent transitions into `requires_action`. This parameter is intended for simpler integrations that do not handle customer actions, like [saving cards without authentication](stripe.com/docs/payments/save-card-without-authentication).



6980
6981
6982
# File 'lib/stripe/services/payment_intent_service.rb', line 6980

def error_on_requires_action
  @error_on_requires_action
end

#expandObject

Specifies which fields in the response should be expanded.



6982
6983
6984
# File 'lib/stripe/services/payment_intent_service.rb', line 6982

def expand
  @expand
end

#mandateObject

ID of the mandate that’s used for this payment.



6984
6985
6986
# File 'lib/stripe/services/payment_intent_service.rb', line 6984

def mandate
  @mandate
end

#mandate_dataObject

Attribute for param field mandate_data



6986
6987
6988
# File 'lib/stripe/services/payment_intent_service.rb', line 6986

def mandate_data
  @mandate_data
end

#off_sessionObject

Set to ‘true` to indicate that the customer isn’t in your checkout flow during this payment attempt and can’t authenticate. Use this parameter in scenarios where you collect card details and [charge them later](stripe.com/docs/payments/cards/charging-saved-cards).



6988
6989
6990
# File 'lib/stripe/services/payment_intent_service.rb', line 6988

def off_session
  @off_session
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or [compatible Source](stripe.com/docs/payments/payment-methods/transitioning#compatibility) object) to attach to this PaymentIntent.



6990
6991
6992
# File 'lib/stripe/services/payment_intent_service.rb', line 6990

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the [payment_method](stripe.com/docs/api/payment_intents/object#payment_intent_object-payment_method) property on the PaymentIntent.



6994
6995
6996
# File 'lib/stripe/services/payment_intent_service.rb', line 6994

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this PaymentIntent.



6996
6997
6998
# File 'lib/stripe/services/payment_intent_service.rb', line 6996

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, a card) that this PaymentIntent can use. Use ‘automatic_payment_methods` to manage payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods).



6998
6999
7000
# File 'lib/stripe/services/payment_intent_service.rb', line 6998

def payment_method_types
  @payment_method_types
end

#radar_optionsObject

Options to configure Radar. Learn more about [Radar Sessions](stripe.com/docs/radar/radar-session).



7000
7001
7002
# File 'lib/stripe/services/payment_intent_service.rb', line 7000

def radar_options
  @radar_options
end

#receipt_emailObject

Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).



7002
7003
7004
# File 'lib/stripe/services/payment_intent_service.rb', line 7002

def receipt_email
  @receipt_email
end

#return_urlObject

The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.



7006
7007
7008
# File 'lib/stripe/services/payment_intent_service.rb', line 7006

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



7016
7017
7018
# File 'lib/stripe/services/payment_intent_service.rb', line 7016

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this PaymentIntent.



7018
7019
7020
# File 'lib/stripe/services/payment_intent_service.rb', line 7018

def shipping
  @shipping
end

#use_stripe_sdkObject

Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.



7020
7021
7022
# File 'lib/stripe/services/payment_intent_service.rb', line 7020

def use_stripe_sdk
  @use_stripe_sdk
end