Class: Stripe::PaymentIntentService::ConfirmParams::AmountDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: LineItem, Shipping, Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails

Returns a new instance of AmountDetails.



8669
8670
8671
8672
8673
8674
# File 'lib/stripe/services/payment_intent_service.rb', line 8669

def initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil)
  @discount_amount = discount_amount
  @line_items = line_items
  @shipping = shipping
  @tax = tax
end

Instance Attribute Details

#discount_amountObject

The amount an item was discounted for.



8661
8662
8663
# File 'lib/stripe/services/payment_intent_service.rb', line 8661

def discount_amount
  @discount_amount
end

#line_itemsObject

A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.



8663
8664
8665
# File 'lib/stripe/services/payment_intent_service.rb', line 8663

def line_items
  @line_items
end

#shippingObject

Contains information about the shipping portion of the amount.



8665
8666
8667
# File 'lib/stripe/services/payment_intent_service.rb', line 8665

def shipping
  @shipping
end

#taxObject

Contains information about the tax portion of the amount.



8667
8668
8669
# File 'lib/stripe/services/payment_intent_service.rb', line 8667

def tax
  @tax
end