Class: Stripe::PaymentIntentService::ConfirmParams::AmountDetails::LineItem::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Card, CardPresent, Klarna, Paypal

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(card: nil, card_present: nil, klarna: nil, paypal: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



8583
8584
8585
8586
8587
8588
# File 'lib/stripe/services/payment_intent_service.rb', line 8583

def initialize(card: nil, card_present: nil, klarna: nil, paypal: nil)
  @card = card
  @card_present = card_present
  @klarna = klarna
  @paypal = paypal
end

Instance Attribute Details

#cardObject

This sub-hash contains line item details that are specific to ‘card` payment method.“



8575
8576
8577
# File 'lib/stripe/services/payment_intent_service.rb', line 8575

def card
  @card
end

#card_presentObject

This sub-hash contains line item details that are specific to ‘card_present` payment method.“



8577
8578
8579
# File 'lib/stripe/services/payment_intent_service.rb', line 8577

def card_present
  @card_present
end

#klarnaObject

This sub-hash contains line item details that are specific to ‘klarna` payment method.“



8579
8580
8581
# File 'lib/stripe/services/payment_intent_service.rb', line 8579

def klarna
  @klarna
end

#paypalObject

This sub-hash contains line item details that are specific to ‘paypal` payment method.“



8581
8582
8583
# File 'lib/stripe/services/payment_intent_service.rb', line 8581

def paypal
  @paypal
end