Class: Stripe::PaymentIntentService::ConfirmParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



4735
4736
4737
4738
4739
4740
# File 'lib/stripe/services/payment_intent_service.rb', line 4735

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



4727
4728
4729
# File 'lib/stripe/services/payment_intent_service.rb', line 4727

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



4729
4730
4731
# File 'lib/stripe/services/payment_intent_service.rb', line 4729

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



4731
4732
4733
# File 'lib/stripe/services/payment_intent_service.rb', line 4731

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



4733
4734
4735
# File 'lib/stripe/services/payment_intent_service.rb', line 4733

def type
  @type
end