Class: Stripe::PaymentIntentService::ConfirmParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



7509
7510
7511
7512
7513
7514
# File 'lib/stripe/services/payment_intent_service.rb', line 7509

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



7501
7502
7503
# File 'lib/stripe/services/payment_intent_service.rb', line 7501

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



7503
7504
7505
# File 'lib/stripe/services/payment_intent_service.rb', line 7503

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



7505
7506
7507
# File 'lib/stripe/services/payment_intent_service.rb', line 7505

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



7507
7508
7509
# File 'lib/stripe/services/payment_intent_service.rb', line 7507

def type
  @type
end