Class: Stripe::PaymentIntentService::ConfirmParams::MandateData::CustomerAcceptance::Online

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ip_address: nil, user_agent: nil) ⇒ Online

Returns a new instance of Online.



7537
7538
7539
7540
# File 'lib/stripe/services/payment_intent_service.rb', line 7537

def initialize(ip_address: nil, user_agent: nil)
  @ip_address = ip_address
  @user_agent = user_agent
end

Instance Attribute Details

#ip_addressObject

The IP address from which the Mandate was accepted by the customer.



7533
7534
7535
# File 'lib/stripe/services/payment_intent_service.rb', line 7533

def ip_address
  @ip_address
end

#user_agentObject

The user agent of the browser from which the Mandate was accepted by the customer.



7535
7536
7537
# File 'lib/stripe/services/payment_intent_service.rb', line 7535

def user_agent
  @user_agent
end