Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
9427 9428 9429 9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9427 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
9413 9414 9415 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9413 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
9415 9416 9417 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9415 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
9417 9418 9419 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9417 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
9419 9420 9421 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9419 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
9421 9422 9423 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9421 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
9423 9424 9425 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9423 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
9425 9426 9427 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9425 def subscription @subscription end |