Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
8599 8600 8601 8602 8603 8604 8605 8606 8607 8608 8609 8610 8611 8612 8613 8614 8615 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8599 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
8585 8586 8587 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8585 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
8587 8588 8589 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8587 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
8589 8590 8591 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8589 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
8591 8592 8593 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8591 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
8593 8594 8595 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8593 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
8595 8596 8597 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8595 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
8597 8598 8599 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8597 def subscription @subscription end |