Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#distance ⇒ Object
The details of the distance traveled during the rental period.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#pickup_location_name ⇒ Object
Name of the pickup location.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#return_location_name ⇒ Object
Name of the return location.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
The vehicle identification number.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental
Returns a new instance of CarRental.
9019 9020 9021 9022 9023 9024 9025 9026 9027 9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 9054 9055 9056 9057 9058 9059 9060 9061 9062 9063 9064 9065 9066 9067 9068 9069 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9019 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @distance = distance @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @pickup_location_name = pickup_location_name @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @return_location_name = return_location_name @tax_exempt = tax_exempt @vehicle_identification_number = vehicle_identification_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
8971 8972 8973 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8971 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
8973 8974 8975 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8973 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
8975 8976 8977 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8975 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
8977 8978 8979 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8977 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
8979 8980 8981 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8979 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
8981 8982 8983 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8981 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
8983 8984 8985 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8983 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
8985 8986 8987 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8985 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
8987 8988 8989 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8987 def delivery @delivery end |
#distance ⇒ Object
The details of the distance traveled during the rental period.
8989 8990 8991 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8989 def distance @distance end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
8991 8992 8993 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8991 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
8993 8994 8995 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8993 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
8995 8996 8997 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8995 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
8997 8998 8999 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8997 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
8999 9000 9001 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8999 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object
Name of the pickup location.
9001 9002 9003 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9001 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object
Rental rate.
9003 9004 9005 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9003 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
9005 9006 9007 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9005 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
9007 9008 9009 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9007 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
9009 9010 9011 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9009 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
9011 9012 9013 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9011 def return_at @return_at end |
#return_location_name ⇒ Object
Name of the return location.
9013 9014 9015 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9013 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
9015 9016 9017 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9015 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object
The vehicle identification number.
9017 9018 9019 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9017 def vehicle_identification_number @vehicle_identification_number end |