Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#distance ⇒ Object
The details of the distance traveled during the rental period.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#pickup_location_name ⇒ Object
Name of the pickup location.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#return_location_name ⇒ Object
Name of the return location.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
The vehicle identification number.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental
Returns a new instance of CarRental.
8915 8916 8917 8918 8919 8920 8921 8922 8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 8935 8936 8937 8938 8939 8940 8941 8942 8943 8944 8945 8946 8947 8948 8949 8950 8951 8952 8953 8954 8955 8956 8957 8958 8959 8960 8961 8962 8963 8964 8965 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8915 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @distance = distance @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @pickup_location_name = pickup_location_name @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @return_location_name = return_location_name @tax_exempt = tax_exempt @vehicle_identification_number = vehicle_identification_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
8867 8868 8869 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8867 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
8869 8870 8871 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8869 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
8871 8872 8873 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8871 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
8873 8874 8875 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8873 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
8875 8876 8877 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8875 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
8877 8878 8879 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8877 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
8879 8880 8881 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8879 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
8881 8882 8883 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8881 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
8883 8884 8885 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8883 def delivery @delivery end |
#distance ⇒ Object
The details of the distance traveled during the rental period.
8885 8886 8887 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8885 def distance @distance end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
8887 8888 8889 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8887 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
8889 8890 8891 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8889 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
8891 8892 8893 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8891 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
8893 8894 8895 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8893 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
8895 8896 8897 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8895 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object
Name of the pickup location.
8897 8898 8899 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8897 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object
Rental rate.
8899 8900 8901 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8899 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
8901 8902 8903 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8901 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
8903 8904 8905 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8903 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
8905 8906 8907 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8905 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
8907 8908 8909 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8907 def return_at @return_at end |
#return_location_name ⇒ Object
Name of the return location.
8909 8910 8911 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8909 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
8911 8912 8913 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8911 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object
The vehicle identification number.
8913 8914 8915 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8913 def vehicle_identification_number @vehicle_identification_number end |