Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#distance ⇒ Object
The details of the distance traveled during the rental period.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#pickup_location_name ⇒ Object
Name of the pickup location.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#return_location_name ⇒ Object
Name of the return location.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
The vehicle identification number.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental
Returns a new instance of CarRental.
8291 8292 8293 8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 8311 8312 8313 8314 8315 8316 8317 8318 8319 8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 8335 8336 8337 8338 8339 8340 8341 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8291 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @distance = distance @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @pickup_location_name = pickup_location_name @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @return_location_name = return_location_name @tax_exempt = tax_exempt @vehicle_identification_number = vehicle_identification_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
8243 8244 8245 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8243 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
8245 8246 8247 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8245 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
8247 8248 8249 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8247 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
8249 8250 8251 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8249 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
8251 8252 8253 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8251 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
8253 8254 8255 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8253 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
8255 8256 8257 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8255 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
8257 8258 8259 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8257 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
8259 8260 8261 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8259 def delivery @delivery end |
#distance ⇒ Object
The details of the distance traveled during the rental period.
8261 8262 8263 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8261 def distance @distance end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
8263 8264 8265 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8263 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
8265 8266 8267 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8265 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
8267 8268 8269 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8267 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
8269 8270 8271 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8269 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
8271 8272 8273 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8271 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object
Name of the pickup location.
8273 8274 8275 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8273 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object
Rental rate.
8275 8276 8277 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8275 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
8277 8278 8279 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8277 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
8279 8280 8281 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8279 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
8281 8282 8283 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8281 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
8283 8284 8285 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8283 def return_at @return_at end |
#return_location_name ⇒ Object
Name of the return location.
8285 8286 8287 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8285 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
8287 8288 8289 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8287 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object
The vehicle identification number.
8289 8290 8291 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8289 def vehicle_identification_number @vehicle_identification_number end |