Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
8006 8007 8008 8009 8010 8011 8012 8013 8014 8015 8016 8017 8018 8019 8020 8021 8022 8023 8024 8025 8026 8027 8028 8029 8030 8031 8032 8033 8034 8035 8036 8037 8038 8039 8040 8041 8042 8043 8044 8045 8046 8047 8048 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8006 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
7966 7967 7968 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7966 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
7968 7969 7970 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7968 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
7970 7971 7972 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7970 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
7972 7973 7974 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7972 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
7974 7975 7976 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7974 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
7976 7977 7978 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7976 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
7978 7979 7980 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7978 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
7980 7981 7982 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7980 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
7982 7983 7984 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7982 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
7984 7985 7986 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7984 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
7986 7987 7988 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7986 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
7988 7989 7990 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7988 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
7990 7991 7992 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7990 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
7992 7993 7994 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7992 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
7994 7995 7996 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7994 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
7996 7997 7998 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7996 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
7998 7999 8000 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7998 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
8000 8001 8002 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8000 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
8002 8003 8004 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8002 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
8004 8005 8006 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8004 def tax_exempt @tax_exempt end |