Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
8051 8052 8053 8054 8055 8056 8057 8058 8059 8060 8061 8062 8063 8064 8065 8066 8067 8068 8069 8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 8088 8089 8090 8091 8092 8093 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8051 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
8011 8012 8013 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8011 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
8013 8014 8015 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8013 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
8015 8016 8017 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8015 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
8017 8018 8019 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8017 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
8019 8020 8021 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8019 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
8021 8022 8023 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8021 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
8023 8024 8025 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8023 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
8025 8026 8027 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8025 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
8027 8028 8029 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8027 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
8029 8030 8031 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8029 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
8031 8032 8033 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8031 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
8033 8034 8035 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8033 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
8035 8036 8037 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8035 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
8037 8038 8039 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8037 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
8039 8040 8041 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8039 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
8041 8042 8043 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8041 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
8043 8044 8045 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8043 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
8045 8046 8047 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8045 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
8047 8048 8049 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8047 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
8049 8050 8051 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8049 def tax_exempt @tax_exempt end |