Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental

Returns a new instance of CarRental.



7714
7715
7716
7717
7718
7719
7720
7721
7722
7723
7724
7725
7726
7727
7728
7729
7730
7731
7732
7733
7734
7735
7736
7737
7738
7739
7740
7741
7742
7743
7744
7745
7746
7747
7748
7749
7750
7751
7752
7753
7754
7755
7756
# File 'lib/stripe/services/payment_intent_service.rb', line 7714

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  tax_exempt: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @tax_exempt = tax_exempt
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



7674
7675
7676
# File 'lib/stripe/services/payment_intent_service.rb', line 7674

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



7676
7677
7678
# File 'lib/stripe/services/payment_intent_service.rb', line 7676

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



7678
7679
7680
# File 'lib/stripe/services/payment_intent_service.rb', line 7678

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



7680
7681
7682
# File 'lib/stripe/services/payment_intent_service.rb', line 7680

def car_make
  @car_make
end

#car_modelObject

Model of the car.



7682
7683
7684
# File 'lib/stripe/services/payment_intent_service.rb', line 7682

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



7684
7685
7686
# File 'lib/stripe/services/payment_intent_service.rb', line 7684

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



7686
7687
7688
# File 'lib/stripe/services/payment_intent_service.rb', line 7686

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



7688
7689
7690
# File 'lib/stripe/services/payment_intent_service.rb', line 7688

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



7690
7691
7692
# File 'lib/stripe/services/payment_intent_service.rb', line 7690

def delivery
  @delivery
end

#driversObject

The details of the passengers in the travel reservation



7692
7693
7694
# File 'lib/stripe/services/payment_intent_service.rb', line 7692

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



7694
7695
7696
# File 'lib/stripe/services/payment_intent_service.rb', line 7694

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



7696
7697
7698
# File 'lib/stripe/services/payment_intent_service.rb', line 7696

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



7698
7699
7700
# File 'lib/stripe/services/payment_intent_service.rb', line 7698

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



7700
7701
7702
# File 'lib/stripe/services/payment_intent_service.rb', line 7700

def pickup_at
  @pickup_at
end

#rate_amountObject

Rental rate.



7702
7703
7704
# File 'lib/stripe/services/payment_intent_service.rb', line 7702

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



7704
7705
7706
# File 'lib/stripe/services/payment_intent_service.rb', line 7704

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



7706
7707
7708
# File 'lib/stripe/services/payment_intent_service.rb', line 7706

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



7708
7709
7710
# File 'lib/stripe/services/payment_intent_service.rb', line 7708

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



7710
7711
7712
# File 'lib/stripe/services/payment_intent_service.rb', line 7710

def return_at
  @return_at
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



7712
7713
7714
# File 'lib/stripe/services/payment_intent_service.rb', line 7712

def tax_exempt
  @tax_exempt
end