Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
8589 8590 8591 8592 8593 8594 8595 8596 8597 8598 8599 8600 8601 8602 8603 8604 8605 8606 8607 8608 8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8589 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
8530 8531 8532 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8530 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
8533 8534 8535 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8533 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
8536 8537 8538 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8536 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
8539 8540 8541 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8539 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
8542 8543 8544 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8542 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
8545 8546 8547 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8545 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
8548 8549 8550 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8548 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
8551 8552 8553 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8551 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
8554 8555 8556 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8554 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
8557 8558 8559 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8557 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
8560 8561 8562 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8560 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
8563 8564 8565 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8563 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
8566 8567 8568 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8566 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
8569 8570 8571 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8569 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
8572 8573 8574 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8572 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
8575 8576 8577 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8575 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
8578 8579 8580 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8578 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
8581 8582 8583 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8581 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
8584 8585 8586 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8584 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
8587 8588 8589 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8587 def tax_exempt @tax_exempt end |