Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
7672 7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 7713 7714 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7672 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
7632 7633 7634 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7632 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
7634 7635 7636 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7634 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
7636 7637 7638 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7636 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
7638 7639 7640 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7638 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
7640 7641 7642 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7640 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
7642 7643 7644 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7642 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
7644 7645 7646 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7644 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
7646 7647 7648 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7646 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
7648 7649 7650 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7648 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
7650 7651 7652 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7650 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
7652 7653 7654 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7652 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
7654 7655 7656 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7654 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
7656 7657 7658 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7656 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
7658 7659 7660 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7658 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
7660 7661 7662 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7660 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
7662 7663 7664 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7662 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
7664 7665 7666 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7664 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
7666 7667 7668 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7666 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
7668 7669 7670 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7668 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
7670 7671 7672 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7670 def tax_exempt @tax_exempt end |