Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



8761
8762
8763
8764
8765
# File 'lib/stripe/services/payment_intent_service.rb', line 8761

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



8755
8756
8757
# File 'lib/stripe/services/payment_intent_service.rb', line 8755

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



8757
8758
8759
# File 'lib/stripe/services/payment_intent_service.rb', line 8757

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



8759
8760
8761
# File 'lib/stripe/services/payment_intent_service.rb', line 8759

def phone
  @phone
end