Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



7933
7934
7935
7936
7937
# File 'lib/stripe/services/payment_intent_service.rb', line 7933

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



7927
7928
7929
# File 'lib/stripe/services/payment_intent_service.rb', line 7927

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



7929
7930
7931
# File 'lib/stripe/services/payment_intent_service.rb', line 7929

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



7931
7932
7933
# File 'lib/stripe/services/payment_intent_service.rb', line 7931

def phone
  @phone
end