Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
7933 7934 7935 7936 7937 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7933 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
7927 7928 7929 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7927 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
7929 7930 7931 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7929 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
7931 7932 7933 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7931 def phone @phone end |