Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



7878
7879
7880
7881
7882
# File 'lib/stripe/services/payment_intent_service.rb', line 7878

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



7872
7873
7874
# File 'lib/stripe/services/payment_intent_service.rb', line 7872

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



7874
7875
7876
# File 'lib/stripe/services/payment_intent_service.rb', line 7874

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



7876
7877
7878
# File 'lib/stripe/services/payment_intent_service.rb', line 7876

def phone
  @phone
end