Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



7544
7545
7546
7547
7548
# File 'lib/stripe/services/payment_intent_service.rb', line 7544

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



7538
7539
7540
# File 'lib/stripe/services/payment_intent_service.rb', line 7538

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



7540
7541
7542
# File 'lib/stripe/services/payment_intent_service.rb', line 7540

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



7542
7543
7544
# File 'lib/stripe/services/payment_intent_service.rb', line 7542

def phone
  @phone
end