Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



7516
7517
7518
7519
7520
# File 'lib/stripe/services/payment_intent_service.rb', line 7516

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



7510
7511
7512
# File 'lib/stripe/services/payment_intent_service.rb', line 7510

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



7512
7513
7514
# File 'lib/stripe/services/payment_intent_service.rb', line 7512

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



7514
7515
7516
# File 'lib/stripe/services/payment_intent_service.rb', line 7514

def phone
  @phone
end