Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



8431
8432
8433
8434
8435
# File 'lib/stripe/services/payment_intent_service.rb', line 8431

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



8423
8424
8425
# File 'lib/stripe/services/payment_intent_service.rb', line 8423

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



8426
8427
8428
# File 'lib/stripe/services/payment_intent_service.rb', line 8426

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



8429
8430
8431
# File 'lib/stripe/services/payment_intent_service.rb', line 8429

def phone
  @phone
end