Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
8431 8432 8433 8434 8435 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8431 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
8423 8424 8425 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8423 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
8426 8427 8428 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8426 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
8429 8430 8431 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8429 def phone @phone end |