Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
9053 9054 9055 9056 9057 9058 9059 9060 9061 9062 9063 9064 9065 9066 9067 9068 9069 9070 9071 9072 9073 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9053 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
9035 9036 9037 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9035 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
9037 9038 9039 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9037 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
9039 9040 9041 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9039 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
9041 9042 9043 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9041 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
9043 9044 9045 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9043 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
9045 9046 9047 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9045 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
9047 9048 9049 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9047 def genre @genre end |
#name ⇒ Object
The name of the event.
9049 9050 9051 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9049 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
9051 9052 9053 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9051 def starts_at @starts_at end |