Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
8429 8430 8431 8432 8433 8434 8435 8436 8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8429 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
8411 8412 8413 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8411 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
8413 8414 8415 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8413 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
8415 8416 8417 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8415 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
8417 8418 8419 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8417 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
8419 8420 8421 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8419 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
8421 8422 8423 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8421 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
8423 8424 8425 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8423 def genre @genre end |
#name ⇒ Object
The name of the event.
8425 8426 8427 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8425 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
8427 8428 8429 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8427 def starts_at @starts_at end |