Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
8225 8226 8227 8228 8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 8242 8243 8244 8245 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8225 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
8207 8208 8209 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8207 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
8209 8210 8211 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8209 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
8211 8212 8213 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8211 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
8213 8214 8215 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8213 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
8215 8216 8217 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8215 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
8217 8218 8219 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8217 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
8219 8220 8221 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8219 def genre @genre end |
#name ⇒ Object
The name of the event.
8221 8222 8223 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8221 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
8223 8224 8225 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8223 def starts_at @starts_at end |