Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
8181 8182 8183 8184 8185 8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 8197 8198 8199 8200 8201 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8181 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
8163 8164 8165 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8163 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
8165 8166 8167 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8165 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
8167 8168 8169 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8167 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
8169 8170 8171 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8169 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
8171 8172 8173 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8171 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
8173 8174 8175 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8173 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
8175 8176 8177 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8175 def genre @genre end |
#name ⇒ Object
The name of the event.
8177 8178 8179 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8177 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
8179 8180 8181 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8179 def starts_at @starts_at end |