Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
8136 8137 8138 8139 8140 8141 8142 8143 8144 8145 8146 8147 8148 8149 8150 8151 8152 8153 8154 8155 8156 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8136 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
8118 8119 8120 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8118 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
8120 8121 8122 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8120 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
8122 8123 8124 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8122 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
8124 8125 8126 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8124 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
8126 8127 8128 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8126 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
8128 8129 8130 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8128 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
8130 8131 8132 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8130 def genre @genre end |
#name ⇒ Object
The name of the event.
8132 8133 8134 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8132 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
8134 8135 8136 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8134 def starts_at @starts_at end |