Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
7844 7845 7846 7847 7848 7849 7850 7851 7852 7853 7854 7855 7856 7857 7858 7859 7860 7861 7862 7863 7864 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7844 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
7826 7827 7828 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7826 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
7828 7829 7830 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7828 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
7830 7831 7832 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7830 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
7832 7833 7834 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7832 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
7834 7835 7836 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7834 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
7836 7837 7838 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7836 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
7838 7839 7840 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7838 def genre @genre end |
#name ⇒ Object
The name of the event.
7840 7841 7842 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7840 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
7842 7843 7844 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7842 def starts_at @starts_at end |