Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
8735 8736 8737 8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8735 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
8709 8710 8711 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8709 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
8712 8713 8714 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8712 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
8715 8716 8717 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8715 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
8718 8719 8720 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8718 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
8721 8722 8723 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8721 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
8724 8725 8726 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8724 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
8727 8728 8729 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8727 def genre @genre end |
#name ⇒ Object
The name of the event.
8730 8731 8732 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8730 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
8733 8734 8735 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8733 def starts_at @starts_at end |