Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
9018 9019 9020 9021 9022 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9018 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
9012 9013 9014 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9012 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
9014 9015 9016 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9014 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
9016 9017 9018 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9016 def phone @phone end |