Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



8101
8102
8103
8104
8105
# File 'lib/stripe/services/payment_intent_service.rb', line 8101

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



8095
8096
8097
# File 'lib/stripe/services/payment_intent_service.rb', line 8095

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



8097
8098
8099
# File 'lib/stripe/services/payment_intent_service.rb', line 8097

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



8099
8100
8101
# File 'lib/stripe/services/payment_intent_service.rb', line 8099

def phone
  @phone
end