Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



7767
7768
7769
7770
7771
# File 'lib/stripe/services/payment_intent_service.rb', line 7767

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



7761
7762
7763
# File 'lib/stripe/services/payment_intent_service.rb', line 7761

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



7763
7764
7765
# File 'lib/stripe/services/payment_intent_service.rb', line 7763

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



7765
7766
7767
# File 'lib/stripe/services/payment_intent_service.rb', line 7765

def phone
  @phone
end