Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



7739
7740
7741
7742
7743
# File 'lib/stripe/services/payment_intent_service.rb', line 7739

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



7733
7734
7735
# File 'lib/stripe/services/payment_intent_service.rb', line 7733

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



7735
7736
7737
# File 'lib/stripe/services/payment_intent_service.rb', line 7735

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



7737
7738
7739
# File 'lib/stripe/services/payment_intent_service.rb', line 7737

def phone
  @phone
end