Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
7739 7740 7741 7742 7743 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7739 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
7733 7734 7735 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7733 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
7735 7736 7737 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7735 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
7737 7738 7739 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7737 def phone @phone end |