Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
9176 9177 9178 9179 9180 9181 9182 9183 9184 9185 9186 9187 9188 9189 9190 9191 9192 9193 9194 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9176 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
9160 9161 9162 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9160 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
9162 9163 9164 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9162 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
9164 9165 9166 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9164 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
9166 9167 9168 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9166 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
9168 9169 9170 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9168 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
9170 9171 9172 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9170 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
9172 9173 9174 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9172 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
9174 9175 9176 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9174 def ticket_number @ticket_number end |