Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 8568 8569 8570 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8552 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
8536 8537 8538 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8536 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
8538 8539 8540 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8538 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
8540 8541 8542 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8540 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
8542 8543 8544 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8542 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
8544 8545 8546 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8544 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
8546 8547 8548 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8546 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
8548 8549 8550 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8548 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
8550 8551 8552 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8550 def ticket_number @ticket_number end |