Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
8348 8349 8350 8351 8352 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8364 8365 8366 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8348 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
8332 8333 8334 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8332 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
8334 8335 8336 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8334 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
8336 8337 8338 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8336 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
8338 8339 8340 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8338 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
8340 8341 8342 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8340 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
8342 8343 8344 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8342 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
8344 8345 8346 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8344 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
8346 8347 8348 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8346 def ticket_number @ticket_number end |