Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
8304 8305 8306 8307 8308 8309 8310 8311 8312 8313 8314 8315 8316 8317 8318 8319 8320 8321 8322 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8304 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
8288 8289 8290 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8288 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
8290 8291 8292 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8290 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
8292 8293 8294 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8292 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
8294 8295 8296 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8294 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
8296 8297 8298 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8296 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
8298 8299 8300 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8298 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
8300 8301 8302 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8300 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
8302 8303 8304 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8302 def ticket_number @ticket_number end |