Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8875 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
8852 8853 8854 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8852 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
8855 8856 8857 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8855 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
8858 8859 8860 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8858 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
8861 8862 8863 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8861 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
8864 8865 8866 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8864 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
8867 8868 8869 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8867 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
8870 8871 8872 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8870 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
8873 8874 8875 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8873 def ticket_number @ticket_number end |