Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
7897 7898 7899 7900 7901 7902 7903 7904 7905 7906 7907 7908 7909 7910 7911 7912 7913 7914 7915 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7897 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
7881 7882 7883 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7881 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
7883 7884 7885 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7883 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
7885 7886 7887 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7885 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
7887 7888 7889 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7887 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
7889 7890 7891 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7889 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
7891 7892 7893 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7891 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
7893 7894 7895 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7893 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
7895 7896 7897 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7895 def ticket_number @ticket_number end |