Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
9199 9200 9201 9202 9203 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9199 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
9193 9194 9195 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9193 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
9195 9196 9197 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9195 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
9197 9198 9199 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9197 def phone @phone end |