Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



9095
9096
9097
9098
9099
# File 'lib/stripe/services/payment_intent_service.rb', line 9095

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



9089
9090
9091
# File 'lib/stripe/services/payment_intent_service.rb', line 9089

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



9091
9092
9093
# File 'lib/stripe/services/payment_intent_service.rb', line 9091

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



9093
9094
9095
# File 'lib/stripe/services/payment_intent_service.rb', line 9093

def phone
  @phone
end