Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



8471
8472
8473
8474
8475
# File 'lib/stripe/services/payment_intent_service.rb', line 8471

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



8465
8466
8467
# File 'lib/stripe/services/payment_intent_service.rb', line 8465

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



8467
8468
8469
# File 'lib/stripe/services/payment_intent_service.rb', line 8467

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



8469
8470
8471
# File 'lib/stripe/services/payment_intent_service.rb', line 8469

def phone
  @phone
end