Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



8267
8268
8269
8270
8271
# File 'lib/stripe/services/payment_intent_service.rb', line 8267

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



8261
8262
8263
# File 'lib/stripe/services/payment_intent_service.rb', line 8261

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



8263
8264
8265
# File 'lib/stripe/services/payment_intent_service.rb', line 8263

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



8265
8266
8267
# File 'lib/stripe/services/payment_intent_service.rb', line 8265

def phone
  @phone
end