Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
8178 8179 8180 8181 8182 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8178 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
8172 8173 8174 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8172 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
8174 8175 8176 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8174 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
8176 8177 8178 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8176 def phone @phone end |