Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



7886
7887
7888
7889
7890
# File 'lib/stripe/services/payment_intent_service.rb', line 7886

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



7880
7881
7882
# File 'lib/stripe/services/payment_intent_service.rb', line 7880

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



7882
7883
7884
# File 'lib/stripe/services/payment_intent_service.rb', line 7882

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



7884
7885
7886
# File 'lib/stripe/services/payment_intent_service.rb', line 7884

def phone
  @phone
end