Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
7886 7887 7888 7889 7890 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7886 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
7880 7881 7882 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7880 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
7882 7883 7884 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7882 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
7884 7885 7886 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7884 def phone @phone end |