Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



7844
7845
7846
7847
7848
# File 'lib/stripe/services/payment_intent_service.rb', line 7844

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



7838
7839
7840
# File 'lib/stripe/services/payment_intent_service.rb', line 7838

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



7840
7841
7842
# File 'lib/stripe/services/payment_intent_service.rb', line 7840

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



7842
7843
7844
# File 'lib/stripe/services/payment_intent_service.rb', line 7842

def phone
  @phone
end