Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



7816
7817
7818
7819
7820
# File 'lib/stripe/services/payment_intent_service.rb', line 7816

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



7810
7811
7812
# File 'lib/stripe/services/payment_intent_service.rb', line 7810

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



7812
7813
7814
# File 'lib/stripe/services/payment_intent_service.rb', line 7812

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



7814
7815
7816
# File 'lib/stripe/services/payment_intent_service.rb', line 7814

def phone
  @phone
end