Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
9419 9420 9421 9422 9423 9424 9425 9426 9427 9428 9429 9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9419 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
9377 9378 9379 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9377 def address @address end |
#adults ⇒ Object
The number of adults on the booking
9379 9380 9381 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9379 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
9381 9382 9383 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9381 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
9383 9384 9385 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9383 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
9385 9386 9387 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9385 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
9387 9388 9389 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9387 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
9389 9390 9391 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9389 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
9391 9392 9393 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9391 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
9393 9394 9395 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9393 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
9395 9396 9397 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9395 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
9397 9398 9399 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9397 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
9399 9400 9401 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9399 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
9401 9402 9403 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9401 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
9403 9404 9405 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9403 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
9405 9406 9407 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9405 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
9407 9408 9409 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9407 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
9409 9410 9411 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9409 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
9411 9412 9413 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9411 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
9413 9414 9415 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9413 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
9415 9416 9417 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9415 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
9417 9418 9419 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9417 def total_tax_amount @total_tax_amount end |