Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
9315 9316 9317 9318 9319 9320 9321 9322 9323 9324 9325 9326 9327 9328 9329 9330 9331 9332 9333 9334 9335 9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 9355 9356 9357 9358 9359 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9315 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
9273 9274 9275 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9273 def address @address end |
#adults ⇒ Object
The number of adults on the booking
9275 9276 9277 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9275 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
9277 9278 9279 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9277 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
9279 9280 9281 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9279 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
9281 9282 9283 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9281 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
9283 9284 9285 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9283 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
9285 9286 9287 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9285 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
9287 9288 9289 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9287 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
9289 9290 9291 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9289 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
9291 9292 9293 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9291 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
9293 9294 9295 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9293 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
9295 9296 9297 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9295 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
9297 9298 9299 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9297 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
9299 9300 9301 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9299 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
9301 9302 9303 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9301 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
9303 9304 9305 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9303 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
9305 9306 9307 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9305 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
9307 9308 9309 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9307 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
9309 9310 9311 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9309 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
9311 9312 9313 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9311 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
9313 9314 9315 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9313 def total_tax_amount @total_tax_amount end |