Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



8691
8692
8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
8704
8705
8706
8707
8708
8709
8710
8711
8712
8713
8714
8715
8716
8717
8718
8719
8720
8721
8722
8723
8724
8725
8726
8727
8728
8729
8730
8731
8732
8733
8734
8735
# File 'lib/stripe/services/payment_intent_service.rb', line 8691

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



8649
8650
8651
# File 'lib/stripe/services/payment_intent_service.rb', line 8649

def address
  @address
end

#adultsObject

The number of adults on the booking



8651
8652
8653
# File 'lib/stripe/services/payment_intent_service.rb', line 8651

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



8653
8654
8655
# File 'lib/stripe/services/payment_intent_service.rb', line 8653

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



8655
8656
8657
# File 'lib/stripe/services/payment_intent_service.rb', line 8655

def booking_number
  @booking_number
end

#categoryObject

The lodging category



8657
8658
8659
# File 'lib/stripe/services/payment_intent_service.rb', line 8657

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



8659
8660
8661
# File 'lib/stripe/services/payment_intent_service.rb', line 8659

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



8661
8662
8663
# File 'lib/stripe/services/payment_intent_service.rb', line 8661

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



8663
8664
8665
# File 'lib/stripe/services/payment_intent_service.rb', line 8663

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



8665
8666
8667
# File 'lib/stripe/services/payment_intent_service.rb', line 8665

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



8667
8668
8669
# File 'lib/stripe/services/payment_intent_service.rb', line 8667

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



8669
8670
8671
# File 'lib/stripe/services/payment_intent_service.rb', line 8669

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



8671
8672
8673
# File 'lib/stripe/services/payment_intent_service.rb', line 8671

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



8673
8674
8675
# File 'lib/stripe/services/payment_intent_service.rb', line 8673

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



8675
8676
8677
# File 'lib/stripe/services/payment_intent_service.rb', line 8675

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



8677
8678
8679
# File 'lib/stripe/services/payment_intent_service.rb', line 8677

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



8679
8680
8681
# File 'lib/stripe/services/payment_intent_service.rb', line 8679

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



8681
8682
8683
# File 'lib/stripe/services/payment_intent_service.rb', line 8681

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



8683
8684
8685
# File 'lib/stripe/services/payment_intent_service.rb', line 8683

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



8685
8686
8687
# File 'lib/stripe/services/payment_intent_service.rb', line 8685

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



8687
8688
8689
# File 'lib/stripe/services/payment_intent_service.rb', line 8687

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



8689
8690
8691
# File 'lib/stripe/services/payment_intent_service.rb', line 8689

def total_tax_amount
  @total_tax_amount
end