Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
8487 8488 8489 8490 8491 8492 8493 8494 8495 8496 8497 8498 8499 8500 8501 8502 8503 8504 8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 8515 8516 8517 8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8487 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
8445 8446 8447 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8445 def address @address end |
#adults ⇒ Object
The number of adults on the booking
8447 8448 8449 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8447 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
8449 8450 8451 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8449 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
8451 8452 8453 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8451 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
8453 8454 8455 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8453 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
8455 8456 8457 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8455 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
8457 8458 8459 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8457 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
8459 8460 8461 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8459 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
8461 8462 8463 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8461 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
8463 8464 8465 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8463 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
8465 8466 8467 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8465 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
8467 8468 8469 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8467 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
8469 8470 8471 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8469 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
8471 8472 8473 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8471 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
8473 8474 8475 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8473 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
8475 8476 8477 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8475 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
8477 8478 8479 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8477 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
8479 8480 8481 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8479 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
8481 8482 8483 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8481 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
8483 8484 8485 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8483 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
8485 8486 8487 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8485 def total_tax_amount @total_tax_amount end |