Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
8410
8411
8412
8413
8414
8415
8416
8417
8418
8419
8420
8421
8422
8423
8424
8425
8426
8427
8428
8429
8430
8431
8432
8433
8434
8435
8436
8437
8438
8439
8440
8441
8442
# File 'lib/stripe/services/payment_intent_service.rb', line 8398

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



8356
8357
8358
# File 'lib/stripe/services/payment_intent_service.rb', line 8356

def address
  @address
end

#adultsObject

The number of adults on the booking



8358
8359
8360
# File 'lib/stripe/services/payment_intent_service.rb', line 8358

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



8360
8361
8362
# File 'lib/stripe/services/payment_intent_service.rb', line 8360

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



8362
8363
8364
# File 'lib/stripe/services/payment_intent_service.rb', line 8362

def booking_number
  @booking_number
end

#categoryObject

The lodging category



8364
8365
8366
# File 'lib/stripe/services/payment_intent_service.rb', line 8364

def category
  @category
end

#checkin_atObject

Loding check-in time. Measured in seconds since the Unix epoch.



8366
8367
8368
# File 'lib/stripe/services/payment_intent_service.rb', line 8366

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



8368
8369
8370
# File 'lib/stripe/services/payment_intent_service.rb', line 8368

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



8370
8371
8372
# File 'lib/stripe/services/payment_intent_service.rb', line 8370

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



8372
8373
8374
# File 'lib/stripe/services/payment_intent_service.rb', line 8372

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



8374
8375
8376
# File 'lib/stripe/services/payment_intent_service.rb', line 8374

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



8376
8377
8378
# File 'lib/stripe/services/payment_intent_service.rb', line 8376

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



8378
8379
8380
# File 'lib/stripe/services/payment_intent_service.rb', line 8378

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



8380
8381
8382
# File 'lib/stripe/services/payment_intent_service.rb', line 8380

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



8382
8383
8384
# File 'lib/stripe/services/payment_intent_service.rb', line 8382

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



8384
8385
8386
# File 'lib/stripe/services/payment_intent_service.rb', line 8384

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



8386
8387
8388
# File 'lib/stripe/services/payment_intent_service.rb', line 8386

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



8388
8389
8390
# File 'lib/stripe/services/payment_intent_service.rb', line 8388

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



8390
8391
8392
# File 'lib/stripe/services/payment_intent_service.rb', line 8390

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



8392
8393
8394
# File 'lib/stripe/services/payment_intent_service.rb', line 8392

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



8394
8395
8396
# File 'lib/stripe/services/payment_intent_service.rb', line 8394

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



8396
8397
8398
# File 'lib/stripe/services/payment_intent_service.rb', line 8396

def total_tax_amount
  @total_tax_amount
end