Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Loding check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 8470 8471 8472 8473 8474 8475 8476 8477 8478 8479 8480 8481 8482 8483 8484 8485 8486 8487 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8443 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
8401 8402 8403 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8401 def address @address end |
#adults ⇒ Object
The number of adults on the booking
8403 8404 8405 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8403 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
8405 8406 8407 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8405 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
8407 8408 8409 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8407 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
8409 8410 8411 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8409 def category @category end |
#checkin_at ⇒ Object
Loding check-in time. Measured in seconds since the Unix epoch.
8411 8412 8413 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8411 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
8413 8414 8415 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8413 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
8415 8416 8417 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8415 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
8417 8418 8419 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8417 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
8419 8420 8421 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8419 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
8421 8422 8423 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8421 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
8423 8424 8425 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8423 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
8425 8426 8427 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8425 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
8427 8428 8429 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8427 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
8429 8430 8431 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8429 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
8431 8432 8433 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8431 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
8433 8434 8435 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8433 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
8435 8436 8437 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8435 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
8437 8438 8439 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8437 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
8439 8440 8441 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8439 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
8441 8442 8443 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8441 def total_tax_amount @total_tax_amount end |