Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Loding check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
8106 8107 8108 8109 8110 8111 8112 8113 8114 8115 8116 8117 8118 8119 8120 8121 8122 8123 8124 8125 8126 8127 8128 8129 8130 8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 8143 8144 8145 8146 8147 8148 8149 8150 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8106 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
8064 8065 8066 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8064 def address @address end |
#adults ⇒ Object
The number of adults on the booking
8066 8067 8068 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8066 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
8068 8069 8070 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8068 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
8070 8071 8072 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8070 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
8072 8073 8074 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8072 def category @category end |
#checkin_at ⇒ Object
Loding check-in time. Measured in seconds since the Unix epoch.
8074 8075 8076 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8074 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
8076 8077 8078 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8076 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
8078 8079 8080 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8078 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
8080 8081 8082 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8080 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
8082 8083 8084 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8082 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
8084 8085 8086 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8084 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
8086 8087 8088 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8086 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
8088 8089 8090 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8088 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
8090 8091 8092 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8090 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
8092 8093 8094 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8092 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
8094 8095 8096 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8094 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
8096 8097 8098 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8096 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
8098 8099 8100 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8098 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
8100 8101 8102 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8100 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
8102 8103 8104 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8102 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
8104 8105 8106 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8104 def total_tax_amount @total_tax_amount end |