Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
8089
8090
8091
8092
8093
8094
8095
8096
8097
8098
8099
8100
8101
8102
8103
8104
8105
8106
8107
8108
# File 'lib/stripe/services/payment_intent_service.rb', line 8064

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



8022
8023
8024
# File 'lib/stripe/services/payment_intent_service.rb', line 8022

def address
  @address
end

#adultsObject

The number of adults on the booking



8024
8025
8026
# File 'lib/stripe/services/payment_intent_service.rb', line 8024

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



8026
8027
8028
# File 'lib/stripe/services/payment_intent_service.rb', line 8026

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



8028
8029
8030
# File 'lib/stripe/services/payment_intent_service.rb', line 8028

def booking_number
  @booking_number
end

#categoryObject

The lodging category



8030
8031
8032
# File 'lib/stripe/services/payment_intent_service.rb', line 8030

def category
  @category
end

#checkin_atObject

Loding check-in time. Measured in seconds since the Unix epoch.



8032
8033
8034
# File 'lib/stripe/services/payment_intent_service.rb', line 8032

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



8034
8035
8036
# File 'lib/stripe/services/payment_intent_service.rb', line 8034

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



8036
8037
8038
# File 'lib/stripe/services/payment_intent_service.rb', line 8036

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



8038
8039
8040
# File 'lib/stripe/services/payment_intent_service.rb', line 8038

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



8040
8041
8042
# File 'lib/stripe/services/payment_intent_service.rb', line 8040

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



8042
8043
8044
# File 'lib/stripe/services/payment_intent_service.rb', line 8042

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



8044
8045
8046
# File 'lib/stripe/services/payment_intent_service.rb', line 8044

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



8046
8047
8048
# File 'lib/stripe/services/payment_intent_service.rb', line 8046

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



8048
8049
8050
# File 'lib/stripe/services/payment_intent_service.rb', line 8048

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



8050
8051
8052
# File 'lib/stripe/services/payment_intent_service.rb', line 8050

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



8052
8053
8054
# File 'lib/stripe/services/payment_intent_service.rb', line 8052

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



8054
8055
8056
# File 'lib/stripe/services/payment_intent_service.rb', line 8054

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



8056
8057
8058
# File 'lib/stripe/services/payment_intent_service.rb', line 8056

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



8058
8059
8060
# File 'lib/stripe/services/payment_intent_service.rb', line 8058

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



8060
8061
8062
# File 'lib/stripe/services/payment_intent_service.rb', line 8060

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



8062
8063
8064
# File 'lib/stripe/services/payment_intent_service.rb', line 8062

def total_tax_amount
  @total_tax_amount
end