Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
9080
9081
9082
9083
9084
9085
9086
# File 'lib/stripe/services/payment_intent_service.rb', line 9042

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



8980
8981
8982
# File 'lib/stripe/services/payment_intent_service.rb', line 8980

def address
  @address
end

#adultsObject

The number of adults on the booking



8983
8984
8985
# File 'lib/stripe/services/payment_intent_service.rb', line 8983

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



8986
8987
8988
# File 'lib/stripe/services/payment_intent_service.rb', line 8986

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



8989
8990
8991
# File 'lib/stripe/services/payment_intent_service.rb', line 8989

def booking_number
  @booking_number
end

#categoryObject

The lodging category



8992
8993
8994
# File 'lib/stripe/services/payment_intent_service.rb', line 8992

def category
  @category
end

#checkin_atObject

Loding check-in time. Measured in seconds since the Unix epoch.



8995
8996
8997
# File 'lib/stripe/services/payment_intent_service.rb', line 8995

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



8998
8999
9000
# File 'lib/stripe/services/payment_intent_service.rb', line 8998

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



9001
9002
9003
# File 'lib/stripe/services/payment_intent_service.rb', line 9001

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



9004
9005
9006
# File 'lib/stripe/services/payment_intent_service.rb', line 9004

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



9007
9008
9009
# File 'lib/stripe/services/payment_intent_service.rb', line 9007

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



9010
9011
9012
# File 'lib/stripe/services/payment_intent_service.rb', line 9010

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



9013
9014
9015
# File 'lib/stripe/services/payment_intent_service.rb', line 9013

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



9016
9017
9018
# File 'lib/stripe/services/payment_intent_service.rb', line 9016

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



9019
9020
9021
# File 'lib/stripe/services/payment_intent_service.rb', line 9019

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



9022
9023
9024
# File 'lib/stripe/services/payment_intent_service.rb', line 9022

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



9025
9026
9027
# File 'lib/stripe/services/payment_intent_service.rb', line 9025

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



9028
9029
9030
# File 'lib/stripe/services/payment_intent_service.rb', line 9028

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



9031
9032
9033
# File 'lib/stripe/services/payment_intent_service.rb', line 9031

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



9034
9035
9036
# File 'lib/stripe/services/payment_intent_service.rb', line 9034

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



9037
9038
9039
# File 'lib/stripe/services/payment_intent_service.rb', line 9037

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



9040
9041
9042
# File 'lib/stripe/services/payment_intent_service.rb', line 9040

def total_tax_amount
  @total_tax_amount
end