Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



8036
8037
8038
8039
8040
8041
8042
8043
8044
8045
8046
8047
8048
8049
8050
8051
8052
8053
8054
8055
8056
8057
8058
8059
8060
8061
8062
8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
# File 'lib/stripe/services/payment_intent_service.rb', line 8036

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



7994
7995
7996
# File 'lib/stripe/services/payment_intent_service.rb', line 7994

def address
  @address
end

#adultsObject

The number of adults on the booking



7996
7997
7998
# File 'lib/stripe/services/payment_intent_service.rb', line 7996

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



7998
7999
8000
# File 'lib/stripe/services/payment_intent_service.rb', line 7998

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



8000
8001
8002
# File 'lib/stripe/services/payment_intent_service.rb', line 8000

def booking_number
  @booking_number
end

#categoryObject

The lodging category



8002
8003
8004
# File 'lib/stripe/services/payment_intent_service.rb', line 8002

def category
  @category
end

#checkin_atObject

Loding check-in time. Measured in seconds since the Unix epoch.



8004
8005
8006
# File 'lib/stripe/services/payment_intent_service.rb', line 8004

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



8006
8007
8008
# File 'lib/stripe/services/payment_intent_service.rb', line 8006

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



8008
8009
8010
# File 'lib/stripe/services/payment_intent_service.rb', line 8008

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



8010
8011
8012
# File 'lib/stripe/services/payment_intent_service.rb', line 8010

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



8012
8013
8014
# File 'lib/stripe/services/payment_intent_service.rb', line 8012

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



8014
8015
8016
# File 'lib/stripe/services/payment_intent_service.rb', line 8014

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



8016
8017
8018
# File 'lib/stripe/services/payment_intent_service.rb', line 8016

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



8018
8019
8020
# File 'lib/stripe/services/payment_intent_service.rb', line 8018

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



8020
8021
8022
# File 'lib/stripe/services/payment_intent_service.rb', line 8020

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



8022
8023
8024
# File 'lib/stripe/services/payment_intent_service.rb', line 8022

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



8024
8025
8026
# File 'lib/stripe/services/payment_intent_service.rb', line 8024

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



8026
8027
8028
# File 'lib/stripe/services/payment_intent_service.rb', line 8026

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



8028
8029
8030
# File 'lib/stripe/services/payment_intent_service.rb', line 8028

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



8030
8031
8032
# File 'lib/stripe/services/payment_intent_service.rb', line 8030

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



8032
8033
8034
# File 'lib/stripe/services/payment_intent_service.rb', line 8032

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



8034
8035
8036
# File 'lib/stripe/services/payment_intent_service.rb', line 8034

def total_tax_amount
  @total_tax_amount
end