Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



9247
9248
9249
9250
9251
# File 'lib/stripe/services/payment_intent_service.rb', line 9247

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



9241
9242
9243
# File 'lib/stripe/services/payment_intent_service.rb', line 9241

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



9243
9244
9245
# File 'lib/stripe/services/payment_intent_service.rb', line 9243

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



9245
9246
9247
# File 'lib/stripe/services/payment_intent_service.rb', line 9245

def phone
  @phone
end