Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
8623 8624 8625 8626 8627 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8623 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
8617 8618 8619 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8617 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
8619 8620 8621 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8619 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
8621 8622 8623 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8621 def phone @phone end |