Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



8419
8420
8421
8422
8423
# File 'lib/stripe/services/payment_intent_service.rb', line 8419

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



8413
8414
8415
# File 'lib/stripe/services/payment_intent_service.rb', line 8413

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



8415
8416
8417
# File 'lib/stripe/services/payment_intent_service.rb', line 8415

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



8417
8418
8419
# File 'lib/stripe/services/payment_intent_service.rb', line 8417

def phone
  @phone
end