Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



8038
8039
8040
8041
8042
# File 'lib/stripe/services/payment_intent_service.rb', line 8038

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



8032
8033
8034
# File 'lib/stripe/services/payment_intent_service.rb', line 8032

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



8034
8035
8036
# File 'lib/stripe/services/payment_intent_service.rb', line 8034

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



8036
8037
8038
# File 'lib/stripe/services/payment_intent_service.rb', line 8036

def phone
  @phone
end