Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



7996
7997
7998
7999
8000
# File 'lib/stripe/services/payment_intent_service.rb', line 7996

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



7990
7991
7992
# File 'lib/stripe/services/payment_intent_service.rb', line 7990

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



7992
7993
7994
# File 'lib/stripe/services/payment_intent_service.rb', line 7992

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



7994
7995
7996
# File 'lib/stripe/services/payment_intent_service.rb', line 7994

def phone
  @phone
end