Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
7968 7969 7970 7971 7972 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7968 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
7962 7963 7964 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7962 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
7964 7965 7966 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7964 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
7966 7967 7968 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7966 def phone @phone end |