Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
8953 8954 8955 8956 8957 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8953 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
8945 8946 8947 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8945 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
8948 8949 8950 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8948 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
8951 8952 8953 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8951 def phone @phone end |