Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Subscription
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, BillingInterval
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#auto_renewal ⇒ Object
Info whether the subscription will be auto renewed upon expiry.
-
#billing_interval ⇒ Object
Subscription billing details for this purchase.
-
#ends_at ⇒ Object
Subscription end time.
-
#name ⇒ Object
Name of the product on subscription.
-
#starts_at ⇒ Object
Subscription start time.
Instance Method Summary collapse
-
#initialize(affiliate: nil, auto_renewal: nil, billing_interval: nil, ends_at: nil, name: nil, starts_at: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, auto_renewal: nil, billing_interval: nil, ends_at: nil, name: nil, starts_at: nil) ⇒ Subscription
Returns a new instance of Subscription.
8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 8197 8198 8199 8200 8201 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8187 def initialize( affiliate: nil, auto_renewal: nil, billing_interval: nil, ends_at: nil, name: nil, starts_at: nil ) @affiliate = affiliate @auto_renewal = auto_renewal @billing_interval = billing_interval @ends_at = ends_at @name = name @starts_at = starts_at end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
8175 8176 8177 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8175 def affiliate @affiliate end |
#auto_renewal ⇒ Object
Info whether the subscription will be auto renewed upon expiry.
8177 8178 8179 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8177 def auto_renewal @auto_renewal end |
#billing_interval ⇒ Object
Subscription billing details for this purchase.
8179 8180 8181 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8179 def billing_interval @billing_interval end |
#ends_at ⇒ Object
Subscription end time. Measured in seconds since the Unix epoch.
8181 8182 8183 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8181 def ends_at @ends_at end |
#name ⇒ Object
Name of the product on subscription. e.g. Apple Music Subscription
8183 8184 8185 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8183 def name @name end |
#starts_at ⇒ Object
Subscription start time. Measured in seconds since the Unix epoch.
8185 8186 8187 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8185 def starts_at @starts_at end |