Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



8461
8462
8463
8464
# File 'lib/stripe/services/payment_intent_service.rb', line 8461

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



8457
8458
8459
# File 'lib/stripe/services/payment_intent_service.rb', line 8457

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



8459
8460
8461
# File 'lib/stripe/services/payment_intent_service.rb', line 8459

def interval
  @interval
end