Class: Stripe::PaymentIntentService::ConfirmParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



8169
8170
8171
8172
# File 'lib/stripe/services/payment_intent_service.rb', line 8169

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



8165
8166
8167
# File 'lib/stripe/services/payment_intent_service.rb', line 8165

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



8167
8168
8169
# File 'lib/stripe/services/payment_intent_service.rb', line 8167

def interval
  @interval
end