Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, RadarOptions, Rechnung, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, StripeBalance, Swish, Twint, UsBankAccount, WechatPay, Zip
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If this is an ‘acss_debit` PaymentMethod, this hash contains details about the ACSS Debit payment method.
-
#affirm ⇒ Object
If this is an ‘affirm` PaymentMethod, this hash contains details about the Affirm payment method.
-
#afterpay_clearpay ⇒ Object
If this is an ‘AfterpayClearpay` PaymentMethod, this hash contains details about the AfterpayClearpay payment method.
-
#alipay ⇒ Object
If this is an ‘Alipay` PaymentMethod, this hash contains details about the Alipay payment method.
-
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#alma ⇒ Object
If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.
-
#amazon_pay ⇒ Object
If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.
-
#au_becs_debit ⇒ Object
If this is an ‘au_becs_debit` PaymentMethod, this hash contains details about the bank account.
-
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.
-
#bancontact ⇒ Object
If this is a ‘bancontact` PaymentMethod, this hash contains details about the Bancontact payment method.
-
#billie ⇒ Object
If this is a ‘billie` PaymentMethod, this hash contains details about the Billie payment method.
-
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
-
#blik ⇒ Object
If this is a ‘blik` PaymentMethod, this hash contains details about the BLIK payment method.
-
#boleto ⇒ Object
If this is a ‘boleto` PaymentMethod, this hash contains details about the Boleto payment method.
-
#cashapp ⇒ Object
If this is a ‘cashapp` PaymentMethod, this hash contains details about the Cash App Pay payment method.
-
#crypto ⇒ Object
If this is a Crypto PaymentMethod, this hash contains details about the Crypto payment method.
-
#customer_balance ⇒ Object
If this is a ‘customer_balance` PaymentMethod, this hash contains details about the CustomerBalance payment method.
-
#eps ⇒ Object
If this is an ‘eps` PaymentMethod, this hash contains details about the EPS payment method.
-
#fpx ⇒ Object
If this is an ‘fpx` PaymentMethod, this hash contains details about the FPX payment method.
-
#giropay ⇒ Object
If this is a ‘giropay` PaymentMethod, this hash contains details about the Giropay payment method.
-
#gopay ⇒ Object
If this is a Gopay PaymentMethod, this hash contains details about the Gopay payment method.
-
#grabpay ⇒ Object
If this is a ‘grabpay` PaymentMethod, this hash contains details about the GrabPay payment method.
-
#id_bank_transfer ⇒ Object
If this is an ‘IdBankTransfer` PaymentMethod, this hash contains details about the IdBankTransfer payment method.
-
#ideal ⇒ Object
If this is an ‘ideal` PaymentMethod, this hash contains details about the iDEAL payment method.
-
#interac_present ⇒ Object
If this is an ‘interac_present` PaymentMethod, this hash contains details about the Interac Present payment method.
-
#kakao_pay ⇒ Object
If this is a ‘kakao_pay` PaymentMethod, this hash contains details about the Kakao Pay payment method.
-
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method.
-
#konbini ⇒ Object
If this is a ‘konbini` PaymentMethod, this hash contains details about the Konbini payment method.
-
#kr_card ⇒ Object
If this is a ‘kr_card` PaymentMethod, this hash contains details about the Korean Card payment method.
-
#link ⇒ Object
If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.
-
#mb_way ⇒ Object
If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#mobilepay ⇒ Object
If this is a ‘mobilepay` PaymentMethod, this hash contains details about the MobilePay payment method.
-
#multibanco ⇒ Object
If this is a ‘multibanco` PaymentMethod, this hash contains details about the Multibanco payment method.
-
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.
-
#nz_bank_account ⇒ Object
If this is an nz_bank_account PaymentMethod, this hash contains details about the nz_bank_account payment method.
-
#oxxo ⇒ Object
If this is an ‘oxxo` PaymentMethod, this hash contains details about the OXXO payment method.
-
#p24 ⇒ Object
If this is a ‘p24` PaymentMethod, this hash contains details about the P24 payment method.
-
#pay_by_bank ⇒ Object
If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.
-
#payco ⇒ Object
If this is a ‘payco` PaymentMethod, this hash contains details about the PAYCO payment method.
-
#paynow ⇒ Object
If this is a ‘paynow` PaymentMethod, this hash contains details about the PayNow payment method.
-
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this hash contains details about the PayPal payment method.
-
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.
-
#pix ⇒ Object
If this is a ‘pix` PaymentMethod, this hash contains details about the Pix payment method.
-
#promptpay ⇒ Object
If this is a ‘promptpay` PaymentMethod, this hash contains details about the PromptPay payment method.
-
#qris ⇒ Object
If this is a ‘qris` PaymentMethod, this hash contains details about the QRIS payment method.
-
#radar_options ⇒ Object
Options to configure Radar.
-
#rechnung ⇒ Object
If this is a ‘rechnung` PaymentMethod, this hash contains details about the Rechnung payment method.
-
#revolut_pay ⇒ Object
If this is a ‘revolut_pay` PaymentMethod, this hash contains details about the Revolut Pay payment method.
-
#samsung_pay ⇒ Object
If this is a ‘samsung_pay` PaymentMethod, this hash contains details about the SamsungPay payment method.
-
#satispay ⇒ Object
If this is a ‘satispay` PaymentMethod, this hash contains details about the Satispay payment method.
-
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` PaymentMethod, this hash contains details about the SEPA debit bank account.
-
#shopeepay ⇒ Object
If this is a Shopeepay PaymentMethod, this hash contains details about the Shopeepay payment method.
-
#sofort ⇒ Object
If this is a ‘sofort` PaymentMethod, this hash contains details about the SOFORT payment method.
-
#stripe_balance ⇒ Object
This hash contains details about the Stripe balance payment method.
-
#swish ⇒ Object
If this is a ‘swish` PaymentMethod, this hash contains details about the Swish payment method.
-
#twint ⇒ Object
If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.
-
#type ⇒ Object
The type of the PaymentMethod.
-
#us_bank_account ⇒ Object
If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.
-
#wechat_pay ⇒ Object
If this is an ‘wechat_pay` PaymentMethod, this hash contains details about the wechat_pay payment method.
-
#zip ⇒ Object
If this is a ‘zip` PaymentMethod, this hash contains details about the Zip payment method.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, billing_details: nil, blik: nil, boleto: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, radar_options: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, swish: nil, twint: nil, type: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodData
Returns a new instance of PaymentMethodData.
9311 9312 9313 9314 9315 9316 9317 9318 9319 9320 9321 9322 9323 9324 9325 9326 9327 9328 9329 9330 9331 9332 9333 9334 9335 9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 9355 9356 9357 9358 9359 9360 9361 9362 9363 9364 9365 9366 9367 9368 9369 9370 9371 9372 9373 9374 9375 9376 9377 9378 9379 9380 9381 9382 9383 9384 9385 9386 9387 9388 9389 9390 9391 9392 9393 9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 9425 9426 9427 9428 9429 9430 9431 9432 9433 9434 9435 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9311 def initialize( acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, billing_details: nil, blik: nil, boleto: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, radar_options: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, swish: nil, twint: nil, type: nil, us_bank_account: nil, wechat_pay: nil, zip: nil ) @acss_debit = acss_debit @affirm = affirm @afterpay_clearpay = afterpay_clearpay @alipay = alipay @allow_redisplay = allow_redisplay @alma = alma @amazon_pay = amazon_pay @au_becs_debit = au_becs_debit @bacs_debit = bacs_debit @bancontact = bancontact @billie = billie @billing_details = billing_details @blik = blik @boleto = boleto @cashapp = cashapp @crypto = crypto @customer_balance = customer_balance @eps = eps @fpx = fpx @giropay = giropay @gopay = gopay @grabpay = grabpay @id_bank_transfer = id_bank_transfer @ideal = ideal @interac_present = interac_present @kakao_pay = kakao_pay @klarna = klarna @konbini = konbini @kr_card = kr_card @link = link @mb_way = mb_way @metadata = @mobilepay = mobilepay @multibanco = multibanco @naver_pay = naver_pay @nz_bank_account = nz_bank_account @oxxo = oxxo @p24 = p24 @pay_by_bank = pay_by_bank @payco = payco @paynow = paynow @paypal = paypal @payto = payto @pix = pix @promptpay = promptpay @qris = qris @radar_options = @rechnung = rechnung @revolut_pay = revolut_pay @samsung_pay = samsung_pay @satispay = satispay @sepa_debit = sepa_debit @shopeepay = shopeepay @sofort = sofort @stripe_balance = stripe_balance @swish = swish @twint = twint @type = type @us_bank_account = us_bank_account @wechat_pay = wechat_pay @zip = zip end |
Instance Attribute Details
#acss_debit ⇒ Object
If this is an ‘acss_debit` PaymentMethod, this hash contains details about the ACSS Debit payment method.
9189 9190 9191 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9189 def acss_debit @acss_debit end |
#affirm ⇒ Object
If this is an ‘affirm` PaymentMethod, this hash contains details about the Affirm payment method.
9191 9192 9193 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9191 def affirm @affirm end |
#afterpay_clearpay ⇒ Object
If this is an ‘AfterpayClearpay` PaymentMethod, this hash contains details about the AfterpayClearpay payment method.
9193 9194 9195 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9193 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
If this is an ‘Alipay` PaymentMethod, this hash contains details about the Alipay payment method.
9195 9196 9197 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9195 def alipay @alipay end |
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.
9197 9198 9199 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9197 def allow_redisplay @allow_redisplay end |
#alma ⇒ Object
If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.
9199 9200 9201 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9199 def alma @alma end |
#amazon_pay ⇒ Object
If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.
9201 9202 9203 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9201 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object
If this is an ‘au_becs_debit` PaymentMethod, this hash contains details about the bank account.
9203 9204 9205 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9203 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.
9205 9206 9207 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9205 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object
If this is a ‘bancontact` PaymentMethod, this hash contains details about the Bancontact payment method.
9207 9208 9209 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9207 def bancontact @bancontact end |
#billie ⇒ Object
If this is a ‘billie` PaymentMethod, this hash contains details about the Billie payment method.
9209 9210 9211 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9209 def billie @billie end |
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
9211 9212 9213 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9211 def billing_details @billing_details end |
#blik ⇒ Object
If this is a ‘blik` PaymentMethod, this hash contains details about the BLIK payment method.
9213 9214 9215 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9213 def blik @blik end |
#boleto ⇒ Object
If this is a ‘boleto` PaymentMethod, this hash contains details about the Boleto payment method.
9215 9216 9217 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9215 def boleto @boleto end |
#cashapp ⇒ Object
If this is a ‘cashapp` PaymentMethod, this hash contains details about the Cash App Pay payment method.
9217 9218 9219 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9217 def cashapp @cashapp end |
#crypto ⇒ Object
If this is a Crypto PaymentMethod, this hash contains details about the Crypto payment method.
9219 9220 9221 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9219 def crypto @crypto end |
#customer_balance ⇒ Object
If this is a ‘customer_balance` PaymentMethod, this hash contains details about the CustomerBalance payment method.
9221 9222 9223 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9221 def customer_balance @customer_balance end |
#eps ⇒ Object
If this is an ‘eps` PaymentMethod, this hash contains details about the EPS payment method.
9223 9224 9225 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9223 def eps @eps end |
#fpx ⇒ Object
If this is an ‘fpx` PaymentMethod, this hash contains details about the FPX payment method.
9225 9226 9227 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9225 def fpx @fpx end |
#giropay ⇒ Object
If this is a ‘giropay` PaymentMethod, this hash contains details about the Giropay payment method.
9227 9228 9229 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9227 def giropay @giropay end |
#gopay ⇒ Object
If this is a Gopay PaymentMethod, this hash contains details about the Gopay payment method.
9229 9230 9231 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9229 def gopay @gopay end |
#grabpay ⇒ Object
If this is a ‘grabpay` PaymentMethod, this hash contains details about the GrabPay payment method.
9231 9232 9233 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9231 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object
If this is an ‘IdBankTransfer` PaymentMethod, this hash contains details about the IdBankTransfer payment method.
9233 9234 9235 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9233 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object
If this is an ‘ideal` PaymentMethod, this hash contains details about the iDEAL payment method.
9235 9236 9237 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9235 def ideal @ideal end |
#interac_present ⇒ Object
If this is an ‘interac_present` PaymentMethod, this hash contains details about the Interac Present payment method.
9237 9238 9239 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9237 def interac_present @interac_present end |
#kakao_pay ⇒ Object
If this is a ‘kakao_pay` PaymentMethod, this hash contains details about the Kakao Pay payment method.
9239 9240 9241 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9239 def kakao_pay @kakao_pay end |
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method.
9241 9242 9243 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9241 def klarna @klarna end |
#konbini ⇒ Object
If this is a ‘konbini` PaymentMethod, this hash contains details about the Konbini payment method.
9243 9244 9245 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9243 def konbini @konbini end |
#kr_card ⇒ Object
If this is a ‘kr_card` PaymentMethod, this hash contains details about the Korean Card payment method.
9245 9246 9247 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9245 def kr_card @kr_card end |
#link ⇒ Object
If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.
9247 9248 9249 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9247 def link @link end |
#mb_way ⇒ Object
If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.
9249 9250 9251 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9249 def mb_way @mb_way end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
9251 9252 9253 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9251 def @metadata end |
#mobilepay ⇒ Object
If this is a ‘mobilepay` PaymentMethod, this hash contains details about the MobilePay payment method.
9253 9254 9255 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9253 def mobilepay @mobilepay end |
#multibanco ⇒ Object
If this is a ‘multibanco` PaymentMethod, this hash contains details about the Multibanco payment method.
9255 9256 9257 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9255 def multibanco @multibanco end |
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.
9257 9258 9259 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9257 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object
If this is an nz_bank_account PaymentMethod, this hash contains details about the nz_bank_account payment method.
9259 9260 9261 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9259 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object
If this is an ‘oxxo` PaymentMethod, this hash contains details about the OXXO payment method.
9261 9262 9263 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9261 def oxxo @oxxo end |
#p24 ⇒ Object
If this is a ‘p24` PaymentMethod, this hash contains details about the P24 payment method.
9263 9264 9265 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9263 def p24 @p24 end |
#pay_by_bank ⇒ Object
If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.
9265 9266 9267 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9265 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object
If this is a ‘payco` PaymentMethod, this hash contains details about the PAYCO payment method.
9267 9268 9269 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9267 def payco @payco end |
#paynow ⇒ Object
If this is a ‘paynow` PaymentMethod, this hash contains details about the PayNow payment method.
9269 9270 9271 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9269 def paynow @paynow end |
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this hash contains details about the PayPal payment method.
9271 9272 9273 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9271 def paypal @paypal end |
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.
9273 9274 9275 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9273 def payto @payto end |
#pix ⇒ Object
If this is a ‘pix` PaymentMethod, this hash contains details about the Pix payment method.
9275 9276 9277 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9275 def pix @pix end |
#promptpay ⇒ Object
If this is a ‘promptpay` PaymentMethod, this hash contains details about the PromptPay payment method.
9277 9278 9279 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9277 def promptpay @promptpay end |
#qris ⇒ Object
If this is a ‘qris` PaymentMethod, this hash contains details about the QRIS payment method.
9279 9280 9281 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9279 def qris @qris end |
#radar_options ⇒ Object
Options to configure Radar. See [Radar Session](stripe.com/docs/radar/radar-session) for more information.
9281 9282 9283 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9281 def @radar_options end |
#rechnung ⇒ Object
If this is a ‘rechnung` PaymentMethod, this hash contains details about the Rechnung payment method.
9283 9284 9285 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9283 def rechnung @rechnung end |
#revolut_pay ⇒ Object
If this is a ‘revolut_pay` PaymentMethod, this hash contains details about the Revolut Pay payment method.
9285 9286 9287 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9285 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object
If this is a ‘samsung_pay` PaymentMethod, this hash contains details about the SamsungPay payment method.
9287 9288 9289 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9287 def samsung_pay @samsung_pay end |
#satispay ⇒ Object
If this is a ‘satispay` PaymentMethod, this hash contains details about the Satispay payment method.
9289 9290 9291 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9289 def satispay @satispay end |
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` PaymentMethod, this hash contains details about the SEPA debit bank account.
9291 9292 9293 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9291 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object
If this is a Shopeepay PaymentMethod, this hash contains details about the Shopeepay payment method.
9293 9294 9295 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9293 def shopeepay @shopeepay end |
#sofort ⇒ Object
If this is a ‘sofort` PaymentMethod, this hash contains details about the SOFORT payment method.
9295 9296 9297 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9295 def sofort @sofort end |
#stripe_balance ⇒ Object
This hash contains details about the Stripe balance payment method.
9297 9298 9299 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9297 def stripe_balance @stripe_balance end |
#swish ⇒ Object
If this is a ‘swish` PaymentMethod, this hash contains details about the Swish payment method.
9299 9300 9301 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9299 def swish @swish end |
#twint ⇒ Object
If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.
9301 9302 9303 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9301 def twint @twint end |
#type ⇒ Object
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
9303 9304 9305 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9303 def type @type end |
#us_bank_account ⇒ Object
If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.
9305 9306 9307 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9305 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
If this is an ‘wechat_pay` PaymentMethod, this hash contains details about the wechat_pay payment method.
9307 9308 9309 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9307 def wechat_pay @wechat_pay end |
#zip ⇒ Object
If this is a ‘zip` PaymentMethod, this hash contains details about the Zip payment method.
9309 9310 9311 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9309 def zip @zip end |