Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
9764 9765 9766 9767 9768 9769 9770 9771 9772 9773 9774 9775 9776 9777 9778 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9764 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
9752 9753 9754 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9752 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
9754 9755 9756 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9754 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
9756 9757 9758 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9756 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
9758 9759 9760 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9758 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
9760 9761 9762 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9760 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
9762 9763 9764 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9762 def suffix @suffix end |