Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



5177
5178
5179
5180
5181
5182
5183
5184
5185
5186
5187
5188
5189
5190
5191
# File 'lib/stripe/services/payment_intent_service.rb', line 5177

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



5165
5166
5167
# File 'lib/stripe/services/payment_intent_service.rb', line 5165

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



5167
5168
5169
# File 'lib/stripe/services/payment_intent_service.rb', line 5167

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



5169
5170
5171
# File 'lib/stripe/services/payment_intent_service.rb', line 5169

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



5171
5172
5173
# File 'lib/stripe/services/payment_intent_service.rb', line 5171

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



5173
5174
5175
# File 'lib/stripe/services/payment_intent_service.rb', line 5173

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



5175
5176
5177
# File 'lib/stripe/services/payment_intent_service.rb', line 5175

def suffix
  @suffix
end