Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



9660
9661
9662
9663
9664
9665
9666
9667
9668
9669
9670
9671
9672
9673
9674
# File 'lib/stripe/services/payment_intent_service.rb', line 9660

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



9648
9649
9650
# File 'lib/stripe/services/payment_intent_service.rb', line 9648

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



9650
9651
9652
# File 'lib/stripe/services/payment_intent_service.rb', line 9650

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



9652
9653
9654
# File 'lib/stripe/services/payment_intent_service.rb', line 9652

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



9654
9655
9656
# File 'lib/stripe/services/payment_intent_service.rb', line 9654

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



9656
9657
9658
# File 'lib/stripe/services/payment_intent_service.rb', line 9656

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



9658
9659
9660
# File 'lib/stripe/services/payment_intent_service.rb', line 9658

def suffix
  @suffix
end