Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



9036
9037
9038
9039
9040
9041
9042
9043
9044
9045
9046
9047
9048
9049
9050
# File 'lib/stripe/services/payment_intent_service.rb', line 9036

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



9024
9025
9026
# File 'lib/stripe/services/payment_intent_service.rb', line 9024

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



9026
9027
9028
# File 'lib/stripe/services/payment_intent_service.rb', line 9026

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



9028
9029
9030
# File 'lib/stripe/services/payment_intent_service.rb', line 9028

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



9030
9031
9032
# File 'lib/stripe/services/payment_intent_service.rb', line 9030

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



9032
9033
9034
# File 'lib/stripe/services/payment_intent_service.rb', line 9032

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



9034
9035
9036
# File 'lib/stripe/services/payment_intent_service.rb', line 9034

def suffix
  @suffix
end