Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5157 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
5145 5146 5147 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5145 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
5147 5148 5149 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5147 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
5149 5150 5151 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5149 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
5151 5152 5153 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5151 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
5153 5154 5155 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5153 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
5155 5156 5157 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5155 def suffix @suffix end |