Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
8831 8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8831 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
8819 8820 8821 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8819 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
8821 8822 8823 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8821 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
8823 8824 8825 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8823 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
8825 8826 8827 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8825 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
8827 8828 8829 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8827 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
8829 8830 8831 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8829 def suffix @suffix end |