Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
# File 'lib/stripe/services/payment_intent_service.rb', line 4952

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



4940
4941
4942
# File 'lib/stripe/services/payment_intent_service.rb', line 4940

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



4942
4943
4944
# File 'lib/stripe/services/payment_intent_service.rb', line 4942

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



4944
4945
4946
# File 'lib/stripe/services/payment_intent_service.rb', line 4944

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



4946
4947
4948
# File 'lib/stripe/services/payment_intent_service.rb', line 4946

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



4948
4949
4950
# File 'lib/stripe/services/payment_intent_service.rb', line 4948

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



4950
4951
4952
# File 'lib/stripe/services/payment_intent_service.rb', line 4950

def suffix
  @suffix
end