Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
4952 4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4952 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
4940 4941 4942 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4940 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
4942 4943 4944 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4942 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
4944 4945 4946 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4944 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
4946 4947 4948 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4946 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
4948 4949 4950 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4948 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
4950 4951 4952 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4950 def suffix @suffix end |