Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



5061
5062
5063
5064
5065
5066
5067
5068
5069
5070
5071
5072
5073
5074
5075
# File 'lib/stripe/services/payment_intent_service.rb', line 5061

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



5049
5050
5051
# File 'lib/stripe/services/payment_intent_service.rb', line 5049

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



5051
5052
5053
# File 'lib/stripe/services/payment_intent_service.rb', line 5051

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



5053
5054
5055
# File 'lib/stripe/services/payment_intent_service.rb', line 5053

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



5055
5056
5057
# File 'lib/stripe/services/payment_intent_service.rb', line 5055

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



5057
5058
5059
# File 'lib/stripe/services/payment_intent_service.rb', line 5057

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



5059
5060
5061
# File 'lib/stripe/services/payment_intent_service.rb', line 5059

def suffix
  @suffix
end