Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



8822
8823
8824
8825
8826
8827
8828
8829
8830
8831
8832
8833
8834
8835
8836
# File 'lib/stripe/services/payment_intent_service.rb', line 8822

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



8810
8811
8812
# File 'lib/stripe/services/payment_intent_service.rb', line 8810

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



8812
8813
8814
# File 'lib/stripe/services/payment_intent_service.rb', line 8812

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



8814
8815
8816
# File 'lib/stripe/services/payment_intent_service.rb', line 8814

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



8816
8817
8818
# File 'lib/stripe/services/payment_intent_service.rb', line 8816

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



8818
8819
8820
# File 'lib/stripe/services/payment_intent_service.rb', line 8818

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



8820
8821
8822
# File 'lib/stripe/services/payment_intent_service.rb', line 8820

def suffix
  @suffix
end