Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



5018
5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
# File 'lib/stripe/services/payment_intent_service.rb', line 5018

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



5006
5007
5008
# File 'lib/stripe/services/payment_intent_service.rb', line 5006

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



5008
5009
5010
# File 'lib/stripe/services/payment_intent_service.rb', line 5008

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



5010
5011
5012
# File 'lib/stripe/services/payment_intent_service.rb', line 5010

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



5012
5013
5014
# File 'lib/stripe/services/payment_intent_service.rb', line 5012

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



5014
5015
5016
# File 'lib/stripe/services/payment_intent_service.rb', line 5014

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



5016
5017
5018
# File 'lib/stripe/services/payment_intent_service.rb', line 5016

def suffix
  @suffix
end