Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



8766
8767
8768
8769
8770
8771
8772
8773
8774
8775
8776
8777
8778
8779
8780
# File 'lib/stripe/services/payment_intent_service.rb', line 8766

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



8754
8755
8756
# File 'lib/stripe/services/payment_intent_service.rb', line 8754

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



8756
8757
8758
# File 'lib/stripe/services/payment_intent_service.rb', line 8756

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



8758
8759
8760
# File 'lib/stripe/services/payment_intent_service.rb', line 8758

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



8760
8761
8762
# File 'lib/stripe/services/payment_intent_service.rb', line 8760

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



8762
8763
8764
# File 'lib/stripe/services/payment_intent_service.rb', line 8762

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



8764
8765
8766
# File 'lib/stripe/services/payment_intent_service.rb', line 8764

def suffix
  @suffix
end