Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 8780 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8766 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
8754 8755 8756 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8754 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
8756 8757 8758 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8756 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
8758 8759 8760 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8758 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
8760 8761 8762 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8760 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
8762 8763 8764 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8762 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
8764 8765 8766 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8764 def suffix @suffix end |