Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::StripeBalance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::StripeBalance
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment.
-
#source_type ⇒ Object
The [source_type](docs.stripe.com/api/balance/balance_object#balance_object-available-source_types) of the balance.
Instance Method Summary collapse
-
#initialize(account: nil, source_type: nil) ⇒ StripeBalance
constructor
A new instance of StripeBalance.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, source_type: nil) ⇒ StripeBalance
Returns a new instance of StripeBalance.
8955 8956 8957 8958 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8955 def initialize(account: nil, source_type: nil) @account = account @source_type = source_type end |
Instance Attribute Details
#account ⇒ Object
The connected account ID whose Stripe balance to use as the source of payment
8951 8952 8953 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8951 def account @account end |
#source_type ⇒ Object
The [source_type](docs.stripe.com/api/balance/balance_object#balance_object-available-source_types) of the balance
8953 8954 8955 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8953 def source_type @source_type end |