Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
9795 9796 9797 9798 9799 9800 9801 9802 9803 9804 9805 9806 9807 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9795 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
9785 9786 9787 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9785 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
9787 9788 9789 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9787 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
9789 9790 9791 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9789 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
9791 9792 9793 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9791 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
9793 9794 9795 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9793 def routing_number @routing_number end |