Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8966 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
8956 8957 8958 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8956 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
8958 8959 8960 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8958 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
8960 8961 8962 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8960 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
8962 8963 8964 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8962 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
8964 8965 8966 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8964 def routing_number @routing_number end |