Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 5172 5173 5174 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5162 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
5152 5153 5154 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5152 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
5154 5155 5156 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5154 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
5156 5157 5158 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5156 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
5158 5159 5160 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5158 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
5160 5161 5162 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5160 def routing_number @routing_number end |