Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
8582 8583 8584 8585 8586 8587 8588 8589 8590 8591 8592 8593 8594 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8582 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
8572 8573 8574 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8572 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
8574 8575 8576 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8574 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
8576 8577 8578 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8576 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
8578 8579 8580 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8578 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
8580 8581 8582 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8580 def routing_number @routing_number end |