Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
8540 8541 8542 8543 8544 8545 8546 8547 8548 8549 8550 8551 8552 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8540 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
8530 8531 8532 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8530 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
8532 8533 8534 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8532 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
8534 8535 8536 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8534 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
8536 8537 8538 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8536 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
8538 8539 8540 |
# File 'lib/stripe/services/payment_intent_service.rb', line 8538 def routing_number @routing_number end |