Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
9548 9549 9550 9551 9552 9553 9554 9555 9556 9557 9558 9559 9560 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9548 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
9534 9535 9536 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9534 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
9537 9538 9539 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9537 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
9540 9541 9542 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9540 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
9543 9544 9545 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9543 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
9546 9547 9548 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9546 def routing_number @routing_number end |