Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Blik, Boleto, Card, CardPresent, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, SepaDebit, Shopeepay, Sofort, Swish, Twint, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, blik: nil, boleto: nil, card: nil, card_present: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



10497
10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
10508
10509
10510
10511
10512
10513
10514
10515
10516
10517
10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
10528
10529
10530
10531
10532
10533
10534
10535
10536
10537
10538
10539
10540
10541
10542
10543
10544
10545
10546
10547
10548
10549
10550
10551
10552
10553
10554
10555
10556
10557
10558
10559
10560
10561
10562
10563
10564
10565
10566
10567
10568
10569
10570
10571
10572
10573
10574
10575
10576
10577
10578
10579
10580
10581
10582
10583
10584
10585
10586
10587
10588
10589
10590
10591
10592
10593
10594
10595
10596
10597
10598
10599
10600
10601
10602
10603
10604
10605
# File 'lib/stripe/services/payment_intent_service.rb', line 10497

def initialize(
  acss_debit: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  alma: nil,
  amazon_pay: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  blik: nil,
  boleto: nil,
  card: nil,
  card_present: nil,
  cashapp: nil,
  customer_balance: nil,
  eps: nil,
  fpx: nil,
  giropay: nil,
  gopay: nil,
  grabpay: nil,
  id_bank_transfer: nil,
  ideal: nil,
  interac_present: nil,
  kakao_pay: nil,
  klarna: nil,
  konbini: nil,
  kr_card: nil,
  link: nil,
  mb_way: nil,
  mobilepay: nil,
  multibanco: nil,
  naver_pay: nil,
  oxxo: nil,
  p24: nil,
  pay_by_bank: nil,
  payco: nil,
  paynow: nil,
  paypal: nil,
  payto: nil,
  pix: nil,
  promptpay: nil,
  qris: nil,
  rechnung: nil,
  revolut_pay: nil,
  samsung_pay: nil,
  sepa_debit: nil,
  shopeepay: nil,
  sofort: nil,
  swish: nil,
  twint: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @alma = alma
  @amazon_pay = amazon_pay
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @blik = blik
  @boleto = boleto
  @card = card
  @card_present = card_present
  @cashapp = cashapp
  @customer_balance = customer_balance
  @eps = eps
  @fpx = fpx
  @giropay = giropay
  @gopay = gopay
  @grabpay = grabpay
  @id_bank_transfer = id_bank_transfer
  @ideal = ideal
  @interac_present = interac_present
  @kakao_pay = kakao_pay
  @klarna = klarna
  @konbini = konbini
  @kr_card = kr_card
  @link = link
  @mb_way = mb_way
  @mobilepay = mobilepay
  @multibanco = multibanco
  @naver_pay = naver_pay
  @oxxo = oxxo
  @p24 = p24
  @pay_by_bank = pay_by_bank
  @payco = payco
  @paynow = paynow
  @paypal = paypal
  @payto = payto
  @pix = pix
  @promptpay = promptpay
  @qris = qris
  @rechnung = rechnung
  @revolut_pay = revolut_pay
  @samsung_pay = samsung_pay
  @sepa_debit = sepa_debit
  @shopeepay = shopeepay
  @sofort = sofort
  @swish = swish
  @twint = twint
  @us_bank_account = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

If this is a ‘acss_debit` PaymentMethod, this sub-hash contains details about the ACSS Debit payment method options.



10391
10392
10393
# File 'lib/stripe/services/payment_intent_service.rb', line 10391

def acss_debit
  @acss_debit
end

#affirmObject

If this is an ‘affirm` PaymentMethod, this sub-hash contains details about the Affirm payment method options.



10393
10394
10395
# File 'lib/stripe/services/payment_intent_service.rb', line 10393

def affirm
  @affirm
end

#afterpay_clearpayObject

If this is a ‘afterpay_clearpay` PaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options.



10395
10396
10397
# File 'lib/stripe/services/payment_intent_service.rb', line 10395

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If this is a ‘alipay` PaymentMethod, this sub-hash contains details about the Alipay payment method options.



10397
10398
10399
# File 'lib/stripe/services/payment_intent_service.rb', line 10397

def alipay
  @alipay
end

#almaObject

If this is a ‘alma` PaymentMethod, this sub-hash contains details about the Alma payment method options.



10399
10400
10401
# File 'lib/stripe/services/payment_intent_service.rb', line 10399

def alma
  @alma
end

#amazon_payObject

If this is a ‘amazon_pay` PaymentMethod, this sub-hash contains details about the Amazon Pay payment method options.



10401
10402
10403
# File 'lib/stripe/services/payment_intent_service.rb', line 10401

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject

If this is a ‘au_becs_debit` PaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options.



10403
10404
10405
# File 'lib/stripe/services/payment_intent_service.rb', line 10403

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

If this is a ‘bacs_debit` PaymentMethod, this sub-hash contains details about the BACS Debit payment method options.



10405
10406
10407
# File 'lib/stripe/services/payment_intent_service.rb', line 10405

def bacs_debit
  @bacs_debit
end

#bancontactObject

If this is a ‘bancontact` PaymentMethod, this sub-hash contains details about the Bancontact payment method options.



10407
10408
10409
# File 'lib/stripe/services/payment_intent_service.rb', line 10407

def bancontact
  @bancontact
end

#blikObject

If this is a ‘blik` PaymentMethod, this sub-hash contains details about the BLIK payment method options.



10409
10410
10411
# File 'lib/stripe/services/payment_intent_service.rb', line 10409

def blik
  @blik
end

#boletoObject

If this is a ‘boleto` PaymentMethod, this sub-hash contains details about the Boleto payment method options.



10411
10412
10413
# File 'lib/stripe/services/payment_intent_service.rb', line 10411

def boleto
  @boleto
end

#cardObject

Configuration for any card payments attempted on this PaymentIntent.



10413
10414
10415
# File 'lib/stripe/services/payment_intent_service.rb', line 10413

def card
  @card
end

#card_presentObject

If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.



10415
10416
10417
# File 'lib/stripe/services/payment_intent_service.rb', line 10415

def card_present
  @card_present
end

#cashappObject

If this is a ‘cashapp` PaymentMethod, this sub-hash contains details about the Cash App Pay payment method options.



10417
10418
10419
# File 'lib/stripe/services/payment_intent_service.rb', line 10417

def cashapp
  @cashapp
end

#customer_balanceObject

If this is a ‘customer balance` PaymentMethod, this sub-hash contains details about the customer balance payment method options.



10419
10420
10421
# File 'lib/stripe/services/payment_intent_service.rb', line 10419

def customer_balance
  @customer_balance
end

#epsObject

If this is a ‘eps` PaymentMethod, this sub-hash contains details about the EPS payment method options.



10421
10422
10423
# File 'lib/stripe/services/payment_intent_service.rb', line 10421

def eps
  @eps
end

#fpxObject

If this is a ‘fpx` PaymentMethod, this sub-hash contains details about the FPX payment method options.



10423
10424
10425
# File 'lib/stripe/services/payment_intent_service.rb', line 10423

def fpx
  @fpx
end

#giropayObject

If this is a ‘giropay` PaymentMethod, this sub-hash contains details about the Giropay payment method options.



10425
10426
10427
# File 'lib/stripe/services/payment_intent_service.rb', line 10425

def giropay
  @giropay
end

#gopayObject

If this is a ‘gopay` PaymentMethod, this sub-hash contains details about the GoPay payment method options.



10427
10428
10429
# File 'lib/stripe/services/payment_intent_service.rb', line 10427

def gopay
  @gopay
end

#grabpayObject

If this is a ‘grabpay` PaymentMethod, this sub-hash contains details about the Grabpay payment method options.



10429
10430
10431
# File 'lib/stripe/services/payment_intent_service.rb', line 10429

def grabpay
  @grabpay
end

#id_bank_transferObject

If this is a ‘id_bank_transfer` PaymentMethod, this sub-hash contains details about the Indonesia Bank Transfer payment method options.



10431
10432
10433
# File 'lib/stripe/services/payment_intent_service.rb', line 10431

def id_bank_transfer
  @id_bank_transfer
end

#idealObject

If this is a ‘ideal` PaymentMethod, this sub-hash contains details about the Ideal payment method options.



10433
10434
10435
# File 'lib/stripe/services/payment_intent_service.rb', line 10433

def ideal
  @ideal
end

#interac_presentObject

If this is a ‘interac_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.



10435
10436
10437
# File 'lib/stripe/services/payment_intent_service.rb', line 10435

def interac_present
  @interac_present
end

#kakao_payObject

If this is a ‘kakao_pay` PaymentMethod, this sub-hash contains details about the Kakao Pay payment method options.



10437
10438
10439
# File 'lib/stripe/services/payment_intent_service.rb', line 10437

def kakao_pay
  @kakao_pay
end

#klarnaObject

If this is a ‘klarna` PaymentMethod, this sub-hash contains details about the Klarna payment method options.



10439
10440
10441
# File 'lib/stripe/services/payment_intent_service.rb', line 10439

def klarna
  @klarna
end

#konbiniObject

If this is a ‘konbini` PaymentMethod, this sub-hash contains details about the Konbini payment method options.



10441
10442
10443
# File 'lib/stripe/services/payment_intent_service.rb', line 10441

def konbini
  @konbini
end

#kr_cardObject

If this is a ‘kr_card` PaymentMethod, this sub-hash contains details about the KR Card payment method options.



10443
10444
10445
# File 'lib/stripe/services/payment_intent_service.rb', line 10443

def kr_card
  @kr_card
end

If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options.



10445
10446
10447
# File 'lib/stripe/services/payment_intent_service.rb', line 10445

def link
  @link
end

#mb_wayObject

If this is a ‘mb_way` PaymentMethod, this sub-hash contains details about the MB WAY payment method options.



10447
10448
10449
# File 'lib/stripe/services/payment_intent_service.rb', line 10447

def mb_way
  @mb_way
end

#mobilepayObject

If this is a ‘MobilePay` PaymentMethod, this sub-hash contains details about the MobilePay payment method options.



10449
10450
10451
# File 'lib/stripe/services/payment_intent_service.rb', line 10449

def mobilepay
  @mobilepay
end

#multibancoObject

If this is a ‘multibanco` PaymentMethod, this sub-hash contains details about the Multibanco payment method options.



10451
10452
10453
# File 'lib/stripe/services/payment_intent_service.rb', line 10451

def multibanco
  @multibanco
end

If this is a ‘naver_pay` PaymentMethod, this sub-hash contains details about the Naver Pay payment method options.



10453
10454
10455
# File 'lib/stripe/services/payment_intent_service.rb', line 10453

def naver_pay
  @naver_pay
end

#oxxoObject

If this is a ‘oxxo` PaymentMethod, this sub-hash contains details about the OXXO payment method options.



10455
10456
10457
# File 'lib/stripe/services/payment_intent_service.rb', line 10455

def oxxo
  @oxxo
end

#p24Object

If this is a ‘p24` PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options.



10457
10458
10459
# File 'lib/stripe/services/payment_intent_service.rb', line 10457

def p24
  @p24
end

#pay_by_bankObject

If this is a ‘pay_by_bank` PaymentMethod, this sub-hash contains details about the PayByBank payment method options.



10459
10460
10461
# File 'lib/stripe/services/payment_intent_service.rb', line 10459

def pay_by_bank
  @pay_by_bank
end

#paycoObject

If this is a ‘payco` PaymentMethod, this sub-hash contains details about the PAYCO payment method options.



10461
10462
10463
# File 'lib/stripe/services/payment_intent_service.rb', line 10461

def payco
  @payco
end

#paynowObject

If this is a ‘paynow` PaymentMethod, this sub-hash contains details about the PayNow payment method options.



10463
10464
10465
# File 'lib/stripe/services/payment_intent_service.rb', line 10463

def paynow
  @paynow
end

#paypalObject

If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.



10465
10466
10467
# File 'lib/stripe/services/payment_intent_service.rb', line 10465

def paypal
  @paypal
end

#paytoObject

If this is a ‘payto` PaymentMethod, this sub-hash contains details about the PayTo payment method options.



10467
10468
10469
# File 'lib/stripe/services/payment_intent_service.rb', line 10467

def payto
  @payto
end

#pixObject

If this is a ‘pix` PaymentMethod, this sub-hash contains details about the Pix payment method options.



10469
10470
10471
# File 'lib/stripe/services/payment_intent_service.rb', line 10469

def pix
  @pix
end

#promptpayObject

If this is a ‘promptpay` PaymentMethod, this sub-hash contains details about the PromptPay payment method options.



10471
10472
10473
# File 'lib/stripe/services/payment_intent_service.rb', line 10471

def promptpay
  @promptpay
end

#qrisObject

If this is a ‘qris` PaymentMethod, this sub-hash contains details about the QRIS payment method options.



10473
10474
10475
# File 'lib/stripe/services/payment_intent_service.rb', line 10473

def qris
  @qris
end

#rechnungObject

If this is a ‘rechnung` PaymentMethod, this sub-hash contains details about the Rechnung payment method options.



10475
10476
10477
# File 'lib/stripe/services/payment_intent_service.rb', line 10475

def rechnung
  @rechnung
end

#revolut_payObject

If this is a ‘revolut_pay` PaymentMethod, this sub-hash contains details about the Revolut Pay payment method options.



10477
10478
10479
# File 'lib/stripe/services/payment_intent_service.rb', line 10477

def revolut_pay
  @revolut_pay
end

#samsung_payObject

If this is a ‘samsung_pay` PaymentMethod, this sub-hash contains details about the Samsung Pay payment method options.



10479
10480
10481
# File 'lib/stripe/services/payment_intent_service.rb', line 10479

def samsung_pay
  @samsung_pay
end

#sepa_debitObject

If this is a ‘sepa_debit` PaymentIntent, this sub-hash contains details about the SEPA Debit payment method options.



10481
10482
10483
# File 'lib/stripe/services/payment_intent_service.rb', line 10481

def sepa_debit
  @sepa_debit
end

#shopeepayObject

If this is a ‘shopeepay` PaymentMethod, this sub-hash contains details about the ShopeePay payment method options.



10483
10484
10485
# File 'lib/stripe/services/payment_intent_service.rb', line 10483

def shopeepay
  @shopeepay
end

#sofortObject

If this is a ‘sofort` PaymentMethod, this sub-hash contains details about the SOFORT payment method options.



10485
10486
10487
# File 'lib/stripe/services/payment_intent_service.rb', line 10485

def sofort
  @sofort
end

#swishObject

If this is a ‘Swish` PaymentMethod, this sub-hash contains details about the Swish payment method options.



10487
10488
10489
# File 'lib/stripe/services/payment_intent_service.rb', line 10487

def swish
  @swish
end

#twintObject

If this is a ‘twint` PaymentMethod, this sub-hash contains details about the TWINT payment method options.



10489
10490
10491
# File 'lib/stripe/services/payment_intent_service.rb', line 10489

def twint
  @twint
end

#us_bank_accountObject

If this is a ‘us_bank_account` PaymentMethod, this sub-hash contains details about the US bank account payment method options.



10491
10492
10493
# File 'lib/stripe/services/payment_intent_service.rb', line 10491

def 
  @us_bank_account
end

#wechat_payObject

If this is a ‘wechat_pay` PaymentMethod, this sub-hash contains details about the WeChat Pay payment method options.



10493
10494
10495
# File 'lib/stripe/services/payment_intent_service.rb', line 10493

def wechat_pay
  @wechat_pay
end

#zipObject

If this is a ‘zip` PaymentMethod, this sub-hash contains details about the Zip payment method options.



10495
10496
10497
# File 'lib/stripe/services/payment_intent_service.rb', line 10495

def zip
  @zip
end