Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Blik, Boleto, Card, CardPresent, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, Oxxo, P24, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, SepaDebit, Shopeepay, Sofort, Swish, Twint, UsBankAccount, WechatPay, Zip
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If this is a ‘acss_debit` PaymentMethod, this sub-hash contains details about the ACSS Debit payment method options.
-
#affirm ⇒ Object
If this is an ‘affirm` PaymentMethod, this sub-hash contains details about the Affirm payment method options.
-
#afterpay_clearpay ⇒ Object
If this is a ‘afterpay_clearpay` PaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options.
-
#alipay ⇒ Object
If this is a ‘alipay` PaymentMethod, this sub-hash contains details about the Alipay payment method options.
-
#alma ⇒ Object
If this is a ‘alma` PaymentMethod, this sub-hash contains details about the Alma payment method options.
-
#amazon_pay ⇒ Object
If this is a ‘amazon_pay` PaymentMethod, this sub-hash contains details about the Amazon Pay payment method options.
-
#au_becs_debit ⇒ Object
If this is a ‘au_becs_debit` PaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options.
-
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` PaymentMethod, this sub-hash contains details about the BACS Debit payment method options.
-
#bancontact ⇒ Object
If this is a ‘bancontact` PaymentMethod, this sub-hash contains details about the Bancontact payment method options.
-
#blik ⇒ Object
If this is a ‘blik` PaymentMethod, this sub-hash contains details about the BLIK payment method options.
-
#boleto ⇒ Object
If this is a ‘boleto` PaymentMethod, this sub-hash contains details about the Boleto payment method options.
-
#card ⇒ Object
Configuration for any card payments attempted on this PaymentIntent.
-
#card_present ⇒ Object
If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.
-
#cashapp ⇒ Object
If this is a ‘cashapp` PaymentMethod, this sub-hash contains details about the Cash App Pay payment method options.
-
#customer_balance ⇒ Object
If this is a ‘customer balance` PaymentMethod, this sub-hash contains details about the customer balance payment method options.
-
#eps ⇒ Object
If this is a ‘eps` PaymentMethod, this sub-hash contains details about the EPS payment method options.
-
#fpx ⇒ Object
If this is a ‘fpx` PaymentMethod, this sub-hash contains details about the FPX payment method options.
-
#giropay ⇒ Object
If this is a ‘giropay` PaymentMethod, this sub-hash contains details about the Giropay payment method options.
-
#gopay ⇒ Object
If this is a ‘gopay` PaymentMethod, this sub-hash contains details about the GoPay payment method options.
-
#grabpay ⇒ Object
If this is a ‘grabpay` PaymentMethod, this sub-hash contains details about the Grabpay payment method options.
-
#id_bank_transfer ⇒ Object
If this is a ‘id_bank_transfer` PaymentMethod, this sub-hash contains details about the Indonesia Bank Transfer payment method options.
-
#ideal ⇒ Object
If this is a ‘ideal` PaymentMethod, this sub-hash contains details about the Ideal payment method options.
-
#interac_present ⇒ Object
If this is a ‘interac_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.
-
#kakao_pay ⇒ Object
If this is a ‘kakao_pay` PaymentMethod, this sub-hash contains details about the Kakao Pay payment method options.
-
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this sub-hash contains details about the Klarna payment method options.
-
#konbini ⇒ Object
If this is a ‘konbini` PaymentMethod, this sub-hash contains details about the Konbini payment method options.
-
#kr_card ⇒ Object
If this is a ‘kr_card` PaymentMethod, this sub-hash contains details about the KR Card payment method options.
-
#link ⇒ Object
If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options.
-
#mb_way ⇒ Object
If this is a ‘mb_way` PaymentMethod, this sub-hash contains details about the MB WAY payment method options.
-
#mobilepay ⇒ Object
If this is a ‘MobilePay` PaymentMethod, this sub-hash contains details about the MobilePay payment method options.
-
#multibanco ⇒ Object
If this is a ‘multibanco` PaymentMethod, this sub-hash contains details about the Multibanco payment method options.
-
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this sub-hash contains details about the Naver Pay payment method options.
-
#oxxo ⇒ Object
If this is a ‘oxxo` PaymentMethod, this sub-hash contains details about the OXXO payment method options.
-
#p24 ⇒ Object
If this is a ‘p24` PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options.
-
#payco ⇒ Object
If this is a ‘payco` PaymentMethod, this sub-hash contains details about the PAYCO payment method options.
-
#paynow ⇒ Object
If this is a ‘paynow` PaymentMethod, this sub-hash contains details about the PayNow payment method options.
-
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.
-
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this sub-hash contains details about the PayTo payment method options.
-
#pix ⇒ Object
If this is a ‘pix` PaymentMethod, this sub-hash contains details about the Pix payment method options.
-
#promptpay ⇒ Object
If this is a ‘promptpay` PaymentMethod, this sub-hash contains details about the PromptPay payment method options.
-
#qris ⇒ Object
If this is a ‘qris` PaymentMethod, this sub-hash contains details about the QRIS payment method options.
-
#rechnung ⇒ Object
If this is a ‘rechnung` PaymentMethod, this sub-hash contains details about the Rechnung payment method options.
-
#revolut_pay ⇒ Object
If this is a ‘revolut_pay` PaymentMethod, this sub-hash contains details about the Revolut Pay payment method options.
-
#samsung_pay ⇒ Object
If this is a ‘samsung_pay` PaymentMethod, this sub-hash contains details about the Samsung Pay payment method options.
-
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` PaymentIntent, this sub-hash contains details about the SEPA Debit payment method options.
-
#shopeepay ⇒ Object
If this is a ‘shopeepay` PaymentMethod, this sub-hash contains details about the ShopeePay payment method options.
-
#sofort ⇒ Object
If this is a ‘sofort` PaymentMethod, this sub-hash contains details about the SOFORT payment method options.
-
#swish ⇒ Object
If this is a ‘Swish` PaymentMethod, this sub-hash contains details about the Swish payment method options.
-
#twint ⇒ Object
If this is a ‘twint` PaymentMethod, this sub-hash contains details about the TWINT payment method options.
-
#us_bank_account ⇒ Object
If this is a ‘us_bank_account` PaymentMethod, this sub-hash contains details about the US bank account payment method options.
-
#wechat_pay ⇒ Object
If this is a ‘wechat_pay` PaymentMethod, this sub-hash contains details about the WeChat Pay payment method options.
-
#zip ⇒ Object
If this is a ‘zip` PaymentMethod, this sub-hash contains details about the Zip payment method options.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, blik: nil, boleto: nil, card: nil, card_present: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, oxxo: nil, p24: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
10394 10395 10396 10397 10398 10399 10400 10401 10402 10403 10404 10405 10406 10407 10408 10409 10410 10411 10412 10413 10414 10415 10416 10417 10418 10419 10420 10421 10422 10423 10424 10425 10426 10427 10428 10429 10430 10431 10432 10433 10434 10435 10436 10437 10438 10439 10440 10441 10442 10443 10444 10445 10446 10447 10448 10449 10450 10451 10452 10453 10454 10455 10456 10457 10458 10459 10460 10461 10462 10463 10464 10465 10466 10467 10468 10469 10470 10471 10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 10482 10483 10484 10485 10486 10487 10488 10489 10490 10491 10492 10493 10494 10495 10496 10497 10498 10499 10500 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10394 def initialize( acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, blik: nil, boleto: nil, card: nil, card_present: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, oxxo: nil, p24: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil ) @acss_debit = acss_debit @affirm = affirm @afterpay_clearpay = afterpay_clearpay @alipay = alipay @alma = alma @amazon_pay = amazon_pay @au_becs_debit = au_becs_debit @bacs_debit = bacs_debit @bancontact = bancontact @blik = blik @boleto = boleto @card = card @card_present = card_present @cashapp = cashapp @customer_balance = customer_balance @eps = eps @fpx = fpx @giropay = giropay @gopay = gopay @grabpay = grabpay @id_bank_transfer = id_bank_transfer @ideal = ideal @interac_present = interac_present @kakao_pay = kakao_pay @klarna = klarna @konbini = konbini @kr_card = kr_card @link = link @mb_way = mb_way @mobilepay = mobilepay @multibanco = multibanco @naver_pay = naver_pay @oxxo = oxxo @p24 = p24 @payco = payco @paynow = paynow @paypal = paypal @payto = payto @pix = pix @promptpay = promptpay @qris = qris @rechnung = rechnung @revolut_pay = revolut_pay @samsung_pay = samsung_pay @sepa_debit = sepa_debit @shopeepay = shopeepay @sofort = sofort @swish = swish @twint = twint @us_bank_account = us_bank_account @wechat_pay = wechat_pay @zip = zip end |
Instance Attribute Details
#acss_debit ⇒ Object
If this is a ‘acss_debit` PaymentMethod, this sub-hash contains details about the ACSS Debit payment method options.
10290 10291 10292 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10290 def acss_debit @acss_debit end |
#affirm ⇒ Object
If this is an ‘affirm` PaymentMethod, this sub-hash contains details about the Affirm payment method options.
10292 10293 10294 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10292 def affirm @affirm end |
#afterpay_clearpay ⇒ Object
If this is a ‘afterpay_clearpay` PaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options.
10294 10295 10296 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10294 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
If this is a ‘alipay` PaymentMethod, this sub-hash contains details about the Alipay payment method options.
10296 10297 10298 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10296 def alipay @alipay end |
#alma ⇒ Object
If this is a ‘alma` PaymentMethod, this sub-hash contains details about the Alma payment method options.
10298 10299 10300 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10298 def alma @alma end |
#amazon_pay ⇒ Object
If this is a ‘amazon_pay` PaymentMethod, this sub-hash contains details about the Amazon Pay payment method options.
10300 10301 10302 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10300 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object
If this is a ‘au_becs_debit` PaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options.
10302 10303 10304 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10302 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` PaymentMethod, this sub-hash contains details about the BACS Debit payment method options.
10304 10305 10306 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10304 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object
If this is a ‘bancontact` PaymentMethod, this sub-hash contains details about the Bancontact payment method options.
10306 10307 10308 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10306 def bancontact @bancontact end |
#blik ⇒ Object
If this is a ‘blik` PaymentMethod, this sub-hash contains details about the BLIK payment method options.
10308 10309 10310 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10308 def blik @blik end |
#boleto ⇒ Object
If this is a ‘boleto` PaymentMethod, this sub-hash contains details about the Boleto payment method options.
10310 10311 10312 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10310 def boleto @boleto end |
#card ⇒ Object
Configuration for any card payments attempted on this PaymentIntent.
10312 10313 10314 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10312 def card @card end |
#card_present ⇒ Object
If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.
10314 10315 10316 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10314 def card_present @card_present end |
#cashapp ⇒ Object
If this is a ‘cashapp` PaymentMethod, this sub-hash contains details about the Cash App Pay payment method options.
10316 10317 10318 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10316 def cashapp @cashapp end |
#customer_balance ⇒ Object
If this is a ‘customer balance` PaymentMethod, this sub-hash contains details about the customer balance payment method options.
10318 10319 10320 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10318 def customer_balance @customer_balance end |
#eps ⇒ Object
If this is a ‘eps` PaymentMethod, this sub-hash contains details about the EPS payment method options.
10320 10321 10322 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10320 def eps @eps end |
#fpx ⇒ Object
If this is a ‘fpx` PaymentMethod, this sub-hash contains details about the FPX payment method options.
10322 10323 10324 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10322 def fpx @fpx end |
#giropay ⇒ Object
If this is a ‘giropay` PaymentMethod, this sub-hash contains details about the Giropay payment method options.
10324 10325 10326 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10324 def giropay @giropay end |
#gopay ⇒ Object
If this is a ‘gopay` PaymentMethod, this sub-hash contains details about the GoPay payment method options.
10326 10327 10328 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10326 def gopay @gopay end |
#grabpay ⇒ Object
If this is a ‘grabpay` PaymentMethod, this sub-hash contains details about the Grabpay payment method options.
10328 10329 10330 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10328 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object
If this is a ‘id_bank_transfer` PaymentMethod, this sub-hash contains details about the Indonesia Bank Transfer payment method options.
10330 10331 10332 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10330 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object
If this is a ‘ideal` PaymentMethod, this sub-hash contains details about the Ideal payment method options.
10332 10333 10334 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10332 def ideal @ideal end |
#interac_present ⇒ Object
If this is a ‘interac_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.
10334 10335 10336 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10334 def interac_present @interac_present end |
#kakao_pay ⇒ Object
If this is a ‘kakao_pay` PaymentMethod, this sub-hash contains details about the Kakao Pay payment method options.
10336 10337 10338 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10336 def kakao_pay @kakao_pay end |
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this sub-hash contains details about the Klarna payment method options.
10338 10339 10340 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10338 def klarna @klarna end |
#konbini ⇒ Object
If this is a ‘konbini` PaymentMethod, this sub-hash contains details about the Konbini payment method options.
10340 10341 10342 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10340 def konbini @konbini end |
#kr_card ⇒ Object
If this is a ‘kr_card` PaymentMethod, this sub-hash contains details about the KR Card payment method options.
10342 10343 10344 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10342 def kr_card @kr_card end |
#link ⇒ Object
If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options.
10344 10345 10346 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10344 def link @link end |
#mb_way ⇒ Object
If this is a ‘mb_way` PaymentMethod, this sub-hash contains details about the MB WAY payment method options.
10346 10347 10348 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10346 def mb_way @mb_way end |
#mobilepay ⇒ Object
If this is a ‘MobilePay` PaymentMethod, this sub-hash contains details about the MobilePay payment method options.
10348 10349 10350 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10348 def mobilepay @mobilepay end |
#multibanco ⇒ Object
If this is a ‘multibanco` PaymentMethod, this sub-hash contains details about the Multibanco payment method options.
10350 10351 10352 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10350 def multibanco @multibanco end |
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this sub-hash contains details about the Naver Pay payment method options.
10352 10353 10354 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10352 def naver_pay @naver_pay end |
#oxxo ⇒ Object
If this is a ‘oxxo` PaymentMethod, this sub-hash contains details about the OXXO payment method options.
10354 10355 10356 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10354 def oxxo @oxxo end |
#p24 ⇒ Object
If this is a ‘p24` PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options.
10356 10357 10358 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10356 def p24 @p24 end |
#payco ⇒ Object
If this is a ‘payco` PaymentMethod, this sub-hash contains details about the PAYCO payment method options.
10358 10359 10360 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10358 def payco @payco end |
#paynow ⇒ Object
If this is a ‘paynow` PaymentMethod, this sub-hash contains details about the PayNow payment method options.
10360 10361 10362 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10360 def paynow @paynow end |
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.
10362 10363 10364 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10362 def paypal @paypal end |
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this sub-hash contains details about the PayTo payment method options.
10364 10365 10366 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10364 def payto @payto end |
#pix ⇒ Object
If this is a ‘pix` PaymentMethod, this sub-hash contains details about the Pix payment method options.
10366 10367 10368 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10366 def pix @pix end |
#promptpay ⇒ Object
If this is a ‘promptpay` PaymentMethod, this sub-hash contains details about the PromptPay payment method options.
10368 10369 10370 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10368 def promptpay @promptpay end |
#qris ⇒ Object
If this is a ‘qris` PaymentMethod, this sub-hash contains details about the QRIS payment method options.
10370 10371 10372 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10370 def qris @qris end |
#rechnung ⇒ Object
If this is a ‘rechnung` PaymentMethod, this sub-hash contains details about the Rechnung payment method options.
10372 10373 10374 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10372 def rechnung @rechnung end |
#revolut_pay ⇒ Object
If this is a ‘revolut_pay` PaymentMethod, this sub-hash contains details about the Revolut Pay payment method options.
10374 10375 10376 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10374 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object
If this is a ‘samsung_pay` PaymentMethod, this sub-hash contains details about the Samsung Pay payment method options.
10376 10377 10378 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10376 def samsung_pay @samsung_pay end |
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` PaymentIntent, this sub-hash contains details about the SEPA Debit payment method options.
10378 10379 10380 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10378 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object
If this is a ‘shopeepay` PaymentMethod, this sub-hash contains details about the ShopeePay payment method options.
10380 10381 10382 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10380 def shopeepay @shopeepay end |
#sofort ⇒ Object
If this is a ‘sofort` PaymentMethod, this sub-hash contains details about the SOFORT payment method options.
10382 10383 10384 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10382 def sofort @sofort end |
#swish ⇒ Object
If this is a ‘Swish` PaymentMethod, this sub-hash contains details about the Swish payment method options.
10384 10385 10386 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10384 def swish @swish end |
#twint ⇒ Object
If this is a ‘twint` PaymentMethod, this sub-hash contains details about the TWINT payment method options.
10386 10387 10388 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10386 def twint @twint end |
#us_bank_account ⇒ Object
If this is a ‘us_bank_account` PaymentMethod, this sub-hash contains details about the US bank account payment method options.
10388 10389 10390 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10388 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
If this is a ‘wechat_pay` PaymentMethod, this sub-hash contains details about the WeChat Pay payment method options.
10390 10391 10392 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10390 def wechat_pay @wechat_pay end |
#zip ⇒ Object
If this is a ‘zip` PaymentMethod, this sub-hash contains details about the Zip payment method options.
10392 10393 10394 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10392 def zip @zip end |