Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step.
-
#interval_description ⇒ Object
Description of the mandate interval.
-
#payment_schedule ⇒ Object
Payment schedule for the mandate.
-
#transaction_type ⇒ Object
Transaction type of the mandate.
Instance Method Summary collapse
-
#initialize(custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
5487 5488 5489 5490 5491 5492 5493 5494 5495 5496 5497 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5487 def initialize( custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil ) @custom_mandate_url = custom_mandate_url @interval_description = interval_description @payment_schedule = payment_schedule @transaction_type = transaction_type end |
Instance Attribute Details
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.
5479 5480 5481 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5479 def custom_mandate_url @custom_mandate_url end |
#interval_description ⇒ Object
Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.
5481 5482 5483 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5481 def interval_description @interval_description end |
#payment_schedule ⇒ Object
Payment schedule for the mandate.
5483 5484 5485 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5483 def payment_schedule @payment_schedule end |
#transaction_type ⇒ Object
Transaction type of the mandate.
5485 5486 5487 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5485 def transaction_type @transaction_type end |