Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step.
-
#interval_description ⇒ Object
Description of the mandate interval.
-
#payment_schedule ⇒ Object
Payment schedule for the mandate.
-
#transaction_type ⇒ Object
Transaction type of the mandate.
Instance Method Summary collapse
-
#initialize(custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
9243 9244 9245 9246 9247 9248 9249 9250 9251 9252 9253 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9243 def initialize( custom_mandate_url: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil ) @custom_mandate_url = custom_mandate_url @interval_description = interval_description @payment_schedule = payment_schedule @transaction_type = transaction_type end |
Instance Attribute Details
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.
9235 9236 9237 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9235 def custom_mandate_url @custom_mandate_url end |
#interval_description ⇒ Object
Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.
9237 9238 9239 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9237 def interval_description @interval_description end |
#payment_schedule ⇒ Object
Payment schedule for the mandate.
9239 9240 9241 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9239 def payment_schedule @payment_schedule end |
#transaction_type ⇒ Object
Transaction type of the mandate.
9241 9242 9243 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9241 def transaction_type @transaction_type end |