Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Card

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Installments, MandateOptions, StatementDetails, ThreeDSecure

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capture_method: nil, cvc_token: nil, installments: nil, mandate_options: nil, moto: nil, network: nil, request_decremental_authorization: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_partial_authorization: nil, request_three_d_secure: nil, require_cvc_recollection: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil, statement_details: nil, three_d_secure: nil) ⇒ Card

Returns a new instance of Card.



9352
9353
9354
9355
9356
9357
9358
9359
9360
9361
9362
9363
9364
9365
9366
9367
9368
9369
9370
9371
9372
9373
9374
9375
9376
9377
9378
9379
9380
9381
9382
9383
9384
9385
9386
9387
9388
9389
9390
9391
9392
# File 'lib/stripe/services/payment_intent_service.rb', line 9352

def initialize(
  capture_method: nil,
  cvc_token: nil,
  installments: nil,
  mandate_options: nil,
  moto: nil,
  network: nil,
  request_decremental_authorization: nil,
  request_extended_authorization: nil,
  request_incremental_authorization: nil,
  request_multicapture: nil,
  request_overcapture: nil,
  request_partial_authorization: nil,
  request_three_d_secure: nil,
  require_cvc_recollection: nil,
  setup_future_usage: nil,
  statement_descriptor_suffix_kana: nil,
  statement_descriptor_suffix_kanji: nil,
  statement_details: nil,
  three_d_secure: nil
)
  @capture_method = capture_method
  @cvc_token = cvc_token
  @installments = installments
  @mandate_options = mandate_options
  @moto = moto
  @network = network
  @request_decremental_authorization = request_decremental_authorization
  @request_extended_authorization = request_extended_authorization
  @request_incremental_authorization = request_incremental_authorization
  @request_multicapture = request_multicapture
  @request_overcapture = request_overcapture
  @request_partial_authorization = request_partial_authorization
  @request_three_d_secure = request_three_d_secure
  @require_cvc_recollection = require_cvc_recollection
  @setup_future_usage = setup_future_usage
  @statement_descriptor_suffix_kana = statement_descriptor_suffix_kana
  @statement_descriptor_suffix_kanji = statement_descriptor_suffix_kanji
  @statement_details = statement_details
  @three_d_secure = three_d_secure
end

Instance Attribute Details

#capture_methodObject

Controls when the funds are captured from the customer’s account.

If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.

If ‘capture_method` is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.



9301
9302
9303
# File 'lib/stripe/services/payment_intent_service.rb', line 9301

def capture_method
  @capture_method
end

#cvc_tokenObject

A single-use ‘cvc_update` Token that represents a card CVC value. When provided, the CVC value will be verified during the card payment attempt. This parameter can only be provided during confirmation.



9303
9304
9305
# File 'lib/stripe/services/payment_intent_service.rb', line 9303

def cvc_token
  @cvc_token
end

#installmentsObject

Installment configuration for payments attempted on this PaymentIntent (Mexico Only).

For more information, see the [installments integration guide](stripe.com/docs/payments/installments).



9307
9308
9309
# File 'lib/stripe/services/payment_intent_service.rb', line 9307

def installments
  @installments
end

#mandate_optionsObject

Configuration options for setting up an eMandate for cards issued in India.



9309
9310
9311
# File 'lib/stripe/services/payment_intent_service.rb', line 9309

def mandate_options
  @mandate_options
end

#motoObject

When specified, this parameter indicates that a transaction will be marked as MOTO (Mail Order Telephone Order) and thus out of scope for SCA. This parameter can only be provided during confirmation.



9313
9314
9315
# File 'lib/stripe/services/payment_intent_service.rb', line 9313

def moto
  @moto
end

#networkObject

Selected network to process this PaymentIntent on. Depends on the available networks of the card attached to the PaymentIntent. Can be only set confirm-time.



9315
9316
9317
# File 'lib/stripe/services/payment_intent_service.rb', line 9315

def network
  @network
end

#request_decremental_authorizationObject

Request ability to [decrement the authorization](stripe.com/docs/payments/decremental-authorization) for this PaymentIntent.



9317
9318
9319
# File 'lib/stripe/services/payment_intent_service.rb', line 9317

def request_decremental_authorization
  @request_decremental_authorization
end

#request_extended_authorizationObject

Request ability to [capture beyond the standard authorization validity window](stripe.com/docs/payments/extended-authorization) for this PaymentIntent.



9319
9320
9321
# File 'lib/stripe/services/payment_intent_service.rb', line 9319

def request_extended_authorization
  @request_extended_authorization
end

#request_incremental_authorizationObject

Request ability to [increment the authorization](stripe.com/docs/payments/incremental-authorization) for this PaymentIntent.



9321
9322
9323
# File 'lib/stripe/services/payment_intent_service.rb', line 9321

def request_incremental_authorization
  @request_incremental_authorization
end

#request_multicaptureObject

Request ability to make [multiple captures](stripe.com/docs/payments/multicapture) for this PaymentIntent.



9323
9324
9325
# File 'lib/stripe/services/payment_intent_service.rb', line 9323

def request_multicapture
  @request_multicapture
end

#request_overcaptureObject

Request ability to [overcapture](stripe.com/docs/payments/overcapture) for this PaymentIntent.



9325
9326
9327
# File 'lib/stripe/services/payment_intent_service.rb', line 9325

def request_overcapture
  @request_overcapture
end

#request_partial_authorizationObject

Request partial authorization on this PaymentIntent.



9327
9328
9329
# File 'lib/stripe/services/payment_intent_service.rb', line 9327

def request_partial_authorization
  @request_partial_authorization
end

#request_three_d_secureObject

We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](stripe.com/docs/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.



9329
9330
9331
# File 'lib/stripe/services/payment_intent_service.rb', line 9329

def request_three_d_secure
  @request_three_d_secure
end

#require_cvc_recollectionObject

When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).



9331
9332
9333
# File 'lib/stripe/services/payment_intent_service.rb', line 9331

def require_cvc_recollection
  @require_cvc_recollection
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



9341
9342
9343
# File 'lib/stripe/services/payment_intent_service.rb', line 9341

def setup_future_usage
  @setup_future_usage
end

#statement_descriptor_suffix_kanaObject

Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.



9343
9344
9345
# File 'lib/stripe/services/payment_intent_service.rb', line 9343

def statement_descriptor_suffix_kana
  @statement_descriptor_suffix_kana
end

#statement_descriptor_suffix_kanjiObject

Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.



9345
9346
9347
# File 'lib/stripe/services/payment_intent_service.rb', line 9345

def statement_descriptor_suffix_kanji
  @statement_descriptor_suffix_kanji
end

#statement_detailsObject

Statement details for this payment intent. You can use this to override the merchant details shown on your customers’ statements.



9347
9348
9349
# File 'lib/stripe/services/payment_intent_service.rb', line 9347

def statement_details
  @statement_details
end

#three_d_secureObject

If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this payment.



9350
9351
9352
# File 'lib/stripe/services/payment_intent_service.rb', line 9350

def three_d_secure
  @three_d_secure
end