Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Card::Installments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Plan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, plan: nil) ⇒ Installments

Returns a new instance of Installments.



9557
9558
9559
9560
# File 'lib/stripe/services/payment_intent_service.rb', line 9557

def initialize(enabled: nil, plan: nil)
  @enabled = enabled
  @plan = plan
end

Instance Attribute Details

#enabledObject

Setting to true enables installments for this PaymentIntent. This will cause the response to contain a list of available installment plans. Setting to false will prevent any selected plan from applying to a charge.



9552
9553
9554
# File 'lib/stripe/services/payment_intent_service.rb', line 9552

def enabled
  @enabled
end

#planObject

The selected installment plan to use for this payment attempt. This parameter can only be provided during confirmation.



9555
9556
9557
# File 'lib/stripe/services/payment_intent_service.rb', line 9555

def plan
  @plan
end