Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



5562
5563
5564
5565
5566
# File 'lib/stripe/services/payment_intent_service.rb', line 5562

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



5555
5556
5557
# File 'lib/stripe/services/payment_intent_service.rb', line 5555

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



5558
5559
5560
# File 'lib/stripe/services/payment_intent_service.rb', line 5558

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`.



5560
5561
5562
# File 'lib/stripe/services/payment_intent_service.rb', line 5560

def type
  @type
end