Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Card::Installments::Plan
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Card::Installments::Plan
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#count ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`.
Instance Method Summary collapse
-
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
constructor
A new instance of Plan.
Methods inherited from RequestParams
Constructor Details
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
Returns a new instance of Plan.
9487 9488 9489 9490 9491 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9487 def initialize(count: nil, interval: nil, type: nil) @count = count @interval = interval @type = type end |
Instance Attribute Details
#count ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.
9480 9481 9482 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9480 def count @count end |
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.
9483 9484 9485 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9483 def interval @interval end |
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`.
9485 9486 9487 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9485 def type @type end |