Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



10400
10401
10402
10403
10404
10405
10406
10407
10408
10409
10410
10411
10412
10413
10414
10415
10416
10417
10418
10419
10420
# File 'lib/stripe/services/payment_intent_service.rb', line 10400

def initialize(
  amount: nil,
  amount_type: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



10382
10383
10384
# File 'lib/stripe/services/payment_intent_service.rb', line 10382

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



10384
10385
10386
# File 'lib/stripe/services/payment_intent_service.rb', line 10384

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



10386
10387
10388
# File 'lib/stripe/services/payment_intent_service.rb', line 10386

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



10388
10389
10390
# File 'lib/stripe/services/payment_intent_service.rb', line 10388

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



10390
10391
10392
# File 'lib/stripe/services/payment_intent_service.rb', line 10390

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



10392
10393
10394
# File 'lib/stripe/services/payment_intent_service.rb', line 10392

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



10394
10395
10396
# File 'lib/stripe/services/payment_intent_service.rb', line 10394

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



10396
10397
10398
# File 'lib/stripe/services/payment_intent_service.rb', line 10396

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are ‘india`.



10398
10399
10400
# File 'lib/stripe/services/payment_intent_service.rb', line 10398

def supported_types
  @supported_types
end