Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Card::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Card::MandateOptions
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments.
-
#amount_type ⇒ Object
One of ‘fixed` or `maximum`.
-
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
-
#end_date ⇒ Object
End date of the mandate or subscription.
-
#interval ⇒ Object
Specifies payment frequency.
-
#interval_count ⇒ Object
The number of intervals between payments.
-
#reference ⇒ Object
Unique identifier for the mandate or subscription.
-
#start_date ⇒ Object
Start date of the mandate or subscription.
-
#supported_types ⇒ Object
Specifies the type of mandates supported.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
9776 9777 9778 9779 9780 9781 9782 9783 9784 9785 9786 9787 9788 9789 9790 9791 9792 9793 9794 9795 9796 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9776 def initialize( amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil ) @amount = amount @amount_type = amount_type @description = description @end_date = end_date @interval = interval @interval_count = interval_count @reference = reference @start_date = start_date @supported_types = supported_types end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments.
9758 9759 9760 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9758 def amount @amount end |
#amount_type ⇒ Object
One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.
9760 9761 9762 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9760 def amount_type @amount_type end |
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
9762 9763 9764 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9762 def description @description end |
#end_date ⇒ Object
End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.
9764 9765 9766 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9764 def end_date @end_date end |
#interval ⇒ Object
Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.
9766 9767 9768 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9766 def interval @interval end |
#interval_count ⇒ Object
The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.
9768 9769 9770 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9768 def interval_count @interval_count end |
#reference ⇒ Object
Unique identifier for the mandate or subscription.
9770 9771 9772 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9770 def reference @reference end |
#start_date ⇒ Object
Start date of the mandate or subscription. Start date should not be lesser than yesterday.
9772 9773 9774 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9772 def start_date @start_date end |
#supported_types ⇒ Object
Specifies the type of mandates supported. Possible values are ‘india`.
9774 9775 9776 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9774 def supported_types @supported_types end |