Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



9567
9568
9569
9570
9571
9572
9573
9574
9575
9576
9577
9578
9579
9580
9581
9582
9583
9584
9585
9586
9587
# File 'lib/stripe/services/payment_intent_service.rb', line 9567

def initialize(
  amount: nil,
  amount_type: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



9549
9550
9551
# File 'lib/stripe/services/payment_intent_service.rb', line 9549

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



9551
9552
9553
# File 'lib/stripe/services/payment_intent_service.rb', line 9551

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



9553
9554
9555
# File 'lib/stripe/services/payment_intent_service.rb', line 9553

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



9555
9556
9557
# File 'lib/stripe/services/payment_intent_service.rb', line 9555

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



9557
9558
9559
# File 'lib/stripe/services/payment_intent_service.rb', line 9557

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



9559
9560
9561
# File 'lib/stripe/services/payment_intent_service.rb', line 9559

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



9561
9562
9563
# File 'lib/stripe/services/payment_intent_service.rb', line 9561

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



9563
9564
9565
# File 'lib/stripe/services/payment_intent_service.rb', line 9563

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are ‘india`.



9565
9566
9567
# File 'lib/stripe/services/payment_intent_service.rb', line 9565

def supported_types
  @supported_types
end