Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Card::ThreeDSecure
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Card::ThreeDSecure
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: NetworkOptions
Instance Attribute Summary collapse
-
#ares_trans_status ⇒ Object
The ‘transStatus` returned from the card Issuer’s ACS in the ARes.
-
#cryptogram ⇒ Object
The cryptogram, also known as the “authentication value” (AAV, CAVV or AEVV).
-
#electronic_commerce_indicator ⇒ Object
The Electronic Commerce Indicator (ECI) is returned by your 3D Secure provider and indicates what degree of authentication was performed.
-
#exemption_indicator ⇒ Object
The exemption requested via 3DS and accepted by the issuer at authentication time.
-
#network_options ⇒ Object
Network specific 3DS fields.
-
#requestor_challenge_indicator ⇒ Object
The challenge indicator (‘threeDSRequestorChallengeInd`) which was requested in the AReq sent to the card Issuer’s ACS.
-
#transaction_id ⇒ Object
For 3D Secure 1, the XID.
-
#version ⇒ Object
The version of 3D Secure that was performed.
Instance Method Summary collapse
-
#initialize(ares_trans_status: nil, cryptogram: nil, electronic_commerce_indicator: nil, exemption_indicator: nil, network_options: nil, requestor_challenge_indicator: nil, transaction_id: nil, version: nil) ⇒ ThreeDSecure
constructor
A new instance of ThreeDSecure.
Methods inherited from RequestParams
Constructor Details
#initialize(ares_trans_status: nil, cryptogram: nil, electronic_commerce_indicator: nil, exemption_indicator: nil, network_options: nil, requestor_challenge_indicator: nil, transaction_id: nil, version: nil) ⇒ ThreeDSecure
Returns a new instance of ThreeDSecure.
10519 10520 10521 10522 10523 10524 10525 10526 10527 10528 10529 10530 10531 10532 10533 10534 10535 10536 10537 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10519 def initialize( ares_trans_status: nil, cryptogram: nil, electronic_commerce_indicator: nil, exemption_indicator: nil, network_options: nil, requestor_challenge_indicator: nil, transaction_id: nil, version: nil ) @ares_trans_status = ares_trans_status @cryptogram = cryptogram @electronic_commerce_indicator = electronic_commerce_indicator @exemption_indicator = exemption_indicator @network_options = @requestor_challenge_indicator = requestor_challenge_indicator @transaction_id = transaction_id @version = version end |
Instance Attribute Details
#ares_trans_status ⇒ Object
The ‘transStatus` returned from the card Issuer’s ACS in the ARes.
10495 10496 10497 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10495 def ares_trans_status @ares_trans_status end |
#cryptogram ⇒ Object
The cryptogram, also known as the “authentication value” (AAV, CAVV or AEVV). This value is 20 bytes, base64-encoded into a 28-character string. (Most 3D Secure providers will return the base64-encoded version, which is what you should specify here.)
10500 10501 10502 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10500 def cryptogram @cryptogram end |
#electronic_commerce_indicator ⇒ Object
The Electronic Commerce Indicator (ECI) is returned by your 3D Secure provider and indicates what degree of authentication was performed.
10503 10504 10505 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10503 def electronic_commerce_indicator @electronic_commerce_indicator end |
#exemption_indicator ⇒ Object
The exemption requested via 3DS and accepted by the issuer at authentication time.
10505 10506 10507 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10505 def exemption_indicator @exemption_indicator end |
#network_options ⇒ Object
Network specific 3DS fields. Network specific arguments require an explicit card brand choice. The parameter ‘payment_method_options.card.network“ must be populated accordingly
10509 10510 10511 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10509 def @network_options end |
#requestor_challenge_indicator ⇒ Object
The challenge indicator (‘threeDSRequestorChallengeInd`) which was requested in the AReq sent to the card Issuer’s ACS. A string containing 2 digits from 01-99.
10512 10513 10514 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10512 def requestor_challenge_indicator @requestor_challenge_indicator end |
#transaction_id ⇒ Object
For 3D Secure 1, the XID. For 3D Secure 2, the Directory Server Transaction ID (dsTransID).
10515 10516 10517 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10515 def transaction_id @transaction_id end |
#version ⇒ Object
The version of 3D Secure that was performed.
10517 10518 10519 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10517 def version @version end |