Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::CustomerBalance::BankTransfer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: EuBankTransfer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(eu_bank_transfer: nil, requested_address_types: nil, type: nil) ⇒ BankTransfer

Returns a new instance of BankTransfer.



5856
5857
5858
5859
5860
# File 'lib/stripe/services/payment_intent_service.rb', line 5856

def initialize(eu_bank_transfer: nil, requested_address_types: nil, type: nil)
  @eu_bank_transfer = eu_bank_transfer
  @requested_address_types = requested_address_types
  @type = type
end

Instance Attribute Details

#eu_bank_transferObject

Configuration for the eu_bank_transfer funding type.



5848
5849
5850
# File 'lib/stripe/services/payment_intent_service.rb', line 5848

def eu_bank_transfer
  @eu_bank_transfer
end

#requested_address_typesObject

List of address types that should be returned in the financial_addresses response. If not specified, all valid types will be returned.

Permitted values include: ‘sort_code`, `zengin`, `iban`, or `spei`.



5852
5853
5854
# File 'lib/stripe/services/payment_intent_service.rb', line 5852

def requested_address_types
  @requested_address_types
end

#typeObject

The list of bank transfer types that this PaymentIntent is allowed to use for funding Permitted values include: ‘eu_bank_transfer`, `gb_bank_transfer`, `jp_bank_transfer`, `mx_bank_transfer`, or `us_bank_transfer`.



5854
5855
5856
# File 'lib/stripe/services/payment_intent_service.rb', line 5854

def type
  @type
end