Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Klarna::OnDemand

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand

Returns a new instance of OnDemand.



10915
10916
10917
10918
10919
10920
10921
10922
10923
10924
10925
10926
10927
# File 'lib/stripe/services/payment_intent_service.rb', line 10915

def initialize(
  average_amount: nil,
  maximum_amount: nil,
  minimum_amount: nil,
  purchase_interval: nil,
  purchase_interval_count: nil
)
  @average_amount = average_amount
  @maximum_amount = maximum_amount
  @minimum_amount = minimum_amount
  @purchase_interval = purchase_interval
  @purchase_interval_count = purchase_interval_count
end

Instance Attribute Details

#average_amountObject

Your average amount value. You can use a value across your customer base, or segment based on customer type, country, etc.



10905
10906
10907
# File 'lib/stripe/services/payment_intent_service.rb', line 10905

def average_amount
  @average_amount
end

#maximum_amountObject

The maximum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



10907
10908
10909
# File 'lib/stripe/services/payment_intent_service.rb', line 10907

def maximum_amount
  @maximum_amount
end

#minimum_amountObject

The lowest or minimum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



10909
10910
10911
# File 'lib/stripe/services/payment_intent_service.rb', line 10909

def minimum_amount
  @minimum_amount
end

#purchase_intervalObject

Interval at which the customer is making purchases



10911
10912
10913
# File 'lib/stripe/services/payment_intent_service.rb', line 10911

def purchase_interval
  @purchase_interval
end

#purchase_interval_countObject

The number of ‘purchase_interval` between charges



10913
10914
10915
# File 'lib/stripe/services/payment_intent_service.rb', line 10913

def purchase_interval_count
  @purchase_interval_count
end