Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Klarna::OnDemand

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand

Returns a new instance of OnDemand.



10291
10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
# File 'lib/stripe/services/payment_intent_service.rb', line 10291

def initialize(
  average_amount: nil,
  maximum_amount: nil,
  minimum_amount: nil,
  purchase_interval: nil,
  purchase_interval_count: nil
)
  @average_amount = average_amount
  @maximum_amount = maximum_amount
  @minimum_amount = minimum_amount
  @purchase_interval = purchase_interval
  @purchase_interval_count = purchase_interval_count
end

Instance Attribute Details

#average_amountObject

Your average amount value. You can use a value across your customer base, or segment based on customer type, country, etc.



10281
10282
10283
# File 'lib/stripe/services/payment_intent_service.rb', line 10281

def average_amount
  @average_amount
end

#maximum_amountObject

The maximum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



10283
10284
10285
# File 'lib/stripe/services/payment_intent_service.rb', line 10283

def maximum_amount
  @maximum_amount
end

#minimum_amountObject

The lowest or minimum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



10285
10286
10287
# File 'lib/stripe/services/payment_intent_service.rb', line 10285

def minimum_amount
  @minimum_amount
end

#purchase_intervalObject

Interval at which the customer is making purchases



10287
10288
10289
# File 'lib/stripe/services/payment_intent_service.rb', line 10287

def purchase_interval
  @purchase_interval
end

#purchase_interval_countObject

The number of ‘purchase_interval` between charges



10289
10290
10291
# File 'lib/stripe/services/payment_intent_service.rb', line 10289

def purchase_interval_count
  @purchase_interval_count
end