Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
6270 6271 6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6270 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
6260 6261 6262 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6260 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
6262 6263 6264 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6262 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
6264 6265 6266 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6264 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
6266 6267 6268 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6266 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
6268 6269 6270 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6268 def reference @reference end |