Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
11291 11292 11293 11294 11295 11296 11297 11298 11299 11300 11301 11302 11303 11304 11305 11306 11307 11308 11309 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11291 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
11275 11276 11277 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11275 def category @category end |
#description ⇒ Object
Description of the line item.
11277 11278 11279 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11277 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
11279 11280 11281 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11279 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
11281 11282 11283 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11281 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
11283 11284 11285 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11283 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
11285 11286 11287 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11285 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
11287 11288 11289 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11287 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
11289 11290 11291 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11289 def unit_amount @unit_amount end |