Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
10667 10668 10669 10670 10671 10672 10673 10674 10675 10676 10677 10678 10679 10680 10681 10682 10683 10684 10685 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10667 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
10651 10652 10653 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10651 def category @category end |
#description ⇒ Object
Description of the line item.
10653 10654 10655 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10653 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
10655 10656 10657 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10655 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
10657 10658 10659 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10657 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
10659 10660 10661 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10659 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
10661 10662 10663 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10661 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
10663 10664 10665 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10663 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
10665 10666 10667 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10665 def unit_amount @unit_amount end |