Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
10365 10366 10367 10368 10369 10370 10371 10372 10373 10374 10375 10376 10377 10378 10379 10380 10381 10382 10383 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10365 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
10349 10350 10351 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10349 def category @category end |
#description ⇒ Object
Description of the line item.
10351 10352 10353 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10351 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
10353 10354 10355 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10353 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
10355 10356 10357 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10355 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
10357 10358 10359 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10357 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
10359 10360 10361 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10359 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
10361 10362 10363 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10361 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
10363 10364 10365 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10363 def unit_amount @unit_amount end |