Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



10383
10384
10385
10386
10387
10388
10389
10390
10391
10392
10393
10394
10395
10396
10397
10398
10399
10400
10401
# File 'lib/stripe/services/payment_intent_service.rb', line 10383

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



10367
10368
10369
# File 'lib/stripe/services/payment_intent_service.rb', line 10367

def category
  @category
end

#descriptionObject

Description of the line item.



10369
10370
10371
# File 'lib/stripe/services/payment_intent_service.rb', line 10369

def description
  @description
end

#nameObject

Descriptive name of the line item.



10371
10372
10373
# File 'lib/stripe/services/payment_intent_service.rb', line 10371

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



10373
10374
10375
# File 'lib/stripe/services/payment_intent_service.rb', line 10373

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



10375
10376
10377
# File 'lib/stripe/services/payment_intent_service.rb', line 10375

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



10377
10378
10379
# File 'lib/stripe/services/payment_intent_service.rb', line 10377

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



10379
10380
10381
# File 'lib/stripe/services/payment_intent_service.rb', line 10379

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



10381
10382
10383
# File 'lib/stripe/services/payment_intent_service.rb', line 10381

def unit_amount
  @unit_amount
end