Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



10327
10328
10329
10330
10331
10332
10333
10334
10335
10336
10337
10338
10339
10340
10341
10342
10343
10344
10345
# File 'lib/stripe/services/payment_intent_service.rb', line 10327

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



10311
10312
10313
# File 'lib/stripe/services/payment_intent_service.rb', line 10311

def category
  @category
end

#descriptionObject

Description of the line item.



10313
10314
10315
# File 'lib/stripe/services/payment_intent_service.rb', line 10313

def description
  @description
end

#nameObject

Descriptive name of the line item.



10315
10316
10317
# File 'lib/stripe/services/payment_intent_service.rb', line 10315

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



10317
10318
10319
# File 'lib/stripe/services/payment_intent_service.rb', line 10317

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



10319
10320
10321
# File 'lib/stripe/services/payment_intent_service.rb', line 10319

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



10321
10322
10323
# File 'lib/stripe/services/payment_intent_service.rb', line 10321

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



10323
10324
10325
# File 'lib/stripe/services/payment_intent_service.rb', line 10323

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



10325
10326
10327
# File 'lib/stripe/services/payment_intent_service.rb', line 10325

def unit_amount
  @unit_amount
end