Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
9941
9942
9943
9944
9945
9946
# File 'lib/stripe/services/payment_intent_service.rb', line 9928

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



9912
9913
9914
# File 'lib/stripe/services/payment_intent_service.rb', line 9912

def category
  @category
end

#descriptionObject

Description of the line item.



9914
9915
9916
# File 'lib/stripe/services/payment_intent_service.rb', line 9914

def description
  @description
end

#nameObject

Descriptive name of the line item.



9916
9917
9918
# File 'lib/stripe/services/payment_intent_service.rb', line 9916

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



9918
9919
9920
# File 'lib/stripe/services/payment_intent_service.rb', line 9918

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



9920
9921
9922
# File 'lib/stripe/services/payment_intent_service.rb', line 9920

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



9922
9923
9924
# File 'lib/stripe/services/payment_intent_service.rb', line 9922

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



9924
9925
9926
# File 'lib/stripe/services/payment_intent_service.rb', line 9924

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



9926
9927
9928
# File 'lib/stripe/services/payment_intent_service.rb', line 9926

def unit_amount
  @unit_amount
end