Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
9872 9873 9874 9875 9876 9877 9878 9879 9880 9881 9882 9883 9884 9885 9886 9887 9888 9889 9890 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9872 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
9856 9857 9858 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9856 def category @category end |
#description ⇒ Object
Description of the line item.
9858 9859 9860 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9858 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
9860 9861 9862 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9860 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
9862 9863 9864 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9862 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
9864 9865 9866 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9864 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
9866 9867 9868 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9866 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
9868 9869 9870 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9868 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
9870 9871 9872 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9870 def unit_amount @unit_amount end |