Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
9834 9835 9836 9837 9838 9839 9840 9841 9842 9843 9844 9845 9846 9847 9848 9849 9850 9851 9852 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9834 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
9818 9819 9820 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9818 def category @category end |
#description ⇒ Object
Description of the line item.
9820 9821 9822 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9820 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
9822 9823 9824 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9822 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
9824 9825 9826 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9824 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
9826 9827 9828 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9826 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
9828 9829 9830 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9828 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
9830 9831 9832 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9830 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
9832 9833 9834 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9832 def unit_amount @unit_amount end |