Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
11015 11016 11017 11018 11019 11020 11021 11022 11023 11024 11025 11026 11027 11028 11029 11030 11031 11032 11033 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11015 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
10992 10993 10994 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10992 def category @category end |
#description ⇒ Object
Description of the line item.
10995 10996 10997 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10995 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
10998 10999 11000 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10998 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
11001 11002 11003 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11001 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
11004 11005 11006 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11004 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
11007 11008 11009 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11007 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
11010 11011 11012 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11010 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
11013 11014 11015 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11013 def unit_amount @unit_amount end |