Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The tax for a single unit of the line item in minor units.
-
#behavior ⇒ Object
The tax behavior for the line item.
Instance Method Summary collapse
-
#initialize(amount: nil, behavior: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, behavior: nil) ⇒ Tax
Returns a new instance of Tax.
9850 9851 9852 9853 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9850 def initialize(amount: nil, behavior: nil) @amount = amount @behavior = behavior end |
Instance Attribute Details
#amount ⇒ Object
The tax for a single unit of the line item in minor units. Cannot be a negative number.
9846 9847 9848 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9846 def amount @amount end |
#behavior ⇒ Object
The tax behavior for the line item.
9848 9849 9850 |
# File 'lib/stripe/services/payment_intent_service.rb', line 9848 def behavior @behavior end |