Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



10009
10010
10011
10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
10022
10023
# File 'lib/stripe/services/payment_intent_service.rb', line 10009

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when ‘amount_type` is `fixed`.



9997
9998
9999
# File 'lib/stripe/services/payment_intent_service.rb', line 9997

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.



9999
10000
10001
# File 'lib/stripe/services/payment_intent_service.rb', line 9999

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



10001
10002
10003
# File 'lib/stripe/services/payment_intent_service.rb', line 10001

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected.



10003
10004
10005
# File 'lib/stripe/services/payment_intent_service.rb', line 10003

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.



10005
10006
10007
# File 'lib/stripe/services/payment_intent_service.rb', line 10005

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Defaults to retail.



10007
10008
10009
# File 'lib/stripe/services/payment_intent_service.rb', line 10007

def purpose
  @purpose
end