Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



9953
9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
# File 'lib/stripe/services/payment_intent_service.rb', line 9953

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when ‘amount_type` is `fixed`.



9941
9942
9943
# File 'lib/stripe/services/payment_intent_service.rb', line 9941

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.



9943
9944
9945
# File 'lib/stripe/services/payment_intent_service.rb', line 9943

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



9945
9946
9947
# File 'lib/stripe/services/payment_intent_service.rb', line 9945

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected.



9947
9948
9949
# File 'lib/stripe/services/payment_intent_service.rb', line 9947

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.



9949
9950
9951
# File 'lib/stripe/services/payment_intent_service.rb', line 9949

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Defaults to retail.



9951
9952
9953
# File 'lib/stripe/services/payment_intent_service.rb', line 9951

def purpose
  @purpose
end