Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Payto::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::Payto::MandateOptions
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount that will be collected.
-
#amount_type ⇒ Object
The type of amount that will be collected.
-
#end_date ⇒ Object
Date, in YYYY-MM-DD format, after which payments will not be collected.
-
#payment_schedule ⇒ Object
The periodicity at which payments will be collected.
-
#payments_per_period ⇒ Object
The number of payments that will be made during a payment period.
-
#purpose ⇒ Object
The purpose for which payments are made.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
11108 11109 11110 11111 11112 11113 11114 11115 11116 11117 11118 11119 11120 11121 11122 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11108 def initialize( amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil ) @amount = amount @amount_type = amount_type @end_date = end_date @payment_schedule = payment_schedule @payments_per_period = payments_per_period @purpose = purpose end |
Instance Attribute Details
#amount ⇒ Object
Amount that will be collected. It is required when ‘amount_type` is `fixed`.
11091 11092 11093 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11091 def amount @amount end |
#amount_type ⇒ Object
The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.
11094 11095 11096 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11094 def amount_type @amount_type end |
#end_date ⇒ Object
Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.
11097 11098 11099 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11097 def end_date @end_date end |
#payment_schedule ⇒ Object
The periodicity at which payments will be collected.
11100 11101 11102 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11100 def payment_schedule @payment_schedule end |
#payments_per_period ⇒ Object
The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.
11103 11104 11105 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11103 def payments_per_period @payments_per_period end |
#purpose ⇒ Object
The purpose for which payments are made. Defaults to retail.
11106 11107 11108 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11106 def purpose @purpose end |