Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::UsBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: FinancialConnections, MandateOptions, Networks
Instance Attribute Summary collapse
-
#financial_connections ⇒ Object
Additional fields for Financial Connections Session creation.
-
#mandate_options ⇒ Object
Additional fields for Mandate creation.
-
#networks ⇒ Object
Additional fields for network related functions.
-
#preferred_settlement_speed ⇒ Object
Preferred transaction settlement speed.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer’s account.
-
#verification_method ⇒ Object
Bank account verification method.
Instance Method Summary collapse
-
#initialize(financial_connections: nil, mandate_options: nil, networks: nil, preferred_settlement_speed: nil, setup_future_usage: nil, target_date: nil, verification_method: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(financial_connections: nil, mandate_options: nil, networks: nil, preferred_settlement_speed: nil, setup_future_usage: nil, target_date: nil, verification_method: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
11100 11101 11102 11103 11104 11105 11106 11107 11108 11109 11110 11111 11112 11113 11114 11115 11116 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11100 def initialize( financial_connections: nil, mandate_options: nil, networks: nil, preferred_settlement_speed: nil, setup_future_usage: nil, target_date: nil, verification_method: nil ) @financial_connections = financial_connections @mandate_options = @networks = networks @preferred_settlement_speed = preferred_settlement_speed @setup_future_usage = setup_future_usage @target_date = target_date @verification_method = verification_method end |
Instance Attribute Details
#financial_connections ⇒ Object
Additional fields for Financial Connections Session creation
11078 11079 11080 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11078 def financial_connections @financial_connections end |
#mandate_options ⇒ Object
Additional fields for Mandate creation
11080 11081 11082 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11080 def @mandate_options end |
#networks ⇒ Object
Additional fields for network related functions
11082 11083 11084 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11082 def networks @networks end |
#preferred_settlement_speed ⇒ Object
Preferred transaction settlement speed
11084 11085 11086 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11084 def preferred_settlement_speed @preferred_settlement_speed end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.
11094 11095 11096 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11094 def setup_future_usage @setup_future_usage end |
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer’s account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.
11096 11097 11098 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11096 def target_date @target_date end |
#verification_method ⇒ Object
Bank account verification method.
11098 11099 11100 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11098 def verification_method @verification_method end |