Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Filters
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(filters: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
6791 6792 6793 6794 6795 6796 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6791 def initialize(filters: nil, permissions: nil, prefetch: nil, return_url: nil) @filters = filters @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
6783 6784 6785 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6783 def filters @filters end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
6785 6786 6787 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6785 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
6787 6788 6789 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6787 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
6789 6790 6791 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6789 def return_url @return_url end |