Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Filters, ManualEntry
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#manual_entry ⇒ Object
Customize manual entry behavior.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
11045 11046 11047 11048 11049 11050 11051 11052 11053 11054 11055 11056 11057 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11045 def initialize( filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil ) @filters = filters @manual_entry = manual_entry @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
11035 11036 11037 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11035 def filters @filters end |
#manual_entry ⇒ Object
Customize manual entry behavior
11037 11038 11039 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11037 def manual_entry @manual_entry end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
11039 11040 11041 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11039 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
11041 11042 11043 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11041 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
11043 11044 11045 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11043 def return_url @return_url end |