Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



10749
10750
10751
10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
# File 'lib/stripe/services/payment_intent_service.rb', line 10749

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



10739
10740
10741
# File 'lib/stripe/services/payment_intent_service.rb', line 10739

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



10741
10742
10743
# File 'lib/stripe/services/payment_intent_service.rb', line 10741

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



10743
10744
10745
# File 'lib/stripe/services/payment_intent_service.rb', line 10743

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



10745
10746
10747
# File 'lib/stripe/services/payment_intent_service.rb', line 10745

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



10747
10748
10749
# File 'lib/stripe/services/payment_intent_service.rb', line 10747

def return_url
  @return_url
end