Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Filters, ManualEntry
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#manual_entry ⇒ Object
Customize manual entry behavior.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
10693 10694 10695 10696 10697 10698 10699 10700 10701 10702 10703 10704 10705 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10693 def initialize( filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil ) @filters = filters @manual_entry = manual_entry @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
10683 10684 10685 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10683 def filters @filters end |
#manual_entry ⇒ Object
Customize manual entry behavior
10685 10686 10687 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10685 def manual_entry @manual_entry end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
10687 10688 10689 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10687 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
10689 10690 10691 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10689 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
10691 10692 10693 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10691 def return_url @return_url end |