Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Filters, ManualEntry
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#manual_entry ⇒ Object
Customize manual entry behavior.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
10277 10278 10279 10280 10281 10282 10283 10284 10285 10286 10287 10288 10289 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10277 def initialize( filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil ) @filters = filters @manual_entry = manual_entry @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
10267 10268 10269 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10267 def filters @filters end |
#manual_entry ⇒ Object
Customize manual entry behavior
10269 10270 10271 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10269 def manual_entry @manual_entry end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
10271 10272 10273 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10271 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
10273 10274 10275 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10273 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
10275 10276 10277 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10275 def return_url @return_url end |