Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



10180
10181
10182
10183
10184
10185
10186
10187
10188
10189
10190
10191
10192
# File 'lib/stripe/services/payment_intent_service.rb', line 10180

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method



10170
10171
10172
# File 'lib/stripe/services/payment_intent_service.rb', line 10170

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



10172
10173
10174
# File 'lib/stripe/services/payment_intent_service.rb', line 10172

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



10174
10175
10176
# File 'lib/stripe/services/payment_intent_service.rb', line 10174

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



10176
10177
10178
# File 'lib/stripe/services/payment_intent_service.rb', line 10176

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



10178
10179
10180
# File 'lib/stripe/services/payment_intent_service.rb', line 10178

def return_url
  @return_url
end