Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Filters, ManualEntry
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#manual_entry ⇒ Object
Customize manual entry behavior.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
10218 10219 10220 10221 10222 10223 10224 10225 10226 10227 10228 10229 10230 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10218 def initialize( filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil ) @filters = filters @manual_entry = manual_entry @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method
10208 10209 10210 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10208 def filters @filters end |
#manual_entry ⇒ Object
Customize manual entry behavior
10210 10211 10212 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10210 def manual_entry @manual_entry end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
10212 10213 10214 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10212 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
10214 10215 10216 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10214 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
10216 10217 10218 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10216 def return_url @return_url end |