Class: Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::UsBankAccount::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::PaymentMethodOptions::UsBankAccount::MandateOptions
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#collection_method ⇒ Object
The method used to collect offline mandate customer acceptance.
Instance Method Summary collapse
-
#initialize(collection_method: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(collection_method: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
10762 10763 10764 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10762 def initialize(collection_method: nil) @collection_method = collection_method end |
Instance Attribute Details
#collection_method ⇒ Object
The method used to collect offline mandate customer acceptance.
10760 10761 10762 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10760 def collection_method @collection_method end |