Class: Stripe::PaymentIntentService::ConfirmParams::RadarOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::ConfirmParams::RadarOptions
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#session ⇒ Object
A [Radar Session](stripe.com/docs/radar/radar-session) is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments.
Instance Method Summary collapse
-
#initialize(session: nil) ⇒ RadarOptions
constructor
A new instance of RadarOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(session: nil) ⇒ RadarOptions
Returns a new instance of RadarOptions.
6918 6919 6920 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6918 def initialize(session: nil) @session = session end |
Instance Attribute Details
#session ⇒ Object
A [Radar Session](stripe.com/docs/radar/radar-session) is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments.
6916 6917 6918 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6916 def session @session end |