Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/stripe/services/payment_intent_service.rb', line 286 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
246 247 248 |
# File 'lib/stripe/services/payment_intent_service.rb', line 246 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
248 249 250 |
# File 'lib/stripe/services/payment_intent_service.rb', line 248 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
250 251 252 |
# File 'lib/stripe/services/payment_intent_service.rb', line 250 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
252 253 254 |
# File 'lib/stripe/services/payment_intent_service.rb', line 252 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
254 255 256 |
# File 'lib/stripe/services/payment_intent_service.rb', line 254 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
256 257 258 |
# File 'lib/stripe/services/payment_intent_service.rb', line 256 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
258 259 260 |
# File 'lib/stripe/services/payment_intent_service.rb', line 258 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
260 261 262 |
# File 'lib/stripe/services/payment_intent_service.rb', line 260 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
262 263 264 |
# File 'lib/stripe/services/payment_intent_service.rb', line 262 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
264 265 266 |
# File 'lib/stripe/services/payment_intent_service.rb', line 264 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
266 267 268 |
# File 'lib/stripe/services/payment_intent_service.rb', line 266 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
268 269 270 |
# File 'lib/stripe/services/payment_intent_service.rb', line 268 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
270 271 272 |
# File 'lib/stripe/services/payment_intent_service.rb', line 270 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
272 273 274 |
# File 'lib/stripe/services/payment_intent_service.rb', line 272 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
274 275 276 |
# File 'lib/stripe/services/payment_intent_service.rb', line 274 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
276 277 278 |
# File 'lib/stripe/services/payment_intent_service.rb', line 276 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
278 279 280 |
# File 'lib/stripe/services/payment_intent_service.rb', line 278 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
280 281 282 |
# File 'lib/stripe/services/payment_intent_service.rb', line 280 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
282 283 284 |
# File 'lib/stripe/services/payment_intent_service.rb', line 282 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
284 285 286 |
# File 'lib/stripe/services/payment_intent_service.rb', line 284 def tax_exempt @tax_exempt end |