Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental

Returns a new instance of CarRental.



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/stripe/services/payment_intent_service.rb', line 282

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  tax_exempt: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @tax_exempt = tax_exempt
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



242
243
244
# File 'lib/stripe/services/payment_intent_service.rb', line 242

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



244
245
246
# File 'lib/stripe/services/payment_intent_service.rb', line 244

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



246
247
248
# File 'lib/stripe/services/payment_intent_service.rb', line 246

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



248
249
250
# File 'lib/stripe/services/payment_intent_service.rb', line 248

def car_make
  @car_make
end

#car_modelObject

Model of the car.



250
251
252
# File 'lib/stripe/services/payment_intent_service.rb', line 250

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



252
253
254
# File 'lib/stripe/services/payment_intent_service.rb', line 252

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



254
255
256
# File 'lib/stripe/services/payment_intent_service.rb', line 254

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



256
257
258
# File 'lib/stripe/services/payment_intent_service.rb', line 256

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



258
259
260
# File 'lib/stripe/services/payment_intent_service.rb', line 258

def delivery
  @delivery
end

#driversObject

The details of the passengers in the travel reservation



260
261
262
# File 'lib/stripe/services/payment_intent_service.rb', line 260

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



262
263
264
# File 'lib/stripe/services/payment_intent_service.rb', line 262

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



264
265
266
# File 'lib/stripe/services/payment_intent_service.rb', line 264

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



266
267
268
# File 'lib/stripe/services/payment_intent_service.rb', line 266

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



268
269
270
# File 'lib/stripe/services/payment_intent_service.rb', line 268

def pickup_at
  @pickup_at
end

#rate_amountObject

Rental rate.



270
271
272
# File 'lib/stripe/services/payment_intent_service.rb', line 270

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



272
273
274
# File 'lib/stripe/services/payment_intent_service.rb', line 272

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



274
275
276
# File 'lib/stripe/services/payment_intent_service.rb', line 274

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



276
277
278
# File 'lib/stripe/services/payment_intent_service.rb', line 276

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



278
279
280
# File 'lib/stripe/services/payment_intent_service.rb', line 278

def return_at
  @return_at
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



280
281
282
# File 'lib/stripe/services/payment_intent_service.rb', line 280

def tax_exempt
  @tax_exempt
end