Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



158
159
160
161
162
# File 'lib/stripe/services/payment_intent_service.rb', line 158

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



152
153
154
# File 'lib/stripe/services/payment_intent_service.rb', line 152

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



154
155
156
# File 'lib/stripe/services/payment_intent_service.rb', line 154

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



156
157
158
# File 'lib/stripe/services/payment_intent_service.rb', line 156

def phone
  @phone
end