Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/stripe/services/payment_intent_service.rb', line 412 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
394 395 396 |
# File 'lib/stripe/services/payment_intent_service.rb', line 394 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
396 397 398 |
# File 'lib/stripe/services/payment_intent_service.rb', line 396 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
398 399 400 |
# File 'lib/stripe/services/payment_intent_service.rb', line 398 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
400 401 402 |
# File 'lib/stripe/services/payment_intent_service.rb', line 400 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
402 403 404 |
# File 'lib/stripe/services/payment_intent_service.rb', line 402 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
404 405 406 |
# File 'lib/stripe/services/payment_intent_service.rb', line 404 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
406 407 408 |
# File 'lib/stripe/services/payment_intent_service.rb', line 406 def genre @genre end |
#name ⇒ Object
The name of the event.
408 409 410 |
# File 'lib/stripe/services/payment_intent_service.rb', line 408 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
410 411 412 |
# File 'lib/stripe/services/payment_intent_service.rb', line 410 def starts_at @starts_at end |