Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/stripe/services/payment_intent_service.rb', line 473 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
447 448 449 |
# File 'lib/stripe/services/payment_intent_service.rb', line 447 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
450 451 452 |
# File 'lib/stripe/services/payment_intent_service.rb', line 450 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
453 454 455 |
# File 'lib/stripe/services/payment_intent_service.rb', line 453 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
456 457 458 |
# File 'lib/stripe/services/payment_intent_service.rb', line 456 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
459 460 461 |
# File 'lib/stripe/services/payment_intent_service.rb', line 459 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
462 463 464 |
# File 'lib/stripe/services/payment_intent_service.rb', line 462 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
465 466 467 |
# File 'lib/stripe/services/payment_intent_service.rb', line 465 def genre @genre end |
#name ⇒ Object
The name of the event.
468 469 470 |
# File 'lib/stripe/services/payment_intent_service.rb', line 468 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
471 472 473 |
# File 'lib/stripe/services/payment_intent_service.rb', line 471 def starts_at @starts_at end |