Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
421 422 423 424 425 |
# File 'lib/stripe/services/payment_intent_service.rb', line 421 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
415 416 417 |
# File 'lib/stripe/services/payment_intent_service.rb', line 415 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
417 418 419 |
# File 'lib/stripe/services/payment_intent_service.rb', line 417 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
419 420 421 |
# File 'lib/stripe/services/payment_intent_service.rb', line 419 def phone @phone end |