Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
388 389 390 391 392 |
# File 'lib/stripe/services/payment_intent_service.rb', line 388 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
382 383 384 |
# File 'lib/stripe/services/payment_intent_service.rb', line 382 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
384 385 386 |
# File 'lib/stripe/services/payment_intent_service.rb', line 384 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
386 387 388 |
# File 'lib/stripe/services/payment_intent_service.rb', line 386 def phone @phone end |