Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
465 466 467 468 469 |
# File 'lib/stripe/services/payment_intent_service.rb', line 465 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
459 460 461 |
# File 'lib/stripe/services/payment_intent_service.rb', line 459 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
461 462 463 |
# File 'lib/stripe/services/payment_intent_service.rb', line 461 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
463 464 465 |
# File 'lib/stripe/services/payment_intent_service.rb', line 463 def phone @phone end |