Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



517
518
519
520
521
# File 'lib/stripe/services/payment_intent_service.rb', line 517

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



509
510
511
# File 'lib/stripe/services/payment_intent_service.rb', line 509

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



512
513
514
# File 'lib/stripe/services/payment_intent_service.rb', line 512

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



515
516
517
# File 'lib/stripe/services/payment_intent_service.rb', line 515

def phone
  @phone
end