Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
517 518 519 520 521 |
# File 'lib/stripe/services/payment_intent_service.rb', line 517 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
509 510 511 |
# File 'lib/stripe/services/payment_intent_service.rb', line 509 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
512 513 514 |
# File 'lib/stripe/services/payment_intent_service.rb', line 512 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
515 516 517 |
# File 'lib/stripe/services/payment_intent_service.rb', line 515 def phone @phone end |