Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 |
# File 'lib/stripe/services/payment_intent_service.rb', line 871 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
829 830 831 |
# File 'lib/stripe/services/payment_intent_service.rb', line 829 def address @address end |
#adults ⇒ Object
The number of adults on the booking
831 832 833 |
# File 'lib/stripe/services/payment_intent_service.rb', line 831 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
833 834 835 |
# File 'lib/stripe/services/payment_intent_service.rb', line 833 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
835 836 837 |
# File 'lib/stripe/services/payment_intent_service.rb', line 835 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
837 838 839 |
# File 'lib/stripe/services/payment_intent_service.rb', line 837 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
839 840 841 |
# File 'lib/stripe/services/payment_intent_service.rb', line 839 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
841 842 843 |
# File 'lib/stripe/services/payment_intent_service.rb', line 841 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
843 844 845 |
# File 'lib/stripe/services/payment_intent_service.rb', line 843 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
845 846 847 |
# File 'lib/stripe/services/payment_intent_service.rb', line 845 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
847 848 849 |
# File 'lib/stripe/services/payment_intent_service.rb', line 847 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
849 850 851 |
# File 'lib/stripe/services/payment_intent_service.rb', line 849 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
851 852 853 |
# File 'lib/stripe/services/payment_intent_service.rb', line 851 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
853 854 855 |
# File 'lib/stripe/services/payment_intent_service.rb', line 853 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
855 856 857 |
# File 'lib/stripe/services/payment_intent_service.rb', line 855 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
857 858 859 |
# File 'lib/stripe/services/payment_intent_service.rb', line 857 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
859 860 861 |
# File 'lib/stripe/services/payment_intent_service.rb', line 859 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
861 862 863 |
# File 'lib/stripe/services/payment_intent_service.rb', line 861 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
863 864 865 |
# File 'lib/stripe/services/payment_intent_service.rb', line 863 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
865 866 867 |
# File 'lib/stripe/services/payment_intent_service.rb', line 865 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
867 868 869 |
# File 'lib/stripe/services/payment_intent_service.rb', line 867 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
869 870 871 |
# File 'lib/stripe/services/payment_intent_service.rb', line 869 def total_tax_amount @total_tax_amount end |