Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 |
# File 'lib/stripe/services/payment_intent_service.rb', line 718 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
676 677 678 |
# File 'lib/stripe/services/payment_intent_service.rb', line 676 def address @address end |
#adults ⇒ Object
The number of adults on the booking
678 679 680 |
# File 'lib/stripe/services/payment_intent_service.rb', line 678 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
680 681 682 |
# File 'lib/stripe/services/payment_intent_service.rb', line 680 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
682 683 684 |
# File 'lib/stripe/services/payment_intent_service.rb', line 682 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
684 685 686 |
# File 'lib/stripe/services/payment_intent_service.rb', line 684 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
686 687 688 |
# File 'lib/stripe/services/payment_intent_service.rb', line 686 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
688 689 690 |
# File 'lib/stripe/services/payment_intent_service.rb', line 688 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
690 691 692 |
# File 'lib/stripe/services/payment_intent_service.rb', line 690 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
692 693 694 |
# File 'lib/stripe/services/payment_intent_service.rb', line 692 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
694 695 696 |
# File 'lib/stripe/services/payment_intent_service.rb', line 694 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
696 697 698 |
# File 'lib/stripe/services/payment_intent_service.rb', line 696 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
698 699 700 |
# File 'lib/stripe/services/payment_intent_service.rb', line 698 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
700 701 702 |
# File 'lib/stripe/services/payment_intent_service.rb', line 700 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
702 703 704 |
# File 'lib/stripe/services/payment_intent_service.rb', line 702 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
704 705 706 |
# File 'lib/stripe/services/payment_intent_service.rb', line 704 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
706 707 708 |
# File 'lib/stripe/services/payment_intent_service.rb', line 706 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
708 709 710 |
# File 'lib/stripe/services/payment_intent_service.rb', line 708 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
710 711 712 |
# File 'lib/stripe/services/payment_intent_service.rb', line 710 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
712 713 714 |
# File 'lib/stripe/services/payment_intent_service.rb', line 712 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
714 715 716 |
# File 'lib/stripe/services/payment_intent_service.rb', line 714 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
716 717 718 |
# File 'lib/stripe/services/payment_intent_service.rb', line 716 def total_tax_amount @total_tax_amount end |