Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
# File 'lib/stripe/services/payment_intent_service.rb', line 678

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



636
637
638
# File 'lib/stripe/services/payment_intent_service.rb', line 636

def address
  @address
end

#adultsObject

The number of adults on the booking



638
639
640
# File 'lib/stripe/services/payment_intent_service.rb', line 638

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



640
641
642
# File 'lib/stripe/services/payment_intent_service.rb', line 640

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



642
643
644
# File 'lib/stripe/services/payment_intent_service.rb', line 642

def booking_number
  @booking_number
end

#categoryObject

The lodging category



644
645
646
# File 'lib/stripe/services/payment_intent_service.rb', line 644

def category
  @category
end

#checkin_atObject

Loding check-in time. Measured in seconds since the Unix epoch.



646
647
648
# File 'lib/stripe/services/payment_intent_service.rb', line 646

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



648
649
650
# File 'lib/stripe/services/payment_intent_service.rb', line 648

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



650
651
652
# File 'lib/stripe/services/payment_intent_service.rb', line 650

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



652
653
654
# File 'lib/stripe/services/payment_intent_service.rb', line 652

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



654
655
656
# File 'lib/stripe/services/payment_intent_service.rb', line 654

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



656
657
658
# File 'lib/stripe/services/payment_intent_service.rb', line 656

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



658
659
660
# File 'lib/stripe/services/payment_intent_service.rb', line 658

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



660
661
662
# File 'lib/stripe/services/payment_intent_service.rb', line 660

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



662
663
664
# File 'lib/stripe/services/payment_intent_service.rb', line 662

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



664
665
666
# File 'lib/stripe/services/payment_intent_service.rb', line 664

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



666
667
668
# File 'lib/stripe/services/payment_intent_service.rb', line 666

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



668
669
670
# File 'lib/stripe/services/payment_intent_service.rb', line 668

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



670
671
672
# File 'lib/stripe/services/payment_intent_service.rb', line 670

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



672
673
674
# File 'lib/stripe/services/payment_intent_service.rb', line 672

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



674
675
676
# File 'lib/stripe/services/payment_intent_service.rb', line 674

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



676
677
678
# File 'lib/stripe/services/payment_intent_service.rb', line 676

def total_tax_amount
  @total_tax_amount
end