Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Loding check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 |
# File 'lib/stripe/services/payment_intent_service.rb', line 685 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
643 644 645 |
# File 'lib/stripe/services/payment_intent_service.rb', line 643 def address @address end |
#adults ⇒ Object
The number of adults on the booking
645 646 647 |
# File 'lib/stripe/services/payment_intent_service.rb', line 645 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
647 648 649 |
# File 'lib/stripe/services/payment_intent_service.rb', line 647 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
649 650 651 |
# File 'lib/stripe/services/payment_intent_service.rb', line 649 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
651 652 653 |
# File 'lib/stripe/services/payment_intent_service.rb', line 651 def category @category end |
#checkin_at ⇒ Object
Loding check-in time. Measured in seconds since the Unix epoch.
653 654 655 |
# File 'lib/stripe/services/payment_intent_service.rb', line 653 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
655 656 657 |
# File 'lib/stripe/services/payment_intent_service.rb', line 655 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
657 658 659 |
# File 'lib/stripe/services/payment_intent_service.rb', line 657 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
659 660 661 |
# File 'lib/stripe/services/payment_intent_service.rb', line 659 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
661 662 663 |
# File 'lib/stripe/services/payment_intent_service.rb', line 661 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
663 664 665 |
# File 'lib/stripe/services/payment_intent_service.rb', line 663 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
665 666 667 |
# File 'lib/stripe/services/payment_intent_service.rb', line 665 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
667 668 669 |
# File 'lib/stripe/services/payment_intent_service.rb', line 667 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
669 670 671 |
# File 'lib/stripe/services/payment_intent_service.rb', line 669 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
671 672 673 |
# File 'lib/stripe/services/payment_intent_service.rb', line 671 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
673 674 675 |
# File 'lib/stripe/services/payment_intent_service.rb', line 673 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
675 676 677 |
# File 'lib/stripe/services/payment_intent_service.rb', line 675 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
677 678 679 |
# File 'lib/stripe/services/payment_intent_service.rb', line 677 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
679 680 681 |
# File 'lib/stripe/services/payment_intent_service.rb', line 679 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
681 682 683 |
# File 'lib/stripe/services/payment_intent_service.rb', line 681 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
683 684 685 |
# File 'lib/stripe/services/payment_intent_service.rb', line 683 def total_tax_amount @total_tax_amount end |