Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
# File 'lib/stripe/services/payment_intent_service.rb', line 780

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



718
719
720
# File 'lib/stripe/services/payment_intent_service.rb', line 718

def address
  @address
end

#adultsObject

The number of adults on the booking



721
722
723
# File 'lib/stripe/services/payment_intent_service.rb', line 721

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



724
725
726
# File 'lib/stripe/services/payment_intent_service.rb', line 724

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



727
728
729
# File 'lib/stripe/services/payment_intent_service.rb', line 727

def booking_number
  @booking_number
end

#categoryObject

The lodging category



730
731
732
# File 'lib/stripe/services/payment_intent_service.rb', line 730

def category
  @category
end

#checkin_atObject

Loding check-in time. Measured in seconds since the Unix epoch.



733
734
735
# File 'lib/stripe/services/payment_intent_service.rb', line 733

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



736
737
738
# File 'lib/stripe/services/payment_intent_service.rb', line 736

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



739
740
741
# File 'lib/stripe/services/payment_intent_service.rb', line 739

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



742
743
744
# File 'lib/stripe/services/payment_intent_service.rb', line 742

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



745
746
747
# File 'lib/stripe/services/payment_intent_service.rb', line 745

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



748
749
750
# File 'lib/stripe/services/payment_intent_service.rb', line 748

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



751
752
753
# File 'lib/stripe/services/payment_intent_service.rb', line 751

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



754
755
756
# File 'lib/stripe/services/payment_intent_service.rb', line 754

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



757
758
759
# File 'lib/stripe/services/payment_intent_service.rb', line 757

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



760
761
762
# File 'lib/stripe/services/payment_intent_service.rb', line 760

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



763
764
765
# File 'lib/stripe/services/payment_intent_service.rb', line 763

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



766
767
768
# File 'lib/stripe/services/payment_intent_service.rb', line 766

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



769
770
771
# File 'lib/stripe/services/payment_intent_service.rb', line 769

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



772
773
774
# File 'lib/stripe/services/payment_intent_service.rb', line 772

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



775
776
777
# File 'lib/stripe/services/payment_intent_service.rb', line 775

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



778
779
780
# File 'lib/stripe/services/payment_intent_service.rb', line 778

def total_tax_amount
  @total_tax_amount
end