Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
803 804 805 806 807 |
# File 'lib/stripe/services/payment_intent_service.rb', line 803 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
797 798 799 |
# File 'lib/stripe/services/payment_intent_service.rb', line 797 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
799 800 801 |
# File 'lib/stripe/services/payment_intent_service.rb', line 799 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
801 802 803 |
# File 'lib/stripe/services/payment_intent_service.rb', line 801 def phone @phone end |