Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



617
618
619
620
621
# File 'lib/stripe/services/payment_intent_service.rb', line 617

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



611
612
613
# File 'lib/stripe/services/payment_intent_service.rb', line 611

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



613
614
615
# File 'lib/stripe/services/payment_intent_service.rb', line 613

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



615
616
617
# File 'lib/stripe/services/payment_intent_service.rb', line 615

def phone
  @phone
end