Class: Stripe::PaymentIntentService::CreateParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
617 618 619 620 621 |
# File 'lib/stripe/services/payment_intent_service.rb', line 617 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
611 612 613 |
# File 'lib/stripe/services/payment_intent_service.rb', line 611 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
613 614 615 |
# File 'lib/stripe/services/payment_intent_service.rb', line 613 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
615 616 617 |
# File 'lib/stripe/services/payment_intent_service.rb', line 615 def phone @phone end |