Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentMethodData
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, RadarOptions, Rechnung, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, StripeBalance, Swish, Twint, UsBankAccount, WechatPay, Zip
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If this is an ‘acss_debit` PaymentMethod, this hash contains details about the ACSS Debit payment method.
-
#affirm ⇒ Object
If this is an ‘affirm` PaymentMethod, this hash contains details about the Affirm payment method.
-
#afterpay_clearpay ⇒ Object
If this is an ‘AfterpayClearpay` PaymentMethod, this hash contains details about the AfterpayClearpay payment method.
-
#alipay ⇒ Object
If this is an ‘Alipay` PaymentMethod, this hash contains details about the Alipay payment method.
-
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#alma ⇒ Object
If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.
-
#amazon_pay ⇒ Object
If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.
-
#au_becs_debit ⇒ Object
If this is an ‘au_becs_debit` PaymentMethod, this hash contains details about the bank account.
-
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.
-
#bancontact ⇒ Object
If this is a ‘bancontact` PaymentMethod, this hash contains details about the Bancontact payment method.
-
#billie ⇒ Object
If this is a ‘billie` PaymentMethod, this hash contains details about the Billie payment method.
-
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
-
#blik ⇒ Object
If this is a ‘blik` PaymentMethod, this hash contains details about the BLIK payment method.
-
#boleto ⇒ Object
If this is a ‘boleto` PaymentMethod, this hash contains details about the Boleto payment method.
-
#cashapp ⇒ Object
If this is a ‘cashapp` PaymentMethod, this hash contains details about the Cash App Pay payment method.
-
#customer_balance ⇒ Object
If this is a ‘customer_balance` PaymentMethod, this hash contains details about the CustomerBalance payment method.
-
#eps ⇒ Object
If this is an ‘eps` PaymentMethod, this hash contains details about the EPS payment method.
-
#fpx ⇒ Object
If this is an ‘fpx` PaymentMethod, this hash contains details about the FPX payment method.
-
#giropay ⇒ Object
If this is a ‘giropay` PaymentMethod, this hash contains details about the Giropay payment method.
-
#gopay ⇒ Object
If this is a Gopay PaymentMethod, this hash contains details about the Gopay payment method.
-
#grabpay ⇒ Object
If this is a ‘grabpay` PaymentMethod, this hash contains details about the GrabPay payment method.
-
#id_bank_transfer ⇒ Object
If this is an ‘IdBankTransfer` PaymentMethod, this hash contains details about the IdBankTransfer payment method.
-
#ideal ⇒ Object
If this is an ‘ideal` PaymentMethod, this hash contains details about the iDEAL payment method.
-
#interac_present ⇒ Object
If this is an ‘interac_present` PaymentMethod, this hash contains details about the Interac Present payment method.
-
#kakao_pay ⇒ Object
If this is a ‘kakao_pay` PaymentMethod, this hash contains details about the Kakao Pay payment method.
-
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method.
-
#konbini ⇒ Object
If this is a ‘konbini` PaymentMethod, this hash contains details about the Konbini payment method.
-
#kr_card ⇒ Object
If this is a ‘kr_card` PaymentMethod, this hash contains details about the Korean Card payment method.
-
#link ⇒ Object
If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.
-
#mb_way ⇒ Object
If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#mobilepay ⇒ Object
If this is a ‘mobilepay` PaymentMethod, this hash contains details about the MobilePay payment method.
-
#multibanco ⇒ Object
If this is a ‘multibanco` PaymentMethod, this hash contains details about the Multibanco payment method.
-
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.
-
#nz_bank_account ⇒ Object
If this is an nz_bank_account PaymentMethod, this hash contains details about the nz_bank_account payment method.
-
#oxxo ⇒ Object
If this is an ‘oxxo` PaymentMethod, this hash contains details about the OXXO payment method.
-
#p24 ⇒ Object
If this is a ‘p24` PaymentMethod, this hash contains details about the P24 payment method.
-
#pay_by_bank ⇒ Object
If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.
-
#payco ⇒ Object
If this is a ‘payco` PaymentMethod, this hash contains details about the PAYCO payment method.
-
#paynow ⇒ Object
If this is a ‘paynow` PaymentMethod, this hash contains details about the PayNow payment method.
-
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this hash contains details about the PayPal payment method.
-
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.
-
#pix ⇒ Object
If this is a ‘pix` PaymentMethod, this hash contains details about the Pix payment method.
-
#promptpay ⇒ Object
If this is a ‘promptpay` PaymentMethod, this hash contains details about the PromptPay payment method.
-
#qris ⇒ Object
If this is a ‘qris` PaymentMethod, this hash contains details about the QRIS payment method.
-
#radar_options ⇒ Object
Options to configure Radar.
-
#rechnung ⇒ Object
If this is a ‘rechnung` PaymentMethod, this hash contains details about the Rechnung payment method.
-
#revolut_pay ⇒ Object
If this is a ‘revolut_pay` PaymentMethod, this hash contains details about the Revolut Pay payment method.
-
#samsung_pay ⇒ Object
If this is a ‘samsung_pay` PaymentMethod, this hash contains details about the SamsungPay payment method.
-
#satispay ⇒ Object
If this is a ‘satispay` PaymentMethod, this hash contains details about the Satispay payment method.
-
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` PaymentMethod, this hash contains details about the SEPA debit bank account.
-
#shopeepay ⇒ Object
If this is a Shopeepay PaymentMethod, this hash contains details about the Shopeepay payment method.
-
#sofort ⇒ Object
If this is a ‘sofort` PaymentMethod, this hash contains details about the SOFORT payment method.
-
#stripe_balance ⇒ Object
This hash contains details about the Stripe balance payment method.
-
#swish ⇒ Object
If this is a ‘swish` PaymentMethod, this hash contains details about the Swish payment method.
-
#twint ⇒ Object
If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.
-
#type ⇒ Object
The type of the PaymentMethod.
-
#us_bank_account ⇒ Object
If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.
-
#wechat_pay ⇒ Object
If this is an ‘wechat_pay` PaymentMethod, this hash contains details about the wechat_pay payment method.
-
#zip ⇒ Object
If this is a ‘zip` PaymentMethod, this hash contains details about the Zip payment method.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, billing_details: nil, blik: nil, boleto: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, radar_options: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, swish: nil, twint: nil, type: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodData
Returns a new instance of PaymentMethodData.
1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1344 def initialize( acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, billing_details: nil, blik: nil, boleto: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, radar_options: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, swish: nil, twint: nil, type: nil, us_bank_account: nil, wechat_pay: nil, zip: nil ) @acss_debit = acss_debit @affirm = affirm @afterpay_clearpay = afterpay_clearpay @alipay = alipay @allow_redisplay = allow_redisplay @alma = alma @amazon_pay = amazon_pay @au_becs_debit = au_becs_debit @bacs_debit = bacs_debit @bancontact = bancontact @billie = billie @billing_details = billing_details @blik = blik @boleto = boleto @cashapp = cashapp @customer_balance = customer_balance @eps = eps @fpx = fpx @giropay = giropay @gopay = gopay @grabpay = grabpay @id_bank_transfer = id_bank_transfer @ideal = ideal @interac_present = interac_present @kakao_pay = kakao_pay @klarna = klarna @konbini = konbini @kr_card = kr_card @link = link @mb_way = mb_way @metadata = @mobilepay = mobilepay @multibanco = multibanco @naver_pay = naver_pay @nz_bank_account = nz_bank_account @oxxo = oxxo @p24 = p24 @pay_by_bank = pay_by_bank @payco = payco @paynow = paynow @paypal = paypal @payto = payto @pix = pix @promptpay = promptpay @qris = qris @radar_options = @rechnung = rechnung @revolut_pay = revolut_pay @samsung_pay = samsung_pay @satispay = satispay @sepa_debit = sepa_debit @shopeepay = shopeepay @sofort = sofort @stripe_balance = stripe_balance @swish = swish @twint = twint @type = type @us_bank_account = us_bank_account @wechat_pay = wechat_pay @zip = zip end |
Instance Attribute Details
#acss_debit ⇒ Object
If this is an ‘acss_debit` PaymentMethod, this hash contains details about the ACSS Debit payment method.
1224 1225 1226 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1224 def acss_debit @acss_debit end |
#affirm ⇒ Object
If this is an ‘affirm` PaymentMethod, this hash contains details about the Affirm payment method.
1226 1227 1228 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1226 def affirm @affirm end |
#afterpay_clearpay ⇒ Object
If this is an ‘AfterpayClearpay` PaymentMethod, this hash contains details about the AfterpayClearpay payment method.
1228 1229 1230 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1228 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
If this is an ‘Alipay` PaymentMethod, this hash contains details about the Alipay payment method.
1230 1231 1232 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1230 def alipay @alipay end |
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.
1232 1233 1234 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1232 def allow_redisplay @allow_redisplay end |
#alma ⇒ Object
If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.
1234 1235 1236 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1234 def alma @alma end |
#amazon_pay ⇒ Object
If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.
1236 1237 1238 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1236 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object
If this is an ‘au_becs_debit` PaymentMethod, this hash contains details about the bank account.
1238 1239 1240 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1238 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.
1240 1241 1242 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1240 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object
If this is a ‘bancontact` PaymentMethod, this hash contains details about the Bancontact payment method.
1242 1243 1244 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1242 def bancontact @bancontact end |
#billie ⇒ Object
If this is a ‘billie` PaymentMethod, this hash contains details about the Billie payment method.
1244 1245 1246 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1244 def billie @billie end |
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
1246 1247 1248 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1246 def billing_details @billing_details end |
#blik ⇒ Object
If this is a ‘blik` PaymentMethod, this hash contains details about the BLIK payment method.
1248 1249 1250 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1248 def blik @blik end |
#boleto ⇒ Object
If this is a ‘boleto` PaymentMethod, this hash contains details about the Boleto payment method.
1250 1251 1252 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1250 def boleto @boleto end |
#cashapp ⇒ Object
If this is a ‘cashapp` PaymentMethod, this hash contains details about the Cash App Pay payment method.
1252 1253 1254 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1252 def cashapp @cashapp end |
#customer_balance ⇒ Object
If this is a ‘customer_balance` PaymentMethod, this hash contains details about the CustomerBalance payment method.
1254 1255 1256 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1254 def customer_balance @customer_balance end |
#eps ⇒ Object
If this is an ‘eps` PaymentMethod, this hash contains details about the EPS payment method.
1256 1257 1258 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1256 def eps @eps end |
#fpx ⇒ Object
If this is an ‘fpx` PaymentMethod, this hash contains details about the FPX payment method.
1258 1259 1260 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1258 def fpx @fpx end |
#giropay ⇒ Object
If this is a ‘giropay` PaymentMethod, this hash contains details about the Giropay payment method.
1260 1261 1262 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1260 def giropay @giropay end |
#gopay ⇒ Object
If this is a Gopay PaymentMethod, this hash contains details about the Gopay payment method.
1262 1263 1264 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1262 def gopay @gopay end |
#grabpay ⇒ Object
If this is a ‘grabpay` PaymentMethod, this hash contains details about the GrabPay payment method.
1264 1265 1266 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1264 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object
If this is an ‘IdBankTransfer` PaymentMethod, this hash contains details about the IdBankTransfer payment method.
1266 1267 1268 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1266 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object
If this is an ‘ideal` PaymentMethod, this hash contains details about the iDEAL payment method.
1268 1269 1270 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1268 def ideal @ideal end |
#interac_present ⇒ Object
If this is an ‘interac_present` PaymentMethod, this hash contains details about the Interac Present payment method.
1270 1271 1272 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1270 def interac_present @interac_present end |
#kakao_pay ⇒ Object
If this is a ‘kakao_pay` PaymentMethod, this hash contains details about the Kakao Pay payment method.
1272 1273 1274 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1272 def kakao_pay @kakao_pay end |
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method.
1274 1275 1276 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1274 def klarna @klarna end |
#konbini ⇒ Object
If this is a ‘konbini` PaymentMethod, this hash contains details about the Konbini payment method.
1276 1277 1278 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1276 def konbini @konbini end |
#kr_card ⇒ Object
If this is a ‘kr_card` PaymentMethod, this hash contains details about the Korean Card payment method.
1278 1279 1280 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1278 def kr_card @kr_card end |
#link ⇒ Object
If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.
1280 1281 1282 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1280 def link @link end |
#mb_way ⇒ Object
If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.
1282 1283 1284 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1282 def mb_way @mb_way end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1284 1285 1286 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1284 def @metadata end |
#mobilepay ⇒ Object
If this is a ‘mobilepay` PaymentMethod, this hash contains details about the MobilePay payment method.
1286 1287 1288 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1286 def mobilepay @mobilepay end |
#multibanco ⇒ Object
If this is a ‘multibanco` PaymentMethod, this hash contains details about the Multibanco payment method.
1288 1289 1290 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1288 def multibanco @multibanco end |
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.
1290 1291 1292 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1290 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object
If this is an nz_bank_account PaymentMethod, this hash contains details about the nz_bank_account payment method.
1292 1293 1294 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1292 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object
If this is an ‘oxxo` PaymentMethod, this hash contains details about the OXXO payment method.
1294 1295 1296 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1294 def oxxo @oxxo end |
#p24 ⇒ Object
If this is a ‘p24` PaymentMethod, this hash contains details about the P24 payment method.
1296 1297 1298 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1296 def p24 @p24 end |
#pay_by_bank ⇒ Object
If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.
1298 1299 1300 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1298 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object
If this is a ‘payco` PaymentMethod, this hash contains details about the PAYCO payment method.
1300 1301 1302 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1300 def payco @payco end |
#paynow ⇒ Object
If this is a ‘paynow` PaymentMethod, this hash contains details about the PayNow payment method.
1302 1303 1304 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1302 def paynow @paynow end |
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this hash contains details about the PayPal payment method.
1304 1305 1306 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1304 def paypal @paypal end |
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.
1306 1307 1308 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1306 def payto @payto end |
#pix ⇒ Object
If this is a ‘pix` PaymentMethod, this hash contains details about the Pix payment method.
1308 1309 1310 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1308 def pix @pix end |
#promptpay ⇒ Object
If this is a ‘promptpay` PaymentMethod, this hash contains details about the PromptPay payment method.
1310 1311 1312 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1310 def promptpay @promptpay end |
#qris ⇒ Object
If this is a ‘qris` PaymentMethod, this hash contains details about the QRIS payment method.
1312 1313 1314 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1312 def qris @qris end |
#radar_options ⇒ Object
Options to configure Radar. See [Radar Session](stripe.com/docs/radar/radar-session) for more information.
1314 1315 1316 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1314 def @radar_options end |
#rechnung ⇒ Object
If this is a ‘rechnung` PaymentMethod, this hash contains details about the Rechnung payment method.
1316 1317 1318 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1316 def rechnung @rechnung end |
#revolut_pay ⇒ Object
If this is a ‘revolut_pay` PaymentMethod, this hash contains details about the Revolut Pay payment method.
1318 1319 1320 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1318 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object
If this is a ‘samsung_pay` PaymentMethod, this hash contains details about the SamsungPay payment method.
1320 1321 1322 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1320 def samsung_pay @samsung_pay end |
#satispay ⇒ Object
If this is a ‘satispay` PaymentMethod, this hash contains details about the Satispay payment method.
1322 1323 1324 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1322 def satispay @satispay end |
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` PaymentMethod, this hash contains details about the SEPA debit bank account.
1324 1325 1326 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1324 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object
If this is a Shopeepay PaymentMethod, this hash contains details about the Shopeepay payment method.
1326 1327 1328 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1326 def shopeepay @shopeepay end |
#sofort ⇒ Object
If this is a ‘sofort` PaymentMethod, this hash contains details about the SOFORT payment method.
1328 1329 1330 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1328 def sofort @sofort end |
#stripe_balance ⇒ Object
This hash contains details about the Stripe balance payment method.
1330 1331 1332 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1330 def stripe_balance @stripe_balance end |
#swish ⇒ Object
If this is a ‘swish` PaymentMethod, this hash contains details about the Swish payment method.
1332 1333 1334 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1332 def swish @swish end |
#twint ⇒ Object
If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.
1334 1335 1336 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1334 def twint @twint end |
#type ⇒ Object
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
1336 1337 1338 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1336 def type @type end |
#us_bank_account ⇒ Object
If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.
1338 1339 1340 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1338 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
If this is an ‘wechat_pay` PaymentMethod, this hash contains details about the wechat_pay payment method.
1340 1341 1342 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1340 def wechat_pay @wechat_pay end |
#zip ⇒ Object
If this is a ‘zip` PaymentMethod, this hash contains details about the Zip payment method.
1342 1343 1344 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1342 def zip @zip end |