Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1216 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1204 1205 1206 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1204 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
1206 1207 1208 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1206 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
1208 1209 1210 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1208 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
1210 1211 1212 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1210 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
1212 1213 1214 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1212 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
1214 1215 1216 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1214 def suffix @suffix end |