Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/stripe/services/payment_intent_service.rb', line 311

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



299
300
301
# File 'lib/stripe/services/payment_intent_service.rb', line 299

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



301
302
303
# File 'lib/stripe/services/payment_intent_service.rb', line 301

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



303
304
305
# File 'lib/stripe/services/payment_intent_service.rb', line 303

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



305
306
307
# File 'lib/stripe/services/payment_intent_service.rb', line 305

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



307
308
309
# File 'lib/stripe/services/payment_intent_service.rb', line 307

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



309
310
311
# File 'lib/stripe/services/payment_intent_service.rb', line 309

def suffix
  @suffix
end