Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1062 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1050 1051 1052 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1050 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
1052 1053 1054 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1052 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
1054 1055 1056 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1054 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
1056 1057 1058 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1056 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
1058 1059 1060 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1058 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
1060 1061 1062 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1060 def suffix @suffix end |