Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/stripe/services/payment_intent_service.rb', line 342

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



330
331
332
# File 'lib/stripe/services/payment_intent_service.rb', line 330

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



332
333
334
# File 'lib/stripe/services/payment_intent_service.rb', line 332

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



334
335
336
# File 'lib/stripe/services/payment_intent_service.rb', line 334

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



336
337
338
# File 'lib/stripe/services/payment_intent_service.rb', line 336

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



338
339
340
# File 'lib/stripe/services/payment_intent_service.rb', line 338

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



340
341
342
# File 'lib/stripe/services/payment_intent_service.rb', line 340

def suffix
  @suffix
end