Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/stripe/services/payment_intent_service.rb', line 1064

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1052
1053
1054
# File 'lib/stripe/services/payment_intent_service.rb', line 1052

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



1054
1055
1056
# File 'lib/stripe/services/payment_intent_service.rb', line 1054

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



1056
1057
1058
# File 'lib/stripe/services/payment_intent_service.rb', line 1056

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



1058
1059
1060
# File 'lib/stripe/services/payment_intent_service.rb', line 1058

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



1060
1061
1062
# File 'lib/stripe/services/payment_intent_service.rb', line 1060

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



1062
1063
1064
# File 'lib/stripe/services/payment_intent_service.rb', line 1062

def suffix
  @suffix
end