Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
# File 'lib/stripe/services/payment_intent_service.rb', line 1046

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1034
1035
1036
# File 'lib/stripe/services/payment_intent_service.rb', line 1034

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



1036
1037
1038
# File 'lib/stripe/services/payment_intent_service.rb', line 1036

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



1038
1039
1040
# File 'lib/stripe/services/payment_intent_service.rb', line 1038

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



1040
1041
1042
# File 'lib/stripe/services/payment_intent_service.rb', line 1040

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



1042
1043
1044
# File 'lib/stripe/services/payment_intent_service.rb', line 1042

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



1044
1045
1046
# File 'lib/stripe/services/payment_intent_service.rb', line 1044

def suffix
  @suffix
end