Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
443 444 445 446 447 448 449 450 451 452 453 454 455 |
# File 'lib/stripe/services/payment_intent_service.rb', line 443 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
433 434 435 |
# File 'lib/stripe/services/payment_intent_service.rb', line 433 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
435 436 437 |
# File 'lib/stripe/services/payment_intent_service.rb', line 435 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
437 438 439 |
# File 'lib/stripe/services/payment_intent_service.rb', line 437 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
439 440 441 |
# File 'lib/stripe/services/payment_intent_service.rb', line 439 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
441 442 443 |
# File 'lib/stripe/services/payment_intent_service.rb', line 441 def routing_number @routing_number end |