Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CardPresent, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, SepaDebit, Shopeepay, Sofort, StripeBalance, Swish, Twint, UsBankAccount, WechatPay, Zip
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If this is a ‘acss_debit` PaymentMethod, this sub-hash contains details about the ACSS Debit payment method options.
-
#affirm ⇒ Object
If this is an ‘affirm` PaymentMethod, this sub-hash contains details about the Affirm payment method options.
-
#afterpay_clearpay ⇒ Object
If this is a ‘afterpay_clearpay` PaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options.
-
#alipay ⇒ Object
If this is a ‘alipay` PaymentMethod, this sub-hash contains details about the Alipay payment method options.
-
#alma ⇒ Object
If this is a ‘alma` PaymentMethod, this sub-hash contains details about the Alma payment method options.
-
#amazon_pay ⇒ Object
If this is a ‘amazon_pay` PaymentMethod, this sub-hash contains details about the Amazon Pay payment method options.
-
#au_becs_debit ⇒ Object
If this is a ‘au_becs_debit` PaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options.
-
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` PaymentMethod, this sub-hash contains details about the BACS Debit payment method options.
-
#bancontact ⇒ Object
If this is a ‘bancontact` PaymentMethod, this sub-hash contains details about the Bancontact payment method options.
-
#billie ⇒ Object
If this is a ‘billie` PaymentMethod, this sub-hash contains details about the Billie payment method options.
-
#blik ⇒ Object
If this is a ‘blik` PaymentMethod, this sub-hash contains details about the BLIK payment method options.
-
#boleto ⇒ Object
If this is a ‘boleto` PaymentMethod, this sub-hash contains details about the Boleto payment method options.
-
#card ⇒ Object
Configuration for any card payments attempted on this PaymentIntent.
-
#card_present ⇒ Object
If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.
-
#cashapp ⇒ Object
If this is a ‘cashapp` PaymentMethod, this sub-hash contains details about the Cash App Pay payment method options.
-
#customer_balance ⇒ Object
If this is a ‘customer balance` PaymentMethod, this sub-hash contains details about the customer balance payment method options.
-
#eps ⇒ Object
If this is a ‘eps` PaymentMethod, this sub-hash contains details about the EPS payment method options.
-
#fpx ⇒ Object
If this is a ‘fpx` PaymentMethod, this sub-hash contains details about the FPX payment method options.
-
#giropay ⇒ Object
If this is a ‘giropay` PaymentMethod, this sub-hash contains details about the Giropay payment method options.
-
#gopay ⇒ Object
If this is a ‘gopay` PaymentMethod, this sub-hash contains details about the GoPay payment method options.
-
#grabpay ⇒ Object
If this is a ‘grabpay` PaymentMethod, this sub-hash contains details about the Grabpay payment method options.
-
#id_bank_transfer ⇒ Object
If this is a ‘id_bank_transfer` PaymentMethod, this sub-hash contains details about the Indonesia Bank Transfer payment method options.
-
#ideal ⇒ Object
If this is a ‘ideal` PaymentMethod, this sub-hash contains details about the Ideal payment method options.
-
#interac_present ⇒ Object
If this is a ‘interac_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.
-
#kakao_pay ⇒ Object
If this is a ‘kakao_pay` PaymentMethod, this sub-hash contains details about the Kakao Pay payment method options.
-
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this sub-hash contains details about the Klarna payment method options.
-
#konbini ⇒ Object
If this is a ‘konbini` PaymentMethod, this sub-hash contains details about the Konbini payment method options.
-
#kr_card ⇒ Object
If this is a ‘kr_card` PaymentMethod, this sub-hash contains details about the KR Card payment method options.
-
#link ⇒ Object
If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options.
-
#mb_way ⇒ Object
If this is a ‘mb_way` PaymentMethod, this sub-hash contains details about the MB WAY payment method options.
-
#mobilepay ⇒ Object
If this is a ‘MobilePay` PaymentMethod, this sub-hash contains details about the MobilePay payment method options.
-
#multibanco ⇒ Object
If this is a ‘multibanco` PaymentMethod, this sub-hash contains details about the Multibanco payment method options.
-
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this sub-hash contains details about the Naver Pay payment method options.
-
#nz_bank_account ⇒ Object
If this is a ‘nz_bank_account` PaymentMethod, this sub-hash contains details about the NZ BECS Direct Debit payment method options.
-
#oxxo ⇒ Object
If this is a ‘oxxo` PaymentMethod, this sub-hash contains details about the OXXO payment method options.
-
#p24 ⇒ Object
If this is a ‘p24` PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options.
-
#pay_by_bank ⇒ Object
If this is a ‘pay_by_bank` PaymentMethod, this sub-hash contains details about the PayByBank payment method options.
-
#payco ⇒ Object
If this is a ‘payco` PaymentMethod, this sub-hash contains details about the PAYCO payment method options.
-
#paynow ⇒ Object
If this is a ‘paynow` PaymentMethod, this sub-hash contains details about the PayNow payment method options.
-
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.
-
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this sub-hash contains details about the PayTo payment method options.
-
#pix ⇒ Object
If this is a ‘pix` PaymentMethod, this sub-hash contains details about the Pix payment method options.
-
#promptpay ⇒ Object
If this is a ‘promptpay` PaymentMethod, this sub-hash contains details about the PromptPay payment method options.
-
#qris ⇒ Object
If this is a ‘qris` PaymentMethod, this sub-hash contains details about the QRIS payment method options.
-
#rechnung ⇒ Object
If this is a ‘rechnung` PaymentMethod, this sub-hash contains details about the Rechnung payment method options.
-
#revolut_pay ⇒ Object
If this is a ‘revolut_pay` PaymentMethod, this sub-hash contains details about the Revolut Pay payment method options.
-
#samsung_pay ⇒ Object
If this is a ‘samsung_pay` PaymentMethod, this sub-hash contains details about the Samsung Pay payment method options.
-
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` PaymentIntent, this sub-hash contains details about the SEPA Debit payment method options.
-
#shopeepay ⇒ Object
If this is a ‘shopeepay` PaymentMethod, this sub-hash contains details about the ShopeePay payment method options.
-
#sofort ⇒ Object
If this is a ‘sofort` PaymentMethod, this sub-hash contains details about the SOFORT payment method options.
-
#stripe_balance ⇒ Object
If this is a ‘stripe_balance` PaymentMethod, this sub-hash contains details about the Stripe Balance payment method options.
-
#swish ⇒ Object
If this is a ‘Swish` PaymentMethod, this sub-hash contains details about the Swish payment method options.
-
#twint ⇒ Object
If this is a ‘twint` PaymentMethod, this sub-hash contains details about the TWINT payment method options.
-
#us_bank_account ⇒ Object
If this is a ‘us_bank_account` PaymentMethod, this sub-hash contains details about the US bank account payment method options.
-
#wechat_pay ⇒ Object
If this is a ‘wechat_pay` PaymentMethod, this sub-hash contains details about the WeChat Pay payment method options.
-
#zip ⇒ Object
If this is a ‘zip` PaymentMethod, this sub-hash contains details about the Zip payment method options.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, blik: nil, boleto: nil, card: nil, card_present: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
3217 3218 3219 3220 3221 3222 3223 3224 3225 3226 3227 3228 3229 3230 3231 3232 3233 3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 3295 3296 3297 3298 3299 3300 3301 3302 3303 3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 3318 3319 3320 3321 3322 3323 3324 3325 3326 3327 3328 3329 3330 3331 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3217 def initialize( acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, blik: nil, boleto: nil, card: nil, card_present: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil ) @acss_debit = acss_debit @affirm = affirm @afterpay_clearpay = afterpay_clearpay @alipay = alipay @alma = alma @amazon_pay = amazon_pay @au_becs_debit = au_becs_debit @bacs_debit = bacs_debit @bancontact = bancontact @billie = billie @blik = blik @boleto = boleto @card = card @card_present = card_present @cashapp = cashapp @customer_balance = customer_balance @eps = eps @fpx = fpx @giropay = giropay @gopay = gopay @grabpay = grabpay @id_bank_transfer = id_bank_transfer @ideal = ideal @interac_present = interac_present @kakao_pay = kakao_pay @klarna = klarna @konbini = konbini @kr_card = kr_card @link = link @mb_way = mb_way @mobilepay = mobilepay @multibanco = multibanco @naver_pay = naver_pay @nz_bank_account = nz_bank_account @oxxo = oxxo @p24 = p24 @pay_by_bank = pay_by_bank @payco = payco @paynow = paynow @paypal = paypal @payto = payto @pix = pix @promptpay = promptpay @qris = qris @rechnung = rechnung @revolut_pay = revolut_pay @samsung_pay = samsung_pay @sepa_debit = sepa_debit @shopeepay = shopeepay @sofort = sofort @stripe_balance = stripe_balance @swish = swish @twint = twint @us_bank_account = us_bank_account @wechat_pay = wechat_pay @zip = zip end |
Instance Attribute Details
#acss_debit ⇒ Object
If this is a ‘acss_debit` PaymentMethod, this sub-hash contains details about the ACSS Debit payment method options.
3105 3106 3107 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3105 def acss_debit @acss_debit end |
#affirm ⇒ Object
If this is an ‘affirm` PaymentMethod, this sub-hash contains details about the Affirm payment method options.
3107 3108 3109 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3107 def affirm @affirm end |
#afterpay_clearpay ⇒ Object
If this is a ‘afterpay_clearpay` PaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options.
3109 3110 3111 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3109 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
If this is a ‘alipay` PaymentMethod, this sub-hash contains details about the Alipay payment method options.
3111 3112 3113 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3111 def alipay @alipay end |
#alma ⇒ Object
If this is a ‘alma` PaymentMethod, this sub-hash contains details about the Alma payment method options.
3113 3114 3115 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3113 def alma @alma end |
#amazon_pay ⇒ Object
If this is a ‘amazon_pay` PaymentMethod, this sub-hash contains details about the Amazon Pay payment method options.
3115 3116 3117 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3115 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object
If this is a ‘au_becs_debit` PaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options.
3117 3118 3119 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3117 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` PaymentMethod, this sub-hash contains details about the BACS Debit payment method options.
3119 3120 3121 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3119 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object
If this is a ‘bancontact` PaymentMethod, this sub-hash contains details about the Bancontact payment method options.
3121 3122 3123 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3121 def bancontact @bancontact end |
#billie ⇒ Object
If this is a ‘billie` PaymentMethod, this sub-hash contains details about the Billie payment method options.
3123 3124 3125 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3123 def billie @billie end |
#blik ⇒ Object
If this is a ‘blik` PaymentMethod, this sub-hash contains details about the BLIK payment method options.
3125 3126 3127 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3125 def blik @blik end |
#boleto ⇒ Object
If this is a ‘boleto` PaymentMethod, this sub-hash contains details about the Boleto payment method options.
3127 3128 3129 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3127 def boleto @boleto end |
#card ⇒ Object
Configuration for any card payments attempted on this PaymentIntent.
3129 3130 3131 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3129 def card @card end |
#card_present ⇒ Object
If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.
3131 3132 3133 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3131 def card_present @card_present end |
#cashapp ⇒ Object
If this is a ‘cashapp` PaymentMethod, this sub-hash contains details about the Cash App Pay payment method options.
3133 3134 3135 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3133 def cashapp @cashapp end |
#customer_balance ⇒ Object
If this is a ‘customer balance` PaymentMethod, this sub-hash contains details about the customer balance payment method options.
3135 3136 3137 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3135 def customer_balance @customer_balance end |
#eps ⇒ Object
If this is a ‘eps` PaymentMethod, this sub-hash contains details about the EPS payment method options.
3137 3138 3139 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3137 def eps @eps end |
#fpx ⇒ Object
If this is a ‘fpx` PaymentMethod, this sub-hash contains details about the FPX payment method options.
3139 3140 3141 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3139 def fpx @fpx end |
#giropay ⇒ Object
If this is a ‘giropay` PaymentMethod, this sub-hash contains details about the Giropay payment method options.
3141 3142 3143 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3141 def giropay @giropay end |
#gopay ⇒ Object
If this is a ‘gopay` PaymentMethod, this sub-hash contains details about the GoPay payment method options.
3143 3144 3145 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3143 def gopay @gopay end |
#grabpay ⇒ Object
If this is a ‘grabpay` PaymentMethod, this sub-hash contains details about the Grabpay payment method options.
3145 3146 3147 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3145 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object
If this is a ‘id_bank_transfer` PaymentMethod, this sub-hash contains details about the Indonesia Bank Transfer payment method options.
3147 3148 3149 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3147 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object
If this is a ‘ideal` PaymentMethod, this sub-hash contains details about the Ideal payment method options.
3149 3150 3151 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3149 def ideal @ideal end |
#interac_present ⇒ Object
If this is a ‘interac_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.
3151 3152 3153 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3151 def interac_present @interac_present end |
#kakao_pay ⇒ Object
If this is a ‘kakao_pay` PaymentMethod, this sub-hash contains details about the Kakao Pay payment method options.
3153 3154 3155 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3153 def kakao_pay @kakao_pay end |
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this sub-hash contains details about the Klarna payment method options.
3155 3156 3157 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3155 def klarna @klarna end |
#konbini ⇒ Object
If this is a ‘konbini` PaymentMethod, this sub-hash contains details about the Konbini payment method options.
3157 3158 3159 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3157 def konbini @konbini end |
#kr_card ⇒ Object
If this is a ‘kr_card` PaymentMethod, this sub-hash contains details about the KR Card payment method options.
3159 3160 3161 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3159 def kr_card @kr_card end |
#link ⇒ Object
If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options.
3161 3162 3163 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3161 def link @link end |
#mb_way ⇒ Object
If this is a ‘mb_way` PaymentMethod, this sub-hash contains details about the MB WAY payment method options.
3163 3164 3165 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3163 def mb_way @mb_way end |
#mobilepay ⇒ Object
If this is a ‘MobilePay` PaymentMethod, this sub-hash contains details about the MobilePay payment method options.
3165 3166 3167 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3165 def mobilepay @mobilepay end |
#multibanco ⇒ Object
If this is a ‘multibanco` PaymentMethod, this sub-hash contains details about the Multibanco payment method options.
3167 3168 3169 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3167 def multibanco @multibanco end |
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this sub-hash contains details about the Naver Pay payment method options.
3169 3170 3171 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3169 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object
If this is a ‘nz_bank_account` PaymentMethod, this sub-hash contains details about the NZ BECS Direct Debit payment method options.
3171 3172 3173 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3171 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object
If this is a ‘oxxo` PaymentMethod, this sub-hash contains details about the OXXO payment method options.
3173 3174 3175 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3173 def oxxo @oxxo end |
#p24 ⇒ Object
If this is a ‘p24` PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options.
3175 3176 3177 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3175 def p24 @p24 end |
#pay_by_bank ⇒ Object
If this is a ‘pay_by_bank` PaymentMethod, this sub-hash contains details about the PayByBank payment method options.
3177 3178 3179 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3177 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object
If this is a ‘payco` PaymentMethod, this sub-hash contains details about the PAYCO payment method options.
3179 3180 3181 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3179 def payco @payco end |
#paynow ⇒ Object
If this is a ‘paynow` PaymentMethod, this sub-hash contains details about the PayNow payment method options.
3181 3182 3183 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3181 def paynow @paynow end |
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.
3183 3184 3185 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3183 def paypal @paypal end |
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this sub-hash contains details about the PayTo payment method options.
3185 3186 3187 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3185 def payto @payto end |
#pix ⇒ Object
If this is a ‘pix` PaymentMethod, this sub-hash contains details about the Pix payment method options.
3187 3188 3189 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3187 def pix @pix end |
#promptpay ⇒ Object
If this is a ‘promptpay` PaymentMethod, this sub-hash contains details about the PromptPay payment method options.
3189 3190 3191 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3189 def promptpay @promptpay end |
#qris ⇒ Object
If this is a ‘qris` PaymentMethod, this sub-hash contains details about the QRIS payment method options.
3191 3192 3193 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3191 def qris @qris end |
#rechnung ⇒ Object
If this is a ‘rechnung` PaymentMethod, this sub-hash contains details about the Rechnung payment method options.
3193 3194 3195 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3193 def rechnung @rechnung end |
#revolut_pay ⇒ Object
If this is a ‘revolut_pay` PaymentMethod, this sub-hash contains details about the Revolut Pay payment method options.
3195 3196 3197 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3195 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object
If this is a ‘samsung_pay` PaymentMethod, this sub-hash contains details about the Samsung Pay payment method options.
3197 3198 3199 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3197 def samsung_pay @samsung_pay end |
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` PaymentIntent, this sub-hash contains details about the SEPA Debit payment method options.
3199 3200 3201 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3199 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object
If this is a ‘shopeepay` PaymentMethod, this sub-hash contains details about the ShopeePay payment method options.
3201 3202 3203 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3201 def shopeepay @shopeepay end |
#sofort ⇒ Object
If this is a ‘sofort` PaymentMethod, this sub-hash contains details about the SOFORT payment method options.
3203 3204 3205 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3203 def sofort @sofort end |
#stripe_balance ⇒ Object
If this is a ‘stripe_balance` PaymentMethod, this sub-hash contains details about the Stripe Balance payment method options.
3205 3206 3207 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3205 def stripe_balance @stripe_balance end |
#swish ⇒ Object
If this is a ‘Swish` PaymentMethod, this sub-hash contains details about the Swish payment method options.
3207 3208 3209 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3207 def swish @swish end |
#twint ⇒ Object
If this is a ‘twint` PaymentMethod, this sub-hash contains details about the TWINT payment method options.
3209 3210 3211 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3209 def twint @twint end |
#us_bank_account ⇒ Object
If this is a ‘us_bank_account` PaymentMethod, this sub-hash contains details about the US bank account payment method options.
3211 3212 3213 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3211 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
If this is a ‘wechat_pay` PaymentMethod, this sub-hash contains details about the WeChat Pay payment method options.
3213 3214 3215 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3213 def wechat_pay @wechat_pay end |
#zip ⇒ Object
If this is a ‘zip` PaymentMethod, this sub-hash contains details about the Zip payment method options.
3215 3216 3217 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3215 def zip @zip end |