Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Card::Installments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Card::Installments
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Plan
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Setting to true enables installments for this PaymentIntent.
-
#plan ⇒ Object
The selected installment plan to use for this payment attempt.
Instance Method Summary collapse
-
#initialize(enabled: nil, plan: nil) ⇒ Installments
constructor
A new instance of Installments.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, plan: nil) ⇒ Installments
Returns a new instance of Installments.
973 974 975 976 |
# File 'lib/stripe/services/payment_intent_service.rb', line 973 def initialize(enabled: nil, plan: nil) @enabled = enabled @plan = plan end |
Instance Attribute Details
#enabled ⇒ Object
Setting to true enables installments for this PaymentIntent. This will cause the response to contain a list of available installment plans. Setting to false will prevent any selected plan from applying to a charge.
968 969 970 |
# File 'lib/stripe/services/payment_intent_service.rb', line 968 def enabled @enabled end |
#plan ⇒ Object
The selected installment plan to use for this payment attempt. This parameter can only be provided during confirmation.
971 972 973 |
# File 'lib/stripe/services/payment_intent_service.rb', line 971 def plan @plan end |