Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



925
926
927
928
929
# File 'lib/stripe/services/payment_intent_service.rb', line 925

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



918
919
920
# File 'lib/stripe/services/payment_intent_service.rb', line 918

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



921
922
923
# File 'lib/stripe/services/payment_intent_service.rb', line 921

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



923
924
925
# File 'lib/stripe/services/payment_intent_service.rb', line 923

def type
  @type
end