Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



1758
1759
1760
1761
1762
# File 'lib/stripe/services/payment_intent_service.rb', line 1758

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



1751
1752
1753
# File 'lib/stripe/services/payment_intent_service.rb', line 1751

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



1754
1755
1756
# File 'lib/stripe/services/payment_intent_service.rb', line 1754

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`.



1756
1757
1758
# File 'lib/stripe/services/payment_intent_service.rb', line 1756

def type
  @type
end