Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Card::Installments::Plan
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Card::Installments::Plan
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#count ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`.
Instance Method Summary collapse
-
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
constructor
A new instance of Plan.
Methods inherited from RequestParams
Constructor Details
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
Returns a new instance of Plan.
1785 1786 1787 1788 1789 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1785 def initialize(count: nil, interval: nil, type: nil) @count = count @interval = interval @type = type end |
Instance Attribute Details
#count ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.
1778 1779 1780 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1778 def count @count end |
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.
1781 1782 1783 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1781 def interval @interval end |
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`.
1783 1784 1785 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1783 def type @type end |