Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Card::Installments::Plan
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Card::Installments::Plan
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#count ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`.
Instance Method Summary collapse
-
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
constructor
A new instance of Plan.
Methods inherited from RequestParams
Constructor Details
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
Returns a new instance of Plan.
1767 1768 1769 1770 1771 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1767 def initialize(count: nil, interval: nil, type: nil) @count = count @interval = interval @type = type end |
Instance Attribute Details
#count ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.
1760 1761 1762 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1760 def count @count end |
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.
1763 1764 1765 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1763 def interval @interval end |
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`.
1765 1766 1767 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1765 def type @type end |