Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



959
960
961
962
963
# File 'lib/stripe/services/payment_intent_service.rb', line 959

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



952
953
954
# File 'lib/stripe/services/payment_intent_service.rb', line 952

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



955
956
957
# File 'lib/stripe/services/payment_intent_service.rb', line 955

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`.



957
958
959
# File 'lib/stripe/services/payment_intent_service.rb', line 957

def type
  @type
end