Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
# File 'lib/stripe/services/payment_intent_service.rb', line 1711

def initialize(
  amount: nil,
  amount_type: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



1693
1694
1695
# File 'lib/stripe/services/payment_intent_service.rb', line 1693

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



1695
1696
1697
# File 'lib/stripe/services/payment_intent_service.rb', line 1695

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



1697
1698
1699
# File 'lib/stripe/services/payment_intent_service.rb', line 1697

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



1699
1700
1701
# File 'lib/stripe/services/payment_intent_service.rb', line 1699

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



1701
1702
1703
# File 'lib/stripe/services/payment_intent_service.rb', line 1701

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



1703
1704
1705
# File 'lib/stripe/services/payment_intent_service.rb', line 1703

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



1705
1706
1707
# File 'lib/stripe/services/payment_intent_service.rb', line 1705

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



1707
1708
1709
# File 'lib/stripe/services/payment_intent_service.rb', line 1707

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are ‘india`.



1709
1710
1711
# File 'lib/stripe/services/payment_intent_service.rb', line 1709

def supported_types
  @supported_types
end