Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::CustomerBalance::BankTransfer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::CustomerBalance::BankTransfer
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: EuBankTransfer
Instance Attribute Summary collapse
-
#eu_bank_transfer ⇒ Object
Configuration for the eu_bank_transfer funding type.
-
#requested_address_types ⇒ Object
List of address types that should be returned in the financial_addresses response.
-
#type ⇒ Object
The list of bank transfer types that this PaymentIntent is allowed to use for funding Permitted values include: ‘eu_bank_transfer`, `gb_bank_transfer`, `jp_bank_transfer`, `mx_bank_transfer`, or `us_bank_transfer`.
Instance Method Summary collapse
-
#initialize(eu_bank_transfer: nil, requested_address_types: nil, type: nil) ⇒ BankTransfer
constructor
A new instance of BankTransfer.
Methods inherited from RequestParams
Constructor Details
#initialize(eu_bank_transfer: nil, requested_address_types: nil, type: nil) ⇒ BankTransfer
Returns a new instance of BankTransfer.
2106 2107 2108 2109 2110 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2106 def initialize(eu_bank_transfer: nil, requested_address_types: nil, type: nil) @eu_bank_transfer = eu_bank_transfer @requested_address_types = requested_address_types @type = type end |
Instance Attribute Details
#eu_bank_transfer ⇒ Object
Configuration for the eu_bank_transfer funding type.
2098 2099 2100 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2098 def eu_bank_transfer @eu_bank_transfer end |
#requested_address_types ⇒ Object
List of address types that should be returned in the financial_addresses response. If not specified, all valid types will be returned.
Permitted values include: ‘sort_code`, `zengin`, `iban`, or `spei`.
2102 2103 2104 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2102 def requested_address_types @requested_address_types end |
#type ⇒ Object
The list of bank transfer types that this PaymentIntent is allowed to use for funding Permitted values include: ‘eu_bank_transfer`, `gb_bank_transfer`, `jp_bank_transfer`, `mx_bank_transfer`, or `us_bank_transfer`.
2104 2105 2106 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2104 def type @type end |