Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::CustomerBalance::BankTransfer::EuBankTransfer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::CustomerBalance::BankTransfer::EuBankTransfer
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#country ⇒ Object
The desired country code of the bank account information.
Instance Method Summary collapse
-
#initialize(country: nil) ⇒ EuBankTransfer
constructor
A new instance of EuBankTransfer.
Methods inherited from RequestParams
Constructor Details
#initialize(country: nil) ⇒ EuBankTransfer
Returns a new instance of EuBankTransfer.
1999 2000 2001 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1999 def initialize(country: nil) @country = country end |
Instance Attribute Details
#country ⇒ Object
The desired country code of the bank account information. Permitted values include: ‘BE`, `DE`, `ES`, `FR`, `IE`, or `NL`.
1997 1998 1999 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1997 def country @country end |