Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 2712 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2694 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
2678 2679 2680 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2678 def category @category end |
#description ⇒ Object
Description of the line item.
2680 2681 2682 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2680 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
2682 2683 2684 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2682 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
2684 2685 2686 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2684 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
2686 2687 2688 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2686 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
2688 2689 2690 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2688 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
2690 2691 2692 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2690 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
2692 2693 2694 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2692 def unit_amount @unit_amount end |