Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2596 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
2580 2581 2582 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2580 def category @category end |
#description ⇒ Object
Description of the line item.
2582 2583 2584 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2582 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
2584 2585 2586 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2584 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
2586 2587 2588 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2586 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
2588 2589 2590 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2588 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
2590 2591 2592 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2590 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
2592 2593 2594 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2592 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
2594 2595 2596 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2594 def unit_amount @unit_amount end |