Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
2625 2626 2627 2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2625 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
2609 2610 2611 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2609 def category @category end |
#description ⇒ Object
Description of the line item.
2611 2612 2613 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2611 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
2613 2614 2615 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2613 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
2615 2616 2617 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2615 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
2617 2618 2619 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2617 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
2619 2620 2621 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2619 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
2621 2622 2623 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2621 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
2623 2624 2625 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2623 def unit_amount @unit_amount end |