Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
2513
2514
# File 'lib/stripe/services/payment_intent_service.rb', line 2496

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



2480
2481
2482
# File 'lib/stripe/services/payment_intent_service.rb', line 2480

def category
  @category
end

#descriptionObject

Description of the line item.



2482
2483
2484
# File 'lib/stripe/services/payment_intent_service.rb', line 2482

def description
  @description
end

#nameObject

Descriptive name of the line item.



2484
2485
2486
# File 'lib/stripe/services/payment_intent_service.rb', line 2484

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



2486
2487
2488
# File 'lib/stripe/services/payment_intent_service.rb', line 2486

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



2488
2489
2490
# File 'lib/stripe/services/payment_intent_service.rb', line 2488

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



2490
2491
2492
# File 'lib/stripe/services/payment_intent_service.rb', line 2490

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



2492
2493
2494
# File 'lib/stripe/services/payment_intent_service.rb', line 2492

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



2494
2495
2496
# File 'lib/stripe/services/payment_intent_service.rb', line 2494

def unit_amount
  @unit_amount
end