Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
# File 'lib/stripe/services/payment_intent_service.rb', line 2472

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



2456
2457
2458
# File 'lib/stripe/services/payment_intent_service.rb', line 2456

def category
  @category
end

#descriptionObject

Description of the line item.



2458
2459
2460
# File 'lib/stripe/services/payment_intent_service.rb', line 2458

def description
  @description
end

#nameObject

Descriptive name of the line item.



2460
2461
2462
# File 'lib/stripe/services/payment_intent_service.rb', line 2460

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



2462
2463
2464
# File 'lib/stripe/services/payment_intent_service.rb', line 2462

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



2464
2465
2466
# File 'lib/stripe/services/payment_intent_service.rb', line 2464

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



2466
2467
2468
# File 'lib/stripe/services/payment_intent_service.rb', line 2466

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



2468
2469
2470
# File 'lib/stripe/services/payment_intent_service.rb', line 2468

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



2470
2471
2472
# File 'lib/stripe/services/payment_intent_service.rb', line 2470

def unit_amount
  @unit_amount
end