Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
2753 2754 2755 2756 2757 2758 2759 2760 2761 2762 2763 2764 2765 2766 2767 2768 2769 2770 2771 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2753 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
2730 2731 2732 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2730 def category @category end |
#description ⇒ Object
Description of the line item.
2733 2734 2735 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2733 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
2736 2737 2738 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2736 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
2739 2740 2741 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2739 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
2742 2743 2744 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2742 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
2745 2746 2747 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2745 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
2748 2749 2750 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2748 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
2751 2752 2753 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2751 def unit_amount @unit_amount end |