Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
2482 2483 2484 2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 2496 2497 2498 2499 2500 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2482 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
2466 2467 2468 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2466 def category @category end |
#description ⇒ Object
Description of the line item.
2468 2469 2470 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2468 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
2470 2471 2472 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2470 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
2472 2473 2474 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2472 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
2474 2475 2476 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2474 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
2476 2477 2478 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2476 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
2478 2479 2480 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2478 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
2480 2481 2482 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2480 def unit_amount @unit_amount end |