Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The tax for a single unit of the line item in minor units.
-
#behavior ⇒ Object
The tax behavior for the line item.
Instance Method Summary collapse
-
#initialize(amount: nil, behavior: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, behavior: nil) ⇒ Tax
Returns a new instance of Tax.
2450 2451 2452 2453 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2450 def initialize(amount: nil, behavior: nil) @amount = amount @behavior = behavior end |
Instance Attribute Details
#amount ⇒ Object
The tax for a single unit of the line item in minor units. Cannot be a negative number.
2446 2447 2448 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2446 def amount @amount end |
#behavior ⇒ Object
The tax behavior for the line item.
2448 2449 2450 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2448 def behavior @behavior end |