Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::UsBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: FinancialConnections, MandateOptions, Networks

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(financial_connections: nil, mandate_options: nil, networks: nil, preferred_settlement_speed: nil, setup_future_usage: nil, verification_method: nil) ⇒ UsBankAccount

Returns a new instance of UsBankAccount.



2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
# File 'lib/stripe/services/payment_intent_service.rb', line 2881

def initialize(
  financial_connections: nil,
  mandate_options: nil,
  networks: nil,
  preferred_settlement_speed: nil,
  setup_future_usage: nil,
  verification_method: nil
)
  @financial_connections = financial_connections
  @mandate_options = mandate_options
  @networks = networks
  @preferred_settlement_speed = preferred_settlement_speed
  @setup_future_usage = setup_future_usage
  @verification_method = verification_method
end

Instance Attribute Details

#financial_connectionsObject

Additional fields for Financial Connections Session creation



2861
2862
2863
# File 'lib/stripe/services/payment_intent_service.rb', line 2861

def financial_connections
  @financial_connections
end

#mandate_optionsObject

Additional fields for Mandate creation



2863
2864
2865
# File 'lib/stripe/services/payment_intent_service.rb', line 2863

def mandate_options
  @mandate_options
end

#networksObject

Additional fields for network related functions



2865
2866
2867
# File 'lib/stripe/services/payment_intent_service.rb', line 2865

def networks
  @networks
end

#preferred_settlement_speedObject

Preferred transaction settlement speed



2867
2868
2869
# File 'lib/stripe/services/payment_intent_service.rb', line 2867

def preferred_settlement_speed
  @preferred_settlement_speed
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



2877
2878
2879
# File 'lib/stripe/services/payment_intent_service.rb', line 2877

def setup_future_usage
  @setup_future_usage
end

#verification_methodObject

Bank account verification method.



2879
2880
2881
# File 'lib/stripe/services/payment_intent_service.rb', line 2879

def verification_method
  @verification_method
end