Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
# File 'lib/stripe/services/payment_intent_service.rb', line 3072

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



3062
3063
3064
# File 'lib/stripe/services/payment_intent_service.rb', line 3062

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



3064
3065
3066
# File 'lib/stripe/services/payment_intent_service.rb', line 3064

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



3066
3067
3068
# File 'lib/stripe/services/payment_intent_service.rb', line 3066

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



3068
3069
3070
# File 'lib/stripe/services/payment_intent_service.rb', line 3068

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



3070
3071
3072
# File 'lib/stripe/services/payment_intent_service.rb', line 3070

def return_url
  @return_url
end