Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Filters
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(filters: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
1875 1876 1877 1878 1879 1880 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1875 def initialize(filters: nil, permissions: nil, prefetch: nil, return_url: nil) @filters = filters @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
1867 1868 1869 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1867 def filters @filters end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
1869 1870 1871 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1869 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
1871 1872 1873 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1871 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
1873 1874 1875 |
# File 'lib/stripe/services/payment_intent_service.rb', line 1873 def return_url @return_url end |