Class: Stripe::PaymentIntentService::CreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
# File 'lib/stripe/services/payment_intent_service.rb', line 2828

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method



2818
2819
2820
# File 'lib/stripe/services/payment_intent_service.rb', line 2818

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



2820
2821
2822
# File 'lib/stripe/services/payment_intent_service.rb', line 2820

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



2822
2823
2824
# File 'lib/stripe/services/payment_intent_service.rb', line 2822

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



2824
2825
2826
# File 'lib/stripe/services/payment_intent_service.rb', line 2824

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



2826
2827
2828
# File 'lib/stripe/services/payment_intent_service.rb', line 2826

def return_url
  @return_url
end