Class: Stripe::PaymentIntentService::CreateParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::CreateParams::TransferData
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds.
-
#destination ⇒ Object
If specified, successful charges will be attributed to the destination account for tax reporting, and the funds from charges will be transferred to the destination account.
Instance Method Summary collapse
-
#initialize(amount: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
3589 3590 3591 3592 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3589 def initialize(amount: nil, destination: nil) @amount = amount @destination = destination end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds. The amount is capped at the total transaction amount and if no amount is set, the full amount is transferred.
If you intend to collect a fee and you need a more robust reporting experience, using [application_fee_amount](stripe.com/docs/api/payment_intents/create#create_payment_intent-application_fee_amount) might be a better fit for your integration.
3581 3582 3583 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3581 def amount @amount end |
#destination ⇒ Object
If specified, successful charges will be attributed to the destination account for tax reporting, and the funds from charges will be transferred to the destination account. The ID of the resulting transfer will be returned on the successful charge’s ‘transfer` field.
3587 3588 3589 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3587 def destination @destination end |