Class: Stripe::PaymentIntentService::DecrementAuthorizationParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Hooks, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, transfer_data: nil) ⇒ DecrementAuthorizationParams

Returns a new instance of DecrementAuthorizationParams.



12238
12239
12240
12241
12242
12243
12244
12245
12246
12247
12248
12249
12250
12251
12252
12253
12254
# File 'lib/stripe/services/payment_intent_service.rb', line 12238

def initialize(
  amount: nil,
  application_fee_amount: nil,
  description: nil,
  expand: nil,
  hooks: nil,
  metadata: nil,
  transfer_data: nil
)
  @amount = amount
  @application_fee_amount = application_fee_amount
  @description = description
  @expand = expand
  @hooks = hooks
  @metadata = 
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The updated total amount that you intend to collect from the cardholder. This amount must be smaller than the currently authorized amount and greater than the already captured amount.



12223
12224
12225
# File 'lib/stripe/services/payment_intent_service.rb', line 12223

def amount
  @amount
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



12225
12226
12227
# File 'lib/stripe/services/payment_intent_service.rb', line 12225

def application_fee_amount
  @application_fee_amount
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



12227
12228
12229
# File 'lib/stripe/services/payment_intent_service.rb', line 12227

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



12229
12230
12231
# File 'lib/stripe/services/payment_intent_service.rb', line 12229

def expand
  @expand
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



12231
12232
12233
# File 'lib/stripe/services/payment_intent_service.rb', line 12231

def hooks
  @hooks
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



12233
12234
12235
# File 'lib/stripe/services/payment_intent_service.rb', line 12233

def 
  @metadata
end

#transfer_dataObject

The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



12236
12237
12238
# File 'lib/stripe/services/payment_intent_service.rb', line 12236

def transfer_data
  @transfer_data
end