Class: Stripe::PaymentIntentService::DecrementAuthorizationParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Hooks, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, transfer_data: nil) ⇒ DecrementAuthorizationParams

Returns a new instance of DecrementAuthorizationParams.



11610
11611
11612
11613
11614
11615
11616
11617
11618
11619
11620
11621
11622
11623
11624
11625
11626
# File 'lib/stripe/services/payment_intent_service.rb', line 11610

def initialize(
  amount: nil,
  application_fee_amount: nil,
  description: nil,
  expand: nil,
  hooks: nil,
  metadata: nil,
  transfer_data: nil
)
  @amount = amount
  @application_fee_amount = application_fee_amount
  @description = description
  @expand = expand
  @hooks = hooks
  @metadata = 
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The updated total amount that you intend to collect from the cardholder. This amount must be smaller than the currently authorized amount and greater than the already captured amount.



11595
11596
11597
# File 'lib/stripe/services/payment_intent_service.rb', line 11595

def amount
  @amount
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



11597
11598
11599
# File 'lib/stripe/services/payment_intent_service.rb', line 11597

def application_fee_amount
  @application_fee_amount
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



11599
11600
11601
# File 'lib/stripe/services/payment_intent_service.rb', line 11599

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



11601
11602
11603
# File 'lib/stripe/services/payment_intent_service.rb', line 11601

def expand
  @expand
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



11603
11604
11605
# File 'lib/stripe/services/payment_intent_service.rb', line 11603

def hooks
  @hooks
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



11605
11606
11607
# File 'lib/stripe/services/payment_intent_service.rb', line 11605

def 
  @metadata
end

#transfer_dataObject

The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



11608
11609
11610
# File 'lib/stripe/services/payment_intent_service.rb', line 11608

def transfer_data
  @transfer_data
end