Class: Stripe::PaymentIntentService::DecrementAuthorizationParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::DecrementAuthorizationParams
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Hooks, TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured.
Instance Method Summary collapse
-
#initialize(amount: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, transfer_data: nil) ⇒ DecrementAuthorizationParams
constructor
A new instance of DecrementAuthorizationParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, transfer_data: nil) ⇒ DecrementAuthorizationParams
Returns a new instance of DecrementAuthorizationParams.
11304 11305 11306 11307 11308 11309 11310 11311 11312 11313 11314 11315 11316 11317 11318 11319 11320 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11304 def initialize( amount: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, transfer_data: nil ) @amount = amount @application_fee_amount = application_fee_amount @description = description @expand = @hooks = hooks @metadata = @transfer_data = transfer_data end |
Instance Attribute Details
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder. This amount must be smaller than the currently authorized amount and greater than the already captured amount.
11289 11290 11291 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11289 def amount @amount end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
11291 11292 11293 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11291 def application_fee_amount @application_fee_amount end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
11293 11294 11295 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11293 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
11295 11296 11297 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11295 def @expand end |
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle
11297 11298 11299 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11297 def hooks @hooks end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
11299 11300 11301 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11299 def @metadata end |
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
11302 11303 11304 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11302 def transfer_data @transfer_data end |