Class: Stripe::PaymentIntentService::DecrementAuthorizationParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::DecrementAuthorizationParams
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: AsyncWorkflows, TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#async_workflows ⇒ Object
Automations to be run during the PaymentIntent lifecycle.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured.
Instance Method Summary collapse
-
#initialize(amount: nil, application_fee_amount: nil, async_workflows: nil, description: nil, expand: nil, metadata: nil, transfer_data: nil) ⇒ DecrementAuthorizationParams
constructor
A new instance of DecrementAuthorizationParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, application_fee_amount: nil, async_workflows: nil, description: nil, expand: nil, metadata: nil, transfer_data: nil) ⇒ DecrementAuthorizationParams
Returns a new instance of DecrementAuthorizationParams.
10817 10818 10819 10820 10821 10822 10823 10824 10825 10826 10827 10828 10829 10830 10831 10832 10833 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10817 def initialize( amount: nil, application_fee_amount: nil, async_workflows: nil, description: nil, expand: nil, metadata: nil, transfer_data: nil ) @amount = amount @application_fee_amount = application_fee_amount @async_workflows = async_workflows @description = description @expand = @metadata = @transfer_data = transfer_data end |
Instance Attribute Details
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder. This amount must be smaller than the currently authorized amount and greater than the already captured amount.
10802 10803 10804 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10802 def amount @amount end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total payment amount. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
10804 10805 10806 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10804 def application_fee_amount @application_fee_amount end |
#async_workflows ⇒ Object
Automations to be run during the PaymentIntent lifecycle
10806 10807 10808 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10806 def async_workflows @async_workflows end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
10808 10809 10810 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10808 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
10810 10811 10812 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10810 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
10812 10813 10814 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10812 def @metadata end |
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
10815 10816 10817 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10815 def transfer_data @transfer_data end |