Class: Stripe::PaymentIntentService::DecrementAuthorizationParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: AsyncWorkflows, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, application_fee_amount: nil, async_workflows: nil, description: nil, expand: nil, metadata: nil, transfer_data: nil) ⇒ DecrementAuthorizationParams

Returns a new instance of DecrementAuthorizationParams.



12009
12010
12011
12012
12013
12014
12015
12016
12017
12018
12019
12020
12021
12022
12023
12024
12025
# File 'lib/stripe/services/payment_intent_service.rb', line 12009

def initialize(
  amount: nil,
  application_fee_amount: nil,
  async_workflows: nil,
  description: nil,
  expand: nil,
  metadata: nil,
  transfer_data: nil
)
  @amount = amount
  @application_fee_amount = application_fee_amount
  @async_workflows = async_workflows
  @description = description
  @expand = expand
  @metadata = 
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The updated total amount that you intend to collect from the cardholder. This amount must be smaller than the currently authorized amount and greater than the already captured amount.



11988
11989
11990
# File 'lib/stripe/services/payment_intent_service.rb', line 11988

def amount
  @amount
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total payment amount. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



11991
11992
11993
# File 'lib/stripe/services/payment_intent_service.rb', line 11991

def application_fee_amount
  @application_fee_amount
end

#async_workflowsObject

Automations to be run during the PaymentIntent lifecycle



11994
11995
11996
# File 'lib/stripe/services/payment_intent_service.rb', line 11994

def async_workflows
  @async_workflows
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



11997
11998
11999
# File 'lib/stripe/services/payment_intent_service.rb', line 11997

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



12000
12001
12002
# File 'lib/stripe/services/payment_intent_service.rb', line 12000

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



12003
12004
12005
# File 'lib/stripe/services/payment_intent_service.rb', line 12003

def 
  @metadata
end

#transfer_dataObject

The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



12007
12008
12009
# File 'lib/stripe/services/payment_intent_service.rb', line 12007

def transfer_data
  @transfer_data
end