Class: Stripe::PaymentIntentService::IncrementAuthorizationParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: AmountDetails, Hooks, PaymentDetails, PaymentMethodOptions, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_details: nil, application_fee_amount: nil, description: nil, expand: nil, hooks: nil, metadata: nil, payment_details: nil, payment_method_options: nil, statement_descriptor: nil, transfer_data: nil) ⇒ IncrementAuthorizationParams

Returns a new instance of IncrementAuthorizationParams.



12497
12498
12499
12500
12501
12502
12503
12504
12505
12506
12507
12508
12509
12510
12511
12512
12513
12514
12515
12516
12517
12518
12519
12520
12521
# File 'lib/stripe/services/payment_intent_service.rb', line 12497

def initialize(
  amount: nil,
  amount_details: nil,
  application_fee_amount: nil,
  description: nil,
  expand: nil,
  hooks: nil,
  metadata: nil,
  payment_details: nil,
  payment_method_options: nil,
  statement_descriptor: nil,
  transfer_data: nil
)
  @amount = amount
  @amount_details = amount_details
  @application_fee_amount = application_fee_amount
  @description = description
  @expand = expand
  @hooks = hooks
  @metadata = 
  @payment_details = payment_details
  @payment_method_options = payment_method_options
  @statement_descriptor = statement_descriptor
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The updated total amount that you intend to collect from the cardholder. This amount must be greater than the currently authorized amount.



12474
12475
12476
# File 'lib/stripe/services/payment_intent_service.rb', line 12474

def amount
  @amount
end

#amount_detailsObject

Provides industry-specific information about the amount.



12476
12477
12478
# File 'lib/stripe/services/payment_intent_service.rb', line 12476

def amount_details
  @amount_details
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



12478
12479
12480
# File 'lib/stripe/services/payment_intent_service.rb', line 12478

def application_fee_amount
  @application_fee_amount
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



12480
12481
12482
# File 'lib/stripe/services/payment_intent_service.rb', line 12480

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



12482
12483
12484
# File 'lib/stripe/services/payment_intent_service.rb', line 12482

def expand
  @expand
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



12484
12485
12486
# File 'lib/stripe/services/payment_intent_service.rb', line 12484

def hooks
  @hooks
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



12486
12487
12488
# File 'lib/stripe/services/payment_intent_service.rb', line 12486

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



12488
12489
12490
# File 'lib/stripe/services/payment_intent_service.rb', line 12488

def payment_details
  @payment_details
end

#payment_method_optionsObject

Payment method-specific configuration for this PaymentIntent.



12490
12491
12492
# File 'lib/stripe/services/payment_intent_service.rb', line 12490

def payment_method_options
  @payment_method_options
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card or card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).



12492
12493
12494
# File 'lib/stripe/services/payment_intent_service.rb', line 12492

def statement_descriptor
  @statement_descriptor
end

#transfer_dataObject

The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



12495
12496
12497
# File 'lib/stripe/services/payment_intent_service.rb', line 12495

def transfer_data
  @transfer_data
end