Class: Stripe::PaymentIntentService::IncrementAuthorizationParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::IncrementAuthorizationParams
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card or card charge.
-
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured.
Instance Method Summary collapse
-
#initialize(amount: nil, application_fee_amount: nil, description: nil, expand: nil, metadata: nil, statement_descriptor: nil, transfer_data: nil) ⇒ IncrementAuthorizationParams
constructor
A new instance of IncrementAuthorizationParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, application_fee_amount: nil, description: nil, expand: nil, metadata: nil, statement_descriptor: nil, transfer_data: nil) ⇒ IncrementAuthorizationParams
Returns a new instance of IncrementAuthorizationParams.
7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 7101 7102 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7086 def initialize( amount: nil, application_fee_amount: nil, description: nil, expand: nil, metadata: nil, statement_descriptor: nil, transfer_data: nil ) @amount = amount @application_fee_amount = application_fee_amount @description = description @expand = @metadata = @statement_descriptor = statement_descriptor @transfer_data = transfer_data end |
Instance Attribute Details
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder. This amount must be greater than the currently authorized amount.
7071 7072 7073 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7071 def amount @amount end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
7073 7074 7075 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7073 def application_fee_amount @application_fee_amount end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
7075 7076 7077 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7075 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
7077 7078 7079 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7077 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
7079 7080 7081 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7079 def @metadata end |
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card or card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
7081 7082 7083 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7081 def statement_descriptor @statement_descriptor end |
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
7084 7085 7086 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7084 def transfer_data @transfer_data end |