Class: Stripe::PaymentIntentService::IncrementAuthorizationParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: AsyncWorkflows, PaymentMethodOptions, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, application_fee_amount: nil, async_workflows: nil, description: nil, expand: nil, metadata: nil, payment_method_options: nil, statement_descriptor: nil, transfer_data: nil) ⇒ IncrementAuthorizationParams

Returns a new instance of IncrementAuthorizationParams.



11395
11396
11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
# File 'lib/stripe/services/payment_intent_service.rb', line 11395

def initialize(
  amount: nil,
  application_fee_amount: nil,
  async_workflows: nil,
  description: nil,
  expand: nil,
  metadata: nil,
  payment_method_options: nil,
  statement_descriptor: nil,
  transfer_data: nil
)
  @amount = amount
  @application_fee_amount = application_fee_amount
  @async_workflows = async_workflows
  @description = description
  @expand = expand
  @metadata = 
  @payment_method_options = payment_method_options
  @statement_descriptor = statement_descriptor
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The updated total amount that you intend to collect from the cardholder. This amount must be greater than the currently authorized amount.



11376
11377
11378
# File 'lib/stripe/services/payment_intent_service.rb', line 11376

def amount
  @amount
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



11378
11379
11380
# File 'lib/stripe/services/payment_intent_service.rb', line 11378

def application_fee_amount
  @application_fee_amount
end

#async_workflowsObject

Automations to be run during the PaymentIntent lifecycle



11380
11381
11382
# File 'lib/stripe/services/payment_intent_service.rb', line 11380

def async_workflows
  @async_workflows
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



11382
11383
11384
# File 'lib/stripe/services/payment_intent_service.rb', line 11382

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



11384
11385
11386
# File 'lib/stripe/services/payment_intent_service.rb', line 11384

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



11386
11387
11388
# File 'lib/stripe/services/payment_intent_service.rb', line 11386

def 
  @metadata
end

#payment_method_optionsObject

Payment method-specific configuration for this PaymentIntent.



11388
11389
11390
# File 'lib/stripe/services/payment_intent_service.rb', line 11388

def payment_method_options
  @payment_method_options
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card or card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).



11390
11391
11392
# File 'lib/stripe/services/payment_intent_service.rb', line 11390

def statement_descriptor
  @statement_descriptor
end

#transfer_dataObject

The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



11393
11394
11395
# File 'lib/stripe/services/payment_intent_service.rb', line 11393

def transfer_data
  @transfer_data
end