Class: Stripe::PaymentIntentService::IncrementAuthorizationParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: AsyncWorkflows, PaymentMethodOptions, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, application_fee_amount: nil, async_workflows: nil, description: nil, expand: nil, metadata: nil, payment_method_options: nil, statement_descriptor: nil, transfer_data: nil) ⇒ IncrementAuthorizationParams

Returns a new instance of IncrementAuthorizationParams.



10802
10803
10804
10805
10806
10807
10808
10809
10810
10811
10812
10813
10814
10815
10816
10817
10818
10819
10820
10821
10822
# File 'lib/stripe/services/payment_intent_service.rb', line 10802

def initialize(
  amount: nil,
  application_fee_amount: nil,
  async_workflows: nil,
  description: nil,
  expand: nil,
  metadata: nil,
  payment_method_options: nil,
  statement_descriptor: nil,
  transfer_data: nil
)
  @amount = amount
  @application_fee_amount = application_fee_amount
  @async_workflows = async_workflows
  @description = description
  @expand = expand
  @metadata = 
  @payment_method_options = payment_method_options
  @statement_descriptor = statement_descriptor
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The updated total amount that you intend to collect from the cardholder. This amount must be greater than the currently authorized amount.



10783
10784
10785
# File 'lib/stripe/services/payment_intent_service.rb', line 10783

def amount
  @amount
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total payment amount. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



10785
10786
10787
# File 'lib/stripe/services/payment_intent_service.rb', line 10785

def application_fee_amount
  @application_fee_amount
end

#async_workflowsObject

Automations to be run during the PaymentIntent lifecycle



10787
10788
10789
# File 'lib/stripe/services/payment_intent_service.rb', line 10787

def async_workflows
  @async_workflows
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



10789
10790
10791
# File 'lib/stripe/services/payment_intent_service.rb', line 10789

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



10791
10792
10793
# File 'lib/stripe/services/payment_intent_service.rb', line 10791

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



10793
10794
10795
# File 'lib/stripe/services/payment_intent_service.rb', line 10793

def 
  @metadata
end

#payment_method_optionsObject

Payment method-specific configuration for this PaymentIntent.



10795
10796
10797
# File 'lib/stripe/services/payment_intent_service.rb', line 10795

def payment_method_options
  @payment_method_options
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card or card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).



10797
10798
10799
# File 'lib/stripe/services/payment_intent_service.rb', line 10797

def statement_descriptor
  @statement_descriptor
end

#transfer_dataObject

The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



10800
10801
10802
# File 'lib/stripe/services/payment_intent_service.rb', line 10800

def transfer_data
  @transfer_data
end