Class: Stripe::PaymentIntentService::IncrementAuthorizationParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::IncrementAuthorizationParams
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: AsyncWorkflows, PaymentMethodOptions, TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#async_workflows ⇒ Object
Automations to be run during the PaymentIntent lifecycle.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment_method_options ⇒ Object
Payment method-specific configuration for this PaymentIntent.
-
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card or card charge.
-
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured.
Instance Method Summary collapse
-
#initialize(amount: nil, application_fee_amount: nil, async_workflows: nil, description: nil, expand: nil, metadata: nil, payment_method_options: nil, statement_descriptor: nil, transfer_data: nil) ⇒ IncrementAuthorizationParams
constructor
A new instance of IncrementAuthorizationParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, application_fee_amount: nil, async_workflows: nil, description: nil, expand: nil, metadata: nil, payment_method_options: nil, statement_descriptor: nil, transfer_data: nil) ⇒ IncrementAuthorizationParams
Returns a new instance of IncrementAuthorizationParams.
10844 10845 10846 10847 10848 10849 10850 10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 10863 10864 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10844 def initialize( amount: nil, application_fee_amount: nil, async_workflows: nil, description: nil, expand: nil, metadata: nil, payment_method_options: nil, statement_descriptor: nil, transfer_data: nil ) @amount = amount @application_fee_amount = application_fee_amount @async_workflows = async_workflows @description = description @expand = @metadata = @payment_method_options = @statement_descriptor = statement_descriptor @transfer_data = transfer_data end |
Instance Attribute Details
#amount ⇒ Object
The updated total amount that you intend to collect from the cardholder. This amount must be greater than the currently authorized amount.
10825 10826 10827 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10825 def amount @amount end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total payment amount. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
10827 10828 10829 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10827 def application_fee_amount @application_fee_amount end |
#async_workflows ⇒ Object
Automations to be run during the PaymentIntent lifecycle
10829 10830 10831 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10829 def async_workflows @async_workflows end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
10831 10832 10833 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10831 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
10833 10834 10835 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10833 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
10835 10836 10837 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10835 def @metadata end |
#payment_method_options ⇒ Object
Payment method-specific configuration for this PaymentIntent.
10837 10838 10839 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10837 def @payment_method_options end |
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card or card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
10839 10840 10841 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10839 def statement_descriptor @statement_descriptor end |
#transfer_data ⇒ Object
The parameters used to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
10842 10843 10844 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10842 def transfer_data @transfer_data end |