Class: Stripe::PaymentIntentService::IncrementAuthorizationParams::AmountDetails::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::IncrementAuthorizationParams::AmountDetails::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The amount an item was discounted for.
-
#payment_method_options ⇒ Object
Payment method-specific information for line items.
-
#product_code ⇒ Object
Unique identifier of the product.
-
#product_name ⇒ Object
Name of the product.
-
#quantity ⇒ Object
Number of items of the product.
-
#tax ⇒ Object
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
Cost of the product.
-
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
Returns a new instance of LineItem.
12350 12351 12352 12353 12354 12355 12356 12357 12358 12359 12360 12361 12362 12363 12364 12365 12366 12367 12368 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12350 def initialize( discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil ) @discount_amount = discount_amount @payment_method_options = @product_code = product_code @product_name = product_name @quantity = quantity @tax = tax @unit_cost = unit_cost @unit_of_measure = unit_of_measure end |
Instance Attribute Details
#discount_amount ⇒ Object
The amount an item was discounted for. Positive integer.
12334 12335 12336 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12334 def discount_amount @discount_amount end |
#payment_method_options ⇒ Object
Payment method-specific information for line items.
12336 12337 12338 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12336 def @payment_method_options end |
#product_code ⇒ Object
Unique identifier of the product. At most 12 characters long.
12338 12339 12340 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12338 def product_code @product_code end |
#product_name ⇒ Object
Name of the product. At most 100 characters long.
12340 12341 12342 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12340 def product_name @product_name end |
#quantity ⇒ Object
Number of items of the product. Positive integer.
12342 12343 12344 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12342 def quantity @quantity end |
#tax ⇒ Object
Contains information about the tax on the item.
12344 12345 12346 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12344 def tax @tax end |
#unit_cost ⇒ Object
Cost of the product. Non-negative integer.
12346 12347 12348 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12346 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
12348 12349 12350 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12348 def unit_of_measure @unit_of_measure end |