Class: Stripe::PaymentIntentService::IncrementAuthorizationParams::AmountDetails::LineItem::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Card, CardPresent, Klarna, Paypal

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(card: nil, card_present: nil, klarna: nil, paypal: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



12317
12318
12319
12320
12321
12322
# File 'lib/stripe/services/payment_intent_service.rb', line 12317

def initialize(card: nil, card_present: nil, klarna: nil, paypal: nil)
  @card = card
  @card_present = card_present
  @klarna = klarna
  @paypal = paypal
end

Instance Attribute Details

#cardObject

This sub-hash contains line item details that are specific to ‘card` payment method.“



12309
12310
12311
# File 'lib/stripe/services/payment_intent_service.rb', line 12309

def card
  @card
end

#card_presentObject

This sub-hash contains line item details that are specific to ‘card_present` payment method.“



12311
12312
12313
# File 'lib/stripe/services/payment_intent_service.rb', line 12311

def card_present
  @card_present
end

#klarnaObject

This sub-hash contains line item details that are specific to ‘klarna` payment method.“



12313
12314
12315
# File 'lib/stripe/services/payment_intent_service.rb', line 12313

def klarna
  @klarna
end

#paypalObject

This sub-hash contains line item details that are specific to ‘paypal` payment method.“



12315
12316
12317
# File 'lib/stripe/services/payment_intent_service.rb', line 12315

def paypal
  @paypal
end