Class: Stripe::PaymentIntentService::IncrementAuthorizationParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::IncrementAuthorizationParams::PaymentDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
Instance Method Summary collapse
-
#initialize(customer_reference: nil, order_reference: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(customer_reference: nil, order_reference: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
12596 12597 12598 12599 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12596 def initialize(customer_reference: nil, order_reference: nil) @customer_reference = customer_reference @order_reference = order_reference end |
Instance Attribute Details
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
12592 12593 12594 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12592 def customer_reference @customer_reference end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
12594 12595 12596 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12594 def order_reference @order_reference end |