Class: Stripe::PaymentIntentService::IncrementAuthorizationParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::IncrementAuthorizationParams::PaymentMethodOptions
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Card
Instance Attribute Summary collapse
-
#card ⇒ Object
Configuration for any card payments attempted on this PaymentIntent.
Instance Method Summary collapse
-
#initialize(card: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(card: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
12066 12067 12068 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12066 def initialize(card: nil) @card = card end |
Instance Attribute Details
#card ⇒ Object
Configuration for any card payments attempted on this PaymentIntent.
12064 12065 12066 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12064 def card @card end |