Class: Stripe::PaymentIntentService::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::RetrieveParams
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#client_secret ⇒ Object
The client secret of the PaymentIntent.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
3845 3846 3847 3848 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3845 def initialize(client_secret: nil, expand: nil) @client_secret = client_secret @expand = end |
Instance Attribute Details
#client_secret ⇒ Object
The client secret of the PaymentIntent. We require it if you use a publishable key to retrieve the source.
3841 3842 3843 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3841 def client_secret @client_secret end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
3843 3844 3845 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3843 def @expand end |