Class: Stripe::PaymentIntentService::RetrieveParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams

Returns a new instance of RetrieveParams.



3586
3587
3588
3589
# File 'lib/stripe/services/payment_intent_service.rb', line 3586

def initialize(client_secret: nil, expand: nil)
  @client_secret = client_secret
  @expand = expand
end

Instance Attribute Details

#client_secretObject

The client secret of the PaymentIntent. We require it if you use a publishable key to retrieve the source.



3582
3583
3584
# File 'lib/stripe/services/payment_intent_service.rb', line 3582

def client_secret
  @client_secret
end

#expandObject

Specifies which fields in the response should be expanded.



3584
3585
3586
# File 'lib/stripe/services/payment_intent_service.rb', line 3584

def expand
  @expand
end