Class: Stripe::PaymentIntentService::RetrieveParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams

Returns a new instance of RetrieveParams.



3392
3393
3394
3395
# File 'lib/stripe/services/payment_intent_service.rb', line 3392

def initialize(client_secret: nil, expand: nil)
  @client_secret = client_secret
  @expand = expand
end

Instance Attribute Details

#client_secretObject

The client secret of the PaymentIntent. We require it if you use a publishable key to retrieve the source.



3388
3389
3390
# File 'lib/stripe/services/payment_intent_service.rb', line 3388

def client_secret
  @client_secret
end

#expandObject

Specifies which fields in the response should be expanded.



3390
3391
3392
# File 'lib/stripe/services/payment_intent_service.rb', line 3390

def expand
  @expand
end