Class: Stripe::PaymentIntentService::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::RetrieveParams
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#client_secret ⇒ Object
The client secret of the PaymentIntent.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
3392 3393 3394 3395 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3392 def initialize(client_secret: nil, expand: nil) @client_secret = client_secret @expand = end |
Instance Attribute Details
#client_secret ⇒ Object
The client secret of the PaymentIntent. We require it if you use a publishable key to retrieve the source.
3388 3389 3390 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3388 def client_secret @client_secret end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
3390 3391 3392 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3390 def @expand end |