Class: Stripe::PaymentIntentService::SearchParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams

Returns a new instance of SearchParams.



7539
7540
7541
7542
7543
7544
# File 'lib/stripe/services/payment_intent_service.rb', line 7539

def initialize(expand: nil, limit: nil, page: nil, query: nil)
  @expand = expand
  @limit = limit
  @page = page
  @query = query
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



7531
7532
7533
# File 'lib/stripe/services/payment_intent_service.rb', line 7531

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



7533
7534
7535
# File 'lib/stripe/services/payment_intent_service.rb', line 7533

def limit
  @limit
end

#pageObject

A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.



7535
7536
7537
# File 'lib/stripe/services/payment_intent_service.rb', line 7535

def page
  @page
end

#queryObject

The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for payment intents](stripe.com/docs/search#query-fields-for-payment-intents).



7537
7538
7539
# File 'lib/stripe/services/payment_intent_service.rb', line 7537

def query
  @query
end