Class: Stripe::PaymentIntentService::SearchParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::SearchParams
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#page ⇒ Object
A cursor for pagination across multiple pages of results.
-
#query ⇒ Object
The search query string.
Instance Method Summary collapse
-
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
constructor
A new instance of SearchParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
Returns a new instance of SearchParams.
4621 4622 4623 4624 4625 4626 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4621 def initialize(expand: nil, limit: nil, page: nil, query: nil) @expand = @limit = limit @page = page @query = query end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
4613 4614 4615 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4613 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
4615 4616 4617 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4615 def limit @limit end |
#page ⇒ Object
A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.
4617 4618 4619 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4617 def page @page end |
#query ⇒ Object
The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for payment intents](stripe.com/docs/search#query-fields-for-payment-intents).
4619 4620 4621 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4619 def query @query end |