Class: Stripe::PaymentIntentService::SearchParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::SearchParams
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#page ⇒ Object
A cursor for pagination across multiple pages of results.
-
#query ⇒ Object
The search query string.
Instance Method Summary collapse
-
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
constructor
A new instance of SearchParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
Returns a new instance of SearchParams.
6673 6674 6675 6676 6677 6678 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6673 def initialize(expand: nil, limit: nil, page: nil, query: nil) @expand = @limit = limit @page = page @query = query end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
6665 6666 6667 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6665 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
6667 6668 6669 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6667 def limit @limit end |
#page ⇒ Object
A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.
6669 6670 6671 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6669 def page @page end |
#query ⇒ Object
The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for payment intents](stripe.com/docs/search#query-fields-for-payment-intents).
6671 6672 6673 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6671 def query @query end |