Class: Stripe::PaymentIntentService::TriggerActionParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::TriggerActionParams
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: ScanQrCode
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
-
#type ⇒ Object
The type of action to be simulated.
Instance Method Summary collapse
-
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
constructor
A new instance of TriggerActionParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
Returns a new instance of TriggerActionParams.
11449 11450 11451 11452 11453 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11449 def initialize(expand: nil, scan_qr_code: nil, type: nil) @expand = @scan_qr_code = scan_qr_code @type = type end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
11443 11444 11445 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11443 def @expand end |
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
11445 11446 11447 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11445 def scan_qr_code @scan_qr_code end |
#type ⇒ Object
The type of action to be simulated.
11447 11448 11449 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11447 def type @type end |