Class: Stripe::PaymentIntentService::TriggerActionParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::TriggerActionParams
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: ScanQrCode
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
-
#type ⇒ Object
The type of action to be simulated.
Instance Method Summary collapse
-
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
constructor
A new instance of TriggerActionParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
Returns a new instance of TriggerActionParams.
11389 11390 11391 11392 11393 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11389 def initialize(expand: nil, scan_qr_code: nil, type: nil) @expand = @scan_qr_code = scan_qr_code @type = type end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
11383 11384 11385 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11383 def @expand end |
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
11385 11386 11387 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11385 def scan_qr_code @scan_qr_code end |
#type ⇒ Object
The type of action to be simulated.
11387 11388 11389 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11387 def type @type end |