Class: Stripe::PaymentIntentService::TriggerActionParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::TriggerActionParams
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: ScanQrCode
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
-
#type ⇒ Object
The type of action to be simulated.
Instance Method Summary collapse
-
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
constructor
A new instance of TriggerActionParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
Returns a new instance of TriggerActionParams.
12165 12166 12167 12168 12169 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12165 def initialize(expand: nil, scan_qr_code: nil, type: nil) @expand = @scan_qr_code = scan_qr_code @type = type end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
12157 12158 12159 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12157 def @expand end |
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
12160 12161 12162 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12160 def scan_qr_code @scan_qr_code end |
#type ⇒ Object
The type of action to be simulated.
12163 12164 12165 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12163 def type @type end |