Class: Stripe::PaymentIntentService::TriggerActionParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::TriggerActionParams
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: ScanQrCode
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
-
#type ⇒ Object
The type of action to be simulated.
Instance Method Summary collapse
-
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
constructor
A new instance of TriggerActionParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
Returns a new instance of TriggerActionParams.
10856 10857 10858 10859 10860 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10856 def initialize(expand: nil, scan_qr_code: nil, type: nil) @expand = @scan_qr_code = scan_qr_code @type = type end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
10850 10851 10852 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10850 def @expand end |
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
10852 10853 10854 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10852 def scan_qr_code @scan_qr_code end |
#type ⇒ Object
The type of action to be simulated.
10854 10855 10856 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10854 def type @type end |