Class: Stripe::PaymentIntentService::TriggerActionParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::TriggerActionParams
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: ScanQrCode
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
-
#type ⇒ Object
The type of action to be simulated.
Instance Method Summary collapse
-
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
constructor
A new instance of TriggerActionParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, scan_qr_code: nil, type: nil) ⇒ TriggerActionParams
Returns a new instance of TriggerActionParams.
10898 10899 10900 10901 10902 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10898 def initialize(expand: nil, scan_qr_code: nil, type: nil) @expand = @scan_qr_code = scan_qr_code @type = type end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
10892 10893 10894 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10892 def @expand end |
#scan_qr_code ⇒ Object
True to simulate success, false to simulate failure.
10894 10895 10896 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10894 def scan_qr_code @scan_qr_code end |
#type ⇒ Object
The type of action to be simulated.
10896 10897 10898 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10896 def type @type end |