Class: Stripe::PaymentIntentService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: PaymentMethodData, PaymentMethodOptions, Shipping, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, application_fee_amount: nil, capture_method: nil, currency: nil, customer: nil, description: nil, expand: nil, metadata: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, receipt_email: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



4643
4644
4645
4646
4647
4648
4649
4650
4651
4652
4653
4654
4655
4656
4657
4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
4685
# File 'lib/stripe/services/payment_intent_service.rb', line 4643

def initialize(
  amount: nil,
  application_fee_amount: nil,
  capture_method: nil,
  currency: nil,
  customer: nil,
  description: nil,
  expand: nil,
  metadata: nil,
  payment_method: nil,
  payment_method_configuration: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  receipt_email: nil,
  setup_future_usage: nil,
  shipping: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil,
  transfer_group: nil
)
  @amount = amount
  @application_fee_amount = application_fee_amount
  @capture_method = capture_method
  @currency = currency
  @customer = customer
  @description = description
  @expand = expand
  @metadata = 
  @payment_method = payment_method
  @payment_method_configuration = payment_method_configuration
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @receipt_email = receipt_email
  @setup_future_usage = setup_future_usage
  @shipping = shipping
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
  @transfer_group = transfer_group
end

Instance Attribute Details

#amountObject

Amount intended to be collected by this PaymentIntent. A positive integer representing how much to charge in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge currency](stripe.com/docs/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).



4587
4588
4589
# File 'lib/stripe/services/payment_intent_service.rb', line 4587

def amount
  @amount
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



4589
4590
4591
# File 'lib/stripe/services/payment_intent_service.rb', line 4589

def application_fee_amount
  @application_fee_amount
end

#capture_methodObject

Controls when the funds will be captured from the customer’s account.



4591
4592
4593
# File 'lib/stripe/services/payment_intent_service.rb', line 4591

def capture_method
  @capture_method
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



4593
4594
4595
# File 'lib/stripe/services/payment_intent_service.rb', line 4593

def currency
  @currency
end

#customerObject

ID of the Customer this PaymentIntent belongs to, if one exists.

Payment methods attached to other Customers cannot be used with this PaymentIntent.

If [setup_future_usage](stripe.com/docs/api#payment_intent_object-setup_future_usage) is set and this PaymentIntent’s payment method is not ‘card_present`, then the payment method attaches to the Customer after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is `card_present` and isn’t a digital wallet, then a [generated_card](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Customer instead.



4599
4600
4601
# File 'lib/stripe/services/payment_intent_service.rb', line 4599

def customer
  @customer
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



4601
4602
4603
# File 'lib/stripe/services/payment_intent_service.rb', line 4601

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



4603
4604
4605
# File 'lib/stripe/services/payment_intent_service.rb', line 4603

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



4605
4606
4607
# File 'lib/stripe/services/payment_intent_service.rb', line 4605

def 
  @metadata
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or [compatible Source](stripe.com/docs/payments/payment-methods/transitioning#compatibility) object) to attach to this PaymentIntent. To unset this field to null, pass in an empty string.



4607
4608
4609
# File 'lib/stripe/services/payment_intent_service.rb', line 4607

def payment_method
  @payment_method
end

#payment_method_configurationObject

The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this PaymentIntent.



4609
4610
4611
# File 'lib/stripe/services/payment_intent_service.rb', line 4609

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the [payment_method](stripe.com/docs/api/payment_intents/object#payment_intent_object-payment_method) property on the PaymentIntent.



4613
4614
4615
# File 'lib/stripe/services/payment_intent_service.rb', line 4613

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment-method-specific configuration for this PaymentIntent.



4615
4616
4617
# File 'lib/stripe/services/payment_intent_service.rb', line 4615

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, card) that this PaymentIntent can use. Use ‘automatic_payment_methods` to manage payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods).



4617
4618
4619
# File 'lib/stripe/services/payment_intent_service.rb', line 4617

def payment_method_types
  @payment_method_types
end

#receipt_emailObject

Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).



4619
4620
4621
# File 'lib/stripe/services/payment_intent_service.rb', line 4619

def receipt_email
  @receipt_email
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



4629
4630
4631
# File 'lib/stripe/services/payment_intent_service.rb', line 4629

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this PaymentIntent.



4631
4632
4633
# File 'lib/stripe/services/payment_intent_service.rb', line 4631

def shipping
  @shipping
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).

Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.



4635
4636
4637
# File 'lib/stripe/services/payment_intent_service.rb', line 4635

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



4637
4638
4639
# File 'lib/stripe/services/payment_intent_service.rb', line 4637

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

Use this parameter to automatically create a Transfer when the payment succeeds. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



4639
4640
4641
# File 'lib/stripe/services/payment_intent_service.rb', line 4639

def transfer_data
  @transfer_data
end

#transfer_groupObject

A string that identifies the resulting payment as part of a group. You can only provide ‘transfer_group` if it hasn’t been set. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



4641
4642
4643
# File 'lib/stripe/services/payment_intent_service.rb', line 4641

def transfer_group
  @transfer_group
end