Class: Stripe::PaymentIntentService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: AsyncWorkflows, MandateData, PaymentDetails, PaymentMethodData, PaymentMethodOptions, Shipping, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, application_fee_amount: nil, async_workflows: nil, capture_method: nil, currency: nil, customer: nil, customer_account: nil, description: nil, expand: nil, fx_quote: nil, mandate_data: nil, metadata: nil, payment_details: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, receipt_email: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



6979
6980
6981
6982
6983
6984
6985
6986
6987
6988
6989
6990
6991
6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
# File 'lib/stripe/services/payment_intent_service.rb', line 6979

def initialize(
  amount: nil,
  application_fee_amount: nil,
  async_workflows: nil,
  capture_method: nil,
  currency: nil,
  customer: nil,
  customer_account: nil,
  description: nil,
  expand: nil,
  fx_quote: nil,
  mandate_data: nil,
  metadata: nil,
  payment_details: nil,
  payment_method: nil,
  payment_method_configuration: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  receipt_email: nil,
  setup_future_usage: nil,
  shipping: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil,
  transfer_group: nil
)
  @amount = amount
  @application_fee_amount = application_fee_amount
  @async_workflows = async_workflows
  @capture_method = capture_method
  @currency = currency
  @customer = customer
  @customer_account = 
  @description = description
  @expand = expand
  @fx_quote = fx_quote
  @mandate_data = mandate_data
  @metadata = 
  @payment_details = payment_details
  @payment_method = payment_method
  @payment_method_configuration = payment_method_configuration
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @receipt_email = receipt_email
  @setup_future_usage = setup_future_usage
  @shipping = shipping
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
  @transfer_group = transfer_group
end

Instance Attribute Details

#amountObject

Amount intended to be collected by this PaymentIntent. A positive integer representing how much to charge in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge currency](stripe.com/docs/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).



6909
6910
6911
# File 'lib/stripe/services/payment_intent_service.rb', line 6909

def amount
  @amount
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



6911
6912
6913
# File 'lib/stripe/services/payment_intent_service.rb', line 6911

def application_fee_amount
  @application_fee_amount
end

#async_workflowsObject

Automations to be run during the PaymentIntent lifecycle



6913
6914
6915
# File 'lib/stripe/services/payment_intent_service.rb', line 6913

def async_workflows
  @async_workflows
end

#capture_methodObject

Controls when the funds will be captured from the customer’s account.



6915
6916
6917
# File 'lib/stripe/services/payment_intent_service.rb', line 6915

def capture_method
  @capture_method
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



6917
6918
6919
# File 'lib/stripe/services/payment_intent_service.rb', line 6917

def currency
  @currency
end

#customerObject

ID of the Customer this PaymentIntent belongs to, if one exists.

Payment methods attached to other Customers cannot be used with this PaymentIntent.

If [setup_future_usage](stripe.com/docs/api#payment_intent_object-setup_future_usage) is set and this PaymentIntent’s payment method is not ‘card_present`, then the payment method attaches to the Customer after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is `card_present` and isn’t a digital wallet, then a [generated_card](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Customer instead.



6923
6924
6925
# File 'lib/stripe/services/payment_intent_service.rb', line 6923

def customer
  @customer
end

#customer_accountObject

ID of the Account this PaymentIntent belongs to, if one exists.

Payment methods attached to other Accounts cannot be used with this PaymentIntent.

If [setup_future_usage](stripe.com/docs/api#payment_intent_object-setup_future_usage) is set and this PaymentIntent’s payment method is not ‘card_present`, then the payment method attaches to the Account after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is `card_present` and isn’t a digital wallet, then a [generated_card](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Account instead.



6929
6930
6931
# File 'lib/stripe/services/payment_intent_service.rb', line 6929

def 
  @customer_account
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



6931
6932
6933
# File 'lib/stripe/services/payment_intent_service.rb', line 6931

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



6933
6934
6935
# File 'lib/stripe/services/payment_intent_service.rb', line 6933

def expand
  @expand
end

#fx_quoteObject

The FX rate in the quote is validated and used to convert the presentment amount to the settlement amount.



6935
6936
6937
# File 'lib/stripe/services/payment_intent_service.rb', line 6935

def fx_quote
  @fx_quote
end

#mandate_dataObject

This hash contains details about the Mandate to create.



6937
6938
6939
# File 'lib/stripe/services/payment_intent_service.rb', line 6937

def mandate_data
  @mandate_data
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



6939
6940
6941
# File 'lib/stripe/services/payment_intent_service.rb', line 6939

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



6941
6942
6943
# File 'lib/stripe/services/payment_intent_service.rb', line 6941

def payment_details
  @payment_details
end

#payment_methodObject

Attribute for param field payment_method



6943
6944
6945
# File 'lib/stripe/services/payment_intent_service.rb', line 6943

def payment_method
  @payment_method
end

#payment_method_configurationObject

The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this PaymentIntent.



6945
6946
6947
# File 'lib/stripe/services/payment_intent_service.rb', line 6945

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the [payment_method](stripe.com/docs/api/payment_intents/object#payment_intent_object-payment_method) property on the PaymentIntent.



6949
6950
6951
# File 'lib/stripe/services/payment_intent_service.rb', line 6949

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment-method-specific configuration for this PaymentIntent.



6951
6952
6953
# File 'lib/stripe/services/payment_intent_service.rb', line 6951

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, card) that this PaymentIntent can use. Use ‘automatic_payment_methods` to manage payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods).



6953
6954
6955
# File 'lib/stripe/services/payment_intent_service.rb', line 6953

def payment_method_types
  @payment_method_types
end

#receipt_emailObject

Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).



6955
6956
6957
# File 'lib/stripe/services/payment_intent_service.rb', line 6955

def receipt_email
  @receipt_email
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



6965
6966
6967
# File 'lib/stripe/services/payment_intent_service.rb', line 6965

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this PaymentIntent.



6967
6968
6969
# File 'lib/stripe/services/payment_intent_service.rb', line 6967

def shipping
  @shipping
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).

Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.



6971
6972
6973
# File 'lib/stripe/services/payment_intent_service.rb', line 6971

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



6973
6974
6975
# File 'lib/stripe/services/payment_intent_service.rb', line 6973

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

Use this parameter to automatically create a Transfer when the payment succeeds. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



6975
6976
6977
# File 'lib/stripe/services/payment_intent_service.rb', line 6975

def transfer_data
  @transfer_data
end

#transfer_groupObject

A string that identifies the resulting payment as part of a group. You can only provide ‘transfer_group` if it hasn’t been set. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



6977
6978
6979
# File 'lib/stripe/services/payment_intent_service.rb', line 6977

def transfer_group
  @transfer_group
end