Class: Stripe::PaymentIntentService::UpdateParams::AmountDetails::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::AmountDetails::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The amount an item was discounted for.
-
#payment_method_options ⇒ Object
Payment method-specific information for line items.
-
#product_code ⇒ Object
Unique identifier of the product.
-
#product_name ⇒ Object
Name of the product.
-
#quantity ⇒ Object
Number of items of the product.
-
#tax ⇒ Object
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
Cost of the product.
-
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
Returns a new instance of LineItem.
3944 3945 3946 3947 3948 3949 3950 3951 3952 3953 3954 3955 3956 3957 3958 3959 3960 3961 3962 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3944 def initialize( discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil ) @discount_amount = discount_amount @payment_method_options = @product_code = product_code @product_name = product_name @quantity = quantity @tax = tax @unit_cost = unit_cost @unit_of_measure = unit_of_measure end |
Instance Attribute Details
#discount_amount ⇒ Object
The amount an item was discounted for. Positive integer.
3928 3929 3930 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3928 def discount_amount @discount_amount end |
#payment_method_options ⇒ Object
Payment method-specific information for line items.
3930 3931 3932 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3930 def @payment_method_options end |
#product_code ⇒ Object
Unique identifier of the product. At most 12 characters long.
3932 3933 3934 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3932 def product_code @product_code end |
#product_name ⇒ Object
Name of the product. At most 100 characters long.
3934 3935 3936 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3934 def product_name @product_name end |
#quantity ⇒ Object
Number of items of the product. Positive integer.
3936 3937 3938 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3936 def quantity @quantity end |
#tax ⇒ Object
Contains information about the tax on the item.
3938 3939 3940 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3938 def tax @tax end |
#unit_cost ⇒ Object
Cost of the product. Non-negative integer.
3940 3941 3942 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3940 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
3942 3943 3944 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3942 def unit_of_measure @unit_of_measure end |