Class: Stripe::PaymentIntentService::UpdateParams::AmountDetails::LineItem::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Card, CardPresent, Klarna, Paypal

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(card: nil, card_present: nil, klarna: nil, paypal: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



3911
3912
3913
3914
3915
3916
# File 'lib/stripe/services/payment_intent_service.rb', line 3911

def initialize(card: nil, card_present: nil, klarna: nil, paypal: nil)
  @card = card
  @card_present = card_present
  @klarna = klarna
  @paypal = paypal
end

Instance Attribute Details

#cardObject

This sub-hash contains line item details that are specific to ‘card` payment method.“



3903
3904
3905
# File 'lib/stripe/services/payment_intent_service.rb', line 3903

def card
  @card
end

#card_presentObject

This sub-hash contains line item details that are specific to ‘card_present` payment method.“



3905
3906
3907
# File 'lib/stripe/services/payment_intent_service.rb', line 3905

def card_present
  @card_present
end

#klarnaObject

This sub-hash contains line item details that are specific to ‘klarna` payment method.“



3907
3908
3909
# File 'lib/stripe/services/payment_intent_service.rb', line 3907

def klarna
  @klarna
end

#paypalObject

This sub-hash contains line item details that are specific to ‘paypal` payment method.“



3909
3910
3911
# File 'lib/stripe/services/payment_intent_service.rb', line 3909

def paypal
  @paypal
end