Class: Stripe::PaymentIntentService::UpdateParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



3738
3739
3740
3741
# File 'lib/stripe/services/payment_intent_service.rb', line 3738

def initialize(online: nil, type: nil)
  @online = online
  @type = type
end

Instance Attribute Details

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



3734
3735
3736
# File 'lib/stripe/services/payment_intent_service.rb', line 3734

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate.



3736
3737
3738
# File 'lib/stripe/services/payment_intent_service.rb', line 3736

def type
  @type
end