Class: Stripe::PaymentIntentService::UpdateParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



3636
3637
3638
3639
# File 'lib/stripe/services/payment_intent_service.rb', line 3636

def initialize(online: nil, type: nil)
  @online = online
  @type = type
end

Instance Attribute Details

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



3632
3633
3634
# File 'lib/stripe/services/payment_intent_service.rb', line 3632

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate.



3634
3635
3636
# File 'lib/stripe/services/payment_intent_service.rb', line 3634

def type
  @type
end