Class: Stripe::PaymentIntentService::UpdateParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



3625
3626
3627
3628
# File 'lib/stripe/services/payment_intent_service.rb', line 3625

def initialize(online: nil, type: nil)
  @online = online
  @type = type
end

Instance Attribute Details

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



3621
3622
3623
# File 'lib/stripe/services/payment_intent_service.rb', line 3621

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate.



3623
3624
3625
# File 'lib/stripe/services/payment_intent_service.rb', line 3623

def type
  @type
end