Class: Stripe::PaymentIntentService::UpdateParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



3647
3648
3649
3650
# File 'lib/stripe/services/payment_intent_service.rb', line 3647

def initialize(online: nil, type: nil)
  @online = online
  @type = type
end

Instance Attribute Details

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



3643
3644
3645
# File 'lib/stripe/services/payment_intent_service.rb', line 3643

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate.



3645
3646
3647
# File 'lib/stripe/services/payment_intent_service.rb', line 3645

def type
  @type
end