Class: Stripe::PaymentIntentService::UpdateParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



3456
3457
3458
3459
# File 'lib/stripe/services/payment_intent_service.rb', line 3456

def initialize(online: nil, type: nil)
  @online = online
  @type = type
end

Instance Attribute Details

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



3452
3453
3454
# File 'lib/stripe/services/payment_intent_service.rb', line 3452

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate.



3454
3455
3456
# File 'lib/stripe/services/payment_intent_service.rb', line 3454

def type
  @type
end