Class: Stripe::PaymentIntentService::UpdateParams::MandateData::CustomerAcceptance::Online
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::MandateData::CustomerAcceptance::Online
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#ip_address ⇒ Object
The IP address from which the Mandate was accepted by the customer.
-
#user_agent ⇒ Object
The user agent of the browser from which the Mandate was accepted by the customer.
Instance Method Summary collapse
-
#initialize(ip_address: nil, user_agent: nil) ⇒ Online
constructor
A new instance of Online.
Methods inherited from RequestParams
Constructor Details
#initialize(ip_address: nil, user_agent: nil) ⇒ Online
Returns a new instance of Online.
3432 3433 3434 3435 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3432 def initialize(ip_address: nil, user_agent: nil) @ip_address = ip_address @user_agent = user_agent end |
Instance Attribute Details
#ip_address ⇒ Object
The IP address from which the Mandate was accepted by the customer.
3428 3429 3430 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3428 def ip_address @ip_address end |
#user_agent ⇒ Object
The user agent of the browser from which the Mandate was accepted by the customer.
3430 3431 3432 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3430 def user_agent @user_agent end |