Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
4747 4748 4749 4750 4751 4752 4753 4754 4755 4756 4757 4758 4759 4760 4761 4762 4763 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4747 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
4733 4734 4735 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4733 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
4735 4736 4737 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4735 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
4737 4738 4739 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4737 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
4739 4740 4741 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4739 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
4741 4742 4743 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4741 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
4743 4744 4745 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4743 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
4745 4746 4747 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4745 def subscription @subscription end |