Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



4437
4438
4439
4440
4441
4442
4443
4444
4445
4446
4447
4448
4449
4450
4451
4452
4453
# File 'lib/stripe/services/payment_intent_service.rb', line 4437

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



4423
4424
4425
# File 'lib/stripe/services/payment_intent_service.rb', line 4423

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



4425
4426
4427
# File 'lib/stripe/services/payment_intent_service.rb', line 4425

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



4427
4428
4429
# File 'lib/stripe/services/payment_intent_service.rb', line 4427

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



4429
4430
4431
# File 'lib/stripe/services/payment_intent_service.rb', line 4429

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



4431
4432
4433
# File 'lib/stripe/services/payment_intent_service.rb', line 4431

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



4433
4434
4435
# File 'lib/stripe/services/payment_intent_service.rb', line 4433

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



4435
4436
4437
# File 'lib/stripe/services/payment_intent_service.rb', line 4435

def subscription
  @subscription
end