Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



4335
4336
4337
4338
4339
4340
4341
4342
4343
4344
4345
4346
4347
4348
4349
4350
4351
# File 'lib/stripe/services/payment_intent_service.rb', line 4335

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



4321
4322
4323
# File 'lib/stripe/services/payment_intent_service.rb', line 4321

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



4323
4324
4325
# File 'lib/stripe/services/payment_intent_service.rb', line 4323

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



4325
4326
4327
# File 'lib/stripe/services/payment_intent_service.rb', line 4325

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



4327
4328
4329
# File 'lib/stripe/services/payment_intent_service.rb', line 4327

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



4329
4330
4331
# File 'lib/stripe/services/payment_intent_service.rb', line 4329

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



4331
4332
4333
# File 'lib/stripe/services/payment_intent_service.rb', line 4331

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



4333
4334
4335
# File 'lib/stripe/services/payment_intent_service.rb', line 4333

def subscription
  @subscription
end