Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



4312
4313
4314
4315
4316
4317
4318
4319
4320
4321
4322
4323
4324
4325
4326
4327
4328
# File 'lib/stripe/services/payment_intent_service.rb', line 4312

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



4298
4299
4300
# File 'lib/stripe/services/payment_intent_service.rb', line 4298

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



4300
4301
4302
# File 'lib/stripe/services/payment_intent_service.rb', line 4300

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



4302
4303
4304
# File 'lib/stripe/services/payment_intent_service.rb', line 4302

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



4304
4305
4306
# File 'lib/stripe/services/payment_intent_service.rb', line 4304

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



4306
4307
4308
# File 'lib/stripe/services/payment_intent_service.rb', line 4306

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



4308
4309
4310
# File 'lib/stripe/services/payment_intent_service.rb', line 4308

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



4310
4311
4312
# File 'lib/stripe/services/payment_intent_service.rb', line 4310

def subscription
  @subscription
end