Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#distance ⇒ Object
The details of the distance traveled during the rental period.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#pickup_location_name ⇒ Object
Name of the pickup location.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#return_location_name ⇒ Object
Name of the return location.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
The vehicle identification number.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental
Returns a new instance of CarRental.
4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4235 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @distance = distance @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @pickup_location_name = pickup_location_name @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @return_location_name = return_location_name @tax_exempt = tax_exempt @vehicle_identification_number = vehicle_identification_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
4187 4188 4189 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4187 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
4189 4190 4191 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4189 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
4191 4192 4193 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4191 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
4193 4194 4195 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4193 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
4195 4196 4197 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4195 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
4197 4198 4199 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4197 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
4199 4200 4201 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4199 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
4201 4202 4203 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4201 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
4203 4204 4205 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4203 def delivery @delivery end |
#distance ⇒ Object
The details of the distance traveled during the rental period.
4205 4206 4207 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4205 def distance @distance end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
4207 4208 4209 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4207 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
4209 4210 4211 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4209 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
4211 4212 4213 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4211 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
4213 4214 4215 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4213 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
4215 4216 4217 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4215 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object
Name of the pickup location.
4217 4218 4219 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4217 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object
Rental rate.
4219 4220 4221 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4219 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
4221 4222 4223 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4221 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
4223 4224 4225 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4223 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
4225 4226 4227 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4225 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
4227 4228 4229 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4227 def return_at @return_at end |
#return_location_name ⇒ Object
Name of the return location.
4229 4230 4231 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4229 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
4231 4232 4233 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4231 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object
The vehicle identification number.
4233 4234 4235 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4233 def vehicle_identification_number @vehicle_identification_number end |