Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#distance ⇒ Object
The details of the distance traveled during the rental period.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#pickup_location_name ⇒ Object
Name of the pickup location.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#return_location_name ⇒ Object
Name of the return location.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
The vehicle identification number.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental
Returns a new instance of CarRental.
3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 3936 3937 3938 3939 3940 3941 3942 3943 3944 3945 3946 3947 3948 3949 3950 3951 3952 3953 3954 3955 3956 3957 3958 3959 3960 3961 3962 3963 3964 3965 3966 3967 3968 3969 3970 3971 3972 3973 3974 3975 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3925 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @distance = distance @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @pickup_location_name = pickup_location_name @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @return_location_name = return_location_name @tax_exempt = tax_exempt @vehicle_identification_number = vehicle_identification_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
3877 3878 3879 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3877 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
3879 3880 3881 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3879 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
3881 3882 3883 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3881 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
3883 3884 3885 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3883 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
3885 3886 3887 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3885 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
3887 3888 3889 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3887 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
3889 3890 3891 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3889 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
3891 3892 3893 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3891 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
3893 3894 3895 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3893 def delivery @delivery end |
#distance ⇒ Object
The details of the distance traveled during the rental period.
3895 3896 3897 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3895 def distance @distance end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
3897 3898 3899 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3897 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
3899 3900 3901 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3899 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
3901 3902 3903 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3901 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
3903 3904 3905 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3903 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
3905 3906 3907 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3905 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object
Name of the pickup location.
3907 3908 3909 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3907 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object
Rental rate.
3909 3910 3911 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3909 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
3911 3912 3913 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3911 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
3913 3914 3915 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3913 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
3915 3916 3917 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3915 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
3917 3918 3919 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3917 def return_at @return_at end |
#return_location_name ⇒ Object
Name of the return location.
3919 3920 3921 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3919 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
3921 3922 3923 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3921 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object
The vehicle identification number.
3923 3924 3925 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3923 def vehicle_identification_number @vehicle_identification_number end |