Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental

Returns a new instance of CarRental.



3808
3809
3810
3811
3812
3813
3814
3815
3816
3817
3818
3819
3820
3821
3822
3823
3824
3825
3826
3827
3828
3829
3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
# File 'lib/stripe/services/payment_intent_service.rb', line 3808

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  tax_exempt: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @tax_exempt = tax_exempt
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



3768
3769
3770
# File 'lib/stripe/services/payment_intent_service.rb', line 3768

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



3770
3771
3772
# File 'lib/stripe/services/payment_intent_service.rb', line 3770

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



3772
3773
3774
# File 'lib/stripe/services/payment_intent_service.rb', line 3772

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



3774
3775
3776
# File 'lib/stripe/services/payment_intent_service.rb', line 3774

def car_make
  @car_make
end

#car_modelObject

Model of the car.



3776
3777
3778
# File 'lib/stripe/services/payment_intent_service.rb', line 3776

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



3778
3779
3780
# File 'lib/stripe/services/payment_intent_service.rb', line 3778

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



3780
3781
3782
# File 'lib/stripe/services/payment_intent_service.rb', line 3780

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



3782
3783
3784
# File 'lib/stripe/services/payment_intent_service.rb', line 3782

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



3784
3785
3786
# File 'lib/stripe/services/payment_intent_service.rb', line 3784

def delivery
  @delivery
end

#driversObject

The details of the passengers in the travel reservation



3786
3787
3788
# File 'lib/stripe/services/payment_intent_service.rb', line 3786

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



3788
3789
3790
# File 'lib/stripe/services/payment_intent_service.rb', line 3788

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



3790
3791
3792
# File 'lib/stripe/services/payment_intent_service.rb', line 3790

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



3792
3793
3794
# File 'lib/stripe/services/payment_intent_service.rb', line 3792

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



3794
3795
3796
# File 'lib/stripe/services/payment_intent_service.rb', line 3794

def pickup_at
  @pickup_at
end

#rate_amountObject

Rental rate.



3796
3797
3798
# File 'lib/stripe/services/payment_intent_service.rb', line 3796

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



3798
3799
3800
# File 'lib/stripe/services/payment_intent_service.rb', line 3798

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



3800
3801
3802
# File 'lib/stripe/services/payment_intent_service.rb', line 3800

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



3802
3803
3804
# File 'lib/stripe/services/payment_intent_service.rb', line 3802

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



3804
3805
3806
# File 'lib/stripe/services/payment_intent_service.rb', line 3804

def return_at
  @return_at
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



3806
3807
3808
# File 'lib/stripe/services/payment_intent_service.rb', line 3806

def tax_exempt
  @tax_exempt
end