Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 3812 3813 3814 3815 3816 3817 3818 3819 3820 3821 3822 3823 3824 3825 3826 3827 3828 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3786 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
3746 3747 3748 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3746 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
3748 3749 3750 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3748 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
3750 3751 3752 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3750 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
3752 3753 3754 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3752 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
3754 3755 3756 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3754 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
3756 3757 3758 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3756 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
3758 3759 3760 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3758 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
3760 3761 3762 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3760 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
3762 3763 3764 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3762 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
3764 3765 3766 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3764 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
3766 3767 3768 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3766 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
3768 3769 3770 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3768 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
3770 3771 3772 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3770 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
3772 3773 3774 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3772 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
3774 3775 3776 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3774 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
3776 3777 3778 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3776 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
3778 3779 3780 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3778 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
3780 3781 3782 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3780 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
3782 3783 3784 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3782 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
3784 3785 3786 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3784 def tax_exempt @tax_exempt end |