Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 3649 3650 3651 3652 3653 3654 3655 3656 3657 3658 3659 3660 3661 3662 3663 3664 3665 3666 3667 3668 3669 3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 3680 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3638 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
3598 3599 3600 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3598 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
3600 3601 3602 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3600 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
3602 3603 3604 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3602 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
3604 3605 3606 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3604 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
3606 3607 3608 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3606 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
3608 3609 3610 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3608 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
3610 3611 3612 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3610 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
3612 3613 3614 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3612 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
3614 3615 3616 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3614 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
3616 3617 3618 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3616 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
3618 3619 3620 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3618 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
3620 3621 3622 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3620 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
3622 3623 3624 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3622 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
3624 3625 3626 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3624 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
3626 3627 3628 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3626 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
3628 3629 3630 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3628 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
3630 3631 3632 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3630 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
3632 3633 3634 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3632 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
3634 3635 3636 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3634 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
3636 3637 3638 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3636 def tax_exempt @tax_exempt end |