Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
3617 3618 3619 3620 3621 3622 3623 3624 3625 3626 3627 3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 3649 3650 3651 3652 3653 3654 3655 3656 3657 3658 3659 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3617 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
3577 3578 3579 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3577 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
3579 3580 3581 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3579 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
3581 3582 3583 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3581 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
3583 3584 3585 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3583 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
3585 3586 3587 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3585 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
3587 3588 3589 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3587 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
3589 3590 3591 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3589 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
3591 3592 3593 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3591 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
3593 3594 3595 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3593 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
3595 3596 3597 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3595 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
3597 3598 3599 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3597 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
3599 3600 3601 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3599 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
3601 3602 3603 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3601 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
3603 3604 3605 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3603 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
3605 3606 3607 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3605 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
3607 3608 3609 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3607 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
3609 3610 3611 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3609 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
3611 3612 3613 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3611 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
3613 3614 3615 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3613 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
3615 3616 3617 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3615 def tax_exempt @tax_exempt end |