Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental

Returns a new instance of CarRental.



4045
4046
4047
4048
4049
4050
4051
4052
4053
4054
4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
# File 'lib/stripe/services/payment_intent_service.rb', line 4045

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  tax_exempt: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @tax_exempt = tax_exempt
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



3986
3987
3988
# File 'lib/stripe/services/payment_intent_service.rb', line 3986

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



3989
3990
3991
# File 'lib/stripe/services/payment_intent_service.rb', line 3989

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



3992
3993
3994
# File 'lib/stripe/services/payment_intent_service.rb', line 3992

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



3995
3996
3997
# File 'lib/stripe/services/payment_intent_service.rb', line 3995

def car_make
  @car_make
end

#car_modelObject

Model of the car.



3998
3999
4000
# File 'lib/stripe/services/payment_intent_service.rb', line 3998

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



4001
4002
4003
# File 'lib/stripe/services/payment_intent_service.rb', line 4001

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



4004
4005
4006
# File 'lib/stripe/services/payment_intent_service.rb', line 4004

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



4007
4008
4009
# File 'lib/stripe/services/payment_intent_service.rb', line 4007

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



4010
4011
4012
# File 'lib/stripe/services/payment_intent_service.rb', line 4010

def delivery
  @delivery
end

#driversObject

The details of the passengers in the travel reservation



4013
4014
4015
# File 'lib/stripe/services/payment_intent_service.rb', line 4013

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



4016
4017
4018
# File 'lib/stripe/services/payment_intent_service.rb', line 4016

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



4019
4020
4021
# File 'lib/stripe/services/payment_intent_service.rb', line 4019

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



4022
4023
4024
# File 'lib/stripe/services/payment_intent_service.rb', line 4022

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



4025
4026
4027
# File 'lib/stripe/services/payment_intent_service.rb', line 4025

def pickup_at
  @pickup_at
end

#rate_amountObject

Rental rate.



4028
4029
4030
# File 'lib/stripe/services/payment_intent_service.rb', line 4028

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



4031
4032
4033
# File 'lib/stripe/services/payment_intent_service.rb', line 4031

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



4034
4035
4036
# File 'lib/stripe/services/payment_intent_service.rb', line 4034

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



4037
4038
4039
# File 'lib/stripe/services/payment_intent_service.rb', line 4037

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



4040
4041
4042
# File 'lib/stripe/services/payment_intent_service.rb', line 4040

def return_at
  @return_at
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



4043
4044
4045
# File 'lib/stripe/services/payment_intent_service.rb', line 4043

def tax_exempt
  @tax_exempt
end