Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
4135 4136 4137 4138 4139 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4135 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
4129 4130 4131 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4129 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
4131 4132 4133 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4131 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
4133 4134 4135 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4133 def phone @phone end |