Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
4081 4082 4083 4084 4085 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4081 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
4075 4076 4077 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4075 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
4077 4078 4079 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4077 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
4079 4080 4081 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4079 def phone @phone end |