Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
3669 3670 3671 3672 3673 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3669 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
3663 3664 3665 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3663 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
3665 3666 3667 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3665 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
3667 3668 3669 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3667 def phone @phone end |