Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



3658
3659
3660
3661
3662
# File 'lib/stripe/services/payment_intent_service.rb', line 3658

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



3652
3653
3654
# File 'lib/stripe/services/payment_intent_service.rb', line 3652

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



3654
3655
3656
# File 'lib/stripe/services/payment_intent_service.rb', line 3654

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



3656
3657
3658
# File 'lib/stripe/services/payment_intent_service.rb', line 3656

def phone
  @phone
end