Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
3489 3490 3491 3492 3493 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3489 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
3483 3484 3485 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3483 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
3485 3486 3487 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3485 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
3487 3488 3489 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3487 def phone @phone end |