Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 4385 4386 4387 4388 4389 4390 4391 4392 4393 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4373 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
4355 4356 4357 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4355 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
4357 4358 4359 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4357 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
4359 4360 4361 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4359 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
4361 4362 4363 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4361 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
4363 4364 4365 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4363 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
4365 4366 4367 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4365 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
4367 4368 4369 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4367 def genre @genre end |
#name ⇒ Object
The name of the event.
4369 4370 4371 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4369 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
4371 4372 4373 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4371 def starts_at @starts_at end |