Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3768 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
3750 3751 3752 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3750 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
3752 3753 3754 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3752 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
3754 3755 3756 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3754 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
3756 3757 3758 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3756 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
3758 3759 3760 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3758 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
3760 3761 3762 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3760 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
3762 3763 3764 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3762 def genre @genre end |
#name ⇒ Object
The name of the event.
3764 3765 3766 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3764 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
3766 3767 3768 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3766 def starts_at @starts_at end |