Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3747 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
3729 3730 3731 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3729 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
3731 3732 3733 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3731 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
3733 3734 3735 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3733 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
3735 3736 3737 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3735 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
3737 3738 3739 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3737 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
3739 3740 3741 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3739 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
3741 3742 3743 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3741 def genre @genre end |
#name ⇒ Object
The name of the event.
3743 3744 3745 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3743 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
3745 3746 3747 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3745 def starts_at @starts_at end |