Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
3733 3734 3735 3736 3737 3738 3739 3740 3741 3742 3743 3744 3745 3746 3747 3748 3749 3750 3751 3752 3753 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3733 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
3715 3716 3717 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3715 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
3717 3718 3719 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3717 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
3719 3720 3721 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3719 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
3721 3722 3723 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3721 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
3723 3724 3725 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3723 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
3725 3726 3727 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3725 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
3727 3728 3729 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3727 def genre @genre end |
#name ⇒ Object
The name of the event.
3729 3730 3731 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3729 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
3731 3732 3733 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3731 def starts_at @starts_at end |