Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
4392 4393 4394 4395 4396 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4392 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
4386 4387 4388 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4386 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
4388 4389 4390 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4388 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
4390 4391 4392 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4390 def phone @phone end |