Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



4338
4339
4340
4341
4342
# File 'lib/stripe/services/payment_intent_service.rb', line 4338

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



4332
4333
4334
# File 'lib/stripe/services/payment_intent_service.rb', line 4332

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



4334
4335
4336
# File 'lib/stripe/services/payment_intent_service.rb', line 4334

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



4336
4337
4338
# File 'lib/stripe/services/payment_intent_service.rb', line 4336

def phone
  @phone
end