Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



4028
4029
4030
4031
4032
# File 'lib/stripe/services/payment_intent_service.rb', line 4028

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



4022
4023
4024
# File 'lib/stripe/services/payment_intent_service.rb', line 4022

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



4024
4025
4026
# File 'lib/stripe/services/payment_intent_service.rb', line 4024

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



4026
4027
4028
# File 'lib/stripe/services/payment_intent_service.rb', line 4026

def phone
  @phone
end