Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



3926
3927
3928
3929
3930
# File 'lib/stripe/services/payment_intent_service.rb', line 3926

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



3920
3921
3922
# File 'lib/stripe/services/payment_intent_service.rb', line 3920

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



3922
3923
3924
# File 'lib/stripe/services/payment_intent_service.rb', line 3922

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



3924
3925
3926
# File 'lib/stripe/services/payment_intent_service.rb', line 3924

def phone
  @phone
end