Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



3733
3734
3735
3736
3737
# File 'lib/stripe/services/payment_intent_service.rb', line 3733

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



3727
3728
3729
# File 'lib/stripe/services/payment_intent_service.rb', line 3727

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



3729
3730
3731
# File 'lib/stripe/services/payment_intent_service.rb', line 3729

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



3731
3732
3733
# File 'lib/stripe/services/payment_intent_service.rb', line 3731

def phone
  @phone
end