Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



3712
3713
3714
3715
3716
# File 'lib/stripe/services/payment_intent_service.rb', line 3712

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



3706
3707
3708
# File 'lib/stripe/services/payment_intent_service.rb', line 3706

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



3708
3709
3710
# File 'lib/stripe/services/payment_intent_service.rb', line 3708

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



3710
3711
3712
# File 'lib/stripe/services/payment_intent_service.rb', line 3710

def phone
  @phone
end