Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



3698
3699
3700
3701
3702
# File 'lib/stripe/services/payment_intent_service.rb', line 3698

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



3692
3693
3694
# File 'lib/stripe/services/payment_intent_service.rb', line 3692

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



3694
3695
3696
# File 'lib/stripe/services/payment_intent_service.rb', line 3694

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



3696
3697
3698
# File 'lib/stripe/services/payment_intent_service.rb', line 3696

def phone
  @phone
end