Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4186 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
4170 4171 4172 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4170 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
4172 4173 4174 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4172 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
4174 4175 4176 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4174 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
4176 4177 4178 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4176 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
4178 4179 4180 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4178 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
4180 4181 4182 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4180 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
4182 4183 4184 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4182 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
4184 4185 4186 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4184 def ticket_number @ticket_number end |