Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
4061 4062 4063 4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4061 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
4045 4046 4047 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4045 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
4047 4048 4049 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4047 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
4049 4050 4051 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4049 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
4051 4052 4053 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4051 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
4053 4054 4055 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4053 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
4055 4056 4057 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4055 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
4057 4058 4059 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4057 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
4059 4060 4061 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4059 def ticket_number @ticket_number end |