Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3891 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
3875 3876 3877 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3875 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
3877 3878 3879 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3877 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
3879 3880 3881 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3879 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
3881 3882 3883 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3881 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
3883 3884 3885 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3883 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
3885 3886 3887 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3885 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
3887 3888 3889 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3887 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
3889 3890 3891 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3889 def ticket_number @ticket_number end |