Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
4331 4332 4333 4334 4335 4336 4337 4338 4339 4340 4341 4342 4343 4344 4345 4346 4347 4348 4349 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4331 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
4308 4309 4310 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4308 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
4311 4312 4313 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4311 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
4314 4315 4316 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4314 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
4317 4318 4319 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4317 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
4320 4321 4322 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4320 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
4323 4324 4325 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4323 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
4326 4327 4328 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4326 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
4329 4330 4331 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4329 def ticket_number @ticket_number end |