Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
4105 4106 4107 4108 4109 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4105 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
4099 4100 4101 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4099 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
4101 4102 4103 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4101 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
4103 4104 4105 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4103 def phone @phone end |