Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



4003
4004
4005
4006
4007
# File 'lib/stripe/services/payment_intent_service.rb', line 4003

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



3997
3998
3999
# File 'lib/stripe/services/payment_intent_service.rb', line 3997

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



3999
4000
4001
# File 'lib/stripe/services/payment_intent_service.rb', line 3999

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



4001
4002
4003
# File 'lib/stripe/services/payment_intent_service.rb', line 4001

def phone
  @phone
end