Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
3958 3959 3960 3961 3962 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3958 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
3952 3953 3954 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3952 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
3954 3955 3956 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3954 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
3956 3957 3958 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3956 def phone @phone end |