Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



3789
3790
3791
3792
3793
# File 'lib/stripe/services/payment_intent_service.rb', line 3789

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



3783
3784
3785
# File 'lib/stripe/services/payment_intent_service.rb', line 3783

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



3785
3786
3787
# File 'lib/stripe/services/payment_intent_service.rb', line 3785

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



3787
3788
3789
# File 'lib/stripe/services/payment_intent_service.rb', line 3787

def phone
  @phone
end