Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
3775 3776 3777 3778 3779 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3775 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
3769 3770 3771 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3769 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
3771 3772 3773 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3771 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
3773 3774 3775 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3773 def phone @phone end |