Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
4689 4690 4691 4692 4693 4694 4695 4696 4697 4698 4699 4700 4701 4702 4703 4704 4705 4706 4707 4708 4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4689 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
4647 4648 4649 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4647 def address @address end |
#adults ⇒ Object
The number of adults on the booking
4649 4650 4651 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4649 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
4651 4652 4653 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4651 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
4653 4654 4655 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4653 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
4655 4656 4657 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4655 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
4657 4658 4659 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4657 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
4659 4660 4661 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4659 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
4661 4662 4663 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4661 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
4663 4664 4665 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4663 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
4665 4666 4667 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4665 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
4667 4668 4669 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4667 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
4669 4670 4671 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4669 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
4671 4672 4673 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4671 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
4673 4674 4675 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4673 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
4675 4676 4677 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4675 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
4677 4678 4679 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4677 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
4679 4680 4681 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4679 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
4681 4682 4683 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4681 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
4683 4684 4685 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4683 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
4685 4686 4687 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4685 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
4687 4688 4689 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4687 def total_tax_amount @total_tax_amount end |