Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 4673 4674 4675 4676 4677 4678 4679 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4635 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
4593 4594 4595 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4593 def address @address end |
#adults ⇒ Object
The number of adults on the booking
4595 4596 4597 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4595 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
4597 4598 4599 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4597 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
4599 4600 4601 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4599 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
4601 4602 4603 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4601 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
4603 4604 4605 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4603 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
4605 4606 4607 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4605 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
4607 4608 4609 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4607 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
4609 4610 4611 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4609 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
4611 4612 4613 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4611 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
4613 4614 4615 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4613 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
4615 4616 4617 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4615 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
4617 4618 4619 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4617 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
4619 4620 4621 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4619 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
4621 4622 4623 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4621 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
4623 4624 4625 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4623 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
4625 4626 4627 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4625 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
4627 4628 4629 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4627 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
4629 4630 4631 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4629 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
4631 4632 4633 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4631 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
4633 4634 4635 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4633 def total_tax_amount @total_tax_amount end |