Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 4335 4336 4337 4338 4339 4340 4341 4342 4343 4344 4345 4346 4347 4348 4349 4350 4351 4352 4353 4354 4355 4356 4357 4358 4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 4369 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4325 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
4283 4284 4285 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4283 def address @address end |
#adults ⇒ Object
The number of adults on the booking
4285 4286 4287 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4285 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
4287 4288 4289 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4287 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
4289 4290 4291 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4289 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
4291 4292 4293 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4291 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
4293 4294 4295 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4293 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
4295 4296 4297 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4295 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
4297 4298 4299 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4297 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
4299 4300 4301 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4299 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
4301 4302 4303 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4301 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
4303 4304 4305 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4303 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
4305 4306 4307 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4305 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
4307 4308 4309 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4307 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
4309 4310 4311 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4309 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
4311 4312 4313 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4311 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
4313 4314 4315 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4313 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
4315 4316 4317 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4315 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
4317 4318 4319 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4317 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
4319 4320 4321 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4319 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
4321 4322 4323 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4321 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
4323 4324 4325 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4323 def total_tax_amount @total_tax_amount end |