Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4223 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
4181 4182 4183 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4181 def address @address end |
#adults ⇒ Object
The number of adults on the booking
4183 4184 4185 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4183 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
4185 4186 4187 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4185 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
4187 4188 4189 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4187 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
4189 4190 4191 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4189 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
4191 4192 4193 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4191 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
4193 4194 4195 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4193 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
4195 4196 4197 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4195 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
4197 4198 4199 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4197 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
4199 4200 4201 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4199 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
4201 4202 4203 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4201 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
4203 4204 4205 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4203 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
4205 4206 4207 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4205 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
4207 4208 4209 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4207 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
4209 4210 4211 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4209 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
4211 4212 4213 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4211 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
4213 4214 4215 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4213 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
4215 4216 4217 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4215 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
4217 4218 4219 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4217 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
4219 4220 4221 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4219 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
4221 4222 4223 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4221 def total_tax_amount @total_tax_amount end |