Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Loding check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4200 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
4158 4159 4160 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4158 def address @address end |
#adults ⇒ Object
The number of adults on the booking
4160 4161 4162 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4160 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
4162 4163 4164 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4162 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
4164 4165 4166 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4164 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
4166 4167 4168 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4166 def category @category end |
#checkin_at ⇒ Object
Loding check-in time. Measured in seconds since the Unix epoch.
4168 4169 4170 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4168 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
4170 4171 4172 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4170 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
4172 4173 4174 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4172 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
4174 4175 4176 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4174 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
4176 4177 4178 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4176 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
4178 4179 4180 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4178 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
4180 4181 4182 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4180 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
4182 4183 4184 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4182 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
4184 4185 4186 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4184 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
4186 4187 4188 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4186 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
4188 4189 4190 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4188 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
4190 4191 4192 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4190 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
4192 4193 4194 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4192 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
4194 4195 4196 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4194 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
4196 4197 4198 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4196 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
4198 4199 4200 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4198 def total_tax_amount @total_tax_amount end |