Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Loding check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
4178 4179 4180 4181 4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4178 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
4136 4137 4138 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4136 def address @address end |
#adults ⇒ Object
The number of adults on the booking
4138 4139 4140 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4138 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
4140 4141 4142 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4140 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
4142 4143 4144 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4142 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
4144 4145 4146 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4144 def category @category end |
#checkin_at ⇒ Object
Loding check-in time. Measured in seconds since the Unix epoch.
4146 4147 4148 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4146 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
4148 4149 4150 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4148 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
4150 4151 4152 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4150 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
4152 4153 4154 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4152 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
4154 4155 4156 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4154 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
4156 4157 4158 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4156 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
4158 4159 4160 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4158 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
4160 4161 4162 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4160 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
4162 4163 4164 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4162 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
4164 4165 4166 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4164 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
4166 4167 4168 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4166 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
4168 4169 4170 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4168 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
4170 4171 4172 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4170 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
4172 4173 4174 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4172 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
4174 4175 4176 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4174 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
4176 4177 4178 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4176 def total_tax_amount @total_tax_amount end |