Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
4040
4041
4042
4043
4044
4045
4046
4047
4048
4049
4050
4051
4052
4053
4054
4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
# File 'lib/stripe/services/payment_intent_service.rb', line 4030

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



3988
3989
3990
# File 'lib/stripe/services/payment_intent_service.rb', line 3988

def address
  @address
end

#adultsObject

The number of adults on the booking



3990
3991
3992
# File 'lib/stripe/services/payment_intent_service.rb', line 3990

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



3992
3993
3994
# File 'lib/stripe/services/payment_intent_service.rb', line 3992

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



3994
3995
3996
# File 'lib/stripe/services/payment_intent_service.rb', line 3994

def booking_number
  @booking_number
end

#categoryObject

The lodging category



3996
3997
3998
# File 'lib/stripe/services/payment_intent_service.rb', line 3996

def category
  @category
end

#checkin_atObject

Loding check-in time. Measured in seconds since the Unix epoch.



3998
3999
4000
# File 'lib/stripe/services/payment_intent_service.rb', line 3998

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



4000
4001
4002
# File 'lib/stripe/services/payment_intent_service.rb', line 4000

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



4002
4003
4004
# File 'lib/stripe/services/payment_intent_service.rb', line 4002

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



4004
4005
4006
# File 'lib/stripe/services/payment_intent_service.rb', line 4004

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



4006
4007
4008
# File 'lib/stripe/services/payment_intent_service.rb', line 4006

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



4008
4009
4010
# File 'lib/stripe/services/payment_intent_service.rb', line 4008

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



4010
4011
4012
# File 'lib/stripe/services/payment_intent_service.rb', line 4010

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



4012
4013
4014
# File 'lib/stripe/services/payment_intent_service.rb', line 4012

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



4014
4015
4016
# File 'lib/stripe/services/payment_intent_service.rb', line 4014

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



4016
4017
4018
# File 'lib/stripe/services/payment_intent_service.rb', line 4016

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



4018
4019
4020
# File 'lib/stripe/services/payment_intent_service.rb', line 4018

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



4020
4021
4022
# File 'lib/stripe/services/payment_intent_service.rb', line 4020

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



4022
4023
4024
# File 'lib/stripe/services/payment_intent_service.rb', line 4022

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



4024
4025
4026
# File 'lib/stripe/services/payment_intent_service.rb', line 4024

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



4026
4027
4028
# File 'lib/stripe/services/payment_intent_service.rb', line 4026

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



4028
4029
4030
# File 'lib/stripe/services/payment_intent_service.rb', line 4028

def total_tax_amount
  @total_tax_amount
end