Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Loding check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 4515 4516 4517 4518 4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4498 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
4436 4437 4438 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4436 def address @address end |
#adults ⇒ Object
The number of adults on the booking
4439 4440 4441 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4439 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
4442 4443 4444 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4442 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
4445 4446 4447 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4445 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
4448 4449 4450 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4448 def category @category end |
#checkin_at ⇒ Object
Loding check-in time. Measured in seconds since the Unix epoch.
4451 4452 4453 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4451 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
4454 4455 4456 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4454 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
4457 4458 4459 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4457 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
4460 4461 4462 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4460 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
4463 4464 4465 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4463 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
4466 4467 4468 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4466 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
4469 4470 4471 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4469 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
4472 4473 4474 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4472 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
4475 4476 4477 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4475 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
4478 4479 4480 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4478 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
4481 4482 4483 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4481 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
4484 4485 4486 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4484 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
4487 4488 4489 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4487 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
4490 4491 4492 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4490 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
4493 4494 4495 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4493 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
4496 4497 4498 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4496 def total_tax_amount @total_tax_amount end |