Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/stripe/services/payment_intent_service.rb', line 3995

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



3953
3954
3955
# File 'lib/stripe/services/payment_intent_service.rb', line 3953

def address
  @address
end

#adultsObject

The number of adults on the booking



3955
3956
3957
# File 'lib/stripe/services/payment_intent_service.rb', line 3955

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



3957
3958
3959
# File 'lib/stripe/services/payment_intent_service.rb', line 3957

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



3959
3960
3961
# File 'lib/stripe/services/payment_intent_service.rb', line 3959

def booking_number
  @booking_number
end

#categoryObject

The lodging category



3961
3962
3963
# File 'lib/stripe/services/payment_intent_service.rb', line 3961

def category
  @category
end

#checkin_atObject

Loding check-in time. Measured in seconds since the Unix epoch.



3963
3964
3965
# File 'lib/stripe/services/payment_intent_service.rb', line 3963

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



3965
3966
3967
# File 'lib/stripe/services/payment_intent_service.rb', line 3965

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



3967
3968
3969
# File 'lib/stripe/services/payment_intent_service.rb', line 3967

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



3969
3970
3971
# File 'lib/stripe/services/payment_intent_service.rb', line 3969

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



3971
3972
3973
# File 'lib/stripe/services/payment_intent_service.rb', line 3971

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



3973
3974
3975
# File 'lib/stripe/services/payment_intent_service.rb', line 3973

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



3975
3976
3977
# File 'lib/stripe/services/payment_intent_service.rb', line 3975

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



3977
3978
3979
# File 'lib/stripe/services/payment_intent_service.rb', line 3977

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



3979
3980
3981
# File 'lib/stripe/services/payment_intent_service.rb', line 3979

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



3981
3982
3983
# File 'lib/stripe/services/payment_intent_service.rb', line 3981

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



3983
3984
3985
# File 'lib/stripe/services/payment_intent_service.rb', line 3983

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



3985
3986
3987
# File 'lib/stripe/services/payment_intent_service.rb', line 3985

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



3987
3988
3989
# File 'lib/stripe/services/payment_intent_service.rb', line 3987

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



3989
3990
3991
# File 'lib/stripe/services/payment_intent_service.rb', line 3989

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



3991
3992
3993
# File 'lib/stripe/services/payment_intent_service.rb', line 3991

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



3993
3994
3995
# File 'lib/stripe/services/payment_intent_service.rb', line 3993

def total_tax_amount
  @total_tax_amount
end