Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



4110
4111
4112
4113
4114
# File 'lib/stripe/services/payment_intent_service.rb', line 4110

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



4104
4105
4106
# File 'lib/stripe/services/payment_intent_service.rb', line 4104

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



4106
4107
4108
# File 'lib/stripe/services/payment_intent_service.rb', line 4106

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



4108
4109
4110
# File 'lib/stripe/services/payment_intent_service.rb', line 4108

def phone
  @phone
end