Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



4132
4133
4134
4135
4136
# File 'lib/stripe/services/payment_intent_service.rb', line 4132

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



4126
4127
4128
# File 'lib/stripe/services/payment_intent_service.rb', line 4126

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



4128
4129
4130
# File 'lib/stripe/services/payment_intent_service.rb', line 4128

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



4130
4131
4132
# File 'lib/stripe/services/payment_intent_service.rb', line 4130

def phone
  @phone
end