Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
3941 3942 3943 3944 3945 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3941 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
3935 3936 3937 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3935 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
3937 3938 3939 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3937 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
3939 3940 3941 |
# File 'lib/stripe/services/payment_intent_service.rb', line 3939 def phone @phone end |