Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



4388
4389
4390
4391
# File 'lib/stripe/services/payment_intent_service.rb', line 4388

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



4384
4385
4386
# File 'lib/stripe/services/payment_intent_service.rb', line 4384

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



4386
4387
4388
# File 'lib/stripe/services/payment_intent_service.rb', line 4386

def interval
  @interval
end