Class: Stripe::PaymentIntentService::UpdateParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



4241
4242
4243
4244
# File 'lib/stripe/services/payment_intent_service.rb', line 4241

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



4237
4238
4239
# File 'lib/stripe/services/payment_intent_service.rb', line 4237

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



4239
4240
4241
# File 'lib/stripe/services/payment_intent_service.rb', line 4239

def interval
  @interval
end