Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodData
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, RadarOptions, Rechnung, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, StripeBalance, Swish, Twint, UsBankAccount, WechatPay, Zip
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If this is an ‘acss_debit` PaymentMethod, this hash contains details about the ACSS Debit payment method.
-
#affirm ⇒ Object
If this is an ‘affirm` PaymentMethod, this hash contains details about the Affirm payment method.
-
#afterpay_clearpay ⇒ Object
If this is an ‘AfterpayClearpay` PaymentMethod, this hash contains details about the AfterpayClearpay payment method.
-
#alipay ⇒ Object
If this is an ‘Alipay` PaymentMethod, this hash contains details about the Alipay payment method.
-
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#alma ⇒ Object
If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.
-
#amazon_pay ⇒ Object
If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.
-
#au_becs_debit ⇒ Object
If this is an ‘au_becs_debit` PaymentMethod, this hash contains details about the bank account.
-
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.
-
#bancontact ⇒ Object
If this is a ‘bancontact` PaymentMethod, this hash contains details about the Bancontact payment method.
-
#billie ⇒ Object
If this is a ‘billie` PaymentMethod, this hash contains details about the Billie payment method.
-
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
-
#blik ⇒ Object
If this is a ‘blik` PaymentMethod, this hash contains details about the BLIK payment method.
-
#boleto ⇒ Object
If this is a ‘boleto` PaymentMethod, this hash contains details about the Boleto payment method.
-
#cashapp ⇒ Object
If this is a ‘cashapp` PaymentMethod, this hash contains details about the Cash App Pay payment method.
-
#crypto ⇒ Object
If this is a Crypto PaymentMethod, this hash contains details about the Crypto payment method.
-
#customer_balance ⇒ Object
If this is a ‘customer_balance` PaymentMethod, this hash contains details about the CustomerBalance payment method.
-
#eps ⇒ Object
If this is an ‘eps` PaymentMethod, this hash contains details about the EPS payment method.
-
#fpx ⇒ Object
If this is an ‘fpx` PaymentMethod, this hash contains details about the FPX payment method.
-
#giropay ⇒ Object
If this is a ‘giropay` PaymentMethod, this hash contains details about the Giropay payment method.
-
#gopay ⇒ Object
If this is a Gopay PaymentMethod, this hash contains details about the Gopay payment method.
-
#grabpay ⇒ Object
If this is a ‘grabpay` PaymentMethod, this hash contains details about the GrabPay payment method.
-
#id_bank_transfer ⇒ Object
If this is an ‘IdBankTransfer` PaymentMethod, this hash contains details about the IdBankTransfer payment method.
-
#ideal ⇒ Object
If this is an ‘ideal` PaymentMethod, this hash contains details about the iDEAL payment method.
-
#interac_present ⇒ Object
If this is an ‘interac_present` PaymentMethod, this hash contains details about the Interac Present payment method.
-
#kakao_pay ⇒ Object
If this is a ‘kakao_pay` PaymentMethod, this hash contains details about the Kakao Pay payment method.
-
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method.
-
#konbini ⇒ Object
If this is a ‘konbini` PaymentMethod, this hash contains details about the Konbini payment method.
-
#kr_card ⇒ Object
If this is a ‘kr_card` PaymentMethod, this hash contains details about the Korean Card payment method.
-
#link ⇒ Object
If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.
-
#mb_way ⇒ Object
If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#mobilepay ⇒ Object
If this is a ‘mobilepay` PaymentMethod, this hash contains details about the MobilePay payment method.
-
#multibanco ⇒ Object
If this is a ‘multibanco` PaymentMethod, this hash contains details about the Multibanco payment method.
-
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.
-
#nz_bank_account ⇒ Object
If this is an nz_bank_account PaymentMethod, this hash contains details about the nz_bank_account payment method.
-
#oxxo ⇒ Object
If this is an ‘oxxo` PaymentMethod, this hash contains details about the OXXO payment method.
-
#p24 ⇒ Object
If this is a ‘p24` PaymentMethod, this hash contains details about the P24 payment method.
-
#pay_by_bank ⇒ Object
If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.
-
#payco ⇒ Object
If this is a ‘payco` PaymentMethod, this hash contains details about the PAYCO payment method.
-
#paynow ⇒ Object
If this is a ‘paynow` PaymentMethod, this hash contains details about the PayNow payment method.
-
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this hash contains details about the PayPal payment method.
-
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.
-
#pix ⇒ Object
If this is a ‘pix` PaymentMethod, this hash contains details about the Pix payment method.
-
#promptpay ⇒ Object
If this is a ‘promptpay` PaymentMethod, this hash contains details about the PromptPay payment method.
-
#qris ⇒ Object
If this is a ‘qris` PaymentMethod, this hash contains details about the QRIS payment method.
-
#radar_options ⇒ Object
Options to configure Radar.
-
#rechnung ⇒ Object
If this is a ‘rechnung` PaymentMethod, this hash contains details about the Rechnung payment method.
-
#revolut_pay ⇒ Object
If this is a ‘revolut_pay` PaymentMethod, this hash contains details about the Revolut Pay payment method.
-
#samsung_pay ⇒ Object
If this is a ‘samsung_pay` PaymentMethod, this hash contains details about the SamsungPay payment method.
-
#satispay ⇒ Object
If this is a ‘satispay` PaymentMethod, this hash contains details about the Satispay payment method.
-
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` PaymentMethod, this hash contains details about the SEPA debit bank account.
-
#shopeepay ⇒ Object
If this is a Shopeepay PaymentMethod, this hash contains details about the Shopeepay payment method.
-
#sofort ⇒ Object
If this is a ‘sofort` PaymentMethod, this hash contains details about the SOFORT payment method.
-
#stripe_balance ⇒ Object
This hash contains details about the Stripe balance payment method.
-
#swish ⇒ Object
If this is a ‘swish` PaymentMethod, this hash contains details about the Swish payment method.
-
#twint ⇒ Object
If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.
-
#type ⇒ Object
The type of the PaymentMethod.
-
#us_bank_account ⇒ Object
If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.
-
#wechat_pay ⇒ Object
If this is an ‘wechat_pay` PaymentMethod, this hash contains details about the wechat_pay payment method.
-
#zip ⇒ Object
If this is a ‘zip` PaymentMethod, this hash contains details about the Zip payment method.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, billing_details: nil, blik: nil, boleto: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, radar_options: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, swish: nil, twint: nil, type: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodData
Returns a new instance of PaymentMethodData.
4945 4946 4947 4948 4949 4950 4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 4968 4969 4970 4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 5037 5038 5039 5040 5041 5042 5043 5044 5045 5046 5047 5048 5049 5050 5051 5052 5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 5067 5068 5069 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4945 def initialize( acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, billing_details: nil, blik: nil, boleto: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, radar_options: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, swish: nil, twint: nil, type: nil, us_bank_account: nil, wechat_pay: nil, zip: nil ) @acss_debit = acss_debit @affirm = affirm @afterpay_clearpay = afterpay_clearpay @alipay = alipay @allow_redisplay = allow_redisplay @alma = alma @amazon_pay = amazon_pay @au_becs_debit = au_becs_debit @bacs_debit = bacs_debit @bancontact = bancontact @billie = billie @billing_details = billing_details @blik = blik @boleto = boleto @cashapp = cashapp @crypto = crypto @customer_balance = customer_balance @eps = eps @fpx = fpx @giropay = giropay @gopay = gopay @grabpay = grabpay @id_bank_transfer = id_bank_transfer @ideal = ideal @interac_present = interac_present @kakao_pay = kakao_pay @klarna = klarna @konbini = konbini @kr_card = kr_card @link = link @mb_way = mb_way @metadata = @mobilepay = mobilepay @multibanco = multibanco @naver_pay = naver_pay @nz_bank_account = nz_bank_account @oxxo = oxxo @p24 = p24 @pay_by_bank = pay_by_bank @payco = payco @paynow = paynow @paypal = paypal @payto = payto @pix = pix @promptpay = promptpay @qris = qris @radar_options = @rechnung = rechnung @revolut_pay = revolut_pay @samsung_pay = samsung_pay @satispay = satispay @sepa_debit = sepa_debit @shopeepay = shopeepay @sofort = sofort @stripe_balance = stripe_balance @swish = swish @twint = twint @type = type @us_bank_account = us_bank_account @wechat_pay = wechat_pay @zip = zip end |
Instance Attribute Details
#acss_debit ⇒ Object
If this is an ‘acss_debit` PaymentMethod, this hash contains details about the ACSS Debit payment method.
4823 4824 4825 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4823 def acss_debit @acss_debit end |
#affirm ⇒ Object
If this is an ‘affirm` PaymentMethod, this hash contains details about the Affirm payment method.
4825 4826 4827 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4825 def affirm @affirm end |
#afterpay_clearpay ⇒ Object
If this is an ‘AfterpayClearpay` PaymentMethod, this hash contains details about the AfterpayClearpay payment method.
4827 4828 4829 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4827 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
If this is an ‘Alipay` PaymentMethod, this hash contains details about the Alipay payment method.
4829 4830 4831 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4829 def alipay @alipay end |
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.
4831 4832 4833 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4831 def allow_redisplay @allow_redisplay end |
#alma ⇒ Object
If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.
4833 4834 4835 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4833 def alma @alma end |
#amazon_pay ⇒ Object
If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.
4835 4836 4837 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4835 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object
If this is an ‘au_becs_debit` PaymentMethod, this hash contains details about the bank account.
4837 4838 4839 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4837 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.
4839 4840 4841 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4839 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object
If this is a ‘bancontact` PaymentMethod, this hash contains details about the Bancontact payment method.
4841 4842 4843 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4841 def bancontact @bancontact end |
#billie ⇒ Object
If this is a ‘billie` PaymentMethod, this hash contains details about the Billie payment method.
4843 4844 4845 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4843 def billie @billie end |
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
4845 4846 4847 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4845 def billing_details @billing_details end |
#blik ⇒ Object
If this is a ‘blik` PaymentMethod, this hash contains details about the BLIK payment method.
4847 4848 4849 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4847 def blik @blik end |
#boleto ⇒ Object
If this is a ‘boleto` PaymentMethod, this hash contains details about the Boleto payment method.
4849 4850 4851 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4849 def boleto @boleto end |
#cashapp ⇒ Object
If this is a ‘cashapp` PaymentMethod, this hash contains details about the Cash App Pay payment method.
4851 4852 4853 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4851 def cashapp @cashapp end |
#crypto ⇒ Object
If this is a Crypto PaymentMethod, this hash contains details about the Crypto payment method.
4853 4854 4855 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4853 def crypto @crypto end |
#customer_balance ⇒ Object
If this is a ‘customer_balance` PaymentMethod, this hash contains details about the CustomerBalance payment method.
4855 4856 4857 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4855 def customer_balance @customer_balance end |
#eps ⇒ Object
If this is an ‘eps` PaymentMethod, this hash contains details about the EPS payment method.
4857 4858 4859 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4857 def eps @eps end |
#fpx ⇒ Object
If this is an ‘fpx` PaymentMethod, this hash contains details about the FPX payment method.
4859 4860 4861 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4859 def fpx @fpx end |
#giropay ⇒ Object
If this is a ‘giropay` PaymentMethod, this hash contains details about the Giropay payment method.
4861 4862 4863 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4861 def giropay @giropay end |
#gopay ⇒ Object
If this is a Gopay PaymentMethod, this hash contains details about the Gopay payment method.
4863 4864 4865 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4863 def gopay @gopay end |
#grabpay ⇒ Object
If this is a ‘grabpay` PaymentMethod, this hash contains details about the GrabPay payment method.
4865 4866 4867 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4865 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object
If this is an ‘IdBankTransfer` PaymentMethod, this hash contains details about the IdBankTransfer payment method.
4867 4868 4869 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4867 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object
If this is an ‘ideal` PaymentMethod, this hash contains details about the iDEAL payment method.
4869 4870 4871 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4869 def ideal @ideal end |
#interac_present ⇒ Object
If this is an ‘interac_present` PaymentMethod, this hash contains details about the Interac Present payment method.
4871 4872 4873 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4871 def interac_present @interac_present end |
#kakao_pay ⇒ Object
If this is a ‘kakao_pay` PaymentMethod, this hash contains details about the Kakao Pay payment method.
4873 4874 4875 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4873 def kakao_pay @kakao_pay end |
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method.
4875 4876 4877 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4875 def klarna @klarna end |
#konbini ⇒ Object
If this is a ‘konbini` PaymentMethod, this hash contains details about the Konbini payment method.
4877 4878 4879 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4877 def konbini @konbini end |
#kr_card ⇒ Object
If this is a ‘kr_card` PaymentMethod, this hash contains details about the Korean Card payment method.
4879 4880 4881 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4879 def kr_card @kr_card end |
#link ⇒ Object
If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.
4881 4882 4883 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4881 def link @link end |
#mb_way ⇒ Object
If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.
4883 4884 4885 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4883 def mb_way @mb_way end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
4885 4886 4887 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4885 def @metadata end |
#mobilepay ⇒ Object
If this is a ‘mobilepay` PaymentMethod, this hash contains details about the MobilePay payment method.
4887 4888 4889 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4887 def mobilepay @mobilepay end |
#multibanco ⇒ Object
If this is a ‘multibanco` PaymentMethod, this hash contains details about the Multibanco payment method.
4889 4890 4891 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4889 def multibanco @multibanco end |
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.
4891 4892 4893 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4891 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object
If this is an nz_bank_account PaymentMethod, this hash contains details about the nz_bank_account payment method.
4893 4894 4895 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4893 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object
If this is an ‘oxxo` PaymentMethod, this hash contains details about the OXXO payment method.
4895 4896 4897 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4895 def oxxo @oxxo end |
#p24 ⇒ Object
If this is a ‘p24` PaymentMethod, this hash contains details about the P24 payment method.
4897 4898 4899 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4897 def p24 @p24 end |
#pay_by_bank ⇒ Object
If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.
4899 4900 4901 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4899 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object
If this is a ‘payco` PaymentMethod, this hash contains details about the PAYCO payment method.
4901 4902 4903 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4901 def payco @payco end |
#paynow ⇒ Object
If this is a ‘paynow` PaymentMethod, this hash contains details about the PayNow payment method.
4903 4904 4905 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4903 def paynow @paynow end |
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this hash contains details about the PayPal payment method.
4905 4906 4907 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4905 def paypal @paypal end |
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.
4907 4908 4909 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4907 def payto @payto end |
#pix ⇒ Object
If this is a ‘pix` PaymentMethod, this hash contains details about the Pix payment method.
4909 4910 4911 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4909 def pix @pix end |
#promptpay ⇒ Object
If this is a ‘promptpay` PaymentMethod, this hash contains details about the PromptPay payment method.
4911 4912 4913 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4911 def promptpay @promptpay end |
#qris ⇒ Object
If this is a ‘qris` PaymentMethod, this hash contains details about the QRIS payment method.
4913 4914 4915 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4913 def qris @qris end |
#radar_options ⇒ Object
Options to configure Radar. See [Radar Session](stripe.com/docs/radar/radar-session) for more information.
4915 4916 4917 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4915 def @radar_options end |
#rechnung ⇒ Object
If this is a ‘rechnung` PaymentMethod, this hash contains details about the Rechnung payment method.
4917 4918 4919 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4917 def rechnung @rechnung end |
#revolut_pay ⇒ Object
If this is a ‘revolut_pay` PaymentMethod, this hash contains details about the Revolut Pay payment method.
4919 4920 4921 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4919 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object
If this is a ‘samsung_pay` PaymentMethod, this hash contains details about the SamsungPay payment method.
4921 4922 4923 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4921 def samsung_pay @samsung_pay end |
#satispay ⇒ Object
If this is a ‘satispay` PaymentMethod, this hash contains details about the Satispay payment method.
4923 4924 4925 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4923 def satispay @satispay end |
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` PaymentMethod, this hash contains details about the SEPA debit bank account.
4925 4926 4927 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4925 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object
If this is a Shopeepay PaymentMethod, this hash contains details about the Shopeepay payment method.
4927 4928 4929 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4927 def shopeepay @shopeepay end |
#sofort ⇒ Object
If this is a ‘sofort` PaymentMethod, this hash contains details about the SOFORT payment method.
4929 4930 4931 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4929 def sofort @sofort end |
#stripe_balance ⇒ Object
This hash contains details about the Stripe balance payment method.
4931 4932 4933 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4931 def stripe_balance @stripe_balance end |
#swish ⇒ Object
If this is a ‘swish` PaymentMethod, this hash contains details about the Swish payment method.
4933 4934 4935 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4933 def swish @swish end |
#twint ⇒ Object
If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.
4935 4936 4937 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4935 def twint @twint end |
#type ⇒ Object
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
4937 4938 4939 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4937 def type @type end |
#us_bank_account ⇒ Object
If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.
4939 4940 4941 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4939 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
If this is an ‘wechat_pay` PaymentMethod, this hash contains details about the wechat_pay payment method.
4941 4942 4943 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4941 def wechat_pay @wechat_pay end |
#zip ⇒ Object
If this is a ‘zip` PaymentMethod, this hash contains details about the Zip payment method.
4943 4944 4945 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4943 def zip @zip end |