Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
5034 5035 5036 5037 5038 5039 5040 5041 5042 5043 5044 5045 5046 5047 5048 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5034 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
5022 5023 5024 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5022 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
5024 5025 5026 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5024 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
5026 5027 5028 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5026 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
5028 5029 5030 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5028 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
5030 5031 5032 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5030 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
5032 5033 5034 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5032 def suffix @suffix end |