Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



4980
4981
4982
4983
4984
4985
4986
4987
4988
4989
4990
4991
4992
4993
4994
# File 'lib/stripe/services/payment_intent_service.rb', line 4980

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



4968
4969
4970
# File 'lib/stripe/services/payment_intent_service.rb', line 4968

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



4970
4971
4972
# File 'lib/stripe/services/payment_intent_service.rb', line 4970

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



4972
4973
4974
# File 'lib/stripe/services/payment_intent_service.rb', line 4972

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



4974
4975
4976
# File 'lib/stripe/services/payment_intent_service.rb', line 4974

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



4976
4977
4978
# File 'lib/stripe/services/payment_intent_service.rb', line 4976

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



4978
4979
4980
# File 'lib/stripe/services/payment_intent_service.rb', line 4978

def suffix
  @suffix
end