Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4980 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
4968 4969 4970 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4968 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
4970 4971 4972 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4970 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
4972 4973 4974 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4972 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
4974 4975 4976 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4974 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
4976 4977 4978 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4976 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
4978 4979 4980 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4978 def suffix @suffix end |