Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
4670 4671 4672 4673 4674 4675 4676 4677 4678 4679 4680 4681 4682 4683 4684 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4670 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
4658 4659 4660 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4658 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
4660 4661 4662 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4660 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
4662 4663 4664 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4662 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
4664 4665 4666 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4664 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
4666 4667 4668 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4666 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
4668 4669 4670 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4668 def suffix @suffix end |