Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



4567
4568
4569
4570
4571
4572
4573
4574
4575
4576
4577
4578
4579
4580
4581
# File 'lib/stripe/services/payment_intent_service.rb', line 4567

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



4555
4556
4557
# File 'lib/stripe/services/payment_intent_service.rb', line 4555

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



4557
4558
4559
# File 'lib/stripe/services/payment_intent_service.rb', line 4557

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



4559
4560
4561
# File 'lib/stripe/services/payment_intent_service.rb', line 4559

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



4561
4562
4563
# File 'lib/stripe/services/payment_intent_service.rb', line 4561

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



4563
4564
4565
# File 'lib/stripe/services/payment_intent_service.rb', line 4563

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



4565
4566
4567
# File 'lib/stripe/services/payment_intent_service.rb', line 4565

def suffix
  @suffix
end