Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
# File 'lib/stripe/services/payment_intent_service.rb', line 2605

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



2593
2594
2595
# File 'lib/stripe/services/payment_intent_service.rb', line 2593

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



2595
2596
2597
# File 'lib/stripe/services/payment_intent_service.rb', line 2595

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



2597
2598
2599
# File 'lib/stripe/services/payment_intent_service.rb', line 2597

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



2599
2600
2601
# File 'lib/stripe/services/payment_intent_service.rb', line 2599

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



2601
2602
2603
# File 'lib/stripe/services/payment_intent_service.rb', line 2601

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



2603
2604
2605
# File 'lib/stripe/services/payment_intent_service.rb', line 2603

def suffix
  @suffix
end