Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2605 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
2593 2594 2595 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2593 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
2595 2596 2597 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2595 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
2597 2598 2599 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2597 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
2599 2600 2601 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2599 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
2601 2602 2603 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2601 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
2603 2604 2605 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2603 def suffix @suffix end |