Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



2674
2675
2676
2677
2678
2679
2680
2681
2682
2683
2684
2685
2686
2687
2688
# File 'lib/stripe/services/payment_intent_service.rb', line 2674

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



2662
2663
2664
# File 'lib/stripe/services/payment_intent_service.rb', line 2662

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



2664
2665
2666
# File 'lib/stripe/services/payment_intent_service.rb', line 2664

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



2666
2667
2668
# File 'lib/stripe/services/payment_intent_service.rb', line 2666

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



2668
2669
2670
# File 'lib/stripe/services/payment_intent_service.rb', line 2668

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



2670
2671
2672
# File 'lib/stripe/services/payment_intent_service.rb', line 2670

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



2672
2673
2674
# File 'lib/stripe/services/payment_intent_service.rb', line 2672

def suffix
  @suffix
end