Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
4579 4580 4581 4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4579 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
4567 4568 4569 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4567 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
4569 4570 4571 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4569 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
4571 4572 4573 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4571 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
4573 4574 4575 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4573 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
4575 4576 4577 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4575 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
4577 4578 4579 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4577 def suffix @suffix end |