Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
2651 2652 2653 2654 2655 2656 2657 2658 2659 2660 2661 2662 2663 2664 2665 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2651 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
2639 2640 2641 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2639 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
2641 2642 2643 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2641 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
2643 2644 2645 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2643 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
2645 2646 2647 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2645 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
2647 2648 2649 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2647 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
2649 2650 2651 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2649 def suffix @suffix end |