Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
4560
# File 'lib/stripe/services/payment_intent_service.rb', line 4546

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



4534
4535
4536
# File 'lib/stripe/services/payment_intent_service.rb', line 4534

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



4536
4537
4538
# File 'lib/stripe/services/payment_intent_service.rb', line 4536

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



4538
4539
4540
# File 'lib/stripe/services/payment_intent_service.rb', line 4538

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



4540
4541
4542
# File 'lib/stripe/services/payment_intent_service.rb', line 4540

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



4542
4543
4544
# File 'lib/stripe/services/payment_intent_service.rb', line 4542

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



4544
4545
4546
# File 'lib/stripe/services/payment_intent_service.rb', line 4544

def suffix
  @suffix
end