Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



2651
2652
2653
2654
2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
2665
# File 'lib/stripe/services/payment_intent_service.rb', line 2651

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



2639
2640
2641
# File 'lib/stripe/services/payment_intent_service.rb', line 2639

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



2641
2642
2643
# File 'lib/stripe/services/payment_intent_service.rb', line 2641

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



2643
2644
2645
# File 'lib/stripe/services/payment_intent_service.rb', line 2643

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



2645
2646
2647
# File 'lib/stripe/services/payment_intent_service.rb', line 2645

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



2647
2648
2649
# File 'lib/stripe/services/payment_intent_service.rb', line 2647

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



2649
2650
2651
# File 'lib/stripe/services/payment_intent_service.rb', line 2649

def suffix
  @suffix
end