Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
2789 2790 2791 2792 2793 2794 2795 2796 2797 2798 2799 2800 2801 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2789 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
2779 2780 2781 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2779 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
2781 2782 2783 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2781 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
2783 2784 2785 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2783 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
2785 2786 2787 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2785 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
2787 2788 2789 |
# File 'lib/stripe/services/payment_intent_service.rb', line 2787 def routing_number @routing_number end |