Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4736 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
4726 4727 4728 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4726 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
4728 4729 4730 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4728 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
4730 4731 4732 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4730 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
4732 4733 4734 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4732 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
4734 4735 4736 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4734 def routing_number @routing_number end |