Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
4506 4507 4508 4509 4510 4511 4512 4513 4514 4515 4516 4517 4518 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4506 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
4496 4497 4498 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4496 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
4498 4499 4500 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4498 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
4500 4501 4502 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4500 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
4502 4503 4504 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4502 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
4504 4505 4506 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4504 def routing_number @routing_number end |