Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4468 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
4458 4459 4460 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4458 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
4460 4461 4462 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4460 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
4462 4463 4464 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4462 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
4464 4465 4466 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4464 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
4466 4467 4468 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4466 def routing_number @routing_number end |