Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5004 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
4990 4991 4992 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4990 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
4993 4994 4995 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4993 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
4996 4997 4998 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4996 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
4999 5000 5001 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4999 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
5002 5003 5004 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5002 def routing_number @routing_number end |