Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, StripeBalance, Swish, Twint, UsBankAccount, WechatPay, Zip
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If this is a ‘acss_debit` PaymentMethod, this sub-hash contains details about the ACSS Debit payment method options.
-
#affirm ⇒ Object
If this is an ‘affirm` PaymentMethod, this sub-hash contains details about the Affirm payment method options.
-
#afterpay_clearpay ⇒ Object
If this is a ‘afterpay_clearpay` PaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options.
-
#alipay ⇒ Object
If this is a ‘alipay` PaymentMethod, this sub-hash contains details about the Alipay payment method options.
-
#alma ⇒ Object
If this is a ‘alma` PaymentMethod, this sub-hash contains details about the Alma payment method options.
-
#amazon_pay ⇒ Object
If this is a ‘amazon_pay` PaymentMethod, this sub-hash contains details about the Amazon Pay payment method options.
-
#au_becs_debit ⇒ Object
If this is a ‘au_becs_debit` PaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options.
-
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` PaymentMethod, this sub-hash contains details about the BACS Debit payment method options.
-
#bancontact ⇒ Object
If this is a ‘bancontact` PaymentMethod, this sub-hash contains details about the Bancontact payment method options.
-
#billie ⇒ Object
If this is a ‘billie` PaymentMethod, this sub-hash contains details about the Billie payment method options.
-
#blik ⇒ Object
If this is a ‘blik` PaymentMethod, this sub-hash contains details about the BLIK payment method options.
-
#boleto ⇒ Object
If this is a ‘boleto` PaymentMethod, this sub-hash contains details about the Boleto payment method options.
-
#card ⇒ Object
Configuration for any card payments attempted on this PaymentIntent.
-
#card_present ⇒ Object
If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.
-
#cashapp ⇒ Object
If this is a ‘cashapp` PaymentMethod, this sub-hash contains details about the Cash App Pay payment method options.
-
#crypto ⇒ Object
If this is a ‘crypto` PaymentMethod, this sub-hash contains details about the Crypto payment method options.
-
#customer_balance ⇒ Object
If this is a ‘customer balance` PaymentMethod, this sub-hash contains details about the customer balance payment method options.
-
#eps ⇒ Object
If this is a ‘eps` PaymentMethod, this sub-hash contains details about the EPS payment method options.
-
#fpx ⇒ Object
If this is a ‘fpx` PaymentMethod, this sub-hash contains details about the FPX payment method options.
-
#giropay ⇒ Object
If this is a ‘giropay` PaymentMethod, this sub-hash contains details about the Giropay payment method options.
-
#gopay ⇒ Object
If this is a ‘gopay` PaymentMethod, this sub-hash contains details about the Gopay payment method options.
-
#grabpay ⇒ Object
If this is a ‘grabpay` PaymentMethod, this sub-hash contains details about the Grabpay payment method options.
-
#id_bank_transfer ⇒ Object
If this is a ‘id_bank_transfer` PaymentMethod, this sub-hash contains details about the Indonesia Bank Transfer payment method options.
-
#ideal ⇒ Object
If this is a ‘ideal` PaymentMethod, this sub-hash contains details about the Ideal payment method options.
-
#interac_present ⇒ Object
If this is a ‘interac_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.
-
#kakao_pay ⇒ Object
If this is a ‘kakao_pay` PaymentMethod, this sub-hash contains details about the Kakao Pay payment method options.
-
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this sub-hash contains details about the Klarna payment method options.
-
#konbini ⇒ Object
If this is a ‘konbini` PaymentMethod, this sub-hash contains details about the Konbini payment method options.
-
#kr_card ⇒ Object
If this is a ‘kr_card` PaymentMethod, this sub-hash contains details about the KR Card payment method options.
-
#link ⇒ Object
If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options.
-
#mb_way ⇒ Object
If this is a ‘mb_way` PaymentMethod, this sub-hash contains details about the MB WAY payment method options.
-
#mobilepay ⇒ Object
If this is a ‘MobilePay` PaymentMethod, this sub-hash contains details about the MobilePay payment method options.
-
#multibanco ⇒ Object
If this is a ‘multibanco` PaymentMethod, this sub-hash contains details about the Multibanco payment method options.
-
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this sub-hash contains details about the Naver Pay payment method options.
-
#nz_bank_account ⇒ Object
If this is a ‘nz_bank_account` PaymentMethod, this sub-hash contains details about the NZ BECS Direct Debit payment method options.
-
#oxxo ⇒ Object
If this is a ‘oxxo` PaymentMethod, this sub-hash contains details about the OXXO payment method options.
-
#p24 ⇒ Object
If this is a ‘p24` PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options.
-
#pay_by_bank ⇒ Object
If this is a ‘pay_by_bank` PaymentMethod, this sub-hash contains details about the PayByBank payment method options.
-
#payco ⇒ Object
If this is a ‘payco` PaymentMethod, this sub-hash contains details about the PAYCO payment method options.
-
#paynow ⇒ Object
If this is a ‘paynow` PaymentMethod, this sub-hash contains details about the PayNow payment method options.
-
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.
-
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this sub-hash contains details about the PayTo payment method options.
-
#pix ⇒ Object
If this is a ‘pix` PaymentMethod, this sub-hash contains details about the Pix payment method options.
-
#promptpay ⇒ Object
If this is a ‘promptpay` PaymentMethod, this sub-hash contains details about the PromptPay payment method options.
-
#qris ⇒ Object
If this is a ‘qris` PaymentMethod, this sub-hash contains details about the QRIS payment method options.
-
#rechnung ⇒ Object
If this is a ‘rechnung` PaymentMethod, this sub-hash contains details about the Rechnung payment method options.
-
#revolut_pay ⇒ Object
If this is a ‘revolut_pay` PaymentMethod, this sub-hash contains details about the Revolut Pay payment method options.
-
#samsung_pay ⇒ Object
If this is a ‘samsung_pay` PaymentMethod, this sub-hash contains details about the Samsung Pay payment method options.
-
#satispay ⇒ Object
If this is a ‘satispay` PaymentMethod, this sub-hash contains details about the Satispay payment method options.
-
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` PaymentIntent, this sub-hash contains details about the SEPA Debit payment method options.
-
#shopeepay ⇒ Object
If this is a ‘shopeepay` PaymentMethod, this sub-hash contains details about the ShopeePay payment method options.
-
#sofort ⇒ Object
If this is a ‘sofort` PaymentMethod, this sub-hash contains details about the SOFORT payment method options.
-
#stripe_balance ⇒ Object
If this is a ‘stripe_balance` PaymentMethod, this sub-hash contains details about the Stripe Balance payment method options.
-
#swish ⇒ Object
If this is a ‘Swish` PaymentMethod, this sub-hash contains details about the Swish payment method options.
-
#twint ⇒ Object
If this is a ‘twint` PaymentMethod, this sub-hash contains details about the TWINT payment method options.
-
#us_bank_account ⇒ Object
If this is a ‘us_bank_account` PaymentMethod, this sub-hash contains details about the US bank account payment method options.
-
#wechat_pay ⇒ Object
If this is a ‘wechat_pay` PaymentMethod, this sub-hash contains details about the WeChat Pay payment method options.
-
#zip ⇒ Object
If this is a ‘zip` PaymentMethod, this sub-hash contains details about the Zip payment method options.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, blik: nil, boleto: nil, card: nil, card_present: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
7323 7324 7325 7326 7327 7328 7329 7330 7331 7332 7333 7334 7335 7336 7337 7338 7339 7340 7341 7342 7343 7344 7345 7346 7347 7348 7349 7350 7351 7352 7353 7354 7355 7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 7397 7398 7399 7400 7401 7402 7403 7404 7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 7420 7421 7422 7423 7424 7425 7426 7427 7428 7429 7430 7431 7432 7433 7434 7435 7436 7437 7438 7439 7440 7441 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7323 def initialize( acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, blik: nil, boleto: nil, card: nil, card_present: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil ) @acss_debit = acss_debit @affirm = affirm @afterpay_clearpay = afterpay_clearpay @alipay = alipay @alma = alma @amazon_pay = amazon_pay @au_becs_debit = au_becs_debit @bacs_debit = bacs_debit @bancontact = bancontact @billie = billie @blik = blik @boleto = boleto @card = card @card_present = card_present @cashapp = cashapp @crypto = crypto @customer_balance = customer_balance @eps = eps @fpx = fpx @giropay = giropay @gopay = gopay @grabpay = grabpay @id_bank_transfer = id_bank_transfer @ideal = ideal @interac_present = interac_present @kakao_pay = kakao_pay @klarna = klarna @konbini = konbini @kr_card = kr_card @link = link @mb_way = mb_way @mobilepay = mobilepay @multibanco = multibanco @naver_pay = naver_pay @nz_bank_account = nz_bank_account @oxxo = oxxo @p24 = p24 @pay_by_bank = pay_by_bank @payco = payco @paynow = paynow @paypal = paypal @payto = payto @pix = pix @promptpay = promptpay @qris = qris @rechnung = rechnung @revolut_pay = revolut_pay @samsung_pay = samsung_pay @satispay = satispay @sepa_debit = sepa_debit @shopeepay = shopeepay @sofort = sofort @stripe_balance = stripe_balance @swish = swish @twint = twint @us_bank_account = us_bank_account @wechat_pay = wechat_pay @zip = zip end |
Instance Attribute Details
#acss_debit ⇒ Object
If this is a ‘acss_debit` PaymentMethod, this sub-hash contains details about the ACSS Debit payment method options.
7207 7208 7209 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7207 def acss_debit @acss_debit end |
#affirm ⇒ Object
If this is an ‘affirm` PaymentMethod, this sub-hash contains details about the Affirm payment method options.
7209 7210 7211 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7209 def affirm @affirm end |
#afterpay_clearpay ⇒ Object
If this is a ‘afterpay_clearpay` PaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options.
7211 7212 7213 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7211 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
If this is a ‘alipay` PaymentMethod, this sub-hash contains details about the Alipay payment method options.
7213 7214 7215 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7213 def alipay @alipay end |
#alma ⇒ Object
If this is a ‘alma` PaymentMethod, this sub-hash contains details about the Alma payment method options.
7215 7216 7217 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7215 def alma @alma end |
#amazon_pay ⇒ Object
If this is a ‘amazon_pay` PaymentMethod, this sub-hash contains details about the Amazon Pay payment method options.
7217 7218 7219 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7217 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object
If this is a ‘au_becs_debit` PaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options.
7219 7220 7221 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7219 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` PaymentMethod, this sub-hash contains details about the BACS Debit payment method options.
7221 7222 7223 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7221 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object
If this is a ‘bancontact` PaymentMethod, this sub-hash contains details about the Bancontact payment method options.
7223 7224 7225 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7223 def bancontact @bancontact end |
#billie ⇒ Object
If this is a ‘billie` PaymentMethod, this sub-hash contains details about the Billie payment method options.
7225 7226 7227 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7225 def billie @billie end |
#blik ⇒ Object
If this is a ‘blik` PaymentMethod, this sub-hash contains details about the BLIK payment method options.
7227 7228 7229 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7227 def blik @blik end |
#boleto ⇒ Object
If this is a ‘boleto` PaymentMethod, this sub-hash contains details about the Boleto payment method options.
7229 7230 7231 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7229 def boleto @boleto end |
#card ⇒ Object
Configuration for any card payments attempted on this PaymentIntent.
7231 7232 7233 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7231 def card @card end |
#card_present ⇒ Object
If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.
7233 7234 7235 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7233 def card_present @card_present end |
#cashapp ⇒ Object
If this is a ‘cashapp` PaymentMethod, this sub-hash contains details about the Cash App Pay payment method options.
7235 7236 7237 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7235 def cashapp @cashapp end |
#crypto ⇒ Object
If this is a ‘crypto` PaymentMethod, this sub-hash contains details about the Crypto payment method options.
7237 7238 7239 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7237 def crypto @crypto end |
#customer_balance ⇒ Object
If this is a ‘customer balance` PaymentMethod, this sub-hash contains details about the customer balance payment method options.
7239 7240 7241 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7239 def customer_balance @customer_balance end |
#eps ⇒ Object
If this is a ‘eps` PaymentMethod, this sub-hash contains details about the EPS payment method options.
7241 7242 7243 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7241 def eps @eps end |
#fpx ⇒ Object
If this is a ‘fpx` PaymentMethod, this sub-hash contains details about the FPX payment method options.
7243 7244 7245 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7243 def fpx @fpx end |
#giropay ⇒ Object
If this is a ‘giropay` PaymentMethod, this sub-hash contains details about the Giropay payment method options.
7245 7246 7247 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7245 def giropay @giropay end |
#gopay ⇒ Object
If this is a ‘gopay` PaymentMethod, this sub-hash contains details about the Gopay payment method options.
7247 7248 7249 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7247 def gopay @gopay end |
#grabpay ⇒ Object
If this is a ‘grabpay` PaymentMethod, this sub-hash contains details about the Grabpay payment method options.
7249 7250 7251 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7249 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object
If this is a ‘id_bank_transfer` PaymentMethod, this sub-hash contains details about the Indonesia Bank Transfer payment method options.
7251 7252 7253 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7251 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object
If this is a ‘ideal` PaymentMethod, this sub-hash contains details about the Ideal payment method options.
7253 7254 7255 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7253 def ideal @ideal end |
#interac_present ⇒ Object
If this is a ‘interac_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.
7255 7256 7257 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7255 def interac_present @interac_present end |
#kakao_pay ⇒ Object
If this is a ‘kakao_pay` PaymentMethod, this sub-hash contains details about the Kakao Pay payment method options.
7257 7258 7259 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7257 def kakao_pay @kakao_pay end |
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this sub-hash contains details about the Klarna payment method options.
7259 7260 7261 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7259 def klarna @klarna end |
#konbini ⇒ Object
If this is a ‘konbini` PaymentMethod, this sub-hash contains details about the Konbini payment method options.
7261 7262 7263 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7261 def konbini @konbini end |
#kr_card ⇒ Object
If this is a ‘kr_card` PaymentMethod, this sub-hash contains details about the KR Card payment method options.
7263 7264 7265 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7263 def kr_card @kr_card end |
#link ⇒ Object
If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options.
7265 7266 7267 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7265 def link @link end |
#mb_way ⇒ Object
If this is a ‘mb_way` PaymentMethod, this sub-hash contains details about the MB WAY payment method options.
7267 7268 7269 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7267 def mb_way @mb_way end |
#mobilepay ⇒ Object
If this is a ‘MobilePay` PaymentMethod, this sub-hash contains details about the MobilePay payment method options.
7269 7270 7271 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7269 def mobilepay @mobilepay end |
#multibanco ⇒ Object
If this is a ‘multibanco` PaymentMethod, this sub-hash contains details about the Multibanco payment method options.
7271 7272 7273 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7271 def multibanco @multibanco end |
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this sub-hash contains details about the Naver Pay payment method options.
7273 7274 7275 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7273 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object
If this is a ‘nz_bank_account` PaymentMethod, this sub-hash contains details about the NZ BECS Direct Debit payment method options.
7275 7276 7277 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7275 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object
If this is a ‘oxxo` PaymentMethod, this sub-hash contains details about the OXXO payment method options.
7277 7278 7279 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7277 def oxxo @oxxo end |
#p24 ⇒ Object
If this is a ‘p24` PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options.
7279 7280 7281 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7279 def p24 @p24 end |
#pay_by_bank ⇒ Object
If this is a ‘pay_by_bank` PaymentMethod, this sub-hash contains details about the PayByBank payment method options.
7281 7282 7283 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7281 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object
If this is a ‘payco` PaymentMethod, this sub-hash contains details about the PAYCO payment method options.
7283 7284 7285 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7283 def payco @payco end |
#paynow ⇒ Object
If this is a ‘paynow` PaymentMethod, this sub-hash contains details about the PayNow payment method options.
7285 7286 7287 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7285 def paynow @paynow end |
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.
7287 7288 7289 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7287 def paypal @paypal end |
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this sub-hash contains details about the PayTo payment method options.
7289 7290 7291 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7289 def payto @payto end |
#pix ⇒ Object
If this is a ‘pix` PaymentMethod, this sub-hash contains details about the Pix payment method options.
7291 7292 7293 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7291 def pix @pix end |
#promptpay ⇒ Object
If this is a ‘promptpay` PaymentMethod, this sub-hash contains details about the PromptPay payment method options.
7293 7294 7295 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7293 def promptpay @promptpay end |
#qris ⇒ Object
If this is a ‘qris` PaymentMethod, this sub-hash contains details about the QRIS payment method options.
7295 7296 7297 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7295 def qris @qris end |
#rechnung ⇒ Object
If this is a ‘rechnung` PaymentMethod, this sub-hash contains details about the Rechnung payment method options.
7297 7298 7299 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7297 def rechnung @rechnung end |
#revolut_pay ⇒ Object
If this is a ‘revolut_pay` PaymentMethod, this sub-hash contains details about the Revolut Pay payment method options.
7299 7300 7301 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7299 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object
If this is a ‘samsung_pay` PaymentMethod, this sub-hash contains details about the Samsung Pay payment method options.
7301 7302 7303 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7301 def samsung_pay @samsung_pay end |
#satispay ⇒ Object
If this is a ‘satispay` PaymentMethod, this sub-hash contains details about the Satispay payment method options.
7303 7304 7305 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7303 def satispay @satispay end |
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` PaymentIntent, this sub-hash contains details about the SEPA Debit payment method options.
7305 7306 7307 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7305 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object
If this is a ‘shopeepay` PaymentMethod, this sub-hash contains details about the ShopeePay payment method options.
7307 7308 7309 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7307 def shopeepay @shopeepay end |
#sofort ⇒ Object
If this is a ‘sofort` PaymentMethod, this sub-hash contains details about the SOFORT payment method options.
7309 7310 7311 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7309 def sofort @sofort end |
#stripe_balance ⇒ Object
If this is a ‘stripe_balance` PaymentMethod, this sub-hash contains details about the Stripe Balance payment method options.
7311 7312 7313 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7311 def stripe_balance @stripe_balance end |
#swish ⇒ Object
If this is a ‘Swish` PaymentMethod, this sub-hash contains details about the Swish payment method options.
7313 7314 7315 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7313 def swish @swish end |
#twint ⇒ Object
If this is a ‘twint` PaymentMethod, this sub-hash contains details about the TWINT payment method options.
7315 7316 7317 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7315 def twint @twint end |
#us_bank_account ⇒ Object
If this is a ‘us_bank_account` PaymentMethod, this sub-hash contains details about the US bank account payment method options.
7317 7318 7319 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7317 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
If this is a ‘wechat_pay` PaymentMethod, this sub-hash contains details about the WeChat Pay payment method options.
7319 7320 7321 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7319 def wechat_pay @wechat_pay end |
#zip ⇒ Object
If this is a ‘zip` PaymentMethod, this sub-hash contains details about the Zip payment method options.
7321 7322 7323 |
# File 'lib/stripe/services/payment_intent_service.rb', line 7321 def zip @zip end |