Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Installments, MandateOptions, StatementDetails, ThreeDSecure
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
-
#cvc_token ⇒ Object
A single-use ‘cvc_update` Token that represents a card CVC value.
-
#installments ⇒ Object
Installment configuration for payments attempted on this PaymentIntent.
-
#mandate_options ⇒ Object
Configuration options for setting up an eMandate for cards issued in India.
-
#moto ⇒ Object
When specified, this parameter indicates that a transaction will be marked as MOTO (Mail Order Telephone Order) and thus out of scope for SCA.
-
#network ⇒ Object
Selected network to process this PaymentIntent on.
-
#request_decremental_authorization ⇒ Object
Request ability to [decrement the authorization](stripe.com/docs/payments/decremental-authorization) for this PaymentIntent.
-
#request_extended_authorization ⇒ Object
Request ability to [capture beyond the standard authorization validity window](stripe.com/docs/payments/extended-authorization) for this PaymentIntent.
-
#request_incremental_authorization ⇒ Object
Request ability to [increment the authorization](stripe.com/docs/payments/incremental-authorization) for this PaymentIntent.
-
#request_multicapture ⇒ Object
Request ability to make [multiple captures](stripe.com/docs/payments/multicapture) for this PaymentIntent.
-
#request_overcapture ⇒ Object
Request ability to [overcapture](stripe.com/docs/payments/overcapture) for this PaymentIntent.
-
#request_partial_authorization ⇒ Object
Request partial authorization on this PaymentIntent.
-
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication).
-
#require_cvc_recollection ⇒ Object
When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#statement_descriptor_suffix_kana ⇒ Object
Provides information about a card payment that customers see on their statements.
-
#statement_descriptor_suffix_kanji ⇒ Object
Provides information about a card payment that customers see on their statements.
-
#statement_details ⇒ Object
Statement details for this payment intent.
-
#three_d_secure ⇒ Object
If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this payment.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(capture_method: nil, cvc_token: nil, installments: nil, mandate_options: nil, moto: nil, network: nil, request_decremental_authorization: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_partial_authorization: nil, request_three_d_secure: nil, require_cvc_recollection: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil, statement_details: nil, three_d_secure: nil) ⇒ Card
Returns a new instance of Card.
5915 5916 5917 5918 5919 5920 5921 5922 5923 5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 5936 5937 5938 5939 5940 5941 5942 5943 5944 5945 5946 5947 5948 5949 5950 5951 5952 5953 5954 5955 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5915 def initialize( capture_method: nil, cvc_token: nil, installments: nil, mandate_options: nil, moto: nil, network: nil, request_decremental_authorization: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_partial_authorization: nil, request_three_d_secure: nil, require_cvc_recollection: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil, statement_details: nil, three_d_secure: nil ) @capture_method = capture_method @cvc_token = cvc_token @installments = installments @mandate_options = @moto = moto @network = network @request_decremental_authorization = @request_extended_authorization = @request_incremental_authorization = @request_multicapture = request_multicapture @request_overcapture = request_overcapture @request_partial_authorization = @request_three_d_secure = request_three_d_secure @require_cvc_recollection = require_cvc_recollection @setup_future_usage = setup_future_usage @statement_descriptor_suffix_kana = statement_descriptor_suffix_kana @statement_descriptor_suffix_kanji = statement_descriptor_suffix_kanji @statement_details = statement_details @three_d_secure = three_d_secure end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.
If ‘capture_method` is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.
5864 5865 5866 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5864 def capture_method @capture_method end |
#cvc_token ⇒ Object
A single-use ‘cvc_update` Token that represents a card CVC value. When provided, the CVC value will be verified during the card payment attempt. This parameter can only be provided during confirmation.
5866 5867 5868 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5866 def cvc_token @cvc_token end |
#installments ⇒ Object
Installment configuration for payments attempted on this PaymentIntent.
For more information, see the [installments integration guide](stripe.com/docs/payments/installments).
5870 5871 5872 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5870 def installments @installments end |
#mandate_options ⇒ Object
Configuration options for setting up an eMandate for cards issued in India.
5872 5873 5874 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5872 def @mandate_options end |
#moto ⇒ Object
When specified, this parameter indicates that a transaction will be marked as MOTO (Mail Order Telephone Order) and thus out of scope for SCA. This parameter can only be provided during confirmation.
5876 5877 5878 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5876 def moto @moto end |
#network ⇒ Object
Selected network to process this PaymentIntent on. Depends on the available networks of the card attached to the PaymentIntent. Can be only set confirm-time.
5878 5879 5880 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5878 def network @network end |
#request_decremental_authorization ⇒ Object
Request ability to [decrement the authorization](stripe.com/docs/payments/decremental-authorization) for this PaymentIntent.
5880 5881 5882 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5880 def @request_decremental_authorization end |
#request_extended_authorization ⇒ Object
Request ability to [capture beyond the standard authorization validity window](stripe.com/docs/payments/extended-authorization) for this PaymentIntent.
5882 5883 5884 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5882 def @request_extended_authorization end |
#request_incremental_authorization ⇒ Object
Request ability to [increment the authorization](stripe.com/docs/payments/incremental-authorization) for this PaymentIntent.
5884 5885 5886 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5884 def @request_incremental_authorization end |
#request_multicapture ⇒ Object
Request ability to make [multiple captures](stripe.com/docs/payments/multicapture) for this PaymentIntent.
5886 5887 5888 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5886 def request_multicapture @request_multicapture end |
#request_overcapture ⇒ Object
Request ability to [overcapture](stripe.com/docs/payments/overcapture) for this PaymentIntent.
5888 5889 5890 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5888 def request_overcapture @request_overcapture end |
#request_partial_authorization ⇒ Object
Request partial authorization on this PaymentIntent.
5890 5891 5892 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5890 def @request_partial_authorization end |
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](stripe.com/docs/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.
5892 5893 5894 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5892 def request_three_d_secure @request_three_d_secure end |
#require_cvc_recollection ⇒ Object
When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).
5894 5895 5896 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5894 def require_cvc_recollection @require_cvc_recollection end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.
5904 5905 5906 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5904 def setup_future_usage @setup_future_usage end |
#statement_descriptor_suffix_kana ⇒ Object
Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.
5906 5907 5908 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5906 def statement_descriptor_suffix_kana @statement_descriptor_suffix_kana end |
#statement_descriptor_suffix_kanji ⇒ Object
Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.
5908 5909 5910 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5908 def statement_descriptor_suffix_kanji @statement_descriptor_suffix_kanji end |
#statement_details ⇒ Object
Statement details for this payment intent. You can use this to override the merchant details shown on your customers’ statements.
5910 5911 5912 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5910 def statement_details @statement_details end |
#three_d_secure ⇒ Object
If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this payment.
5913 5914 5915 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5913 def three_d_secure @three_d_secure end |