Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Card::Installments::Plan
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Card::Installments::Plan
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#count ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`.
Instance Method Summary collapse
-
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
constructor
A new instance of Plan.
Methods inherited from RequestParams
Constructor Details
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
Returns a new instance of Plan.
5041 5042 5043 5044 5045 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5041 def initialize(count: nil, interval: nil, type: nil) @count = count @interval = interval @type = type end |
Instance Attribute Details
#count ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.
5034 5035 5036 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5034 def count @count end |
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.
5037 5038 5039 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5037 def interval @interval end |
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`.
5039 5040 5041 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5039 def type @type end |