Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



5591
5592
5593
5594
5595
# File 'lib/stripe/services/payment_intent_service.rb', line 5591

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



5582
5583
5584
# File 'lib/stripe/services/payment_intent_service.rb', line 5582

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



5586
5587
5588
# File 'lib/stripe/services/payment_intent_service.rb', line 5586

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`.



5589
5590
5591
# File 'lib/stripe/services/payment_intent_service.rb', line 5589

def type
  @type
end