Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



5006
5007
5008
5009
5010
# File 'lib/stripe/services/payment_intent_service.rb', line 5006

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



4999
5000
5001
# File 'lib/stripe/services/payment_intent_service.rb', line 4999

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



5002
5003
5004
# File 'lib/stripe/services/payment_intent_service.rb', line 5002

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`.



5004
5005
5006
# File 'lib/stripe/services/payment_intent_service.rb', line 5004

def type
  @type
end