Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Card::Installments::Plan
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Card::Installments::Plan
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#count ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`.
Instance Method Summary collapse
-
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
constructor
A new instance of Plan.
Methods inherited from RequestParams
Constructor Details
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
Returns a new instance of Plan.
4985 4986 4987 4988 4989 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4985 def initialize(count: nil, interval: nil, type: nil) @count = count @interval = interval @type = type end |
Instance Attribute Details
#count ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.
4978 4979 4980 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4978 def count @count end |
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.
4981 4982 4983 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4981 def interval @interval end |
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`.
4983 4984 4985 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4983 def type @type end |