Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
# File 'lib/stripe/services/payment_intent_service.rb', line 5081

def initialize(
  amount: nil,
  amount_type: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



5063
5064
5065
# File 'lib/stripe/services/payment_intent_service.rb', line 5063

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



5065
5066
5067
# File 'lib/stripe/services/payment_intent_service.rb', line 5065

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



5067
5068
5069
# File 'lib/stripe/services/payment_intent_service.rb', line 5067

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



5069
5070
5071
# File 'lib/stripe/services/payment_intent_service.rb', line 5069

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



5071
5072
5073
# File 'lib/stripe/services/payment_intent_service.rb', line 5071

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



5073
5074
5075
# File 'lib/stripe/services/payment_intent_service.rb', line 5073

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



5075
5076
5077
# File 'lib/stripe/services/payment_intent_service.rb', line 5075

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



5077
5078
5079
# File 'lib/stripe/services/payment_intent_service.rb', line 5077

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are ‘india`.



5079
5080
5081
# File 'lib/stripe/services/payment_intent_service.rb', line 5079

def supported_types
  @supported_types
end