Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::CardPresent
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::CardPresent
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Routing
Instance Attribute Summary collapse
-
#request_extended_authorization ⇒ Object
Request ability to capture this payment beyond the standard [authorization validity window](stripe.com/docs/terminal/features/extended-authorizations#authorization-validity).
-
#request_incremental_authorization_support ⇒ Object
Request ability to [increment](stripe.com/docs/terminal/features/incremental-authorizations) this PaymentIntent if the combination of MCC and card brand is eligible.
-
#routing ⇒ Object
Network routing priority on co-branded EMV cards supporting domestic debit and international card schemes.
Instance Method Summary collapse
-
#initialize(request_extended_authorization: nil, request_incremental_authorization_support: nil, routing: nil) ⇒ CardPresent
constructor
A new instance of CardPresent.
Methods inherited from RequestParams
Constructor Details
#initialize(request_extended_authorization: nil, request_incremental_authorization_support: nil, routing: nil) ⇒ CardPresent
Returns a new instance of CardPresent.
5561 5562 5563 5564 5565 5566 5567 5568 5569 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5561 def initialize( request_extended_authorization: nil, request_incremental_authorization_support: nil, routing: nil ) @request_extended_authorization = @request_incremental_authorization_support = @routing = routing end |
Instance Attribute Details
#request_extended_authorization ⇒ Object
Request ability to capture this payment beyond the standard [authorization validity window](stripe.com/docs/terminal/features/extended-authorizations#authorization-validity)
5555 5556 5557 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5555 def @request_extended_authorization end |
#request_incremental_authorization_support ⇒ Object
Request ability to [increment](stripe.com/docs/terminal/features/incremental-authorizations) this PaymentIntent if the combination of MCC and card brand is eligible. Check [incremental_authorization_supported](stripe.com/docs/api/charges/object#charge_object-payment_method_details-card_present-incremental_authorization_supported) in the [Confirm](stripe.com/docs/api/payment_intents/confirm) response to verify support.
5557 5558 5559 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5557 def @request_incremental_authorization_support end |
#routing ⇒ Object
Network routing priority on co-branded EMV cards supporting domestic debit and international card schemes.
5559 5560 5561 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5559 def routing @routing end |