Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



5947
5948
5949
5950
# File 'lib/stripe/services/payment_intent_service.rb', line 5947

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



5943
5944
5945
# File 'lib/stripe/services/payment_intent_service.rb', line 5943

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



5945
5946
5947
# File 'lib/stripe/services/payment_intent_service.rb', line 5945

def date
  @date
end