Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



3805
3806
3807
3808
# File 'lib/stripe/services/payment_intent_service.rb', line 3805

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



3801
3802
3803
# File 'lib/stripe/services/payment_intent_service.rb', line 3801

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



3803
3804
3805
# File 'lib/stripe/services/payment_intent_service.rb', line 3803

def date
  @date
end