Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
6611 6612 6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6611 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
6595 6596 6597 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6595 def category @category end |
#description ⇒ Object
Description of the line item.
6597 6598 6599 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6597 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
6599 6600 6601 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6599 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
6601 6602 6603 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6601 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
6603 6604 6605 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6603 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
6605 6606 6607 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6605 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
6607 6608 6609 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6607 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
6609 6610 6611 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6609 def unit_amount @unit_amount end |