Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
6301 6302 6303 6304 6305 6306 6307 6308 6309 6310 6311 6312 6313 6314 6315 6316 6317 6318 6319 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6301 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
6285 6286 6287 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6285 def category @category end |
#description ⇒ Object
Description of the line item.
6287 6288 6289 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6287 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
6289 6290 6291 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6289 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
6291 6292 6293 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6291 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
6293 6294 6295 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6293 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
6295 6296 6297 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6295 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
6297 6298 6299 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6297 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
6299 6300 6301 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6299 def unit_amount @unit_amount end |