Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
6101 6102 6103 6104 6105 6106 6107 6108 6109 6110 6111 6112 6113 6114 6115 6116 6117 6118 6119 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6101 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
6085 6086 6087 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6085 def category @category end |
#description ⇒ Object
Description of the line item.
6087 6088 6089 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6087 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
6089 6090 6091 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6089 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
6091 6092 6093 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6091 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
6093 6094 6095 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6093 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
6095 6096 6097 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6095 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
6097 6098 6099 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6097 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
6099 6100 6101 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6099 def unit_amount @unit_amount end |