Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



6107
6108
6109
6110
6111
6112
6113
6114
6115
6116
6117
6118
6119
6120
6121
6122
6123
6124
6125
# File 'lib/stripe/services/payment_intent_service.rb', line 6107

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



6091
6092
6093
# File 'lib/stripe/services/payment_intent_service.rb', line 6091

def category
  @category
end

#descriptionObject

Description of the line item.



6093
6094
6095
# File 'lib/stripe/services/payment_intent_service.rb', line 6093

def description
  @description
end

#nameObject

Descriptive name of the line item.



6095
6096
6097
# File 'lib/stripe/services/payment_intent_service.rb', line 6095

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



6097
6098
6099
# File 'lib/stripe/services/payment_intent_service.rb', line 6097

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



6099
6100
6101
# File 'lib/stripe/services/payment_intent_service.rb', line 6099

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



6101
6102
6103
# File 'lib/stripe/services/payment_intent_service.rb', line 6101

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



6103
6104
6105
# File 'lib/stripe/services/payment_intent_service.rb', line 6103

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



6105
6106
6107
# File 'lib/stripe/services/payment_intent_service.rb', line 6105

def unit_amount
  @unit_amount
end