Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
6140 6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6140 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
6124 6125 6126 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6124 def category @category end |
#description ⇒ Object
Description of the line item.
6126 6127 6128 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6126 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
6128 6129 6130 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6128 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
6130 6131 6132 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6130 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
6132 6133 6134 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6132 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
6134 6135 6136 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6134 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
6136 6137 6138 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6136 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
6138 6139 6140 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6138 def unit_amount @unit_amount end |