Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
5852 5853 5854 5855 5856 5857 5858 5859 5860 5861 5862 5863 5864 5865 5866 5867 5868 5869 5870 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5852 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
5836 5837 5838 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5836 def category @category end |
#description ⇒ Object
Description of the line item.
5838 5839 5840 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5838 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
5840 5841 5842 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5840 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
5842 5843 5844 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5842 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
5844 5845 5846 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5844 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
5846 5847 5848 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5846 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
5848 5849 5850 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5848 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
5850 5851 5852 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5850 def unit_amount @unit_amount end |