Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



5817
5818
5819
5820
5821
5822
5823
5824
5825
5826
5827
5828
5829
5830
5831
5832
5833
5834
5835
# File 'lib/stripe/services/payment_intent_service.rb', line 5817

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



5801
5802
5803
# File 'lib/stripe/services/payment_intent_service.rb', line 5801

def category
  @category
end

#descriptionObject

Description of the line item.



5803
5804
5805
# File 'lib/stripe/services/payment_intent_service.rb', line 5803

def description
  @description
end

#nameObject

Descriptive name of the line item.



5805
5806
5807
# File 'lib/stripe/services/payment_intent_service.rb', line 5805

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



5807
5808
5809
# File 'lib/stripe/services/payment_intent_service.rb', line 5807

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



5809
5810
5811
# File 'lib/stripe/services/payment_intent_service.rb', line 5809

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



5811
5812
5813
# File 'lib/stripe/services/payment_intent_service.rb', line 5811

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



5813
5814
5815
# File 'lib/stripe/services/payment_intent_service.rb', line 5813

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



5815
5816
5817
# File 'lib/stripe/services/payment_intent_service.rb', line 5815

def unit_amount
  @unit_amount
end