Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
5793 5794 5795 5796 5797 5798 5799 5800 5801 5802 5803 5804 5805 5806 5807 5808 5809 5810 5811 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5793 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
5777 5778 5779 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5777 def category @category end |
#description ⇒ Object
Description of the line item.
5779 5780 5781 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5779 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
5781 5782 5783 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5781 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
5783 5784 5785 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5783 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
5785 5786 5787 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5785 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
5787 5788 5789 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5787 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
5789 5790 5791 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5789 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
5791 5792 5793 |
# File 'lib/stripe/services/payment_intent_service.rb', line 5791 def unit_amount @unit_amount end |