Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
6471 6472 6473 6474 6475 6476 6477 6478 6479 6480 6481 6482 6483 6484 6485 6486 6487 6488 6489 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6471 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
6448 6449 6450 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6448 def category @category end |
#description ⇒ Object
Description of the line item.
6451 6452 6453 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6451 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
6454 6455 6456 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6454 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
6457 6458 6459 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6457 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
6460 6461 6462 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6460 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
6463 6464 6465 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6463 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
6466 6467 6468 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6466 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
6469 6470 6471 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6469 def unit_amount @unit_amount end |