Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Paypal::LineItem::Tax
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The tax for a single unit of the line item in minor units.
-
#behavior ⇒ Object
The tax behavior for the line item.
Instance Method Summary collapse
-
#initialize(amount: nil, behavior: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, behavior: nil) ⇒ Tax
Returns a new instance of Tax.
6118 6119 6120 6121 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6118 def initialize(amount: nil, behavior: nil) @amount = amount @behavior = behavior end |
Instance Attribute Details
#amount ⇒ Object
The tax for a single unit of the line item in minor units. Cannot be a negative number.
6114 6115 6116 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6114 def amount @amount end |
#behavior ⇒ Object
The tax behavior for the line item.
6116 6117 6118 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6116 def behavior @behavior end |