Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
6194
6195
6196
# File 'lib/stripe/services/payment_intent_service.rb', line 6182

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when ‘amount_type` is `fixed`.



6170
6171
6172
# File 'lib/stripe/services/payment_intent_service.rb', line 6170

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.



6172
6173
6174
# File 'lib/stripe/services/payment_intent_service.rb', line 6172

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



6174
6175
6176
# File 'lib/stripe/services/payment_intent_service.rb', line 6174

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected.



6176
6177
6178
# File 'lib/stripe/services/payment_intent_service.rb', line 6176

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.



6178
6179
6180
# File 'lib/stripe/services/payment_intent_service.rb', line 6178

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Defaults to retail.



6180
6181
6182
# File 'lib/stripe/services/payment_intent_service.rb', line 6180

def purpose
  @purpose
end