Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



5933
5934
5935
5936
5937
5938
5939
5940
5941
5942
5943
5944
5945
5946
5947
# File 'lib/stripe/services/payment_intent_service.rb', line 5933

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when ‘amount_type` is `fixed`.



5921
5922
5923
# File 'lib/stripe/services/payment_intent_service.rb', line 5921

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.



5923
5924
5925
# File 'lib/stripe/services/payment_intent_service.rb', line 5923

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



5925
5926
5927
# File 'lib/stripe/services/payment_intent_service.rb', line 5925

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected.



5927
5928
5929
# File 'lib/stripe/services/payment_intent_service.rb', line 5927

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.



5929
5930
5931
# File 'lib/stripe/services/payment_intent_service.rb', line 5929

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Defaults to retail.



5931
5932
5933
# File 'lib/stripe/services/payment_intent_service.rb', line 5931

def purpose
  @purpose
end