Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::UsBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: FinancialConnections, MandateOptions, Networks

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(financial_connections: nil, mandate_options: nil, networks: nil, preferred_settlement_speed: nil, setup_future_usage: nil, target_date: nil, verification_method: nil) ⇒ UsBankAccount

Returns a new instance of UsBankAccount.



6528
6529
6530
6531
6532
6533
6534
6535
6536
6537
6538
6539
6540
6541
6542
6543
6544
# File 'lib/stripe/services/payment_intent_service.rb', line 6528

def initialize(
  financial_connections: nil,
  mandate_options: nil,
  networks: nil,
  preferred_settlement_speed: nil,
  setup_future_usage: nil,
  target_date: nil,
  verification_method: nil
)
  @financial_connections = financial_connections
  @mandate_options = mandate_options
  @networks = networks
  @preferred_settlement_speed = preferred_settlement_speed
  @setup_future_usage = setup_future_usage
  @target_date = target_date
  @verification_method = verification_method
end

Instance Attribute Details

#financial_connectionsObject

Additional fields for Financial Connections Session creation



6506
6507
6508
# File 'lib/stripe/services/payment_intent_service.rb', line 6506

def financial_connections
  @financial_connections
end

#mandate_optionsObject

Additional fields for Mandate creation



6508
6509
6510
# File 'lib/stripe/services/payment_intent_service.rb', line 6508

def mandate_options
  @mandate_options
end

#networksObject

Additional fields for network related functions



6510
6511
6512
# File 'lib/stripe/services/payment_intent_service.rb', line 6510

def networks
  @networks
end

#preferred_settlement_speedObject

Preferred transaction settlement speed



6512
6513
6514
# File 'lib/stripe/services/payment_intent_service.rb', line 6512

def preferred_settlement_speed
  @preferred_settlement_speed
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



6522
6523
6524
# File 'lib/stripe/services/payment_intent_service.rb', line 6522

def setup_future_usage
  @setup_future_usage
end

#target_dateObject

Controls when Stripe will attempt to debit the funds from the customer’s account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.



6524
6525
6526
# File 'lib/stripe/services/payment_intent_service.rb', line 6524

def target_date
  @target_date
end

#verification_methodObject

Bank account verification method.



6526
6527
6528
# File 'lib/stripe/services/payment_intent_service.rb', line 6526

def verification_method
  @verification_method
end