Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Filters, ManualEntry
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#manual_entry ⇒ Object
Customize manual entry behavior.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
6679 6680 6681 6682 6683 6684 6685 6686 6687 6688 6689 6690 6691 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6679 def initialize( filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil ) @filters = filters @manual_entry = manual_entry @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
6669 6670 6671 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6669 def filters @filters end |
#manual_entry ⇒ Object
Customize manual entry behavior
6671 6672 6673 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6671 def manual_entry @manual_entry end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
6673 6674 6675 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6673 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
6675 6676 6677 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6675 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
6677 6678 6679 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6677 def return_url @return_url end |