Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Filters
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(filters: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
4342 4343 4344 4345 4346 4347 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4342 def initialize(filters: nil, permissions: nil, prefetch: nil, return_url: nil) @filters = filters @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
4334 4335 4336 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4334 def filters @filters end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
4336 4337 4338 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4336 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
4338 4339 4340 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4338 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
4340 4341 4342 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4340 def return_url @return_url end |