Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



6479
6480
6481
6482
6483
6484
6485
6486
6487
6488
6489
6490
6491
# File 'lib/stripe/services/payment_intent_service.rb', line 6479

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



6469
6470
6471
# File 'lib/stripe/services/payment_intent_service.rb', line 6469

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



6471
6472
6473
# File 'lib/stripe/services/payment_intent_service.rb', line 6471

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



6473
6474
6475
# File 'lib/stripe/services/payment_intent_service.rb', line 6473

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



6475
6476
6477
# File 'lib/stripe/services/payment_intent_service.rb', line 6475

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



6477
6478
6479
# File 'lib/stripe/services/payment_intent_service.rb', line 6477

def return_url
  @return_url
end