Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Filters
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(filters: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
4142 4143 4144 4145 4146 4147 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4142 def initialize(filters: nil, permissions: nil, prefetch: nil, return_url: nil) @filters = filters @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
4134 4135 4136 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4134 def filters @filters end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
4136 4137 4138 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4136 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
4138 4139 4140 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4138 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
4140 4141 4142 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4140 def return_url @return_url end |