Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Filters, ManualEntry
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#manual_entry ⇒ Object
Customize manual entry behavior.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
6506 6507 6508 6509 6510 6511 6512 6513 6514 6515 6516 6517 6518 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6506 def initialize( filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil ) @filters = filters @manual_entry = manual_entry @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
6496 6497 6498 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6496 def filters @filters end |
#manual_entry ⇒ Object
Customize manual entry behavior
6498 6499 6500 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6498 def manual_entry @manual_entry end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
6500 6501 6502 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6500 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
6502 6503 6504 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6502 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
6504 6505 6506 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6504 def return_url @return_url end |