Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



6201
6202
6203
6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
# File 'lib/stripe/services/payment_intent_service.rb', line 6201

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



6191
6192
6193
# File 'lib/stripe/services/payment_intent_service.rb', line 6191

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



6193
6194
6195
# File 'lib/stripe/services/payment_intent_service.rb', line 6193

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



6195
6196
6197
# File 'lib/stripe/services/payment_intent_service.rb', line 6195

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



6197
6198
6199
# File 'lib/stripe/services/payment_intent_service.rb', line 6197

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



6199
6200
6201
# File 'lib/stripe/services/payment_intent_service.rb', line 6199

def return_url
  @return_url
end