Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
# File 'lib/stripe/services/payment_intent_service.rb', line 6163

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



6153
6154
6155
# File 'lib/stripe/services/payment_intent_service.rb', line 6153

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



6155
6156
6157
# File 'lib/stripe/services/payment_intent_service.rb', line 6155

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



6157
6158
6159
# File 'lib/stripe/services/payment_intent_service.rb', line 6157

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



6159
6160
6161
# File 'lib/stripe/services/payment_intent_service.rb', line 6159

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



6161
6162
6163
# File 'lib/stripe/services/payment_intent_service.rb', line 6161

def return_url
  @return_url
end