Class: Stripe::PaymentIntentService::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



6139
6140
6141
6142
6143
6144
6145
6146
6147
6148
6149
6150
6151
# File 'lib/stripe/services/payment_intent_service.rb', line 6139

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method



6129
6130
6131
# File 'lib/stripe/services/payment_intent_service.rb', line 6129

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



6131
6132
6133
# File 'lib/stripe/services/payment_intent_service.rb', line 6131

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



6133
6134
6135
# File 'lib/stripe/services/payment_intent_service.rb', line 6133

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



6135
6136
6137
# File 'lib/stripe/services/payment_intent_service.rb', line 6135

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



6137
6138
6139
# File 'lib/stripe/services/payment_intent_service.rb', line 6137

def return_url
  @return_url
end