Class: Stripe::PaymentIntentService::UpdateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::Shipping
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
4492 4493 4494 4495 4496 4497 4498 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4492 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
4482 4483 4484 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4482 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
4484 4485 4486 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4484 def carrier @carrier end |
#name ⇒ Object
Recipient name.
4486 4487 4488 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4486 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
4488 4489 4490 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4488 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
4490 4491 4492 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4490 def tracking_number @tracking_number end |