Class: Stripe::PaymentIntentService::UpdateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::Shipping
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
4569 4570 4571 4572 4573 4574 4575 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4569 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
4559 4560 4561 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4559 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
4561 4562 4563 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4561 def carrier @carrier end |
#name ⇒ Object
Recipient name.
4563 4564 4565 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4563 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
4565 4566 4567 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4565 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
4567 4568 4569 |
# File 'lib/stripe/services/payment_intent_service.rb', line 4567 def tracking_number @tracking_number end |