Class: Stripe::PaymentIntentService::UpdateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::Shipping
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
6532 6533 6534 6535 6536 6537 6538 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6532 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
6522 6523 6524 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6522 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
6524 6525 6526 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6524 def carrier @carrier end |
#name ⇒ Object
Recipient name.
6526 6527 6528 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6526 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
6528 6529 6530 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6528 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
6530 6531 6532 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6530 def tracking_number @tracking_number end |