Class: Stripe::PaymentIntentService::UpdateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::UpdateParams::Shipping
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
6504 6505 6506 6507 6508 6509 6510 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6504 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
6494 6495 6496 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6494 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
6496 6497 6498 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6496 def carrier @carrier end |
#name ⇒ Object
Recipient name.
6498 6499 6500 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6498 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
6500 6501 6502 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6500 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
6502 6503 6504 |
# File 'lib/stripe/services/payment_intent_service.rb', line 6502 def tracking_number @tracking_number end |