Class: Stripe::PaymentIntentService::VerifyMicrodepositsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams

Returns a new instance of VerifyMicrodepositsParams.



12532
12533
12534
12535
12536
# File 'lib/stripe/services/payment_intent_service.rb', line 12532

def initialize(amounts: nil, descriptor_code: nil, expand: nil)
  @amounts = amounts
  @descriptor_code = descriptor_code
  @expand = expand
end

Instance Attribute Details

#amountsObject

Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.



12526
12527
12528
# File 'lib/stripe/services/payment_intent_service.rb', line 12526

def amounts
  @amounts
end

#descriptor_codeObject

A six-character code starting with SM present in the microdeposit sent to the bank account.



12528
12529
12530
# File 'lib/stripe/services/payment_intent_service.rb', line 12528

def descriptor_code
  @descriptor_code
end

#expandObject

Specifies which fields in the response should be expanded.



12530
12531
12532
# File 'lib/stripe/services/payment_intent_service.rb', line 12530

def expand
  @expand
end