Class: Stripe::PaymentIntentService::VerifyMicrodepositsParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::VerifyMicrodepositsParams
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#amounts ⇒ Object
Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.
-
#descriptor_code ⇒ Object
A six-character code starting with SM present in the microdeposit sent to the bank account.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams
constructor
A new instance of VerifyMicrodepositsParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams
Returns a new instance of VerifyMicrodepositsParams.
11731 11732 11733 11734 11735 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11731 def initialize(amounts: nil, descriptor_code: nil, expand: nil) @amounts = amounts @descriptor_code = descriptor_code @expand = end |
Instance Attribute Details
#amounts ⇒ Object
Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.
11725 11726 11727 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11725 def amounts @amounts end |
#descriptor_code ⇒ Object
A six-character code starting with SM present in the microdeposit sent to the bank account.
11727 11728 11729 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11727 def descriptor_code @descriptor_code end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
11729 11730 11731 |
# File 'lib/stripe/services/payment_intent_service.rb', line 11729 def @expand end |