Class: Stripe::PaymentIntentService::VerifyMicrodepositsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams

Returns a new instance of VerifyMicrodepositsParams.



11425
11426
11427
11428
11429
# File 'lib/stripe/services/payment_intent_service.rb', line 11425

def initialize(amounts: nil, descriptor_code: nil, expand: nil)
  @amounts = amounts
  @descriptor_code = descriptor_code
  @expand = expand
end

Instance Attribute Details

#amountsObject

Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.



11419
11420
11421
# File 'lib/stripe/services/payment_intent_service.rb', line 11419

def amounts
  @amounts
end

#descriptor_codeObject

A six-character code starting with SM present in the microdeposit sent to the bank account.



11421
11422
11423
# File 'lib/stripe/services/payment_intent_service.rb', line 11421

def descriptor_code
  @descriptor_code
end

#expandObject

Specifies which fields in the response should be expanded.



11423
11424
11425
# File 'lib/stripe/services/payment_intent_service.rb', line 11423

def expand
  @expand
end