Class: Stripe::PaymentIntentService::VerifyMicrodepositsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams

Returns a new instance of VerifyMicrodepositsParams.



6997
6998
6999
7000
7001
# File 'lib/stripe/services/payment_intent_service.rb', line 6997

def initialize(amounts: nil, descriptor_code: nil, expand: nil)
  @amounts = amounts
  @descriptor_code = descriptor_code
  @expand = expand
end

Instance Attribute Details

#amountsObject

Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.



6991
6992
6993
# File 'lib/stripe/services/payment_intent_service.rb', line 6991

def amounts
  @amounts
end

#descriptor_codeObject

A six-character code starting with SM present in the microdeposit sent to the bank account.



6993
6994
6995
# File 'lib/stripe/services/payment_intent_service.rb', line 6993

def descriptor_code
  @descriptor_code
end

#expandObject

Specifies which fields in the response should be expanded.



6995
6996
6997
# File 'lib/stripe/services/payment_intent_service.rb', line 6995

def expand
  @expand
end