Class: Stripe::PaymentIntentService::VerifyMicrodepositsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams

Returns a new instance of VerifyMicrodepositsParams.



10875
10876
10877
10878
10879
# File 'lib/stripe/services/payment_intent_service.rb', line 10875

def initialize(amounts: nil, descriptor_code: nil, expand: nil)
  @amounts = amounts
  @descriptor_code = descriptor_code
  @expand = expand
end

Instance Attribute Details

#amountsObject

Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.



10869
10870
10871
# File 'lib/stripe/services/payment_intent_service.rb', line 10869

def amounts
  @amounts
end

#descriptor_codeObject

A six-character code starting with SM present in the microdeposit sent to the bank account.



10871
10872
10873
# File 'lib/stripe/services/payment_intent_service.rb', line 10871

def descriptor_code
  @descriptor_code
end

#expandObject

Specifies which fields in the response should be expanded.



10873
10874
10875
# File 'lib/stripe/services/payment_intent_service.rb', line 10873

def expand
  @expand
end