Class: Stripe::PaymentIntentService::VerifyMicrodepositsParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::VerifyMicrodepositsParams
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#amounts ⇒ Object
Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.
-
#descriptor_code ⇒ Object
A six-character code starting with SM present in the microdeposit sent to the bank account.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams
constructor
A new instance of VerifyMicrodepositsParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams
Returns a new instance of VerifyMicrodepositsParams.
12140 12141 12142 12143 12144 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12140 def initialize(amounts: nil, descriptor_code: nil, expand: nil) @amounts = amounts @descriptor_code = descriptor_code @expand = end |
Instance Attribute Details
#amounts ⇒ Object
Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.
12132 12133 12134 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12132 def amounts @amounts end |
#descriptor_code ⇒ Object
A six-character code starting with SM present in the microdeposit sent to the bank account.
12135 12136 12137 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12135 def descriptor_code @descriptor_code end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
12138 12139 12140 |
# File 'lib/stripe/services/payment_intent_service.rb', line 12138 def @expand end |