Class: Stripe::PaymentIntentService::VerifyMicrodepositsParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentService::VerifyMicrodepositsParams
- Defined in:
- lib/stripe/services/payment_intent_service.rb
Instance Attribute Summary collapse
-
#amounts ⇒ Object
Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.
-
#descriptor_code ⇒ Object
A six-character code starting with SM present in the microdeposit sent to the bank account.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams
constructor
A new instance of VerifyMicrodepositsParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams
Returns a new instance of VerifyMicrodepositsParams.
10833 10834 10835 10836 10837 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10833 def initialize(amounts: nil, descriptor_code: nil, expand: nil) @amounts = amounts @descriptor_code = descriptor_code @expand = end |
Instance Attribute Details
#amounts ⇒ Object
Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.
10827 10828 10829 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10827 def amounts @amounts end |
#descriptor_code ⇒ Object
A six-character code starting with SM present in the microdeposit sent to the bank account.
10829 10830 10831 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10829 def descriptor_code @descriptor_code end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
10831 10832 10833 |
# File 'lib/stripe/services/payment_intent_service.rb', line 10831 def @expand end |