Class: Stripe::PaymentIntentUpdateCryptoRefundAddressParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateCryptoRefundAddressParams
- Defined in:
- lib/stripe/params/payment_intent_update_crypto_refund_address_params.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#network ⇒ Object
The blockchain network for the refund address.
-
#refund_address ⇒ Object
The wallet address that should receive refunds for deposits on the specified network.
Instance Method Summary collapse
-
#initialize(expand: nil, network: nil, refund_address: nil) ⇒ PaymentIntentUpdateCryptoRefundAddressParams
constructor
A new instance of PaymentIntentUpdateCryptoRefundAddressParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expand: nil, network: nil, refund_address: nil) ⇒ PaymentIntentUpdateCryptoRefundAddressParams
Returns a new instance of PaymentIntentUpdateCryptoRefundAddressParams.
13 14 15 16 17 |
# File 'lib/stripe/params/payment_intent_update_crypto_refund_address_params.rb', line 13 def initialize(expand: nil, network: nil, refund_address: nil) @expand = @network = network @refund_address = refund_address end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
7 8 9 |
# File 'lib/stripe/params/payment_intent_update_crypto_refund_address_params.rb', line 7 def @expand end |
#network ⇒ Object
The blockchain network for the refund address.
9 10 11 |
# File 'lib/stripe/params/payment_intent_update_crypto_refund_address_params.rb', line 9 def network @network end |
#refund_address ⇒ Object
The wallet address that should receive refunds for deposits on the specified network.
11 12 13 |
# File 'lib/stripe/params/payment_intent_update_crypto_refund_address_params.rb', line 11 def refund_address @refund_address end |