Class: Stripe::PaymentIntentUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: AllocatedFunds, AmountDetails, Hooks, MandateData, PaymentDetails, PaymentMethodData, PaymentMethodOptions, Shipping, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(allocated_funds: nil, allowed_payment_method_types: nil, amount: nil, amount_details: nil, application_fee_amount: nil, capture_method: nil, currency: nil, customer: nil, customer_account: nil, description: nil, excluded_payment_method_types: nil, expand: nil, fx_quote: nil, hooks: nil, mandate_data: nil, metadata: nil, payment_details: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, receipt_email: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ PaymentIntentUpdateParams

Returns a new instance of PaymentIntentUpdateParams.



6487
6488
6489
6490
6491
6492
6493
6494
6495
6496
6497
6498
6499
6500
6501
6502
6503
6504
6505
6506
6507
6508
6509
6510
6511
6512
6513
6514
6515
6516
6517
6518
6519
6520
6521
6522
6523
6524
6525
6526
6527
6528
6529
6530
6531
6532
6533
6534
6535
6536
6537
6538
6539
6540
6541
6542
6543
6544
6545
6546
6547
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6487

def initialize(
  allocated_funds: nil,
  allowed_payment_method_types: nil,
  amount: nil,
  amount_details: nil,
  application_fee_amount: nil,
  capture_method: nil,
  currency: nil,
  customer: nil,
  customer_account: nil,
  description: nil,
  excluded_payment_method_types: nil,
  expand: nil,
  fx_quote: nil,
  hooks: nil,
  mandate_data: nil,
  metadata: nil,
  payment_details: nil,
  payment_method: nil,
  payment_method_configuration: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  receipt_email: nil,
  setup_future_usage: nil,
  shipping: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil,
  transfer_group: nil
)
  @allocated_funds = allocated_funds
  @allowed_payment_method_types = allowed_payment_method_types
  @amount = amount
  @amount_details = amount_details
  @application_fee_amount = application_fee_amount
  @capture_method = capture_method
  @currency = currency
  @customer = customer
  @customer_account = 
  @description = description
  @excluded_payment_method_types = excluded_payment_method_types
  @expand = expand
  @fx_quote = fx_quote
  @hooks = hooks
  @mandate_data = mandate_data
  @metadata = 
  @payment_details = payment_details
  @payment_method = payment_method
  @payment_method_configuration = payment_method_configuration
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @receipt_email = receipt_email
  @setup_future_usage = setup_future_usage
  @shipping = shipping
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
  @transfer_group = transfer_group
end

Instance Attribute Details

#allocated_fundsObject

Allocated Funds configuration for this PaymentIntent.



6409
6410
6411
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6409

def allocated_funds
  @allocated_funds
end

#allowed_payment_method_typesObject

The list of payment method types allowed for use with this payment. Stripe automatically returns compatible payment methods from this list in the payment_method_types field of the response, based on the other PaymentIntent parameters, such as currency, amount, and customer.



6411
6412
6413
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6411

def allowed_payment_method_types
  @allowed_payment_method_types
end

#amountObject

Amount intended to be collected by this PaymentIntent. A positive integer representing how much to charge in the smallest currency unit (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or equivalent in charge currency. The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).



6413
6414
6415
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6413

def amount
  @amount
end

#amount_detailsObject

Provides industry-specific information about the amount.



6415
6416
6417
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6415

def amount_details
  @amount_details
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents use case for connected accounts.



6417
6418
6419
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6417

def application_fee_amount
  @application_fee_amount
end

#capture_methodObject

Controls when the funds will be captured from the customer's account.



6419
6420
6421
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6419

def capture_method
  @capture_method
end

#currencyObject

Three-letter ISO currency code, in lowercase. Must be a supported currency.



6421
6422
6423
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6421

def currency
  @currency
end

#customerObject

ID of the Customer this PaymentIntent belongs to, if one exists.

Payment methods attached to other Customers cannot be used with this PaymentIntent.

If setup_future_usage is set and this PaymentIntent's payment method is not card_present, then the payment method attaches to the Customer after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is card_present and isn't a digital wallet, then a generated_card payment method representing the card is created and attached to the Customer instead.



6427
6428
6429
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6427

def customer
  @customer
end

#customer_accountObject

ID of the Account representing the customer that this PaymentIntent belongs to, if one exists.

Payment methods attached to other Accounts cannot be used with this PaymentIntent.

If setup_future_usage is set and this PaymentIntent's payment method is not card_present, then the payment method attaches to the Account after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is card_present and isn't a digital wallet, then a generated_card payment method representing the card is created and attached to the Account instead.



6433
6434
6435
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6433

def 
  @customer_account
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



6435
6436
6437
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6435

def description
  @description
end

#excluded_payment_method_typesObject

The list of payment method types to exclude from use with this payment.



6437
6438
6439
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6437

def excluded_payment_method_types
  @excluded_payment_method_types
end

#expandObject

Specifies which fields in the response should be expanded.



6439
6440
6441
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6439

def expand
  @expand
end

#fx_quoteObject

The FX rate in the quote is validated and used to convert the presentment amount to the settlement amount.



6441
6442
6443
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6441

def fx_quote
  @fx_quote
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



6443
6444
6445
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6443

def hooks
  @hooks
end

#mandate_dataObject

This hash contains details about the Mandate to create.



6445
6446
6447
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6445

def mandate_data
  @mandate_data
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



6447
6448
6449
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6447

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



6449
6450
6451
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6449

def payment_details
  @payment_details
end

#payment_methodObject

Attribute for param field payment_method



6451
6452
6453
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6451

def payment_method
  @payment_method
end

#payment_method_configurationObject

The ID of the payment method configuration to use with this PaymentIntent.



6453
6454
6455
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6453

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the payment_method property on the PaymentIntent.



6457
6458
6459
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6457

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment-method-specific configuration for this PaymentIntent.



6459
6460
6461
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6459

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, card) that this PaymentIntent can use. Use automatic_payment_methods to manage payment methods from the Stripe Dashboard. A list of valid payment method types can be found here.



6461
6462
6463
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6461

def payment_method_types
  @payment_method_types
end

#receipt_emailObject

Email address that the receipt for the resulting payment will be sent to. If receipt_email is specified for a payment in live mode, a receipt will be sent regardless of your email settings.



6463
6464
6465
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6463

def receipt_email
  @receipt_email
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.

If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.



6473
6474
6475
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6473

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this PaymentIntent.



6475
6476
6477
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6475

def shipping
  @shipping
end

#statement_descriptorObject

Text that appears on the customer's statement as the statement descriptor for a non-card charge. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see the Statement Descriptor docs.

Setting this value for a card charge returns an error. For card charges, set the statement_descriptor_suffix instead.



6479
6480
6481
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6479

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account's statement descriptor prefix to form the complete statement descriptor that appears on the customer's statement.



6481
6482
6483
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6481

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

Use this parameter to automatically create a Transfer when the payment succeeds. Learn more about the use case for connected accounts.



6483
6484
6485
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6483

def transfer_data
  @transfer_data
end

#transfer_groupObject

A string that identifies the resulting payment as part of a group. You can only provide transfer_group if it hasn't been set. Learn more about the use case for connected accounts.



6485
6486
6487
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6485

def transfer_group
  @transfer_group
end