Class: Stripe::PaymentIntentUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: AmountDetails, Hooks, PaymentDetails, PaymentMethodData, PaymentMethodOptions, Shipping, TransferData
Instance Attribute Summary collapse
-
#allowed_payment_method_types ⇒ Object
The list of payment method types allowed for use with this payment.
-
#amount ⇒ Object
Amount intended to be collected by this PaymentIntent.
-
#amount_details ⇒ Object
Provides industry-specific information about the amount.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account.
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer's account.
-
#currency ⇒ Object
Three-letter ISO currency code, in lowercase.
-
#customer ⇒ Object
ID of the Customer this PaymentIntent belongs to, if one exists.
-
#customer_account ⇒ Object
ID of the Account representing the customer that this PaymentIntent belongs to, if one exists.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#excluded_payment_method_types ⇒ Object
The list of payment method types to exclude from use with this payment.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#payment_details ⇒ Object
Provides industry-specific information about the charge.
-
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or compatible Source object) to attach to this PaymentIntent.
-
#payment_method_configuration ⇒ Object
The ID of the payment method configuration to use with this PaymentIntent.
-
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod.
-
#payment_method_options ⇒ Object
Payment-method-specific configuration for this PaymentIntent.
-
#payment_method_types ⇒ Object
The list of payment method types (for example, card) that this PaymentIntent can use.
-
#receipt_email ⇒ Object
Email address that the receipt for the resulting payment will be sent to.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
-
#shipping ⇒ Object
Shipping information for this PaymentIntent.
-
#statement_descriptor ⇒ Object
Text that appears on the customer's statement as the statement descriptor for a non-card charge.
-
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge.
-
#transfer_data ⇒ Object
Use this parameter to automatically create a Transfer when the payment succeeds.
-
#transfer_group ⇒ Object
A string that identifies the resulting payment as part of a group.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(allowed_payment_method_types: nil, amount: nil, amount_details: nil, application_fee_amount: nil, capture_method: nil, currency: nil, customer: nil, customer_account: nil, description: nil, excluded_payment_method_types: nil, expand: nil, hooks: nil, metadata: nil, payment_details: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, receipt_email: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ PaymentIntentUpdateParams
Returns a new instance of PaymentIntentUpdateParams.
2842 2843 2844 2845 2846 2847 2848 2849 2850 2851 2852 2853 2854 2855 2856 2857 2858 2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2842 def initialize( allowed_payment_method_types: nil, amount: nil, amount_details: nil, application_fee_amount: nil, capture_method: nil, currency: nil, customer: nil, customer_account: nil, description: nil, excluded_payment_method_types: nil, expand: nil, hooks: nil, metadata: nil, payment_details: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, receipt_email: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil ) @allowed_payment_method_types = allowed_payment_method_types @amount = amount @amount_details = amount_details @application_fee_amount = application_fee_amount @capture_method = capture_method @currency = currency @customer = customer @customer_account = customer_account @description = description @excluded_payment_method_types = excluded_payment_method_types @expand = @hooks = hooks @metadata = @payment_details = payment_details @payment_method = payment_method @payment_method_configuration = payment_method_configuration @payment_method_data = payment_method_data @payment_method_options = @payment_method_types = payment_method_types @receipt_email = receipt_email @setup_future_usage = setup_future_usage @shipping = shipping @statement_descriptor = statement_descriptor @statement_descriptor_suffix = statement_descriptor_suffix @transfer_data = transfer_data @transfer_group = transfer_group end |
Instance Attribute Details
#allowed_payment_method_types ⇒ Object
The list of payment method types allowed for use with this payment. Stripe automatically returns compatible payment methods from this list in the payment_method_types field of the response, based on the other PaymentIntent parameters, such as currency, amount, and customer.
2770 2771 2772 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2770 def allowed_payment_method_types @allowed_payment_method_types end |
#amount ⇒ Object
Amount intended to be collected by this PaymentIntent. A positive integer representing how much to charge in the smallest currency unit (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or equivalent in charge currency. The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).
2772 2773 2774 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2772 def amount @amount end |
#amount_details ⇒ Object
Provides industry-specific information about the amount.
2774 2775 2776 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2774 def amount_details @amount_details end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents use case for connected accounts.
2776 2777 2778 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2776 def application_fee_amount @application_fee_amount end |
#capture_method ⇒ Object
Controls when the funds will be captured from the customer's account.
2778 2779 2780 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2778 def capture_method @capture_method end |
#currency ⇒ Object
Three-letter ISO currency code, in lowercase. Must be a supported currency.
2780 2781 2782 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2780 def currency @currency end |
#customer ⇒ Object
ID of the Customer this PaymentIntent belongs to, if one exists.
Payment methods attached to other Customers cannot be used with this PaymentIntent.
If setup_future_usage is set and this PaymentIntent's payment method is not card_present, then the payment method attaches to the Customer after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is card_present and isn't a digital wallet, then a generated_card payment method representing the card is created and attached to the Customer instead.
2786 2787 2788 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2786 def customer @customer end |
#customer_account ⇒ Object
ID of the Account representing the customer that this PaymentIntent belongs to, if one exists.
Payment methods attached to other Accounts cannot be used with this PaymentIntent.
If setup_future_usage is set and this PaymentIntent's payment method is not card_present, then the payment method attaches to the Account after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is card_present and isn't a digital wallet, then a generated_card payment method representing the card is created and attached to the Account instead.
2792 2793 2794 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2792 def customer_account @customer_account end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
2794 2795 2796 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2794 def description @description end |
#excluded_payment_method_types ⇒ Object
The list of payment method types to exclude from use with this payment.
2796 2797 2798 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2796 def excluded_payment_method_types @excluded_payment_method_types end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2798 2799 2800 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2798 def @expand end |
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle
2800 2801 2802 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2800 def hooks @hooks end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
2802 2803 2804 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2802 def @metadata end |
#payment_details ⇒ Object
Provides industry-specific information about the charge.
2804 2805 2806 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2804 def payment_details @payment_details end |
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or compatible Source object) to attach to this PaymentIntent. To unset this field to null, pass in an empty string.
2806 2807 2808 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2806 def payment_method @payment_method end |
#payment_method_configuration ⇒ Object
The ID of the payment method configuration to use with this PaymentIntent.
2808 2809 2810 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2808 def payment_method_configuration @payment_method_configuration end |
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the payment_method property on the PaymentIntent.
2812 2813 2814 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2812 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment-method-specific configuration for this PaymentIntent.
2814 2815 2816 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2814 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types (for example, card) that this PaymentIntent can use. Use automatic_payment_methods to manage payment methods from the Stripe Dashboard. A list of valid payment method types can be found here.
2816 2817 2818 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2816 def payment_method_types @payment_method_types end |
#receipt_email ⇒ Object
Email address that the receipt for the resulting payment will be sent to. If receipt_email is specified for a payment in live mode, a receipt will be sent regardless of your email settings.
2818 2819 2820 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2818 def receipt_email @receipt_email end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.
2828 2829 2830 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2828 def setup_future_usage @setup_future_usage end |
#shipping ⇒ Object
Shipping information for this PaymentIntent.
2830 2831 2832 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2830 def shipping @shipping end |
#statement_descriptor ⇒ Object
Text that appears on the customer's statement as the statement descriptor for a non-card charge. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see the Statement Descriptor docs.
Setting this value for a card charge returns an error. For card charges, set the statement_descriptor_suffix instead.
2834 2835 2836 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2834 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge. Concatenated to the account's statement descriptor prefix to form the complete statement descriptor that appears on the customer's statement.
2836 2837 2838 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2836 def statement_descriptor_suffix @statement_descriptor_suffix end |
#transfer_data ⇒ Object
Use this parameter to automatically create a Transfer when the payment succeeds. Learn more about the use case for connected accounts.
2838 2839 2840 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2838 def transfer_data @transfer_data end |
#transfer_group ⇒ Object
A string that identifies the resulting payment as part of a group. You can only provide transfer_group if it hasn't been set. Learn more about the use case for connected accounts.
2840 2841 2842 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2840 def transfer_group @transfer_group end |