Class: Stripe::PaymentIntentUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: AmountDetails, Hooks, MandateData, PaymentDetails, PaymentMethodData, PaymentMethodOptions, Shipping, TransferData
Instance Attribute Summary collapse
-
#allowed_payment_method_types ⇒ Object
The list of payment method types allowed for use with this payment.
-
#amount ⇒ Object
Amount intended to be collected by this PaymentIntent.
-
#amount_details ⇒ Object
Provides industry-specific information about the amount.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account.
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer's account.
-
#currency ⇒ Object
Three-letter ISO currency code, in lowercase.
-
#customer ⇒ Object
ID of the Customer this PaymentIntent belongs to, if one exists.
-
#customer_account ⇒ Object
ID of the Account representing the customer that this PaymentIntent belongs to, if one exists.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#excluded_payment_method_types ⇒ Object
The list of payment method types to exclude from use with this payment.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fx_quote ⇒ Object
The FX rate in the quote is validated and used to convert the presentment amount to the settlement amount.
-
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle.
-
#mandate_data ⇒ Object
This hash contains details about the Mandate to create.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#payment_details ⇒ Object
Provides industry-specific information about the charge.
-
#payment_method ⇒ Object
Attribute for param field payment_method.
-
#payment_method_configuration ⇒ Object
The ID of the payment method configuration to use with this PaymentIntent.
-
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod.
-
#payment_method_options ⇒ Object
Payment-method-specific configuration for this PaymentIntent.
-
#payment_method_types ⇒ Object
The list of payment method types (for example, card) that this PaymentIntent can use.
-
#receipt_email ⇒ Object
Email address that the receipt for the resulting payment will be sent to.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
-
#shipping ⇒ Object
Shipping information for this PaymentIntent.
-
#statement_descriptor ⇒ Object
Text that appears on the customer's statement as the statement descriptor for a non-card charge.
-
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge.
-
#transfer_data ⇒ Object
Use this parameter to automatically create a Transfer when the payment succeeds.
-
#transfer_group ⇒ Object
A string that identifies the resulting payment as part of a group.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(allowed_payment_method_types: nil, amount: nil, amount_details: nil, application_fee_amount: nil, capture_method: nil, currency: nil, customer: nil, customer_account: nil, description: nil, excluded_payment_method_types: nil, expand: nil, fx_quote: nil, hooks: nil, mandate_data: nil, metadata: nil, payment_details: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, receipt_email: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ PaymentIntentUpdateParams
Returns a new instance of PaymentIntentUpdateParams.
5804 5805 5806 5807 5808 5809 5810 5811 5812 5813 5814 5815 5816 5817 5818 5819 5820 5821 5822 5823 5824 5825 5826 5827 5828 5829 5830 5831 5832 5833 5834 5835 5836 5837 5838 5839 5840 5841 5842 5843 5844 5845 5846 5847 5848 5849 5850 5851 5852 5853 5854 5855 5856 5857 5858 5859 5860 5861 5862 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5804 def initialize( allowed_payment_method_types: nil, amount: nil, amount_details: nil, application_fee_amount: nil, capture_method: nil, currency: nil, customer: nil, customer_account: nil, description: nil, excluded_payment_method_types: nil, expand: nil, fx_quote: nil, hooks: nil, mandate_data: nil, metadata: nil, payment_details: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, receipt_email: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil ) @allowed_payment_method_types = allowed_payment_method_types @amount = amount @amount_details = amount_details @application_fee_amount = application_fee_amount @capture_method = capture_method @currency = currency @customer = customer @customer_account = customer_account @description = description @excluded_payment_method_types = excluded_payment_method_types @expand = @fx_quote = fx_quote @hooks = hooks @mandate_data = mandate_data @metadata = @payment_details = payment_details @payment_method = payment_method @payment_method_configuration = payment_method_configuration @payment_method_data = payment_method_data @payment_method_options = @payment_method_types = payment_method_types @receipt_email = receipt_email @setup_future_usage = setup_future_usage @shipping = shipping @statement_descriptor = statement_descriptor @statement_descriptor_suffix = statement_descriptor_suffix @transfer_data = transfer_data @transfer_group = transfer_group end |
Instance Attribute Details
#allowed_payment_method_types ⇒ Object
The list of payment method types allowed for use with this payment. Stripe automatically returns compatible payment methods from this list in the payment_method_types field of the response, based on the other PaymentIntent parameters, such as currency, amount, and customer.
5728 5729 5730 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5728 def allowed_payment_method_types @allowed_payment_method_types end |
#amount ⇒ Object
Amount intended to be collected by this PaymentIntent. A positive integer representing how much to charge in the smallest currency unit (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or equivalent in charge currency. The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).
5730 5731 5732 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5730 def amount @amount end |
#amount_details ⇒ Object
Provides industry-specific information about the amount.
5732 5733 5734 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5732 def amount_details @amount_details end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents use case for connected accounts.
5734 5735 5736 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5734 def application_fee_amount @application_fee_amount end |
#capture_method ⇒ Object
Controls when the funds will be captured from the customer's account.
5736 5737 5738 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5736 def capture_method @capture_method end |
#currency ⇒ Object
Three-letter ISO currency code, in lowercase. Must be a supported currency.
5738 5739 5740 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5738 def currency @currency end |
#customer ⇒ Object
ID of the Customer this PaymentIntent belongs to, if one exists.
Payment methods attached to other Customers cannot be used with this PaymentIntent.
If setup_future_usage is set and this PaymentIntent's payment method is not card_present, then the payment method attaches to the Customer after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is card_present and isn't a digital wallet, then a generated_card payment method representing the card is created and attached to the Customer instead.
5744 5745 5746 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5744 def customer @customer end |
#customer_account ⇒ Object
ID of the Account representing the customer that this PaymentIntent belongs to, if one exists.
Payment methods attached to other Accounts cannot be used with this PaymentIntent.
If setup_future_usage is set and this PaymentIntent's payment method is not card_present, then the payment method attaches to the Account after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is card_present and isn't a digital wallet, then a generated_card payment method representing the card is created and attached to the Account instead.
5750 5751 5752 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5750 def customer_account @customer_account end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
5752 5753 5754 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5752 def description @description end |
#excluded_payment_method_types ⇒ Object
The list of payment method types to exclude from use with this payment.
5754 5755 5756 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5754 def excluded_payment_method_types @excluded_payment_method_types end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
5756 5757 5758 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5756 def @expand end |
#fx_quote ⇒ Object
The FX rate in the quote is validated and used to convert the presentment amount to the settlement amount.
5758 5759 5760 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5758 def fx_quote @fx_quote end |
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle
5760 5761 5762 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5760 def hooks @hooks end |
#mandate_data ⇒ Object
This hash contains details about the Mandate to create.
5762 5763 5764 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5762 def mandate_data @mandate_data end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
5764 5765 5766 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5764 def @metadata end |
#payment_details ⇒ Object
Provides industry-specific information about the charge.
5766 5767 5768 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5766 def payment_details @payment_details end |
#payment_method ⇒ Object
Attribute for param field payment_method
5768 5769 5770 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5768 def payment_method @payment_method end |
#payment_method_configuration ⇒ Object
The ID of the payment method configuration to use with this PaymentIntent.
5770 5771 5772 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5770 def payment_method_configuration @payment_method_configuration end |
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the payment_method property on the PaymentIntent.
5774 5775 5776 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5774 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment-method-specific configuration for this PaymentIntent.
5776 5777 5778 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5776 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types (for example, card) that this PaymentIntent can use. Use automatic_payment_methods to manage payment methods from the Stripe Dashboard. A list of valid payment method types can be found here.
5778 5779 5780 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5778 def payment_method_types @payment_method_types end |
#receipt_email ⇒ Object
Email address that the receipt for the resulting payment will be sent to. If receipt_email is specified for a payment in live mode, a receipt will be sent regardless of your email settings.
5780 5781 5782 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5780 def receipt_email @receipt_email end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.
5790 5791 5792 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5790 def setup_future_usage @setup_future_usage end |
#shipping ⇒ Object
Shipping information for this PaymentIntent.
5792 5793 5794 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5792 def shipping @shipping end |
#statement_descriptor ⇒ Object
Text that appears on the customer's statement as the statement descriptor for a non-card charge. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see the Statement Descriptor docs.
Setting this value for a card charge returns an error. For card charges, set the statement_descriptor_suffix instead.
5796 5797 5798 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5796 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge. Concatenated to the account's statement descriptor prefix to form the complete statement descriptor that appears on the customer's statement.
5798 5799 5800 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5798 def statement_descriptor_suffix @statement_descriptor_suffix end |
#transfer_data ⇒ Object
Use this parameter to automatically create a Transfer when the payment succeeds. Learn more about the use case for connected accounts.
5800 5801 5802 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5800 def transfer_data @transfer_data end |
#transfer_group ⇒ Object
A string that identifies the resulting payment as part of a group. You can only provide transfer_group if it hasn't been set. Learn more about the use case for connected accounts.
5802 5803 5804 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5802 def transfer_group @transfer_group end |