Class: Stripe::PaymentIntentUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: AllocatedFunds, AmountDetails, Hooks, MandateData, PaymentDetails, PaymentMethodData, PaymentMethodOptions, Shipping, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allocated_funds: nil, amount: nil, amount_details: nil, application_fee_amount: nil, capture_method: nil, currency: nil, customer: nil, customer_account: nil, description: nil, excluded_payment_method_types: nil, expand: nil, fx_quote: nil, hooks: nil, mandate_data: nil, metadata: nil, payment_details: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, receipt_email: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ PaymentIntentUpdateParams

Returns a new instance of PaymentIntentUpdateParams.



5634
5635
5636
5637
5638
5639
5640
5641
5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
5688
5689
5690
5691
5692
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5634

def initialize(
  allocated_funds: nil,
  amount: nil,
  amount_details: nil,
  application_fee_amount: nil,
  capture_method: nil,
  currency: nil,
  customer: nil,
  customer_account: nil,
  description: nil,
  excluded_payment_method_types: nil,
  expand: nil,
  fx_quote: nil,
  hooks: nil,
  mandate_data: nil,
  metadata: nil,
  payment_details: nil,
  payment_method: nil,
  payment_method_configuration: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  receipt_email: nil,
  setup_future_usage: nil,
  shipping: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil,
  transfer_group: nil
)
  @allocated_funds = allocated_funds
  @amount = amount
  @amount_details = amount_details
  @application_fee_amount = application_fee_amount
  @capture_method = capture_method
  @currency = currency
  @customer = customer
  @customer_account = 
  @description = description
  @excluded_payment_method_types = excluded_payment_method_types
  @expand = expand
  @fx_quote = fx_quote
  @hooks = hooks
  @mandate_data = mandate_data
  @metadata = 
  @payment_details = payment_details
  @payment_method = payment_method
  @payment_method_configuration = payment_method_configuration
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @receipt_email = receipt_email
  @setup_future_usage = setup_future_usage
  @shipping = shipping
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
  @transfer_group = transfer_group
end

Instance Attribute Details

#allocated_fundsObject

Allocated Funds configuration for this PaymentIntent.



5558
5559
5560
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5558

def allocated_funds
  @allocated_funds
end

#amountObject

Amount intended to be collected by this PaymentIntent. A positive integer representing how much to charge in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge currency](stripe.com/docs/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).



5560
5561
5562
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5560

def amount
  @amount
end

#amount_detailsObject

Provides industry-specific information about the amount.



5562
5563
5564
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5562

def amount_details
  @amount_details
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



5564
5565
5566
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5564

def application_fee_amount
  @application_fee_amount
end

#capture_methodObject

Controls when the funds will be captured from the customer’s account.



5566
5567
5568
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5566

def capture_method
  @capture_method
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



5568
5569
5570
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5568

def currency
  @currency
end

#customerObject

ID of the Customer this PaymentIntent belongs to, if one exists.

Payment methods attached to other Customers cannot be used with this PaymentIntent.

If [setup_future_usage](stripe.com/docs/api#payment_intent_object-setup_future_usage) is set and this PaymentIntent’s payment method is not ‘card_present`, then the payment method attaches to the Customer after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is `card_present` and isn’t a digital wallet, then a [generated_card](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Customer instead.



5574
5575
5576
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5574

def customer
  @customer
end

#customer_accountObject

ID of the Account this PaymentIntent belongs to, if one exists.

Payment methods attached to other Accounts cannot be used with this PaymentIntent.

If [setup_future_usage](stripe.com/docs/api#payment_intent_object-setup_future_usage) is set and this PaymentIntent’s payment method is not ‘card_present`, then the payment method attaches to the Account after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is `card_present` and isn’t a digital wallet, then a [generated_card](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Account instead.



5580
5581
5582
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5580

def 
  @customer_account
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



5582
5583
5584
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5582

def description
  @description
end

#excluded_payment_method_typesObject

The list of payment method types to exclude from use with this payment.



5584
5585
5586
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5584

def excluded_payment_method_types
  @excluded_payment_method_types
end

#expandObject

Specifies which fields in the response should be expanded.



5586
5587
5588
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5586

def expand
  @expand
end

#fx_quoteObject

The FX rate in the quote is validated and used to convert the presentment amount to the settlement amount.



5588
5589
5590
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5588

def fx_quote
  @fx_quote
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



5590
5591
5592
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5590

def hooks
  @hooks
end

#mandate_dataObject

This hash contains details about the Mandate to create.



5592
5593
5594
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5592

def mandate_data
  @mandate_data
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



5594
5595
5596
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5594

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



5596
5597
5598
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5596

def payment_details
  @payment_details
end

#payment_methodObject

Attribute for param field payment_method



5598
5599
5600
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5598

def payment_method
  @payment_method
end

#payment_method_configurationObject

The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this PaymentIntent.



5600
5601
5602
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5600

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the [payment_method](stripe.com/docs/api/payment_intents/object#payment_intent_object-payment_method) property on the PaymentIntent.



5604
5605
5606
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5604

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment-method-specific configuration for this PaymentIntent.



5606
5607
5608
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5606

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, card) that this PaymentIntent can use. Use ‘automatic_payment_methods` to manage payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).



5608
5609
5610
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5608

def payment_method_types
  @payment_method_types
end

#receipt_emailObject

Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).



5610
5611
5612
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5610

def receipt_email
  @receipt_email
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



5620
5621
5622
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5620

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this PaymentIntent.



5622
5623
5624
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5622

def shipping
  @shipping
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).

Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.



5626
5627
5628
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5626

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



5628
5629
5630
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5628

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

Use this parameter to automatically create a Transfer when the payment succeeds. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



5630
5631
5632
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5630

def transfer_data
  @transfer_data
end

#transfer_groupObject

A string that identifies the resulting payment as part of a group. You can only provide ‘transfer_group` if it hasn’t been set. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



5632
5633
5634
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5632

def transfer_group
  @transfer_group
end