Class: Stripe::PaymentIntentUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: PaymentMethodData, PaymentMethodOptions, Shipping, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, application_fee_amount: nil, capture_method: nil, currency: nil, customer: nil, description: nil, excluded_payment_method_types: nil, expand: nil, metadata: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, receipt_email: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ PaymentIntentUpdateParams

Returns a new instance of PaymentIntentUpdateParams.



2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
2346
2347
2348
2349
2350
2351
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2307

def initialize(
  amount: nil,
  application_fee_amount: nil,
  capture_method: nil,
  currency: nil,
  customer: nil,
  description: nil,
  excluded_payment_method_types: nil,
  expand: nil,
  metadata: nil,
  payment_method: nil,
  payment_method_configuration: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  receipt_email: nil,
  setup_future_usage: nil,
  shipping: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil,
  transfer_group: nil
)
  @amount = amount
  @application_fee_amount = application_fee_amount
  @capture_method = capture_method
  @currency = currency
  @customer = customer
  @description = description
  @excluded_payment_method_types = excluded_payment_method_types
  @expand = expand
  @metadata = 
  @payment_method = payment_method
  @payment_method_configuration = payment_method_configuration
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @receipt_email = receipt_email
  @setup_future_usage = setup_future_usage
  @shipping = shipping
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
  @transfer_group = transfer_group
end

Instance Attribute Details

#amountObject

Amount intended to be collected by this PaymentIntent. A positive integer representing how much to charge in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge currency](stripe.com/docs/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).



2249
2250
2251
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2249

def amount
  @amount
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



2251
2252
2253
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2251

def application_fee_amount
  @application_fee_amount
end

#capture_methodObject

Controls when the funds will be captured from the customer’s account.



2253
2254
2255
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2253

def capture_method
  @capture_method
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



2255
2256
2257
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2255

def currency
  @currency
end

#customerObject

ID of the Customer this PaymentIntent belongs to, if one exists.

Payment methods attached to other Customers cannot be used with this PaymentIntent.

If [setup_future_usage](stripe.com/docs/api#payment_intent_object-setup_future_usage) is set and this PaymentIntent’s payment method is not ‘card_present`, then the payment method attaches to the Customer after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is `card_present` and isn’t a digital wallet, then a [generated_card](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Customer instead.



2261
2262
2263
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2261

def customer
  @customer
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



2263
2264
2265
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2263

def description
  @description
end

#excluded_payment_method_typesObject

The list of payment method types to exclude from use with this payment.



2265
2266
2267
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2265

def excluded_payment_method_types
  @excluded_payment_method_types
end

#expandObject

Specifies which fields in the response should be expanded.



2267
2268
2269
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2267

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2269
2270
2271
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2269

def 
  @metadata
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or [compatible Source](stripe.com/docs/payments/payment-methods/transitioning#compatibility) object) to attach to this PaymentIntent. To unset this field to null, pass in an empty string.



2271
2272
2273
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2271

def payment_method
  @payment_method
end

#payment_method_configurationObject

The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this PaymentIntent.



2273
2274
2275
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2273

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the [payment_method](stripe.com/docs/api/payment_intents/object#payment_intent_object-payment_method) property on the PaymentIntent.



2277
2278
2279
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2277

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment-method-specific configuration for this PaymentIntent.



2279
2280
2281
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2279

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, card) that this PaymentIntent can use. Use ‘automatic_payment_methods` to manage payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).



2281
2282
2283
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2281

def payment_method_types
  @payment_method_types
end

#receipt_emailObject

Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).



2283
2284
2285
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2283

def receipt_email
  @receipt_email
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



2293
2294
2295
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2293

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this PaymentIntent.



2295
2296
2297
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2295

def shipping
  @shipping
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).

Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.



2299
2300
2301
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2299

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



2301
2302
2303
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2301

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

Use this parameter to automatically create a Transfer when the payment succeeds. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



2303
2304
2305
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2303

def transfer_data
  @transfer_data
end

#transfer_groupObject

A string that identifies the resulting payment as part of a group. You can only provide ‘transfer_group` if it hasn’t been set. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



2305
2306
2307
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2305

def transfer_group
  @transfer_group
end