Class: Stripe::PaymentIntentUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: AmountDetails, Hooks, MandateData, PaymentDetails, PaymentMethodData, PaymentMethodOptions, Shipping, TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount intended to be collected by this PaymentIntent.
-
#amount_details ⇒ Object
Provides industry-specific information about the amount.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
ID of the Customer this PaymentIntent belongs to, if one exists.
-
#customer_account ⇒ Object
ID of the Account this PaymentIntent belongs to, if one exists.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#excluded_payment_method_types ⇒ Object
The list of payment method types to exclude from use with this payment.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fx_quote ⇒ Object
The FX rate in the quote is validated and used to convert the presentment amount to the settlement amount.
-
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle.
-
#mandate_data ⇒ Object
This hash contains details about the Mandate to create.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment_details ⇒ Object
Provides industry-specific information about the charge.
-
#payment_method ⇒ Object
Attribute for param field payment_method.
-
#payment_method_configuration ⇒ Object
The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this PaymentIntent.
-
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod.
-
#payment_method_options ⇒ Object
Payment-method-specific configuration for this PaymentIntent.
-
#payment_method_types ⇒ Object
The list of payment method types (for example, card) that this PaymentIntent can use.
-
#receipt_email ⇒ Object
Email address that the receipt for the resulting payment will be sent to.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#shipping ⇒ Object
Shipping information for this PaymentIntent.
-
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card charge.
-
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge.
-
#transfer_data ⇒ Object
Use this parameter to automatically create a Transfer when the payment succeeds.
-
#transfer_group ⇒ Object
A string that identifies the resulting payment as part of a group.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_details: nil, application_fee_amount: nil, capture_method: nil, currency: nil, customer: nil, customer_account: nil, description: nil, excluded_payment_method_types: nil, expand: nil, fx_quote: nil, hooks: nil, mandate_data: nil, metadata: nil, payment_details: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, receipt_email: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ PaymentIntentUpdateParams
Returns a new instance of PaymentIntentUpdateParams.
3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 3710 3711 3712 3713 3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 3740 3741 3742 3743 3744 3745 3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3700 def initialize( amount: nil, amount_details: nil, application_fee_amount: nil, capture_method: nil, currency: nil, customer: nil, customer_account: nil, description: nil, excluded_payment_method_types: nil, expand: nil, fx_quote: nil, hooks: nil, mandate_data: nil, metadata: nil, payment_details: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, receipt_email: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil ) @amount = amount @amount_details = amount_details @application_fee_amount = application_fee_amount @capture_method = capture_method @currency = currency @customer = customer @customer_account = customer_account @description = description @excluded_payment_method_types = excluded_payment_method_types @expand = @fx_quote = fx_quote @hooks = hooks @mandate_data = mandate_data @metadata = @payment_details = payment_details @payment_method = payment_method @payment_method_configuration = payment_method_configuration @payment_method_data = payment_method_data @payment_method_options = @payment_method_types = payment_method_types @receipt_email = receipt_email @setup_future_usage = setup_future_usage @shipping = shipping @statement_descriptor = statement_descriptor @statement_descriptor_suffix = statement_descriptor_suffix @transfer_data = transfer_data @transfer_group = transfer_group end |
Instance Attribute Details
#amount ⇒ Object
Amount intended to be collected by this PaymentIntent. A positive integer representing how much to charge in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge currency](stripe.com/docs/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).
3626 3627 3628 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3626 def amount @amount end |
#amount_details ⇒ Object
Provides industry-specific information about the amount.
3628 3629 3630 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3628 def amount_details @amount_details end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
3630 3631 3632 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3630 def application_fee_amount @application_fee_amount end |
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
3632 3633 3634 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3632 def capture_method @capture_method end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
3634 3635 3636 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3634 def currency @currency end |
#customer ⇒ Object
ID of the Customer this PaymentIntent belongs to, if one exists.
Payment methods attached to other Customers cannot be used with this PaymentIntent.
If [setup_future_usage](stripe.com/docs/api#payment_intent_object-setup_future_usage) is set and this PaymentIntent’s payment method is not ‘card_present`, then the payment method attaches to the Customer after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is `card_present` and isn’t a digital wallet, then a [generated_card](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Customer instead.
3640 3641 3642 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3640 def customer @customer end |
#customer_account ⇒ Object
ID of the Account this PaymentIntent belongs to, if one exists.
Payment methods attached to other Accounts cannot be used with this PaymentIntent.
If [setup_future_usage](stripe.com/docs/api#payment_intent_object-setup_future_usage) is set and this PaymentIntent’s payment method is not ‘card_present`, then the payment method attaches to the Account after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is `card_present` and isn’t a digital wallet, then a [generated_card](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Account instead.
3646 3647 3648 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3646 def customer_account @customer_account end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
3648 3649 3650 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3648 def description @description end |
#excluded_payment_method_types ⇒ Object
The list of payment method types to exclude from use with this payment.
3650 3651 3652 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3650 def excluded_payment_method_types @excluded_payment_method_types end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
3652 3653 3654 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3652 def @expand end |
#fx_quote ⇒ Object
The FX rate in the quote is validated and used to convert the presentment amount to the settlement amount.
3654 3655 3656 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3654 def fx_quote @fx_quote end |
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle
3656 3657 3658 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3656 def hooks @hooks end |
#mandate_data ⇒ Object
This hash contains details about the Mandate to create.
3658 3659 3660 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3658 def mandate_data @mandate_data end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
3660 3661 3662 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3660 def @metadata end |
#payment_details ⇒ Object
Provides industry-specific information about the charge.
3662 3663 3664 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3662 def payment_details @payment_details end |
#payment_method ⇒ Object
Attribute for param field payment_method
3664 3665 3666 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3664 def payment_method @payment_method end |
#payment_method_configuration ⇒ Object
The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this PaymentIntent.
3666 3667 3668 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3666 def payment_method_configuration @payment_method_configuration end |
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the [payment_method](stripe.com/docs/api/payment_intents/object#payment_intent_object-payment_method) property on the PaymentIntent.
3670 3671 3672 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3670 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment-method-specific configuration for this PaymentIntent.
3672 3673 3674 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3672 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types (for example, card) that this PaymentIntent can use. Use ‘automatic_payment_methods` to manage payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).
3674 3675 3676 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3674 def payment_method_types @payment_method_types end |
#receipt_email ⇒ Object
Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).
3676 3677 3678 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3676 def receipt_email @receipt_email end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.
3686 3687 3688 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3686 def setup_future_usage @setup_future_usage end |
#shipping ⇒ Object
Shipping information for this PaymentIntent.
3688 3689 3690 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3688 def shipping @shipping end |
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.
3692 3693 3694 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3692 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.
3694 3695 3696 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3694 def statement_descriptor_suffix @statement_descriptor_suffix end |
#transfer_data ⇒ Object
Use this parameter to automatically create a Transfer when the payment succeeds. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
3696 3697 3698 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3696 def transfer_data @transfer_data end |
#transfer_group ⇒ Object
A string that identifies the resulting payment as part of a group. You can only provide ‘transfer_group` if it hasn’t been set. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
3698 3699 3700 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3698 def transfer_group @transfer_group end |