Class: Stripe::PaymentIntentUpdateParams::AmountDetails::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::AmountDetails::Tax
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#total_tax_amount ⇒ Object
Total portion of the amount that is for tax.
Instance Method Summary collapse
-
#initialize(total_tax_amount: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
Constructor Details
#initialize(total_tax_amount: nil) ⇒ Tax
Returns a new instance of Tax.
138 139 140 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 138 def initialize(total_tax_amount: nil) @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#total_tax_amount ⇒ Object
Total portion of the amount that is for tax.
136 137 138 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 136 def total_tax_amount @total_tax_amount end |