Class: Stripe::PaymentIntentUpdateParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



258
259
260
261
# File 'lib/stripe/params/payment_intent_update_params.rb', line 258

def initialize(online: nil, type: nil)
  @online = online
  @type = type
end

Instance Attribute Details

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



254
255
256
# File 'lib/stripe/params/payment_intent_update_params.rb', line 254

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate.



256
257
258
# File 'lib/stripe/params/payment_intent_update_params.rb', line 256

def type
  @type
end