Class: Stripe::PaymentIntentUpdateParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



229
230
231
232
# File 'lib/stripe/params/payment_intent_update_params.rb', line 229

def initialize(online: nil, type: nil)
  @online = online
  @type = type
end

Instance Attribute Details

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



225
226
227
# File 'lib/stripe/params/payment_intent_update_params.rb', line 225

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate.



227
228
229
# File 'lib/stripe/params/payment_intent_update_params.rb', line 227

def type
  @type
end