Class: Stripe::PaymentIntentUpdateParams::MandateData::CustomerAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::MandateData::CustomerAcceptance
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Online
Instance Attribute Summary collapse
-
#online ⇒ Object
If this is a Mandate accepted online, this hash contains details about the online acceptance.
-
#type ⇒ Object
The type of customer acceptance information included with the Mandate.
Instance Method Summary collapse
-
#initialize(online: nil, type: nil) ⇒ CustomerAcceptance
constructor
A new instance of CustomerAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(online: nil, type: nil) ⇒ CustomerAcceptance
Returns a new instance of CustomerAcceptance.
202 203 204 205 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 202 def initialize(online: nil, type: nil) @online = online @type = type end |
Instance Attribute Details
#online ⇒ Object
If this is a Mandate accepted online, this hash contains details about the online acceptance.
198 199 200 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 198 def online @online end |
#type ⇒ Object
The type of customer acceptance information included with the Mandate.
200 201 202 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 200 def type @type end |