Class: Stripe::PaymentIntentUpdateParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Benefit, CarRental, CarRentalDatum, EventDetails, FleetDatum, Flight, FlightDatum, Lodging, LodgingDatum, MoneyServices, Subscription
Instance Attribute Summary collapse
-
#benefit ⇒ Object
Benefit details for this PaymentIntent.
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#car_rental_data ⇒ Object
Car rental data for this PaymentIntent.
-
#customer_reference ⇒ Object
A unique value to identify the customer.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#fleet_data ⇒ Object
Fleet data for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#flight_data ⇒ Object
Flight data for this PaymentIntent.
-
#location ⇒ Object
The ID of the Payment Location for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#lodging_data ⇒ Object
Lodging data for this PaymentIntent.
-
#money_services ⇒ Object
Money services details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(benefit: nil, car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, fleet_data: nil, flight: nil, flight_data: nil, location: nil, lodging: nil, lodging_data: nil, money_services: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(benefit: nil, car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, fleet_data: nil, flight: nil, flight_data: nil, location: nil, lodging: nil, lodging_data: nil, money_services: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2192 def initialize( benefit: nil, car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, fleet_data: nil, flight: nil, flight_data: nil, location: nil, lodging: nil, lodging_data: nil, money_services: nil, order_reference: nil, subscription: nil ) @benefit = benefit @car_rental = car_rental @car_rental_data = car_rental_data @customer_reference = customer_reference @event_details = event_details @fleet_data = fleet_data @flight = flight @flight_data = flight_data @location = location @lodging = lodging @lodging_data = lodging_data @money_services = money_services @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#benefit ⇒ Object
Benefit details for this PaymentIntent
2160 2161 2162 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2160 def benefit @benefit end |
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
2162 2163 2164 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2162 def car_rental @car_rental end |
#car_rental_data ⇒ Object
Car rental data for this PaymentIntent.
2164 2165 2166 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2164 def car_rental_data @car_rental_data end |
#customer_reference ⇒ Object
A unique value to identify the customer. This field is available only for card payments.
This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.
2168 2169 2170 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2168 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
2170 2171 2172 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2170 def event_details @event_details end |
#fleet_data ⇒ Object
Fleet data for this PaymentIntent.
2172 2173 2174 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2172 def fleet_data @fleet_data end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
2174 2175 2176 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2174 def flight @flight end |
#flight_data ⇒ Object
Flight data for this PaymentIntent.
2176 2177 2178 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2176 def flight_data @flight_data end |
#location ⇒ Object
The ID of the Payment Location for this PaymentIntent.
2178 2179 2180 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2178 def location @location end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
2180 2181 2182 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2180 def lodging @lodging end |
#lodging_data ⇒ Object
Lodging data for this PaymentIntent.
2182 2183 2184 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2182 def lodging_data @lodging_data end |
#money_services ⇒ Object
Money services details for this PaymentIntent.
2184 2185 2186 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2184 def money_services @money_services end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.
For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.
2188 2189 2190 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2188 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
2190 2191 2192 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2190 def subscription @subscription end |