Class: Stripe::PaymentIntentUpdateParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: CarRental, CarRentalDatum, EventDetails, Flight, FlightDatum, Lodging, LodgingDatum, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#car_rental_data ⇒ Object
Car rental data for this PaymentIntent.
-
#customer_reference ⇒ Object
A unique value to identify the customer.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#flight_data ⇒ Object
Flight data for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#lodging_data ⇒ Object
Lodging data for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1879 def initialize( car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @car_rental_data = car_rental_data @customer_reference = customer_reference @event_details = event_details @flight = flight @flight_data = flight_data @lodging = lodging @lodging_data = lodging_data @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
1855 1856 1857 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1855 def car_rental @car_rental end |
#car_rental_data ⇒ Object
Car rental data for this PaymentIntent.
1857 1858 1859 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1857 def car_rental_data @car_rental_data end |
#customer_reference ⇒ Object
A unique value to identify the customer. This field is available only for card payments.
This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.
1861 1862 1863 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1861 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
1863 1864 1865 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1863 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
1865 1866 1867 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1865 def flight @flight end |
#flight_data ⇒ Object
Flight data for this PaymentIntent.
1867 1868 1869 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1867 def flight_data @flight_data end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
1869 1870 1871 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1869 def lodging @lodging end |
#lodging_data ⇒ Object
Lodging data for this PaymentIntent.
1871 1872 1873 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1871 def lodging_data @lodging_data end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.
For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.
1875 1876 1877 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1875 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
1877 1878 1879 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1877 def subscription @subscription end |