Class: Stripe::PaymentIntentUpdateParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Benefit, CarRental, CarRentalDatum, EventDetails, Flight, FlightDatum, Lodging, LodgingDatum, Subscription
Instance Attribute Summary collapse
-
#benefit ⇒ Object
Benefit details for this PaymentIntent.
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#car_rental_data ⇒ Object
Car rental data for this PaymentIntent.
-
#customer_reference ⇒ Object
A unique value to identify the customer.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#flight_data ⇒ Object
Flight data for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#lodging_data ⇒ Object
Lodging data for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(benefit: nil, car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(benefit: nil, car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
1907 1908 1909 1910 1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 1931 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1907 def initialize( benefit: nil, car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil ) @benefit = benefit @car_rental = car_rental @car_rental_data = car_rental_data @customer_reference = customer_reference @event_details = event_details @flight = flight @flight_data = flight_data @lodging = lodging @lodging_data = lodging_data @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#benefit ⇒ Object
Benefit details for this PaymentIntent
1881 1882 1883 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1881 def benefit @benefit end |
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
1883 1884 1885 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1883 def car_rental @car_rental end |
#car_rental_data ⇒ Object
Car rental data for this PaymentIntent.
1885 1886 1887 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1885 def car_rental_data @car_rental_data end |
#customer_reference ⇒ Object
A unique value to identify the customer. This field is available only for card payments.
This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.
1889 1890 1891 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1889 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
1891 1892 1893 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1891 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
1893 1894 1895 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1893 def flight @flight end |
#flight_data ⇒ Object
Flight data for this PaymentIntent.
1895 1896 1897 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1895 def flight_data @flight_data end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
1897 1898 1899 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1897 def lodging @lodging end |
#lodging_data ⇒ Object
Lodging data for this PaymentIntent.
1899 1900 1901 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1899 def lodging_data @lodging_data end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.
For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.
1903 1904 1905 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1903 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
1905 1906 1907 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1905 def subscription @subscription end |