Class: Stripe::PaymentIntentUpdateParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(customer_reference: nil, order_reference: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



227
228
229
230
# File 'lib/stripe/params/payment_intent_update_params.rb', line 227

def initialize(customer_reference: nil, order_reference: nil)
  @customer_reference = customer_reference
  @order_reference = order_reference
end

Instance Attribute Details

#customer_referenceObject

A unique value to identify the customer. This field is available only for card payments.

This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.



219
220
221
# File 'lib/stripe/params/payment_intent_update_params.rb', line 219

def customer_reference
  @customer_reference
end

#order_referenceObject

A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.

Required when the Payment Method Types array contains ‘card`, including when [automatic_payment_methods.enabled](/api/payment_intents/create#create_payment_intent-automatic_payment_methods-enabled) is set to `true`.

For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.



225
226
227
# File 'lib/stripe/params/payment_intent_update_params.rb', line 225

def order_reference
  @order_reference
end