Class: Stripe::PaymentIntentUpdateParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: CarRental, CarRentalDatum, EventDetails, Flight, FlightDatum, Lodging, LodgingDatum, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1865

def initialize(
  car_rental: nil,
  car_rental_data: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  flight_data: nil,
  lodging: nil,
  lodging_data: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @car_rental_data = car_rental_data
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @flight_data = flight_data
  @lodging = lodging
  @lodging_data = lodging_data
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



1839
1840
1841
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1839

def car_rental
  @car_rental
end

#car_rental_dataObject

Car rental data for this PaymentIntent.



1841
1842
1843
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1841

def car_rental_data
  @car_rental_data
end

#customer_referenceObject

A unique value to identify the customer. This field is available only for card payments.

This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.



1845
1846
1847
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1845

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



1847
1848
1849
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1847

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



1849
1850
1851
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1849

def flight
  @flight
end

#flight_dataObject

Flight data for this PaymentIntent.



1851
1852
1853
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1851

def flight_data
  @flight_data
end

#lodgingObject

Lodging reservation details for this PaymentIntent



1853
1854
1855
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1853

def lodging
  @lodging
end

#lodging_dataObject

Lodging data for this PaymentIntent.



1855
1856
1857
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1855

def lodging_data
  @lodging_data
end

#order_referenceObject

A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.

Required when the Payment Method Types array contains ‘card`, including when [automatic_payment_methods.enabled](/api/payment_intents/create#create_payment_intent-automatic_payment_methods-enabled) is set to `true`.

For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.



1861
1862
1863
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1861

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



1863
1864
1865
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1863

def subscription
  @subscription
end