Class: Stripe::PaymentIntentUpdateParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Benefit, CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#benefit ⇒ Object
Benefit details for this PaymentIntent.
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(benefit: nil, car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(benefit: nil, car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 928 def initialize( benefit: nil, car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @benefit = benefit @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#benefit ⇒ Object
Benefit details for this PaymentIntent
912 913 914 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 912 def benefit @benefit end |
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
914 915 916 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 914 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
916 917 918 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 916 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
918 919 920 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 918 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
920 921 922 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 920 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
922 923 924 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 922 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
924 925 926 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 924 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
926 927 928 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 926 def subscription @subscription end |