Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#distance ⇒ Object
The details of the distance traveled during the rental period.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#pickup_location_name ⇒ Object
Name of the pickup location.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#return_location_name ⇒ Object
Name of the return location.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
The vehicle identification number.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental
Returns a new instance of CarRental.
538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 538 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @distance = distance @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @pickup_location_name = pickup_location_name @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @return_location_name = return_location_name @tax_exempt = tax_exempt @vehicle_identification_number = vehicle_identification_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
490 491 492 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 490 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
492 493 494 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 492 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
494 495 496 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 494 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
496 497 498 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 496 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
498 499 500 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 498 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
500 501 502 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 500 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
502 503 504 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 502 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
504 505 506 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 504 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
506 507 508 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 506 def delivery @delivery end |
#distance ⇒ Object
The details of the distance traveled during the rental period.
508 509 510 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 508 def distance @distance end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
510 511 512 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 510 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
512 513 514 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 512 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
514 515 516 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 514 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
516 517 518 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 516 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
518 519 520 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 518 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object
Name of the pickup location.
520 521 522 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 520 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object
Rental rate.
522 523 524 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 522 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of day, week or month
524 525 526 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 524 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
526 527 528 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 526 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
528 529 530 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 528 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
530 531 532 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 530 def return_at @return_at end |
#return_location_name ⇒ Object
Name of the return location.
532 533 534 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 532 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
534 535 536 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 534 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object
The vehicle identification number.
536 537 538 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 536 def vehicle_identification_number @vehicle_identification_number end |