Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental

Returns a new instance of CarRental.



406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
# File 'lib/stripe/params/payment_intent_update_params.rb', line 406

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  distance: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  pickup_location_name: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  return_location_name: nil,
  tax_exempt: nil,
  vehicle_identification_number: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @distance = distance
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @pickup_location_name = pickup_location_name
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @return_location_name = return_location_name
  @tax_exempt = tax_exempt
  @vehicle_identification_number = vehicle_identification_number
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



358
359
360
# File 'lib/stripe/params/payment_intent_update_params.rb', line 358

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



360
361
362
# File 'lib/stripe/params/payment_intent_update_params.rb', line 360

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



362
363
364
# File 'lib/stripe/params/payment_intent_update_params.rb', line 362

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



364
365
366
# File 'lib/stripe/params/payment_intent_update_params.rb', line 364

def car_make
  @car_make
end

#car_modelObject

Model of the car.



366
367
368
# File 'lib/stripe/params/payment_intent_update_params.rb', line 366

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



368
369
370
# File 'lib/stripe/params/payment_intent_update_params.rb', line 368

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



370
371
372
# File 'lib/stripe/params/payment_intent_update_params.rb', line 370

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



372
373
374
# File 'lib/stripe/params/payment_intent_update_params.rb', line 372

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



374
375
376
# File 'lib/stripe/params/payment_intent_update_params.rb', line 374

def delivery
  @delivery
end

#distanceObject

The details of the distance traveled during the rental period.



376
377
378
# File 'lib/stripe/params/payment_intent_update_params.rb', line 376

def distance
  @distance
end

#driversObject

The details of the passengers in the travel reservation



378
379
380
# File 'lib/stripe/params/payment_intent_update_params.rb', line 378

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



380
381
382
# File 'lib/stripe/params/payment_intent_update_params.rb', line 380

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



382
383
384
# File 'lib/stripe/params/payment_intent_update_params.rb', line 382

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



384
385
386
# File 'lib/stripe/params/payment_intent_update_params.rb', line 384

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



386
387
388
# File 'lib/stripe/params/payment_intent_update_params.rb', line 386

def pickup_at
  @pickup_at
end

#pickup_location_nameObject

Name of the pickup location.



388
389
390
# File 'lib/stripe/params/payment_intent_update_params.rb', line 388

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject

Rental rate.



390
391
392
# File 'lib/stripe/params/payment_intent_update_params.rb', line 390

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



392
393
394
# File 'lib/stripe/params/payment_intent_update_params.rb', line 392

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



394
395
396
# File 'lib/stripe/params/payment_intent_update_params.rb', line 394

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



396
397
398
# File 'lib/stripe/params/payment_intent_update_params.rb', line 396

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



398
399
400
# File 'lib/stripe/params/payment_intent_update_params.rb', line 398

def return_at
  @return_at
end

#return_location_nameObject

Name of the return location.



400
401
402
# File 'lib/stripe/params/payment_intent_update_params.rb', line 400

def return_location_name
  @return_location_name
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



402
403
404
# File 'lib/stripe/params/payment_intent_update_params.rb', line 402

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject

The vehicle identification number.



404
405
406
# File 'lib/stripe/params/payment_intent_update_params.rb', line 404

def vehicle_identification_number
  @vehicle_identification_number
end