Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental

Returns a new instance of CarRental.



389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
# File 'lib/stripe/params/payment_intent_update_params.rb', line 389

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  distance: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  pickup_location_name: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  return_location_name: nil,
  tax_exempt: nil,
  vehicle_identification_number: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @distance = distance
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @pickup_location_name = pickup_location_name
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @return_location_name = return_location_name
  @tax_exempt = tax_exempt
  @vehicle_identification_number = vehicle_identification_number
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



341
342
343
# File 'lib/stripe/params/payment_intent_update_params.rb', line 341

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



343
344
345
# File 'lib/stripe/params/payment_intent_update_params.rb', line 343

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



345
346
347
# File 'lib/stripe/params/payment_intent_update_params.rb', line 345

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



347
348
349
# File 'lib/stripe/params/payment_intent_update_params.rb', line 347

def car_make
  @car_make
end

#car_modelObject

Model of the car.



349
350
351
# File 'lib/stripe/params/payment_intent_update_params.rb', line 349

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



351
352
353
# File 'lib/stripe/params/payment_intent_update_params.rb', line 351

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



353
354
355
# File 'lib/stripe/params/payment_intent_update_params.rb', line 353

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



355
356
357
# File 'lib/stripe/params/payment_intent_update_params.rb', line 355

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



357
358
359
# File 'lib/stripe/params/payment_intent_update_params.rb', line 357

def delivery
  @delivery
end

#distanceObject

The details of the distance traveled during the rental period.



359
360
361
# File 'lib/stripe/params/payment_intent_update_params.rb', line 359

def distance
  @distance
end

#driversObject

The details of the passengers in the travel reservation



361
362
363
# File 'lib/stripe/params/payment_intent_update_params.rb', line 361

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



363
364
365
# File 'lib/stripe/params/payment_intent_update_params.rb', line 363

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



365
366
367
# File 'lib/stripe/params/payment_intent_update_params.rb', line 365

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



367
368
369
# File 'lib/stripe/params/payment_intent_update_params.rb', line 367

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



369
370
371
# File 'lib/stripe/params/payment_intent_update_params.rb', line 369

def pickup_at
  @pickup_at
end

#pickup_location_nameObject

Name of the pickup location.



371
372
373
# File 'lib/stripe/params/payment_intent_update_params.rb', line 371

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject

Rental rate.



373
374
375
# File 'lib/stripe/params/payment_intent_update_params.rb', line 373

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



375
376
377
# File 'lib/stripe/params/payment_intent_update_params.rb', line 375

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



377
378
379
# File 'lib/stripe/params/payment_intent_update_params.rb', line 377

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



379
380
381
# File 'lib/stripe/params/payment_intent_update_params.rb', line 379

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



381
382
383
# File 'lib/stripe/params/payment_intent_update_params.rb', line 381

def return_at
  @return_at
end

#return_location_nameObject

Name of the return location.



383
384
385
# File 'lib/stripe/params/payment_intent_update_params.rb', line 383

def return_location_name
  @return_location_name
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



385
386
387
# File 'lib/stripe/params/payment_intent_update_params.rb', line 385

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject

The vehicle identification number.



387
388
389
# File 'lib/stripe/params/payment_intent_update_params.rb', line 387

def vehicle_identification_number
  @vehicle_identification_number
end