Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



329
330
331
332
333
# File 'lib/stripe/params/payment_intent_update_params.rb', line 329

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



323
324
325
# File 'lib/stripe/params/payment_intent_update_params.rb', line 323

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



325
326
327
# File 'lib/stripe/params/payment_intent_update_params.rb', line 325

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



327
328
329
# File 'lib/stripe/params/payment_intent_update_params.rb', line 327

def phone
  @phone
end