Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
252 253 254 255 256 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 252 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
246 247 248 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 246 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
248 249 250 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 248 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
250 251 252 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 250 def phone @phone end |