Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
235 236 237 238 239 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 235 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
229 230 231 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 229 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
231 232 233 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 231 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
233 234 235 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 233 def phone @phone end |