Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::CarRental::Driver
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::CarRental::Driver
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#driver_identification_number ⇒ Object
Driver’s identification number.
-
#driver_tax_number ⇒ Object
Driver’s tax number.
-
#name ⇒ Object
Full name of the person or entity on the car reservation.
Instance Method Summary collapse
-
#initialize(driver_identification_number: nil, driver_tax_number: nil, name: nil) ⇒ Driver
constructor
A new instance of Driver.
Methods inherited from RequestParams
Constructor Details
#initialize(driver_identification_number: nil, driver_tax_number: nil, name: nil) ⇒ Driver
Returns a new instance of Driver.
289 290 291 292 293 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 289 def initialize(driver_identification_number: nil, driver_tax_number: nil, name: nil) @driver_identification_number = driver_identification_number @driver_tax_number = driver_tax_number @name = name end |
Instance Attribute Details
#driver_identification_number ⇒ Object
Driver’s identification number.
283 284 285 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 283 def driver_identification_number @driver_identification_number end |
#driver_tax_number ⇒ Object
Driver’s tax number.
285 286 287 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 285 def driver_tax_number @driver_tax_number end |
#name ⇒ Object
Full name of the person or entity on the car reservation.
287 288 289 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 287 def name @name end |