Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::CarRentalDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::CarRentalDatum
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Affiliate, Distance, Driver, DropOff, Insurance, Pickup, Total, Vehicle
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate (such as travel agency) details for the rental.
-
#booking_number ⇒ Object
Booking confirmation number for the car rental.
-
#carrier_name ⇒ Object
Name of the car rental company.
-
#customer_service_phone_number ⇒ Object
Customer service phone number for the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#distance ⇒ Object
Distance details for the rental.
-
#drivers ⇒ Object
List of drivers for the rental.
-
#drop_off ⇒ Object
Drop-off location details.
-
#insurances ⇒ Object
Insurance details for the rental.
-
#no_show_indicator ⇒ Object
Indicates if the customer was a no-show.
-
#pickup ⇒ Object
Pickup location details.
-
#renter_name ⇒ Object
Name of the person renting the vehicle.
-
#total ⇒ Object
Total cost breakdown for the rental.
-
#vehicle ⇒ Object
Vehicle details for the rental.
Instance Method Summary collapse
-
#initialize(affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil) ⇒ CarRentalDatum
constructor
A new instance of CarRentalDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil) ⇒ CarRentalDatum
Returns a new instance of CarRentalDatum.
814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 814 def initialize( affiliate: nil, booking_number: nil, carrier_name: nil, customer_service_phone_number: nil, days_rented: nil, distance: nil, drivers: nil, drop_off: nil, insurances: nil, no_show_indicator: nil, pickup: nil, renter_name: nil, total: nil, vehicle: nil ) @affiliate = affiliate @booking_number = booking_number @carrier_name = carrier_name @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @distance = distance @drivers = drivers @drop_off = drop_off @insurances = insurances @no_show_indicator = no_show_indicator @pickup = pickup @renter_name = renter_name @total = total @vehicle = vehicle end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate (such as travel agency) details for the rental.
786 787 788 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 786 def affiliate @affiliate end |
#booking_number ⇒ Object
Booking confirmation number for the car rental.
788 789 790 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 788 def booking_number @booking_number end |
#carrier_name ⇒ Object
Name of the car rental company.
790 791 792 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 790 def carrier_name @carrier_name end |
#customer_service_phone_number ⇒ Object
Customer service phone number for the car rental company.
792 793 794 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 792 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
794 795 796 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 794 def days_rented @days_rented end |
#distance ⇒ Object
Distance details for the rental.
796 797 798 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 796 def distance @distance end |
#drivers ⇒ Object
List of drivers for the rental.
798 799 800 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 798 def drivers @drivers end |
#drop_off ⇒ Object
Drop-off location details.
800 801 802 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 800 def drop_off @drop_off end |
#insurances ⇒ Object
Insurance details for the rental.
802 803 804 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 802 def insurances @insurances end |
#no_show_indicator ⇒ Object
Indicates if the customer was a no-show.
804 805 806 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 804 def no_show_indicator @no_show_indicator end |
#pickup ⇒ Object
Pickup location details.
806 807 808 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 806 def pickup @pickup end |
#renter_name ⇒ Object
Name of the person renting the vehicle.
808 809 810 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 808 def renter_name @renter_name end |
#total ⇒ Object
Total cost breakdown for the rental.
810 811 812 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 810 def total @total end |
#vehicle ⇒ Object
Vehicle details for the rental.
812 813 814 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 812 def vehicle @vehicle end |