Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



941
942
943
944
945
# File 'lib/stripe/params/payment_intent_update_params.rb', line 941

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



935
936
937
# File 'lib/stripe/params/payment_intent_update_params.rb', line 935

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



937
938
939
# File 'lib/stripe/params/payment_intent_update_params.rb', line 937

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



939
940
941
# File 'lib/stripe/params/payment_intent_update_params.rb', line 939

def phone
  @phone
end