Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



897
898
899
900
901
# File 'lib/stripe/params/payment_intent_update_params.rb', line 897

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



891
892
893
# File 'lib/stripe/params/payment_intent_update_params.rb', line 891

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



893
894
895
# File 'lib/stripe/params/payment_intent_update_params.rb', line 893

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



895
896
897
# File 'lib/stripe/params/payment_intent_update_params.rb', line 895

def phone
  @phone
end