Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



881
882
883
884
885
# File 'lib/stripe/params/payment_intent_update_params.rb', line 881

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



875
876
877
# File 'lib/stripe/params/payment_intent_update_params.rb', line 875

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



877
878
879
# File 'lib/stripe/params/payment_intent_update_params.rb', line 877

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



879
880
881
# File 'lib/stripe/params/payment_intent_update_params.rb', line 879

def phone
  @phone
end