Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1039 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
1023 1024 1025 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1023 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
1025 1026 1027 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1025 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
1027 1028 1029 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1027 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
1029 1030 1031 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1029 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
1031 1032 1033 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1031 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
1033 1034 1035 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1033 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
1035 1036 1037 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1035 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
1037 1038 1039 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1037 def ticket_number @ticket_number end |