Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 650 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
634 635 636 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 634 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
636 637 638 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 636 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
638 639 640 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 638 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
640 641 642 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 640 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
642 643 644 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 642 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
644 645 646 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 644 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
646 647 648 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 646 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
648 649 650 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 648 def ticket_number @ticket_number end |