Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1111
1112
1113
1114
1115
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1111

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1105
1106
1107
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1105

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1107
1108
1109
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1107

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1109
1110
1111
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1109

def phone
  @phone
end