Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



974
975
976
977
978
# File 'lib/stripe/params/payment_intent_update_params.rb', line 974

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



968
969
970
# File 'lib/stripe/params/payment_intent_update_params.rb', line 968

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



970
971
972
# File 'lib/stripe/params/payment_intent_update_params.rb', line 970

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



972
973
974
# File 'lib/stripe/params/payment_intent_update_params.rb', line 972

def phone
  @phone
end