Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



958
959
960
961
962
# File 'lib/stripe/params/payment_intent_update_params.rb', line 958

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



952
953
954
# File 'lib/stripe/params/payment_intent_update_params.rb', line 952

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



954
955
956
# File 'lib/stripe/params/payment_intent_update_params.rb', line 954

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



956
957
958
# File 'lib/stripe/params/payment_intent_update_params.rb', line 956

def phone
  @phone
end