Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



984
985
986
987
988
# File 'lib/stripe/params/payment_intent_update_params.rb', line 984

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



978
979
980
# File 'lib/stripe/params/payment_intent_update_params.rb', line 978

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



980
981
982
# File 'lib/stripe/params/payment_intent_update_params.rb', line 980

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



982
983
984
# File 'lib/stripe/params/payment_intent_update_params.rb', line 982

def phone
  @phone
end