Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



594
595
596
597
598
# File 'lib/stripe/params/payment_intent_update_params.rb', line 594

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



588
589
590
# File 'lib/stripe/params/payment_intent_update_params.rb', line 588

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



590
591
592
# File 'lib/stripe/params/payment_intent_update_params.rb', line 590

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



592
593
594
# File 'lib/stripe/params/payment_intent_update_params.rb', line 592

def phone
  @phone
end