Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



586
587
588
589
590
# File 'lib/stripe/params/payment_intent_update_params.rb', line 586

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



580
581
582
# File 'lib/stripe/params/payment_intent_update_params.rb', line 580

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



582
583
584
# File 'lib/stripe/params/payment_intent_update_params.rb', line 582

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



584
585
586
# File 'lib/stripe/params/payment_intent_update_params.rb', line 584

def phone
  @phone
end