Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
586 587 588 589 590 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 586 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
580 581 582 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 580 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
582 583 584 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 582 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
584 585 586 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 584 def phone @phone end |