Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Flight::Segment
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::Flight::Segment
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The flight segment amount.
-
#arrival_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the arrival airport.
-
#arrives_at ⇒ Object
The arrival time for the flight segment.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier operating the flight segment.
-
#departs_at ⇒ Object
The departure time for the flight segment.
-
#departure_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the departure airport.
-
#flight_number ⇒ Object
The flight number associated with the segment.
-
#service_class ⇒ Object
The fare class for the segment.
Instance Method Summary collapse
-
#initialize(amount: nil, arrival_airport: nil, arrives_at: nil, carrier: nil, departs_at: nil, departure_airport: nil, flight_number: nil, service_class: nil) ⇒ Segment
constructor
A new instance of Segment.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, arrival_airport: nil, arrives_at: nil, carrier: nil, departs_at: nil, departure_airport: nil, flight_number: nil, service_class: nil) ⇒ Segment
Returns a new instance of Segment.
1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1015 def initialize( amount: nil, arrival_airport: nil, arrives_at: nil, carrier: nil, departs_at: nil, departure_airport: nil, flight_number: nil, service_class: nil ) @amount = amount @arrival_airport = arrival_airport @arrives_at = arrives_at @carrier = carrier @departs_at = departs_at @departure_airport = departure_airport @flight_number = flight_number @service_class = service_class end |
Instance Attribute Details
#amount ⇒ Object
The flight segment amount.
999 1000 1001 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 999 def amount @amount end |
#arrival_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the arrival airport.
1001 1002 1003 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1001 def arrival_airport @arrival_airport end |
#arrives_at ⇒ Object
The arrival time for the flight segment. Measured in seconds since the Unix epoch.
1003 1004 1005 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1003 def arrives_at @arrives_at end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier operating the flight segment.
1005 1006 1007 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1005 def carrier @carrier end |
#departs_at ⇒ Object
The departure time for the flight segment. Measured in seconds since the Unix epoch.
1007 1008 1009 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1007 def departs_at @departs_at end |
#departure_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the departure airport.
1009 1010 1011 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1009 def departure_airport @departure_airport end |
#flight_number ⇒ Object
The flight number associated with the segment
1011 1012 1013 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1011 def flight_number @flight_number end |
#service_class ⇒ Object
The fare class for the segment.
1013 1014 1015 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1013 def service_class @service_class end |