Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::FlightDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::FlightDatum
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Affiliate, Insurance, Passenger, Segment, Total
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details if applicable.
-
#booking_number ⇒ Object
Reservation reference.
-
#computerized_reservation_system ⇒ Object
Computerized reservation system used to make the reservation and purchase the ticket.
-
#endorsements_and_restrictions ⇒ Object
Ticket restrictions.
-
#insurances ⇒ Object
List of insurances.
-
#passengers ⇒ Object
List of passengers.
-
#segments ⇒ Object
List of flight segments.
-
#ticket_electronically_issued_indicator ⇒ Object
Electronic ticket indicator.
-
#total ⇒ Object
Total cost breakdown.
-
#transaction_type ⇒ Object
Type of flight transaction.
Instance Method Summary collapse
-
#initialize(affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil) ⇒ FlightDatum
constructor
A new instance of FlightDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil) ⇒ FlightDatum
Returns a new instance of FlightDatum.
1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1320 def initialize( affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil ) @affiliate = affiliate @booking_number = booking_number @computerized_reservation_system = computerized_reservation_system @endorsements_and_restrictions = endorsements_and_restrictions @insurances = insurances @passengers = passengers @segments = segments @ticket_electronically_issued_indicator = ticket_electronically_issued_indicator @total = total @transaction_type = transaction_type end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details if applicable.
1300 1301 1302 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1300 def affiliate @affiliate end |
#booking_number ⇒ Object
Reservation reference.
1302 1303 1304 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1302 def booking_number @booking_number end |
#computerized_reservation_system ⇒ Object
Computerized reservation system used to make the reservation and purchase the ticket.
1304 1305 1306 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1304 def computerized_reservation_system @computerized_reservation_system end |
#endorsements_and_restrictions ⇒ Object
Ticket restrictions.
1306 1307 1308 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1306 def endorsements_and_restrictions @endorsements_and_restrictions end |
#insurances ⇒ Object
List of insurances.
1308 1309 1310 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1308 def insurances @insurances end |
#passengers ⇒ Object
List of passengers.
1310 1311 1312 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1310 def passengers @passengers end |
#segments ⇒ Object
List of flight segments.
1312 1313 1314 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1312 def segments @segments end |
#ticket_electronically_issued_indicator ⇒ Object
Electronic ticket indicator.
1314 1315 1316 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1314 def ticket_electronically_issued_indicator @ticket_electronically_issued_indicator end |
#total ⇒ Object
Total cost breakdown.
1316 1317 1318 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1316 def total @total end |
#transaction_type ⇒ Object
Type of flight transaction.
1318 1319 1320 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1318 def transaction_type @transaction_type end |