Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::FlightDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::FlightDatum
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Affiliate, Insurance, Passenger, Segment, Total
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details if applicable.
-
#booking_number ⇒ Object
Reservation reference.
-
#computerized_reservation_system ⇒ Object
Computerized reservation system used to make the reservation and purchase the ticket.
-
#endorsements_and_restrictions ⇒ Object
Ticket restrictions.
-
#insurances ⇒ Object
List of insurances.
-
#passengers ⇒ Object
List of passengers.
-
#segments ⇒ Object
List of flight segments.
-
#ticket_electronically_issued_indicator ⇒ Object
Electronic ticket indicator.
-
#total ⇒ Object
Total cost breakdown.
-
#transaction_type ⇒ Object
Type of flight transaction.
Instance Method Summary collapse
-
#initialize(affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil) ⇒ FlightDatum
constructor
A new instance of FlightDatum.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil) ⇒ FlightDatum
Returns a new instance of FlightDatum.
1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1304 def initialize( affiliate: nil, booking_number: nil, computerized_reservation_system: nil, endorsements_and_restrictions: nil, insurances: nil, passengers: nil, segments: nil, ticket_electronically_issued_indicator: nil, total: nil, transaction_type: nil ) @affiliate = affiliate @booking_number = booking_number @computerized_reservation_system = computerized_reservation_system @endorsements_and_restrictions = endorsements_and_restrictions @insurances = insurances @passengers = passengers @segments = segments @ticket_electronically_issued_indicator = ticket_electronically_issued_indicator @total = total @transaction_type = transaction_type end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details if applicable.
1284 1285 1286 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1284 def affiliate @affiliate end |
#booking_number ⇒ Object
Reservation reference.
1286 1287 1288 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1286 def booking_number @booking_number end |
#computerized_reservation_system ⇒ Object
Computerized reservation system used to make the reservation and purchase the ticket.
1288 1289 1290 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1288 def computerized_reservation_system @computerized_reservation_system end |
#endorsements_and_restrictions ⇒ Object
Ticket restrictions.
1290 1291 1292 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1290 def endorsements_and_restrictions @endorsements_and_restrictions end |
#insurances ⇒ Object
List of insurances.
1292 1293 1294 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1292 def insurances @insurances end |
#passengers ⇒ Object
List of passengers.
1294 1295 1296 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1294 def passengers @passengers end |
#segments ⇒ Object
List of flight segments.
1296 1297 1298 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1296 def segments @segments end |
#ticket_electronically_issued_indicator ⇒ Object
Electronic ticket indicator.
1298 1299 1300 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1298 def ticket_electronically_issued_indicator @ticket_electronically_issued_indicator end |
#total ⇒ Object
Total cost breakdown.
1300 1301 1302 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1300 def total @total end |
#transaction_type ⇒ Object
Type of flight transaction.
1302 1303 1304 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1302 def transaction_type @transaction_type end |