Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::FlightDatum::Affiliate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::FlightDatum::Affiliate
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#code ⇒ Object
Affiliate partner code.
-
#name ⇒ Object
Name of affiliate partner.
-
#travel_authorization_code ⇒ Object
Code provided by the company to a travel agent authorizing ticket issuance.
Instance Method Summary collapse
-
#initialize(code: nil, name: nil, travel_authorization_code: nil) ⇒ Affiliate
constructor
A new instance of Affiliate.
Methods inherited from RequestParams
Constructor Details
#initialize(code: nil, name: nil, travel_authorization_code: nil) ⇒ Affiliate
Returns a new instance of Affiliate.
1082 1083 1084 1085 1086 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1082 def initialize(code: nil, name: nil, travel_authorization_code: nil) @code = code @name = name @travel_authorization_code = end |
Instance Attribute Details
#code ⇒ Object
Affiliate partner code.
1076 1077 1078 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1076 def code @code end |
#name ⇒ Object
Name of affiliate partner.
1078 1079 1080 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1078 def name @name end |
#travel_authorization_code ⇒ Object
Code provided by the company to a travel agent authorizing ticket issuance.
1080 1081 1082 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1080 def @travel_authorization_code end |