Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1395
1396
1397
1398
1399
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1395

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1389
1390
1391
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1389

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1391
1392
1393
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1391

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1393
1394
1395
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1393

def phone
  @phone
end