Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1379
1380
1381
1382
1383
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1379

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1373
1374
1375
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1373

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1375
1376
1377
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1375

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1377
1378
1379
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1377

def phone
  @phone
end