Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
1405 1406 1407 1408 1409 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1405 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
1399 1400 1401 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1399 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
1401 1402 1403 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1401 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
1403 1404 1405 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1403 def phone @phone end |