Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



746
747
748
749
750
# File 'lib/stripe/params/payment_intent_update_params.rb', line 746

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



740
741
742
# File 'lib/stripe/params/payment_intent_update_params.rb', line 740

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



742
743
744
# File 'lib/stripe/params/payment_intent_update_params.rb', line 742

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



744
745
746
# File 'lib/stripe/params/payment_intent_update_params.rb', line 744

def phone
  @phone
end