Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::LodgingDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::LodgingDatum
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Accommodation, Affiliate, Guest, Host, Insurance, Total
Instance Attribute Summary collapse
-
#accommodation ⇒ Object
Accommodation details for the lodging.
-
#affiliate ⇒ Object
Affiliate details if applicable.
-
#booking_number ⇒ Object
Booking confirmation number for the lodging.
-
#checkin_at ⇒ Object
Check-in date.
-
#checkout_at ⇒ Object
Check-out date.
-
#customer_service_phone_number ⇒ Object
Customer service phone number for the lodging company.
-
#fire_safety_act_compliance_indicator ⇒ Object
Whether the lodging is compliant with any hotel fire safety regulations.
-
#guests ⇒ Object
List of guests for the lodging.
-
#host ⇒ Object
Host details for the lodging.
-
#insurances ⇒ Object
List of insurances for the lodging.
-
#no_show_indicator ⇒ Object
Whether the renter is a no-show.
-
#renter_id_number ⇒ Object
Renter ID number for the lodging.
-
#renter_name ⇒ Object
Renter name for the lodging.
-
#total ⇒ Object
Total details for the lodging.
Instance Method Summary collapse
-
#initialize(accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil) ⇒ LodgingDatum
constructor
A new instance of LodgingDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil) ⇒ LodgingDatum
Returns a new instance of LodgingDatum.
1908 1909 1910 1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1908 def initialize( accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil ) @accommodation = accommodation @affiliate = affiliate @booking_number = booking_number @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @fire_safety_act_compliance_indicator = fire_safety_act_compliance_indicator @guests = guests @host = host @insurances = insurances @no_show_indicator = no_show_indicator @renter_id_number = renter_id_number @renter_name = renter_name @total = total end |
Instance Attribute Details
#accommodation ⇒ Object
Accommodation details for the lodging.
1880 1881 1882 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1880 def accommodation @accommodation end |
#affiliate ⇒ Object
Affiliate details if applicable.
1882 1883 1884 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1882 def affiliate @affiliate end |
#booking_number ⇒ Object
Booking confirmation number for the lodging.
1884 1885 1886 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1884 def booking_number @booking_number end |
#checkin_at ⇒ Object
Check-in date.
1886 1887 1888 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1886 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Check-out date.
1888 1889 1890 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1888 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
Customer service phone number for the lodging company.
1890 1891 1892 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1890 def customer_service_phone_number @customer_service_phone_number end |
#fire_safety_act_compliance_indicator ⇒ Object
Whether the lodging is compliant with any hotel fire safety regulations.
1892 1893 1894 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1892 def fire_safety_act_compliance_indicator @fire_safety_act_compliance_indicator end |
#guests ⇒ Object
List of guests for the lodging.
1894 1895 1896 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1894 def guests @guests end |
#host ⇒ Object
Host details for the lodging.
1896 1897 1898 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1896 def host @host end |
#insurances ⇒ Object
List of insurances for the lodging.
1898 1899 1900 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1898 def insurances @insurances end |
#no_show_indicator ⇒ Object
Whether the renter is a no-show.
1900 1901 1902 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1900 def no_show_indicator @no_show_indicator end |
#renter_id_number ⇒ Object
Renter ID number for the lodging.
1902 1903 1904 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1902 def renter_id_number @renter_id_number end |
#renter_name ⇒ Object
Renter name for the lodging.
1904 1905 1906 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1904 def renter_name @renter_name end |
#total ⇒ Object
Total details for the lodging.
1906 1907 1908 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1906 def total @total end |