Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::LodgingDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::LodgingDatum
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Accommodation, Affiliate, Guest, Host, Insurance, Total
Instance Attribute Summary collapse
-
#accommodation ⇒ Object
Accommodation details for the lodging.
-
#affiliate ⇒ Object
Affiliate details if applicable.
-
#booking_number ⇒ Object
Booking confirmation number for the lodging.
-
#checkin_at ⇒ Object
Check-in date.
-
#checkout_at ⇒ Object
Check-out date.
-
#customer_service_phone_number ⇒ Object
Customer service phone number for the lodging company.
-
#fire_safety_act_compliance_indicator ⇒ Object
Whether the lodging is compliant with any hotel fire safety regulations.
-
#guests ⇒ Object
List of guests for the lodging.
-
#host ⇒ Object
Host details for the lodging.
-
#insurances ⇒ Object
List of insurances for the lodging.
-
#no_show_indicator ⇒ Object
Whether the renter is a no-show.
-
#renter_id_number ⇒ Object
Renter ID number for the lodging.
-
#renter_name ⇒ Object
Renter name for the lodging.
-
#total ⇒ Object
Total details for the lodging.
Instance Method Summary collapse
-
#initialize(accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil) ⇒ LodgingDatum
constructor
A new instance of LodgingDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil) ⇒ LodgingDatum
Returns a new instance of LodgingDatum.
1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1771 def initialize( accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil ) @accommodation = accommodation @affiliate = affiliate @booking_number = booking_number @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @fire_safety_act_compliance_indicator = fire_safety_act_compliance_indicator @guests = guests @host = host @insurances = insurances @no_show_indicator = no_show_indicator @renter_id_number = renter_id_number @renter_name = renter_name @total = total end |
Instance Attribute Details
#accommodation ⇒ Object
Accommodation details for the lodging.
1743 1744 1745 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1743 def accommodation @accommodation end |
#affiliate ⇒ Object
Affiliate details if applicable.
1745 1746 1747 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1745 def affiliate @affiliate end |
#booking_number ⇒ Object
Booking confirmation number for the lodging.
1747 1748 1749 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1747 def booking_number @booking_number end |
#checkin_at ⇒ Object
Check-in date.
1749 1750 1751 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1749 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Check-out date.
1751 1752 1753 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1751 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
Customer service phone number for the lodging company.
1753 1754 1755 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1753 def customer_service_phone_number @customer_service_phone_number end |
#fire_safety_act_compliance_indicator ⇒ Object
Whether the lodging is compliant with any hotel fire safety regulations.
1755 1756 1757 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1755 def fire_safety_act_compliance_indicator @fire_safety_act_compliance_indicator end |
#guests ⇒ Object
List of guests for the lodging.
1757 1758 1759 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1757 def guests @guests end |
#host ⇒ Object
Host details for the lodging.
1759 1760 1761 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1759 def host @host end |
#insurances ⇒ Object
List of insurances for the lodging.
1761 1762 1763 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1761 def insurances @insurances end |
#no_show_indicator ⇒ Object
Whether the renter is a no-show.
1763 1764 1765 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1763 def no_show_indicator @no_show_indicator end |
#renter_id_number ⇒ Object
Renter ID number for the lodging.
1765 1766 1767 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1765 def renter_id_number @renter_id_number end |
#renter_name ⇒ Object
Renter name for the lodging.
1767 1768 1769 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1767 def renter_name @renter_name end |
#total ⇒ Object
Total details for the lodging.
1769 1770 1771 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1769 def total @total end |