Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::LodgingDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::LodgingDatum
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Accommodation, Affiliate, Guest, Host, Insurance, Total
Instance Attribute Summary collapse
-
#accommodation ⇒ Object
Accommodation details for the lodging.
-
#affiliate ⇒ Object
Affiliate details if applicable.
-
#booking_number ⇒ Object
Booking confirmation number for the lodging.
-
#checkin_at ⇒ Object
Check-in date.
-
#checkout_at ⇒ Object
Check-out date.
-
#customer_service_phone_number ⇒ Object
Customer service phone number for the lodging company.
-
#fire_safety_act_compliance_indicator ⇒ Object
Whether the lodging is compliant with any hotel fire safety regulations.
-
#guests ⇒ Object
List of guests for the lodging.
-
#host ⇒ Object
Host details for the lodging.
-
#insurances ⇒ Object
List of insurances for the lodging.
-
#no_show_indicator ⇒ Object
Whether the renter is a no-show.
-
#renter_id_number ⇒ Object
Renter ID number for the lodging.
-
#renter_name ⇒ Object
Renter name for the lodging.
-
#total ⇒ Object
Total details for the lodging.
Instance Method Summary collapse
-
#initialize(accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil) ⇒ LodgingDatum
constructor
A new instance of LodgingDatum.
Methods inherited from RequestParams
Constructor Details
#initialize(accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil) ⇒ LodgingDatum
Returns a new instance of LodgingDatum.
1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1755 def initialize( accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil ) @accommodation = accommodation @affiliate = affiliate @booking_number = booking_number @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @fire_safety_act_compliance_indicator = fire_safety_act_compliance_indicator @guests = guests @host = host @insurances = insurances @no_show_indicator = no_show_indicator @renter_id_number = renter_id_number @renter_name = renter_name @total = total end |
Instance Attribute Details
#accommodation ⇒ Object
Accommodation details for the lodging.
1727 1728 1729 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1727 def accommodation @accommodation end |
#affiliate ⇒ Object
Affiliate details if applicable.
1729 1730 1731 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1729 def affiliate @affiliate end |
#booking_number ⇒ Object
Booking confirmation number for the lodging.
1731 1732 1733 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1731 def booking_number @booking_number end |
#checkin_at ⇒ Object
Check-in date.
1733 1734 1735 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1733 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Check-out date.
1735 1736 1737 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1735 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
Customer service phone number for the lodging company.
1737 1738 1739 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1737 def customer_service_phone_number @customer_service_phone_number end |
#fire_safety_act_compliance_indicator ⇒ Object
Whether the lodging is compliant with any hotel fire safety regulations.
1739 1740 1741 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1739 def fire_safety_act_compliance_indicator @fire_safety_act_compliance_indicator end |
#guests ⇒ Object
List of guests for the lodging.
1741 1742 1743 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1741 def guests @guests end |
#host ⇒ Object
Host details for the lodging.
1743 1744 1745 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1743 def host @host end |
#insurances ⇒ Object
List of insurances for the lodging.
1745 1746 1747 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1745 def insurances @insurances end |
#no_show_indicator ⇒ Object
Whether the renter is a no-show.
1747 1748 1749 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1747 def no_show_indicator @no_show_indicator end |
#renter_id_number ⇒ Object
Renter ID number for the lodging.
1749 1750 1751 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1749 def renter_id_number @renter_id_number end |
#renter_name ⇒ Object
Renter name for the lodging.
1751 1752 1753 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1751 def renter_name @renter_name end |
#total ⇒ Object
Total details for the lodging.
1753 1754 1755 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1753 def total @total end |