Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::LodgingDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::LodgingDatum
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Accommodation, Affiliate, Guest, Host, Insurance, Total
Instance Attribute Summary collapse
-
#accommodation ⇒ Object
Accommodation details for the lodging.
-
#affiliate ⇒ Object
Affiliate details if applicable.
-
#booking_number ⇒ Object
Booking confirmation number for the lodging.
-
#checkin_at ⇒ Object
Check-in date.
-
#checkout_at ⇒ Object
Check-out date.
-
#customer_service_phone_number ⇒ Object
Customer service phone number for the lodging company.
-
#fire_safety_act_compliance_indicator ⇒ Object
Whether the lodging is compliant with any hotel fire safety regulations.
-
#guests ⇒ Object
List of guests for the lodging.
-
#host ⇒ Object
Host details for the lodging.
-
#insurances ⇒ Object
List of insurances for the lodging.
-
#no_show_indicator ⇒ Object
Whether the renter is a no-show.
-
#renter_id_number ⇒ Object
Renter ID number for the lodging.
-
#renter_name ⇒ Object
Renter name for the lodging.
-
#total ⇒ Object
Total details for the lodging.
Instance Method Summary collapse
-
#initialize(accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil) ⇒ LodgingDatum
constructor
A new instance of LodgingDatum.
Methods inherited from RequestParams
Constructor Details
#initialize(accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil) ⇒ LodgingDatum
Returns a new instance of LodgingDatum.
1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1768 def initialize( accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil ) @accommodation = accommodation @affiliate = affiliate @booking_number = booking_number @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @fire_safety_act_compliance_indicator = fire_safety_act_compliance_indicator @guests = guests @host = host @insurances = insurances @no_show_indicator = no_show_indicator @renter_id_number = renter_id_number @renter_name = renter_name @total = total end |
Instance Attribute Details
#accommodation ⇒ Object
Accommodation details for the lodging.
1740 1741 1742 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1740 def accommodation @accommodation end |
#affiliate ⇒ Object
Affiliate details if applicable.
1742 1743 1744 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1742 def affiliate @affiliate end |
#booking_number ⇒ Object
Booking confirmation number for the lodging.
1744 1745 1746 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1744 def booking_number @booking_number end |
#checkin_at ⇒ Object
Check-in date.
1746 1747 1748 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1746 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Check-out date.
1748 1749 1750 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1748 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
Customer service phone number for the lodging company.
1750 1751 1752 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1750 def customer_service_phone_number @customer_service_phone_number end |
#fire_safety_act_compliance_indicator ⇒ Object
Whether the lodging is compliant with any hotel fire safety regulations.
1752 1753 1754 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1752 def fire_safety_act_compliance_indicator @fire_safety_act_compliance_indicator end |
#guests ⇒ Object
List of guests for the lodging.
1754 1755 1756 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1754 def guests @guests end |
#host ⇒ Object
Host details for the lodging.
1756 1757 1758 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1756 def host @host end |
#insurances ⇒ Object
List of insurances for the lodging.
1758 1759 1760 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1758 def insurances @insurances end |
#no_show_indicator ⇒ Object
Whether the renter is a no-show.
1760 1761 1762 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1760 def no_show_indicator @no_show_indicator end |
#renter_id_number ⇒ Object
Renter ID number for the lodging.
1762 1763 1764 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1762 def renter_id_number @renter_id_number end |
#renter_name ⇒ Object
Renter name for the lodging.
1764 1765 1766 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1764 def renter_name @renter_name end |
#total ⇒ Object
Total details for the lodging.
1766 1767 1768 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1766 def total @total end |