Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentDetails::Subscription
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Affiliate, BillingInterval
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#auto_renewal ⇒ Object
Info whether the subscription will be auto renewed upon expiry.
-
#billing_interval ⇒ Object
Subscription billing details for this purchase.
-
#ends_at ⇒ Object
Subscription end time.
-
#name ⇒ Object
Name of the product on subscription.
-
#starts_at ⇒ Object
Subscription start time.
Instance Method Summary collapse
-
#initialize(affiliate: nil, auto_renewal: nil, billing_interval: nil, ends_at: nil, name: nil, starts_at: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate: nil, auto_renewal: nil, billing_interval: nil, ends_at: nil, name: nil, starts_at: nil) ⇒ Subscription
Returns a new instance of Subscription.
1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1877 def initialize( affiliate: nil, auto_renewal: nil, billing_interval: nil, ends_at: nil, name: nil, starts_at: nil ) @affiliate = affiliate @auto_renewal = auto_renewal @billing_interval = billing_interval @ends_at = ends_at @name = name @starts_at = starts_at end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
1865 1866 1867 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1865 def affiliate @affiliate end |
#auto_renewal ⇒ Object
Info whether the subscription will be auto renewed upon expiry.
1867 1868 1869 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1867 def auto_renewal @auto_renewal end |
#billing_interval ⇒ Object
Subscription billing details for this purchase.
1869 1870 1871 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1869 def billing_interval @billing_interval end |
#ends_at ⇒ Object
Subscription end time. Measured in seconds since the Unix epoch.
1871 1872 1873 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1871 def ends_at @ends_at end |
#name ⇒ Object
Name of the product on subscription. e.g. Apple Music Subscription
1873 1874 1875 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1873 def name @name end |
#starts_at ⇒ Object
Subscription start time. Measured in seconds since the Unix epoch.
1875 1876 1877 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1875 def starts_at @starts_at end |