Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



1820
1821
1822
1823
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1820

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1816
1817
1818
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1816

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1818
1819
1820
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1818

def interval
  @interval
end