Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



1846
1847
1848
1849
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1846

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1842
1843
1844
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1842

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1844
1845
1846
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1844

def interval
  @interval
end