Class: Stripe::PaymentIntentUpdateParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



877
878
879
880
# File 'lib/stripe/params/payment_intent_update_params.rb', line 877

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



873
874
875
# File 'lib/stripe/params/payment_intent_update_params.rb', line 873

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



875
876
877
# File 'lib/stripe/params/payment_intent_update_params.rb', line 875

def interval
  @interval
end