Class: Stripe::PaymentIntentUpdateParams::PaymentMethodData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodData
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Bizum, Blik, Boleto, Cashapp, Crypto, CustomerBalance, Eps, Fpx, GiftCard, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, RadarOptions, Rechnung, RevolutPay, SamsungPay, Satispay, Scalapay, SepaDebit, Shopeepay, Sofort, StripeBalance, Sunbit, Swish, Tamara, Twint, Upi, UsBankAccount, Vipps, WechatPay, Zip
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If this is an
acss_debitPaymentMethod, this hash contains details about the ACSS Debit payment method. -
#affirm ⇒ Object
If this is an
affirmPaymentMethod, this hash contains details about the Affirm payment method. -
#afterpay_clearpay ⇒ Object
If this is an
AfterpayClearpayPaymentMethod, this hash contains details about the AfterpayClearpay payment method. -
#alipay ⇒ Object
If this is an
AlipayPaymentMethod, this hash contains details about the Alipay payment method. -
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#alma ⇒ Object
If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.
-
#amazon_pay ⇒ Object
If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.
-
#au_becs_debit ⇒ Object
If this is an
au_becs_debitPaymentMethod, this hash contains details about the bank account. -
#bacs_debit ⇒ Object
If this is a
bacs_debitPaymentMethod, this hash contains details about the Bacs Direct Debit bank account. -
#bancontact ⇒ Object
If this is a
bancontactPaymentMethod, this hash contains details about the Bancontact payment method. -
#billie ⇒ Object
If this is a
billiePaymentMethod, this hash contains details about the Billie payment method. -
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
-
#bizum ⇒ Object
If this is a
bizumPaymentMethod, this hash contains details about the Bizum payment method. -
#blik ⇒ Object
If this is a
blikPaymentMethod, this hash contains details about the BLIK payment method. -
#boleto ⇒ Object
If this is a
boletoPaymentMethod, this hash contains details about the Boleto payment method. -
#cashapp ⇒ Object
If this is a
cashappPaymentMethod, this hash contains details about the Cash App Pay payment method. -
#crypto ⇒ Object
If this is a Crypto PaymentMethod, this hash contains details about the Crypto payment method.
-
#customer_balance ⇒ Object
If this is a
customer_balancePaymentMethod, this hash contains details about the CustomerBalance payment method. -
#eps ⇒ Object
If this is an
epsPaymentMethod, this hash contains details about the EPS payment method. -
#fpx ⇒ Object
If this is an
fpxPaymentMethod, this hash contains details about the FPX payment method. -
#gift_card ⇒ Object
If this is a
gift_cardPaymentMethod, this hash contains details about the gift card payment method. -
#giropay ⇒ Object
If this is a
giropayPaymentMethod, this hash contains details about the Giropay payment method. -
#gopay ⇒ Object
If this is a Gopay PaymentMethod, this hash contains details about the Gopay payment method.
-
#grabpay ⇒ Object
If this is a
grabpayPaymentMethod, this hash contains details about the GrabPay payment method. -
#id_bank_transfer ⇒ Object
If this is an
IdBankTransferPaymentMethod, this hash contains details about the IdBankTransfer payment method. -
#ideal ⇒ Object
If this is an
idealPaymentMethod, this hash contains details about the iDEAL payment method. -
#interac_present ⇒ Object
If this is an
interac_presentPaymentMethod, this hash contains details about the Interac Present payment method. -
#kakao_pay ⇒ Object
If this is a
kakao_payPaymentMethod, this hash contains details about the Kakao Pay payment method. -
#klarna ⇒ Object
If this is a
klarnaPaymentMethod, this hash contains details about the Klarna payment method. -
#konbini ⇒ Object
If this is a
konbiniPaymentMethod, this hash contains details about the Konbini payment method. -
#kr_card ⇒ Object
If this is a
kr_cardPaymentMethod, this hash contains details about the Korean Card payment method. -
#link ⇒ Object
If this is an
LinkPaymentMethod, this hash contains details about the Link payment method (Link is also known as Onelink in the UK). -
#mb_way ⇒ Object
If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#mobilepay ⇒ Object
If this is a
mobilepayPaymentMethod, this hash contains details about the MobilePay payment method. -
#multibanco ⇒ Object
If this is a
multibancoPaymentMethod, this hash contains details about the Multibanco payment method. -
#naver_pay ⇒ Object
If this is a
naver_payPaymentMethod, this hash contains details about the Naver Pay payment method. -
#nz_bank_account ⇒ Object
If this is an nz_bank_account PaymentMethod, this hash contains details about the nz_bank_account payment method.
-
#oxxo ⇒ Object
If this is an
oxxoPaymentMethod, this hash contains details about the OXXO payment method. -
#p24 ⇒ Object
If this is a
p24PaymentMethod, this hash contains details about the P24 payment method. -
#pay_by_bank ⇒ Object
If this is a
pay_by_bankPaymentMethod, this hash contains details about the PayByBank payment method. -
#payco ⇒ Object
If this is a
paycoPaymentMethod, this hash contains details about the PAYCO payment method. -
#paynow ⇒ Object
If this is a
paynowPaymentMethod, this hash contains details about the PayNow payment method. -
#paypal ⇒ Object
If this is a
paypalPaymentMethod, this hash contains details about the PayPal payment method. -
#paypay ⇒ Object
If this is a
paypayPaymentMethod, this hash contains details about the PayPay payment method. -
#payto ⇒ Object
If this is a
paytoPaymentMethod, this hash contains details about the PayTo payment method. -
#pix ⇒ Object
If this is a
pixPaymentMethod, this hash contains details about the Pix payment method. -
#promptpay ⇒ Object
If this is a
promptpayPaymentMethod, this hash contains details about the PromptPay payment method. -
#qris ⇒ Object
If this is a
qrisPaymentMethod, this hash contains details about the QRIS payment method. -
#radar_options ⇒ Object
Options to configure Radar.
-
#rechnung ⇒ Object
If this is a
rechnungPaymentMethod, this hash contains details about the Rechnung payment method. -
#revolut_pay ⇒ Object
If this is a
revolut_payPaymentMethod, this hash contains details about the Revolut Pay payment method. -
#samsung_pay ⇒ Object
If this is a
samsung_payPaymentMethod, this hash contains details about the SamsungPay payment method. -
#satispay ⇒ Object
If this is a
satispayPaymentMethod, this hash contains details about the Satispay payment method. -
#scalapay ⇒ Object
If this is a Scalapay PaymentMethod, this hash contains details about the Scalapay payment method.
-
#sepa_debit ⇒ Object
If this is a
sepa_debitPaymentMethod, this hash contains details about the SEPA debit bank account. -
#shared_payment_granted_token ⇒ Object
ID of the SharedPaymentGrantedToken used to confirm this PaymentIntent.
-
#shopeepay ⇒ Object
If this is a Shopeepay PaymentMethod, this hash contains details about the Shopeepay payment method.
-
#sofort ⇒ Object
If this is a
sofortPaymentMethod, this hash contains details about the SOFORT payment method. -
#stripe_balance ⇒ Object
This hash contains details about the Stripe balance payment method.
-
#sunbit ⇒ Object
If this is a
sunbitPaymentMethod, this hash contains details about the Sunbit payment method. -
#swish ⇒ Object
If this is a
swishPaymentMethod, this hash contains details about the Swish payment method. -
#tamara ⇒ Object
If this is a
tamaraPaymentMethod, this hash contains details about the Tamara payment method. -
#twint ⇒ Object
If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.
-
#type ⇒ Object
The type of the PaymentMethod.
-
#upi ⇒ Object
If this is a
upiPaymentMethod, this hash contains details about the UPI payment method. -
#us_bank_account ⇒ Object
If this is an
us_bank_accountPaymentMethod, this hash contains details about the US bank account payment method. -
#vipps ⇒ Object
If this is a
vippsPaymentMethod, this hash contains details about the Vipps payment method. -
#wechat_pay ⇒ Object
If this is an
wechat_payPaymentMethod, this hash contains details about the wechat_pay payment method. -
#zip ⇒ Object
If this is a
zipPaymentMethod, this hash contains details about the Zip payment method.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, billing_details: nil, bizum: nil, blik: nil, boleto: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, gift_card: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, paypay: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, radar_options: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, scalapay: nil, sepa_debit: nil, shared_payment_granted_token: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, sunbit: nil, swish: nil, tamara: nil, twint: nil, type: nil, upi: nil, us_bank_account: nil, vipps: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodData
Returns a new instance of PaymentMethodData.
2838 2839 2840 2841 2842 2843 2844 2845 2846 2847 2848 2849 2850 2851 2852 2853 2854 2855 2856 2857 2858 2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2838 def initialize( acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, billing_details: nil, bizum: nil, blik: nil, boleto: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, gift_card: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, paypay: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, radar_options: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, scalapay: nil, sepa_debit: nil, shared_payment_granted_token: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, sunbit: nil, swish: nil, tamara: nil, twint: nil, type: nil, upi: nil, us_bank_account: nil, vipps: nil, wechat_pay: nil, zip: nil ) @acss_debit = acss_debit @affirm = affirm @afterpay_clearpay = afterpay_clearpay @alipay = alipay @allow_redisplay = allow_redisplay @alma = alma @amazon_pay = amazon_pay @au_becs_debit = au_becs_debit @bacs_debit = bacs_debit @bancontact = bancontact @billie = billie @billing_details = billing_details @bizum = bizum @blik = blik @boleto = boleto @cashapp = cashapp @crypto = crypto @customer_balance = customer_balance @eps = eps @fpx = fpx @gift_card = gift_card @giropay = giropay @gopay = gopay @grabpay = grabpay @id_bank_transfer = id_bank_transfer @ideal = ideal @interac_present = interac_present @kakao_pay = kakao_pay @klarna = klarna @konbini = konbini @kr_card = kr_card @link = link @mb_way = mb_way @metadata = @mobilepay = mobilepay @multibanco = multibanco @naver_pay = naver_pay @nz_bank_account = nz_bank_account @oxxo = oxxo @p24 = p24 @pay_by_bank = pay_by_bank @payco = payco @paynow = paynow @paypal = paypal @paypay = paypay @payto = payto @pix = pix @promptpay = promptpay @qris = qris @radar_options = @rechnung = rechnung @revolut_pay = revolut_pay @samsung_pay = samsung_pay @satispay = satispay @scalapay = scalapay @sepa_debit = sepa_debit @shared_payment_granted_token = shared_payment_granted_token @shopeepay = shopeepay @sofort = sofort @stripe_balance = stripe_balance @sunbit = sunbit @swish = swish @tamara = tamara @twint = twint @type = type @upi = upi @us_bank_account = us_bank_account @vipps = vipps @wechat_pay = wechat_pay @zip = zip end |
Instance Attribute Details
#acss_debit ⇒ Object
If this is an acss_debit PaymentMethod, this hash contains details about the ACSS Debit payment method.
2698 2699 2700 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2698 def acss_debit @acss_debit end |
#affirm ⇒ Object
If this is an affirm PaymentMethod, this hash contains details about the Affirm payment method.
2700 2701 2702 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2700 def affirm @affirm end |
#afterpay_clearpay ⇒ Object
If this is an AfterpayClearpay PaymentMethod, this hash contains details about the AfterpayClearpay payment method.
2702 2703 2704 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2702 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
If this is an Alipay PaymentMethod, this hash contains details about the Alipay payment method.
2704 2705 2706 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2704 def alipay @alipay end |
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to unspecified.
2706 2707 2708 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2706 def allow_redisplay @allow_redisplay end |
#alma ⇒ Object
If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.
2708 2709 2710 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2708 def alma @alma end |
#amazon_pay ⇒ Object
If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.
2710 2711 2712 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2710 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object
If this is an au_becs_debit PaymentMethod, this hash contains details about the bank account.
2712 2713 2714 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2712 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object
If this is a bacs_debit PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.
2714 2715 2716 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2714 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object
If this is a bancontact PaymentMethod, this hash contains details about the Bancontact payment method.
2716 2717 2718 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2716 def bancontact @bancontact end |
#billie ⇒ Object
If this is a billie PaymentMethod, this hash contains details about the Billie payment method.
2718 2719 2720 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2718 def billie @billie end |
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
2720 2721 2722 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2720 def billing_details @billing_details end |
#bizum ⇒ Object
If this is a bizum PaymentMethod, this hash contains details about the Bizum payment method.
2722 2723 2724 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2722 def bizum @bizum end |
#blik ⇒ Object
If this is a blik PaymentMethod, this hash contains details about the BLIK payment method.
2724 2725 2726 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2724 def blik @blik end |
#boleto ⇒ Object
If this is a boleto PaymentMethod, this hash contains details about the Boleto payment method.
2726 2727 2728 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2726 def boleto @boleto end |
#cashapp ⇒ Object
If this is a cashapp PaymentMethod, this hash contains details about the Cash App Pay payment method.
2728 2729 2730 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2728 def cashapp @cashapp end |
#crypto ⇒ Object
If this is a Crypto PaymentMethod, this hash contains details about the Crypto payment method.
2730 2731 2732 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2730 def crypto @crypto end |
#customer_balance ⇒ Object
If this is a customer_balance PaymentMethod, this hash contains details about the CustomerBalance payment method.
2732 2733 2734 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2732 def customer_balance @customer_balance end |
#eps ⇒ Object
If this is an eps PaymentMethod, this hash contains details about the EPS payment method.
2734 2735 2736 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2734 def eps @eps end |
#fpx ⇒ Object
If this is an fpx PaymentMethod, this hash contains details about the FPX payment method.
2736 2737 2738 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2736 def fpx @fpx end |
#gift_card ⇒ Object
If this is a gift_card PaymentMethod, this hash contains details about the gift card payment method.
2738 2739 2740 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2738 def gift_card @gift_card end |
#giropay ⇒ Object
If this is a giropay PaymentMethod, this hash contains details about the Giropay payment method.
2740 2741 2742 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2740 def giropay @giropay end |
#gopay ⇒ Object
If this is a Gopay PaymentMethod, this hash contains details about the Gopay payment method.
2742 2743 2744 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2742 def gopay @gopay end |
#grabpay ⇒ Object
If this is a grabpay PaymentMethod, this hash contains details about the GrabPay payment method.
2744 2745 2746 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2744 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object
If this is an IdBankTransfer PaymentMethod, this hash contains details about the IdBankTransfer payment method.
2746 2747 2748 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2746 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object
If this is an ideal PaymentMethod, this hash contains details about the iDEAL payment method.
2748 2749 2750 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2748 def ideal @ideal end |
#interac_present ⇒ Object
If this is an interac_present PaymentMethod, this hash contains details about the Interac Present payment method.
2750 2751 2752 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2750 def interac_present @interac_present end |
#kakao_pay ⇒ Object
If this is a kakao_pay PaymentMethod, this hash contains details about the Kakao Pay payment method.
2752 2753 2754 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2752 def kakao_pay @kakao_pay end |
#klarna ⇒ Object
If this is a klarna PaymentMethod, this hash contains details about the Klarna payment method.
2754 2755 2756 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2754 def klarna @klarna end |
#konbini ⇒ Object
If this is a konbini PaymentMethod, this hash contains details about the Konbini payment method.
2756 2757 2758 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2756 def konbini @konbini end |
#kr_card ⇒ Object
If this is a kr_card PaymentMethod, this hash contains details about the Korean Card payment method.
2758 2759 2760 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2758 def kr_card @kr_card end |
#link ⇒ Object
If this is an Link PaymentMethod, this hash contains details about the Link payment method (Link is also known as Onelink in the UK).
2760 2761 2762 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2760 def link @link end |
#mb_way ⇒ Object
If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.
2762 2763 2764 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2762 def mb_way @mb_way end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
2764 2765 2766 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2764 def @metadata end |
#mobilepay ⇒ Object
If this is a mobilepay PaymentMethod, this hash contains details about the MobilePay payment method.
2766 2767 2768 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2766 def mobilepay @mobilepay end |
#multibanco ⇒ Object
If this is a multibanco PaymentMethod, this hash contains details about the Multibanco payment method.
2768 2769 2770 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2768 def multibanco @multibanco end |
#naver_pay ⇒ Object
If this is a naver_pay PaymentMethod, this hash contains details about the Naver Pay payment method.
2770 2771 2772 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2770 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object
If this is an nz_bank_account PaymentMethod, this hash contains details about the nz_bank_account payment method.
2772 2773 2774 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2772 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object
If this is an oxxo PaymentMethod, this hash contains details about the OXXO payment method.
2774 2775 2776 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2774 def oxxo @oxxo end |
#p24 ⇒ Object
If this is a p24 PaymentMethod, this hash contains details about the P24 payment method.
2776 2777 2778 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2776 def p24 @p24 end |
#pay_by_bank ⇒ Object
If this is a pay_by_bank PaymentMethod, this hash contains details about the PayByBank payment method.
2778 2779 2780 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2778 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object
If this is a payco PaymentMethod, this hash contains details about the PAYCO payment method.
2780 2781 2782 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2780 def payco @payco end |
#paynow ⇒ Object
If this is a paynow PaymentMethod, this hash contains details about the PayNow payment method.
2782 2783 2784 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2782 def paynow @paynow end |
#paypal ⇒ Object
If this is a paypal PaymentMethod, this hash contains details about the PayPal payment method.
2784 2785 2786 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2784 def paypal @paypal end |
#paypay ⇒ Object
If this is a paypay PaymentMethod, this hash contains details about the PayPay payment method.
2786 2787 2788 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2786 def paypay @paypay end |
#payto ⇒ Object
If this is a payto PaymentMethod, this hash contains details about the PayTo payment method.
2788 2789 2790 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2788 def payto @payto end |
#pix ⇒ Object
If this is a pix PaymentMethod, this hash contains details about the Pix payment method.
2790 2791 2792 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2790 def pix @pix end |
#promptpay ⇒ Object
If this is a promptpay PaymentMethod, this hash contains details about the PromptPay payment method.
2792 2793 2794 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2792 def promptpay @promptpay end |
#qris ⇒ Object
If this is a qris PaymentMethod, this hash contains details about the QRIS payment method.
2794 2795 2796 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2794 def qris @qris end |
#radar_options ⇒ Object
Options to configure Radar. See Radar Session for more information.
2796 2797 2798 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2796 def @radar_options end |
#rechnung ⇒ Object
If this is a rechnung PaymentMethod, this hash contains details about the Rechnung payment method.
2798 2799 2800 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2798 def rechnung @rechnung end |
#revolut_pay ⇒ Object
If this is a revolut_pay PaymentMethod, this hash contains details about the Revolut Pay payment method.
2800 2801 2802 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2800 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object
If this is a samsung_pay PaymentMethod, this hash contains details about the SamsungPay payment method.
2802 2803 2804 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2802 def samsung_pay @samsung_pay end |
#satispay ⇒ Object
If this is a satispay PaymentMethod, this hash contains details about the Satispay payment method.
2804 2805 2806 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2804 def satispay @satispay end |
#scalapay ⇒ Object
If this is a Scalapay PaymentMethod, this hash contains details about the Scalapay payment method.
2806 2807 2808 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2806 def scalapay @scalapay end |
#sepa_debit ⇒ Object
If this is a sepa_debit PaymentMethod, this hash contains details about the SEPA debit bank account.
2808 2809 2810 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2808 def sepa_debit @sepa_debit end |
#shared_payment_granted_token ⇒ Object
ID of the SharedPaymentGrantedToken used to confirm this PaymentIntent.
2810 2811 2812 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2810 def shared_payment_granted_token @shared_payment_granted_token end |
#shopeepay ⇒ Object
If this is a Shopeepay PaymentMethod, this hash contains details about the Shopeepay payment method.
2812 2813 2814 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2812 def shopeepay @shopeepay end |
#sofort ⇒ Object
If this is a sofort PaymentMethod, this hash contains details about the SOFORT payment method.
2814 2815 2816 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2814 def sofort @sofort end |
#stripe_balance ⇒ Object
This hash contains details about the Stripe balance payment method.
2816 2817 2818 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2816 def stripe_balance @stripe_balance end |
#sunbit ⇒ Object
If this is a sunbit PaymentMethod, this hash contains details about the Sunbit payment method.
2818 2819 2820 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2818 def sunbit @sunbit end |
#swish ⇒ Object
If this is a swish PaymentMethod, this hash contains details about the Swish payment method.
2820 2821 2822 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2820 def swish @swish end |
#tamara ⇒ Object
If this is a tamara PaymentMethod, this hash contains details about the Tamara payment method.
2822 2823 2824 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2822 def tamara @tamara end |
#twint ⇒ Object
If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.
2824 2825 2826 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2824 def twint @twint end |
#type ⇒ Object
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
2826 2827 2828 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2826 def type @type end |
#upi ⇒ Object
If this is a upi PaymentMethod, this hash contains details about the UPI payment method.
2828 2829 2830 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2828 def upi @upi end |
#us_bank_account ⇒ Object
If this is an us_bank_account PaymentMethod, this hash contains details about the US bank account payment method.
2830 2831 2832 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2830 def us_bank_account @us_bank_account end |
#vipps ⇒ Object
If this is a vipps PaymentMethod, this hash contains details about the Vipps payment method.
2832 2833 2834 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2832 def vipps @vipps end |
#wechat_pay ⇒ Object
If this is an wechat_pay PaymentMethod, this hash contains details about the wechat_pay payment method.
2834 2835 2836 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2834 def wechat_pay @wechat_pay end |
#zip ⇒ Object
If this is a zip PaymentMethod, this hash contains details about the Zip payment method.
2836 2837 2838 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2836 def zip @zip end |