Class: Stripe::PaymentIntentUpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account's bank.
-
#branch_code ⇒ Object
The numeric code for the bank account's bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2517 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
2505 2506 2507 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2505 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
2507 2508 2509 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2507 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account's bank.
2509 2510 2511 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2509 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account's bank branch.
2511 2512 2513 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2511 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
2513 2514 2515 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2513 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
2515 2516 2517 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2515 def suffix @suffix end |