Class: Stripe::PaymentIntentUpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
# File 'lib/stripe/params/payment_intent_update_params.rb', line 436

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



424
425
426
# File 'lib/stripe/params/payment_intent_update_params.rb', line 424

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



426
427
428
# File 'lib/stripe/params/payment_intent_update_params.rb', line 426

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



428
429
430
# File 'lib/stripe/params/payment_intent_update_params.rb', line 428

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



430
431
432
# File 'lib/stripe/params/payment_intent_update_params.rb', line 430

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



432
433
434
# File 'lib/stripe/params/payment_intent_update_params.rb', line 432

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



434
435
436
# File 'lib/stripe/params/payment_intent_update_params.rb', line 434

def suffix
  @suffix
end