Class: Stripe::PaymentIntentUpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



2445
2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2445

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



2433
2434
2435
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2433

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



2435
2436
2437
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2435

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



2437
2438
2439
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2437

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



2439
2440
2441
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2439

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



2441
2442
2443
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2441

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



2443
2444
2445
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2443

def suffix
  @suffix
end