Class: Stripe::PaymentIntentUpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2118

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



2106
2107
2108
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2106

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



2108
2109
2110
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2108

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



2110
2111
2112
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2110

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



2112
2113
2114
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2112

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



2114
2115
2116
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2114

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



2116
2117
2118
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2116

def suffix
  @suffix
end