Class: Stripe::PaymentIntentUpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2165

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



2153
2154
2155
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2153

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



2155
2156
2157
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2155

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



2157
2158
2159
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2157

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



2159
2160
2161
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2159

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



2161
2162
2163
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2161

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



2163
2164
2165
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2163

def suffix
  @suffix
end