Class: Stripe::PaymentIntentUpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2104

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



2092
2093
2094
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2092

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



2094
2095
2096
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2094

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



2096
2097
2098
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2096

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



2098
2099
2100
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2098

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



2100
2101
2102
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2100

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



2102
2103
2104
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2102

def suffix
  @suffix
end