Class: Stripe::PaymentIntentUpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2104 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
2092 2093 2094 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2092 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
2094 2095 2096 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2094 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
2096 2097 2098 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2096 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
2098 2099 2100 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2098 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
2100 2101 2102 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2100 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
2102 2103 2104 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2102 def suffix @suffix end |