Class: Stripe::PaymentIntentUpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2121

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



2109
2110
2111
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2109

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



2111
2112
2113
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2111

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



2113
2114
2115
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2113

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



2115
2116
2117
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2115

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



2117
2118
2119
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2117

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



2119
2120
2121
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2119

def suffix
  @suffix
end