Class: Stripe::PaymentIntentUpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
# File 'lib/stripe/params/payment_intent_update_params.rb', line 399

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



387
388
389
# File 'lib/stripe/params/payment_intent_update_params.rb', line 387

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



389
390
391
# File 'lib/stripe/params/payment_intent_update_params.rb', line 389

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



391
392
393
# File 'lib/stripe/params/payment_intent_update_params.rb', line 391

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



393
394
395
# File 'lib/stripe/params/payment_intent_update_params.rb', line 393

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



395
396
397
# File 'lib/stripe/params/payment_intent_update_params.rb', line 395

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



397
398
399
# File 'lib/stripe/params/payment_intent_update_params.rb', line 397

def suffix
  @suffix
end