Class: Stripe::PaymentIntentUpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1155 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1143 1144 1145 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1143 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
1145 1146 1147 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1145 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
1147 1148 1149 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1147 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
1149 1150 1151 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1149 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
1151 1152 1153 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1151 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
1153 1154 1155 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1153 def suffix @suffix end |