Class: Stripe::PaymentIntentUpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 437 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
425 426 427 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 425 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
427 428 429 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 427 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
429 430 431 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 429 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
431 432 433 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 431 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
433 434 435 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 433 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
435 436 437 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 435 def suffix @suffix end |