Class: Stripe::PaymentIntentUpdateParams::PaymentMethodData::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2652
2653
2654
2655
2656
2657
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2652

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



2644
2645
2646
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2644

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



2646
2647
2648
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2646

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



2648
2649
2650
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2648

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



2650
2651
2652
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2650

def end_date
  @end_date
end