Class: Stripe::PaymentIntentUpdateParams::PaymentMethodData::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2253
2254
2255
2256
2257
2258
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2253

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



2245
2246
2247
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2245

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



2247
2248
2249
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2247

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



2249
2250
2251
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2249

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



2251
2252
2253
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2251

def end_date
  @end_date
end