Class: Stripe::PaymentIntentUpdateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2257 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
2247 2248 2249 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2247 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
2249 2250 2251 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2249 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
2251 2252 2253 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2251 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
2253 2254 2255 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2253 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
2255 2256 2257 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2255 def routing_number @routing_number end |