Class: Stripe::PaymentIntentUpdateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 480 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
470 471 472 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 470 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
472 473 474 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 472 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
474 475 476 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 474 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
476 477 478 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 476 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
478 479 480 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 478 def routing_number @routing_number end |