Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Bizum, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, Scalapay, SepaDebit, Shopeepay, Sofort, StripeBalance, Swish, Twint, Upi, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, bizum: nil, blik: nil, boleto: nil, card: nil, card_present: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, paypay: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, scalapay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, swish: nil, twint: nil, upi: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
5479
5480
5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
5501
5502
5503
5504
5505
5506
5507
5508
5509
5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
5542
5543
5544
5545
5546
5547
5548
5549
5550
5551
5552
5553
5554
5555
5556
5557
5558
5559
5560
5561
5562
5563
5564
5565
5566
5567
5568
5569
5570
5571
5572
5573
5574
5575
5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5466

def initialize(
  acss_debit: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  alma: nil,
  amazon_pay: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  billie: nil,
  bizum: nil,
  blik: nil,
  boleto: nil,
  card: nil,
  card_present: nil,
  cashapp: nil,
  crypto: nil,
  customer_balance: nil,
  eps: nil,
  fpx: nil,
  giropay: nil,
  gopay: nil,
  grabpay: nil,
  id_bank_transfer: nil,
  ideal: nil,
  interac_present: nil,
  kakao_pay: nil,
  klarna: nil,
  konbini: nil,
  kr_card: nil,
  link: nil,
  mb_way: nil,
  mobilepay: nil,
  multibanco: nil,
  naver_pay: nil,
  nz_bank_account: nil,
  oxxo: nil,
  p24: nil,
  pay_by_bank: nil,
  payco: nil,
  paynow: nil,
  paypal: nil,
  paypay: nil,
  payto: nil,
  pix: nil,
  promptpay: nil,
  qris: nil,
  rechnung: nil,
  revolut_pay: nil,
  samsung_pay: nil,
  satispay: nil,
  scalapay: nil,
  sepa_debit: nil,
  shopeepay: nil,
  sofort: nil,
  stripe_balance: nil,
  swish: nil,
  twint: nil,
  upi: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @alma = alma
  @amazon_pay = amazon_pay
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @billie = billie
  @bizum = bizum
  @blik = blik
  @boleto = boleto
  @card = card
  @card_present = card_present
  @cashapp = cashapp
  @crypto = crypto
  @customer_balance = customer_balance
  @eps = eps
  @fpx = fpx
  @giropay = giropay
  @gopay = gopay
  @grabpay = grabpay
  @id_bank_transfer = id_bank_transfer
  @ideal = ideal
  @interac_present = interac_present
  @kakao_pay = kakao_pay
  @klarna = klarna
  @konbini = konbini
  @kr_card = kr_card
  @link = link
  @mb_way = mb_way
  @mobilepay = mobilepay
  @multibanco = multibanco
  @naver_pay = naver_pay
  @nz_bank_account = 
  @oxxo = oxxo
  @p24 = p24
  @pay_by_bank = pay_by_bank
  @payco = payco
  @paynow = paynow
  @paypal = paypal
  @paypay = paypay
  @payto = payto
  @pix = pix
  @promptpay = promptpay
  @qris = qris
  @rechnung = rechnung
  @revolut_pay = revolut_pay
  @samsung_pay = samsung_pay
  @satispay = satispay
  @scalapay = scalapay
  @sepa_debit = sepa_debit
  @shopeepay = shopeepay
  @sofort = sofort
  @stripe_balance = stripe_balance
  @swish = swish
  @twint = twint
  @upi = upi
  @us_bank_account = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

If this is a ‘acss_debit` PaymentMethod, this sub-hash contains details about the ACSS Debit payment method options.



5342
5343
5344
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5342

def acss_debit
  @acss_debit
end

#affirmObject

If this is an ‘affirm` PaymentMethod, this sub-hash contains details about the Affirm payment method options.



5344
5345
5346
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5344

def affirm
  @affirm
end

#afterpay_clearpayObject

If this is a ‘afterpay_clearpay` PaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options.



5346
5347
5348
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5346

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If this is a ‘alipay` PaymentMethod, this sub-hash contains details about the Alipay payment method options.



5348
5349
5350
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5348

def alipay
  @alipay
end

#almaObject

If this is a ‘alma` PaymentMethod, this sub-hash contains details about the Alma payment method options.



5350
5351
5352
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5350

def alma
  @alma
end

#amazon_payObject

If this is a ‘amazon_pay` PaymentMethod, this sub-hash contains details about the Amazon Pay payment method options.



5352
5353
5354
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5352

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject

If this is a ‘au_becs_debit` PaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options.



5354
5355
5356
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5354

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

If this is a ‘bacs_debit` PaymentMethod, this sub-hash contains details about the BACS Debit payment method options.



5356
5357
5358
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5356

def bacs_debit
  @bacs_debit
end

#bancontactObject

If this is a ‘bancontact` PaymentMethod, this sub-hash contains details about the Bancontact payment method options.



5358
5359
5360
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5358

def bancontact
  @bancontact
end

#billieObject

If this is a ‘billie` PaymentMethod, this sub-hash contains details about the Billie payment method options.



5360
5361
5362
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5360

def billie
  @billie
end

#bizumObject

If this is a ‘bizum` PaymentMethod, this sub-hash contains details about the Bizum payment method options.



5362
5363
5364
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5362

def bizum
  @bizum
end

#blikObject

If this is a ‘blik` PaymentMethod, this sub-hash contains details about the BLIK payment method options.



5364
5365
5366
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5364

def blik
  @blik
end

#boletoObject

If this is a ‘boleto` PaymentMethod, this sub-hash contains details about the Boleto payment method options.



5366
5367
5368
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5366

def boleto
  @boleto
end

#cardObject

Configuration for any card payments attempted on this PaymentIntent.



5368
5369
5370
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5368

def card
  @card
end

#card_presentObject

If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.



5370
5371
5372
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5370

def card_present
  @card_present
end

#cashappObject

If this is a ‘cashapp` PaymentMethod, this sub-hash contains details about the Cash App Pay payment method options.



5372
5373
5374
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5372

def cashapp
  @cashapp
end

#cryptoObject

If this is a ‘crypto` PaymentMethod, this sub-hash contains details about the Crypto payment method options.



5374
5375
5376
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5374

def crypto
  @crypto
end

#customer_balanceObject

If this is a ‘customer balance` PaymentMethod, this sub-hash contains details about the customer balance payment method options.



5376
5377
5378
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5376

def customer_balance
  @customer_balance
end

#epsObject

If this is a ‘eps` PaymentMethod, this sub-hash contains details about the EPS payment method options.



5378
5379
5380
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5378

def eps
  @eps
end

#fpxObject

If this is a ‘fpx` PaymentMethod, this sub-hash contains details about the FPX payment method options.



5380
5381
5382
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5380

def fpx
  @fpx
end

#giropayObject

If this is a ‘giropay` PaymentMethod, this sub-hash contains details about the Giropay payment method options.



5382
5383
5384
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5382

def giropay
  @giropay
end

#gopayObject

If this is a ‘gopay` PaymentMethod, this sub-hash contains details about the Gopay payment method options.



5384
5385
5386
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5384

def gopay
  @gopay
end

#grabpayObject

If this is a ‘grabpay` PaymentMethod, this sub-hash contains details about the Grabpay payment method options.



5386
5387
5388
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5386

def grabpay
  @grabpay
end

#id_bank_transferObject

If this is a ‘id_bank_transfer` PaymentMethod, this sub-hash contains details about the Indonesia Bank Transfer payment method options.



5388
5389
5390
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5388

def id_bank_transfer
  @id_bank_transfer
end

#idealObject

If this is a ‘ideal` PaymentMethod, this sub-hash contains details about the Ideal payment method options.



5390
5391
5392
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5390

def ideal
  @ideal
end

#interac_presentObject

If this is a ‘interac_present` PaymentMethod, this sub-hash contains details about the Card Present payment method options.



5392
5393
5394
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5392

def interac_present
  @interac_present
end

#kakao_payObject

If this is a ‘kakao_pay` PaymentMethod, this sub-hash contains details about the Kakao Pay payment method options.



5394
5395
5396
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5394

def kakao_pay
  @kakao_pay
end

#klarnaObject

If this is a ‘klarna` PaymentMethod, this sub-hash contains details about the Klarna payment method options.



5396
5397
5398
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5396

def klarna
  @klarna
end

#konbiniObject

If this is a ‘konbini` PaymentMethod, this sub-hash contains details about the Konbini payment method options.



5398
5399
5400
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5398

def konbini
  @konbini
end

#kr_cardObject

If this is a ‘kr_card` PaymentMethod, this sub-hash contains details about the KR Card payment method options.



5400
5401
5402
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5400

def kr_card
  @kr_card
end

If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options (Link is also known as Onelink in the UK).



5402
5403
5404
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5402

def link
  @link
end

#mb_wayObject

If this is a ‘mb_way` PaymentMethod, this sub-hash contains details about the MB WAY payment method options.



5404
5405
5406
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5404

def mb_way
  @mb_way
end

#mobilepayObject

If this is a ‘MobilePay` PaymentMethod, this sub-hash contains details about the MobilePay payment method options.



5406
5407
5408
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5406

def mobilepay
  @mobilepay
end

#multibancoObject

If this is a ‘multibanco` PaymentMethod, this sub-hash contains details about the Multibanco payment method options.



5408
5409
5410
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5408

def multibanco
  @multibanco
end

If this is a ‘naver_pay` PaymentMethod, this sub-hash contains details about the Naver Pay payment method options.



5410
5411
5412
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5410

def naver_pay
  @naver_pay
end

#nz_bank_accountObject

If this is a ‘nz_bank_account` PaymentMethod, this sub-hash contains details about the NZ BECS Direct Debit payment method options.



5412
5413
5414
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5412

def 
  @nz_bank_account
end

#oxxoObject

If this is a ‘oxxo` PaymentMethod, this sub-hash contains details about the OXXO payment method options.



5414
5415
5416
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5414

def oxxo
  @oxxo
end

#p24Object

If this is a ‘p24` PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options.



5416
5417
5418
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5416

def p24
  @p24
end

#pay_by_bankObject

If this is a ‘pay_by_bank` PaymentMethod, this sub-hash contains details about the PayByBank payment method options.



5418
5419
5420
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5418

def pay_by_bank
  @pay_by_bank
end

#paycoObject

If this is a ‘payco` PaymentMethod, this sub-hash contains details about the PAYCO payment method options.



5420
5421
5422
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5420

def payco
  @payco
end

#paynowObject

If this is a ‘paynow` PaymentMethod, this sub-hash contains details about the PayNow payment method options.



5422
5423
5424
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5422

def paynow
  @paynow
end

#paypalObject

If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.



5424
5425
5426
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5424

def paypal
  @paypal
end

#paypayObject

If this is a ‘paypay` PaymentMethod, this sub-hash contains details about the PayPay payment method options.



5426
5427
5428
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5426

def paypay
  @paypay
end

#paytoObject

If this is a ‘payto` PaymentMethod, this sub-hash contains details about the PayTo payment method options.



5428
5429
5430
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5428

def payto
  @payto
end

#pixObject

If this is a ‘pix` PaymentMethod, this sub-hash contains details about the Pix payment method options.



5430
5431
5432
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5430

def pix
  @pix
end

#promptpayObject

If this is a ‘promptpay` PaymentMethod, this sub-hash contains details about the PromptPay payment method options.



5432
5433
5434
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5432

def promptpay
  @promptpay
end

#qrisObject

If this is a ‘qris` PaymentMethod, this sub-hash contains details about the QRIS payment method options.



5434
5435
5436
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5434

def qris
  @qris
end

#rechnungObject

If this is a ‘rechnung` PaymentMethod, this sub-hash contains details about the Rechnung payment method options.



5436
5437
5438
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5436

def rechnung
  @rechnung
end

#revolut_payObject

If this is a ‘revolut_pay` PaymentMethod, this sub-hash contains details about the Revolut Pay payment method options.



5438
5439
5440
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5438

def revolut_pay
  @revolut_pay
end

#samsung_payObject

If this is a ‘samsung_pay` PaymentMethod, this sub-hash contains details about the Samsung Pay payment method options.



5440
5441
5442
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5440

def samsung_pay
  @samsung_pay
end

#satispayObject

If this is a ‘satispay` PaymentMethod, this sub-hash contains details about the Satispay payment method options.



5442
5443
5444
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5442

def satispay
  @satispay
end

#scalapayObject

If this is a ‘scalapay` PaymentMethod, this sub-hash contains details about the ScalaPay payment method options.



5444
5445
5446
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5444

def scalapay
  @scalapay
end

#sepa_debitObject

If this is a ‘sepa_debit` PaymentIntent, this sub-hash contains details about the SEPA Debit payment method options.



5446
5447
5448
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5446

def sepa_debit
  @sepa_debit
end

#shopeepayObject

If this is a ‘shopeepay` PaymentMethod, this sub-hash contains details about the ShopeePay payment method options.



5448
5449
5450
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5448

def shopeepay
  @shopeepay
end

#sofortObject

If this is a ‘sofort` PaymentMethod, this sub-hash contains details about the SOFORT payment method options.



5450
5451
5452
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5450

def sofort
  @sofort
end

#stripe_balanceObject

If this is a ‘stripe_balance` PaymentMethod, this sub-hash contains details about the Stripe Balance payment method options.



5452
5453
5454
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5452

def stripe_balance
  @stripe_balance
end

#swishObject

If this is a ‘Swish` PaymentMethod, this sub-hash contains details about the Swish payment method options.



5454
5455
5456
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5454

def swish
  @swish
end

#twintObject

If this is a ‘twint` PaymentMethod, this sub-hash contains details about the TWINT payment method options.



5456
5457
5458
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5456

def twint
  @twint
end

#upiObject

If this is a ‘upi` PaymentIntent, this sub-hash contains details about the UPI payment method options.



5458
5459
5460
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5458

def upi
  @upi
end

#us_bank_accountObject

If this is a ‘us_bank_account` PaymentMethod, this sub-hash contains details about the US bank account payment method options.



5460
5461
5462
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5460

def 
  @us_bank_account
end

#wechat_payObject

If this is a ‘wechat_pay` PaymentMethod, this sub-hash contains details about the WeChat Pay payment method options.



5462
5463
5464
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5462

def wechat_pay
  @wechat_pay
end

#zipObject

If this is a ‘zip` PaymentMethod, this sub-hash contains details about the Zip payment method options.



5464
5465
5466
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5464

def zip
  @zip
end