Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Bizum, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Grabpay, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, RevolutPay, SamsungPay, Satispay, Scalapay, SepaDebit, Sequra, Sofort, Sunbit, Swish, Twint, Upi, UsBankAccount, WechatPay, Zip
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If this is a
acss_debitPaymentMethod, this sub-hash contains details about the ACSS Debit payment method options. -
#affirm ⇒ Object
If this is an
affirmPaymentMethod, this sub-hash contains details about the Affirm payment method options. -
#afterpay_clearpay ⇒ Object
If this is a
afterpay_clearpayPaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options. -
#alipay ⇒ Object
If this is a
alipayPaymentMethod, this sub-hash contains details about the Alipay payment method options. -
#alma ⇒ Object
If this is a
almaPaymentMethod, this sub-hash contains details about the Alma payment method options. -
#amazon_pay ⇒ Object
If this is a
amazon_payPaymentMethod, this sub-hash contains details about the Amazon Pay payment method options. -
#au_becs_debit ⇒ Object
If this is a
au_becs_debitPaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options. -
#bacs_debit ⇒ Object
If this is a
bacs_debitPaymentMethod, this sub-hash contains details about the BACS Debit payment method options. -
#bancontact ⇒ Object
If this is a
bancontactPaymentMethod, this sub-hash contains details about the Bancontact payment method options. -
#billie ⇒ Object
If this is a
billiePaymentMethod, this sub-hash contains details about the Billie payment method options. -
#bizum ⇒ Object
If this is a
bizumPaymentMethod, this sub-hash contains details about the Bizum payment method options. -
#blik ⇒ Object
If this is a
blikPaymentMethod, this sub-hash contains details about the BLIK payment method options. -
#boleto ⇒ Object
If this is a
boletoPaymentMethod, this sub-hash contains details about the Boleto payment method options. -
#card ⇒ Object
Configuration for any card payments attempted on this PaymentIntent.
-
#card_present ⇒ Object
If this is a
card_presentPaymentMethod, this sub-hash contains details about the Card Present payment method options. -
#cashapp ⇒ Object
If this is a
cashappPaymentMethod, this sub-hash contains details about the Cash App Pay payment method options. -
#crypto ⇒ Object
If this is a
cryptoPaymentMethod, this sub-hash contains details about the Crypto payment method options. -
#customer_balance ⇒ Object
If this is a
customer balancePaymentMethod, this sub-hash contains details about the customer balance payment method options. -
#eps ⇒ Object
If this is a
epsPaymentMethod, this sub-hash contains details about the EPS payment method options. -
#fpx ⇒ Object
If this is a
fpxPaymentMethod, this sub-hash contains details about the FPX payment method options. -
#giropay ⇒ Object
If this is a
giropayPaymentMethod, this sub-hash contains details about the Giropay payment method options. -
#grabpay ⇒ Object
If this is a
grabpayPaymentMethod, this sub-hash contains details about the Grabpay payment method options. -
#ideal ⇒ Object
If this is a
idealPaymentMethod, this sub-hash contains details about the Ideal payment method options. -
#interac_present ⇒ Object
If this is a
interac_presentPaymentMethod, this sub-hash contains details about the Card Present payment method options. -
#kakao_pay ⇒ Object
If this is a
kakao_payPaymentMethod, this sub-hash contains details about the Kakao Pay payment method options. -
#klarna ⇒ Object
If this is a
klarnaPaymentMethod, this sub-hash contains details about the Klarna payment method options. -
#konbini ⇒ Object
If this is a
konbiniPaymentMethod, this sub-hash contains details about the Konbini payment method options. -
#kr_card ⇒ Object
If this is a
kr_cardPaymentMethod, this sub-hash contains details about the KR Card payment method options. -
#link ⇒ Object
If this is a
linkPaymentMethod, this sub-hash contains details about the Link payment method options (Link is also known as Onelink in the UK). -
#mb_way ⇒ Object
If this is a
mb_wayPaymentMethod, this sub-hash contains details about the MB WAY payment method options. -
#mobilepay ⇒ Object
If this is a
MobilePayPaymentMethod, this sub-hash contains details about the MobilePay payment method options. -
#multibanco ⇒ Object
If this is a
multibancoPaymentMethod, this sub-hash contains details about the Multibanco payment method options. -
#naver_pay ⇒ Object
If this is a
naver_payPaymentMethod, this sub-hash contains details about the Naver Pay payment method options. -
#nz_bank_account ⇒ Object
If this is a
nz_bank_accountPaymentMethod, this sub-hash contains details about the NZ BECS Direct Debit payment method options. -
#oxxo ⇒ Object
If this is a
oxxoPaymentMethod, this sub-hash contains details about the OXXO payment method options. -
#p24 ⇒ Object
If this is a
p24PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options. -
#pay_by_bank ⇒ Object
If this is a
pay_by_bankPaymentMethod, this sub-hash contains details about the PayByBank payment method options. -
#payco ⇒ Object
If this is a
paycoPaymentMethod, this sub-hash contains details about the PAYCO payment method options. -
#paynow ⇒ Object
If this is a
paynowPaymentMethod, this sub-hash contains details about the PayNow payment method options. -
#paypal ⇒ Object
If this is a
paypalPaymentMethod, this sub-hash contains details about the PayPal payment method options. -
#paypay ⇒ Object
If this is a
paypayPaymentMethod, this sub-hash contains details about the PayPay payment method options. -
#payto ⇒ Object
If this is a
paytoPaymentMethod, this sub-hash contains details about the PayTo payment method options. -
#pix ⇒ Object
If this is a
pixPaymentMethod, this sub-hash contains details about the Pix payment method options. -
#promptpay ⇒ Object
If this is a
promptpayPaymentMethod, this sub-hash contains details about the PromptPay payment method options. -
#revolut_pay ⇒ Object
If this is a
revolut_payPaymentMethod, this sub-hash contains details about the Revolut Pay payment method options. -
#samsung_pay ⇒ Object
If this is a
samsung_payPaymentMethod, this sub-hash contains details about the Samsung Pay payment method options. -
#satispay ⇒ Object
If this is a
satispayPaymentMethod, this sub-hash contains details about the Satispay payment method options. -
#scalapay ⇒ Object
If this is a
scalapayPaymentMethod, this sub-hash contains details about the ScalaPay payment method options. -
#sepa_debit ⇒ Object
If this is a
sepa_debitPaymentIntent, this sub-hash contains details about the SEPA Debit payment method options. -
#sequra ⇒ Object
If this is a
sequraPaymentMethod, this sub-hash contains details about the SeQura payment method options. -
#sofort ⇒ Object
If this is a
sofortPaymentMethod, this sub-hash contains details about the SOFORT payment method options. -
#sunbit ⇒ Object
If this is a
sunbitPaymentMethod, this sub-hash contains details about the Sunbit payment method options. -
#swish ⇒ Object
If this is a
SwishPaymentMethod, this sub-hash contains details about the Swish payment method options. -
#twint ⇒ Object
If this is a
twintPaymentMethod, this sub-hash contains details about the TWINT payment method options. -
#upi ⇒ Object
If this is a
upiPaymentIntent, this sub-hash contains details about the UPI payment method options. -
#us_bank_account ⇒ Object
If this is a
us_bank_accountPaymentMethod, this sub-hash contains details about the US bank account payment method options. -
#wechat_pay ⇒ Object
If this is a
wechat_payPaymentMethod, this sub-hash contains details about the WeChat Pay payment method options. -
#zip ⇒ Object
If this is a
zipPaymentMethod, this sub-hash contains details about the Zip payment method options.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, bizum: nil, blik: nil, boleto: nil, card: nil, card_present: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, paypay: nil, payto: nil, pix: nil, promptpay: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, scalapay: nil, sepa_debit: nil, sequra: nil, sofort: nil, sunbit: nil, swish: nil, twint: nil, upi: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 2752 2753 2754 2755 2756 2757 2758 2759 2760 2761 2762 2763 2764 2765 2766 2767 2768 2769 2770 2771 2772 2773 2774 2775 2776 2777 2778 2779 2780 2781 2782 2783 2784 2785 2786 2787 2788 2789 2790 2791 2792 2793 2794 2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2687 def initialize( acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, bizum: nil, blik: nil, boleto: nil, card: nil, card_present: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, paypay: nil, payto: nil, pix: nil, promptpay: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, scalapay: nil, sepa_debit: nil, sequra: nil, sofort: nil, sunbit: nil, swish: nil, twint: nil, upi: nil, us_bank_account: nil, wechat_pay: nil, zip: nil ) @acss_debit = acss_debit @affirm = affirm @afterpay_clearpay = afterpay_clearpay @alipay = alipay @alma = alma @amazon_pay = amazon_pay @au_becs_debit = au_becs_debit @bacs_debit = bacs_debit @bancontact = bancontact @billie = billie @bizum = bizum @blik = blik @boleto = boleto @card = card @card_present = card_present @cashapp = cashapp @crypto = crypto @customer_balance = customer_balance @eps = eps @fpx = fpx @giropay = giropay @grabpay = grabpay @ideal = ideal @interac_present = interac_present @kakao_pay = kakao_pay @klarna = klarna @konbini = konbini @kr_card = kr_card @link = link @mb_way = mb_way @mobilepay = mobilepay @multibanco = multibanco @naver_pay = naver_pay @nz_bank_account = nz_bank_account @oxxo = oxxo @p24 = p24 @pay_by_bank = pay_by_bank @payco = payco @paynow = paynow @paypal = paypal @paypay = paypay @payto = payto @pix = pix @promptpay = promptpay @revolut_pay = revolut_pay @samsung_pay = samsung_pay @satispay = satispay @scalapay = scalapay @sepa_debit = sepa_debit @sequra = sequra @sofort = sofort @sunbit = sunbit @swish = swish @twint = twint @upi = upi @us_bank_account = us_bank_account @wechat_pay = wechat_pay @zip = zip end |
Instance Attribute Details
#acss_debit ⇒ Object
If this is a acss_debit PaymentMethod, this sub-hash contains details about the ACSS Debit payment method options.
2571 2572 2573 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2571 def acss_debit @acss_debit end |
#affirm ⇒ Object
If this is an affirm PaymentMethod, this sub-hash contains details about the Affirm payment method options.
2573 2574 2575 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2573 def affirm @affirm end |
#afterpay_clearpay ⇒ Object
If this is a afterpay_clearpay PaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options.
2575 2576 2577 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2575 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
If this is a alipay PaymentMethod, this sub-hash contains details about the Alipay payment method options.
2577 2578 2579 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2577 def alipay @alipay end |
#alma ⇒ Object
If this is a alma PaymentMethod, this sub-hash contains details about the Alma payment method options.
2579 2580 2581 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2579 def alma @alma end |
#amazon_pay ⇒ Object
If this is a amazon_pay PaymentMethod, this sub-hash contains details about the Amazon Pay payment method options.
2581 2582 2583 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2581 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object
If this is a au_becs_debit PaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options.
2583 2584 2585 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2583 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object
If this is a bacs_debit PaymentMethod, this sub-hash contains details about the BACS Debit payment method options.
2585 2586 2587 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2585 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object
If this is a bancontact PaymentMethod, this sub-hash contains details about the Bancontact payment method options.
2587 2588 2589 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2587 def bancontact @bancontact end |
#billie ⇒ Object
If this is a billie PaymentMethod, this sub-hash contains details about the Billie payment method options.
2589 2590 2591 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2589 def billie @billie end |
#bizum ⇒ Object
If this is a bizum PaymentMethod, this sub-hash contains details about the Bizum payment method options.
2591 2592 2593 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2591 def bizum @bizum end |
#blik ⇒ Object
If this is a blik PaymentMethod, this sub-hash contains details about the BLIK payment method options.
2593 2594 2595 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2593 def blik @blik end |
#boleto ⇒ Object
If this is a boleto PaymentMethod, this sub-hash contains details about the Boleto payment method options.
2595 2596 2597 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2595 def boleto @boleto end |
#card ⇒ Object
Configuration for any card payments attempted on this PaymentIntent.
2597 2598 2599 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2597 def card @card end |
#card_present ⇒ Object
If this is a card_present PaymentMethod, this sub-hash contains details about the Card Present payment method options.
2599 2600 2601 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2599 def card_present @card_present end |
#cashapp ⇒ Object
If this is a cashapp PaymentMethod, this sub-hash contains details about the Cash App Pay payment method options.
2601 2602 2603 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2601 def cashapp @cashapp end |
#crypto ⇒ Object
If this is a crypto PaymentMethod, this sub-hash contains details about the Crypto payment method options.
2603 2604 2605 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2603 def crypto @crypto end |
#customer_balance ⇒ Object
If this is a customer balance PaymentMethod, this sub-hash contains details about the customer balance payment method options.
2605 2606 2607 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2605 def customer_balance @customer_balance end |
#eps ⇒ Object
If this is a eps PaymentMethod, this sub-hash contains details about the EPS payment method options.
2607 2608 2609 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2607 def eps @eps end |
#fpx ⇒ Object
If this is a fpx PaymentMethod, this sub-hash contains details about the FPX payment method options.
2609 2610 2611 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2609 def fpx @fpx end |
#giropay ⇒ Object
If this is a giropay PaymentMethod, this sub-hash contains details about the Giropay payment method options.
2611 2612 2613 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2611 def giropay @giropay end |
#grabpay ⇒ Object
If this is a grabpay PaymentMethod, this sub-hash contains details about the Grabpay payment method options.
2613 2614 2615 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2613 def grabpay @grabpay end |
#ideal ⇒ Object
If this is a ideal PaymentMethod, this sub-hash contains details about the Ideal payment method options.
2615 2616 2617 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2615 def ideal @ideal end |
#interac_present ⇒ Object
If this is a interac_present PaymentMethod, this sub-hash contains details about the Card Present payment method options.
2617 2618 2619 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2617 def interac_present @interac_present end |
#kakao_pay ⇒ Object
If this is a kakao_pay PaymentMethod, this sub-hash contains details about the Kakao Pay payment method options.
2619 2620 2621 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2619 def kakao_pay @kakao_pay end |
#klarna ⇒ Object
If this is a klarna PaymentMethod, this sub-hash contains details about the Klarna payment method options.
2621 2622 2623 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2621 def klarna @klarna end |
#konbini ⇒ Object
If this is a konbini PaymentMethod, this sub-hash contains details about the Konbini payment method options.
2623 2624 2625 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2623 def konbini @konbini end |
#kr_card ⇒ Object
If this is a kr_card PaymentMethod, this sub-hash contains details about the KR Card payment method options.
2625 2626 2627 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2625 def kr_card @kr_card end |
#link ⇒ Object
If this is a link PaymentMethod, this sub-hash contains details about the Link payment method options (Link is also known as Onelink in the UK).
2627 2628 2629 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2627 def link @link end |
#mb_way ⇒ Object
If this is a mb_way PaymentMethod, this sub-hash contains details about the MB WAY payment method options.
2629 2630 2631 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2629 def mb_way @mb_way end |
#mobilepay ⇒ Object
If this is a MobilePay PaymentMethod, this sub-hash contains details about the MobilePay payment method options.
2631 2632 2633 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2631 def mobilepay @mobilepay end |
#multibanco ⇒ Object
If this is a multibanco PaymentMethod, this sub-hash contains details about the Multibanco payment method options.
2633 2634 2635 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2633 def multibanco @multibanco end |
#naver_pay ⇒ Object
If this is a naver_pay PaymentMethod, this sub-hash contains details about the Naver Pay payment method options.
2635 2636 2637 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2635 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object
If this is a nz_bank_account PaymentMethod, this sub-hash contains details about the NZ BECS Direct Debit payment method options.
2637 2638 2639 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2637 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object
If this is a oxxo PaymentMethod, this sub-hash contains details about the OXXO payment method options.
2639 2640 2641 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2639 def oxxo @oxxo end |
#p24 ⇒ Object
If this is a p24 PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options.
2641 2642 2643 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2641 def p24 @p24 end |
#pay_by_bank ⇒ Object
If this is a pay_by_bank PaymentMethod, this sub-hash contains details about the PayByBank payment method options.
2643 2644 2645 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2643 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object
If this is a payco PaymentMethod, this sub-hash contains details about the PAYCO payment method options.
2645 2646 2647 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2645 def payco @payco end |
#paynow ⇒ Object
If this is a paynow PaymentMethod, this sub-hash contains details about the PayNow payment method options.
2647 2648 2649 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2647 def paynow @paynow end |
#paypal ⇒ Object
If this is a paypal PaymentMethod, this sub-hash contains details about the PayPal payment method options.
2649 2650 2651 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2649 def paypal @paypal end |
#paypay ⇒ Object
If this is a paypay PaymentMethod, this sub-hash contains details about the PayPay payment method options.
2651 2652 2653 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2651 def paypay @paypay end |
#payto ⇒ Object
If this is a payto PaymentMethod, this sub-hash contains details about the PayTo payment method options.
2653 2654 2655 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2653 def payto @payto end |
#pix ⇒ Object
If this is a pix PaymentMethod, this sub-hash contains details about the Pix payment method options.
2655 2656 2657 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2655 def pix @pix end |
#promptpay ⇒ Object
If this is a promptpay PaymentMethod, this sub-hash contains details about the PromptPay payment method options.
2657 2658 2659 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2657 def promptpay @promptpay end |
#revolut_pay ⇒ Object
If this is a revolut_pay PaymentMethod, this sub-hash contains details about the Revolut Pay payment method options.
2659 2660 2661 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2659 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object
If this is a samsung_pay PaymentMethod, this sub-hash contains details about the Samsung Pay payment method options.
2661 2662 2663 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2661 def samsung_pay @samsung_pay end |
#satispay ⇒ Object
If this is a satispay PaymentMethod, this sub-hash contains details about the Satispay payment method options.
2663 2664 2665 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2663 def satispay @satispay end |
#scalapay ⇒ Object
If this is a scalapay PaymentMethod, this sub-hash contains details about the ScalaPay payment method options.
2665 2666 2667 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2665 def scalapay @scalapay end |
#sepa_debit ⇒ Object
If this is a sepa_debit PaymentIntent, this sub-hash contains details about the SEPA Debit payment method options.
2667 2668 2669 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2667 def sepa_debit @sepa_debit end |
#sequra ⇒ Object
If this is a sequra PaymentMethod, this sub-hash contains details about the SeQura payment method options.
2669 2670 2671 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2669 def sequra @sequra end |
#sofort ⇒ Object
If this is a sofort PaymentMethod, this sub-hash contains details about the SOFORT payment method options.
2671 2672 2673 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2671 def sofort @sofort end |
#sunbit ⇒ Object
If this is a sunbit PaymentMethod, this sub-hash contains details about the Sunbit payment method options.
2673 2674 2675 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2673 def sunbit @sunbit end |
#swish ⇒ Object
If this is a Swish PaymentMethod, this sub-hash contains details about the Swish payment method options.
2675 2676 2677 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2675 def swish @swish end |
#twint ⇒ Object
If this is a twint PaymentMethod, this sub-hash contains details about the TWINT payment method options.
2677 2678 2679 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2677 def twint @twint end |
#upi ⇒ Object
If this is a upi PaymentIntent, this sub-hash contains details about the UPI payment method options.
2679 2680 2681 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2679 def upi @upi end |
#us_bank_account ⇒ Object
If this is a us_bank_account PaymentMethod, this sub-hash contains details about the US bank account payment method options.
2681 2682 2683 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2681 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
If this is a wechat_pay PaymentMethod, this sub-hash contains details about the WeChat Pay payment method options.
2683 2684 2685 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2683 def wechat_pay @wechat_pay end |
#zip ⇒ Object
If this is a zip PaymentMethod, this sub-hash contains details about the Zip payment method options.
2685 2686 2687 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2685 def zip @zip end |