Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Grabpay, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, RevolutPay, SamsungPay, Satispay, SepaDebit, Sofort, Swish, Twint, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, blik: nil, boleto: nil, card: nil, card_present: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, sofort: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



2393
2394
2395
2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
2499
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2393

def initialize(
  acss_debit: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  alma: nil,
  amazon_pay: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  billie: nil,
  blik: nil,
  boleto: nil,
  card: nil,
  card_present: nil,
  cashapp: nil,
  crypto: nil,
  customer_balance: nil,
  eps: nil,
  fpx: nil,
  giropay: nil,
  grabpay: nil,
  ideal: nil,
  interac_present: nil,
  kakao_pay: nil,
  klarna: nil,
  konbini: nil,
  kr_card: nil,
  link: nil,
  mb_way: nil,
  mobilepay: nil,
  multibanco: nil,
  naver_pay: nil,
  nz_bank_account: nil,
  oxxo: nil,
  p24: nil,
  pay_by_bank: nil,
  payco: nil,
  paynow: nil,
  paypal: nil,
  payto: nil,
  pix: nil,
  promptpay: nil,
  revolut_pay: nil,
  samsung_pay: nil,
  satispay: nil,
  sepa_debit: nil,
  sofort: nil,
  swish: nil,
  twint: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @alma = alma
  @amazon_pay = amazon_pay
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @billie = billie
  @blik = blik
  @boleto = boleto
  @card = card
  @card_present = card_present
  @cashapp = cashapp
  @crypto = crypto
  @customer_balance = customer_balance
  @eps = eps
  @fpx = fpx
  @giropay = giropay
  @grabpay = grabpay
  @ideal = ideal
  @interac_present = interac_present
  @kakao_pay = kakao_pay
  @klarna = klarna
  @konbini = konbini
  @kr_card = kr_card
  @link = link
  @mb_way = mb_way
  @mobilepay = mobilepay
  @multibanco = multibanco
  @naver_pay = naver_pay
   = 
  @oxxo = oxxo
  @p24 = p24
  @pay_by_bank = pay_by_bank
  @payco = payco
  @paynow = paynow
  @paypal = paypal
  @payto = payto
  @pix = pix
  @promptpay = promptpay
  @revolut_pay = revolut_pay
  @samsung_pay = samsung_pay
  @satispay = satispay
  @sepa_debit = sepa_debit
  @sofort = sofort
  @swish = swish
  @twint = twint
   = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

If this is a acss_debit PaymentMethod, this sub-hash contains details about the ACSS Debit payment method options.



2289
2290
2291
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2289

def acss_debit
  @acss_debit
end

#affirmObject

If this is an affirm PaymentMethod, this sub-hash contains details about the Affirm payment method options.



2291
2292
2293
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2291

def affirm
  @affirm
end

#afterpay_clearpayObject

If this is a afterpay_clearpay PaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options.



2293
2294
2295
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2293

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If this is a alipay PaymentMethod, this sub-hash contains details about the Alipay payment method options.



2295
2296
2297
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2295

def alipay
  @alipay
end

#almaObject

If this is a alma PaymentMethod, this sub-hash contains details about the Alma payment method options.



2297
2298
2299
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2297

def alma
  @alma
end

#amazon_payObject

If this is a amazon_pay PaymentMethod, this sub-hash contains details about the Amazon Pay payment method options.



2299
2300
2301
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2299

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject

If this is a au_becs_debit PaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options.



2301
2302
2303
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2301

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

If this is a bacs_debit PaymentMethod, this sub-hash contains details about the BACS Debit payment method options.



2303
2304
2305
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2303

def bacs_debit
  @bacs_debit
end

#bancontactObject

If this is a bancontact PaymentMethod, this sub-hash contains details about the Bancontact payment method options.



2305
2306
2307
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2305

def bancontact
  @bancontact
end

#billieObject

If this is a billie PaymentMethod, this sub-hash contains details about the Billie payment method options.



2307
2308
2309
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2307

def billie
  @billie
end

#blikObject

If this is a blik PaymentMethod, this sub-hash contains details about the BLIK payment method options.



2309
2310
2311
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2309

def blik
  @blik
end

#boletoObject

If this is a boleto PaymentMethod, this sub-hash contains details about the Boleto payment method options.



2311
2312
2313
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2311

def boleto
  @boleto
end

#cardObject

Configuration for any card payments attempted on this PaymentIntent.



2313
2314
2315
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2313

def card
  @card
end

#card_presentObject

If this is a card_present PaymentMethod, this sub-hash contains details about the Card Present payment method options.



2315
2316
2317
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2315

def card_present
  @card_present
end

#cashappObject

If this is a cashapp PaymentMethod, this sub-hash contains details about the Cash App Pay payment method options.



2317
2318
2319
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2317

def cashapp
  @cashapp
end

#cryptoObject

If this is a crypto PaymentMethod, this sub-hash contains details about the Crypto payment method options.



2319
2320
2321
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2319

def crypto
  @crypto
end

#customer_balanceObject

If this is a ‘customer balance` PaymentMethod, this sub-hash contains details about the customer balance payment method options.



2321
2322
2323
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2321

def customer_balance
  @customer_balance
end

#epsObject

If this is a eps PaymentMethod, this sub-hash contains details about the EPS payment method options.



2323
2324
2325
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2323

def eps
  @eps
end

#fpxObject

If this is a fpx PaymentMethod, this sub-hash contains details about the FPX payment method options.



2325
2326
2327
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2325

def fpx
  @fpx
end

#giropayObject

If this is a giropay PaymentMethod, this sub-hash contains details about the Giropay payment method options.



2327
2328
2329
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2327

def giropay
  @giropay
end

#grabpayObject

If this is a grabpay PaymentMethod, this sub-hash contains details about the Grabpay payment method options.



2329
2330
2331
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2329

def grabpay
  @grabpay
end

#idealObject

If this is a ideal PaymentMethod, this sub-hash contains details about the Ideal payment method options.



2331
2332
2333
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2331

def ideal
  @ideal
end

#interac_presentObject

If this is a interac_present PaymentMethod, this sub-hash contains details about the Card Present payment method options.



2333
2334
2335
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2333

def interac_present
  @interac_present
end

#kakao_payObject

If this is a kakao_pay PaymentMethod, this sub-hash contains details about the Kakao Pay payment method options.



2335
2336
2337
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2335

def kakao_pay
  @kakao_pay
end

#klarnaObject

If this is a klarna PaymentMethod, this sub-hash contains details about the Klarna payment method options.



2337
2338
2339
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2337

def klarna
  @klarna
end

#konbiniObject

If this is a konbini PaymentMethod, this sub-hash contains details about the Konbini payment method options.



2339
2340
2341
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2339

def konbini
  @konbini
end

#kr_cardObject

If this is a kr_card PaymentMethod, this sub-hash contains details about the KR Card payment method options.



2341
2342
2343
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2341

def kr_card
  @kr_card
end

If this is a link PaymentMethod, this sub-hash contains details about the Link payment method options.



2343
2344
2345
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2343

def link
  @link
end

#mb_wayObject

If this is a mb_way PaymentMethod, this sub-hash contains details about the MB WAY payment method options.



2345
2346
2347
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2345

def mb_way
  @mb_way
end

#mobilepayObject

If this is a MobilePay PaymentMethod, this sub-hash contains details about the MobilePay payment method options.



2347
2348
2349
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2347

def mobilepay
  @mobilepay
end

#multibancoObject

If this is a multibanco PaymentMethod, this sub-hash contains details about the Multibanco payment method options.



2349
2350
2351
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2349

def multibanco
  @multibanco
end

If this is a naver_pay PaymentMethod, this sub-hash contains details about the Naver Pay payment method options.



2351
2352
2353
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2351

def naver_pay
  @naver_pay
end

#nz_bank_accountObject

If this is a nz_bank_account PaymentMethod, this sub-hash contains details about the NZ BECS Direct Debit payment method options.



2353
2354
2355
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2353

def 
  
end

#oxxoObject

If this is a oxxo PaymentMethod, this sub-hash contains details about the OXXO payment method options.



2355
2356
2357
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2355

def oxxo
  @oxxo
end

#p24Object

If this is a p24 PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options.



2357
2358
2359
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2357

def p24
  @p24
end

#pay_by_bankObject

If this is a pay_by_bank PaymentMethod, this sub-hash contains details about the PayByBank payment method options.



2359
2360
2361
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2359

def pay_by_bank
  @pay_by_bank
end

#paycoObject

If this is a payco PaymentMethod, this sub-hash contains details about the PAYCO payment method options.



2361
2362
2363
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2361

def payco
  @payco
end

#paynowObject

If this is a paynow PaymentMethod, this sub-hash contains details about the PayNow payment method options.



2363
2364
2365
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2363

def paynow
  @paynow
end

#paypalObject

If this is a paypal PaymentMethod, this sub-hash contains details about the PayPal payment method options.



2365
2366
2367
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2365

def paypal
  @paypal
end

#paytoObject

If this is a payto PaymentMethod, this sub-hash contains details about the PayTo payment method options.



2367
2368
2369
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2367

def payto
  @payto
end

#pixObject

If this is a pix PaymentMethod, this sub-hash contains details about the Pix payment method options.



2369
2370
2371
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2369

def pix
  @pix
end

#promptpayObject

If this is a promptpay PaymentMethod, this sub-hash contains details about the PromptPay payment method options.



2371
2372
2373
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2371

def promptpay
  @promptpay
end

#revolut_payObject

If this is a revolut_pay PaymentMethod, this sub-hash contains details about the Revolut Pay payment method options.



2373
2374
2375
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2373

def revolut_pay
  @revolut_pay
end

#samsung_payObject

If this is a samsung_pay PaymentMethod, this sub-hash contains details about the Samsung Pay payment method options.



2375
2376
2377
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2375

def samsung_pay
  @samsung_pay
end

#satispayObject

If this is a satispay PaymentMethod, this sub-hash contains details about the Satispay payment method options.



2377
2378
2379
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2377

def satispay
  @satispay
end

#sepa_debitObject

If this is a sepa_debit PaymentIntent, this sub-hash contains details about the SEPA Debit payment method options.



2379
2380
2381
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2379

def sepa_debit
  @sepa_debit
end

#sofortObject

If this is a sofort PaymentMethod, this sub-hash contains details about the SOFORT payment method options.



2381
2382
2383
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2381

def sofort
  @sofort
end

#swishObject

If this is a Swish PaymentMethod, this sub-hash contains details about the Swish payment method options.



2383
2384
2385
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2383

def swish
  @swish
end

#twintObject

If this is a twint PaymentMethod, this sub-hash contains details about the TWINT payment method options.



2385
2386
2387
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2385

def twint
  @twint
end

#us_bank_accountObject

If this is a us_bank_account PaymentMethod, this sub-hash contains details about the US bank account payment method options.



2387
2388
2389
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2387

def 
  
end

#wechat_payObject

If this is a wechat_pay PaymentMethod, this sub-hash contains details about the WeChat Pay payment method options.



2389
2390
2391
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2389

def wechat_pay
  @wechat_pay
end

#zipObject

If this is a zip PaymentMethod, this sub-hash contains details about the Zip payment method options.



2391
2392
2393
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2391

def zip
  @zip
end