Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::AcssDebit

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: MandateOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(mandate_options: nil, setup_future_usage: nil, target_date: nil, verification_method: nil) ⇒ AcssDebit

Returns a new instance of AcssDebit.



2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2614

def initialize(
  mandate_options: nil,
  setup_future_usage: nil,
  target_date: nil,
  verification_method: nil
)
  @mandate_options = mandate_options
  @setup_future_usage = setup_future_usage
  @target_date = target_date
  @verification_method = verification_method
end

Instance Attribute Details

#mandate_optionsObject

Additional fields for Mandate creation



2598
2599
2600
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2598

def mandate_options
  @mandate_options
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.

If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.



2608
2609
2610
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2608

def setup_future_usage
  @setup_future_usage
end

#target_dateObject

Controls when Stripe will attempt to debit the funds from the customer's account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.



2610
2611
2612
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2610

def target_date
  @target_date
end

#verification_methodObject

Bank account verification method. The default value is automatic.



2612
2613
2614
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2612

def verification_method
  @verification_method
end