Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::AfterpayClearpay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::AfterpayClearpay
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
-
#reference ⇒ Object
An internal identifier or reference that this payment corresponds to.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
Instance Method Summary collapse
-
#initialize(capture_method: nil, reference: nil, setup_future_usage: nil) ⇒ AfterpayClearpay
constructor
A new instance of AfterpayClearpay.
Methods inherited from RequestParams
Constructor Details
#initialize(capture_method: nil, reference: nil, setup_future_usage: nil) ⇒ AfterpayClearpay
Returns a new instance of AfterpayClearpay.
2615 2616 2617 2618 2619 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2615 def initialize(capture_method: nil, reference: nil, setup_future_usage: nil) @capture_method = capture_method @reference = reference @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.
If ‘capture_method` is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.
2600 2601 2602 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2600 def capture_method @capture_method end |
#reference ⇒ Object
An internal identifier or reference that this payment corresponds to. You must limit the identifier to 128 characters, and it can only contain letters, numbers, underscores, backslashes, and dashes. This field differs from the statement descriptor and item name.
2603 2604 2605 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2603 def reference @reference end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.
2613 2614 2615 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2613 def setup_future_usage @setup_future_usage end |