Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Card

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Installments, MandateOptions, PaymentDetails, StatementDetails, ThreeDSecure

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(capture_method: nil, cvc_token: nil, installments: nil, mandate_options: nil, moto: nil, network: nil, payment_details: nil, request_decremental_authorization: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_partial_authorization: nil, request_reauthorization: nil, request_three_d_secure: nil, require_cvc_recollection: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil, statement_details: nil, three_d_secure: nil) ⇒ Card

Returns a new instance of Card.



3491
3492
3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
3527
3528
3529
3530
3531
3532
3533
3534
3535
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3491

def initialize(
  capture_method: nil,
  cvc_token: nil,
  installments: nil,
  mandate_options: nil,
  moto: nil,
  network: nil,
  payment_details: nil,
  request_decremental_authorization: nil,
  request_extended_authorization: nil,
  request_incremental_authorization: nil,
  request_multicapture: nil,
  request_overcapture: nil,
  request_partial_authorization: nil,
  request_reauthorization: nil,
  request_three_d_secure: nil,
  require_cvc_recollection: nil,
  setup_future_usage: nil,
  statement_descriptor_suffix_kana: nil,
  statement_descriptor_suffix_kanji: nil,
  statement_details: nil,
  three_d_secure: nil
)
  @capture_method = capture_method
  @cvc_token = cvc_token
  @installments = installments
  @mandate_options = mandate_options
  @moto = moto
  @network = network
  @payment_details = payment_details
  @request_decremental_authorization = request_decremental_authorization
  @request_extended_authorization = request_extended_authorization
  @request_incremental_authorization = request_incremental_authorization
  @request_multicapture = request_multicapture
  @request_overcapture = request_overcapture
  @request_partial_authorization = request_partial_authorization
  @request_reauthorization = request_reauthorization
  @request_three_d_secure = request_three_d_secure
  @require_cvc_recollection = require_cvc_recollection
  @setup_future_usage = setup_future_usage
  @statement_descriptor_suffix_kana = statement_descriptor_suffix_kana
  @statement_descriptor_suffix_kanji = statement_descriptor_suffix_kanji
  @statement_details = statement_details
  @three_d_secure = three_d_secure
end

Instance Attribute Details

#capture_methodObject

Controls when the funds are captured from the customer’s account.

If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.

If ‘capture_method` is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.



3436
3437
3438
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3436

def capture_method
  @capture_method
end

#cvc_tokenObject

A single-use ‘cvc_update` Token that represents a card CVC value. When provided, the CVC value will be verified during the card payment attempt. This parameter can only be provided during confirmation.



3438
3439
3440
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3438

def cvc_token
  @cvc_token
end

#installmentsObject

Installment configuration for payments attempted on this PaymentIntent.

For more information, see the [installments integration guide](docs.stripe.com/payments/installments).



3442
3443
3444
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3442

def installments
  @installments
end

#mandate_optionsObject

Configuration options for setting up an eMandate for cards issued in India.



3444
3445
3446
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3444

def mandate_options
  @mandate_options
end

#motoObject

When specified, this parameter indicates that a transaction will be marked as MOTO (Mail Order Telephone Order) and thus out of scope for SCA. This parameter can only be provided during confirmation.



3448
3449
3450
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3448

def moto
  @moto
end

#networkObject

Selected network to process this PaymentIntent on. Depends on the available networks of the card attached to the PaymentIntent. Can be only set confirm-time.



3450
3451
3452
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3450

def network
  @network
end

#payment_detailsObject

Payment details for payment method specific funding fields.



3452
3453
3454
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3452

def payment_details
  @payment_details
end

#request_decremental_authorizationObject

Request ability to [decrement the authorization](docs.stripe.com/payments/decremental-authorization) for this PaymentIntent.



3454
3455
3456
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3454

def request_decremental_authorization
  @request_decremental_authorization
end

#request_extended_authorizationObject

Request ability to [capture beyond the standard authorization validity window](docs.stripe.com/payments/extended-authorization) for this PaymentIntent.



3456
3457
3458
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3456

def request_extended_authorization
  @request_extended_authorization
end

#request_incremental_authorizationObject

Request ability to [increment the authorization](docs.stripe.com/payments/incremental-authorization) for this PaymentIntent.



3458
3459
3460
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3458

def request_incremental_authorization
  @request_incremental_authorization
end

#request_multicaptureObject

Request ability to make [multiple captures](docs.stripe.com/payments/multicapture) for this PaymentIntent.



3460
3461
3462
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3460

def request_multicapture
  @request_multicapture
end

#request_overcaptureObject

Request ability to [overcapture](docs.stripe.com/payments/overcapture) for this PaymentIntent.



3462
3463
3464
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3462

def request_overcapture
  @request_overcapture
end

#request_partial_authorizationObject

Request partial authorization on this PaymentIntent.



3464
3465
3466
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3464

def request_partial_authorization
  @request_partial_authorization
end

#request_reauthorizationObject

Request ability to [reauthorize](docs.stripe.com/payments/reauthorization) for this PaymentIntent.



3466
3467
3468
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3466

def request_reauthorization
  @request_reauthorization
end

#request_three_d_secureObject

We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](docs.stripe.com/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](docs.stripe.com/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.



3468
3469
3470
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3468

def request_three_d_secure
  @request_three_d_secure
end

#require_cvc_recollectionObject

When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).



3470
3471
3472
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3470

def require_cvc_recollection
  @require_cvc_recollection
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



3480
3481
3482
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3480

def setup_future_usage
  @setup_future_usage
end

#statement_descriptor_suffix_kanaObject

Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.



3482
3483
3484
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3482

def statement_descriptor_suffix_kana
  @statement_descriptor_suffix_kana
end

#statement_descriptor_suffix_kanjiObject

Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.



3484
3485
3486
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3484

def statement_descriptor_suffix_kanji
  @statement_descriptor_suffix_kanji
end

#statement_detailsObject

Statement details for this payment intent. You can use this to override the merchant details shown on your customers’ statements.



3486
3487
3488
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3486

def statement_details
  @statement_details
end

#three_d_secureObject

If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this payment.



3489
3490
3491
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3489

def three_d_secure
  @three_d_secure
end