Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



3295
3296
3297
3298
3299
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3295

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For fixed_count installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



3288
3289
3290
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3288

def count
  @count
end

#intervalObject

For fixed_count installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of month.



3291
3292
3293
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3291

def interval
  @interval
end

#typeObject

Type of installment plan, one of fixed_count, bonus, or revolving.



3293
3294
3295
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3293

def type
  @type
end