Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



1120
1121
1122
1123
1124
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1120

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



1113
1114
1115
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1113

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



1116
1117
1118
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1116

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



1118
1119
1120
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1118

def type
  @type
end