Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



3190
3191
3192
3193
3194
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3190

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



3183
3184
3185
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3183

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



3186
3187
3188
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3186

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



3188
3189
3190
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3188

def type
  @type
end