Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1160

def initialize(
  amount: nil,
  amount_type: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments, specified in the presentment currency.



1142
1143
1144
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1142

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



1144
1145
1146
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1144

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



1146
1147
1148
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1146

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



1148
1149
1150
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1148

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of day, week, month, year, or sporadic.



1150
1151
1152
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1150

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, interval=month and interval_count=3 indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when interval=sporadic.



1152
1153
1154
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1152

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



1154
1155
1156
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1154

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



1156
1157
1158
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1156

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are india.



1158
1159
1160
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1158

def supported_types
  @supported_types
end