Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2911

def initialize(
  amount: nil,
  amount_type: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments, specified in the presentment currency.



2893
2894
2895
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2893

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



2895
2896
2897
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2895

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



2897
2898
2899
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2897

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



2899
2900
2901
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2899

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of day, week, month, year, or sporadic.



2901
2902
2903
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2901

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, interval=month and interval_count=3 indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when interval=sporadic.



2903
2904
2905
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2903

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



2905
2906
2907
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2905

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



2907
2908
2909
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2907

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are india.



2909
2910
2911
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2909

def supported_types
  @supported_types
end