Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



3208
3209
3210
3211
3212
3213
3214
3215
3216
3217
3218
3219
3220
3221
3222
3223
3224
3225
3226
3227
3228
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3208

def initialize(
  amount: nil,
  amount_type: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments, specified in the presentment currency.



3190
3191
3192
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3190

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



3192
3193
3194
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3192

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



3194
3195
3196
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3194

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



3196
3197
3198
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3196

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



3198
3199
3200
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3198

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



3200
3201
3202
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3200

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



3202
3203
3204
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3202

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



3204
3205
3206
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3204

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are ‘india`.



3206
3207
3208
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3206

def supported_types
  @supported_types
end