Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2866
2867
2868
2869
2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2866

def initialize(
  amount: nil,
  amount_type: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



2848
2849
2850
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2848

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



2850
2851
2852
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2850

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



2852
2853
2854
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2852

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



2854
2855
2856
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2854

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



2856
2857
2858
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2856

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



2858
2859
2860
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2858

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



2860
2861
2862
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2860

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



2862
2863
2864
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2862

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are ‘india`.



2864
2865
2866
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2864

def supported_types
  @supported_types
end