Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Card::StatementDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Card::StatementDetails
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Please pass in an address that is within your Stripe user account country.
-
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call).
Instance Method Summary collapse
-
#initialize(address: nil, phone: nil) ⇒ StatementDetails
constructor
A new instance of StatementDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, phone: nil) ⇒ StatementDetails
Returns a new instance of StatementDetails.
2908 2909 2910 2911 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2908 def initialize(address: nil, phone: nil) @address = address @phone = phone end |
Instance Attribute Details
#address ⇒ Object
Please pass in an address that is within your Stripe user account country
2904 2905 2906 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2904 def address @address end |
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call)
2906 2907 2908 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2906 def phone @phone end |