Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Card::StatementDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Card::StatementDetails
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Please pass in an address that is within your Stripe user account country.
-
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call).
Instance Method Summary collapse
-
#initialize(address: nil, phone: nil) ⇒ StatementDetails
constructor
A new instance of StatementDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, phone: nil) ⇒ StatementDetails
Returns a new instance of StatementDetails.
1959 1960 1961 1962 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1959 def initialize(address: nil, phone: nil) @address = address @phone = phone end |
Instance Attribute Details
#address ⇒ Object
Please pass in an address that is within your Stripe user account country
1955 1956 1957 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1955 def address @address end |
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call)
1957 1958 1959 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1957 def phone @phone end |