Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Card::StatementDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Card::StatementDetails
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Please pass in an address that is within your Stripe user account country.
-
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call).
Instance Method Summary collapse
-
#initialize(address: nil, phone: nil) ⇒ StatementDetails
constructor
A new instance of StatementDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, phone: nil) ⇒ StatementDetails
Returns a new instance of StatementDetails.
1938 1939 1940 1941 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1938 def initialize(address: nil, phone: nil) @address = address @phone = phone end |
Instance Attribute Details
#address ⇒ Object
Please pass in an address that is within your Stripe user account country
1934 1935 1936 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1934 def address @address end |
#phone ⇒ Object
Phone number (e.g., a toll-free number that customers can call)
1936 1937 1938 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1936 def phone @phone end |