Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::CardPresent

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: PaymentDetails, Routing

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(capture_method: nil, request_extended_authorization: nil, request_incremental_authorization_support: nil, request_reauthorization: nil, routing: nil, payment_details: nil) ⇒ CardPresent

Returns a new instance of CardPresent.



3245
3246
3247
3248
3249
3250
3251
3252
3253
3254
3255
3256
3257
3258
3259
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3245

def initialize(
  capture_method: nil,
  request_extended_authorization: nil,
  request_incremental_authorization_support: nil,
  request_reauthorization: nil,
  routing: nil,
  payment_details: nil
)
  @capture_method = capture_method
  @request_extended_authorization = request_extended_authorization
  @request_incremental_authorization_support = request_incremental_authorization_support
  @request_reauthorization = request_reauthorization
  @routing = routing
  @payment_details = payment_details
end

Instance Attribute Details

#capture_methodObject

Controls when the funds are captured from the customer’s account.

If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.

If ‘capture_method` is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.



3233
3234
3235
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3233

def capture_method
  @capture_method
end

#payment_detailsObject

Payment details for payment method specific funding transaction fields.



3243
3244
3245
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3243

def payment_details
  @payment_details
end

#request_extended_authorizationObject

Request ability to capture this payment beyond the standard [authorization validity window](docs.stripe.com/terminal/features/extended-authorizations#authorization-validity)



3235
3236
3237
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3235

def request_extended_authorization
  @request_extended_authorization
end

#request_incremental_authorization_supportObject

Request ability to [increment](docs.stripe.com/terminal/features/incremental-authorizations) this PaymentIntent if the combination of MCC and card brand is eligible. Check [incremental_authorization_supported](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-incremental_authorization_supported) in the [Confirm](docs.stripe.com/api/payment_intents/confirm) response to verify support.



3237
3238
3239
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3237

def request_incremental_authorization_support
  @request_incremental_authorization_support
end

#request_reauthorizationObject

Request ability to [reauthorize](docs.stripe.com/payments/reauthorization) for this PaymentIntent.



3239
3240
3241
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3239

def request_reauthorization
  @request_reauthorization
end

#routingObject

Network routing priority on co-branded EMV cards supporting domestic debit and international card schemes.



3241
3242
3243
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3241

def routing
  @routing
end