Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::GiftCard
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::GiftCard
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#ignore_application_fee ⇒ Object
Set to
yesto ignore the application fee on the PaymentIntent when redeeming this gift card. -
#ignore_transfer_data ⇒ Object
Set to
yesto ignore transfer data on the PaymentIntent when redeeming this gift card. -
#request_partial_authorization ⇒ Object
Request partial authorization on this PaymentIntent.
Instance Method Summary collapse
-
#initialize(ignore_application_fee: nil, ignore_transfer_data: nil, request_partial_authorization: nil) ⇒ GiftCard
constructor
A new instance of GiftCard.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(ignore_application_fee: nil, ignore_transfer_data: nil, request_partial_authorization: nil) ⇒ GiftCard
Returns a new instance of GiftCard.
3894 3895 3896 3897 3898 3899 3900 3901 3902 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3894 def initialize( ignore_application_fee: nil, ignore_transfer_data: nil, request_partial_authorization: nil ) @ignore_application_fee = ignore_application_fee @ignore_transfer_data = ignore_transfer_data @request_partial_authorization = end |
Instance Attribute Details
#ignore_application_fee ⇒ Object
Set to yes to ignore the application fee on the PaymentIntent when redeeming this gift card.
3888 3889 3890 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3888 def ignore_application_fee @ignore_application_fee end |
#ignore_transfer_data ⇒ Object
Set to yes to ignore transfer data on the PaymentIntent when redeeming this gift card.
3890 3891 3892 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3890 def ignore_transfer_data @ignore_transfer_data end |
#request_partial_authorization ⇒ Object
Request partial authorization on this PaymentIntent.
3892 3893 3894 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3892 def @request_partial_authorization end |