Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: OnDemand, Subscription, SupplementaryPurchaseData
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds are captured from the customer's account.
-
#on_demand ⇒ Object
On-demand details if setting up or charging an on-demand payment.
-
#preferred_locale ⇒ Object
Preferred language of the Klarna authorization page that the customer is redirected to.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
-
#subscriptions ⇒ Object
Subscription details if setting up or charging a subscription.
-
#supplementary_purchase_data ⇒ Object
Supplementary Purchase Data for the corresponding Klarna payment.
Instance Method Summary collapse
-
#initialize(capture_method: nil, on_demand: nil, preferred_locale: nil, setup_future_usage: nil, subscriptions: nil, supplementary_purchase_data: nil) ⇒ Klarna
constructor
A new instance of Klarna.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(capture_method: nil, on_demand: nil, preferred_locale: nil, setup_future_usage: nil, subscriptions: nil, supplementary_purchase_data: nil) ⇒ Klarna
Returns a new instance of Klarna.
4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4444 def initialize( capture_method: nil, on_demand: nil, preferred_locale: nil, setup_future_usage: nil, subscriptions: nil, supplementary_purchase_data: nil ) @capture_method = capture_method @on_demand = on_demand @preferred_locale = preferred_locale @setup_future_usage = setup_future_usage @subscriptions = subscriptions @supplementary_purchase_data = supplementary_purchase_data end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds are captured from the customer's account.
If provided, this parameter overrides the behavior of the top-level capture_method for this payment method type when finalizing the payment with this payment method type.
If capture_method is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.
4424 4425 4426 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4424 def capture_method @capture_method end |
#on_demand ⇒ Object
On-demand details if setting up or charging an on-demand payment.
4426 4427 4428 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4426 def on_demand @on_demand end |
#preferred_locale ⇒ Object
Preferred language of the Klarna authorization page that the customer is redirected to
4428 4429 4430 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4428 def preferred_locale @preferred_locale end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.
4438 4439 4440 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4438 def setup_future_usage @setup_future_usage end |
#subscriptions ⇒ Object
Subscription details if setting up or charging a subscription.
4440 4441 4442 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4440 def subscriptions @subscriptions end |
#supplementary_purchase_data ⇒ Object
Supplementary Purchase Data for the corresponding Klarna payment
4442 4443 4444 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4442 def supplementary_purchase_data @supplementary_purchase_data end |