Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::OnDemand

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand

Returns a new instance of OnDemand.



3925
3926
3927
3928
3929
3930
3931
3932
3933
3934
3935
3936
3937
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3925

def initialize(
  average_amount: nil,
  maximum_amount: nil,
  minimum_amount: nil,
  purchase_interval: nil,
  purchase_interval_count: nil
)
  @average_amount = average_amount
  @maximum_amount = maximum_amount
  @minimum_amount = minimum_amount
  @purchase_interval = purchase_interval
  @purchase_interval_count = purchase_interval_count
end

Instance Attribute Details

#average_amountObject

Your average amount value. You can use a value across your customer base, or segment based on customer type, country, etc.



3915
3916
3917
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3915

def average_amount
  @average_amount
end

#maximum_amountObject

The maximum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



3917
3918
3919
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3917

def maximum_amount
  @maximum_amount
end

#minimum_amountObject

The lowest or minimum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



3919
3920
3921
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3919

def minimum_amount
  @minimum_amount
end

#purchase_intervalObject

Interval at which the customer is making purchases



3921
3922
3923
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3921

def purchase_interval
  @purchase_interval
end

#purchase_interval_countObject

The number of ‘purchase_interval` between charges



3923
3924
3925
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3923

def purchase_interval_count
  @purchase_interval_count
end