Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3503 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
3493 3494 3495 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3493 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
3495 3496 3497 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3495 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
3497 3498 3499 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3497 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
3499 3500 3501 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3499 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
3501 3502 3503 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3501 def reference @reference end |