Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
3440 3441 3442 3443 3444 3445 3446 3447 3448 3449 3450 3451 3452 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3440 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
3430 3431 3432 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3430 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
3432 3433 3434 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3432 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
3434 3435 3436 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3434 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
3436 3437 3438 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3436 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
3438 3439 3440 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3438 def reference @reference end |