Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



1594
1595
1596
1597
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1594

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



1590
1591
1592
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1590

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



1592
1593
1594
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1592

def date
  @date
end