Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



1566
1567
1568
1569
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1566

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



1562
1563
1564
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1562

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



1564
1565
1566
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1564

def date
  @date
end