Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



1553
1554
1555
1556
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1553

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



1549
1550
1551
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1549

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



1551
1552
1553
# File 'lib/stripe/params/payment_intent_update_params.rb', line 1551

def date
  @date
end