Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



3411
3412
3413
3414
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3411

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



3407
3408
3409
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3407

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



3409
3410
3411
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3409

def date
  @date
end