Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3492 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3480 3481 3482 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3480 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3482 3483 3484 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3482 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3484 3485 3486 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3484 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3486 3487 3488 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3486 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3488 3489 3490 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3488 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3490 3491 3492 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3490 def street_address2 @street_address2 end |