Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3596 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3584 3585 3586 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3584 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3586 3587 3588 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3586 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3588 3589 3590 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3588 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3590 3591 3592 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3590 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3592 3593 3594 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3592 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3594 3595 3596 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3594 def street_address2 @street_address2 end |