Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
3442 3443 3444 3445 3446 3447 3448 3449 3450 3451 3452 3453 3454 3455 3456 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3442 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3430 3431 3432 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3430 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3432 3433 3434 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3432 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3434 3435 3436 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3434 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3436 3437 3438 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3436 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3438 3439 3440 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3438 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3440 3441 3442 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3440 def street_address2 @street_address2 end |