Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail::Departure::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail::Departure::Address
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3577 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3565 3566 3567 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3565 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3567 3568 3569 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3567 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3569 3570 3571 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3569 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3571 3572 3573 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3571 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3573 3574 3575 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3573 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3575 3576 3577 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3575 def street_address2 @street_address2 end |