Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Address, Insurance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail

Returns a new instance of EventReservationDetail.



4227
4228
4229
4230
4231
4232
4233
4234
4235
4236
4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4227

def initialize(
  access_controlled_venue: nil,
  address: nil,
  affiliate_name: nil,
  ends_at: nil,
  event_company_name: nil,
  event_name: nil,
  event_type: nil,
  insurances: nil,
  starts_at: nil,
  venue_name: nil
)
  @access_controlled_venue = access_controlled_venue
  @address = address
  @affiliate_name = affiliate_name
  @ends_at = ends_at
  @event_company_name = event_company_name
  @event_name = event_name
  @event_type = event_type
  @insurances = insurances
  @starts_at = starts_at
  @venue_name = venue_name
end

Instance Attribute Details

#access_controlled_venueObject

Indicates if the tickets are digitally checked when entering the venue.



4207
4208
4209
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4207

def access_controlled_venue
  @access_controlled_venue
end

#addressObject

Address of the event.



4209
4210
4211
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4209

def address
  @address
end

#affiliate_nameObject

Name of associated or partner company for the service.



4211
4212
4213
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4211

def affiliate_name
  @affiliate_name
end

#ends_atObject

End timestamp of the event.



4213
4214
4215
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4213

def ends_at
  @ends_at
end

#event_company_nameObject

Company selling the ticket.



4215
4216
4217
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4215

def event_company_name
  @event_company_name
end

#event_nameObject

Name of the event.



4217
4218
4219
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4217

def event_name
  @event_name
end

#event_typeObject

Type of the event.



4219
4220
4221
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4219

def event_type
  @event_type
end

#insurancesObject

List of insurances for this event.



4221
4222
4223
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4221

def insurances
  @insurances
end

#starts_atObject

Start timestamp of the event.



4223
4224
4225
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4223

def starts_at
  @starts_at
end

#venue_nameObject

Name of the venue where the event takes place.



4225
4226
4227
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4225

def venue_name
  @venue_name
end