Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
Address of the event.
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#ends_at ⇒ Object
End timestamp of the event.
-
#event_company_name ⇒ Object
Company selling the ticket.
-
#event_name ⇒ Object
Name of the event.
-
#event_type ⇒ Object
Type of the event.
-
#insurances ⇒ Object
List of insurances for this event.
-
#starts_at ⇒ Object
Start timestamp of the event.
-
#venue_name ⇒ Object
Name of the venue where the event takes place.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail
constructor
A new instance of EventReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail
Returns a new instance of EventReservationDetail.
3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3715 def initialize( access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate_name = affiliate_name @ends_at = ends_at @event_company_name = event_company_name @event_name = event_name @event_type = event_type @insurances = insurances @starts_at = starts_at @venue_name = venue_name end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
3695 3696 3697 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3695 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
Address of the event.
3697 3698 3699 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3697 def address @address end |
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
3699 3700 3701 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3699 def affiliate_name @affiliate_name end |
#ends_at ⇒ Object
End timestamp of the event.
3701 3702 3703 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3701 def ends_at @ends_at end |
#event_company_name ⇒ Object
Company selling the ticket.
3703 3704 3705 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3703 def event_company_name @event_company_name end |
#event_name ⇒ Object
Name of the event.
3705 3706 3707 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3705 def event_name @event_name end |
#event_type ⇒ Object
Type of the event.
3707 3708 3709 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3707 def event_type @event_type end |
#insurances ⇒ Object
List of insurances for this event.
3709 3710 3711 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3709 def insurances @insurances end |
#starts_at ⇒ Object
Start timestamp of the event.
3711 3712 3713 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3711 def starts_at @starts_at end |
#venue_name ⇒ Object
Name of the venue where the event takes place.
3713 3714 3715 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3713 def venue_name @venue_name end |