Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
Address of the event.
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#ends_at ⇒ Object
End timestamp of the event.
-
#event_company_name ⇒ Object
Company selling the ticket.
-
#event_name ⇒ Object
Name of the event.
-
#event_type ⇒ Object
Type of the event.
-
#insurances ⇒ Object
List of insurances for this event.
-
#starts_at ⇒ Object
Start timestamp of the event.
-
#venue_name ⇒ Object
Name of the venue where the event takes place.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail
constructor
A new instance of EventReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail
Returns a new instance of EventReservationDetail.
3819 3820 3821 3822 3823 3824 3825 3826 3827 3828 3829 3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3819 def initialize( access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate_name = affiliate_name @ends_at = ends_at @event_company_name = event_company_name @event_name = event_name @event_type = event_type @insurances = insurances @starts_at = starts_at @venue_name = venue_name end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
3799 3800 3801 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3799 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
Address of the event.
3801 3802 3803 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3801 def address @address end |
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
3803 3804 3805 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3803 def affiliate_name @affiliate_name end |
#ends_at ⇒ Object
End timestamp of the event.
3805 3806 3807 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3805 def ends_at @ends_at end |
#event_company_name ⇒ Object
Company selling the ticket.
3807 3808 3809 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3807 def event_company_name @event_company_name end |
#event_name ⇒ Object
Name of the event.
3809 3810 3811 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3809 def event_name @event_name end |
#event_type ⇒ Object
Type of the event.
3811 3812 3813 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3811 def event_type @event_type end |
#insurances ⇒ Object
List of insurances for this event.
3813 3814 3815 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3813 def insurances @insurances end |
#starts_at ⇒ Object
Start timestamp of the event.
3815 3816 3817 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3815 def starts_at @starts_at end |
#venue_name ⇒ Object
Name of the venue where the event takes place.
3817 3818 3819 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3817 def venue_name @venue_name end |