Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
Address of the event.
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#ends_at ⇒ Object
End timestamp of the event.
-
#event_company_name ⇒ Object
Company selling the ticket.
-
#event_name ⇒ Object
Name of the event.
-
#event_type ⇒ Object
Type of the event.
-
#insurances ⇒ Object
List of insurances for this event.
-
#starts_at ⇒ Object
Start timestamp of the event.
-
#venue_name ⇒ Object
Name of the venue where the event takes place.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail
constructor
A new instance of EventReservationDetail.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail
Returns a new instance of EventReservationDetail.
3665 3666 3667 3668 3669 3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 3680 3681 3682 3683 3684 3685 3686 3687 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3665 def initialize( access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate_name = affiliate_name @ends_at = ends_at @event_company_name = event_company_name @event_name = event_name @event_type = event_type @insurances = insurances @starts_at = starts_at @venue_name = venue_name end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
3645 3646 3647 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3645 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
Address of the event.
3647 3648 3649 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3647 def address @address end |
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
3649 3650 3651 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3649 def affiliate_name @affiliate_name end |
#ends_at ⇒ Object
End timestamp of the event.
3651 3652 3653 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3651 def ends_at @ends_at end |
#event_company_name ⇒ Object
Company selling the ticket.
3653 3654 3655 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3653 def event_company_name @event_company_name end |
#event_name ⇒ Object
Name of the event.
3655 3656 3657 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3655 def event_name @event_name end |
#event_type ⇒ Object
Type of the event.
3657 3658 3659 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3657 def event_type @event_type end |
#insurances ⇒ Object
List of insurances for this event.
3659 3660 3661 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3659 def insurances @insurances end |
#starts_at ⇒ Object
Start timestamp of the event.
3661 3662 3663 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3661 def starts_at @starts_at end |
#venue_name ⇒ Object
Name of the venue where the event takes place.
3663 3664 3665 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3663 def venue_name @venue_name end |