Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Address, Insurance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail

Returns a new instance of EventReservationDetail.



3695
3696
3697
3698
3699
3700
3701
3702
3703
3704
3705
3706
3707
3708
3709
3710
3711
3712
3713
3714
3715
3716
3717
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3695

def initialize(
  access_controlled_venue: nil,
  address: nil,
  affiliate_name: nil,
  ends_at: nil,
  event_company_name: nil,
  event_name: nil,
  event_type: nil,
  insurances: nil,
  starts_at: nil,
  venue_name: nil
)
  @access_controlled_venue = access_controlled_venue
  @address = address
  @affiliate_name = affiliate_name
  @ends_at = ends_at
  @event_company_name = event_company_name
  @event_name = event_name
  @event_type = event_type
  @insurances = insurances
  @starts_at = starts_at
  @venue_name = venue_name
end

Instance Attribute Details

#access_controlled_venueObject

Indicates if the tickets are digitally checked when entering the venue.



3675
3676
3677
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3675

def access_controlled_venue
  @access_controlled_venue
end

#addressObject

Address of the event.



3677
3678
3679
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3677

def address
  @address
end

#affiliate_nameObject

Name of associated or partner company for the service.



3679
3680
3681
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3679

def affiliate_name
  @affiliate_name
end

#ends_atObject

End timestamp of the event.



3681
3682
3683
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3681

def ends_at
  @ends_at
end

#event_company_nameObject

Company selling the ticket.



3683
3684
3685
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3683

def event_company_name
  @event_company_name
end

#event_nameObject

Name of the event.



3685
3686
3687
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3685

def event_name
  @event_name
end

#event_typeObject

Type of the event.



3687
3688
3689
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3687

def event_type
  @event_type
end

#insurancesObject

List of insurances for this event.



3689
3690
3691
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3689

def insurances
  @insurances
end

#starts_atObject

Start timestamp of the event.



3691
3692
3693
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3691

def starts_at
  @starts_at
end

#venue_nameObject

Name of the venue where the event takes place.



3693
3694
3695
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3693

def venue_name
  @venue_name
end