Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
Address of the event.
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#ends_at ⇒ Object
End timestamp of the event.
-
#event_company_name ⇒ Object
Company selling the ticket.
-
#event_name ⇒ Object
Name of the event.
-
#event_type ⇒ Object
Type of the event.
-
#insurances ⇒ Object
List of insurances for this event.
-
#starts_at ⇒ Object
Start timestamp of the event.
-
#venue_name ⇒ Object
Name of the venue where the event takes place.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail
constructor
A new instance of EventReservationDetail.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail
Returns a new instance of EventReservationDetail.
3682 3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3682 def initialize( access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate_name = affiliate_name @ends_at = ends_at @event_company_name = event_company_name @event_name = event_name @event_type = event_type @insurances = insurances @starts_at = starts_at @venue_name = venue_name end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
3662 3663 3664 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3662 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
Address of the event.
3664 3665 3666 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3664 def address @address end |
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
3666 3667 3668 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3666 def affiliate_name @affiliate_name end |
#ends_at ⇒ Object
End timestamp of the event.
3668 3669 3670 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3668 def ends_at @ends_at end |
#event_company_name ⇒ Object
Company selling the ticket.
3670 3671 3672 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3670 def event_company_name @event_company_name end |
#event_name ⇒ Object
Name of the event.
3672 3673 3674 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3672 def event_name @event_name end |
#event_type ⇒ Object
Type of the event.
3674 3675 3676 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3674 def event_type @event_type end |
#insurances ⇒ Object
List of insurances for this event.
3676 3677 3678 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3676 def insurances @insurances end |
#starts_at ⇒ Object
Start timestamp of the event.
3678 3679 3680 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3678 def starts_at @starts_at end |
#venue_name ⇒ Object
Name of the venue where the event takes place.
3680 3681 3682 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3680 def venue_name @venue_name end |