Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail::Address
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4162 4163 4164 4165 4166 4167 4168 4169 4170 4171 4172 4173 4174 4175 4176 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4162 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4150 4151 4152 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4150 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4152 4153 4154 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4152 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4154 4155 4156 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4154 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4156 4157 4158 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4156 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4158 4159 4160 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4158 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4160 4161 4162 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4160 def street_address2 @street_address2 end |