Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail::Address
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
3635 3636 3637 3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 3649 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3635 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3623 3624 3625 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3623 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3625 3626 3627 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3625 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3627 3628 3629 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3627 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3629 3630 3631 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3629 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3631 3632 3633 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3631 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3633 3634 3635 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3633 def street_address2 @street_address2 end |