Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4311 4312 4313 4314 4315 4316 4317 4318 4319 4320 4321 4322 4323 4324 4325 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4311 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4299 4300 4301 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4299 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4301 4302 4303 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4301 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4303 4304 4305 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4303 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4305 4306 4307 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4305 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4307 4308 4309 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4307 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4309 4310 4311 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4309 def street_address2 @street_address2 end |