Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 3769 3770 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3756 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3744 3745 3746 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3744 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3746 3747 3748 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3746 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3748 3749 3750 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3748 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3750 3751 3752 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3750 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3752 3753 3754 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3752 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3754 3755 3756 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3754 def street_address2 @street_address2 end |