Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
3736 3737 3738 3739 3740 3741 3742 3743 3744 3745 3746 3747 3748 3749 3750 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3736 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3724 3725 3726 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3724 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3726 3727 3728 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3726 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3728 3729 3730 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3728 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3730 3731 3732 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3730 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3732 3733 3734 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3732 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3734 3735 3736 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3734 def street_address2 @street_address2 end |