Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Departure::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::FerryReservationDetail::Departure::Address
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3841 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3829 3830 3831 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3829 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3831 3832 3833 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3831 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3833 3834 3835 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3833 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3835 3836 3837 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3835 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3837 3838 3839 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3837 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3839 3840 3841 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3839 def street_address2 @street_address2 end |