Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller::MarketplaceSellerAddress
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller::MarketplaceSellerAddress
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ MarketplaceSellerAddress
constructor
A new instance of MarketplaceSellerAddress.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ MarketplaceSellerAddress
Returns a new instance of MarketplaceSellerAddress.
3942 3943 3944 3945 3946 3947 3948 3949 3950 3951 3952 3953 3954 3955 3956 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3942 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3930 3931 3932 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3930 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3932 3933 3934 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3932 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3934 3935 3936 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3934 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3936 3937 3938 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3936 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3938 3939 3940 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3938 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3940 3941 3942 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3940 def street_address2 @street_address2 end |