Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller::MarketplaceSellerAddress
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller::MarketplaceSellerAddress
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ MarketplaceSellerAddress
constructor
A new instance of MarketplaceSellerAddress.
Methods inherited from RequestParams
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ MarketplaceSellerAddress
Returns a new instance of MarketplaceSellerAddress.
3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 3905 3906 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3892 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3880 3881 3882 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3880 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3882 3883 3884 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3882 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3884 3885 3886 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3884 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3886 3887 3888 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3886 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3888 3889 3890 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3888 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3890 3891 3892 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3890 def street_address2 @street_address2 end |