Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller::MarketplaceSellerAddress
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller::MarketplaceSellerAddress
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ MarketplaceSellerAddress
constructor
A new instance of MarketplaceSellerAddress.
Methods inherited from RequestParams
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ MarketplaceSellerAddress
Returns a new instance of MarketplaceSellerAddress.
3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3909 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
3897 3898 3899 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3897 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
3899 3900 3901 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3899 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
3901 3902 3903 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3901 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
3903 3904 3905 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3903 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
3905 3906 3907 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3905 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
3907 3908 3909 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3907 def street_address2 @street_address2 end |