Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4531 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4519 4520 4521 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4519 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4521 4522 4523 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4521 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4523 4524 4525 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4523 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4525 4526 4527 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4525 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4527 4528 4529 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4527 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4529 4530 4531 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4529 def street_address2 @street_address2 end |