Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4028 4029 4030 4031 4032 4033 4034 4035 4036 4037 4038 4039 4040 4041 4042 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4028 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4016 4017 4018 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4016 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4018 4019 4020 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4018 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4020 4021 4022 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4020 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4022 4023 4024 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4022 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4024 4025 4026 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4024 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4026 4027 4028 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4026 def street_address2 @street_address2 end |