Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Departure::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail::Departure::Address
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4625 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4613 4614 4615 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4613 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4615 4616 4617 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4615 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4617 4618 4619 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4617 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4619 4620 4621 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4619 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4621 4622 4623 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4621 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4623 4624 4625 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4623 def street_address2 @street_address2 end |