Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
4159 4160 4161 4162 4163 4164 4165 4166 4167 4168 4169 4170 4171 4172 4173 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4159 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
4147 4148 4149 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4147 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
4149 4150 4151 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4149 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
4151 4152 4153 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4151 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
4153 4154 4155 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4153 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
4155 4156 4157 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4155 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
4157 4158 4159 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4157 def street_address2 @street_address2 end |