Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::Voucher
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::Voucher
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for this voucher.
-
#ends_at ⇒ Object
The voucher validity end time.
-
#starts_at ⇒ Object
The voucher validity start time.
-
#voucher_company ⇒ Object
The issuer or provider of this voucher.
-
#voucher_name ⇒ Object
The name or reference to identify the voucher.
-
#voucher_type ⇒ Object
The type of this voucher.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil) ⇒ Voucher
constructor
A new instance of Voucher.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil) ⇒ Voucher
Returns a new instance of Voucher.
4354 4355 4356 4357 4358 4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4354 def initialize( affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil ) @affiliate_name = affiliate_name @ends_at = ends_at @starts_at = starts_at @voucher_company = voucher_company @voucher_name = voucher_name @voucher_type = voucher_type end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for this voucher.
4342 4343 4344 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4342 def affiliate_name @affiliate_name end |
#ends_at ⇒ Object
The voucher validity end time.
4344 4345 4346 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4344 def ends_at @ends_at end |
#starts_at ⇒ Object
The voucher validity start time.
4346 4347 4348 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4346 def starts_at @starts_at end |
#voucher_company ⇒ Object
The issuer or provider of this voucher.
4348 4349 4350 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4348 def voucher_company @voucher_company end |
#voucher_name ⇒ Object
The name or reference to identify the voucher.
4350 4351 4352 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4350 def voucher_name @voucher_name end |
#voucher_type ⇒ Object
The type of this voucher.
4352 4353 4354 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4352 def voucher_type @voucher_type end |