Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Oxxo

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(expires_after_days: nil, setup_future_usage: nil) ⇒ Oxxo

Returns a new instance of Oxxo.



4659
4660
4661
4662
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4659

def initialize(expires_after_days: nil, setup_future_usage: nil)
  @expires_after_days = expires_after_days
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#expires_after_daysObject

The number of calendar days before an OXXO voucher expires. For example, if you create an OXXO voucher on Monday and you set expires_after_days to 2, the OXXO invoice will expire on Wednesday at 23:59 America/Mexico_City time.



4647
4648
4649
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4647

def expires_after_days
  @expires_after_days
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.

If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.



4657
4658
4659
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4657

def setup_future_usage
  @setup_future_usage
end