Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Paypal
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Paypal
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: LineItem
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer's account.
-
#line_items ⇒ Object
The line items purchased by the customer.
-
#preferred_locale ⇒ Object
Preferred locale of the PayPal checkout page that the customer is redirected to.
-
#reference ⇒ Object
A reference of the PayPal transaction visible to customer which is mapped to PayPal's invoice ID.
-
#reference_id ⇒ Object
A reference of the PayPal transaction visible to customer which is mapped to PayPal's invoice ID.
-
#risk_correlation_id ⇒ Object
The risk correlation ID for an on-session payment using a saved PayPal payment method.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
-
#subsellers ⇒ Object
The Stripe connected account IDs of the sellers on the platform for this transaction (optional).
Instance Method Summary collapse
-
#initialize(capture_method: nil, line_items: nil, preferred_locale: nil, reference: nil, reference_id: nil, risk_correlation_id: nil, setup_future_usage: nil, subsellers: nil) ⇒ Paypal
constructor
A new instance of Paypal.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(capture_method: nil, line_items: nil, preferred_locale: nil, reference: nil, reference_id: nil, risk_correlation_id: nil, setup_future_usage: nil, subsellers: nil) ⇒ Paypal
Returns a new instance of Paypal.
5400 5401 5402 5403 5404 5405 5406 5407 5408 5409 5410 5411 5412 5413 5414 5415 5416 5417 5418 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5400 def initialize( capture_method: nil, line_items: nil, preferred_locale: nil, reference: nil, reference_id: nil, risk_correlation_id: nil, setup_future_usage: nil, subsellers: nil ) @capture_method = capture_method @line_items = line_items @preferred_locale = preferred_locale @reference = reference @reference_id = reference_id @risk_correlation_id = risk_correlation_id @setup_future_usage = setup_future_usage @subsellers = subsellers end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds will be captured from the customer's account.
5376 5377 5378 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5376 def capture_method @capture_method end |
#line_items ⇒ Object
The line items purchased by the customer.
5378 5379 5380 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5378 def line_items @line_items end |
#preferred_locale ⇒ Object
Preferred locale of the PayPal checkout page that the customer is redirected to.
5380 5381 5382 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5380 def preferred_locale @preferred_locale end |
#reference ⇒ Object
A reference of the PayPal transaction visible to customer which is mapped to PayPal's invoice ID. This must be a globally unique ID if you have configured in your PayPal settings to block multiple payments per invoice ID.
5382 5383 5384 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5382 def reference @reference end |
#reference_id ⇒ Object
A reference of the PayPal transaction visible to customer which is mapped to PayPal's invoice ID. This must be a globally unique ID if you have configured in your PayPal settings to block multiple payments per invoice ID.
5384 5385 5386 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5384 def reference_id @reference_id end |
#risk_correlation_id ⇒ Object
The risk correlation ID for an on-session payment using a saved PayPal payment method.
5386 5387 5388 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5386 def risk_correlation_id @risk_correlation_id end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.
5396 5397 5398 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5396 def setup_future_usage @setup_future_usage end |
#subsellers ⇒ Object
The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when separate charges and transfers are used.
5398 5399 5400 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5398 def subsellers @subsellers end |