Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5247

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



5231
5232
5233
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5231

def category
  @category
end

#descriptionObject

Description of the line item.



5233
5234
5235
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5233

def description
  @description
end

#nameObject

Descriptive name of the line item.



5235
5236
5237
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5235

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



5237
5238
5239
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5237

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



5239
5240
5241
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5239

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



5241
5242
5243
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5241

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



5243
5244
5245
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5243

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



5245
5246
5247
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5245

def unit_amount
  @unit_amount
end