Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
4839 4840 4841 4842 4843 4844 4845 4846 4847 4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4839 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
4823 4824 4825 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4823 def category @category end |
#description ⇒ Object
Description of the line item.
4825 4826 4827 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4825 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
4827 4828 4829 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4827 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
4829 4830 4831 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4829 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
4831 4832 4833 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4831 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
4833 4834 4835 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4833 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
4835 4836 4837 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4835 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
4837 4838 4839 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4837 def unit_amount @unit_amount end |