Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
4703
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4685

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



4669
4670
4671
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4669

def category
  @category
end

#descriptionObject

Description of the line item.



4671
4672
4673
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4671

def description
  @description
end

#nameObject

Descriptive name of the line item.



4673
4674
4675
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4673

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



4675
4676
4677
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4675

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



4677
4678
4679
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4677

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



4679
4680
4681
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4679

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



4681
4682
4683
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4681

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



4683
4684
4685
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4683

def unit_amount
  @unit_amount
end