Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



4702
4703
4704
4705
4706
4707
4708
4709
4710
4711
4712
4713
4714
4715
4716
4717
4718
4719
4720
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4702

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



4686
4687
4688
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4686

def category
  @category
end

#descriptionObject

Description of the line item.



4688
4689
4690
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4688

def description
  @description
end

#nameObject

Descriptive name of the line item.



4690
4691
4692
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4690

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



4692
4693
4694
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4692

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



4694
4695
4696
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4694

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



4696
4697
4698
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4696

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



4698
4699
4700
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4698

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



4700
4701
4702
# File 'lib/stripe/params/payment_intent_update_params.rb', line 4700

def unit_amount
  @unit_amount
end