Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
2799 2800 2801 2802 2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 2813 2814 2815 2816 2817 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2799 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
2783 2784 2785 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2783 def category @category end |
#description ⇒ Object
Description of the line item.
2785 2786 2787 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2785 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
2787 2788 2789 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2787 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
2789 2790 2791 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2789 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
2791 2792 2793 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2791 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
2793 2794 2795 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2793 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
2795 2796 2797 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2795 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
2797 2798 2799 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2797 def unit_amount @unit_amount end |