Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2791

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



2775
2776
2777
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2775

def category
  @category
end

#descriptionObject

Description of the line item.



2777
2778
2779
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2777

def description
  @description
end

#nameObject

Descriptive name of the line item.



2779
2780
2781
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2779

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



2781
2782
2783
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2781

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



2783
2784
2785
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2783

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



2785
2786
2787
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2785

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



2787
2788
2789
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2787

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



2789
2790
2791
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2789

def unit_amount
  @unit_amount
end