Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Payto::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Payto::MandateOptions
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount that will be collected.
-
#amount_type ⇒ Object
The type of amount that will be collected.
-
#end_date ⇒ Object
Date, in YYYY-MM-DD format, after which payments will not be collected.
-
#payment_schedule ⇒ Object
The periodicity at which payments will be collected.
-
#payments_per_period ⇒ Object
The number of payments that will be made during a payment period.
-
#purpose ⇒ Object
The purpose for which payments are made.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
5458 5459 5460 5461 5462 5463 5464 5465 5466 5467 5468 5469 5470 5471 5472 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5458 def initialize( amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil ) @amount = amount @amount_type = amount_type @end_date = end_date @payment_schedule = payment_schedule @payments_per_period = payments_per_period @purpose = purpose end |
Instance Attribute Details
#amount ⇒ Object
Amount that will be collected. It is required when amount_type is fixed.
5446 5447 5448 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5446 def amount @amount end |
#amount_type ⇒ Object
The type of amount that will be collected. The amount charged must be exact or up to the value of amount param for fixed or maximum type respectively. Defaults to maximum.
5448 5449 5450 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5448 def amount_type @amount_type end |
#end_date ⇒ Object
Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.
5450 5451 5452 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5450 def end_date @end_date end |
#payment_schedule ⇒ Object
The periodicity at which payments will be collected. Defaults to adhoc.
5452 5453 5454 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5452 def payment_schedule @payment_schedule end |
#payments_per_period ⇒ Object
The number of payments that will be made during a payment period. Defaults to 1 except for when payment_schedule is adhoc. In that case, it defaults to no limit.
5454 5455 5456 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5454 def payments_per_period @payments_per_period end |
#purpose ⇒ Object
The purpose for which payments are made. Has a default value based on your merchant category code.
5456 5457 5458 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5456 def purpose @purpose end |