Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Pix

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: MandateOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount_includes_iof: nil, expires_after_seconds: nil, expires_at: nil, mandate_options: nil, setup_future_usage: nil) ⇒ Pix

Returns a new instance of Pix.



5549
5550
5551
5552
5553
5554
5555
5556
5557
5558
5559
5560
5561
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5549

def initialize(
  amount_includes_iof: nil,
  expires_after_seconds: nil,
  expires_at: nil,
  mandate_options: nil,
  setup_future_usage: nil
)
  @amount_includes_iof = amount_includes_iof
  @expires_after_seconds = expires_after_seconds
  @expires_at = expires_at
  @mandate_options = mandate_options
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#amount_includes_iofObject

Determines if the amount includes the IOF tax. Defaults to never.



5533
5534
5535
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5533

def amount_includes_iof
  @amount_includes_iof
end

#expires_after_secondsObject

The number of seconds (between 10 and 1209600) after which Pix payment will expire. Defaults to 86400 seconds.



5535
5536
5537
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5535

def expires_after_seconds
  @expires_after_seconds
end

#expires_atObject

The timestamp at which the Pix expires (between 10 and 1209600 seconds in the future). Defaults to 1 day in the future.



5537
5538
5539
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5537

def expires_at
  @expires_at
end

#mandate_optionsObject

Additional fields for mandate creation. Only applicable when setup_future_usage=off_session.



5539
5540
5541
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5539

def mandate_options
  @mandate_options
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.



5547
5548
5549
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5547

def setup_future_usage
  @setup_future_usage
end