Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Pix

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: MandateOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_includes_iof: nil, expires_after_seconds: nil, expires_at: nil, mandate_options: nil, setup_future_usage: nil) ⇒ Pix

Returns a new instance of Pix.



2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
2990
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2978

def initialize(
  amount_includes_iof: nil,
  expires_after_seconds: nil,
  expires_at: nil,
  mandate_options: nil,
  setup_future_usage: nil
)
  @amount_includes_iof = amount_includes_iof
  @expires_after_seconds = expires_after_seconds
  @expires_at = expires_at
  @mandate_options = mandate_options
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#amount_includes_iofObject

Determines if the amount includes the IOF tax. Defaults to ‘never`.



2960
2961
2962
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2960

def amount_includes_iof
  @amount_includes_iof
end

#expires_after_secondsObject

The number of seconds (between 10 and 1209600) after which Pix payment will expire. Defaults to 86400 seconds.



2962
2963
2964
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2962

def expires_after_seconds
  @expires_after_seconds
end

#expires_atObject

The timestamp at which the Pix expires (between 10 and 1209600 seconds in the future). Defaults to 1 day in the future.



2964
2965
2966
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2964

def expires_at
  @expires_at
end

#mandate_optionsObject

Additional fields for mandate creation. Only applicable when ‘setup_future_usage=off_session`.



2966
2967
2968
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2966

def mandate_options
  @mandate_options
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



2976
2977
2978
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2976

def setup_future_usage
  @setup_future_usage
end