Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2317
2318
2319
2320
2321
2322
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2317

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



2309
2310
2311
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2309

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



2311
2312
2313
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2311

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



2313
2314
2315
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2313

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



2315
2316
2317
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2315

def end_date
  @end_date
end