Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



5692
5693
5694
5695
5696
5697
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5692

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



5684
5685
5686
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5684

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



5686
5687
5688
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5686

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



5688
5689
5690
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5688

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



5690
5691
5692
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5690

def end_date
  @end_date
end