Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::UsBankAccount
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: FinancialConnections, MandateOptions, Networks
Instance Attribute Summary collapse
-
#financial_connections ⇒ Object
Additional fields for Financial Connections Session creation.
-
#mandate_options ⇒ Object
Additional fields for Mandate creation.
-
#networks ⇒ Object
Additional fields for network related functions.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
-
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer's account.
-
#transaction_purpose ⇒ Object
The purpose of the transaction.
-
#verification_method ⇒ Object
Bank account verification method.
Instance Method Summary collapse
-
#initialize(financial_connections: nil, mandate_options: nil, networks: nil, setup_future_usage: nil, target_date: nil, transaction_purpose: nil, verification_method: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(financial_connections: nil, mandate_options: nil, networks: nil, setup_future_usage: nil, target_date: nil, transaction_purpose: nil, verification_method: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
5332 5333 5334 5335 5336 5337 5338 5339 5340 5341 5342 5343 5344 5345 5346 5347 5348 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5332 def initialize( financial_connections: nil, mandate_options: nil, networks: nil, setup_future_usage: nil, target_date: nil, transaction_purpose: nil, verification_method: nil ) @financial_connections = financial_connections @mandate_options = @networks = networks @setup_future_usage = setup_future_usage @target_date = target_date @transaction_purpose = transaction_purpose @verification_method = verification_method end |
Instance Attribute Details
#financial_connections ⇒ Object
Additional fields for Financial Connections Session creation
5310 5311 5312 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5310 def financial_connections @financial_connections end |
#mandate_options ⇒ Object
Additional fields for Mandate creation
5312 5313 5314 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5312 def @mandate_options end |
#networks ⇒ Object
Additional fields for network related functions
5314 5315 5316 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5314 def networks @networks end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.
5324 5325 5326 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5324 def setup_future_usage @setup_future_usage end |
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer's account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.
5326 5327 5328 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5326 def target_date @target_date end |
#transaction_purpose ⇒ Object
The purpose of the transaction.
5328 5329 5330 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5328 def transaction_purpose @transaction_purpose end |
#verification_method ⇒ Object
Bank account verification method. The default value is automatic.
5330 5331 5332 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5330 def verification_method @verification_method end |