Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::UsBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: FinancialConnections, MandateOptions, Networks

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(financial_connections: nil, mandate_options: nil, networks: nil, setup_future_usage: nil, target_date: nil, transaction_purpose: nil, verification_method: nil) ⇒ UsBankAccount

Returns a new instance of UsBankAccount.



5258
5259
5260
5261
5262
5263
5264
5265
5266
5267
5268
5269
5270
5271
5272
5273
5274
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5258

def initialize(
  financial_connections: nil,
  mandate_options: nil,
  networks: nil,
  setup_future_usage: nil,
  target_date: nil,
  transaction_purpose: nil,
  verification_method: nil
)
  @financial_connections = financial_connections
  @mandate_options = mandate_options
  @networks = networks
  @setup_future_usage = setup_future_usage
  @target_date = target_date
  @transaction_purpose = transaction_purpose
  @verification_method = verification_method
end

Instance Attribute Details

#financial_connectionsObject

Additional fields for Financial Connections Session creation



5236
5237
5238
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5236

def financial_connections
  @financial_connections
end

#mandate_optionsObject

Additional fields for Mandate creation



5238
5239
5240
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5238

def mandate_options
  @mandate_options
end

#networksObject

Additional fields for network related functions



5240
5241
5242
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5240

def networks
  @networks
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



5250
5251
5252
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5250

def setup_future_usage
  @setup_future_usage
end

#target_dateObject

Controls when Stripe will attempt to debit the funds from the customer’s account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.



5252
5253
5254
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5252

def target_date
  @target_date
end

#transaction_purposeObject

The purpose of the transaction.



5254
5255
5256
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5254

def transaction_purpose
  @transaction_purpose
end

#verification_methodObject

Bank account verification method. The default value is ‘automatic`.



5256
5257
5258
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5256

def verification_method
  @verification_method
end