Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::UsBankAccount
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: FinancialConnections, MandateOptions, Networks
Instance Attribute Summary collapse
-
#financial_connections ⇒ Object
Additional fields for Financial Connections Session creation.
-
#mandate_options ⇒ Object
Additional fields for Mandate creation.
-
#networks ⇒ Object
Additional fields for network related functions.
-
#preferred_settlement_speed ⇒ Object
Preferred transaction settlement speed.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer’s account.
-
#verification_method ⇒ Object
Bank account verification method.
Instance Method Summary collapse
-
#initialize(financial_connections: nil, mandate_options: nil, networks: nil, setup_future_usage: nil, target_date: nil, verification_method: nil, preferred_settlement_speed: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(financial_connections: nil, mandate_options: nil, networks: nil, setup_future_usage: nil, target_date: nil, verification_method: nil, preferred_settlement_speed: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5181 def initialize( financial_connections: nil, mandate_options: nil, networks: nil, setup_future_usage: nil, target_date: nil, verification_method: nil, preferred_settlement_speed: nil ) @financial_connections = financial_connections @mandate_options = @networks = networks @setup_future_usage = setup_future_usage @target_date = target_date @verification_method = verification_method @preferred_settlement_speed = preferred_settlement_speed end |
Instance Attribute Details
#financial_connections ⇒ Object
Additional fields for Financial Connections Session creation
5159 5160 5161 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5159 def financial_connections @financial_connections end |
#mandate_options ⇒ Object
Additional fields for Mandate creation
5161 5162 5163 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5161 def @mandate_options end |
#networks ⇒ Object
Additional fields for network related functions
5163 5164 5165 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5163 def networks @networks end |
#preferred_settlement_speed ⇒ Object
Preferred transaction settlement speed
5179 5180 5181 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5179 def preferred_settlement_speed @preferred_settlement_speed end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.
5173 5174 5175 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5173 def setup_future_usage @setup_future_usage end |
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer’s account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.
5175 5176 5177 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5175 def target_date @target_date end |
#verification_method ⇒ Object
Bank account verification method.
5177 5178 5179 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5177 def verification_method @verification_method end |