Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Filters, ManualEntry
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#manual_entry ⇒ Object
Customize manual entry behavior.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
5203 5204 5205 5206 5207 5208 5209 5210 5211 5212 5213 5214 5215 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5203 def initialize( filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil ) @filters = filters @manual_entry = manual_entry @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
5193 5194 5195 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5193 def filters @filters end |
#manual_entry ⇒ Object
Customize manual entry behavior
5195 5196 5197 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5195 def manual_entry @manual_entry end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
5197 5198 5199 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5197 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
5199 5200 5201 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5199 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
5201 5202 5203 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5201 def return_url @return_url end |