Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



5143
5144
5145
5146
5147
5148
5149
5150
5151
5152
5153
5154
5155
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5143

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



5133
5134
5135
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5133

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



5135
5136
5137
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5135

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



5137
5138
5139
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5137

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



5139
5140
5141
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5139

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



5141
5142
5143
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5141

def return_url
  @return_url
end