Class: Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::UsBankAccount::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::PaymentMethodOptions::UsBankAccount::MandateOptions
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Instance Attribute Summary collapse
-
#collection_method ⇒ Object
The method used to collect offline mandate customer acceptance.
Instance Method Summary collapse
-
#initialize(collection_method: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(collection_method: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
2074 2075 2076 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2074 def initialize(collection_method: nil) @collection_method = collection_method end |
Instance Attribute Details
#collection_method ⇒ Object
The method used to collect offline mandate customer acceptance.
2072 2073 2074 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2072 def collection_method @collection_method end |