Class: Stripe::PaymentIntentUpdateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



6371
6372
6373
6374
6375
6376
6377
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6371

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



6361
6362
6363
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6361

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



6363
6364
6365
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6363

def carrier
  @carrier
end

#nameObject

Recipient name.



6365
6366
6367
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6365

def name
  @name
end

#phoneObject

Recipient phone (including extension).



6367
6368
6369
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6367

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



6369
6370
6371
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6369

def tracking_number
  @tracking_number
end