Class: Stripe::PaymentIntentUpdateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



2732
2733
2734
2735
2736
2737
2738
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2732

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



2722
2723
2724
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2722

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



2724
2725
2726
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2724

def carrier
  @carrier
end

#nameObject

Recipient name.



2726
2727
2728
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2726

def name
  @name
end

#phoneObject

Recipient phone (including extension).



2728
2729
2730
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2728

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



2730
2731
2732
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2730

def tracking_number
  @tracking_number
end