Class: Stripe::PaymentIntentUpdateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::Shipping
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
2679 2680 2681 2682 2683 2684 2685 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2679 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
2669 2670 2671 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2669 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
2671 2672 2673 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2671 def carrier @carrier end |
#name ⇒ Object
Recipient name.
2673 2674 2675 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2673 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
2675 2676 2677 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2675 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
2677 2678 2679 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2677 def tracking_number @tracking_number end |