Class: Stripe::PaymentIntentUpdateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



6127
6128
6129
6130
6131
6132
6133
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6127

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



6117
6118
6119
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6117

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



6119
6120
6121
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6119

def carrier
  @carrier
end

#nameObject

Recipient name.



6121
6122
6123
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6121

def name
  @name
end

#phoneObject

Recipient phone (including extension).



6123
6124
6125
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6123

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



6125
6126
6127
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6125

def tracking_number
  @tracking_number
end