Class: Stripe::PaymentIntentUpdateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



6147
6148
6149
6150
6151
6152
6153
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6147

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



6137
6138
6139
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6137

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



6139
6140
6141
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6139

def carrier
  @carrier
end

#nameObject

Recipient name.



6141
6142
6143
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6141

def name
  @name
end

#phoneObject

Recipient phone (including extension).



6143
6144
6145
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6143

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



6145
6146
6147
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6145

def tracking_number
  @tracking_number
end