Class: Stripe::PaymentIntentUpdateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::Shipping
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
6140 6141 6142 6143 6144 6145 6146 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6140 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
6130 6131 6132 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6130 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
6132 6133 6134 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6132 def carrier @carrier end |
#name ⇒ Object
Recipient name.
6134 6135 6136 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6134 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
6136 6137 6138 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6136 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
6138 6139 6140 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6138 def tracking_number @tracking_number end |