Class: Stripe::PaymentIntentUpdateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



5604
5605
5606
5607
5608
5609
5610
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5604

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



5594
5595
5596
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5594

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



5596
5597
5598
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5596

def carrier
  @carrier
end

#nameObject

Recipient name.



5598
5599
5600
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5598

def name
  @name
end

#phoneObject

Recipient phone (including extension).



5600
5601
5602
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5600

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



5602
5603
5604
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5602

def tracking_number
  @tracking_number
end