Class: Stripe::PaymentIntentUpdateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



6120
6121
6122
6123
6124
6125
6126
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6120

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



6110
6111
6112
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6110

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



6112
6113
6114
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6112

def carrier
  @carrier
end

#nameObject

Recipient name.



6114
6115
6116
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6114

def name
  @name
end

#phoneObject

Recipient phone (including extension).



6116
6117
6118
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6116

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



6118
6119
6120
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6118

def tracking_number
  @tracking_number
end