Class: Stripe::PaymentIntentUpdateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::Shipping
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
5721 5722 5723 5724 5725 5726 5727 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5721 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
5711 5712 5713 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5711 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
5713 5714 5715 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5713 def carrier @carrier end |
#name ⇒ Object
Recipient name.
5715 5716 5717 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5715 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
5717 5718 5719 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5717 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
5719 5720 5721 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5719 def tracking_number @tracking_number end |