Class: Stripe::PaymentIntentUpdateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



5579
5580
5581
5582
5583
5584
5585
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5579

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



5569
5570
5571
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5569

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



5571
5572
5573
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5571

def carrier
  @carrier
end

#nameObject

Recipient name.



5573
5574
5575
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5573

def name
  @name
end

#phoneObject

Recipient phone (including extension).



5575
5576
5577
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5575

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



5577
5578
5579
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5577

def tracking_number
  @tracking_number
end