Class: Stripe::PaymentIntentUpdateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



5523
5524
5525
5526
5527
5528
5529
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5523

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



5513
5514
5515
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5513

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



5515
5516
5517
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5515

def carrier
  @carrier
end

#nameObject

Recipient name.



5517
5518
5519
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5517

def name
  @name
end

#phoneObject

Recipient phone (including extension).



5519
5520
5521
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5519

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



5521
5522
5523
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5521

def tracking_number
  @tracking_number
end