Class: Stripe::PaymentIntentUpdateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::Shipping
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
5523 5524 5525 5526 5527 5528 5529 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5523 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
5513 5514 5515 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5513 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
5515 5516 5517 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5515 def carrier @carrier end |
#name ⇒ Object
Recipient name.
5517 5518 5519 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5517 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
5519 5520 5521 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5519 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
5521 5522 5523 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5521 def tracking_number @tracking_number end |