Class: Stripe::PaymentIntentUpdateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::Shipping
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
5540 5541 5542 5543 5544 5545 5546 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5540 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
5530 5531 5532 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5530 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
5532 5533 5534 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5532 def carrier @carrier end |
#name ⇒ Object
Recipient name.
5534 5535 5536 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5534 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
5536 5537 5538 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5536 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
5538 5539 5540 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5538 def tracking_number @tracking_number end |