Class: Stripe::PaymentIntentUpdateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



3637
3638
3639
3640
3641
3642
3643
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3637

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



3627
3628
3629
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3627

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



3629
3630
3631
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3629

def carrier
  @carrier
end

#nameObject

Recipient name.



3631
3632
3633
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3631

def name
  @name
end

#phoneObject

Recipient phone (including extension).



3633
3634
3635
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3633

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



3635
3636
3637
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3635

def tracking_number
  @tracking_number
end