Class: Stripe::PaymentIntentUpdateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



2420
2421
2422
2423
2424
2425
2426
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2420

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



2410
2411
2412
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2410

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



2412
2413
2414
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2412

def carrier
  @carrier
end

#nameObject

Recipient name.



2414
2415
2416
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2414

def name
  @name
end

#phoneObject

Recipient phone (including extension).



2416
2417
2418
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2416

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



2418
2419
2420
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2418

def tracking_number
  @tracking_number
end