Class: Stripe::PaymentIntentUpdateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::Shipping
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
2420 2421 2422 2423 2424 2425 2426 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2420 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
2410 2411 2412 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2410 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
2412 2413 2414 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2412 def carrier @carrier end |
#name ⇒ Object
Recipient name.
2414 2415 2416 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2414 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
2416 2417 2418 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2416 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
2418 2419 2420 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2418 def tracking_number @tracking_number end |