Class: Stripe::PaymentIntentUpdateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



2231
2232
2233
2234
2235
2236
2237
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2231

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



2221
2222
2223
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2221

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



2223
2224
2225
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2223

def carrier
  @carrier
end

#nameObject

Recipient name.



2225
2226
2227
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2225

def name
  @name
end

#phoneObject

Recipient phone (including extension).



2227
2228
2229
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2227

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



2229
2230
2231
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2229

def tracking_number
  @tracking_number
end