Class: Stripe::PaymentIntentUpdateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



3608
3609
3610
3611
3612
3613
3614
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3608

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



3598
3599
3600
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3598

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



3600
3601
3602
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3600

def carrier
  @carrier
end

#nameObject

Recipient name.



3602
3603
3604
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3602

def name
  @name
end

#phoneObject

Recipient phone (including extension).



3604
3605
3606
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3604

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



3606
3607
3608
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3606

def tracking_number
  @tracking_number
end