Class: Stripe::PaymentIntentUpdateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::Shipping
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
3608 3609 3610 3611 3612 3613 3614 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3608 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
3598 3599 3600 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3598 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
3600 3601 3602 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3600 def carrier @carrier end |
#name ⇒ Object
Recipient name.
3602 3603 3604 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3602 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
3604 3605 3606 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3604 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
3606 3607 3608 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 3606 def tracking_number @tracking_number end |