Class: Stripe::PaymentIntentUpdateParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



2544
2545
2546
2547
2548
2549
2550
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2544

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



2534
2535
2536
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2534

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



2536
2537
2538
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2536

def carrier
  @carrier
end

#nameObject

Recipient name.



2538
2539
2540
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2538

def name
  @name
end

#phoneObject

Recipient phone (including extension).



2540
2541
2542
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2540

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



2542
2543
2544
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2542

def tracking_number
  @tracking_number
end