Class: Stripe::PaymentIntentUpdateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: PaymentData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, description: nil, metadata: nil, payment_data: nil) ⇒ TransferData

Returns a new instance of TransferData.



6401
6402
6403
6404
6405
6406
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6401

def initialize(amount: nil, description: nil, metadata: nil, payment_data: nil)
  @amount = amount
  @description = description
  @metadata = 
  @payment_data = payment_data
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when a charge succeeds.



6393
6394
6395
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6393

def amount
  @amount
end

#descriptionObject

An arbitrary string attached to the transfer. Often useful for displaying to users.



6395
6396
6397
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6395

def description
  @description
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



6397
6398
6399
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6397

def 
  @metadata
end

#payment_dataObject

The data with which to populate the destination payment.



6399
6400
6401
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6399

def payment_data
  @payment_data
end