Class: Stripe::PaymentIntentUpdateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: PaymentData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, description: nil, metadata: nil, payment_data: nil) ⇒ TransferData

Returns a new instance of TransferData.



5720
5721
5722
5723
5724
5725
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5720

def initialize(amount: nil, description: nil, metadata: nil, payment_data: nil)
  @amount = amount
  @description = description
  @metadata = 
  @payment_data = payment_data
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when a charge succeeds.



5712
5713
5714
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5712

def amount
  @amount
end

#descriptionObject

An arbitrary string attached to the transfer. Often useful for displaying to users.



5714
5715
5716
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5714

def description
  @description
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



5716
5717
5718
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5716

def 
  @metadata
end

#payment_dataObject

The data with which to populate the destination payment.



5718
5719
5720
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5718

def payment_data
  @payment_data
end