Class: Stripe::PaymentIntentUpdateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: PaymentData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, description: nil, metadata: nil, payment_data: nil) ⇒ TransferData

Returns a new instance of TransferData.



5702
5703
5704
5705
5706
5707
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5702

def initialize(amount: nil, description: nil, metadata: nil, payment_data: nil)
  @amount = amount
  @description = description
  @metadata = 
  @payment_data = payment_data
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when a charge succeeds.



5694
5695
5696
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5694

def amount
  @amount
end

#descriptionObject

An arbitrary string attached to the transfer. Often useful for displaying to users.



5696
5697
5698
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5696

def description
  @description
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



5698
5699
5700
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5698

def 
  @metadata
end

#payment_dataObject

The data with which to populate the destination payment.



5700
5701
5702
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5700

def payment_data
  @payment_data
end