Class: Stripe::PaymentIntentUpdateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: PaymentData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, description: nil, metadata: nil, payment_data: nil) ⇒ TransferData

Returns a new instance of TransferData.



6216
6217
6218
6219
6220
6221
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6216

def initialize(amount: nil, description: nil, metadata: nil, payment_data: nil)
  @amount = amount
  @description = description
  @metadata = 
  @payment_data = payment_data
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when a charge succeeds.



6208
6209
6210
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6208

def amount
  @amount
end

#descriptionObject

An arbitrary string attached to the transfer. Often useful for displaying to users.



6210
6211
6212
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6210

def description
  @description
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



6212
6213
6214
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6212

def 
  @metadata
end

#payment_dataObject

The data with which to populate the destination payment.



6214
6215
6216
# File 'lib/stripe/params/payment_intent_update_params.rb', line 6214

def payment_data
  @payment_data
end