Class: Stripe::PaymentIntentUpdateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_intent_update_params.rb

Defined Under Namespace

Classes: PaymentData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, description: nil, metadata: nil, payment_data: nil) ⇒ TransferData

Returns a new instance of TransferData.



5667
5668
5669
5670
5671
5672
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5667

def initialize(amount: nil, description: nil, metadata: nil, payment_data: nil)
  @amount = amount
  @description = description
  @metadata = 
  @payment_data = payment_data
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when a charge succeeds.



5659
5660
5661
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5659

def amount
  @amount
end

#descriptionObject

An arbitrary string attached to the transfer. Often useful for displaying to users.



5661
5662
5663
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5661

def description
  @description
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



5663
5664
5665
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5663

def 
  @metadata
end

#payment_dataObject

The data with which to populate the destination payment.



5665
5666
5667
# File 'lib/stripe/params/payment_intent_update_params.rb', line 5665

def payment_data
  @payment_data
end