Class: Stripe::PaymentIntentUpdateParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntentUpdateParams::TransferData
- Defined in:
- lib/stripe/params/payment_intent_update_params.rb
Defined Under Namespace
Classes: PaymentData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds.
-
#description ⇒ Object
An arbitrary string attached to the transfer.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#payment_data ⇒ Object
The data with which to populate the destination payment.
Instance Method Summary collapse
-
#initialize(amount: nil, description: nil, metadata: nil, payment_data: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, description: nil, metadata: nil, payment_data: nil) ⇒ TransferData
Returns a new instance of TransferData.
2709 2710 2711 2712 2713 2714 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2709 def initialize(amount: nil, description: nil, metadata: nil, payment_data: nil) @amount = amount @description = description @metadata = @payment_data = payment_data end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds.
2701 2702 2703 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2701 def amount @amount end |
#description ⇒ Object
An arbitrary string attached to the transfer. Often useful for displaying to users.
2703 2704 2705 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2703 def description @description end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2705 2706 2707 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2705 def @metadata end |
#payment_data ⇒ Object
The data with which to populate the destination payment.
2707 2708 2709 |
# File 'lib/stripe/params/payment_intent_update_params.rb', line 2707 def payment_data @payment_data end |