Class: Stripe::PaymentLink
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::PaymentLink
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/payment_link.rb
Overview
A payment link is a shareable URL that will take your customers to a hosted payment page. A payment link can be shared and used multiple times.
When a customer opens a payment link it will open a new [checkout session](stripe.com/docs/api/checkout/sessions) to render the payment page. You can use [checkout session events](stripe.com/docs/api/events/types#event_types-checkout.session.completed) to track payments through payment links.
Related guide: [Payment Links API](stripe.com/docs/payment-links)
Defined Under Namespace
Classes: AfterCompletion, AutomaticTax, ConsentCollection, CustomField, CustomText, InvoiceCreation, OptionalItem, PaymentIntentData, PhoneNumberCollection, Restrictions, ShippingAddressCollection, ShippingOption, SubscriptionData, TaxIdCollection, TransferData
Constant Summary collapse
- OBJECT_NAME =
"payment_link"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#active ⇒ Object
readonly
Whether the payment link’s ‘url` is active.
-
#after_completion ⇒ Object
readonly
Attribute for field after_completion.
-
#allow_promotion_codes ⇒ Object
readonly
Whether user redeemable promotion codes are enabled.
-
#application ⇒ Object
readonly
The ID of the Connect application that created the Payment Link.
-
#application_fee_amount ⇒ Object
readonly
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#application_fee_percent ⇒ Object
readonly
This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account.
-
#automatic_tax ⇒ Object
readonly
Attribute for field automatic_tax.
-
#billing_address_collection ⇒ Object
readonly
Configuration for collecting the customer’s billing address.
-
#consent_collection ⇒ Object
readonly
When set, provides configuration to gather active consent from customers.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#custom_fields ⇒ Object
readonly
Collect additional information from your customer using custom fields.
-
#custom_text ⇒ Object
readonly
Attribute for field custom_text.
-
#customer_creation ⇒ Object
readonly
Configuration for Customer creation during checkout.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#inactive_message ⇒ Object
readonly
The custom message to be displayed to a customer when a payment link is no longer active.
-
#invoice_creation ⇒ Object
readonly
Configuration for creating invoice for payment mode payment links.
-
#line_items ⇒ Object
readonly
The line items representing what is being sold.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#on_behalf_of ⇒ Object
readonly
The account on behalf of which to charge.
-
#optional_items ⇒ Object
readonly
The optional items presented to the customer at checkout.
-
#payment_intent_data ⇒ Object
readonly
Indicates the parameters to be passed to PaymentIntent creation during checkout.
-
#payment_method_collection ⇒ Object
readonly
Configuration for collecting a payment method during checkout.
-
#payment_method_types ⇒ Object
readonly
The list of payment method types that customers can use.
-
#phone_number_collection ⇒ Object
readonly
Attribute for field phone_number_collection.
-
#restrictions ⇒ Object
readonly
Settings that restrict the usage of a payment link.
-
#shipping_address_collection ⇒ Object
readonly
Configuration for collecting the customer’s shipping address.
-
#shipping_options ⇒ Object
readonly
The shipping rate options applied to the session.
-
#submit_type ⇒ Object
readonly
Indicates the type of transaction being performed which customizes relevant text on the page, such as the submit button.
-
#subscription_data ⇒ Object
readonly
When creating a subscription, the specified configuration data will be used.
-
#tax_id_collection ⇒ Object
readonly
Attribute for field tax_id_collection.
-
#transfer_data ⇒ Object
readonly
The account (if any) the payments will be attributed to for tax reporting, and where funds from each payment will be transferred to.
-
#url ⇒ Object
readonly
The public URL that can be shared with customers.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a payment link.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of your payment links.
-
.list_line_items(payment_link, params = {}, opts = {}) ⇒ Object
When retrieving a payment link, there is an includable line_items property containing the first handful of those items.
- .object_name ⇒ Object
-
.update(payment_link, params = {}, opts = {}) ⇒ Object
Updates a payment link.
Instance Method Summary collapse
-
#list_line_items(params = {}, opts = {}) ⇒ Object
When retrieving a payment link, there is an includable line_items property containing the first handful of those items.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#active ⇒ Object (readonly)
Whether the payment link’s ‘url` is active. If `false`, customers visiting the URL will be shown a page saying that the link has been deactivated.
614 615 616 |
# File 'lib/stripe/resources/payment_link.rb', line 614 def active @active end |
#after_completion ⇒ Object (readonly)
Attribute for field after_completion
616 617 618 |
# File 'lib/stripe/resources/payment_link.rb', line 616 def after_completion @after_completion end |
#allow_promotion_codes ⇒ Object (readonly)
Whether user redeemable promotion codes are enabled.
618 619 620 |
# File 'lib/stripe/resources/payment_link.rb', line 618 def allow_promotion_codes @allow_promotion_codes end |
#application ⇒ Object (readonly)
The ID of the Connect application that created the Payment Link.
620 621 622 |
# File 'lib/stripe/resources/payment_link.rb', line 620 def application @application end |
#application_fee_amount ⇒ Object (readonly)
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
622 623 624 |
# File 'lib/stripe/resources/payment_link.rb', line 622 def application_fee_amount @application_fee_amount end |
#application_fee_percent ⇒ Object (readonly)
This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account.
624 625 626 |
# File 'lib/stripe/resources/payment_link.rb', line 624 def application_fee_percent @application_fee_percent end |
#automatic_tax ⇒ Object (readonly)
Attribute for field automatic_tax
626 627 628 |
# File 'lib/stripe/resources/payment_link.rb', line 626 def automatic_tax @automatic_tax end |
#billing_address_collection ⇒ Object (readonly)
Configuration for collecting the customer’s billing address. Defaults to ‘auto`.
628 629 630 |
# File 'lib/stripe/resources/payment_link.rb', line 628 def billing_address_collection @billing_address_collection end |
#consent_collection ⇒ Object (readonly)
When set, provides configuration to gather active consent from customers.
630 631 632 |
# File 'lib/stripe/resources/payment_link.rb', line 630 def @consent_collection end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
632 633 634 |
# File 'lib/stripe/resources/payment_link.rb', line 632 def currency @currency end |
#custom_fields ⇒ Object (readonly)
Collect additional information from your customer using custom fields. Up to 3 fields are supported.
634 635 636 |
# File 'lib/stripe/resources/payment_link.rb', line 634 def custom_fields @custom_fields end |
#custom_text ⇒ Object (readonly)
Attribute for field custom_text
636 637 638 |
# File 'lib/stripe/resources/payment_link.rb', line 636 def custom_text @custom_text end |
#customer_creation ⇒ Object (readonly)
Configuration for Customer creation during checkout.
638 639 640 |
# File 'lib/stripe/resources/payment_link.rb', line 638 def customer_creation @customer_creation end |
#id ⇒ Object (readonly)
Unique identifier for the object.
640 641 642 |
# File 'lib/stripe/resources/payment_link.rb', line 640 def id @id end |
#inactive_message ⇒ Object (readonly)
The custom message to be displayed to a customer when a payment link is no longer active.
642 643 644 |
# File 'lib/stripe/resources/payment_link.rb', line 642 def @inactive_message end |
#invoice_creation ⇒ Object (readonly)
Configuration for creating invoice for payment mode payment links.
644 645 646 |
# File 'lib/stripe/resources/payment_link.rb', line 644 def invoice_creation @invoice_creation end |
#line_items ⇒ Object (readonly)
The line items representing what is being sold.
646 647 648 |
# File 'lib/stripe/resources/payment_link.rb', line 646 def line_items @line_items end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
648 649 650 |
# File 'lib/stripe/resources/payment_link.rb', line 648 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
650 651 652 |
# File 'lib/stripe/resources/payment_link.rb', line 650 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
652 653 654 |
# File 'lib/stripe/resources/payment_link.rb', line 652 def object @object end |
#on_behalf_of ⇒ Object (readonly)
The account on behalf of which to charge. See the [Connect documentation](support.stripe.com/questions/sending-invoices-on-behalf-of-connected-accounts) for details.
654 655 656 |
# File 'lib/stripe/resources/payment_link.rb', line 654 def on_behalf_of @on_behalf_of end |
#optional_items ⇒ Object (readonly)
The optional items presented to the customer at checkout.
656 657 658 |
# File 'lib/stripe/resources/payment_link.rb', line 656 def optional_items @optional_items end |
#payment_intent_data ⇒ Object (readonly)
Indicates the parameters to be passed to PaymentIntent creation during checkout.
658 659 660 |
# File 'lib/stripe/resources/payment_link.rb', line 658 def payment_intent_data @payment_intent_data end |
#payment_method_collection ⇒ Object (readonly)
Configuration for collecting a payment method during checkout. Defaults to ‘always`.
660 661 662 |
# File 'lib/stripe/resources/payment_link.rb', line 660 def payment_method_collection @payment_method_collection end |
#payment_method_types ⇒ Object (readonly)
The list of payment method types that customers can use. When ‘null`, Stripe will dynamically show relevant payment methods you’ve enabled in your [payment method settings](dashboard.stripe.com/settings/payment_methods).
662 663 664 |
# File 'lib/stripe/resources/payment_link.rb', line 662 def payment_method_types @payment_method_types end |
#phone_number_collection ⇒ Object (readonly)
Attribute for field phone_number_collection
664 665 666 |
# File 'lib/stripe/resources/payment_link.rb', line 664 def phone_number_collection @phone_number_collection end |
#restrictions ⇒ Object (readonly)
Settings that restrict the usage of a payment link.
666 667 668 |
# File 'lib/stripe/resources/payment_link.rb', line 666 def restrictions @restrictions end |
#shipping_address_collection ⇒ Object (readonly)
Configuration for collecting the customer’s shipping address.
668 669 670 |
# File 'lib/stripe/resources/payment_link.rb', line 668 def shipping_address_collection @shipping_address_collection end |
#shipping_options ⇒ Object (readonly)
The shipping rate options applied to the session.
670 671 672 |
# File 'lib/stripe/resources/payment_link.rb', line 670 def @shipping_options end |
#submit_type ⇒ Object (readonly)
Indicates the type of transaction being performed which customizes relevant text on the page, such as the submit button.
672 673 674 |
# File 'lib/stripe/resources/payment_link.rb', line 672 def submit_type @submit_type end |
#subscription_data ⇒ Object (readonly)
When creating a subscription, the specified configuration data will be used. There must be at least one line item with a recurring price to use ‘subscription_data`.
674 675 676 |
# File 'lib/stripe/resources/payment_link.rb', line 674 def subscription_data @subscription_data end |
#tax_id_collection ⇒ Object (readonly)
Attribute for field tax_id_collection
676 677 678 |
# File 'lib/stripe/resources/payment_link.rb', line 676 def tax_id_collection @tax_id_collection end |
#transfer_data ⇒ Object (readonly)
The account (if any) the payments will be attributed to for tax reporting, and where funds from each payment will be transferred to.
678 679 680 |
# File 'lib/stripe/resources/payment_link.rb', line 678 def transfer_data @transfer_data end |
#url ⇒ Object (readonly)
The public URL that can be shared with customers.
680 681 682 |
# File 'lib/stripe/resources/payment_link.rb', line 680 def url @url end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a payment link.
683 684 685 |
# File 'lib/stripe/resources/payment_link.rb', line 683 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/payment_links", params: params, opts: opts) end |
.field_remappings ⇒ Object
742 743 744 |
# File 'lib/stripe/resources/payment_link.rb', line 742 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 |
# File 'lib/stripe/resources/payment_link.rb', line 722 def self.inner_class_types @inner_class_types = { after_completion: AfterCompletion, automatic_tax: AutomaticTax, consent_collection: ConsentCollection, custom_fields: CustomField, custom_text: CustomText, invoice_creation: InvoiceCreation, optional_items: OptionalItem, payment_intent_data: PaymentIntentData, phone_number_collection: PhoneNumberCollection, restrictions: Restrictions, shipping_address_collection: ShippingAddressCollection, shipping_options: ShippingOption, subscription_data: SubscriptionData, tax_id_collection: TaxIdCollection, transfer_data: TransferData, } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of your payment links.
688 689 690 |
# File 'lib/stripe/resources/payment_link.rb', line 688 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/payment_links", params: params, opts: opts) end |
.list_line_items(payment_link, params = {}, opts = {}) ⇒ Object
When retrieving a payment link, there is an includable line_items property containing the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of line items.
703 704 705 706 707 708 709 710 |
# File 'lib/stripe/resources/payment_link.rb', line 703 def self.list_line_items(payment_link, params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/payment_links/%<payment_link>s/line_items", { payment_link: CGI.escape(payment_link) }), params: params, opts: opts ) end |
.object_name ⇒ Object
16 17 18 |
# File 'lib/stripe/resources/payment_link.rb', line 16 def self.object_name "payment_link" end |
.update(payment_link, params = {}, opts = {}) ⇒ Object
Updates a payment link.
713 714 715 716 717 718 719 720 |
# File 'lib/stripe/resources/payment_link.rb', line 713 def self.update(payment_link, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_links/%<payment_link>s", { payment_link: CGI.escape(payment_link) }), params: params, opts: opts ) end |
Instance Method Details
#list_line_items(params = {}, opts = {}) ⇒ Object
When retrieving a payment link, there is an includable line_items property containing the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of line items.
693 694 695 696 697 698 699 700 |
# File 'lib/stripe/resources/payment_link.rb', line 693 def list_line_items(params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/payment_links/%<payment_link>s/line_items", { payment_link: CGI.escape(self["id"]) }), params: params, opts: opts ) end |