Class: Stripe::PaymentLink

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/payment_link.rb

Overview

A payment link is a shareable URL that will take your customers to a hosted payment page. A payment link can be shared and used multiple times.

When a customer opens a payment link it will open a new [checkout session](stripe.com/docs/api/checkout/sessions) to render the payment page. You can use [checkout session events](stripe.com/docs/api/events/types#event_types-checkout.session.completed) to track payments through payment links.

Related guide: [Payment Links API](stripe.com/docs/payment-links)

Defined Under Namespace

Classes: AfterCompletion, AutomaticTax, ConsentCollection, CreateParams, CustomField, CustomText, InvoiceCreation, ListLineItemsParams, ListParams, OptionalItem, PaymentIntentData, PhoneNumberCollection, Restrictions, ShippingAddressCollection, ShippingOption, SubscriptionData, TaxIdCollection, TransferData, UpdateParams

Constant Summary collapse

OBJECT_NAME =
"payment_link"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#activeObject (readonly)

Whether the payment link’s ‘url` is active. If `false`, customers visiting the URL will be shown a page saying that the link has been deactivated.



1662
1663
1664
# File 'lib/stripe/resources/payment_link.rb', line 1662

def active
  @active
end

#after_completionObject (readonly)

Attribute for field after_completion



1664
1665
1666
# File 'lib/stripe/resources/payment_link.rb', line 1664

def after_completion
  @after_completion
end

#allow_promotion_codesObject (readonly)

Whether user redeemable promotion codes are enabled.



1666
1667
1668
# File 'lib/stripe/resources/payment_link.rb', line 1666

def allow_promotion_codes
  @allow_promotion_codes
end

#applicationObject (readonly)

The ID of the Connect application that created the Payment Link.



1668
1669
1670
# File 'lib/stripe/resources/payment_link.rb', line 1668

def application
  @application
end

#application_fee_amountObject (readonly)

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.



1670
1671
1672
# File 'lib/stripe/resources/payment_link.rb', line 1670

def application_fee_amount
  @application_fee_amount
end

#application_fee_percentObject (readonly)

This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account.



1672
1673
1674
# File 'lib/stripe/resources/payment_link.rb', line 1672

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject (readonly)

Attribute for field automatic_tax



1674
1675
1676
# File 'lib/stripe/resources/payment_link.rb', line 1674

def automatic_tax
  @automatic_tax
end

#billing_address_collectionObject (readonly)

Configuration for collecting the customer’s billing address. Defaults to ‘auto`.



1676
1677
1678
# File 'lib/stripe/resources/payment_link.rb', line 1676

def billing_address_collection
  @billing_address_collection
end

When set, provides configuration to gather active consent from customers.



1678
1679
1680
# File 'lib/stripe/resources/payment_link.rb', line 1678

def consent_collection
  @consent_collection
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



1680
1681
1682
# File 'lib/stripe/resources/payment_link.rb', line 1680

def currency
  @currency
end

#custom_fieldsObject (readonly)

Collect additional information from your customer using custom fields. Up to 3 fields are supported.



1682
1683
1684
# File 'lib/stripe/resources/payment_link.rb', line 1682

def custom_fields
  @custom_fields
end

#custom_textObject (readonly)

Attribute for field custom_text



1684
1685
1686
# File 'lib/stripe/resources/payment_link.rb', line 1684

def custom_text
  @custom_text
end

#customer_creationObject (readonly)

Configuration for Customer creation during checkout.



1686
1687
1688
# File 'lib/stripe/resources/payment_link.rb', line 1686

def customer_creation
  @customer_creation
end

#idObject (readonly)

Unique identifier for the object.



1688
1689
1690
# File 'lib/stripe/resources/payment_link.rb', line 1688

def id
  @id
end

#inactive_messageObject (readonly)

The custom message to be displayed to a customer when a payment link is no longer active.



1690
1691
1692
# File 'lib/stripe/resources/payment_link.rb', line 1690

def inactive_message
  @inactive_message
end

#invoice_creationObject (readonly)

Configuration for creating invoice for payment mode payment links.



1692
1693
1694
# File 'lib/stripe/resources/payment_link.rb', line 1692

def invoice_creation
  @invoice_creation
end

#line_itemsObject (readonly)

The line items representing what is being sold.



1694
1695
1696
# File 'lib/stripe/resources/payment_link.rb', line 1694

def line_items
  @line_items
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



1696
1697
1698
# File 'lib/stripe/resources/payment_link.rb', line 1696

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



1698
1699
1700
# File 'lib/stripe/resources/payment_link.rb', line 1698

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



1700
1701
1702
# File 'lib/stripe/resources/payment_link.rb', line 1700

def object
  @object
end

#on_behalf_ofObject (readonly)

The account on behalf of which to charge. See the [Connect documentation](support.stripe.com/questions/sending-invoices-on-behalf-of-connected-accounts) for details.



1702
1703
1704
# File 'lib/stripe/resources/payment_link.rb', line 1702

def on_behalf_of
  @on_behalf_of
end

#optional_itemsObject (readonly)

The optional items presented to the customer at checkout.



1704
1705
1706
# File 'lib/stripe/resources/payment_link.rb', line 1704

def optional_items
  @optional_items
end

#payment_intent_dataObject (readonly)

Indicates the parameters to be passed to PaymentIntent creation during checkout.



1706
1707
1708
# File 'lib/stripe/resources/payment_link.rb', line 1706

def payment_intent_data
  @payment_intent_data
end

#payment_method_collectionObject (readonly)

Configuration for collecting a payment method during checkout. Defaults to ‘always`.



1708
1709
1710
# File 'lib/stripe/resources/payment_link.rb', line 1708

def payment_method_collection
  @payment_method_collection
end

#payment_method_typesObject (readonly)

The list of payment method types that customers can use. When ‘null`, Stripe will dynamically show relevant payment methods you’ve enabled in your [payment method settings](dashboard.stripe.com/settings/payment_methods).



1710
1711
1712
# File 'lib/stripe/resources/payment_link.rb', line 1710

def payment_method_types
  @payment_method_types
end

#phone_number_collectionObject (readonly)

Attribute for field phone_number_collection



1712
1713
1714
# File 'lib/stripe/resources/payment_link.rb', line 1712

def phone_number_collection
  @phone_number_collection
end

#restrictionsObject (readonly)

Settings that restrict the usage of a payment link.



1714
1715
1716
# File 'lib/stripe/resources/payment_link.rb', line 1714

def restrictions
  @restrictions
end

#shipping_address_collectionObject (readonly)

Configuration for collecting the customer’s shipping address.



1716
1717
1718
# File 'lib/stripe/resources/payment_link.rb', line 1716

def shipping_address_collection
  @shipping_address_collection
end

#shipping_optionsObject (readonly)

The shipping rate options applied to the session.



1718
1719
1720
# File 'lib/stripe/resources/payment_link.rb', line 1718

def shipping_options
  @shipping_options
end

#submit_typeObject (readonly)

Indicates the type of transaction being performed which customizes relevant text on the page, such as the submit button.



1720
1721
1722
# File 'lib/stripe/resources/payment_link.rb', line 1720

def submit_type
  @submit_type
end

#subscription_dataObject (readonly)

When creating a subscription, the specified configuration data will be used. There must be at least one line item with a recurring price to use ‘subscription_data`.



1722
1723
1724
# File 'lib/stripe/resources/payment_link.rb', line 1722

def subscription_data
  @subscription_data
end

#tax_id_collectionObject (readonly)

Attribute for field tax_id_collection



1724
1725
1726
# File 'lib/stripe/resources/payment_link.rb', line 1724

def tax_id_collection
  @tax_id_collection
end

#transfer_dataObject (readonly)

The account (if any) the payments will be attributed to for tax reporting, and where funds from each payment will be transferred to.



1726
1727
1728
# File 'lib/stripe/resources/payment_link.rb', line 1726

def transfer_data
  @transfer_data
end

#urlObject (readonly)

The public URL that can be shared with customers.



1728
1729
1730
# File 'lib/stripe/resources/payment_link.rb', line 1728

def url
  @url
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a payment link.



1731
1732
1733
# File 'lib/stripe/resources/payment_link.rb', line 1731

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/payment_links", params: params, opts: opts)
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of your payment links.



1736
1737
1738
# File 'lib/stripe/resources/payment_link.rb', line 1736

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/payment_links", params: params, opts: opts)
end

.list_line_items(payment_link, params = {}, opts = {}) ⇒ Object

When retrieving a payment link, there is an includable line_items property containing the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of line items.



1751
1752
1753
1754
1755
1756
1757
1758
# File 'lib/stripe/resources/payment_link.rb', line 1751

def self.list_line_items(payment_link, params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: format("/v1/payment_links/%<payment_link>s/line_items", { payment_link: CGI.escape(payment_link) }),
    params: params,
    opts: opts
  )
end

.object_nameObject



16
17
18
# File 'lib/stripe/resources/payment_link.rb', line 16

def self.object_name
  "payment_link"
end

.update(payment_link, params = {}, opts = {}) ⇒ Object

Updates a payment link.



1761
1762
1763
1764
1765
1766
1767
1768
# File 'lib/stripe/resources/payment_link.rb', line 1761

def self.update(payment_link, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_links/%<payment_link>s", { payment_link: CGI.escape(payment_link) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#list_line_items(params = {}, opts = {}) ⇒ Object

When retrieving a payment link, there is an includable line_items property containing the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of line items.



1741
1742
1743
1744
1745
1746
1747
1748
# File 'lib/stripe/resources/payment_link.rb', line 1741

def list_line_items(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: format("/v1/payment_links/%<payment_link>s/line_items", { payment_link: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end