Class: Stripe::PaymentLink

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/payment_link.rb

Overview

A payment link is a shareable URL that will take your customers to a hosted payment page. A payment link can be shared and used multiple times.

When a customer opens a payment link it will open a new [checkout session](stripe.com/docs/api/checkout/sessions) to render the payment page. You can use [checkout session events](stripe.com/docs/api/events/types#event_types-checkout.session.completed) to track payments through payment links.

Related guide: [Payment Links API](stripe.com/docs/payment-links)

Defined Under Namespace

Classes: AfterCompletion, AutomaticTax, ConsentCollection, CustomField, CustomText, InvoiceCreation, PaymentIntentData, PhoneNumberCollection, Restrictions, ShippingAddressCollection, ShippingOption, SubscriptionData, TaxIdCollection, TransferData

Constant Summary collapse

OBJECT_NAME =
"payment_link"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#activeObject (readonly)

Whether the payment link’s ‘url` is active. If `false`, customers visiting the URL will be shown a page saying that the link has been deactivated.



152
153
154
# File 'lib/stripe/resources/payment_link.rb', line 152

def active
  @active
end

#after_completionObject (readonly)

Attribute for field after_completion



154
155
156
# File 'lib/stripe/resources/payment_link.rb', line 154

def after_completion
  @after_completion
end

#allow_promotion_codesObject (readonly)

Whether user redeemable promotion codes are enabled.



156
157
158
# File 'lib/stripe/resources/payment_link.rb', line 156

def allow_promotion_codes
  @allow_promotion_codes
end

#applicationObject (readonly)

The ID of the Connect application that created the Payment Link.



158
159
160
# File 'lib/stripe/resources/payment_link.rb', line 158

def application
  @application
end

#application_fee_amountObject (readonly)

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.



160
161
162
# File 'lib/stripe/resources/payment_link.rb', line 160

def application_fee_amount
  @application_fee_amount
end

#application_fee_percentObject (readonly)

This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account.



162
163
164
# File 'lib/stripe/resources/payment_link.rb', line 162

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject (readonly)

Attribute for field automatic_tax



164
165
166
# File 'lib/stripe/resources/payment_link.rb', line 164

def automatic_tax
  @automatic_tax
end

#billing_address_collectionObject (readonly)

Configuration for collecting the customer’s billing address. Defaults to ‘auto`.



166
167
168
# File 'lib/stripe/resources/payment_link.rb', line 166

def billing_address_collection
  @billing_address_collection
end

When set, provides configuration to gather active consent from customers.



168
169
170
# File 'lib/stripe/resources/payment_link.rb', line 168

def consent_collection
  @consent_collection
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



170
171
172
# File 'lib/stripe/resources/payment_link.rb', line 170

def currency
  @currency
end

#custom_fieldsObject (readonly)

Collect additional information from your customer using custom fields. Up to 3 fields are supported.



172
173
174
# File 'lib/stripe/resources/payment_link.rb', line 172

def custom_fields
  @custom_fields
end

#custom_textObject (readonly)

Attribute for field custom_text



174
175
176
# File 'lib/stripe/resources/payment_link.rb', line 174

def custom_text
  @custom_text
end

#customer_creationObject (readonly)

Configuration for Customer creation during checkout.



176
177
178
# File 'lib/stripe/resources/payment_link.rb', line 176

def customer_creation
  @customer_creation
end

#idObject (readonly)

Unique identifier for the object.



178
179
180
# File 'lib/stripe/resources/payment_link.rb', line 178

def id
  @id
end

#inactive_messageObject (readonly)

The custom message to be displayed to a customer when a payment link is no longer active.



180
181
182
# File 'lib/stripe/resources/payment_link.rb', line 180

def inactive_message
  @inactive_message
end

#invoice_creationObject (readonly)

Configuration for creating invoice for payment mode payment links.



182
183
184
# File 'lib/stripe/resources/payment_link.rb', line 182

def invoice_creation
  @invoice_creation
end

#line_itemsObject (readonly)

The line items representing what is being sold.



184
185
186
# File 'lib/stripe/resources/payment_link.rb', line 184

def line_items
  @line_items
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



186
187
188
# File 'lib/stripe/resources/payment_link.rb', line 186

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



188
189
190
# File 'lib/stripe/resources/payment_link.rb', line 188

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



190
191
192
# File 'lib/stripe/resources/payment_link.rb', line 190

def object
  @object
end

#on_behalf_ofObject (readonly)

The account on behalf of which to charge. See the [Connect documentation](support.stripe.com/questions/sending-invoices-on-behalf-of-connected-accounts) for details.



192
193
194
# File 'lib/stripe/resources/payment_link.rb', line 192

def on_behalf_of
  @on_behalf_of
end

#payment_intent_dataObject (readonly)

Indicates the parameters to be passed to PaymentIntent creation during checkout.



194
195
196
# File 'lib/stripe/resources/payment_link.rb', line 194

def payment_intent_data
  @payment_intent_data
end

#payment_method_collectionObject (readonly)

Configuration for collecting a payment method during checkout. Defaults to ‘always`.



196
197
198
# File 'lib/stripe/resources/payment_link.rb', line 196

def payment_method_collection
  @payment_method_collection
end

#payment_method_typesObject (readonly)

The list of payment method types that customers can use. When ‘null`, Stripe will dynamically show relevant payment methods you’ve enabled in your [payment method settings](dashboard.stripe.com/settings/payment_methods).



198
199
200
# File 'lib/stripe/resources/payment_link.rb', line 198

def payment_method_types
  @payment_method_types
end

#phone_number_collectionObject (readonly)

Attribute for field phone_number_collection



200
201
202
# File 'lib/stripe/resources/payment_link.rb', line 200

def phone_number_collection
  @phone_number_collection
end

#restrictionsObject (readonly)

Settings that restrict the usage of a payment link.



202
203
204
# File 'lib/stripe/resources/payment_link.rb', line 202

def restrictions
  @restrictions
end

#shipping_address_collectionObject (readonly)

Configuration for collecting the customer’s shipping address.



204
205
206
# File 'lib/stripe/resources/payment_link.rb', line 204

def shipping_address_collection
  @shipping_address_collection
end

#shipping_optionsObject (readonly)

The shipping rate options applied to the session.



206
207
208
# File 'lib/stripe/resources/payment_link.rb', line 206

def shipping_options
  @shipping_options
end

#submit_typeObject (readonly)

Indicates the type of transaction being performed which customizes relevant text on the page, such as the submit button.



208
209
210
# File 'lib/stripe/resources/payment_link.rb', line 208

def submit_type
  @submit_type
end

#subscription_dataObject (readonly)

When creating a subscription, the specified configuration data will be used. There must be at least one line item with a recurring price to use ‘subscription_data`.



210
211
212
# File 'lib/stripe/resources/payment_link.rb', line 210

def subscription_data
  @subscription_data
end

#tax_id_collectionObject (readonly)

Attribute for field tax_id_collection



212
213
214
# File 'lib/stripe/resources/payment_link.rb', line 212

def tax_id_collection
  @tax_id_collection
end

#transfer_dataObject (readonly)

The account (if any) the payments will be attributed to for tax reporting, and where funds from each payment will be transferred to.



214
215
216
# File 'lib/stripe/resources/payment_link.rb', line 214

def transfer_data
  @transfer_data
end

#urlObject (readonly)

The public URL that can be shared with customers.



216
217
218
# File 'lib/stripe/resources/payment_link.rb', line 216

def url
  @url
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a payment link.



219
220
221
# File 'lib/stripe/resources/payment_link.rb', line 219

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/payment_links", params: params, opts: opts)
end

.list(filters = {}, opts = {}) ⇒ Object

Returns a list of your payment links.



224
225
226
# File 'lib/stripe/resources/payment_link.rb', line 224

def self.list(filters = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/payment_links", params: filters, opts: opts)
end

.list_line_items(payment_link, params = {}, opts = {}) ⇒ Object

When retrieving a payment link, there is an includable line_items property containing the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of line items.



239
240
241
242
243
244
245
246
# File 'lib/stripe/resources/payment_link.rb', line 239

def self.list_line_items(payment_link, params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: format("/v1/payment_links/%<payment_link>s/line_items", { payment_link: CGI.escape(payment_link) }),
    params: params,
    opts: opts
  )
end

.object_nameObject



16
17
18
# File 'lib/stripe/resources/payment_link.rb', line 16

def self.object_name
  "payment_link"
end

.update(id, params = {}, opts = {}) ⇒ Object

Updates a payment link.



249
250
251
252
253
254
255
256
# File 'lib/stripe/resources/payment_link.rb', line 249

def self.update(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_links/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#list_line_items(params = {}, opts = {}) ⇒ Object

When retrieving a payment link, there is an includable line_items property containing the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of line items.



229
230
231
232
233
234
235
236
# File 'lib/stripe/resources/payment_link.rb', line 229

def list_line_items(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: format("/v1/payment_links/%<payment_link>s/line_items", { payment_link: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end