Class: Stripe::PaymentLink::AutomaticTax
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentLink::AutomaticTax
- Defined in:
- lib/stripe/resources/payment_link.rb
Defined Under Namespace
Classes: Liability
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#enabled ⇒ Object
readonly
If ‘true`, tax will be calculated automatically using the customer’s location.
-
#liability ⇒ Object
readonly
The account that’s liable for tax.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#enabled ⇒ Object (readonly)
If ‘true`, tax will be calculated automatically using the customer’s location.
97 98 99 |
# File 'lib/stripe/resources/payment_link.rb', line 97 def enabled @enabled end |
#liability ⇒ Object (readonly)
The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
99 100 101 |
# File 'lib/stripe/resources/payment_link.rb', line 99 def liability @liability end |
Class Method Details
.field_remappings ⇒ Object
105 106 107 |
# File 'lib/stripe/resources/payment_link.rb', line 105 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
101 102 103 |
# File 'lib/stripe/resources/payment_link.rb', line 101 def self.inner_class_types @inner_class_types = { liability: Liability } end |