Class: Stripe::PaymentLink::AutomaticTax
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentLink::AutomaticTax
- Defined in:
- lib/stripe/resources/payment_link.rb
Defined Under Namespace
Classes: Liability
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#enabled ⇒ Object
readonly
If ‘true`, tax will be calculated automatically using the customer’s location.
-
#liability ⇒ Object
readonly
The account that’s liable for tax.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#enabled ⇒ Object (readonly)
If ‘true`, tax will be calculated automatically using the customer’s location.
46 47 48 |
# File 'lib/stripe/resources/payment_link.rb', line 46 def enabled @enabled end |
#liability ⇒ Object (readonly)
The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
48 49 50 |
# File 'lib/stripe/resources/payment_link.rb', line 48 def liability @liability end |