Class: Stripe::PaymentLink::ConsentCollection

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Defined Under Namespace

Classes: PaymentMethodReuseAgreement

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#payment_method_reuse_agreementObject (readonly)

Settings related to the payment method reuse text shown in the Checkout UI.



63
64
65
# File 'lib/stripe/resources/payment_link.rb', line 63

def payment_method_reuse_agreement
  @payment_method_reuse_agreement
end

#promotionsObject (readonly)

If set to ‘auto`, enables the collection of customer consent for promotional communications.



66
67
68
# File 'lib/stripe/resources/payment_link.rb', line 66

def promotions
  @promotions
end

#terms_of_serviceObject (readonly)

If set to ‘required`, it requires cutomers to accept the terms of service before being able to pay. If set to `none`, customers won’t be shown a checkbox to accept the terms of service.



69
70
71
# File 'lib/stripe/resources/payment_link.rb', line 69

def terms_of_service
  @terms_of_service
end