Class: Stripe::PaymentLink::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLink::CreateParams
- Defined in:
- lib/stripe/resources/payment_link.rb
Defined Under Namespace
Classes: AfterCompletion, AutomaticTax, ConsentCollection, CustomField, CustomText, InvoiceCreation, LineItem, PaymentIntentData, PhoneNumberCollection, Restrictions, ShippingAddressCollection, ShippingOption, SubscriptionData, TaxIdCollection, TransferData
Instance Attribute Summary collapse
-
#after_completion ⇒ Object
Behavior after the purchase is complete.
-
#allow_promotion_codes ⇒ Object
Enables user redeemable promotion codes.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#automatic_tax ⇒ Object
Configuration for automatic tax collection.
-
#billing_address_collection ⇒ Object
Configuration for collecting the customer’s billing address.
-
#consent_collection ⇒ Object
Configure fields to gather active consent from customers.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#custom_fields ⇒ Object
Collect additional information from your customer using custom fields.
-
#custom_text ⇒ Object
Display additional text for your customers using custom text.
-
#customer_creation ⇒ Object
Configures whether [checkout sessions](stripe.com/docs/api/checkout/sessions) created by this payment link create a [Customer](stripe.com/docs/api/customers).
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#inactive_message ⇒ Object
The custom message to be displayed to a customer when a payment link is no longer active.
-
#invoice_creation ⇒ Object
Generate a post-purchase Invoice for one-time payments.
-
#line_items ⇒ Object
The line items representing what is being sold.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#on_behalf_of ⇒ Object
The account on behalf of which to charge.
-
#payment_intent_data ⇒ Object
A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in ‘payment` mode.
-
#payment_method_collection ⇒ Object
Specify whether Checkout should collect a payment method.
-
#payment_method_types ⇒ Object
The list of payment method types that customers can use.
-
#phone_number_collection ⇒ Object
Controls phone number collection settings during checkout.
-
#restrictions ⇒ Object
Settings that restrict the usage of a payment link.
-
#shipping_address_collection ⇒ Object
Configuration for collecting the customer’s shipping address.
-
#shipping_options ⇒ Object
The shipping rate options to apply to [checkout sessions](stripe.com/docs/api/checkout/sessions) created by this payment link.
-
#submit_type ⇒ Object
Describes the type of transaction being performed in order to customize relevant text on the page, such as the submit button.
-
#subscription_data ⇒ Object
When creating a subscription, the specified configuration data will be used.
-
#tax_id_collection ⇒ Object
Controls tax ID collection during checkout.
-
#transfer_data ⇒ Object
The account (if any) the payments will be attributed to for tax reporting, and where funds from each payment will be transferred to.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(after_completion: nil, allow_promotion_codes: nil, application_fee_amount: nil, application_fee_percent: nil, automatic_tax: nil, billing_address_collection: nil, consent_collection: nil, currency: nil, custom_fields: nil, custom_text: nil, customer_creation: nil, expand: nil, inactive_message: nil, invoice_creation: nil, line_items: nil, metadata: nil, on_behalf_of: nil, payment_intent_data: nil, payment_method_collection: nil, payment_method_types: nil, phone_number_collection: nil, restrictions: nil, shipping_address_collection: nil, shipping_options: nil, submit_type: nil, subscription_data: nil, tax_id_collection: nil, transfer_data: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 |
# File 'lib/stripe/resources/payment_link.rb', line 881 def initialize( after_completion: nil, allow_promotion_codes: nil, application_fee_amount: nil, application_fee_percent: nil, automatic_tax: nil, billing_address_collection: nil, consent_collection: nil, currency: nil, custom_fields: nil, custom_text: nil, customer_creation: nil, expand: nil, inactive_message: nil, invoice_creation: nil, line_items: nil, metadata: nil, on_behalf_of: nil, payment_intent_data: nil, payment_method_collection: nil, payment_method_types: nil, phone_number_collection: nil, restrictions: nil, shipping_address_collection: nil, shipping_options: nil, submit_type: nil, subscription_data: nil, tax_id_collection: nil, transfer_data: nil ) @after_completion = after_completion @allow_promotion_codes = allow_promotion_codes @application_fee_amount = application_fee_amount @application_fee_percent = application_fee_percent @automatic_tax = automatic_tax @billing_address_collection = billing_address_collection @consent_collection = @currency = currency @custom_fields = custom_fields @custom_text = custom_text @customer_creation = customer_creation @expand = @inactive_message = @invoice_creation = invoice_creation @line_items = line_items @metadata = @on_behalf_of = on_behalf_of @payment_intent_data = payment_intent_data @payment_method_collection = payment_method_collection @payment_method_types = payment_method_types @phone_number_collection = phone_number_collection @restrictions = restrictions @shipping_address_collection = shipping_address_collection @shipping_options = @submit_type = submit_type @subscription_data = subscription_data @tax_id_collection = tax_id_collection @transfer_data = transfer_data end |
Instance Attribute Details
#after_completion ⇒ Object
Behavior after the purchase is complete.
819 820 821 |
# File 'lib/stripe/resources/payment_link.rb', line 819 def after_completion @after_completion end |
#allow_promotion_codes ⇒ Object
Enables user redeemable promotion codes.
821 822 823 |
# File 'lib/stripe/resources/payment_link.rb', line 821 def allow_promotion_codes @allow_promotion_codes end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. Can only be applied when there are no line items with recurring prices.
823 824 825 |
# File 'lib/stripe/resources/payment_link.rb', line 823 def application_fee_amount @application_fee_amount end |
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. There must be at least 1 line item with a recurring price to use this field.
825 826 827 |
# File 'lib/stripe/resources/payment_link.rb', line 825 def application_fee_percent @application_fee_percent end |
#automatic_tax ⇒ Object
Configuration for automatic tax collection.
827 828 829 |
# File 'lib/stripe/resources/payment_link.rb', line 827 def automatic_tax @automatic_tax end |
#billing_address_collection ⇒ Object
Configuration for collecting the customer’s billing address. Defaults to ‘auto`.
829 830 831 |
# File 'lib/stripe/resources/payment_link.rb', line 829 def billing_address_collection @billing_address_collection end |
#consent_collection ⇒ Object
Configure fields to gather active consent from customers.
831 832 833 |
# File 'lib/stripe/resources/payment_link.rb', line 831 def @consent_collection end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies) and supported by each line item’s price.
833 834 835 |
# File 'lib/stripe/resources/payment_link.rb', line 833 def currency @currency end |
#custom_fields ⇒ Object
Collect additional information from your customer using custom fields. Up to 3 fields are supported.
835 836 837 |
# File 'lib/stripe/resources/payment_link.rb', line 835 def custom_fields @custom_fields end |
#custom_text ⇒ Object
Display additional text for your customers using custom text.
837 838 839 |
# File 'lib/stripe/resources/payment_link.rb', line 837 def custom_text @custom_text end |
#customer_creation ⇒ Object
Configures whether [checkout sessions](stripe.com/docs/api/checkout/sessions) created by this payment link create a [Customer](stripe.com/docs/api/customers).
839 840 841 |
# File 'lib/stripe/resources/payment_link.rb', line 839 def customer_creation @customer_creation end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
841 842 843 |
# File 'lib/stripe/resources/payment_link.rb', line 841 def @expand end |
#inactive_message ⇒ Object
The custom message to be displayed to a customer when a payment link is no longer active.
843 844 845 |
# File 'lib/stripe/resources/payment_link.rb', line 843 def @inactive_message end |
#invoice_creation ⇒ Object
Generate a post-purchase Invoice for one-time payments.
845 846 847 |
# File 'lib/stripe/resources/payment_link.rb', line 845 def invoice_creation @invoice_creation end |
#line_items ⇒ Object
The line items representing what is being sold. Each line item represents an item being sold. Up to 20 line items are supported.
847 848 849 |
# File 'lib/stripe/resources/payment_link.rb', line 847 def line_items @line_items end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`. Metadata associated with this Payment Link will automatically be copied to [checkout sessions](stripe.com/docs/api/checkout/sessions) created by this payment link.
849 850 851 |
# File 'lib/stripe/resources/payment_link.rb', line 849 def @metadata end |
#on_behalf_of ⇒ Object
The account on behalf of which to charge.
851 852 853 |
# File 'lib/stripe/resources/payment_link.rb', line 851 def on_behalf_of @on_behalf_of end |
#payment_intent_data ⇒ Object
A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in ‘payment` mode.
853 854 855 |
# File 'lib/stripe/resources/payment_link.rb', line 853 def payment_intent_data @payment_intent_data end |
#payment_method_collection ⇒ Object
Specify whether Checkout should collect a payment method. When set to ‘if_required`, Checkout will not collect a payment method when the total due for the session is 0.This may occur if the Checkout Session includes a free trial or a discount.
Can only be set in ‘subscription` mode. Defaults to `always`.
If you’d like information on how to collect a payment method outside of Checkout, read the guide on [configuring subscriptions with a free trial](stripe.com/docs/payments/checkout/free-trials).
859 860 861 |
# File 'lib/stripe/resources/payment_link.rb', line 859 def payment_method_collection @payment_method_collection end |
#payment_method_types ⇒ Object
The list of payment method types that customers can use. If no value is passed, Stripe will dynamically show relevant payment methods from your [payment method settings](dashboard.stripe.com/settings/payment_methods) (20+ payment methods [supported](stripe.com/docs/payments/payment-methods/integration-options#payment-method-product-support)).
861 862 863 |
# File 'lib/stripe/resources/payment_link.rb', line 861 def payment_method_types @payment_method_types end |
#phone_number_collection ⇒ Object
Controls phone number collection settings during checkout.
We recommend that you review your privacy policy and check with your legal contacts.
865 866 867 |
# File 'lib/stripe/resources/payment_link.rb', line 865 def phone_number_collection @phone_number_collection end |
#restrictions ⇒ Object
Settings that restrict the usage of a payment link.
867 868 869 |
# File 'lib/stripe/resources/payment_link.rb', line 867 def restrictions @restrictions end |
#shipping_address_collection ⇒ Object
Configuration for collecting the customer’s shipping address.
869 870 871 |
# File 'lib/stripe/resources/payment_link.rb', line 869 def shipping_address_collection @shipping_address_collection end |
#shipping_options ⇒ Object
The shipping rate options to apply to [checkout sessions](stripe.com/docs/api/checkout/sessions) created by this payment link.
871 872 873 |
# File 'lib/stripe/resources/payment_link.rb', line 871 def @shipping_options end |
#submit_type ⇒ Object
Describes the type of transaction being performed in order to customize relevant text on the page, such as the submit button. Changing this value will also affect the hostname in the [url](stripe.com/docs/api/payment_links/payment_links/object#url) property (example: ‘donate.stripe.com`).
873 874 875 |
# File 'lib/stripe/resources/payment_link.rb', line 873 def submit_type @submit_type end |
#subscription_data ⇒ Object
When creating a subscription, the specified configuration data will be used. There must be at least one line item with a recurring price to use ‘subscription_data`.
875 876 877 |
# File 'lib/stripe/resources/payment_link.rb', line 875 def subscription_data @subscription_data end |
#tax_id_collection ⇒ Object
Controls tax ID collection during checkout.
877 878 879 |
# File 'lib/stripe/resources/payment_link.rb', line 877 def tax_id_collection @tax_id_collection end |
#transfer_data ⇒ Object
The account (if any) the payments will be attributed to for tax reporting, and where funds from each payment will be transferred to.
879 880 881 |
# File 'lib/stripe/resources/payment_link.rb', line 879 def transfer_data @transfer_data end |