Class: Stripe::PaymentLink::CreateParams::CustomField
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLink::CreateParams::CustomField
- Defined in:
- lib/stripe/resources/payment_link.rb
Defined Under Namespace
Classes: Dropdown, Label, Numeric, Text
Instance Attribute Summary collapse
-
#dropdown ⇒ Object
Configuration for ‘type=dropdown` fields.
-
#key ⇒ Object
String of your choice that your integration can use to reconcile this field.
-
#label ⇒ Object
The label for the field, displayed to the customer.
-
#numeric ⇒ Object
Configuration for ‘type=numeric` fields.
-
#optional ⇒ Object
Whether the customer is required to complete the field before completing the Checkout Session.
-
#text ⇒ Object
Configuration for ‘type=text` fields.
-
#type ⇒ Object
The type of the field.
Instance Method Summary collapse
-
#initialize(dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil) ⇒ CustomField
constructor
A new instance of CustomField.
Methods inherited from RequestParams
Constructor Details
#initialize(dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil) ⇒ CustomField
Returns a new instance of CustomField.
453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 |
# File 'lib/stripe/resources/payment_link.rb', line 453 def initialize( dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil ) @dropdown = dropdown @key = key @label = label @numeric = numeric @optional = optional @text = text @type = type end |
Instance Attribute Details
#dropdown ⇒ Object
Configuration for ‘type=dropdown` fields.
439 440 441 |
# File 'lib/stripe/resources/payment_link.rb', line 439 def dropdown @dropdown end |
#key ⇒ Object
String of your choice that your integration can use to reconcile this field. Must be unique to this field, alphanumeric, and up to 200 characters.
441 442 443 |
# File 'lib/stripe/resources/payment_link.rb', line 441 def key @key end |
#label ⇒ Object
The label for the field, displayed to the customer.
443 444 445 |
# File 'lib/stripe/resources/payment_link.rb', line 443 def label @label end |
#numeric ⇒ Object
Configuration for ‘type=numeric` fields.
445 446 447 |
# File 'lib/stripe/resources/payment_link.rb', line 445 def numeric @numeric end |
#optional ⇒ Object
Whether the customer is required to complete the field before completing the Checkout Session. Defaults to ‘false`.
447 448 449 |
# File 'lib/stripe/resources/payment_link.rb', line 447 def optional @optional end |
#text ⇒ Object
Configuration for ‘type=text` fields.
449 450 451 |
# File 'lib/stripe/resources/payment_link.rb', line 449 def text @text end |
#type ⇒ Object
The type of the field.
451 452 453 |
# File 'lib/stripe/resources/payment_link.rb', line 451 def type @type end |