Class: Stripe::PaymentLink::CreateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLink::CreateParams::LineItem
- Defined in:
- lib/stripe/resources/payment_link.rb
Defined Under Namespace
Classes: AdjustableQuantity
Instance Attribute Summary collapse
-
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during checkout.
-
#price ⇒ Object
The ID of the [Price](stripe.com/docs/api/prices) or [Plan](stripe.com/docs/api/plans) object.
-
#quantity ⇒ Object
The quantity of the line item being purchased.
Instance Method Summary collapse
-
#initialize(adjustable_quantity: nil, price: nil, quantity: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(adjustable_quantity: nil, price: nil, quantity: nil) ⇒ LineItem
Returns a new instance of LineItem.
709 710 711 712 713 |
# File 'lib/stripe/resources/payment_link.rb', line 709 def initialize(adjustable_quantity: nil, price: nil, quantity: nil) @adjustable_quantity = adjustable_quantity @price = price @quantity = quantity end |
Instance Attribute Details
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during checkout.
701 702 703 |
# File 'lib/stripe/resources/payment_link.rb', line 701 def adjustable_quantity @adjustable_quantity end |
#price ⇒ Object
The ID of the [Price](stripe.com/docs/api/prices) or [Plan](stripe.com/docs/api/plans) object.
704 705 706 |
# File 'lib/stripe/resources/payment_link.rb', line 704 def price @price end |
#quantity ⇒ Object
The quantity of the line item being purchased.
707 708 709 |
# File 'lib/stripe/resources/payment_link.rb', line 707 def quantity @quantity end |