Class: Stripe::PaymentLink::CreateParams::LineItem::AdjustableQuantity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLink::CreateParams::LineItem::AdjustableQuantity
- Defined in:
- lib/stripe/resources/payment_link.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative Integer.
-
#maximum ⇒ Object
The maximum quantity the customer can purchase.
-
#minimum ⇒ Object
The minimum quantity the customer can purchase.
Instance Method Summary collapse
-
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
constructor
A new instance of AdjustableQuantity.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
Returns a new instance of AdjustableQuantity.
617 618 619 620 621 |
# File 'lib/stripe/resources/payment_link.rb', line 617 def initialize(enabled: nil, maximum: nil, minimum: nil) @enabled = enabled @maximum = maximum @minimum = minimum end |
Instance Attribute Details
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative Integer.
611 612 613 |
# File 'lib/stripe/resources/payment_link.rb', line 611 def enabled @enabled end |
#maximum ⇒ Object
The maximum quantity the customer can purchase. By default this value is 99. You can specify a value up to 999.
613 614 615 |
# File 'lib/stripe/resources/payment_link.rb', line 613 def maximum @maximum end |
#minimum ⇒ Object
The minimum quantity the customer can purchase. By default this value is 0. If there is only one item in the cart then that item’s quantity cannot go down to 0.
615 616 617 |
# File 'lib/stripe/resources/payment_link.rb', line 615 def minimum @minimum end |