Class: Stripe::PaymentLink::CreateParams::LineItem::AdjustableQuantity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity

Returns a new instance of AdjustableQuantity.



694
695
696
697
698
# File 'lib/stripe/resources/payment_link.rb', line 694

def initialize(enabled: nil, maximum: nil, minimum: nil)
  @enabled = enabled
  @maximum = maximum
  @minimum = minimum
end

Instance Attribute Details

#enabledObject

Set to true if the quantity can be adjusted to any non-negative Integer.



686
687
688
# File 'lib/stripe/resources/payment_link.rb', line 686

def enabled
  @enabled
end

#maximumObject

The maximum quantity the customer can purchase. By default this value is 99. You can specify a value up to 999.



689
690
691
# File 'lib/stripe/resources/payment_link.rb', line 689

def maximum
  @maximum
end

#minimumObject

The minimum quantity the customer can purchase. By default this value is 0. If there is only one item in the cart then that item’s quantity cannot go down to 0.



692
693
694
# File 'lib/stripe/resources/payment_link.rb', line 692

def minimum
  @minimum
end