Class: Stripe::PaymentLink::CreateParams::LineItem::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



674
675
676
677
678
679
680
# File 'lib/stripe/resources/payment_link.rb', line 674

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



664
665
666
# File 'lib/stripe/resources/payment_link.rb', line 664

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



666
667
668
# File 'lib/stripe/resources/payment_link.rb', line 666

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



668
669
670
# File 'lib/stripe/resources/payment_link.rb', line 668

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



670
671
672
# File 'lib/stripe/resources/payment_link.rb', line 670

def name
  @name
end

#tax_codeObject



672
673
674
# File 'lib/stripe/resources/payment_link.rb', line 672

def tax_code
  @tax_code
end