Class: Stripe::PaymentLink::CreateParams::OptionalItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLink::CreateParams::OptionalItem
- Defined in:
- lib/stripe/resources/payment_link.rb
Defined Under Namespace
Classes: AdjustableQuantity
Instance Attribute Summary collapse
-
#adjustable_quantity ⇒ Object
When set, provides configuration for the customer to adjust the quantity of the line item created when a customer chooses to add this optional item to their order.
-
#price ⇒ Object
The ID of the [Price](stripe.com/docs/api/prices) or [Plan](stripe.com/docs/api/plans) object.
-
#quantity ⇒ Object
The initial quantity of the line item created when a customer chooses to add this optional item to their order.
Instance Method Summary collapse
-
#initialize(adjustable_quantity: nil, price: nil, quantity: nil) ⇒ OptionalItem
constructor
A new instance of OptionalItem.
Methods inherited from RequestParams
Constructor Details
#initialize(adjustable_quantity: nil, price: nil, quantity: nil) ⇒ OptionalItem
Returns a new instance of OptionalItem.
766 767 768 769 770 |
# File 'lib/stripe/resources/payment_link.rb', line 766 def initialize(adjustable_quantity: nil, price: nil, quantity: nil) @adjustable_quantity = adjustable_quantity @price = price @quantity = quantity end |
Instance Attribute Details
#adjustable_quantity ⇒ Object
When set, provides configuration for the customer to adjust the quantity of the line item created when a customer chooses to add this optional item to their order.
760 761 762 |
# File 'lib/stripe/resources/payment_link.rb', line 760 def adjustable_quantity @adjustable_quantity end |
#price ⇒ Object
The ID of the [Price](stripe.com/docs/api/prices) or [Plan](stripe.com/docs/api/plans) object.
762 763 764 |
# File 'lib/stripe/resources/payment_link.rb', line 762 def price @price end |
#quantity ⇒ Object
The initial quantity of the line item created when a customer chooses to add this optional item to their order.
764 765 766 |
# File 'lib/stripe/resources/payment_link.rb', line 764 def quantity @quantity end |