Class: Stripe::PaymentLink::CreateParams::OptionalItem::AdjustableQuantity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLink::CreateParams::OptionalItem::AdjustableQuantity
- Defined in:
- lib/stripe/resources/payment_link.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative integer.
-
#maximum ⇒ Object
The maximum quantity of this item the customer can purchase.
-
#minimum ⇒ Object
The minimum quantity of this item the customer must purchase, if they choose to purchase it.
Instance Method Summary collapse
-
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
constructor
A new instance of AdjustableQuantity.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
Returns a new instance of AdjustableQuantity.
678 679 680 681 682 |
# File 'lib/stripe/resources/payment_link.rb', line 678 def initialize(enabled: nil, maximum: nil, minimum: nil) @enabled = enabled @maximum = maximum @minimum = minimum end |
Instance Attribute Details
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative integer.
672 673 674 |
# File 'lib/stripe/resources/payment_link.rb', line 672 def enabled @enabled end |
#maximum ⇒ Object
The maximum quantity of this item the customer can purchase. By default this value is 99.
674 675 676 |
# File 'lib/stripe/resources/payment_link.rb', line 674 def maximum @maximum end |
#minimum ⇒ Object
The minimum quantity of this item the customer must purchase, if they choose to purchase it. Because this item is optional, the customer will always be able to remove it from their order, even if the ‘minimum` configured here is greater than 0. By default this value is 0.
676 677 678 |
# File 'lib/stripe/resources/payment_link.rb', line 676 def minimum @minimum end |