Class: Stripe::PaymentLink::CreateParams::ShippingOption
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLink::CreateParams::ShippingOption
- Defined in:
- lib/stripe/resources/payment_link.rb
Instance Attribute Summary collapse
-
#shipping_rate ⇒ Object
The ID of the Shipping Rate to use for this shipping option.
Instance Method Summary collapse
-
#initialize(shipping_rate: nil) ⇒ ShippingOption
constructor
A new instance of ShippingOption.
Methods inherited from RequestParams
Constructor Details
#initialize(shipping_rate: nil) ⇒ ShippingOption
Returns a new instance of ShippingOption.
809 810 811 |
# File 'lib/stripe/resources/payment_link.rb', line 809 def initialize(shipping_rate: nil) @shipping_rate = shipping_rate end |
Instance Attribute Details
#shipping_rate ⇒ Object
The ID of the Shipping Rate to use for this shipping option.
807 808 809 |
# File 'lib/stripe/resources/payment_link.rb', line 807 def shipping_rate @shipping_rate end |