Class: Stripe::PaymentLink::CreateParams::SubscriptionData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Defined Under Namespace

Classes: InvoiceSettings, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, invoice_settings: nil, metadata: nil, trial_period_days: nil, trial_settings: nil) ⇒ SubscriptionData

Returns a new instance of SubscriptionData.



913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/stripe/resources/payment_link.rb', line 913

def initialize(
  description: nil,
  invoice_settings: nil,
  metadata: nil,
  trial_period_days: nil,
  trial_settings: nil
)
  @description = description
  @invoice_settings = invoice_settings
  @metadata = 
  @trial_period_days = trial_period_days
  @trial_settings = trial_settings
end

Instance Attribute Details

#descriptionObject

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



903
904
905
# File 'lib/stripe/resources/payment_link.rb', line 903

def description
  @description
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



905
906
907
# File 'lib/stripe/resources/payment_link.rb', line 905

def invoice_settings
  @invoice_settings
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that will declaratively set metadata on [Subscriptions](stripe.com/docs/api/subscriptions) generated from this payment link. Unlike object-level metadata, this field is declarative. Updates will clear prior values.



907
908
909
# File 'lib/stripe/resources/payment_link.rb', line 907

def 
  @metadata
end

#trial_period_daysObject

Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.



909
910
911
# File 'lib/stripe/resources/payment_link.rb', line 909

def trial_period_days
  @trial_period_days
end

#trial_settingsObject

Settings related to subscription trials.



911
912
913
# File 'lib/stripe/resources/payment_link.rb', line 911

def trial_settings
  @trial_settings
end