Class: Stripe::PaymentLink::CustomField

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_link.rb

Defined Under Namespace

Classes: Dropdown, Label, Numeric, Text

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

Attribute for field dropdown



99
100
101
# File 'lib/stripe/resources/payment_link.rb', line 99

def dropdown
  @dropdown
end

#keyObject (readonly)

String of your choice that your integration can use to reconcile this field. Must be unique to this field, alphanumeric, and up to 200 characters.



101
102
103
# File 'lib/stripe/resources/payment_link.rb', line 101

def key
  @key
end

#labelObject (readonly)

Attribute for field label



103
104
105
# File 'lib/stripe/resources/payment_link.rb', line 103

def label
  @label
end

#numericObject (readonly)

Attribute for field numeric



105
106
107
# File 'lib/stripe/resources/payment_link.rb', line 105

def numeric
  @numeric
end

#optionalObject (readonly)

Whether the customer is required to complete the field before completing the Checkout Session. Defaults to ‘false`.



107
108
109
# File 'lib/stripe/resources/payment_link.rb', line 107

def optional
  @optional
end

#textObject (readonly)

Attribute for field text



109
110
111
# File 'lib/stripe/resources/payment_link.rb', line 109

def text
  @text
end

#typeObject (readonly)

The type of the field.



111
112
113
# File 'lib/stripe/resources/payment_link.rb', line 111

def type
  @type
end