Class: Stripe::PaymentLink::CustomField

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_link.rb

Defined Under Namespace

Classes: Dropdown, Label, Numeric, Text

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

Attribute for field dropdown



109
110
111
# File 'lib/stripe/resources/payment_link.rb', line 109

def dropdown
  @dropdown
end

#keyObject (readonly)

String of your choice that your integration can use to reconcile this field. Must be unique to this field, alphanumeric, and up to 200 characters.



112
113
114
# File 'lib/stripe/resources/payment_link.rb', line 112

def key
  @key
end

#labelObject (readonly)

Attribute for field label



115
116
117
# File 'lib/stripe/resources/payment_link.rb', line 115

def label
  @label
end

#numericObject (readonly)

Attribute for field numeric



118
119
120
# File 'lib/stripe/resources/payment_link.rb', line 118

def numeric
  @numeric
end

#optionalObject (readonly)

Whether the customer is required to complete the field before completing the Checkout Session. Defaults to ‘false`.



121
122
123
# File 'lib/stripe/resources/payment_link.rb', line 121

def optional
  @optional
end

#textObject (readonly)

Attribute for field text



124
125
126
# File 'lib/stripe/resources/payment_link.rb', line 124

def text
  @text
end

#typeObject (readonly)

The type of the field.



127
128
129
# File 'lib/stripe/resources/payment_link.rb', line 127

def type
  @type
end