Class: Stripe::PaymentLink::InvoiceCreation::InvoiceData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Defined Under Namespace

Classes: CustomField, Issuer, RenderingOptions

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_tax_idsObject (readonly)

The account tax IDs associated with the invoice.



171
172
173
# File 'lib/stripe/resources/payment_link.rb', line 171

def 
  @account_tax_ids
end

#custom_fieldsObject (readonly)

A list of up to 4 custom fields to be displayed on the invoice.



173
174
175
# File 'lib/stripe/resources/payment_link.rb', line 173

def custom_fields
  @custom_fields
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



175
176
177
# File 'lib/stripe/resources/payment_link.rb', line 175

def description
  @description
end

Footer to be displayed on the invoice.



177
178
179
# File 'lib/stripe/resources/payment_link.rb', line 177

def footer
  @footer
end

#issuerObject (readonly)

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



179
180
181
# File 'lib/stripe/resources/payment_link.rb', line 179

def issuer
  @issuer
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



181
182
183
# File 'lib/stripe/resources/payment_link.rb', line 181

def 
  @metadata
end

#rendering_optionsObject (readonly)

Options for invoice PDF rendering.



183
184
185
# File 'lib/stripe/resources/payment_link.rb', line 183

def rendering_options
  @rendering_options
end