Class: Stripe::PaymentLink::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_link.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



288
289
290
291
292
293
294
# File 'lib/stripe/resources/payment_link.rb', line 288

def initialize(active: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil)
  @active = active
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#activeObject

Only return payment links that are active or inactive (e.g., pass ‘false` to list all inactive payment links).



278
279
280
# File 'lib/stripe/resources/payment_link.rb', line 278

def active
  @active
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



280
281
282
# File 'lib/stripe/resources/payment_link.rb', line 280

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



282
283
284
# File 'lib/stripe/resources/payment_link.rb', line 282

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



284
285
286
# File 'lib/stripe/resources/payment_link.rb', line 284

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



286
287
288
# File 'lib/stripe/resources/payment_link.rb', line 286

def starting_after
  @starting_after
end