Class: Stripe::PaymentLink::OptionalItem::AdjustableQuantity
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentLink::OptionalItem::AdjustableQuantity
- Defined in:
- lib/stripe/resources/payment_link.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#enabled ⇒ Object
readonly
Set to true if the quantity can be adjusted to any non-negative integer.
-
#maximum ⇒ Object
readonly
The maximum quantity of this item the customer can purchase.
-
#minimum ⇒ Object
readonly
The minimum quantity of this item the customer must purchase, if they choose to purchase it.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#enabled ⇒ Object (readonly)
Set to true if the quantity can be adjusted to any non-negative integer.
389 390 391 |
# File 'lib/stripe/resources/payment_link.rb', line 389 def enabled @enabled end |
#maximum ⇒ Object (readonly)
The maximum quantity of this item the customer can purchase. By default this value is 99.
391 392 393 |
# File 'lib/stripe/resources/payment_link.rb', line 391 def maximum @maximum end |
#minimum ⇒ Object (readonly)
The minimum quantity of this item the customer must purchase, if they choose to purchase it. Because this item is optional, the customer will always be able to remove it from their order, even if the ‘minimum` configured here is greater than 0. By default this value is 0.
393 394 395 |
# File 'lib/stripe/resources/payment_link.rb', line 393 def minimum @minimum end |
Class Method Details
.field_remappings ⇒ Object
399 400 401 |
# File 'lib/stripe/resources/payment_link.rb', line 399 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
395 396 397 |
# File 'lib/stripe/resources/payment_link.rb', line 395 def self.inner_class_types @inner_class_types = {} end |