Class: Stripe::PaymentLink::PaymentIntentData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentLink::PaymentIntentData
- Defined in:
- lib/stripe/resources/payment_link.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
readonly
Indicates when the funds will be captured from the customer’s account.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that will set metadata on [Payment Intents](stripe.com/docs/api/payment_intents) generated from this payment link.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with the payment method collected during checkout.
-
#statement_descriptor ⇒ Object
readonly
For a non-card payment, information about the charge that appears on the customer’s statement when this payment succeeds in creating a charge.
-
#statement_descriptor_suffix ⇒ Object
readonly
For a card payment, information about the charge that appears on the customer’s statement when this payment succeeds in creating a charge.
-
#transfer_group ⇒ Object
readonly
A string that identifies the resulting payment as part of a group.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#capture_method ⇒ Object (readonly)
Indicates when the funds will be captured from the customer’s account.
187 188 189 |
# File 'lib/stripe/resources/payment_link.rb', line 187 def capture_method @capture_method end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
189 190 191 |
# File 'lib/stripe/resources/payment_link.rb', line 189 def description @description end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that will set metadata on [Payment Intents](stripe.com/docs/api/payment_intents) generated from this payment link.
191 192 193 |
# File 'lib/stripe/resources/payment_link.rb', line 191 def @metadata end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with the payment method collected during checkout.
193 194 195 |
# File 'lib/stripe/resources/payment_link.rb', line 193 def setup_future_usage @setup_future_usage end |
#statement_descriptor ⇒ Object (readonly)
For a non-card payment, information about the charge that appears on the customer’s statement when this payment succeeds in creating a charge.
195 196 197 |
# File 'lib/stripe/resources/payment_link.rb', line 195 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object (readonly)
For a card payment, information about the charge that appears on the customer’s statement when this payment succeeds in creating a charge. Concatenated with the account’s statement descriptor prefix to form the complete statement descriptor.
197 198 199 |
# File 'lib/stripe/resources/payment_link.rb', line 197 def statement_descriptor_suffix @statement_descriptor_suffix end |
#transfer_group ⇒ Object (readonly)
A string that identifies the resulting payment as part of a group. See the PaymentIntents [use case for connected accounts](stripe.com/docs/connect/separate-charges-and-transfers) for details.
199 200 201 |
# File 'lib/stripe/resources/payment_link.rb', line 199 def transfer_group @transfer_group end |