Class: Stripe::PaymentLink::SubscriptionData

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_link.rb

Defined Under Namespace

Classes: InvoiceSettings, TrialSettings

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#descriptionObject (readonly)

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



641
642
643
# File 'lib/stripe/resources/payment_link.rb', line 641

def description
  @description
end

#invoice_settingsObject (readonly)

Attribute for field invoice_settings



643
644
645
# File 'lib/stripe/resources/payment_link.rb', line 643

def invoice_settings
  @invoice_settings
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that will set metadata on [Subscriptions](docs.stripe.com/api/subscriptions) generated from this payment link.



645
646
647
# File 'lib/stripe/resources/payment_link.rb', line 645

def 
  @metadata
end

#trial_period_daysObject (readonly)

Integer representing the number of trial period days before the customer is charged for the first time.



647
648
649
# File 'lib/stripe/resources/payment_link.rb', line 647

def trial_period_days
  @trial_period_days
end

#trial_settingsObject (readonly)

Settings related to subscription trials.



649
650
651
# File 'lib/stripe/resources/payment_link.rb', line 649

def trial_settings
  @trial_settings
end

Class Method Details

.field_remappingsObject



655
656
657
# File 'lib/stripe/resources/payment_link.rb', line 655

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



651
652
653
# File 'lib/stripe/resources/payment_link.rb', line 651

def self.inner_class_types
  @inner_class_types = { invoice_settings: InvoiceSettings, trial_settings: TrialSettings }
end