Class: Stripe::PaymentLink::SubscriptionData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentLink::SubscriptionData
- Defined in:
- lib/stripe/resources/payment_link.rb
Defined Under Namespace
Classes: InvoiceSettings, TrialSettings
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#description ⇒ Object
readonly
The subscription’s description, meant to be displayable to the customer.
-
#invoice_settings ⇒ Object
readonly
Attribute for field invoice_settings.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that will set metadata on [Subscriptions](stripe.com/docs/api/subscriptions) generated from this payment link.
-
#trial_period_days ⇒ Object
readonly
Integer representing the number of trial period days before the customer is charged for the first time.
-
#trial_settings ⇒ Object
readonly
Settings related to subscription trials.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#description ⇒ Object (readonly)
The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
251 252 253 |
# File 'lib/stripe/resources/payment_link.rb', line 251 def description @description end |
#invoice_settings ⇒ Object (readonly)
Attribute for field invoice_settings
253 254 255 |
# File 'lib/stripe/resources/payment_link.rb', line 253 def invoice_settings @invoice_settings end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that will set metadata on [Subscriptions](stripe.com/docs/api/subscriptions) generated from this payment link.
255 256 257 |
# File 'lib/stripe/resources/payment_link.rb', line 255 def @metadata end |
#trial_period_days ⇒ Object (readonly)
Integer representing the number of trial period days before the customer is charged for the first time.
257 258 259 |
# File 'lib/stripe/resources/payment_link.rb', line 257 def trial_period_days @trial_period_days end |
#trial_settings ⇒ Object (readonly)
Settings related to subscription trials.
259 260 261 |
# File 'lib/stripe/resources/payment_link.rb', line 259 def trial_settings @trial_settings end |