Class: Stripe::PaymentLink::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLink::UpdateParams
- Defined in:
- lib/stripe/resources/payment_link.rb
Defined Under Namespace
Classes: AfterCompletion, AutomaticTax, CustomField, CustomText, InvoiceCreation, LineItem, PaymentIntentData, PhoneNumberCollection, Restrictions, ShippingAddressCollection, SubscriptionData, TaxIdCollection
Instance Attribute Summary collapse
-
#active ⇒ Object
Whether the payment link’s ‘url` is active.
-
#after_completion ⇒ Object
Behavior after the purchase is complete.
-
#allow_promotion_codes ⇒ Object
Enables user redeemable promotion codes.
-
#automatic_tax ⇒ Object
Configuration for automatic tax collection.
-
#billing_address_collection ⇒ Object
Configuration for collecting the customer’s billing address.
-
#custom_fields ⇒ Object
Collect additional information from your customer using custom fields.
-
#custom_text ⇒ Object
Display additional text for your customers using custom text.
-
#customer_creation ⇒ Object
Configures whether [checkout sessions](stripe.com/docs/api/checkout/sessions) created by this payment link create a [Customer](stripe.com/docs/api/customers).
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#inactive_message ⇒ Object
The custom message to be displayed to a customer when a payment link is no longer active.
-
#invoice_creation ⇒ Object
Generate a post-purchase Invoice for one-time payments.
-
#line_items ⇒ Object
The line items representing what is being sold.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment_intent_data ⇒ Object
A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in ‘payment` mode.
-
#payment_method_collection ⇒ Object
Specify whether Checkout should collect a payment method.
-
#payment_method_types ⇒ Object
The list of payment method types that customers can use.
-
#phone_number_collection ⇒ Object
Controls phone number collection settings during checkout.
-
#restrictions ⇒ Object
Settings that restrict the usage of a payment link.
-
#shipping_address_collection ⇒ Object
Configuration for collecting the customer’s shipping address.
-
#submit_type ⇒ Object
Describes the type of transaction being performed in order to customize relevant text on the page, such as the submit button.
-
#subscription_data ⇒ Object
When creating a subscription, the specified configuration data will be used.
-
#tax_id_collection ⇒ Object
Controls tax ID collection during checkout.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, after_completion: nil, allow_promotion_codes: nil, automatic_tax: nil, billing_address_collection: nil, custom_fields: nil, custom_text: nil, customer_creation: nil, expand: nil, inactive_message: nil, invoice_creation: nil, line_items: nil, metadata: nil, payment_intent_data: nil, payment_method_collection: nil, payment_method_types: nil, phone_number_collection: nil, restrictions: nil, shipping_address_collection: nil, submit_type: nil, subscription_data: nil, tax_id_collection: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 |
# File 'lib/stripe/resources/payment_link.rb', line 1517 def initialize( active: nil, after_completion: nil, allow_promotion_codes: nil, automatic_tax: nil, billing_address_collection: nil, custom_fields: nil, custom_text: nil, customer_creation: nil, expand: nil, inactive_message: nil, invoice_creation: nil, line_items: nil, metadata: nil, payment_intent_data: nil, payment_method_collection: nil, payment_method_types: nil, phone_number_collection: nil, restrictions: nil, shipping_address_collection: nil, submit_type: nil, subscription_data: nil, tax_id_collection: nil ) @active = active @after_completion = after_completion @allow_promotion_codes = allow_promotion_codes @automatic_tax = automatic_tax @billing_address_collection = billing_address_collection @custom_fields = custom_fields @custom_text = custom_text @customer_creation = customer_creation @expand = @inactive_message = @invoice_creation = invoice_creation @line_items = line_items @metadata = @payment_intent_data = payment_intent_data @payment_method_collection = payment_method_collection @payment_method_types = payment_method_types @phone_number_collection = phone_number_collection @restrictions = restrictions @shipping_address_collection = shipping_address_collection @submit_type = submit_type @subscription_data = subscription_data @tax_id_collection = tax_id_collection end |
Instance Attribute Details
#active ⇒ Object
Whether the payment link’s ‘url` is active. If `false`, customers visiting the URL will be shown a page saying that the link has been deactivated.
1467 1468 1469 |
# File 'lib/stripe/resources/payment_link.rb', line 1467 def active @active end |
#after_completion ⇒ Object
Behavior after the purchase is complete.
1469 1470 1471 |
# File 'lib/stripe/resources/payment_link.rb', line 1469 def after_completion @after_completion end |
#allow_promotion_codes ⇒ Object
Enables user redeemable promotion codes.
1471 1472 1473 |
# File 'lib/stripe/resources/payment_link.rb', line 1471 def allow_promotion_codes @allow_promotion_codes end |
#automatic_tax ⇒ Object
Configuration for automatic tax collection.
1473 1474 1475 |
# File 'lib/stripe/resources/payment_link.rb', line 1473 def automatic_tax @automatic_tax end |
#billing_address_collection ⇒ Object
Configuration for collecting the customer’s billing address. Defaults to ‘auto`.
1475 1476 1477 |
# File 'lib/stripe/resources/payment_link.rb', line 1475 def billing_address_collection @billing_address_collection end |
#custom_fields ⇒ Object
Collect additional information from your customer using custom fields. Up to 3 fields are supported.
1477 1478 1479 |
# File 'lib/stripe/resources/payment_link.rb', line 1477 def custom_fields @custom_fields end |
#custom_text ⇒ Object
Display additional text for your customers using custom text.
1479 1480 1481 |
# File 'lib/stripe/resources/payment_link.rb', line 1479 def custom_text @custom_text end |
#customer_creation ⇒ Object
Configures whether [checkout sessions](stripe.com/docs/api/checkout/sessions) created by this payment link create a [Customer](stripe.com/docs/api/customers).
1481 1482 1483 |
# File 'lib/stripe/resources/payment_link.rb', line 1481 def customer_creation @customer_creation end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1483 1484 1485 |
# File 'lib/stripe/resources/payment_link.rb', line 1483 def @expand end |
#inactive_message ⇒ Object
The custom message to be displayed to a customer when a payment link is no longer active.
1485 1486 1487 |
# File 'lib/stripe/resources/payment_link.rb', line 1485 def @inactive_message end |
#invoice_creation ⇒ Object
Generate a post-purchase Invoice for one-time payments.
1487 1488 1489 |
# File 'lib/stripe/resources/payment_link.rb', line 1487 def invoice_creation @invoice_creation end |
#line_items ⇒ Object
The line items representing what is being sold. Each line item represents an item being sold. Up to 20 line items are supported.
1489 1490 1491 |
# File 'lib/stripe/resources/payment_link.rb', line 1489 def line_items @line_items end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`. Metadata associated with this Payment Link will automatically be copied to [checkout sessions](stripe.com/docs/api/checkout/sessions) created by this payment link.
1491 1492 1493 |
# File 'lib/stripe/resources/payment_link.rb', line 1491 def @metadata end |
#payment_intent_data ⇒ Object
A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in ‘payment` mode.
1493 1494 1495 |
# File 'lib/stripe/resources/payment_link.rb', line 1493 def payment_intent_data @payment_intent_data end |
#payment_method_collection ⇒ Object
Specify whether Checkout should collect a payment method. When set to ‘if_required`, Checkout will not collect a payment method when the total due for the session is 0.This may occur if the Checkout Session includes a free trial or a discount.
Can only be set in ‘subscription` mode. Defaults to `always`.
If you’d like information on how to collect a payment method outside of Checkout, read the guide on [configuring subscriptions with a free trial](stripe.com/docs/payments/checkout/free-trials).
1499 1500 1501 |
# File 'lib/stripe/resources/payment_link.rb', line 1499 def payment_method_collection @payment_method_collection end |
#payment_method_types ⇒ Object
The list of payment method types that customers can use. Pass an empty string to enable dynamic payment methods that use your [payment method settings](dashboard.stripe.com/settings/payment_methods).
1501 1502 1503 |
# File 'lib/stripe/resources/payment_link.rb', line 1501 def payment_method_types @payment_method_types end |
#phone_number_collection ⇒ Object
Controls phone number collection settings during checkout.
We recommend that you review your privacy policy and check with your legal contacts.
1505 1506 1507 |
# File 'lib/stripe/resources/payment_link.rb', line 1505 def phone_number_collection @phone_number_collection end |
#restrictions ⇒ Object
Settings that restrict the usage of a payment link.
1507 1508 1509 |
# File 'lib/stripe/resources/payment_link.rb', line 1507 def restrictions @restrictions end |
#shipping_address_collection ⇒ Object
Configuration for collecting the customer’s shipping address.
1509 1510 1511 |
# File 'lib/stripe/resources/payment_link.rb', line 1509 def shipping_address_collection @shipping_address_collection end |
#submit_type ⇒ Object
Describes the type of transaction being performed in order to customize relevant text on the page, such as the submit button. Changing this value will also affect the hostname in the [url](stripe.com/docs/api/payment_links/payment_links/object#url) property (example: ‘donate.stripe.com`).
1511 1512 1513 |
# File 'lib/stripe/resources/payment_link.rb', line 1511 def submit_type @submit_type end |
#subscription_data ⇒ Object
When creating a subscription, the specified configuration data will be used. There must be at least one line item with a recurring price to use ‘subscription_data`.
1513 1514 1515 |
# File 'lib/stripe/resources/payment_link.rb', line 1513 def subscription_data @subscription_data end |
#tax_id_collection ⇒ Object
Controls tax ID collection during checkout.
1515 1516 1517 |
# File 'lib/stripe/resources/payment_link.rb', line 1515 def tax_id_collection @tax_id_collection end |