Class: Stripe::PaymentLink::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_link.rb

Defined Under Namespace

Classes: AfterCompletion, AutomaticTax, CustomField, CustomText, InvoiceCreation, LineItem, PaymentIntentData, Restrictions, ShippingAddressCollection, SubscriptionData, TaxIdCollection

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, after_completion: nil, allow_promotion_codes: nil, automatic_tax: nil, billing_address_collection: nil, custom_fields: nil, custom_text: nil, customer_creation: nil, expand: nil, inactive_message: nil, invoice_creation: nil, line_items: nil, metadata: nil, payment_intent_data: nil, payment_method_collection: nil, payment_method_types: nil, restrictions: nil, shipping_address_collection: nil, submit_type: nil, subscription_data: nil, tax_id_collection: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
1646
1647
1648
1649
1650
1651
1652
1653
1654
1655
1656
1657
1658
1659
# File 'lib/stripe/resources/payment_link.rb', line 1615

def initialize(
  active: nil,
  after_completion: nil,
  allow_promotion_codes: nil,
  automatic_tax: nil,
  billing_address_collection: nil,
  custom_fields: nil,
  custom_text: nil,
  customer_creation: nil,
  expand: nil,
  inactive_message: nil,
  invoice_creation: nil,
  line_items: nil,
  metadata: nil,
  payment_intent_data: nil,
  payment_method_collection: nil,
  payment_method_types: nil,
  restrictions: nil,
  shipping_address_collection: nil,
  submit_type: nil,
  subscription_data: nil,
  tax_id_collection: nil
)
  @active = active
  @after_completion = after_completion
  @allow_promotion_codes = allow_promotion_codes
  @automatic_tax = automatic_tax
  @billing_address_collection = billing_address_collection
  @custom_fields = custom_fields
  @custom_text = custom_text
  @customer_creation = customer_creation
  @expand = expand
  @inactive_message = inactive_message
  @invoice_creation = invoice_creation
  @line_items = line_items
  @metadata = 
  @payment_intent_data = payment_intent_data
  @payment_method_collection = payment_method_collection
  @payment_method_types = payment_method_types
  @restrictions = restrictions
  @shipping_address_collection = shipping_address_collection
  @submit_type = submit_type
  @subscription_data = subscription_data
  @tax_id_collection = tax_id_collection
end

Instance Attribute Details

#activeObject

Whether the payment link’s ‘url` is active. If `false`, customers visiting the URL will be shown a page saying that the link has been deactivated.



1549
1550
1551
# File 'lib/stripe/resources/payment_link.rb', line 1549

def active
  @active
end

#after_completionObject

Behavior after the purchase is complete.



1552
1553
1554
# File 'lib/stripe/resources/payment_link.rb', line 1552

def after_completion
  @after_completion
end

#allow_promotion_codesObject

Enables user redeemable promotion codes.



1555
1556
1557
# File 'lib/stripe/resources/payment_link.rb', line 1555

def allow_promotion_codes
  @allow_promotion_codes
end

#automatic_taxObject

Configuration for automatic tax collection.



1558
1559
1560
# File 'lib/stripe/resources/payment_link.rb', line 1558

def automatic_tax
  @automatic_tax
end

#billing_address_collectionObject

Configuration for collecting the customer’s billing address. Defaults to ‘auto`.



1561
1562
1563
# File 'lib/stripe/resources/payment_link.rb', line 1561

def billing_address_collection
  @billing_address_collection
end

#custom_fieldsObject

Collect additional information from your customer using custom fields. Up to 3 fields are supported.



1564
1565
1566
# File 'lib/stripe/resources/payment_link.rb', line 1564

def custom_fields
  @custom_fields
end

#custom_textObject

Display additional text for your customers using custom text.



1567
1568
1569
# File 'lib/stripe/resources/payment_link.rb', line 1567

def custom_text
  @custom_text
end

#customer_creationObject

Configures whether [checkout sessions](stripe.com/docs/api/checkout/sessions) created by this payment link create a [Customer](stripe.com/docs/api/customers).



1570
1571
1572
# File 'lib/stripe/resources/payment_link.rb', line 1570

def customer_creation
  @customer_creation
end

#expandObject

Specifies which fields in the response should be expanded.



1573
1574
1575
# File 'lib/stripe/resources/payment_link.rb', line 1573

def expand
  @expand
end

#inactive_messageObject

The custom message to be displayed to a customer when a payment link is no longer active.



1576
1577
1578
# File 'lib/stripe/resources/payment_link.rb', line 1576

def inactive_message
  @inactive_message
end

#invoice_creationObject

Generate a post-purchase Invoice for one-time payments.



1579
1580
1581
# File 'lib/stripe/resources/payment_link.rb', line 1579

def invoice_creation
  @invoice_creation
end

#line_itemsObject

The line items representing what is being sold. Each line item represents an item being sold. Up to 20 line items are supported.



1582
1583
1584
# File 'lib/stripe/resources/payment_link.rb', line 1582

def line_items
  @line_items
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`. Metadata associated with this Payment Link will automatically be copied to [checkout sessions](stripe.com/docs/api/checkout/sessions) created by this payment link.



1585
1586
1587
# File 'lib/stripe/resources/payment_link.rb', line 1585

def 
  @metadata
end

#payment_intent_dataObject

A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in ‘payment` mode.



1588
1589
1590
# File 'lib/stripe/resources/payment_link.rb', line 1588

def payment_intent_data
  @payment_intent_data
end

#payment_method_collectionObject

Specify whether Checkout should collect a payment method. When set to ‘if_required`, Checkout will not collect a payment method when the total due for the session is 0.This may occur if the Checkout Session includes a free trial or a discount.

Can only be set in ‘subscription` mode. Defaults to `always`.

If you’d like information on how to collect a payment method outside of Checkout, read the guide on [configuring subscriptions with a free trial](stripe.com/docs/payments/checkout/free-trials).



1595
1596
1597
# File 'lib/stripe/resources/payment_link.rb', line 1595

def payment_method_collection
  @payment_method_collection
end

#payment_method_typesObject

The list of payment method types that customers can use. Pass an empty string to enable dynamic payment methods that use your [payment method settings](dashboard.stripe.com/settings/payment_methods).



1598
1599
1600
# File 'lib/stripe/resources/payment_link.rb', line 1598

def payment_method_types
  @payment_method_types
end

#restrictionsObject

Settings that restrict the usage of a payment link.



1601
1602
1603
# File 'lib/stripe/resources/payment_link.rb', line 1601

def restrictions
  @restrictions
end

#shipping_address_collectionObject

Configuration for collecting the customer’s shipping address.



1604
1605
1606
# File 'lib/stripe/resources/payment_link.rb', line 1604

def shipping_address_collection
  @shipping_address_collection
end

#submit_typeObject

Describes the type of transaction being performed in order to customize relevant text on the page, such as the submit button. Changing this value will also affect the hostname in the [url](stripe.com/docs/api/payment_links/payment_links/object#url) property (example: ‘donate.stripe.com`).



1607
1608
1609
# File 'lib/stripe/resources/payment_link.rb', line 1607

def submit_type
  @submit_type
end

#subscription_dataObject

When creating a subscription, the specified configuration data will be used. There must be at least one line item with a recurring price to use ‘subscription_data`.



1610
1611
1612
# File 'lib/stripe/resources/payment_link.rb', line 1610

def subscription_data
  @subscription_data
end

#tax_id_collectionObject

Controls tax ID collection during checkout.



1613
1614
1615
# File 'lib/stripe/resources/payment_link.rb', line 1613

def tax_id_collection
  @tax_id_collection
end