Class: Stripe::PaymentLink::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLink::UpdateParams
- Defined in:
- lib/stripe/resources/payment_link.rb
Defined Under Namespace
Classes: AfterCompletion, AutomaticTax, CustomField, CustomText, InvoiceCreation, LineItem, PaymentIntentData, PhoneNumberCollection, Restrictions, ShippingAddressCollection, SubscriptionData, TaxIdCollection
Instance Attribute Summary collapse
-
#active ⇒ Object
Whether the payment link’s ‘url` is active.
-
#after_completion ⇒ Object
Behavior after the purchase is complete.
-
#allow_promotion_codes ⇒ Object
Enables user redeemable promotion codes.
-
#automatic_tax ⇒ Object
Configuration for automatic tax collection.
-
#billing_address_collection ⇒ Object
Configuration for collecting the customer’s billing address.
-
#custom_fields ⇒ Object
Collect additional information from your customer using custom fields.
-
#custom_text ⇒ Object
Display additional text for your customers using custom text.
-
#customer_creation ⇒ Object
Configures whether [checkout sessions](stripe.com/docs/api/checkout/sessions) created by this payment link create a [Customer](stripe.com/docs/api/customers).
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#inactive_message ⇒ Object
The custom message to be displayed to a customer when a payment link is no longer active.
-
#invoice_creation ⇒ Object
Generate a post-purchase Invoice for one-time payments.
-
#line_items ⇒ Object
The line items representing what is being sold.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment_intent_data ⇒ Object
A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in ‘payment` mode.
-
#payment_method_collection ⇒ Object
Specify whether Checkout should collect a payment method.
-
#payment_method_types ⇒ Object
The list of payment method types that customers can use.
-
#phone_number_collection ⇒ Object
Controls phone number collection settings during checkout.
-
#restrictions ⇒ Object
Settings that restrict the usage of a payment link.
-
#shipping_address_collection ⇒ Object
Configuration for collecting the customer’s shipping address.
-
#submit_type ⇒ Object
Describes the type of transaction being performed in order to customize relevant text on the page, such as the submit button.
-
#subscription_data ⇒ Object
When creating a subscription, the specified configuration data will be used.
-
#tax_id_collection ⇒ Object
Controls tax ID collection during checkout.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, after_completion: nil, allow_promotion_codes: nil, automatic_tax: nil, billing_address_collection: nil, custom_fields: nil, custom_text: nil, customer_creation: nil, expand: nil, inactive_message: nil, invoice_creation: nil, line_items: nil, metadata: nil, payment_intent_data: nil, payment_method_collection: nil, payment_method_types: nil, phone_number_collection: nil, restrictions: nil, shipping_address_collection: nil, submit_type: nil, subscription_data: nil, tax_id_collection: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 |
# File 'lib/stripe/resources/payment_link.rb', line 1450 def initialize( active: nil, after_completion: nil, allow_promotion_codes: nil, automatic_tax: nil, billing_address_collection: nil, custom_fields: nil, custom_text: nil, customer_creation: nil, expand: nil, inactive_message: nil, invoice_creation: nil, line_items: nil, metadata: nil, payment_intent_data: nil, payment_method_collection: nil, payment_method_types: nil, phone_number_collection: nil, restrictions: nil, shipping_address_collection: nil, submit_type: nil, subscription_data: nil, tax_id_collection: nil ) @active = active @after_completion = after_completion @allow_promotion_codes = allow_promotion_codes @automatic_tax = automatic_tax @billing_address_collection = billing_address_collection @custom_fields = custom_fields @custom_text = custom_text @customer_creation = customer_creation @expand = @inactive_message = @invoice_creation = invoice_creation @line_items = line_items @metadata = @payment_intent_data = payment_intent_data @payment_method_collection = payment_method_collection @payment_method_types = payment_method_types @phone_number_collection = phone_number_collection @restrictions = restrictions @shipping_address_collection = shipping_address_collection @submit_type = submit_type @subscription_data = subscription_data @tax_id_collection = tax_id_collection end |
Instance Attribute Details
#active ⇒ Object
Whether the payment link’s ‘url` is active. If `false`, customers visiting the URL will be shown a page saying that the link has been deactivated.
1400 1401 1402 |
# File 'lib/stripe/resources/payment_link.rb', line 1400 def active @active end |
#after_completion ⇒ Object
Behavior after the purchase is complete.
1402 1403 1404 |
# File 'lib/stripe/resources/payment_link.rb', line 1402 def after_completion @after_completion end |
#allow_promotion_codes ⇒ Object
Enables user redeemable promotion codes.
1404 1405 1406 |
# File 'lib/stripe/resources/payment_link.rb', line 1404 def allow_promotion_codes @allow_promotion_codes end |
#automatic_tax ⇒ Object
Configuration for automatic tax collection.
1406 1407 1408 |
# File 'lib/stripe/resources/payment_link.rb', line 1406 def automatic_tax @automatic_tax end |
#billing_address_collection ⇒ Object
Configuration for collecting the customer’s billing address. Defaults to ‘auto`.
1408 1409 1410 |
# File 'lib/stripe/resources/payment_link.rb', line 1408 def billing_address_collection @billing_address_collection end |
#custom_fields ⇒ Object
Collect additional information from your customer using custom fields. Up to 3 fields are supported.
1410 1411 1412 |
# File 'lib/stripe/resources/payment_link.rb', line 1410 def custom_fields @custom_fields end |
#custom_text ⇒ Object
Display additional text for your customers using custom text.
1412 1413 1414 |
# File 'lib/stripe/resources/payment_link.rb', line 1412 def custom_text @custom_text end |
#customer_creation ⇒ Object
Configures whether [checkout sessions](stripe.com/docs/api/checkout/sessions) created by this payment link create a [Customer](stripe.com/docs/api/customers).
1414 1415 1416 |
# File 'lib/stripe/resources/payment_link.rb', line 1414 def customer_creation @customer_creation end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1416 1417 1418 |
# File 'lib/stripe/resources/payment_link.rb', line 1416 def @expand end |
#inactive_message ⇒ Object
The custom message to be displayed to a customer when a payment link is no longer active.
1418 1419 1420 |
# File 'lib/stripe/resources/payment_link.rb', line 1418 def @inactive_message end |
#invoice_creation ⇒ Object
Generate a post-purchase Invoice for one-time payments.
1420 1421 1422 |
# File 'lib/stripe/resources/payment_link.rb', line 1420 def invoice_creation @invoice_creation end |
#line_items ⇒ Object
The line items representing what is being sold. Each line item represents an item being sold. Up to 20 line items are supported.
1422 1423 1424 |
# File 'lib/stripe/resources/payment_link.rb', line 1422 def line_items @line_items end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`. Metadata associated with this Payment Link will automatically be copied to [checkout sessions](stripe.com/docs/api/checkout/sessions) created by this payment link.
1424 1425 1426 |
# File 'lib/stripe/resources/payment_link.rb', line 1424 def @metadata end |
#payment_intent_data ⇒ Object
A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in ‘payment` mode.
1426 1427 1428 |
# File 'lib/stripe/resources/payment_link.rb', line 1426 def payment_intent_data @payment_intent_data end |
#payment_method_collection ⇒ Object
Specify whether Checkout should collect a payment method. When set to ‘if_required`, Checkout will not collect a payment method when the total due for the session is 0.This may occur if the Checkout Session includes a free trial or a discount.
Can only be set in ‘subscription` mode. Defaults to `always`.
If you’d like information on how to collect a payment method outside of Checkout, read the guide on [configuring subscriptions with a free trial](stripe.com/docs/payments/checkout/free-trials).
1432 1433 1434 |
# File 'lib/stripe/resources/payment_link.rb', line 1432 def payment_method_collection @payment_method_collection end |
#payment_method_types ⇒ Object
The list of payment method types that customers can use. Pass an empty string to enable dynamic payment methods that use your [payment method settings](dashboard.stripe.com/settings/payment_methods).
1434 1435 1436 |
# File 'lib/stripe/resources/payment_link.rb', line 1434 def payment_method_types @payment_method_types end |
#phone_number_collection ⇒ Object
Controls phone number collection settings during checkout.
We recommend that you review your privacy policy and check with your legal contacts.
1438 1439 1440 |
# File 'lib/stripe/resources/payment_link.rb', line 1438 def phone_number_collection @phone_number_collection end |
#restrictions ⇒ Object
Settings that restrict the usage of a payment link.
1440 1441 1442 |
# File 'lib/stripe/resources/payment_link.rb', line 1440 def restrictions @restrictions end |
#shipping_address_collection ⇒ Object
Configuration for collecting the customer’s shipping address.
1442 1443 1444 |
# File 'lib/stripe/resources/payment_link.rb', line 1442 def shipping_address_collection @shipping_address_collection end |
#submit_type ⇒ Object
Describes the type of transaction being performed in order to customize relevant text on the page, such as the submit button. Changing this value will also affect the hostname in the [url](stripe.com/docs/api/payment_links/payment_links/object#url) property (example: ‘donate.stripe.com`).
1444 1445 1446 |
# File 'lib/stripe/resources/payment_link.rb', line 1444 def submit_type @submit_type end |
#subscription_data ⇒ Object
When creating a subscription, the specified configuration data will be used. There must be at least one line item with a recurring price to use ‘subscription_data`.
1446 1447 1448 |
# File 'lib/stripe/resources/payment_link.rb', line 1446 def subscription_data @subscription_data end |
#tax_id_collection ⇒ Object
Controls tax ID collection during checkout.
1448 1449 1450 |
# File 'lib/stripe/resources/payment_link.rb', line 1448 def tax_id_collection @tax_id_collection end |