Class: Stripe::PaymentLink::UpdateParams::AutomaticTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLink::UpdateParams::AutomaticTax
- Defined in:
- lib/stripe/resources/payment_link.rb
Defined Under Namespace
Classes: Liability
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Set to ‘true` to [calculate tax automatically](docs.stripe.com/tax) using the customer’s location.
-
#liability ⇒ Object
The account that’s liable for tax.
Instance Method Summary collapse
-
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
constructor
A new instance of AutomaticTax.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
Returns a new instance of AutomaticTax.
1003 1004 1005 1006 |
# File 'lib/stripe/resources/payment_link.rb', line 1003 def initialize(enabled: nil, liability: nil) @enabled = enabled @liability = liability end |
Instance Attribute Details
#enabled ⇒ Object
Set to ‘true` to [calculate tax automatically](docs.stripe.com/tax) using the customer’s location.
Enabling this parameter causes the payment link to collect any billing address information necessary for tax calculation.
999 1000 1001 |
# File 'lib/stripe/resources/payment_link.rb', line 999 def enabled @enabled end |
#liability ⇒ Object
The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
1001 1002 1003 |
# File 'lib/stripe/resources/payment_link.rb', line 1001 def liability @liability end |