Class: Stripe::PaymentLink::UpdateParams::CustomField
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLink::UpdateParams::CustomField
- Defined in:
- lib/stripe/resources/payment_link.rb
Defined Under Namespace
Classes: Dropdown, Label, Numeric, Text
Instance Attribute Summary collapse
-
#dropdown ⇒ Object
Configuration for ‘type=dropdown` fields.
-
#key ⇒ Object
String of your choice that your integration can use to reconcile this field.
-
#label ⇒ Object
The label for the field, displayed to the customer.
-
#numeric ⇒ Object
Configuration for ‘type=numeric` fields.
-
#optional ⇒ Object
Whether the customer is required to complete the field before completing the Checkout Session.
-
#text ⇒ Object
Configuration for ‘type=text` fields.
-
#type ⇒ Object
The type of the field.
Instance Method Summary collapse
-
#initialize(dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil) ⇒ CustomField
constructor
A new instance of CustomField.
Methods inherited from RequestParams
Constructor Details
#initialize(dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil) ⇒ CustomField
Returns a new instance of CustomField.
1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 |
# File 'lib/stripe/resources/payment_link.rb', line 1222 def initialize( dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil ) @dropdown = dropdown @key = key @label = label @numeric = numeric @optional = optional @text = text @type = type end |
Instance Attribute Details
#dropdown ⇒ Object
Configuration for ‘type=dropdown` fields.
1208 1209 1210 |
# File 'lib/stripe/resources/payment_link.rb', line 1208 def dropdown @dropdown end |
#key ⇒ Object
String of your choice that your integration can use to reconcile this field. Must be unique to this field, alphanumeric, and up to 200 characters.
1210 1211 1212 |
# File 'lib/stripe/resources/payment_link.rb', line 1210 def key @key end |
#label ⇒ Object
The label for the field, displayed to the customer.
1212 1213 1214 |
# File 'lib/stripe/resources/payment_link.rb', line 1212 def label @label end |
#numeric ⇒ Object
Configuration for ‘type=numeric` fields.
1214 1215 1216 |
# File 'lib/stripe/resources/payment_link.rb', line 1214 def numeric @numeric end |
#optional ⇒ Object
Whether the customer is required to complete the field before completing the Checkout Session. Defaults to ‘false`.
1216 1217 1218 |
# File 'lib/stripe/resources/payment_link.rb', line 1216 def optional @optional end |
#text ⇒ Object
Configuration for ‘type=text` fields.
1218 1219 1220 |
# File 'lib/stripe/resources/payment_link.rb', line 1218 def text @text end |
#type ⇒ Object
The type of the field.
1220 1221 1222 |
# File 'lib/stripe/resources/payment_link.rb', line 1220 def type @type end |