Class: Stripe::PaymentLink::UpdateParams::CustomField

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Defined Under Namespace

Classes: Dropdown, Label, Numeric, Text

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil) ⇒ CustomField

Returns a new instance of CustomField.



1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
# File 'lib/stripe/resources/payment_link.rb', line 1080

def initialize(
  dropdown: nil,
  key: nil,
  label: nil,
  numeric: nil,
  optional: nil,
  text: nil,
  type: nil
)
  @dropdown = dropdown
  @key = key
  @label = label
  @numeric = numeric
  @optional = optional
  @text = text
  @type = type
end

Instance Attribute Details

Configuration for ‘type=dropdown` fields.



1066
1067
1068
# File 'lib/stripe/resources/payment_link.rb', line 1066

def dropdown
  @dropdown
end

#keyObject

String of your choice that your integration can use to reconcile this field. Must be unique to this field, alphanumeric, and up to 200 characters.



1068
1069
1070
# File 'lib/stripe/resources/payment_link.rb', line 1068

def key
  @key
end

#labelObject

The label for the field, displayed to the customer.



1070
1071
1072
# File 'lib/stripe/resources/payment_link.rb', line 1070

def label
  @label
end

#numericObject

Configuration for ‘type=numeric` fields.



1072
1073
1074
# File 'lib/stripe/resources/payment_link.rb', line 1072

def numeric
  @numeric
end

#optionalObject

Whether the customer is required to complete the field before completing the Checkout Session. Defaults to ‘false`.



1074
1075
1076
# File 'lib/stripe/resources/payment_link.rb', line 1074

def optional
  @optional
end

#textObject

Configuration for ‘type=text` fields.



1076
1077
1078
# File 'lib/stripe/resources/payment_link.rb', line 1076

def text
  @text
end

#typeObject

The type of the field.



1078
1079
1080
# File 'lib/stripe/resources/payment_link.rb', line 1078

def type
  @type
end