Class: Stripe::PaymentLink::UpdateParams::CustomField
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLink::UpdateParams::CustomField
- Defined in:
- lib/stripe/resources/payment_link.rb
Defined Under Namespace
Classes: Dropdown, Label, Numeric, Text
Instance Attribute Summary collapse
-
#dropdown ⇒ Object
Configuration for ‘type=dropdown` fields.
-
#key ⇒ Object
String of your choice that your integration can use to reconcile this field.
-
#label ⇒ Object
The label for the field, displayed to the customer.
-
#numeric ⇒ Object
Configuration for ‘type=numeric` fields.
-
#optional ⇒ Object
Whether the customer is required to complete the field before completing the Checkout Session.
-
#text ⇒ Object
Configuration for ‘type=text` fields.
-
#type ⇒ Object
The type of the field.
Instance Method Summary collapse
-
#initialize(dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil) ⇒ CustomField
constructor
A new instance of CustomField.
Methods inherited from RequestParams
Constructor Details
#initialize(dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil) ⇒ CustomField
Returns a new instance of CustomField.
1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 |
# File 'lib/stripe/resources/payment_link.rb', line 1213 def initialize( dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil ) @dropdown = dropdown @key = key @label = label @numeric = numeric @optional = optional @text = text @type = type end |
Instance Attribute Details
#dropdown ⇒ Object
Configuration for ‘type=dropdown` fields.
1193 1194 1195 |
# File 'lib/stripe/resources/payment_link.rb', line 1193 def dropdown @dropdown end |
#key ⇒ Object
String of your choice that your integration can use to reconcile this field. Must be unique to this field, alphanumeric, and up to 200 characters.
1196 1197 1198 |
# File 'lib/stripe/resources/payment_link.rb', line 1196 def key @key end |
#label ⇒ Object
The label for the field, displayed to the customer.
1199 1200 1201 |
# File 'lib/stripe/resources/payment_link.rb', line 1199 def label @label end |
#numeric ⇒ Object
Configuration for ‘type=numeric` fields.
1202 1203 1204 |
# File 'lib/stripe/resources/payment_link.rb', line 1202 def numeric @numeric end |
#optional ⇒ Object
Whether the customer is required to complete the field before completing the Checkout Session. Defaults to ‘false`.
1205 1206 1207 |
# File 'lib/stripe/resources/payment_link.rb', line 1205 def optional @optional end |
#text ⇒ Object
Configuration for ‘type=text` fields.
1208 1209 1210 |
# File 'lib/stripe/resources/payment_link.rb', line 1208 def text @text end |
#type ⇒ Object
The type of the field.
1211 1212 1213 |
# File 'lib/stripe/resources/payment_link.rb', line 1211 def type @type end |