Class: Stripe::PaymentLink::UpdateParams::CustomField::Dropdown::Option
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLink::UpdateParams::CustomField::Dropdown::Option
- Defined in:
- lib/stripe/resources/payment_link.rb
Instance Attribute Summary collapse
-
#label ⇒ Object
The label for the option, displayed to the customer.
-
#value ⇒ Object
The value for this option, not displayed to the customer, used by your integration to reconcile the option selected by the customer.
Instance Method Summary collapse
-
#initialize(label: nil, value: nil) ⇒ Option
constructor
A new instance of Option.
Methods inherited from RequestParams
Constructor Details
#initialize(label: nil, value: nil) ⇒ Option
Returns a new instance of Option.
1141 1142 1143 1144 |
# File 'lib/stripe/resources/payment_link.rb', line 1141 def initialize(label: nil, value: nil) @label = label @value = value end |
Instance Attribute Details
#label ⇒ Object
The label for the option, displayed to the customer. Up to 100 characters.
1136 1137 1138 |
# File 'lib/stripe/resources/payment_link.rb', line 1136 def label @label end |
#value ⇒ Object
The value for this option, not displayed to the customer, used by your integration to reconcile the option selected by the customer. Must be unique to this option, alphanumeric, and up to 100 characters.
1139 1140 1141 |
# File 'lib/stripe/resources/payment_link.rb', line 1139 def value @value end |