Class: Stripe::PaymentLink::UpdateParams::CustomField::Label
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLink::UpdateParams::CustomField::Label
- Defined in:
- lib/stripe/resources/payment_link.rb
Instance Attribute Summary collapse
-
#custom ⇒ Object
Custom text for the label, displayed to the customer.
-
#type ⇒ Object
The type of the label.
Instance Method Summary collapse
-
#initialize(custom: nil, type: nil) ⇒ Label
constructor
A new instance of Label.
Methods inherited from RequestParams
Constructor Details
#initialize(custom: nil, type: nil) ⇒ Label
Returns a new instance of Label.
1161 1162 1163 1164 |
# File 'lib/stripe/resources/payment_link.rb', line 1161 def initialize(custom: nil, type: nil) @custom = custom @type = type end |
Instance Attribute Details
#custom ⇒ Object
Custom text for the label, displayed to the customer. Up to 50 characters.
1156 1157 1158 |
# File 'lib/stripe/resources/payment_link.rb', line 1156 def custom @custom end |
#type ⇒ Object
The type of the label.
1159 1160 1161 |
# File 'lib/stripe/resources/payment_link.rb', line 1159 def type @type end |