Class: Stripe::PaymentLink::UpdateParams::InvoiceCreation::InvoiceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Defined Under Namespace

Classes: CustomField, Issuer, RenderingOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil) ⇒ InvoiceData

Returns a new instance of InvoiceData.



1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
# File 'lib/stripe/resources/payment_link.rb', line 1206

def initialize(
  account_tax_ids: nil,
  custom_fields: nil,
  description: nil,
  footer: nil,
  issuer: nil,
  metadata: nil,
  rendering_options: nil
)
  @account_tax_ids = 
  @custom_fields = custom_fields
  @description = description
  @footer = footer
  @issuer = issuer
  @metadata = 
  @rendering_options = rendering_options
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the invoice.



1192
1193
1194
# File 'lib/stripe/resources/payment_link.rb', line 1192

def 
  @account_tax_ids
end

#custom_fieldsObject

Default custom fields to be displayed on invoices for this customer.



1194
1195
1196
# File 'lib/stripe/resources/payment_link.rb', line 1194

def custom_fields
  @custom_fields
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1196
1197
1198
# File 'lib/stripe/resources/payment_link.rb', line 1196

def description
  @description
end

Default footer to be displayed on invoices for this customer.



1198
1199
1200
# File 'lib/stripe/resources/payment_link.rb', line 1198

def footer
  @footer
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



1200
1201
1202
# File 'lib/stripe/resources/payment_link.rb', line 1200

def issuer
  @issuer
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1202
1203
1204
# File 'lib/stripe/resources/payment_link.rb', line 1202

def 
  @metadata
end

#rendering_optionsObject

Default options for invoice PDF rendering for this customer.



1204
1205
1206
# File 'lib/stripe/resources/payment_link.rb', line 1204

def rendering_options
  @rendering_options
end