Class: Stripe::PaymentLink::UpdateParams::InvoiceCreation::InvoiceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Defined Under Namespace

Classes: CustomField, Issuer, RenderingOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil) ⇒ InvoiceData

Returns a new instance of InvoiceData.



1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
# File 'lib/stripe/resources/payment_link.rb', line 1350

def initialize(
  account_tax_ids: nil,
  custom_fields: nil,
  description: nil,
  footer: nil,
  issuer: nil,
  metadata: nil,
  rendering_options: nil
)
  @account_tax_ids = 
  @custom_fields = custom_fields
  @description = description
  @footer = footer
  @issuer = issuer
  @metadata = 
  @rendering_options = rendering_options
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the invoice.



1330
1331
1332
# File 'lib/stripe/resources/payment_link.rb', line 1330

def 
  @account_tax_ids
end

#custom_fieldsObject

Default custom fields to be displayed on invoices for this customer.



1333
1334
1335
# File 'lib/stripe/resources/payment_link.rb', line 1333

def custom_fields
  @custom_fields
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1336
1337
1338
# File 'lib/stripe/resources/payment_link.rb', line 1336

def description
  @description
end

Default footer to be displayed on invoices for this customer.



1339
1340
1341
# File 'lib/stripe/resources/payment_link.rb', line 1339

def footer
  @footer
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



1342
1343
1344
# File 'lib/stripe/resources/payment_link.rb', line 1342

def issuer
  @issuer
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1345
1346
1347
# File 'lib/stripe/resources/payment_link.rb', line 1345

def 
  @metadata
end

#rendering_optionsObject

Default options for invoice PDF rendering for this customer.



1348
1349
1350
# File 'lib/stripe/resources/payment_link.rb', line 1348

def rendering_options
  @rendering_options
end