Class: Stripe::PaymentLink::UpdateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLink::UpdateParams::LineItem
- Defined in:
- lib/stripe/resources/payment_link.rb
Defined Under Namespace
Classes: AdjustableQuantity
Instance Attribute Summary collapse
-
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during checkout.
-
#id ⇒ Object
The ID of an existing line item on the payment link.
-
#quantity ⇒ Object
The quantity of the line item being purchased.
Instance Method Summary collapse
-
#initialize(adjustable_quantity: nil, id: nil, quantity: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(adjustable_quantity: nil, id: nil, quantity: nil) ⇒ LineItem
Returns a new instance of LineItem.
1715 1716 1717 1718 1719 |
# File 'lib/stripe/resources/payment_link.rb', line 1715 def initialize(adjustable_quantity: nil, id: nil, quantity: nil) @adjustable_quantity = adjustable_quantity @id = id @quantity = quantity end |
Instance Attribute Details
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during checkout.
1709 1710 1711 |
# File 'lib/stripe/resources/payment_link.rb', line 1709 def adjustable_quantity @adjustable_quantity end |
#id ⇒ Object
The ID of an existing line item on the payment link.
1711 1712 1713 |
# File 'lib/stripe/resources/payment_link.rb', line 1711 def id @id end |
#quantity ⇒ Object
The quantity of the line item being purchased.
1713 1714 1715 |
# File 'lib/stripe/resources/payment_link.rb', line 1713 def quantity @quantity end |