Class: Stripe::PaymentLink::UpdateParams::LineItem::AdjustableQuantity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLink::UpdateParams::LineItem::AdjustableQuantity
- Defined in:
- lib/stripe/resources/payment_link.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative Integer.
-
#maximum ⇒ Object
The maximum quantity the customer can purchase.
-
#minimum ⇒ Object
The minimum quantity the customer can purchase.
Instance Method Summary collapse
-
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
constructor
A new instance of AdjustableQuantity.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
Returns a new instance of AdjustableQuantity.
1702 1703 1704 1705 1706 |
# File 'lib/stripe/resources/payment_link.rb', line 1702 def initialize(enabled: nil, maximum: nil, minimum: nil) @enabled = enabled @maximum = maximum @minimum = minimum end |
Instance Attribute Details
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative Integer.
1696 1697 1698 |
# File 'lib/stripe/resources/payment_link.rb', line 1696 def enabled @enabled end |
#maximum ⇒ Object
The maximum quantity the customer can purchase. By default this value is 99. You can specify a value up to 999999.
1698 1699 1700 |
# File 'lib/stripe/resources/payment_link.rb', line 1698 def maximum @maximum end |
#minimum ⇒ Object
The minimum quantity the customer can purchase. By default this value is 0. If there is only one item in the cart then that item’s quantity cannot go down to 0.
1700 1701 1702 |
# File 'lib/stripe/resources/payment_link.rb', line 1700 def minimum @minimum end |