Class: Stripe::PaymentLink::UpdateParams::LineItem::AdjustableQuantity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_link.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity

Returns a new instance of AdjustableQuantity.



1389
1390
1391
1392
1393
# File 'lib/stripe/resources/payment_link.rb', line 1389

def initialize(enabled: nil, maximum: nil, minimum: nil)
  @enabled = enabled
  @maximum = maximum
  @minimum = minimum
end

Instance Attribute Details

#enabledObject

Set to true if the quantity can be adjusted to any non-negative Integer.



1383
1384
1385
# File 'lib/stripe/resources/payment_link.rb', line 1383

def enabled
  @enabled
end

#maximumObject

The maximum quantity the customer can purchase. By default this value is 99. You can specify a value up to 999999.



1385
1386
1387
# File 'lib/stripe/resources/payment_link.rb', line 1385

def maximum
  @maximum
end

#minimumObject

The minimum quantity the customer can purchase. By default this value is 0. If there is only one item in the cart then that item’s quantity cannot go down to 0.



1387
1388
1389
# File 'lib/stripe/resources/payment_link.rb', line 1387

def minimum
  @minimum
end