Class: Stripe::PaymentLinkCreateParams::CustomField::Dropdown::Option
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkCreateParams::CustomField::Dropdown::Option
- Defined in:
- lib/stripe/params/payment_link_create_params.rb
Instance Attribute Summary collapse
-
#label ⇒ Object
The label for the option, displayed to the customer.
-
#value ⇒ Object
The value for this option, not displayed to the customer, used by your integration to reconcile the option selected by the customer.
Instance Method Summary collapse
-
#initialize(label: nil, value: nil) ⇒ Option
constructor
A new instance of Option.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(label: nil, value: nil) ⇒ Option
Returns a new instance of Option.
113 114 115 116 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 113 def initialize(label: nil, value: nil) @label = label @value = value end |
Instance Attribute Details
#label ⇒ Object
The label for the option, displayed to the customer. Up to 100 characters.
109 110 111 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 109 def label @label end |
#value ⇒ Object
The value for this option, not displayed to the customer, used by your integration to reconcile the option selected by the customer. Must be unique to this option, alphanumeric, and up to 100 characters.
111 112 113 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 111 def value @value end |