Class: Stripe::PaymentLinkCreateParams::LineItem::PriceData::ProductData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkCreateParams::LineItem::PriceData::ProductData
- Defined in:
- lib/stripe/params/payment_link_create_params.rb
Defined Under Namespace
Classes: TaxDetails
Instance Attribute Summary collapse
-
#description ⇒ Object
The product’s description, meant to be displayable to the customer.
-
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
-
#tax_code ⇒ Object
A [tax code](docs.stripe.com/tax/tax-categories) ID.
-
#tax_details ⇒ Object
Tax details for this product, including the [tax code](/tax/tax-codes) and an optional performance location.
-
#unit_label ⇒ Object
A label that represents units of this product.
Instance Method Summary collapse
-
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil, tax_details: nil, unit_label: nil) ⇒ ProductData
constructor
A new instance of ProductData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil, tax_details: nil, unit_label: nil) ⇒ ProductData
Returns a new instance of ProductData.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 372 def initialize( description: nil, images: nil, metadata: nil, name: nil, tax_code: nil, tax_details: nil, unit_label: nil ) @description = description @images = images @metadata = @name = name @tax_code = tax_code @tax_details = tax_details @unit_label = unit_label end |
Instance Attribute Details
#description ⇒ Object
The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.
358 359 360 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 358 def description @description end |
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
360 361 362 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 360 def images @images end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
362 363 364 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 362 def @metadata end |
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
364 365 366 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 364 def name @name end |
#tax_code ⇒ Object
A [tax code](docs.stripe.com/tax/tax-categories) ID.
366 367 368 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 366 def tax_code @tax_code end |
#tax_details ⇒ Object
Tax details for this product, including the [tax code](/tax/tax-codes) and an optional performance location.
368 369 370 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 368 def tax_details @tax_details end |
#unit_label ⇒ Object
A label that represents units of this product. When set, this will be included in customers’ receipts, invoices, Checkout, and the customer portal.
370 371 372 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 370 def unit_label @unit_label end |