Class: Stripe::PaymentLinkCreateParams::NameCollection::Business
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkCreateParams::NameCollection::Business
- Defined in:
- lib/stripe/params/payment_link_create_params.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Enable business name collection on the payment link.
-
#optional ⇒ Object
Whether the customer is required to provide their business name before checking out.
Instance Method Summary collapse
-
#initialize(enabled: nil, optional: nil) ⇒ Business
constructor
A new instance of Business.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, optional: nil) ⇒ Business
Returns a new instance of Business.
478 479 480 481 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 478 def initialize(enabled: nil, optional: nil) @enabled = enabled @optional = optional end |
Instance Attribute Details
#enabled ⇒ Object
Enable business name collection on the payment link. Defaults to ‘false`.
474 475 476 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 474 def enabled @enabled end |
#optional ⇒ Object
Whether the customer is required to provide their business name before checking out. Defaults to ‘false`.
476 477 478 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 476 def optional @optional end |