Class: Stripe::PaymentLinkCreateParams::NameCollection::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkCreateParams::NameCollection::Individual
- Defined in:
- lib/stripe/params/payment_link_create_params.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Enable individual name collection on the payment link.
-
#optional ⇒ Object
Whether the customer is required to provide their full name before checking out.
Instance Method Summary collapse
-
#initialize(enabled: nil, optional: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, optional: nil) ⇒ Individual
Returns a new instance of Individual.
471 472 473 474 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 471 def initialize(enabled: nil, optional: nil) @enabled = enabled @optional = optional end |
Instance Attribute Details
#enabled ⇒ Object
Enable individual name collection on the payment link. Defaults to ‘false`.
467 468 469 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 467 def enabled @enabled end |
#optional ⇒ Object
Whether the customer is required to provide their full name before checking out. Defaults to ‘false`.
469 470 471 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 469 def optional @optional end |