Class: Stripe::PaymentLinkCreateParams::OptionalItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_link_create_params.rb

Defined Under Namespace

Classes: AdjustableQuantity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(adjustable_quantity: nil, price: nil, quantity: nil) ⇒ OptionalItem

Returns a new instance of OptionalItem.



543
544
545
546
547
# File 'lib/stripe/params/payment_link_create_params.rb', line 543

def initialize(adjustable_quantity: nil, price: nil, quantity: nil)
  @adjustable_quantity = adjustable_quantity
  @price = price
  @quantity = quantity
end

Instance Attribute Details

#adjustable_quantityObject

When set, provides configuration for the customer to adjust the quantity of the line item created when a customer chooses to add this optional item to their order.



537
538
539
# File 'lib/stripe/params/payment_link_create_params.rb', line 537

def adjustable_quantity
  @adjustable_quantity
end

#priceObject

The ID of the [Price](docs.stripe.com/api/prices) or [Plan](docs.stripe.com/api/plans) object.



539
540
541
# File 'lib/stripe/params/payment_link_create_params.rb', line 539

def price
  @price
end

#quantityObject

The initial quantity of the line item created when a customer chooses to add this optional item to their order.



541
542
543
# File 'lib/stripe/params/payment_link_create_params.rb', line 541

def quantity
  @quantity
end