Class: Stripe::PaymentLinkCreateParams::OptionalItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkCreateParams::OptionalItem
- Defined in:
- lib/stripe/params/payment_link_create_params.rb
Defined Under Namespace
Classes: AdjustableQuantity
Instance Attribute Summary collapse
-
#adjustable_quantity ⇒ Object
When set, provides configuration for the customer to adjust the quantity of the line item created when a customer chooses to add this optional item to their order.
-
#price ⇒ Object
The ID of the [Price](stripe.com/docs/api/prices) or [Plan](stripe.com/docs/api/plans) object.
-
#quantity ⇒ Object
The initial quantity of the line item created when a customer chooses to add this optional item to their order.
Instance Method Summary collapse
-
#initialize(adjustable_quantity: nil, price: nil, quantity: nil) ⇒ OptionalItem
constructor
A new instance of OptionalItem.
Methods inherited from RequestParams
Constructor Details
#initialize(adjustable_quantity: nil, price: nil, quantity: nil) ⇒ OptionalItem
Returns a new instance of OptionalItem.
459 460 461 462 463 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 459 def initialize(adjustable_quantity: nil, price: nil, quantity: nil) @adjustable_quantity = adjustable_quantity @price = price @quantity = quantity end |
Instance Attribute Details
#adjustable_quantity ⇒ Object
When set, provides configuration for the customer to adjust the quantity of the line item created when a customer chooses to add this optional item to their order.
453 454 455 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 453 def adjustable_quantity @adjustable_quantity end |
#price ⇒ Object
The ID of the [Price](stripe.com/docs/api/prices) or [Plan](stripe.com/docs/api/plans) object.
455 456 457 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 455 def price @price end |
#quantity ⇒ Object
The initial quantity of the line item created when a customer chooses to add this optional item to their order.
457 458 459 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 457 def quantity @quantity end |