Class: Stripe::PaymentLinkCreateParams::OptionalItem::AdjustableQuantity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkCreateParams::OptionalItem::AdjustableQuantity
- Defined in:
- lib/stripe/params/payment_link_create_params.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative integer.
-
#maximum ⇒ Object
The maximum quantity of this item the customer can purchase.
-
#minimum ⇒ Object
The minimum quantity of this item the customer must purchase, if they choose to purchase it.
Instance Method Summary collapse
-
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
constructor
A new instance of AdjustableQuantity.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
Returns a new instance of AdjustableQuantity.
491 492 493 494 495 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 491 def initialize(enabled: nil, maximum: nil, minimum: nil) @enabled = enabled @maximum = maximum @minimum = minimum end |
Instance Attribute Details
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative integer.
485 486 487 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 485 def enabled @enabled end |
#maximum ⇒ Object
The maximum quantity of this item the customer can purchase. By default this value is 99.
487 488 489 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 487 def maximum @maximum end |
#minimum ⇒ Object
The minimum quantity of this item the customer must purchase, if they choose to purchase it. Because this item is optional, the customer will always be able to remove it from their order, even if the ‘minimum` configured here is greater than 0. By default this value is 0.
489 490 491 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 489 def minimum @minimum end |