Class: Stripe::PaymentLinkCreateParams::OptionalItem::AdjustableQuantity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_link_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity

Returns a new instance of AdjustableQuantity.



446
447
448
449
450
# File 'lib/stripe/params/payment_link_create_params.rb', line 446

def initialize(enabled: nil, maximum: nil, minimum: nil)
  @enabled = enabled
  @maximum = maximum
  @minimum = minimum
end

Instance Attribute Details

#enabledObject

Set to true if the quantity can be adjusted to any non-negative integer.



440
441
442
# File 'lib/stripe/params/payment_link_create_params.rb', line 440

def enabled
  @enabled
end

#maximumObject

The maximum quantity of this item the customer can purchase. By default this value is 99.



442
443
444
# File 'lib/stripe/params/payment_link_create_params.rb', line 442

def maximum
  @maximum
end

#minimumObject

The minimum quantity of this item the customer must purchase, if they choose to purchase it. Because this item is optional, the customer will always be able to remove it from their order, even if the ‘minimum` configured here is greater than 0. By default this value is 0.



444
445
446
# File 'lib/stripe/params/payment_link_create_params.rb', line 444

def minimum
  @minimum
end