Class: Stripe::PaymentLinkCreateParams::PaymentIntentData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_link_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(capture_method: nil, description: nil, metadata: nil, setup_future_usage: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_group: nil) ⇒ PaymentIntentData

Returns a new instance of PaymentIntentData.



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
# File 'lib/stripe/params/payment_link_create_params.rb', line 563

def initialize(
  capture_method: nil,
  description: nil,
  metadata: nil,
  setup_future_usage: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_group: nil
)
  @capture_method = capture_method
  @description = description
  @metadata = 
  @setup_future_usage = setup_future_usage
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_group = transfer_group
end

Instance Attribute Details

#capture_methodObject

Controls when the funds will be captured from the customer’s account.



537
538
539
# File 'lib/stripe/params/payment_link_create_params.rb', line 537

def capture_method
  @capture_method
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



539
540
541
# File 'lib/stripe/params/payment_link_create_params.rb', line 539

def description
  @description
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that will declaratively set metadata on [Payment Intents](docs.stripe.com/api/payment_intents) generated from this payment link. Unlike object-level metadata, this field is declarative. Updates will clear prior values.



541
542
543
# File 'lib/stripe/params/payment_link_create_params.rb', line 541

def 
  @metadata
end

#setup_future_usageObject

Indicates that you intend to [make future payments](docs.stripe.com/payments/payment-intents#future-usage) with the payment method collected by this Checkout Session.

When setting this to ‘on_session`, Checkout will show a notice to the customer that their payment details will be saved.

When setting this to ‘off_session`, Checkout will show a notice to the customer that their payment details will be saved and used for future payments.

If a Customer has been provided or Checkout creates a new Customer,Checkout will attach the payment method to the Customer.

If Checkout does not create a Customer, the payment method is not attached to a Customer. To reuse the payment method, you can retrieve it from the Checkout Session’s PaymentIntent.

When processing card payments, Checkout also uses ‘setup_future_usage` to dynamically optimize your payment flow and comply with regional legislation and network rules, such as SCA.



553
554
555
# File 'lib/stripe/params/payment_link_create_params.rb', line 553

def setup_future_usage
  @setup_future_usage
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).

Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.



557
558
559
# File 'lib/stripe/params/payment_link_create_params.rb', line 557

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



559
560
561
# File 'lib/stripe/params/payment_link_create_params.rb', line 559

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_groupObject

A string that identifies the resulting payment as part of a group. See the PaymentIntents [use case for connected accounts](docs.stripe.com/connect/separate-charges-and-transfers) for details.



561
562
563
# File 'lib/stripe/params/payment_link_create_params.rb', line 561

def transfer_group
  @transfer_group
end