Class: Stripe::PaymentLinkCreateParams::SubscriptionData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkCreateParams::SubscriptionData
- Defined in:
- lib/stripe/params/payment_link_create_params.rb
Defined Under Namespace
Classes: InvoiceSettings, TrialSettings
Instance Attribute Summary collapse
-
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer.
-
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that will declaratively set metadata on [Subscriptions](docs.stripe.com/api/subscriptions) generated from this payment link.
-
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time.
-
#trial_settings ⇒ Object
Settings related to subscription trials.
Instance Method Summary collapse
-
#initialize(description: nil, invoice_settings: nil, metadata: nil, trial_period_days: nil, trial_settings: nil) ⇒ SubscriptionData
constructor
A new instance of SubscriptionData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(description: nil, invoice_settings: nil, metadata: nil, trial_period_days: nil, trial_settings: nil) ⇒ SubscriptionData
Returns a new instance of SubscriptionData.
685 686 687 688 689 690 691 692 693 694 695 696 697 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 685 def initialize( description: nil, invoice_settings: nil, metadata: nil, trial_period_days: nil, trial_settings: nil ) @description = description @invoice_settings = invoice_settings @metadata = @trial_period_days = trial_period_days @trial_settings = trial_settings end |
Instance Attribute Details
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
675 676 677 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 675 def description @description end |
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
677 678 679 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 677 def invoice_settings @invoice_settings end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that will declaratively set metadata on [Subscriptions](docs.stripe.com/api/subscriptions) generated from this payment link. Unlike object-level metadata, this field is declarative. Updates will clear prior values.
679 680 681 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 679 def @metadata end |
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.
681 682 683 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 681 def trial_period_days @trial_period_days end |
#trial_settings ⇒ Object
Settings related to subscription trials.
683 684 685 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 683 def trial_settings @trial_settings end |