Class: Stripe::PaymentLinkCreateParams::SubscriptionData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_link_create_params.rb

Defined Under Namespace

Classes: InvoiceSettings, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(description: nil, invoice_settings: nil, metadata: nil, trial_period_days: nil, trial_settings: nil) ⇒ SubscriptionData

Returns a new instance of SubscriptionData.



675
676
677
678
679
680
681
682
683
684
685
686
687
# File 'lib/stripe/params/payment_link_create_params.rb', line 675

def initialize(
  description: nil,
  invoice_settings: nil,
  metadata: nil,
  trial_period_days: nil,
  trial_settings: nil
)
  @description = description
  @invoice_settings = invoice_settings
  @metadata = 
  @trial_period_days = trial_period_days
  @trial_settings = trial_settings
end

Instance Attribute Details

#descriptionObject

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



665
666
667
# File 'lib/stripe/params/payment_link_create_params.rb', line 665

def description
  @description
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



667
668
669
# File 'lib/stripe/params/payment_link_create_params.rb', line 667

def invoice_settings
  @invoice_settings
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that will declaratively set metadata on [Subscriptions](docs.stripe.com/api/subscriptions) generated from this payment link. Unlike object-level metadata, this field is declarative. Updates will clear prior values.



669
670
671
# File 'lib/stripe/params/payment_link_create_params.rb', line 669

def 
  @metadata
end

#trial_period_daysObject

Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.



671
672
673
# File 'lib/stripe/params/payment_link_create_params.rb', line 671

def trial_period_days
  @trial_period_days
end

#trial_settingsObject

Settings related to subscription trials.



673
674
675
# File 'lib/stripe/params/payment_link_create_params.rb', line 673

def trial_settings
  @trial_settings
end