Class: Stripe::PaymentLinkCreateParams::SubscriptionData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkCreateParams::SubscriptionData
- Defined in:
- lib/stripe/params/payment_link_create_params.rb
Defined Under Namespace
Classes: InvoiceSettings, TrialSettings
Instance Attribute Summary collapse
-
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer.
-
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that will declaratively set metadata on [Subscriptions](stripe.com/docs/api/subscriptions) generated from this payment link.
-
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time.
-
#trial_settings ⇒ Object
Settings related to subscription trials.
Instance Method Summary collapse
-
#initialize(description: nil, invoice_settings: nil, metadata: nil, trial_period_days: nil, trial_settings: nil) ⇒ SubscriptionData
constructor
A new instance of SubscriptionData.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, invoice_settings: nil, metadata: nil, trial_period_days: nil, trial_settings: nil) ⇒ SubscriptionData
Returns a new instance of SubscriptionData.
606 607 608 609 610 611 612 613 614 615 616 617 618 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 606 def initialize( description: nil, invoice_settings: nil, metadata: nil, trial_period_days: nil, trial_settings: nil ) @description = description @invoice_settings = invoice_settings @metadata = @trial_period_days = trial_period_days @trial_settings = trial_settings end |
Instance Attribute Details
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
596 597 598 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 596 def description @description end |
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
598 599 600 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 598 def invoice_settings @invoice_settings end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that will declaratively set metadata on [Subscriptions](stripe.com/docs/api/subscriptions) generated from this payment link. Unlike object-level metadata, this field is declarative. Updates will clear prior values.
600 601 602 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 600 def @metadata end |
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.
602 603 604 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 602 def trial_period_days @trial_period_days end |
#trial_settings ⇒ Object
Settings related to subscription trials.
604 605 606 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 604 def trial_settings @trial_settings end |