Class: Stripe::PaymentLinkCreateParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkCreateParams::TransferData
- Defined in:
- lib/stripe/params/payment_link_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds.
-
#destination ⇒ Object
If specified, successful charges will be attributed to the destination account for tax reporting, and the funds from charges will be transferred to the destination account.
Instance Method Summary collapse
-
#initialize(amount: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
711 712 713 714 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 711 def initialize(amount: nil, destination: nil) @amount = amount @destination = destination end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds.
704 705 706 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 704 def amount @amount end |
#destination ⇒ Object
If specified, successful charges will be attributed to the destination account for tax reporting, and the funds from charges will be transferred to the destination account. The ID of the resulting transfer will be returned on the successful charge’s ‘transfer` field.
709 710 711 |
# File 'lib/stripe/params/payment_link_create_params.rb', line 709 def destination @destination end |