Class: Stripe::PaymentLinkCreateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_link_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



687
688
689
690
# File 'lib/stripe/params/payment_link_create_params.rb', line 687

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when a charge succeeds.



680
681
682
# File 'lib/stripe/params/payment_link_create_params.rb', line 680

def amount
  @amount
end

#destinationObject

If specified, successful charges will be attributed to the destination account for tax reporting, and the funds from charges will be transferred to the destination account. The ID of the resulting transfer will be returned on the successful charge’s ‘transfer` field.



685
686
687
# File 'lib/stripe/params/payment_link_create_params.rb', line 685

def destination
  @destination
end