Class: Stripe::PaymentLinkService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkService::CreateParams
- Defined in:
- lib/stripe/services/payment_link_service.rb
Defined Under Namespace
Classes: AfterCompletion, AutomaticTax, ConsentCollection, CustomField, CustomText, InvoiceCreation, LineItem, PaymentIntentData, PhoneNumberCollection, Restrictions, ShippingAddressCollection, ShippingOption, SubscriptionData, TaxIdCollection, TransferData
Instance Attribute Summary collapse
-
#after_completion ⇒ Object
Behavior after the purchase is complete.
-
#allow_promotion_codes ⇒ Object
Enables user redeemable promotion codes.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#automatic_tax ⇒ Object
Configuration for automatic tax collection.
-
#billing_address_collection ⇒ Object
Configuration for collecting the customer’s billing address.
-
#consent_collection ⇒ Object
Configure fields to gather active consent from customers.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#custom_fields ⇒ Object
Collect additional information from your customer using custom fields.
-
#custom_text ⇒ Object
Display additional text for your customers using custom text.
-
#customer_creation ⇒ Object
Configures whether [checkout sessions](stripe.com/docs/api/checkout/sessions) created by this payment link create a [Customer](stripe.com/docs/api/customers).
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#inactive_message ⇒ Object
The custom message to be displayed to a customer when a payment link is no longer active.
-
#invoice_creation ⇒ Object
Generate a post-purchase Invoice for one-time payments.
-
#line_items ⇒ Object
The line items representing what is being sold.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#on_behalf_of ⇒ Object
The account on behalf of which to charge.
-
#payment_intent_data ⇒ Object
A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in ‘payment` mode.
-
#payment_method_collection ⇒ Object
Specify whether Checkout should collect a payment method.
-
#payment_method_types ⇒ Object
The list of payment method types that customers can use.
-
#phone_number_collection ⇒ Object
Controls phone number collection settings during checkout.
-
#restrictions ⇒ Object
Settings that restrict the usage of a payment link.
-
#shipping_address_collection ⇒ Object
Configuration for collecting the customer’s shipping address.
-
#shipping_options ⇒ Object
The shipping rate options to apply to [checkout sessions](stripe.com/docs/api/checkout/sessions) created by this payment link.
-
#submit_type ⇒ Object
Describes the type of transaction being performed in order to customize relevant text on the page, such as the submit button.
-
#subscription_data ⇒ Object
When creating a subscription, the specified configuration data will be used.
-
#tax_id_collection ⇒ Object
Controls tax ID collection during checkout.
-
#transfer_data ⇒ Object
The account (if any) the payments will be attributed to for tax reporting, and where funds from each payment will be transferred to.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(after_completion: nil, allow_promotion_codes: nil, application_fee_amount: nil, application_fee_percent: nil, automatic_tax: nil, billing_address_collection: nil, consent_collection: nil, currency: nil, custom_fields: nil, custom_text: nil, customer_creation: nil, expand: nil, inactive_message: nil, invoice_creation: nil, line_items: nil, metadata: nil, on_behalf_of: nil, payment_intent_data: nil, payment_method_collection: nil, payment_method_types: nil, phone_number_collection: nil, restrictions: nil, shipping_address_collection: nil, shipping_options: nil, submit_type: nil, subscription_data: nil, tax_id_collection: nil, transfer_data: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 |
# File 'lib/stripe/services/payment_link_service.rb', line 618 def initialize( after_completion: nil, allow_promotion_codes: nil, application_fee_amount: nil, application_fee_percent: nil, automatic_tax: nil, billing_address_collection: nil, consent_collection: nil, currency: nil, custom_fields: nil, custom_text: nil, customer_creation: nil, expand: nil, inactive_message: nil, invoice_creation: nil, line_items: nil, metadata: nil, on_behalf_of: nil, payment_intent_data: nil, payment_method_collection: nil, payment_method_types: nil, phone_number_collection: nil, restrictions: nil, shipping_address_collection: nil, shipping_options: nil, submit_type: nil, subscription_data: nil, tax_id_collection: nil, transfer_data: nil ) @after_completion = after_completion @allow_promotion_codes = allow_promotion_codes @application_fee_amount = application_fee_amount @application_fee_percent = application_fee_percent @automatic_tax = automatic_tax @billing_address_collection = billing_address_collection @consent_collection = @currency = currency @custom_fields = custom_fields @custom_text = custom_text @customer_creation = customer_creation @expand = @inactive_message = @invoice_creation = invoice_creation @line_items = line_items @metadata = @on_behalf_of = on_behalf_of @payment_intent_data = payment_intent_data @payment_method_collection = payment_method_collection @payment_method_types = payment_method_types @phone_number_collection = phone_number_collection @restrictions = restrictions @shipping_address_collection = shipping_address_collection @shipping_options = @submit_type = submit_type @subscription_data = subscription_data @tax_id_collection = tax_id_collection @transfer_data = transfer_data end |
Instance Attribute Details
#after_completion ⇒ Object
Behavior after the purchase is complete.
556 557 558 |
# File 'lib/stripe/services/payment_link_service.rb', line 556 def after_completion @after_completion end |
#allow_promotion_codes ⇒ Object
Enables user redeemable promotion codes.
558 559 560 |
# File 'lib/stripe/services/payment_link_service.rb', line 558 def allow_promotion_codes @allow_promotion_codes end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. Can only be applied when there are no line items with recurring prices.
560 561 562 |
# File 'lib/stripe/services/payment_link_service.rb', line 560 def application_fee_amount @application_fee_amount end |
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. There must be at least 1 line item with a recurring price to use this field.
562 563 564 |
# File 'lib/stripe/services/payment_link_service.rb', line 562 def application_fee_percent @application_fee_percent end |
#automatic_tax ⇒ Object
Configuration for automatic tax collection.
564 565 566 |
# File 'lib/stripe/services/payment_link_service.rb', line 564 def automatic_tax @automatic_tax end |
#billing_address_collection ⇒ Object
Configuration for collecting the customer’s billing address. Defaults to ‘auto`.
566 567 568 |
# File 'lib/stripe/services/payment_link_service.rb', line 566 def billing_address_collection @billing_address_collection end |
#consent_collection ⇒ Object
Configure fields to gather active consent from customers.
568 569 570 |
# File 'lib/stripe/services/payment_link_service.rb', line 568 def @consent_collection end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies) and supported by each line item’s price.
570 571 572 |
# File 'lib/stripe/services/payment_link_service.rb', line 570 def currency @currency end |
#custom_fields ⇒ Object
Collect additional information from your customer using custom fields. Up to 3 fields are supported.
572 573 574 |
# File 'lib/stripe/services/payment_link_service.rb', line 572 def custom_fields @custom_fields end |
#custom_text ⇒ Object
Display additional text for your customers using custom text.
574 575 576 |
# File 'lib/stripe/services/payment_link_service.rb', line 574 def custom_text @custom_text end |
#customer_creation ⇒ Object
Configures whether [checkout sessions](stripe.com/docs/api/checkout/sessions) created by this payment link create a [Customer](stripe.com/docs/api/customers).
576 577 578 |
# File 'lib/stripe/services/payment_link_service.rb', line 576 def customer_creation @customer_creation end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
578 579 580 |
# File 'lib/stripe/services/payment_link_service.rb', line 578 def @expand end |
#inactive_message ⇒ Object
The custom message to be displayed to a customer when a payment link is no longer active.
580 581 582 |
# File 'lib/stripe/services/payment_link_service.rb', line 580 def @inactive_message end |
#invoice_creation ⇒ Object
Generate a post-purchase Invoice for one-time payments.
582 583 584 |
# File 'lib/stripe/services/payment_link_service.rb', line 582 def invoice_creation @invoice_creation end |
#line_items ⇒ Object
The line items representing what is being sold. Each line item represents an item being sold. Up to 20 line items are supported.
584 585 586 |
# File 'lib/stripe/services/payment_link_service.rb', line 584 def line_items @line_items end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`. Metadata associated with this Payment Link will automatically be copied to [checkout sessions](stripe.com/docs/api/checkout/sessions) created by this payment link.
586 587 588 |
# File 'lib/stripe/services/payment_link_service.rb', line 586 def @metadata end |
#on_behalf_of ⇒ Object
The account on behalf of which to charge.
588 589 590 |
# File 'lib/stripe/services/payment_link_service.rb', line 588 def on_behalf_of @on_behalf_of end |
#payment_intent_data ⇒ Object
A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in ‘payment` mode.
590 591 592 |
# File 'lib/stripe/services/payment_link_service.rb', line 590 def payment_intent_data @payment_intent_data end |
#payment_method_collection ⇒ Object
Specify whether Checkout should collect a payment method. When set to ‘if_required`, Checkout will not collect a payment method when the total due for the session is 0.This may occur if the Checkout Session includes a free trial or a discount.
Can only be set in ‘subscription` mode. Defaults to `always`.
If you’d like information on how to collect a payment method outside of Checkout, read the guide on [configuring subscriptions with a free trial](stripe.com/docs/payments/checkout/free-trials).
596 597 598 |
# File 'lib/stripe/services/payment_link_service.rb', line 596 def payment_method_collection @payment_method_collection end |
#payment_method_types ⇒ Object
The list of payment method types that customers can use. If no value is passed, Stripe will dynamically show relevant payment methods from your [payment method settings](dashboard.stripe.com/settings/payment_methods) (20+ payment methods [supported](stripe.com/docs/payments/payment-methods/integration-options#payment-method-product-support)).
598 599 600 |
# File 'lib/stripe/services/payment_link_service.rb', line 598 def payment_method_types @payment_method_types end |
#phone_number_collection ⇒ Object
Controls phone number collection settings during checkout.
We recommend that you review your privacy policy and check with your legal contacts.
602 603 604 |
# File 'lib/stripe/services/payment_link_service.rb', line 602 def phone_number_collection @phone_number_collection end |
#restrictions ⇒ Object
Settings that restrict the usage of a payment link.
604 605 606 |
# File 'lib/stripe/services/payment_link_service.rb', line 604 def restrictions @restrictions end |
#shipping_address_collection ⇒ Object
Configuration for collecting the customer’s shipping address.
606 607 608 |
# File 'lib/stripe/services/payment_link_service.rb', line 606 def shipping_address_collection @shipping_address_collection end |
#shipping_options ⇒ Object
The shipping rate options to apply to [checkout sessions](stripe.com/docs/api/checkout/sessions) created by this payment link.
608 609 610 |
# File 'lib/stripe/services/payment_link_service.rb', line 608 def @shipping_options end |
#submit_type ⇒ Object
Describes the type of transaction being performed in order to customize relevant text on the page, such as the submit button. Changing this value will also affect the hostname in the [url](stripe.com/docs/api/payment_links/payment_links/object#url) property (example: ‘donate.stripe.com`).
610 611 612 |
# File 'lib/stripe/services/payment_link_service.rb', line 610 def submit_type @submit_type end |
#subscription_data ⇒ Object
When creating a subscription, the specified configuration data will be used. There must be at least one line item with a recurring price to use ‘subscription_data`.
612 613 614 |
# File 'lib/stripe/services/payment_link_service.rb', line 612 def subscription_data @subscription_data end |
#tax_id_collection ⇒ Object
Controls tax ID collection during checkout.
614 615 616 |
# File 'lib/stripe/services/payment_link_service.rb', line 614 def tax_id_collection @tax_id_collection end |
#transfer_data ⇒ Object
The account (if any) the payments will be attributed to for tax reporting, and where funds from each payment will be transferred to.
616 617 618 |
# File 'lib/stripe/services/payment_link_service.rb', line 616 def transfer_data @transfer_data end |