Class: Stripe::PaymentLinkService::CreateParams::CustomText
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkService::CreateParams::CustomText
- Defined in:
- lib/stripe/services/payment_link_service.rb
Defined Under Namespace
Classes: AfterSubmit, ShippingAddress, Submit, TermsOfServiceAcceptance
Instance Attribute Summary collapse
-
#after_submit ⇒ Object
Custom text that should be displayed after the payment confirmation button.
-
#shipping_address ⇒ Object
Custom text that should be displayed alongside shipping address collection.
-
#submit ⇒ Object
Custom text that should be displayed alongside the payment confirmation button.
-
#terms_of_service_acceptance ⇒ Object
Custom text that should be displayed in place of the default terms of service agreement text.
Instance Method Summary collapse
-
#initialize(after_submit: nil, shipping_address: nil, submit: nil, terms_of_service_acceptance: nil) ⇒ CustomText
constructor
A new instance of CustomText.
Methods inherited from RequestParams
Constructor Details
#initialize(after_submit: nil, shipping_address: nil, submit: nil, terms_of_service_acceptance: nil) ⇒ CustomText
Returns a new instance of CustomText.
277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/stripe/services/payment_link_service.rb', line 277 def initialize( after_submit: nil, shipping_address: nil, submit: nil, terms_of_service_acceptance: nil ) @after_submit = after_submit @shipping_address = shipping_address @submit = submit @terms_of_service_acceptance = terms_of_service_acceptance end |
Instance Attribute Details
#after_submit ⇒ Object
Custom text that should be displayed after the payment confirmation button.
266 267 268 |
# File 'lib/stripe/services/payment_link_service.rb', line 266 def after_submit @after_submit end |
#shipping_address ⇒ Object
Custom text that should be displayed alongside shipping address collection.
269 270 271 |
# File 'lib/stripe/services/payment_link_service.rb', line 269 def shipping_address @shipping_address end |
#submit ⇒ Object
Custom text that should be displayed alongside the payment confirmation button.
272 273 274 |
# File 'lib/stripe/services/payment_link_service.rb', line 272 def submit @submit end |
#terms_of_service_acceptance ⇒ Object
Custom text that should be displayed in place of the default terms of service agreement text.
275 276 277 |
# File 'lib/stripe/services/payment_link_service.rb', line 275 def terms_of_service_acceptance @terms_of_service_acceptance end |