Class: Stripe::PaymentLinkService::CreateParams::InvoiceCreation::InvoiceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_link_service.rb

Defined Under Namespace

Classes: CustomField, Issuer, RenderingOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil) ⇒ InvoiceData

Returns a new instance of InvoiceData.



347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/stripe/services/payment_link_service.rb', line 347

def initialize(
  account_tax_ids: nil,
  custom_fields: nil,
  description: nil,
  footer: nil,
  issuer: nil,
  metadata: nil,
  rendering_options: nil
)
  @account_tax_ids = 
  @custom_fields = custom_fields
  @description = description
  @footer = footer
  @issuer = issuer
  @metadata = 
  @rendering_options = rendering_options
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the invoice.



327
328
329
# File 'lib/stripe/services/payment_link_service.rb', line 327

def 
  @account_tax_ids
end

#custom_fieldsObject

Default custom fields to be displayed on invoices for this customer.



330
331
332
# File 'lib/stripe/services/payment_link_service.rb', line 330

def custom_fields
  @custom_fields
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



333
334
335
# File 'lib/stripe/services/payment_link_service.rb', line 333

def description
  @description
end

Default footer to be displayed on invoices for this customer.



336
337
338
# File 'lib/stripe/services/payment_link_service.rb', line 336

def footer
  @footer
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



339
340
341
# File 'lib/stripe/services/payment_link_service.rb', line 339

def issuer
  @issuer
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



342
343
344
# File 'lib/stripe/services/payment_link_service.rb', line 342

def 
  @metadata
end

#rendering_optionsObject

Default options for invoice PDF rendering for this customer.



345
346
347
# File 'lib/stripe/services/payment_link_service.rb', line 345

def rendering_options
  @rendering_options
end