Class: Stripe::PaymentLinkService::CreateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkService::CreateParams::LineItem
- Defined in:
- lib/stripe/services/payment_link_service.rb
Defined Under Namespace
Classes: AdjustableQuantity
Instance Attribute Summary collapse
-
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during checkout.
-
#price ⇒ Object
The ID of the [Price](stripe.com/docs/api/prices) or [Plan](stripe.com/docs/api/plans) object.
-
#quantity ⇒ Object
The quantity of the line item being purchased.
Instance Method Summary collapse
-
#initialize(adjustable_quantity: nil, price: nil, quantity: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(adjustable_quantity: nil, price: nil, quantity: nil) ⇒ LineItem
Returns a new instance of LineItem.
403 404 405 406 407 |
# File 'lib/stripe/services/payment_link_service.rb', line 403 def initialize(adjustable_quantity: nil, price: nil, quantity: nil) @adjustable_quantity = adjustable_quantity @price = price @quantity = quantity end |
Instance Attribute Details
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during checkout.
395 396 397 |
# File 'lib/stripe/services/payment_link_service.rb', line 395 def adjustable_quantity @adjustable_quantity end |
#price ⇒ Object
The ID of the [Price](stripe.com/docs/api/prices) or [Plan](stripe.com/docs/api/plans) object.
398 399 400 |
# File 'lib/stripe/services/payment_link_service.rb', line 398 def price @price end |
#quantity ⇒ Object
The quantity of the line item being purchased.
401 402 403 |
# File 'lib/stripe/services/payment_link_service.rb', line 401 def quantity @quantity end |