Class: Stripe::PaymentLinkService::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/payment_link_service.rb

Defined Under Namespace

Classes: AfterCompletion, AutomaticTax, CustomField, CustomText, InvoiceCreation, LineItem, PaymentIntentData, Restrictions, ShippingAddressCollection, SubscriptionData, TaxIdCollection

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, after_completion: nil, allow_promotion_codes: nil, automatic_tax: nil, billing_address_collection: nil, custom_fields: nil, custom_text: nil, customer_creation: nil, expand: nil, inactive_message: nil, invoice_creation: nil, line_items: nil, metadata: nil, payment_intent_data: nil, payment_method_collection: nil, payment_method_types: nil, restrictions: nil, shipping_address_collection: nil, submit_type: nil, subscription_data: nil, tax_id_collection: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
# File 'lib/stripe/services/payment_link_service.rb', line 1309

def initialize(
  active: nil,
  after_completion: nil,
  allow_promotion_codes: nil,
  automatic_tax: nil,
  billing_address_collection: nil,
  custom_fields: nil,
  custom_text: nil,
  customer_creation: nil,
  expand: nil,
  inactive_message: nil,
  invoice_creation: nil,
  line_items: nil,
  metadata: nil,
  payment_intent_data: nil,
  payment_method_collection: nil,
  payment_method_types: nil,
  restrictions: nil,
  shipping_address_collection: nil,
  submit_type: nil,
  subscription_data: nil,
  tax_id_collection: nil
)
  @active = active
  @after_completion = after_completion
  @allow_promotion_codes = allow_promotion_codes
  @automatic_tax = automatic_tax
  @billing_address_collection = billing_address_collection
  @custom_fields = custom_fields
  @custom_text = custom_text
  @customer_creation = customer_creation
  @expand = expand
  @inactive_message = inactive_message
  @invoice_creation = invoice_creation
  @line_items = line_items
  @metadata = 
  @payment_intent_data = payment_intent_data
  @payment_method_collection = payment_method_collection
  @payment_method_types = payment_method_types
  @restrictions = restrictions
  @shipping_address_collection = shipping_address_collection
  @submit_type = submit_type
  @subscription_data = subscription_data
  @tax_id_collection = tax_id_collection
end

Instance Attribute Details

#activeObject

Whether the payment link’s ‘url` is active. If `false`, customers visiting the URL will be shown a page saying that the link has been deactivated.



1243
1244
1245
# File 'lib/stripe/services/payment_link_service.rb', line 1243

def active
  @active
end

#after_completionObject

Behavior after the purchase is complete.



1246
1247
1248
# File 'lib/stripe/services/payment_link_service.rb', line 1246

def after_completion
  @after_completion
end

#allow_promotion_codesObject

Enables user redeemable promotion codes.



1249
1250
1251
# File 'lib/stripe/services/payment_link_service.rb', line 1249

def allow_promotion_codes
  @allow_promotion_codes
end

#automatic_taxObject

Configuration for automatic tax collection.



1252
1253
1254
# File 'lib/stripe/services/payment_link_service.rb', line 1252

def automatic_tax
  @automatic_tax
end

#billing_address_collectionObject

Configuration for collecting the customer’s billing address. Defaults to ‘auto`.



1255
1256
1257
# File 'lib/stripe/services/payment_link_service.rb', line 1255

def billing_address_collection
  @billing_address_collection
end

#custom_fieldsObject

Collect additional information from your customer using custom fields. Up to 3 fields are supported.



1258
1259
1260
# File 'lib/stripe/services/payment_link_service.rb', line 1258

def custom_fields
  @custom_fields
end

#custom_textObject

Display additional text for your customers using custom text.



1261
1262
1263
# File 'lib/stripe/services/payment_link_service.rb', line 1261

def custom_text
  @custom_text
end

#customer_creationObject

Configures whether [checkout sessions](stripe.com/docs/api/checkout/sessions) created by this payment link create a [Customer](stripe.com/docs/api/customers).



1264
1265
1266
# File 'lib/stripe/services/payment_link_service.rb', line 1264

def customer_creation
  @customer_creation
end

#expandObject

Specifies which fields in the response should be expanded.



1267
1268
1269
# File 'lib/stripe/services/payment_link_service.rb', line 1267

def expand
  @expand
end

#inactive_messageObject

The custom message to be displayed to a customer when a payment link is no longer active.



1270
1271
1272
# File 'lib/stripe/services/payment_link_service.rb', line 1270

def inactive_message
  @inactive_message
end

#invoice_creationObject

Generate a post-purchase Invoice for one-time payments.



1273
1274
1275
# File 'lib/stripe/services/payment_link_service.rb', line 1273

def invoice_creation
  @invoice_creation
end

#line_itemsObject

The line items representing what is being sold. Each line item represents an item being sold. Up to 20 line items are supported.



1276
1277
1278
# File 'lib/stripe/services/payment_link_service.rb', line 1276

def line_items
  @line_items
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`. Metadata associated with this Payment Link will automatically be copied to [checkout sessions](stripe.com/docs/api/checkout/sessions) created by this payment link.



1279
1280
1281
# File 'lib/stripe/services/payment_link_service.rb', line 1279

def 
  @metadata
end

#payment_intent_dataObject

A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in ‘payment` mode.



1282
1283
1284
# File 'lib/stripe/services/payment_link_service.rb', line 1282

def payment_intent_data
  @payment_intent_data
end

#payment_method_collectionObject

Specify whether Checkout should collect a payment method. When set to ‘if_required`, Checkout will not collect a payment method when the total due for the session is 0.This may occur if the Checkout Session includes a free trial or a discount.

Can only be set in ‘subscription` mode. Defaults to `always`.

If you’d like information on how to collect a payment method outside of Checkout, read the guide on [configuring subscriptions with a free trial](stripe.com/docs/payments/checkout/free-trials).



1289
1290
1291
# File 'lib/stripe/services/payment_link_service.rb', line 1289

def payment_method_collection
  @payment_method_collection
end

#payment_method_typesObject

The list of payment method types that customers can use. Pass an empty string to enable dynamic payment methods that use your [payment method settings](dashboard.stripe.com/settings/payment_methods).



1292
1293
1294
# File 'lib/stripe/services/payment_link_service.rb', line 1292

def payment_method_types
  @payment_method_types
end

#restrictionsObject

Settings that restrict the usage of a payment link.



1295
1296
1297
# File 'lib/stripe/services/payment_link_service.rb', line 1295

def restrictions
  @restrictions
end

#shipping_address_collectionObject

Configuration for collecting the customer’s shipping address.



1298
1299
1300
# File 'lib/stripe/services/payment_link_service.rb', line 1298

def shipping_address_collection
  @shipping_address_collection
end

#submit_typeObject

Describes the type of transaction being performed in order to customize relevant text on the page, such as the submit button. Changing this value will also affect the hostname in the [url](stripe.com/docs/api/payment_links/payment_links/object#url) property (example: ‘donate.stripe.com`).



1301
1302
1303
# File 'lib/stripe/services/payment_link_service.rb', line 1301

def submit_type
  @submit_type
end

#subscription_dataObject

When creating a subscription, the specified configuration data will be used. There must be at least one line item with a recurring price to use ‘subscription_data`.



1304
1305
1306
# File 'lib/stripe/services/payment_link_service.rb', line 1304

def subscription_data
  @subscription_data
end

#tax_id_collectionObject

Controls tax ID collection during checkout.



1307
1308
1309
# File 'lib/stripe/services/payment_link_service.rb', line 1307

def tax_id_collection
  @tax_id_collection
end