Class: Stripe::PaymentLinkService::UpdateParams::CustomField
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkService::UpdateParams::CustomField
- Defined in:
- lib/stripe/services/payment_link_service.rb
Defined Under Namespace
Classes: Dropdown, Label, Numeric, Text
Instance Attribute Summary collapse
-
#dropdown ⇒ Object
Configuration for ‘type=dropdown` fields.
-
#key ⇒ Object
String of your choice that your integration can use to reconcile this field.
-
#label ⇒ Object
The label for the field, displayed to the customer.
-
#numeric ⇒ Object
Configuration for ‘type=numeric` fields.
-
#optional ⇒ Object
Whether the customer is required to complete the field before completing the Checkout Session.
-
#text ⇒ Object
Configuration for ‘type=text` fields.
-
#type ⇒ Object
The type of the field.
Instance Method Summary collapse
-
#initialize(dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil) ⇒ CustomField
constructor
A new instance of CustomField.
Methods inherited from RequestParams
Constructor Details
#initialize(dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil) ⇒ CustomField
Returns a new instance of CustomField.
907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 |
# File 'lib/stripe/services/payment_link_service.rb', line 907 def initialize( dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil ) @dropdown = dropdown @key = key @label = label @numeric = numeric @optional = optional @text = text @type = type end |
Instance Attribute Details
#dropdown ⇒ Object
Configuration for ‘type=dropdown` fields.
887 888 889 |
# File 'lib/stripe/services/payment_link_service.rb', line 887 def dropdown @dropdown end |
#key ⇒ Object
String of your choice that your integration can use to reconcile this field. Must be unique to this field, alphanumeric, and up to 200 characters.
890 891 892 |
# File 'lib/stripe/services/payment_link_service.rb', line 890 def key @key end |
#label ⇒ Object
The label for the field, displayed to the customer.
893 894 895 |
# File 'lib/stripe/services/payment_link_service.rb', line 893 def label @label end |
#numeric ⇒ Object
Configuration for ‘type=numeric` fields.
896 897 898 |
# File 'lib/stripe/services/payment_link_service.rb', line 896 def numeric @numeric end |
#optional ⇒ Object
Whether the customer is required to complete the field before completing the Checkout Session. Defaults to ‘false`.
899 900 901 |
# File 'lib/stripe/services/payment_link_service.rb', line 899 def optional @optional end |
#text ⇒ Object
Configuration for ‘type=text` fields.
902 903 904 |
# File 'lib/stripe/services/payment_link_service.rb', line 902 def text @text end |
#type ⇒ Object
The type of the field.
905 906 907 |
# File 'lib/stripe/services/payment_link_service.rb', line 905 def type @type end |