Class: Stripe::PaymentLinkService::UpdateParams::CustomField::Dropdown::Option
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkService::UpdateParams::CustomField::Dropdown::Option
- Defined in:
- lib/stripe/services/payment_link_service.rb
Instance Attribute Summary collapse
-
#label ⇒ Object
The label for the option, displayed to the customer.
-
#value ⇒ Object
The value for this option, not displayed to the customer, used by your integration to reconcile the option selected by the customer.
Instance Method Summary collapse
-
#initialize(label: nil, value: nil) ⇒ Option
constructor
A new instance of Option.
Methods inherited from RequestParams
Constructor Details
#initialize(label: nil, value: nil) ⇒ Option
Returns a new instance of Option.
835 836 837 838 |
# File 'lib/stripe/services/payment_link_service.rb', line 835 def initialize(label: nil, value: nil) @label = label @value = value end |
Instance Attribute Details
#label ⇒ Object
The label for the option, displayed to the customer. Up to 100 characters.
830 831 832 |
# File 'lib/stripe/services/payment_link_service.rb', line 830 def label @label end |
#value ⇒ Object
The value for this option, not displayed to the customer, used by your integration to reconcile the option selected by the customer. Must be unique to this option, alphanumeric, and up to 100 characters.
833 834 835 |
# File 'lib/stripe/services/payment_link_service.rb', line 833 def value @value end |