Class: Stripe::PaymentLinkService::UpdateParams::CustomText

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_link_service.rb

Defined Under Namespace

Classes: AfterSubmit, ShippingAddress, Submit, TermsOfServiceAcceptance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(after_submit: nil, shipping_address: nil, submit: nil, terms_of_service_acceptance: nil) ⇒ CustomText

Returns a new instance of CustomText.



1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
# File 'lib/stripe/services/payment_link_service.rb', line 1007

def initialize(
  after_submit: nil,
  shipping_address: nil,
  submit: nil,
  terms_of_service_acceptance: nil
)
  @after_submit = after_submit
  @shipping_address = shipping_address
  @submit = submit
  @terms_of_service_acceptance = terms_of_service_acceptance
end

Instance Attribute Details

#after_submitObject

Custom text that should be displayed after the payment confirmation button.



999
1000
1001
# File 'lib/stripe/services/payment_link_service.rb', line 999

def after_submit
  @after_submit
end

#shipping_addressObject

Custom text that should be displayed alongside shipping address collection.



1001
1002
1003
# File 'lib/stripe/services/payment_link_service.rb', line 1001

def shipping_address
  @shipping_address
end

#submitObject

Custom text that should be displayed alongside the payment confirmation button.



1003
1004
1005
# File 'lib/stripe/services/payment_link_service.rb', line 1003

def submit
  @submit
end

#terms_of_service_acceptanceObject

Custom text that should be displayed in place of the default terms of service agreement text.



1005
1006
1007
# File 'lib/stripe/services/payment_link_service.rb', line 1005

def terms_of_service_acceptance
  @terms_of_service_acceptance
end