Class: Stripe::PaymentLinkService::UpdateParams::CustomText
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkService::UpdateParams::CustomText
- Defined in:
- lib/stripe/services/payment_link_service.rb
Defined Under Namespace
Classes: AfterSubmit, ShippingAddress, Submit, TermsOfServiceAcceptance
Instance Attribute Summary collapse
-
#after_submit ⇒ Object
Custom text that should be displayed after the payment confirmation button.
-
#shipping_address ⇒ Object
Custom text that should be displayed alongside shipping address collection.
-
#submit ⇒ Object
Custom text that should be displayed alongside the payment confirmation button.
-
#terms_of_service_acceptance ⇒ Object
Custom text that should be displayed in place of the default terms of service agreement text.
Instance Method Summary collapse
-
#initialize(after_submit: nil, shipping_address: nil, submit: nil, terms_of_service_acceptance: nil) ⇒ CustomText
constructor
A new instance of CustomText.
Methods inherited from RequestParams
Constructor Details
#initialize(after_submit: nil, shipping_address: nil, submit: nil, terms_of_service_acceptance: nil) ⇒ CustomText
Returns a new instance of CustomText.
934 935 936 937 938 939 940 941 942 943 944 |
# File 'lib/stripe/services/payment_link_service.rb', line 934 def initialize( after_submit: nil, shipping_address: nil, submit: nil, terms_of_service_acceptance: nil ) @after_submit = after_submit @shipping_address = shipping_address @submit = submit @terms_of_service_acceptance = terms_of_service_acceptance end |
Instance Attribute Details
#after_submit ⇒ Object
Custom text that should be displayed after the payment confirmation button.
926 927 928 |
# File 'lib/stripe/services/payment_link_service.rb', line 926 def after_submit @after_submit end |
#shipping_address ⇒ Object
Custom text that should be displayed alongside shipping address collection.
928 929 930 |
# File 'lib/stripe/services/payment_link_service.rb', line 928 def shipping_address @shipping_address end |
#submit ⇒ Object
Custom text that should be displayed alongside the payment confirmation button.
930 931 932 |
# File 'lib/stripe/services/payment_link_service.rb', line 930 def submit @submit end |
#terms_of_service_acceptance ⇒ Object
Custom text that should be displayed in place of the default terms of service agreement text.
932 933 934 |
# File 'lib/stripe/services/payment_link_service.rb', line 932 def terms_of_service_acceptance @terms_of_service_acceptance end |