Class: Stripe::PaymentLinkService::UpdateParams::InvoiceCreation::InvoiceData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkService::UpdateParams::InvoiceCreation::InvoiceData
- Defined in:
- lib/stripe/services/payment_link_service.rb
Defined Under Namespace
Classes: CustomField, Issuer, RenderingOptions
Instance Attribute Summary collapse
-
#account_tax_ids ⇒ Object
The account tax IDs associated with the invoice.
-
#custom_fields ⇒ Object
Default custom fields to be displayed on invoices for this customer.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#footer ⇒ Object
Default footer to be displayed on invoices for this customer.
-
#issuer ⇒ Object
The connected account that issues the invoice.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#rendering_options ⇒ Object
Default options for invoice PDF rendering for this customer.
Instance Method Summary collapse
-
#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil) ⇒ InvoiceData
constructor
A new instance of InvoiceData.
Methods inherited from RequestParams
Constructor Details
#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil) ⇒ InvoiceData
Returns a new instance of InvoiceData.
943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 |
# File 'lib/stripe/services/payment_link_service.rb', line 943 def initialize( account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil ) @account_tax_ids = account_tax_ids @custom_fields = custom_fields @description = description @footer = @issuer = issuer @metadata = @rendering_options = end |
Instance Attribute Details
#account_tax_ids ⇒ Object
The account tax IDs associated with the invoice.
929 930 931 |
# File 'lib/stripe/services/payment_link_service.rb', line 929 def account_tax_ids @account_tax_ids end |
#custom_fields ⇒ Object
Default custom fields to be displayed on invoices for this customer.
931 932 933 |
# File 'lib/stripe/services/payment_link_service.rb', line 931 def custom_fields @custom_fields end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
933 934 935 |
# File 'lib/stripe/services/payment_link_service.rb', line 933 def description @description end |
#footer ⇒ Object
Default footer to be displayed on invoices for this customer.
935 936 937 |
# File 'lib/stripe/services/payment_link_service.rb', line 935 def @footer end |
#issuer ⇒ Object
The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
937 938 939 |
# File 'lib/stripe/services/payment_link_service.rb', line 937 def issuer @issuer end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
939 940 941 |
# File 'lib/stripe/services/payment_link_service.rb', line 939 def @metadata end |
#rendering_options ⇒ Object
Default options for invoice PDF rendering for this customer.
941 942 943 |
# File 'lib/stripe/services/payment_link_service.rb', line 941 def @rendering_options end |