Class: Stripe::PaymentLinkService::UpdateParams::InvoiceCreation::InvoiceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_link_service.rb

Defined Under Namespace

Classes: CustomField, Issuer, RenderingOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil) ⇒ InvoiceData

Returns a new instance of InvoiceData.



1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
# File 'lib/stripe/services/payment_link_service.rb', line 1044

def initialize(
  account_tax_ids: nil,
  custom_fields: nil,
  description: nil,
  footer: nil,
  issuer: nil,
  metadata: nil,
  rendering_options: nil
)
  @account_tax_ids = 
  @custom_fields = custom_fields
  @description = description
  @footer = footer
  @issuer = issuer
  @metadata = 
  @rendering_options = rendering_options
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the invoice.



1024
1025
1026
# File 'lib/stripe/services/payment_link_service.rb', line 1024

def 
  @account_tax_ids
end

#custom_fieldsObject

Default custom fields to be displayed on invoices for this customer.



1027
1028
1029
# File 'lib/stripe/services/payment_link_service.rb', line 1027

def custom_fields
  @custom_fields
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1030
1031
1032
# File 'lib/stripe/services/payment_link_service.rb', line 1030

def description
  @description
end

Default footer to be displayed on invoices for this customer.



1033
1034
1035
# File 'lib/stripe/services/payment_link_service.rb', line 1033

def footer
  @footer
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



1036
1037
1038
# File 'lib/stripe/services/payment_link_service.rb', line 1036

def issuer
  @issuer
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1039
1040
1041
# File 'lib/stripe/services/payment_link_service.rb', line 1039

def 
  @metadata
end

#rendering_optionsObject

Default options for invoice PDF rendering for this customer.



1042
1043
1044
# File 'lib/stripe/services/payment_link_service.rb', line 1042

def rendering_options
  @rendering_options
end