Class: Stripe::PaymentLinkService::UpdateParams::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_link_service.rb

Defined Under Namespace

Classes: AdjustableQuantity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(adjustable_quantity: nil, id: nil, quantity: nil) ⇒ LineItem

Returns a new instance of LineItem.



1047
1048
1049
1050
1051
# File 'lib/stripe/services/payment_link_service.rb', line 1047

def initialize(adjustable_quantity: nil, id: nil, quantity: nil)
  @adjustable_quantity = adjustable_quantity
  @id = id
  @quantity = quantity
end

Instance Attribute Details

#adjustable_quantityObject

When set, provides configuration for this item’s quantity to be adjusted by the customer during checkout.



1041
1042
1043
# File 'lib/stripe/services/payment_link_service.rb', line 1041

def adjustable_quantity
  @adjustable_quantity
end

#idObject

The ID of an existing line item on the payment link.



1043
1044
1045
# File 'lib/stripe/services/payment_link_service.rb', line 1043

def id
  @id
end

#quantityObject

The quantity of the line item being purchased.



1045
1046
1047
# File 'lib/stripe/services/payment_link_service.rb', line 1045

def quantity
  @quantity
end