Class: Stripe::PaymentLinkService::UpdateParams::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_link_service.rb

Defined Under Namespace

Classes: AdjustableQuantity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(adjustable_quantity: nil, id: nil, quantity: nil) ⇒ LineItem

Returns a new instance of LineItem.



994
995
996
997
998
# File 'lib/stripe/services/payment_link_service.rb', line 994

def initialize(adjustable_quantity: nil, id: nil, quantity: nil)
  @adjustable_quantity = adjustable_quantity
  @id = id
  @quantity = quantity
end

Instance Attribute Details

#adjustable_quantityObject

When set, provides configuration for this item’s quantity to be adjusted by the customer during checkout.



988
989
990
# File 'lib/stripe/services/payment_link_service.rb', line 988

def adjustable_quantity
  @adjustable_quantity
end

#idObject

The ID of an existing line item on the payment link.



990
991
992
# File 'lib/stripe/services/payment_link_service.rb', line 990

def id
  @id
end

#quantityObject

The quantity of the line item being purchased.



992
993
994
# File 'lib/stripe/services/payment_link_service.rb', line 992

def quantity
  @quantity
end