Class: Stripe::PaymentLinkService::UpdateParams::LineItem::AdjustableQuantity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_link_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity

Returns a new instance of AdjustableQuantity.



1110
1111
1112
1113
1114
# File 'lib/stripe/services/payment_link_service.rb', line 1110

def initialize(enabled: nil, maximum: nil, minimum: nil)
  @enabled = enabled
  @maximum = maximum
  @minimum = minimum
end

Instance Attribute Details

#enabledObject

Set to true if the quantity can be adjusted to any non-negative Integer.



1104
1105
1106
# File 'lib/stripe/services/payment_link_service.rb', line 1104

def enabled
  @enabled
end

#maximumObject

The maximum quantity the customer can purchase. By default this value is 99. You can specify a value up to 999999.



1106
1107
1108
# File 'lib/stripe/services/payment_link_service.rb', line 1106

def maximum
  @maximum
end

#minimumObject

The minimum quantity the customer can purchase. By default this value is 0. If there is only one item in the cart then that item’s quantity cannot go down to 0.



1108
1109
1110
# File 'lib/stripe/services/payment_link_service.rb', line 1108

def minimum
  @minimum
end