Class: Stripe::PaymentLinkService::UpdateParams::LineItem::AdjustableQuantity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_link_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity

Returns a new instance of AdjustableQuantity.



1034
1035
1036
1037
1038
# File 'lib/stripe/services/payment_link_service.rb', line 1034

def initialize(enabled: nil, maximum: nil, minimum: nil)
  @enabled = enabled
  @maximum = maximum
  @minimum = minimum
end

Instance Attribute Details

#enabledObject

Set to true if the quantity can be adjusted to any non-negative Integer.



1028
1029
1030
# File 'lib/stripe/services/payment_link_service.rb', line 1028

def enabled
  @enabled
end

#maximumObject

The maximum quantity the customer can purchase. By default this value is 99. You can specify a value up to 999.



1030
1031
1032
# File 'lib/stripe/services/payment_link_service.rb', line 1030

def maximum
  @maximum
end

#minimumObject

The minimum quantity the customer can purchase. By default this value is 0. If there is only one item in the cart then that item’s quantity cannot go down to 0.



1032
1033
1034
# File 'lib/stripe/services/payment_link_service.rb', line 1032

def minimum
  @minimum
end