Class: Stripe::PaymentLinkService::UpdateParams::LineItem::AdjustableQuantity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_link_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity

Returns a new instance of AdjustableQuantity.



1085
1086
1087
1088
1089
# File 'lib/stripe/services/payment_link_service.rb', line 1085

def initialize(enabled: nil, maximum: nil, minimum: nil)
  @enabled = enabled
  @maximum = maximum
  @minimum = minimum
end

Instance Attribute Details

#enabledObject

Set to true if the quantity can be adjusted to any non-negative Integer.



1077
1078
1079
# File 'lib/stripe/services/payment_link_service.rb', line 1077

def enabled
  @enabled
end

#maximumObject

The maximum quantity the customer can purchase. By default this value is 99. You can specify a value up to 999.



1080
1081
1082
# File 'lib/stripe/services/payment_link_service.rb', line 1080

def maximum
  @maximum
end

#minimumObject

The minimum quantity the customer can purchase. By default this value is 0. If there is only one item in the cart then that item’s quantity cannot go down to 0.



1083
1084
1085
# File 'lib/stripe/services/payment_link_service.rb', line 1083

def minimum
  @minimum
end