Class: Stripe::PaymentLinkService::UpdateParams::LineItem::AdjustableQuantity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkService::UpdateParams::LineItem::AdjustableQuantity
- Defined in:
- lib/stripe/services/payment_link_service.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative Integer.
-
#maximum ⇒ Object
The maximum quantity the customer can purchase.
-
#minimum ⇒ Object
The minimum quantity the customer can purchase.
Instance Method Summary collapse
-
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
constructor
A new instance of AdjustableQuantity.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
Returns a new instance of AdjustableQuantity.
981 982 983 984 985 |
# File 'lib/stripe/services/payment_link_service.rb', line 981 def initialize(enabled: nil, maximum: nil, minimum: nil) @enabled = enabled @maximum = maximum @minimum = minimum end |
Instance Attribute Details
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative Integer.
975 976 977 |
# File 'lib/stripe/services/payment_link_service.rb', line 975 def enabled @enabled end |
#maximum ⇒ Object
The maximum quantity the customer can purchase. By default this value is 99. You can specify a value up to 999.
977 978 979 |
# File 'lib/stripe/services/payment_link_service.rb', line 977 def maximum @maximum end |
#minimum ⇒ Object
The minimum quantity the customer can purchase. By default this value is 0. If there is only one item in the cart then that item’s quantity cannot go down to 0.
979 980 981 |
# File 'lib/stripe/services/payment_link_service.rb', line 979 def minimum @minimum end |