Class: Stripe::PaymentLinkService::UpdateParams::SubscriptionData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkService::UpdateParams::SubscriptionData
- Defined in:
- lib/stripe/services/payment_link_service.rb
Defined Under Namespace
Classes: InvoiceSettings, TrialSettings
Instance Attribute Summary collapse
-
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that will declaratively set metadata on [Subscriptions](stripe.com/docs/api/subscriptions) generated from this payment link.
-
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time.
-
#trial_settings ⇒ Object
Settings related to subscription trials.
Instance Method Summary collapse
-
#initialize(invoice_settings: nil, metadata: nil, trial_period_days: nil, trial_settings: nil) ⇒ SubscriptionData
constructor
A new instance of SubscriptionData.
Methods inherited from RequestParams
Constructor Details
#initialize(invoice_settings: nil, metadata: nil, trial_period_days: nil, trial_settings: nil) ⇒ SubscriptionData
Returns a new instance of SubscriptionData.
1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 |
# File 'lib/stripe/services/payment_link_service.rb', line 1165 def initialize( invoice_settings: nil, metadata: nil, trial_period_days: nil, trial_settings: nil ) @invoice_settings = invoice_settings @metadata = @trial_period_days = trial_period_days @trial_settings = trial_settings end |
Instance Attribute Details
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
1157 1158 1159 |
# File 'lib/stripe/services/payment_link_service.rb', line 1157 def invoice_settings @invoice_settings end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that will declaratively set metadata on [Subscriptions](stripe.com/docs/api/subscriptions) generated from this payment link. Unlike object-level metadata, this field is declarative. Updates will clear prior values.
1159 1160 1161 |
# File 'lib/stripe/services/payment_link_service.rb', line 1159 def @metadata end |
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.
1161 1162 1163 |
# File 'lib/stripe/services/payment_link_service.rb', line 1161 def trial_period_days @trial_period_days end |
#trial_settings ⇒ Object
Settings related to subscription trials.
1163 1164 1165 |
# File 'lib/stripe/services/payment_link_service.rb', line 1163 def trial_settings @trial_settings end |