Class: Stripe::PaymentLinkService::UpdateParams::SubscriptionData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_link_service.rb

Defined Under Namespace

Classes: InvoiceSettings, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(invoice_settings: nil, metadata: nil, trial_period_days: nil, trial_settings: nil) ⇒ SubscriptionData

Returns a new instance of SubscriptionData.



1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
# File 'lib/stripe/services/payment_link_service.rb', line 1112

def initialize(
  invoice_settings: nil,
  metadata: nil,
  trial_period_days: nil,
  trial_settings: nil
)
  @invoice_settings = invoice_settings
  @metadata = 
  @trial_period_days = trial_period_days
  @trial_settings = trial_settings
end

Instance Attribute Details

#invoice_settingsObject

All invoices will be billed using the specified settings.



1104
1105
1106
# File 'lib/stripe/services/payment_link_service.rb', line 1104

def invoice_settings
  @invoice_settings
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that will declaratively set metadata on [Subscriptions](stripe.com/docs/api/subscriptions) generated from this payment link. Unlike object-level metadata, this field is declarative. Updates will clear prior values.



1106
1107
1108
# File 'lib/stripe/services/payment_link_service.rb', line 1106

def 
  @metadata
end

#trial_period_daysObject

Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.



1108
1109
1110
# File 'lib/stripe/services/payment_link_service.rb', line 1108

def trial_period_days
  @trial_period_days
end

#trial_settingsObject

Settings related to subscription trials.



1110
1111
1112
# File 'lib/stripe/services/payment_link_service.rb', line 1110

def trial_settings
  @trial_settings
end