Class: Stripe::PaymentLinkUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/payment_link_update_params.rb

Defined Under Namespace

Classes: AfterCompletion, AutomaticTax, ConsentCollection, CustomField, CustomText, InvoiceCreation, LineItem, NameCollection, OptionalItem, PaymentIntentData, PaymentMethodOptions, PhoneNumberCollection, Restrictions, ShippingAddressCollection, ShippingOption, SubscriptionData, TaxIdCollection, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(active: nil, after_completion: nil, allow_promotion_codes: nil, application_fee_amount: nil, application_fee_percent: nil, automatic_tax: nil, billing_address_collection: nil, consent_collection: nil, custom_fields: nil, custom_text: nil, customer_creation: nil, expand: nil, inactive_message: nil, invoice_creation: nil, line_items: nil, metadata: nil, name_collection: nil, on_behalf_of: nil, optional_items: nil, payment_intent_data: nil, payment_method_collection: nil, payment_method_options: nil, payment_method_types: nil, phone_number_collection: nil, restrictions: nil, shipping_address_collection: nil, shipping_options: nil, submit_type: nil, subscription_data: nil, tax_id_collection: nil, transfer_data: nil) ⇒ PaymentLinkUpdateParams

Returns a new instance of PaymentLinkUpdateParams.



690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
# File 'lib/stripe/params/payment_link_update_params.rb', line 690

def initialize(
  active: nil,
  after_completion: nil,
  allow_promotion_codes: nil,
  application_fee_amount: nil,
  application_fee_percent: nil,
  automatic_tax: nil,
  billing_address_collection: nil,
  consent_collection: nil,
  custom_fields: nil,
  custom_text: nil,
  customer_creation: nil,
  expand: nil,
  inactive_message: nil,
  invoice_creation: nil,
  line_items: nil,
  metadata: nil,
  name_collection: nil,
  on_behalf_of: nil,
  optional_items: nil,
  payment_intent_data: nil,
  payment_method_collection: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  phone_number_collection: nil,
  restrictions: nil,
  shipping_address_collection: nil,
  shipping_options: nil,
  submit_type: nil,
  subscription_data: nil,
  tax_id_collection: nil,
  transfer_data: nil
)
  @active = active
  @after_completion = after_completion
  @allow_promotion_codes = allow_promotion_codes
  @application_fee_amount = application_fee_amount
  @application_fee_percent = application_fee_percent
  @automatic_tax = automatic_tax
  @billing_address_collection = billing_address_collection
  @consent_collection = consent_collection
  @custom_fields = custom_fields
  @custom_text = custom_text
  @customer_creation = customer_creation
  @expand = expand
  @inactive_message = inactive_message
  @invoice_creation = invoice_creation
  @line_items = line_items
  @metadata = 
  @name_collection = name_collection
  @on_behalf_of = on_behalf_of
  @optional_items = optional_items
  @payment_intent_data = payment_intent_data
  @payment_method_collection = payment_method_collection
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @phone_number_collection = phone_number_collection
  @restrictions = restrictions
  @shipping_address_collection = shipping_address_collection
  @shipping_options = shipping_options
  @submit_type = submit_type
  @subscription_data = subscription_data
  @tax_id_collection = tax_id_collection
  @transfer_data = transfer_data
end

Instance Attribute Details

#activeObject

Whether the payment link's url is active. If false, customers visiting the URL will be shown a page saying that the link has been deactivated.



620
621
622
# File 'lib/stripe/params/payment_link_update_params.rb', line 620

def active
  @active
end

#after_completionObject

Behavior after the purchase is complete.



622
623
624
# File 'lib/stripe/params/payment_link_update_params.rb', line 622

def after_completion
  @after_completion
end

#allow_promotion_codesObject

Enables user redeemable promotion codes.



624
625
626
# File 'lib/stripe/params/payment_link_update_params.rb', line 624

def allow_promotion_codes
  @allow_promotion_codes
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. Can only be applied when there are no line items with recurring prices.



626
627
628
# File 'lib/stripe/params/payment_link_update_params.rb', line 626

def application_fee_amount
  @application_fee_amount
end

#application_fee_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner's Stripe account. There must be at least 1 line item with a recurring price to use this field.



628
629
630
# File 'lib/stripe/params/payment_link_update_params.rb', line 628

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject

Configuration for automatic tax collection.



630
631
632
# File 'lib/stripe/params/payment_link_update_params.rb', line 630

def automatic_tax
  @automatic_tax
end

#billing_address_collectionObject

Configuration for collecting the customer's billing address. Defaults to auto.



632
633
634
# File 'lib/stripe/params/payment_link_update_params.rb', line 632

def billing_address_collection
  @billing_address_collection
end

Configure fields to gather active consent from customers.



634
635
636
# File 'lib/stripe/params/payment_link_update_params.rb', line 634

def consent_collection
  @consent_collection
end

#custom_fieldsObject

Collect additional information from your customer using custom fields. Up to 3 fields are supported. You can't set this parameter if ui_mode is custom.



636
637
638
# File 'lib/stripe/params/payment_link_update_params.rb', line 636

def custom_fields
  @custom_fields
end

#custom_textObject

Display additional text for your customers using custom text. You can't set this parameter if ui_mode is custom.



638
639
640
# File 'lib/stripe/params/payment_link_update_params.rb', line 638

def custom_text
  @custom_text
end

#customer_creationObject

Configures whether checkout sessions created by this payment link create a Customer.



640
641
642
# File 'lib/stripe/params/payment_link_update_params.rb', line 640

def customer_creation
  @customer_creation
end

#expandObject

Specifies which fields in the response should be expanded.



642
643
644
# File 'lib/stripe/params/payment_link_update_params.rb', line 642

def expand
  @expand
end

#inactive_messageObject

The custom message to be displayed to a customer when a payment link is no longer active.



644
645
646
# File 'lib/stripe/params/payment_link_update_params.rb', line 644

def inactive_message
  @inactive_message
end

#invoice_creationObject

Generate a post-purchase Invoice for one-time payments.



646
647
648
# File 'lib/stripe/params/payment_link_update_params.rb', line 646

def invoice_creation
  @invoice_creation
end

#line_itemsObject

The line items representing what is being sold. Each line item represents an item being sold. Up to 20 line items are supported.



648
649
650
# File 'lib/stripe/params/payment_link_update_params.rb', line 648

def line_items
  @line_items
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata. Metadata associated with this Payment Link will automatically be copied to checkout sessions created by this payment link.



650
651
652
# File 'lib/stripe/params/payment_link_update_params.rb', line 650

def 
  @metadata
end

#name_collectionObject

Controls settings applied for collecting the customer's name.



652
653
654
# File 'lib/stripe/params/payment_link_update_params.rb', line 652

def name_collection
  @name_collection
end

#on_behalf_ofObject

The account on behalf of which to charge.



654
655
656
# File 'lib/stripe/params/payment_link_update_params.rb', line 654

def on_behalf_of
  @on_behalf_of
end

#optional_itemsObject

A list of optional items the customer can add to their order at checkout. Use this parameter to pass one-time or recurring Prices. There is a maximum of 10 optional items allowed on a payment link, and the existing limits on the number of line items allowed on a payment link apply to the combined number of line items and optional items. There is a maximum of 20 combined line items and optional items.



658
659
660
# File 'lib/stripe/params/payment_link_update_params.rb', line 658

def optional_items
  @optional_items
end

#payment_intent_dataObject

A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in payment mode.



660
661
662
# File 'lib/stripe/params/payment_link_update_params.rb', line 660

def payment_intent_data
  @payment_intent_data
end

#payment_method_collectionObject

Specify whether Checkout should collect a payment method. When set to if_required, Checkout will not collect a payment method when the total due for the session is 0.This may occur if the Checkout Session includes a free trial or a discount.

Can only be set in subscription mode. Defaults to always.

If you'd like information on how to collect a payment method outside of Checkout, read the guide on configuring subscriptions with a free trial.



666
667
668
# File 'lib/stripe/params/payment_link_update_params.rb', line 666

def payment_method_collection
  @payment_method_collection
end

#payment_method_optionsObject

Payment-method-specific configuration.



668
669
670
# File 'lib/stripe/params/payment_link_update_params.rb', line 668

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types that customers can use. Pass an empty string to enable dynamic payment methods that use your payment method settings.



670
671
672
# File 'lib/stripe/params/payment_link_update_params.rb', line 670

def payment_method_types
  @payment_method_types
end

#phone_number_collectionObject

Controls phone number collection settings during checkout.

We recommend that you review your privacy policy and check with your legal contacts.



674
675
676
# File 'lib/stripe/params/payment_link_update_params.rb', line 674

def phone_number_collection
  @phone_number_collection
end

#restrictionsObject

Settings that restrict the usage of a payment link.



676
677
678
# File 'lib/stripe/params/payment_link_update_params.rb', line 676

def restrictions
  @restrictions
end

#shipping_address_collectionObject

Configuration for collecting the customer's shipping address.



678
679
680
# File 'lib/stripe/params/payment_link_update_params.rb', line 678

def shipping_address_collection
  @shipping_address_collection
end

#shipping_optionsObject

The shipping rate options to apply to checkout sessions created by this payment link.



680
681
682
# File 'lib/stripe/params/payment_link_update_params.rb', line 680

def shipping_options
  @shipping_options
end

#submit_typeObject

Describes the type of transaction being performed in order to customize relevant text on the page, such as the submit button. Changing this value will also affect the hostname in the url property (example: donate.stripe.com).



682
683
684
# File 'lib/stripe/params/payment_link_update_params.rb', line 682

def submit_type
  @submit_type
end

#subscription_dataObject

When creating a subscription, the specified configuration data will be used. There must be at least one line item with a recurring price to use subscription_data.



684
685
686
# File 'lib/stripe/params/payment_link_update_params.rb', line 684

def subscription_data
  @subscription_data
end

#tax_id_collectionObject

Controls tax ID collection during checkout.



686
687
688
# File 'lib/stripe/params/payment_link_update_params.rb', line 686

def tax_id_collection
  @tax_id_collection
end

#transfer_dataObject

The account (if any) the payments will be attributed to for tax reporting, and where funds from each payment will be transferred to.



688
689
690
# File 'lib/stripe/params/payment_link_update_params.rb', line 688

def transfer_data
  @transfer_data
end