Class: Stripe::PaymentLinkUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLinkUpdateParams
- Defined in:
- lib/stripe/params/payment_link_update_params.rb
Defined Under Namespace
Classes: AfterCompletion, AutomaticTax, ConsentCollection, CustomField, CustomText, InvoiceCreation, LineItem, NameCollection, OptionalItem, PaymentIntentData, PaymentMethodOptions, PhoneNumberCollection, Restrictions, ShippingAddressCollection, ShippingOption, SubscriptionData, TaxIdCollection
Instance Attribute Summary collapse
-
#active ⇒ Object
Whether the payment link's
urlis active. -
#after_completion ⇒ Object
Behavior after the purchase is complete.
-
#allow_promotion_codes ⇒ Object
Enables user redeemable promotion codes.
-
#automatic_tax ⇒ Object
Configuration for automatic tax collection.
-
#billing_address_collection ⇒ Object
Configuration for collecting the customer's billing address.
-
#consent_collection ⇒ Object
Configure fields to gather active consent from customers.
-
#custom_fields ⇒ Object
Collect additional information from your customer using custom fields.
-
#custom_text ⇒ Object
Display additional text for your customers using custom text.
-
#customer_creation ⇒ Object
Configures whether checkout sessions created by this payment link create a Customer.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#inactive_message ⇒ Object
The custom message to be displayed to a customer when a payment link is no longer active.
-
#invoice_creation ⇒ Object
Generate a post-purchase Invoice for one-time payments.
-
#line_items ⇒ Object
The line items representing what is being sold.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#name_collection ⇒ Object
Controls settings applied for collecting the customer's name.
-
#optional_items ⇒ Object
A list of optional items the customer can add to their order at checkout.
-
#payment_intent_data ⇒ Object
A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in
paymentmode. -
#payment_method_collection ⇒ Object
Specify whether Checkout should collect a payment method.
-
#payment_method_options ⇒ Object
Payment-method-specific configuration.
-
#payment_method_types ⇒ Object
The list of payment method types that customers can use.
-
#phone_number_collection ⇒ Object
Controls phone number collection settings during checkout.
-
#restrictions ⇒ Object
Settings that restrict the usage of a payment link.
-
#shipping_address_collection ⇒ Object
Configuration for collecting the customer's shipping address.
-
#shipping_options ⇒ Object
The shipping rate options to apply to checkout sessions created by this payment link.
-
#submit_type ⇒ Object
Describes the type of transaction being performed in order to customize relevant text on the page, such as the submit button.
-
#subscription_data ⇒ Object
When creating a subscription, the specified configuration data will be used.
-
#tax_id_collection ⇒ Object
Controls tax ID collection during checkout.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(active: nil, after_completion: nil, allow_promotion_codes: nil, automatic_tax: nil, billing_address_collection: nil, consent_collection: nil, custom_fields: nil, custom_text: nil, customer_creation: nil, expand: nil, inactive_message: nil, invoice_creation: nil, line_items: nil, metadata: nil, name_collection: nil, optional_items: nil, payment_intent_data: nil, payment_method_collection: nil, payment_method_options: nil, payment_method_types: nil, phone_number_collection: nil, restrictions: nil, shipping_address_collection: nil, shipping_options: nil, submit_type: nil, subscription_data: nil, tax_id_collection: nil) ⇒ PaymentLinkUpdateParams
Returns a new instance of PaymentLinkUpdateParams.
667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 667 def initialize( active: nil, after_completion: nil, allow_promotion_codes: nil, automatic_tax: nil, billing_address_collection: nil, consent_collection: nil, custom_fields: nil, custom_text: nil, customer_creation: nil, expand: nil, inactive_message: nil, invoice_creation: nil, line_items: nil, metadata: nil, name_collection: nil, optional_items: nil, payment_intent_data: nil, payment_method_collection: nil, payment_method_options: nil, payment_method_types: nil, phone_number_collection: nil, restrictions: nil, shipping_address_collection: nil, shipping_options: nil, submit_type: nil, subscription_data: nil, tax_id_collection: nil ) @active = active @after_completion = after_completion @allow_promotion_codes = allow_promotion_codes @automatic_tax = automatic_tax @billing_address_collection = billing_address_collection @consent_collection = @custom_fields = custom_fields @custom_text = custom_text @customer_creation = customer_creation @expand = @inactive_message = @invoice_creation = invoice_creation @line_items = line_items @metadata = @name_collection = name_collection @optional_items = optional_items @payment_intent_data = payment_intent_data @payment_method_collection = payment_method_collection @payment_method_options = @payment_method_types = payment_method_types @phone_number_collection = phone_number_collection @restrictions = restrictions @shipping_address_collection = shipping_address_collection @shipping_options = @submit_type = submit_type @subscription_data = subscription_data @tax_id_collection = tax_id_collection end |
Instance Attribute Details
#active ⇒ Object
Whether the payment link's url is active. If false, customers visiting the URL will be shown a page saying that the link has been deactivated.
605 606 607 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 605 def active @active end |
#after_completion ⇒ Object
Behavior after the purchase is complete.
607 608 609 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 607 def after_completion @after_completion end |
#allow_promotion_codes ⇒ Object
Enables user redeemable promotion codes.
609 610 611 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 609 def allow_promotion_codes @allow_promotion_codes end |
#automatic_tax ⇒ Object
Configuration for automatic tax collection.
611 612 613 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 611 def automatic_tax @automatic_tax end |
#billing_address_collection ⇒ Object
Configuration for collecting the customer's billing address. Defaults to auto.
613 614 615 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 613 def billing_address_collection @billing_address_collection end |
#consent_collection ⇒ Object
Configure fields to gather active consent from customers.
615 616 617 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 615 def @consent_collection end |
#custom_fields ⇒ Object
Collect additional information from your customer using custom fields. Up to 3 fields are supported. You can't set this parameter if ui_mode is custom.
617 618 619 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 617 def custom_fields @custom_fields end |
#custom_text ⇒ Object
Display additional text for your customers using custom text. You can't set this parameter if ui_mode is custom.
619 620 621 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 619 def custom_text @custom_text end |
#customer_creation ⇒ Object
Configures whether checkout sessions created by this payment link create a Customer.
621 622 623 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 621 def customer_creation @customer_creation end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
623 624 625 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 623 def @expand end |
#inactive_message ⇒ Object
The custom message to be displayed to a customer when a payment link is no longer active.
625 626 627 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 625 def @inactive_message end |
#invoice_creation ⇒ Object
Generate a post-purchase Invoice for one-time payments.
627 628 629 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 627 def invoice_creation @invoice_creation end |
#line_items ⇒ Object
The line items representing what is being sold. Each line item represents an item being sold. Up to 20 line items are supported.
629 630 631 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 629 def line_items @line_items end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata. Metadata associated with this Payment Link will automatically be copied to checkout sessions created by this payment link.
631 632 633 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 631 def @metadata end |
#name_collection ⇒ Object
Controls settings applied for collecting the customer's name.
633 634 635 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 633 def name_collection @name_collection end |
#optional_items ⇒ Object
A list of optional items the customer can add to their order at checkout. Use this parameter to pass one-time or recurring Prices. There is a maximum of 10 optional items allowed on a payment link, and the existing limits on the number of line items allowed on a payment link apply to the combined number of line items and optional items. There is a maximum of 20 combined line items and optional items.
637 638 639 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 637 def optional_items @optional_items end |
#payment_intent_data ⇒ Object
A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in payment mode.
639 640 641 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 639 def payment_intent_data @payment_intent_data end |
#payment_method_collection ⇒ Object
Specify whether Checkout should collect a payment method. When set to if_required, Checkout will not collect a payment method when the total due for the session is 0.This may occur if the Checkout Session includes a free trial or a discount.
Can only be set in subscription mode. Defaults to always.
If you'd like information on how to collect a payment method outside of Checkout, read the guide on configuring subscriptions with a free trial.
645 646 647 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 645 def payment_method_collection @payment_method_collection end |
#payment_method_options ⇒ Object
Payment-method-specific configuration.
647 648 649 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 647 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types that customers can use. Pass an empty string to enable dynamic payment methods that use your payment method settings.
649 650 651 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 649 def payment_method_types @payment_method_types end |
#phone_number_collection ⇒ Object
Controls phone number collection settings during checkout.
We recommend that you review your privacy policy and check with your legal contacts.
653 654 655 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 653 def phone_number_collection @phone_number_collection end |
#restrictions ⇒ Object
Settings that restrict the usage of a payment link.
655 656 657 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 655 def restrictions @restrictions end |
#shipping_address_collection ⇒ Object
Configuration for collecting the customer's shipping address.
657 658 659 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 657 def shipping_address_collection @shipping_address_collection end |
#shipping_options ⇒ Object
The shipping rate options to apply to checkout sessions created by this payment link.
659 660 661 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 659 def @shipping_options end |
#submit_type ⇒ Object
Describes the type of transaction being performed in order to customize relevant text on the page, such as the submit button. Changing this value will also affect the hostname in the url property (example: donate.stripe.com).
661 662 663 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 661 def submit_type @submit_type end |
#subscription_data ⇒ Object
When creating a subscription, the specified configuration data will be used. There must be at least one line item with a recurring price to use subscription_data.
663 664 665 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 663 def subscription_data @subscription_data end |
#tax_id_collection ⇒ Object
Controls tax ID collection during checkout.
665 666 667 |
# File 'lib/stripe/params/payment_link_update_params.rb', line 665 def tax_id_collection @tax_id_collection end |