Class: Stripe::PaymentLinkUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/payment_link_update_params.rb

Defined Under Namespace

Classes: AfterCompletion, AutomaticTax, CustomField, CustomText, InvoiceCreation, LineItem, NameCollection, OptionalItem, PaymentIntentData, PaymentMethodOptions, PhoneNumberCollection, Restrictions, ShippingAddressCollection, SubscriptionData, TaxIdCollection

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(active: nil, after_completion: nil, allow_promotion_codes: nil, automatic_tax: nil, billing_address_collection: nil, custom_fields: nil, custom_text: nil, customer_creation: nil, expand: nil, inactive_message: nil, invoice_creation: nil, line_items: nil, metadata: nil, name_collection: nil, optional_items: nil, payment_intent_data: nil, payment_method_collection: nil, payment_method_options: nil, payment_method_types: nil, phone_number_collection: nil, restrictions: nil, shipping_address_collection: nil, submit_type: nil, subscription_data: nil, tax_id_collection: nil) ⇒ PaymentLinkUpdateParams

Returns a new instance of PaymentLinkUpdateParams.



613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
# File 'lib/stripe/params/payment_link_update_params.rb', line 613

def initialize(
  active: nil,
  after_completion: nil,
  allow_promotion_codes: nil,
  automatic_tax: nil,
  billing_address_collection: nil,
  custom_fields: nil,
  custom_text: nil,
  customer_creation: nil,
  expand: nil,
  inactive_message: nil,
  invoice_creation: nil,
  line_items: nil,
  metadata: nil,
  name_collection: nil,
  optional_items: nil,
  payment_intent_data: nil,
  payment_method_collection: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  phone_number_collection: nil,
  restrictions: nil,
  shipping_address_collection: nil,
  submit_type: nil,
  subscription_data: nil,
  tax_id_collection: nil
)
  @active = active
  @after_completion = after_completion
  @allow_promotion_codes = allow_promotion_codes
  @automatic_tax = automatic_tax
  @billing_address_collection = billing_address_collection
  @custom_fields = custom_fields
  @custom_text = custom_text
  @customer_creation = customer_creation
  @expand = expand
  @inactive_message = inactive_message
  @invoice_creation = invoice_creation
  @line_items = line_items
  @metadata = 
  @name_collection = name_collection
  @optional_items = optional_items
  @payment_intent_data = payment_intent_data
  @payment_method_collection = payment_method_collection
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @phone_number_collection = phone_number_collection
  @restrictions = restrictions
  @shipping_address_collection = shipping_address_collection
  @submit_type = submit_type
  @subscription_data = subscription_data
  @tax_id_collection = tax_id_collection
end

Instance Attribute Details

#activeObject

Whether the payment link’s ‘url` is active. If `false`, customers visiting the URL will be shown a page saying that the link has been deactivated.



555
556
557
# File 'lib/stripe/params/payment_link_update_params.rb', line 555

def active
  @active
end

#after_completionObject

Behavior after the purchase is complete.



557
558
559
# File 'lib/stripe/params/payment_link_update_params.rb', line 557

def after_completion
  @after_completion
end

#allow_promotion_codesObject

Enables user redeemable promotion codes.



559
560
561
# File 'lib/stripe/params/payment_link_update_params.rb', line 559

def allow_promotion_codes
  @allow_promotion_codes
end

#automatic_taxObject

Configuration for automatic tax collection.



561
562
563
# File 'lib/stripe/params/payment_link_update_params.rb', line 561

def automatic_tax
  @automatic_tax
end

#billing_address_collectionObject

Configuration for collecting the customer’s billing address. Defaults to ‘auto`.



563
564
565
# File 'lib/stripe/params/payment_link_update_params.rb', line 563

def billing_address_collection
  @billing_address_collection
end

#custom_fieldsObject

Collect additional information from your customer using custom fields. Up to 3 fields are supported. You can’t set this parameter if ‘ui_mode` is `custom`.



565
566
567
# File 'lib/stripe/params/payment_link_update_params.rb', line 565

def custom_fields
  @custom_fields
end

#custom_textObject

Display additional text for your customers using custom text. You can’t set this parameter if ‘ui_mode` is `custom`.



567
568
569
# File 'lib/stripe/params/payment_link_update_params.rb', line 567

def custom_text
  @custom_text
end

#customer_creationObject

Configures whether [checkout sessions](docs.stripe.com/api/checkout/sessions) created by this payment link create a [Customer](docs.stripe.com/api/customers).



569
570
571
# File 'lib/stripe/params/payment_link_update_params.rb', line 569

def customer_creation
  @customer_creation
end

#expandObject

Specifies which fields in the response should be expanded.



571
572
573
# File 'lib/stripe/params/payment_link_update_params.rb', line 571

def expand
  @expand
end

#inactive_messageObject

The custom message to be displayed to a customer when a payment link is no longer active.



573
574
575
# File 'lib/stripe/params/payment_link_update_params.rb', line 573

def inactive_message
  @inactive_message
end

#invoice_creationObject

Generate a post-purchase Invoice for one-time payments.



575
576
577
# File 'lib/stripe/params/payment_link_update_params.rb', line 575

def invoice_creation
  @invoice_creation
end

#line_itemsObject

The line items representing what is being sold. Each line item represents an item being sold. Up to 20 line items are supported.



577
578
579
# File 'lib/stripe/params/payment_link_update_params.rb', line 577

def line_items
  @line_items
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`. Metadata associated with this Payment Link will automatically be copied to [checkout sessions](docs.stripe.com/api/checkout/sessions) created by this payment link.



579
580
581
# File 'lib/stripe/params/payment_link_update_params.rb', line 579

def 
  @metadata
end

#name_collectionObject

Controls settings applied for collecting the customer’s name.



581
582
583
# File 'lib/stripe/params/payment_link_update_params.rb', line 581

def name_collection
  @name_collection
end

#optional_itemsObject

A list of optional items the customer can add to their order at checkout. Use this parameter to pass one-time or recurring [Prices](docs.stripe.com/api/prices). There is a maximum of 10 optional items allowed on a payment link, and the existing limits on the number of line items allowed on a payment link apply to the combined number of line items and optional items. There is a maximum of 20 combined line items and optional items.



585
586
587
# File 'lib/stripe/params/payment_link_update_params.rb', line 585

def optional_items
  @optional_items
end

#payment_intent_dataObject

A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in ‘payment` mode.



587
588
589
# File 'lib/stripe/params/payment_link_update_params.rb', line 587

def payment_intent_data
  @payment_intent_data
end

#payment_method_collectionObject

Specify whether Checkout should collect a payment method. When set to ‘if_required`, Checkout will not collect a payment method when the total due for the session is 0.This may occur if the Checkout Session includes a free trial or a discount.

Can only be set in ‘subscription` mode. Defaults to `always`.

If you’d like information on how to collect a payment method outside of Checkout, read the guide on [configuring subscriptions with a free trial](docs.stripe.com/payments/checkout/free-trials).



593
594
595
# File 'lib/stripe/params/payment_link_update_params.rb', line 593

def payment_method_collection
  @payment_method_collection
end

#payment_method_optionsObject

Payment-method-specific configuration.



595
596
597
# File 'lib/stripe/params/payment_link_update_params.rb', line 595

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types that customers can use. Pass an empty string to enable dynamic payment methods that use your [payment method settings](dashboard.stripe.com/settings/payment_methods).



597
598
599
# File 'lib/stripe/params/payment_link_update_params.rb', line 597

def payment_method_types
  @payment_method_types
end

#phone_number_collectionObject

Controls phone number collection settings during checkout.

We recommend that you review your privacy policy and check with your legal contacts.



601
602
603
# File 'lib/stripe/params/payment_link_update_params.rb', line 601

def phone_number_collection
  @phone_number_collection
end

#restrictionsObject

Settings that restrict the usage of a payment link.



603
604
605
# File 'lib/stripe/params/payment_link_update_params.rb', line 603

def restrictions
  @restrictions
end

#shipping_address_collectionObject

Configuration for collecting the customer’s shipping address.



605
606
607
# File 'lib/stripe/params/payment_link_update_params.rb', line 605

def shipping_address_collection
  @shipping_address_collection
end

#submit_typeObject

Describes the type of transaction being performed in order to customize relevant text on the page, such as the submit button. Changing this value will also affect the hostname in the [url](docs.stripe.com/api/payment_links/payment_links/object#url) property (example: ‘donate.stripe.com`).



607
608
609
# File 'lib/stripe/params/payment_link_update_params.rb', line 607

def submit_type
  @submit_type
end

#subscription_dataObject

When creating a subscription, the specified configuration data will be used. There must be at least one line item with a recurring price to use ‘subscription_data`.



609
610
611
# File 'lib/stripe/params/payment_link_update_params.rb', line 609

def subscription_data
  @subscription_data
end

#tax_id_collectionObject

Controls tax ID collection during checkout.



611
612
613
# File 'lib/stripe/params/payment_link_update_params.rb', line 611

def tax_id_collection
  @tax_id_collection
end