Class: Stripe::PaymentLinkUpdateParams::OptionalItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_link_update_params.rb

Defined Under Namespace

Classes: AdjustableQuantity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(adjustable_quantity: nil, price: nil, quantity: nil) ⇒ OptionalItem

Returns a new instance of OptionalItem.



387
388
389
390
391
# File 'lib/stripe/params/payment_link_update_params.rb', line 387

def initialize(adjustable_quantity: nil, price: nil, quantity: nil)
  @adjustable_quantity = adjustable_quantity
  @price = price
  @quantity = quantity
end

Instance Attribute Details

#adjustable_quantityObject

When set, provides configuration for the customer to adjust the quantity of the line item created when a customer chooses to add this optional item to their order.



381
382
383
# File 'lib/stripe/params/payment_link_update_params.rb', line 381

def adjustable_quantity
  @adjustable_quantity
end

#priceObject

The ID of the [Price](docs.stripe.com/api/prices) or [Plan](docs.stripe.com/api/plans) object.



383
384
385
# File 'lib/stripe/params/payment_link_update_params.rb', line 383

def price
  @price
end

#quantityObject

The initial quantity of the line item created when a customer chooses to add this optional item to their order.



385
386
387
# File 'lib/stripe/params/payment_link_update_params.rb', line 385

def quantity
  @quantity
end