Class: Stripe::PaymentLinkUpdateParams::PaymentIntentData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_link_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(description: nil, metadata: nil, setup_future_usage: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_group: nil) ⇒ PaymentIntentData

Returns a new instance of PaymentIntentData.



447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
# File 'lib/stripe/params/payment_link_update_params.rb', line 447

def initialize(
  description: nil,
  metadata: nil,
  setup_future_usage: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_group: nil
)
  @description = description
  @metadata = 
  @setup_future_usage = setup_future_usage
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_group = transfer_group
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



423
424
425
# File 'lib/stripe/params/payment_link_update_params.rb', line 423

def description
  @description
end

#metadataObject

Set of key-value pairs that will declaratively set metadata on Payment Intents generated from this payment link. Unlike object-level metadata, this field is declarative. Updates will clear prior values.



425
426
427
# File 'lib/stripe/params/payment_link_update_params.rb', line 425

def 
  @metadata
end

#setup_future_usageObject

Indicates that you intend to make future payments with the payment method collected by this Checkout Session.

When setting this to on_session, Checkout will show a notice to the customer that their payment details will be saved.

When setting this to off_session, Checkout will show a notice to the customer that their payment details will be saved and used for future payments.

If a Customer has been provided or Checkout creates a new Customer,Checkout will attach the payment method to the Customer.

If Checkout does not create a Customer, the payment method is not attached to a Customer. To reuse the payment method, you can retrieve it from the Checkout Session's PaymentIntent.

When processing card payments, Checkout also uses setup_future_usage to dynamically optimize your payment flow and comply with regional legislation and network rules, such as SCA.



437
438
439
# File 'lib/stripe/params/payment_link_update_params.rb', line 437

def setup_future_usage
  @setup_future_usage
end

#statement_descriptorObject

Text that appears on the customer's statement as the statement descriptor for a non-card charge. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see the Statement Descriptor docs.

Setting this value for a card charge returns an error. For card charges, set the statement_descriptor_suffix instead.



441
442
443
# File 'lib/stripe/params/payment_link_update_params.rb', line 441

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account's statement descriptor prefix to form the complete statement descriptor that appears on the customer's statement.



443
444
445
# File 'lib/stripe/params/payment_link_update_params.rb', line 443

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_groupObject

A string that identifies the resulting payment as part of a group. See the PaymentIntents use case for connected accounts for details.



445
446
447
# File 'lib/stripe/params/payment_link_update_params.rb', line 445

def transfer_group
  @transfer_group
end