Class: Stripe::PaymentLinkUpdateParams::SubscriptionData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_link_update_params.rb

Defined Under Namespace

Classes: InvoiceSettings, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(invoice_settings: nil, metadata: nil, trial_period_days: nil, trial_settings: nil) ⇒ SubscriptionData

Returns a new instance of SubscriptionData.



580
581
582
583
584
585
586
587
588
589
590
# File 'lib/stripe/params/payment_link_update_params.rb', line 580

def initialize(
  invoice_settings: nil,
  metadata: nil,
  trial_period_days: nil,
  trial_settings: nil
)
  @invoice_settings = invoice_settings
  @metadata = 
  @trial_period_days = trial_period_days
  @trial_settings = trial_settings
end

Instance Attribute Details

#invoice_settingsObject

All invoices will be billed using the specified settings.



572
573
574
# File 'lib/stripe/params/payment_link_update_params.rb', line 572

def invoice_settings
  @invoice_settings
end

#metadataObject

Set of key-value pairs that will declaratively set metadata on Subscriptions generated from this payment link. Unlike object-level metadata, this field is declarative. Updates will clear prior values.



574
575
576
# File 'lib/stripe/params/payment_link_update_params.rb', line 574

def 
  @metadata
end

#trial_period_daysObject

Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.



576
577
578
# File 'lib/stripe/params/payment_link_update_params.rb', line 576

def trial_period_days
  @trial_period_days
end

#trial_settingsObject

Settings related to subscription trials.



578
579
580
# File 'lib/stripe/params/payment_link_update_params.rb', line 578

def trial_settings
  @trial_settings
end