Class: Stripe::PaymentLinkUpdateParams::SubscriptionData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_link_update_params.rb

Defined Under Namespace

Classes: InvoiceSettings, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(invoice_settings: nil, metadata: nil, trial_period_days: nil, trial_settings: nil) ⇒ SubscriptionData

Returns a new instance of SubscriptionData.



530
531
532
533
534
535
536
537
538
539
540
# File 'lib/stripe/params/payment_link_update_params.rb', line 530

def initialize(
  invoice_settings: nil,
  metadata: nil,
  trial_period_days: nil,
  trial_settings: nil
)
  @invoice_settings = invoice_settings
  @metadata = 
  @trial_period_days = trial_period_days
  @trial_settings = trial_settings
end

Instance Attribute Details

#invoice_settingsObject

All invoices will be billed using the specified settings.



522
523
524
# File 'lib/stripe/params/payment_link_update_params.rb', line 522

def invoice_settings
  @invoice_settings
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that will declaratively set metadata on [Subscriptions](docs.stripe.com/api/subscriptions) generated from this payment link. Unlike object-level metadata, this field is declarative. Updates will clear prior values.



524
525
526
# File 'lib/stripe/params/payment_link_update_params.rb', line 524

def 
  @metadata
end

#trial_period_daysObject

Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.



526
527
528
# File 'lib/stripe/params/payment_link_update_params.rb', line 526

def trial_period_days
  @trial_period_days
end

#trial_settingsObject

Settings related to subscription trials.



528
529
530
# File 'lib/stripe/params/payment_link_update_params.rb', line 528

def trial_settings
  @trial_settings
end