Class: Stripe::PaymentLinkUpdateParams::SubscriptionData::TrialSettings::EndBehavior

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_link_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(missing_payment_method: nil) ⇒ EndBehavior

Returns a new instance of EndBehavior.



510
511
512
# File 'lib/stripe/params/payment_link_update_params.rb', line 510

def initialize(missing_payment_method: nil)
  @missing_payment_method = missing_payment_method
end

Instance Attribute Details

#missing_payment_methodObject

Indicates how the subscription should change when the trial ends if the user did not provide a payment method.



508
509
510
# File 'lib/stripe/params/payment_link_update_params.rb', line 508

def missing_payment_method
  @missing_payment_method
end