Class: Stripe::PaymentLocationCapability
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::PaymentLocationCapability
- Extended by:
- APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/payment_location_capability.rb
Overview
A Payment Location Capability represents a capability for a Stripe account at a Payment Location.
Defined Under Namespace
Classes: Requirements
Constant Summary collapse
- OBJECT_NAME =
"payment_location_capability"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The account for which the capability enables functionality.
-
#capability ⇒ Object
readonly
The identifier for the capability.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#location ⇒ Object
readonly
The payment location for which the capability enables functionality.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#requested ⇒ Object
readonly
Whether the capability has been requested.
-
#requested_at ⇒ Object
readonly
Time at which the capability was requested.
-
#requirements ⇒ Object
readonly
Attribute for field requirements.
-
#status ⇒ Object
readonly
The status of the capability.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of PaymentLocationCapability objects associated with the location.
- .object_name ⇒ Object
-
.update(capability, params = {}, opts = {}) ⇒ Object
Updates a specified Payment Location Capability.
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The account for which the capability enables functionality.
48 49 50 |
# File 'lib/stripe/resources/payment_location_capability.rb', line 48 def account @account end |
#capability ⇒ Object (readonly)
The identifier for the capability.
50 51 52 |
# File 'lib/stripe/resources/payment_location_capability.rb', line 50 def capability @capability end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
52 53 54 |
# File 'lib/stripe/resources/payment_location_capability.rb', line 52 def livemode @livemode end |
#location ⇒ Object (readonly)
The payment location for which the capability enables functionality.
54 55 56 |
# File 'lib/stripe/resources/payment_location_capability.rb', line 54 def location @location end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
56 57 58 |
# File 'lib/stripe/resources/payment_location_capability.rb', line 56 def object @object end |
#requested ⇒ Object (readonly)
Whether the capability has been requested.
58 59 60 |
# File 'lib/stripe/resources/payment_location_capability.rb', line 58 def requested @requested end |
#requested_at ⇒ Object (readonly)
Time at which the capability was requested. Measured in seconds since the Unix epoch.
60 61 62 |
# File 'lib/stripe/resources/payment_location_capability.rb', line 60 def requested_at @requested_at end |
#requirements ⇒ Object (readonly)
Attribute for field requirements
62 63 64 |
# File 'lib/stripe/resources/payment_location_capability.rb', line 62 def requirements @requirements end |
#status ⇒ Object (readonly)
The status of the capability.
64 65 66 |
# File 'lib/stripe/resources/payment_location_capability.rb', line 64 def status @status end |
Class Method Details
.field_remappings ⇒ Object
90 91 92 |
# File 'lib/stripe/resources/payment_location_capability.rb', line 90 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
86 87 88 |
# File 'lib/stripe/resources/payment_location_capability.rb', line 86 def self.inner_class_types @inner_class_types = { requirements: Requirements } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of PaymentLocationCapability objects associated with the location.
67 68 69 70 71 72 73 74 |
# File 'lib/stripe/resources/payment_location_capability.rb', line 67 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/payment_location_capabilities", params: params, opts: opts ) end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/payment_location_capability.rb', line 11 def self.object_name "payment_location_capability" end |
.update(capability, params = {}, opts = {}) ⇒ Object
Updates a specified Payment Location Capability. Request or remove a payment location capability by updating its requested parameter.
77 78 79 80 81 82 83 84 |
# File 'lib/stripe/resources/payment_location_capability.rb', line 77 def self.update(capability, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_location_capabilities/%<capability>s", { capability: CGI.escape(capability) }), params: params, opts: opts ) end |