Class: Stripe::PaymentLocationCapability::Requirements
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentLocationCapability::Requirements
- Defined in:
- lib/stripe/resources/payment_location_capability.rb
Defined Under Namespace
Classes: Error
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#currently_due ⇒ Object
readonly
Fields that need to be collected to keep the capability enabled.
-
#disabled_reason ⇒ Object
readonly
Description of why the capability is disabled.
-
#errors ⇒ Object
readonly
Fields that are ‘currently_due` and need to be collected again because validation or verification failed.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#currently_due ⇒ Object (readonly)
Fields that need to be collected to keep the capability enabled.
33 34 35 |
# File 'lib/stripe/resources/payment_location_capability.rb', line 33 def currently_due @currently_due end |
#disabled_reason ⇒ Object (readonly)
Description of why the capability is disabled.
35 36 37 |
# File 'lib/stripe/resources/payment_location_capability.rb', line 35 def disabled_reason @disabled_reason end |
#errors ⇒ Object (readonly)
Fields that are ‘currently_due` and need to be collected again because validation or verification failed.
37 38 39 |
# File 'lib/stripe/resources/payment_location_capability.rb', line 37 def errors @errors end |
Class Method Details
.field_remappings ⇒ Object
43 44 45 |
# File 'lib/stripe/resources/payment_location_capability.rb', line 43 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
39 40 41 |
# File 'lib/stripe/resources/payment_location_capability.rb', line 39 def self.inner_class_types @inner_class_types = { errors: Error } end |