Class: Stripe::PaymentLocationUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentLocationUpdateParams
- Defined in:
- lib/stripe/params/payment_location_update_params.rb
Defined Under Namespace
Classes: Address, BusinessRegistration
Instance Attribute Summary collapse
-
#address ⇒ Object
The full address of the location.
-
#business_registration ⇒ Object
Identification numbers associated with the location.
-
#display_name ⇒ Object
A name for the location.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(address: nil, business_registration: nil, display_name: nil, expand: nil) ⇒ PaymentLocationUpdateParams
constructor
A new instance of PaymentLocationUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, business_registration: nil, display_name: nil, expand: nil) ⇒ PaymentLocationUpdateParams
Returns a new instance of PaymentLocationUpdateParams.
47 48 49 50 51 52 |
# File 'lib/stripe/params/payment_location_update_params.rb', line 47 def initialize(address: nil, business_registration: nil, display_name: nil, expand: nil) @address = address @business_registration = business_registration @display_name = display_name @expand = end |
Instance Attribute Details
#address ⇒ Object
The full address of the location.
39 40 41 |
# File 'lib/stripe/params/payment_location_update_params.rb', line 39 def address @address end |
#business_registration ⇒ Object
Identification numbers associated with the location.
41 42 43 |
# File 'lib/stripe/params/payment_location_update_params.rb', line 41 def business_registration @business_registration end |
#display_name ⇒ Object
A name for the location.
43 44 45 |
# File 'lib/stripe/params/payment_location_update_params.rb', line 43 def display_name @display_name end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
45 46 47 |
# File 'lib/stripe/params/payment_location_update_params.rb', line 45 def @expand end |