Class: Stripe::PaymentMethod

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/payment_method.rb

Overview

PaymentMethod objects represent your customer’s payment instruments. You can use them with [PaymentIntents](stripe.com/docs/payments/payment-intents) to collect payments or save them to Customer objects to store instrument details for future payments.

Related guides: [Payment Methods](stripe.com/docs/payments/payment-methods) and [More Payment Scenarios](stripe.com/docs/payments/more-payment-scenarios).

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AttachParams, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, CreateParams, CustomerBalance, DetachParams, Eps, Fpx, Giropay, Grabpay, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, ListParams, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Pix, Promptpay, RadarOptions, RevolutPay, SamsungPay, Satispay, SepaDebit, Sofort, Swish, Twint, UpdateParams, UsBankAccount, WechatPay, Zip

Constant Summary collapse

OBJECT_NAME =
"payment_method"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

Attribute for field acss_debit



1452
1453
1454
# File 'lib/stripe/resources/payment_method.rb', line 1452

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



1454
1455
1456
# File 'lib/stripe/resources/payment_method.rb', line 1454

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



1456
1457
1458
# File 'lib/stripe/resources/payment_method.rb', line 1456

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



1458
1459
1460
# File 'lib/stripe/resources/payment_method.rb', line 1458

def alipay
  @alipay
end

#allow_redisplayObject (readonly)

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.



1460
1461
1462
# File 'lib/stripe/resources/payment_method.rb', line 1460

def allow_redisplay
  @allow_redisplay
end

#almaObject (readonly)

Attribute for field alma



1462
1463
1464
# File 'lib/stripe/resources/payment_method.rb', line 1462

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



1464
1465
1466
# File 'lib/stripe/resources/payment_method.rb', line 1464

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



1466
1467
1468
# File 'lib/stripe/resources/payment_method.rb', line 1466

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



1468
1469
1470
# File 'lib/stripe/resources/payment_method.rb', line 1468

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



1470
1471
1472
# File 'lib/stripe/resources/payment_method.rb', line 1470

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



1472
1473
1474
# File 'lib/stripe/resources/payment_method.rb', line 1472

def billie
  @billie
end

#billing_detailsObject (readonly)

Attribute for field billing_details



1474
1475
1476
# File 'lib/stripe/resources/payment_method.rb', line 1474

def billing_details
  @billing_details
end

#blikObject (readonly)

Attribute for field blik



1476
1477
1478
# File 'lib/stripe/resources/payment_method.rb', line 1476

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



1478
1479
1480
# File 'lib/stripe/resources/payment_method.rb', line 1478

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



1480
1481
1482
# File 'lib/stripe/resources/payment_method.rb', line 1480

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



1482
1483
1484
# File 'lib/stripe/resources/payment_method.rb', line 1482

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



1484
1485
1486
# File 'lib/stripe/resources/payment_method.rb', line 1484

def cashapp
  @cashapp
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



1486
1487
1488
# File 'lib/stripe/resources/payment_method.rb', line 1486

def created
  @created
end

#customerObject (readonly)

The ID of the Customer to which this PaymentMethod is saved. This will not be set when the PaymentMethod has not been saved to a Customer.



1488
1489
1490
# File 'lib/stripe/resources/payment_method.rb', line 1488

def customer
  @customer
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



1490
1491
1492
# File 'lib/stripe/resources/payment_method.rb', line 1490

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



1492
1493
1494
# File 'lib/stripe/resources/payment_method.rb', line 1492

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



1494
1495
1496
# File 'lib/stripe/resources/payment_method.rb', line 1494

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



1496
1497
1498
# File 'lib/stripe/resources/payment_method.rb', line 1496

def giropay
  @giropay
end

#grabpayObject (readonly)

Attribute for field grabpay



1498
1499
1500
# File 'lib/stripe/resources/payment_method.rb', line 1498

def grabpay
  @grabpay
end

#idObject (readonly)

Unique identifier for the object.



1500
1501
1502
# File 'lib/stripe/resources/payment_method.rb', line 1500

def id
  @id
end

#idealObject (readonly)

Attribute for field ideal



1502
1503
1504
# File 'lib/stripe/resources/payment_method.rb', line 1502

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



1504
1505
1506
# File 'lib/stripe/resources/payment_method.rb', line 1504

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



1506
1507
1508
# File 'lib/stripe/resources/payment_method.rb', line 1506

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



1508
1509
1510
# File 'lib/stripe/resources/payment_method.rb', line 1508

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



1510
1511
1512
# File 'lib/stripe/resources/payment_method.rb', line 1510

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



1512
1513
1514
# File 'lib/stripe/resources/payment_method.rb', line 1512

def kr_card
  @kr_card
end

Attribute for field link



1514
1515
1516
# File 'lib/stripe/resources/payment_method.rb', line 1514

def link
  @link
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



1516
1517
1518
# File 'lib/stripe/resources/payment_method.rb', line 1516

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



1518
1519
1520
# File 'lib/stripe/resources/payment_method.rb', line 1518

def 
  @metadata
end

#mobilepayObject (readonly)

Attribute for field mobilepay



1520
1521
1522
# File 'lib/stripe/resources/payment_method.rb', line 1520

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



1522
1523
1524
# File 'lib/stripe/resources/payment_method.rb', line 1522

def multibanco
  @multibanco
end

Attribute for field naver_pay



1524
1525
1526
# File 'lib/stripe/resources/payment_method.rb', line 1524

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



1526
1527
1528
# File 'lib/stripe/resources/payment_method.rb', line 1526

def 
  @nz_bank_account
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



1528
1529
1530
# File 'lib/stripe/resources/payment_method.rb', line 1528

def object
  @object
end

#oxxoObject (readonly)

Attribute for field oxxo



1530
1531
1532
# File 'lib/stripe/resources/payment_method.rb', line 1530

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



1532
1533
1534
# File 'lib/stripe/resources/payment_method.rb', line 1532

def p24
  @p24
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



1534
1535
1536
# File 'lib/stripe/resources/payment_method.rb', line 1534

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



1536
1537
1538
# File 'lib/stripe/resources/payment_method.rb', line 1536

def payco
  @payco
end

#paynowObject (readonly)

Attribute for field paynow



1538
1539
1540
# File 'lib/stripe/resources/payment_method.rb', line 1538

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



1540
1541
1542
# File 'lib/stripe/resources/payment_method.rb', line 1540

def paypal
  @paypal
end

#pixObject (readonly)

Attribute for field pix



1542
1543
1544
# File 'lib/stripe/resources/payment_method.rb', line 1542

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



1544
1545
1546
# File 'lib/stripe/resources/payment_method.rb', line 1544

def promptpay
  @promptpay
end

#radar_optionsObject (readonly)

Options to configure Radar. See [Radar Session](stripe.com/docs/radar/radar-session) for more information.



1546
1547
1548
# File 'lib/stripe/resources/payment_method.rb', line 1546

def radar_options
  @radar_options
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



1548
1549
1550
# File 'lib/stripe/resources/payment_method.rb', line 1548

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



1550
1551
1552
# File 'lib/stripe/resources/payment_method.rb', line 1550

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



1552
1553
1554
# File 'lib/stripe/resources/payment_method.rb', line 1552

def satispay
  @satispay
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



1554
1555
1556
# File 'lib/stripe/resources/payment_method.rb', line 1554

def sepa_debit
  @sepa_debit
end

#sofortObject (readonly)

Attribute for field sofort



1556
1557
1558
# File 'lib/stripe/resources/payment_method.rb', line 1556

def sofort
  @sofort
end

#swishObject (readonly)

Attribute for field swish



1558
1559
1560
# File 'lib/stripe/resources/payment_method.rb', line 1558

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



1560
1561
1562
# File 'lib/stripe/resources/payment_method.rb', line 1560

def twint
  @twint
end

#typeObject (readonly)

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



1562
1563
1564
# File 'lib/stripe/resources/payment_method.rb', line 1562

def type
  @type
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



1564
1565
1566
# File 'lib/stripe/resources/payment_method.rb', line 1564

def 
  @us_bank_account
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



1566
1567
1568
# File 'lib/stripe/resources/payment_method.rb', line 1566

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



1568
1569
1570
# File 'lib/stripe/resources/payment_method.rb', line 1568

def zip
  @zip
end

Class Method Details

.attach(payment_method, params = {}, opts = {}) ⇒ Object

Attaches a PaymentMethod object to a Customer.

To attach a new PaymentMethod to a customer for future payments, we recommend you use a [SetupIntent](stripe.com/docs/api/setup_intents) or a PaymentIntent with [setup_future_usage](stripe.com/docs/api/payment_intents/create#create_payment_intent-setup_future_usage). These approaches will perform any necessary steps to set up the PaymentMethod for future payments. Using the /v1/payment_methods/:id/attach endpoint without first using a SetupIntent or PaymentIntent with setup_future_usage does not optimize the PaymentMethod for future use, which makes later declines and payment friction more likely. See [Optimizing cards for future payments](stripe.com/docs/payments/payment-intents#future-usage) for more information about setting up future payments.

To use this PaymentMethod as the default for invoice or subscription payments, set [invoice_settings.default_payment_method](stripe.com/docs/api/customers/update#update_customer-invoice_settings-default_payment_method), on the Customer to the PaymentMethod’s ID.



1605
1606
1607
1608
1609
1610
1611
1612
# File 'lib/stripe/resources/payment_method.rb', line 1605

def self.attach(payment_method, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_methods/%<payment_method>s/attach", { payment_method: CGI.escape(payment_method) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

Creates a PaymentMethod object. Read the [Stripe.js reference](stripe.com/docs/stripe-js/reference#stripe-create-payment-method) to learn how to create PaymentMethods via Stripe.js.

Instead of creating a PaymentMethod directly, we recommend using the [PaymentIntents API to accept a payment immediately or the <a href=“/docs/payments/save-and-reuse”>SetupIntent](stripe.com/docs/payments/accept-a-payment) API to collect payment method details ahead of a future payment.



1617
1618
1619
# File 'lib/stripe/resources/payment_method.rb', line 1617

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/payment_methods", params: params, opts: opts)
end

.detach(payment_method, params = {}, opts = {}) ⇒ Object

Detaches a PaymentMethod object from a Customer. After a PaymentMethod is detached, it can no longer be used for a payment or re-attached to a Customer.



1632
1633
1634
1635
1636
1637
1638
1639
# File 'lib/stripe/resources/payment_method.rb', line 1632

def self.detach(payment_method, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_methods/%<payment_method>s/detach", { payment_method: CGI.escape(payment_method) }),
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of PaymentMethods for Treasury flows. If you want to list the PaymentMethods attached to a Customer for payments, you should use the [List a Customer’s PaymentMethods](stripe.com/docs/api/payment_methods/customer_list) API instead.



1642
1643
1644
# File 'lib/stripe/resources/payment_method.rb', line 1642

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/payment_methods", params: params, opts: opts)
end

.object_nameObject



16
17
18
# File 'lib/stripe/resources/payment_method.rb', line 16

def self.object_name
  "payment_method"
end

.update(payment_method, params = {}, opts = {}) ⇒ Object

Updates a PaymentMethod object. A PaymentMethod must be attached a customer to be updated.



1647
1648
1649
1650
1651
1652
1653
1654
# File 'lib/stripe/resources/payment_method.rb', line 1647

def self.update(payment_method, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_methods/%<payment_method>s", { payment_method: CGI.escape(payment_method) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#attach(params = {}, opts = {}) ⇒ Object

Attaches a PaymentMethod object to a Customer.

To attach a new PaymentMethod to a customer for future payments, we recommend you use a [SetupIntent](stripe.com/docs/api/setup_intents) or a PaymentIntent with [setup_future_usage](stripe.com/docs/api/payment_intents/create#create_payment_intent-setup_future_usage). These approaches will perform any necessary steps to set up the PaymentMethod for future payments. Using the /v1/payment_methods/:id/attach endpoint without first using a SetupIntent or PaymentIntent with setup_future_usage does not optimize the PaymentMethod for future use, which makes later declines and payment friction more likely. See [Optimizing cards for future payments](stripe.com/docs/payments/payment-intents#future-usage) for more information about setting up future payments.

To use this PaymentMethod as the default for invoice or subscription payments, set [invoice_settings.default_payment_method](stripe.com/docs/api/customers/update#update_customer-invoice_settings-default_payment_method), on the Customer to the PaymentMethod’s ID.



1583
1584
1585
1586
1587
1588
1589
1590
# File 'lib/stripe/resources/payment_method.rb', line 1583

def attach(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_methods/%<payment_method>s/attach", { payment_method: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#detach(params = {}, opts = {}) ⇒ Object

Detaches a PaymentMethod object from a Customer. After a PaymentMethod is detached, it can no longer be used for a payment or re-attached to a Customer.



1622
1623
1624
1625
1626
1627
1628
1629
# File 'lib/stripe/resources/payment_method.rb', line 1622

def detach(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_methods/%<payment_method>s/detach", { payment_method: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end