Class: Stripe::PaymentMethod

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/payment_method.rb

Overview

PaymentMethod objects represent your customer’s payment instruments. You can use them with [PaymentIntents](stripe.com/docs/payments/payment-intents) to collect payments or save them to Customer objects to store instrument details for future payments.

Related guides: [Payment Methods](stripe.com/docs/payments/payment-methods) and [More Payment Scenarios](stripe.com/docs/payments/more-payment-scenarios).

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AttachParams, AuBecsDebit, BacsDebit, Bancontact, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, CreateParams, CustomerBalance, DetachParams, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, ListParams, MbWay, Mobilepay, Multibanco, NaverPay, Oxxo, P24, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, RadarOptions, Rechnung, RetrieveParams, RevolutPay, SamsungPay, SepaDebit, Shopeepay, Sofort, Swish, Twint, UpdateParams, UsBankAccount, WechatPay, Zip

Constant Summary collapse

OBJECT_NAME =
"payment_method"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

Attribute for field acss_debit



1534
1535
1536
# File 'lib/stripe/resources/payment_method.rb', line 1534

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



1536
1537
1538
# File 'lib/stripe/resources/payment_method.rb', line 1536

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



1538
1539
1540
# File 'lib/stripe/resources/payment_method.rb', line 1538

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



1540
1541
1542
# File 'lib/stripe/resources/payment_method.rb', line 1540

def alipay
  @alipay
end

#allow_redisplayObject (readonly)

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.



1542
1543
1544
# File 'lib/stripe/resources/payment_method.rb', line 1542

def allow_redisplay
  @allow_redisplay
end

#almaObject (readonly)

Attribute for field alma



1544
1545
1546
# File 'lib/stripe/resources/payment_method.rb', line 1544

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



1546
1547
1548
# File 'lib/stripe/resources/payment_method.rb', line 1546

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



1548
1549
1550
# File 'lib/stripe/resources/payment_method.rb', line 1548

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



1550
1551
1552
# File 'lib/stripe/resources/payment_method.rb', line 1550

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



1552
1553
1554
# File 'lib/stripe/resources/payment_method.rb', line 1552

def bancontact
  @bancontact
end

#billing_detailsObject (readonly)

Attribute for field billing_details



1554
1555
1556
# File 'lib/stripe/resources/payment_method.rb', line 1554

def billing_details
  @billing_details
end

#blikObject (readonly)

Attribute for field blik



1556
1557
1558
# File 'lib/stripe/resources/payment_method.rb', line 1556

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



1558
1559
1560
# File 'lib/stripe/resources/payment_method.rb', line 1558

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



1560
1561
1562
# File 'lib/stripe/resources/payment_method.rb', line 1560

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



1562
1563
1564
# File 'lib/stripe/resources/payment_method.rb', line 1562

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



1564
1565
1566
# File 'lib/stripe/resources/payment_method.rb', line 1564

def cashapp
  @cashapp
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



1566
1567
1568
# File 'lib/stripe/resources/payment_method.rb', line 1566

def created
  @created
end

#customerObject (readonly)

The ID of the Customer to which this PaymentMethod is saved. This will not be set when the PaymentMethod has not been saved to a Customer.



1568
1569
1570
# File 'lib/stripe/resources/payment_method.rb', line 1568

def customer
  @customer
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



1570
1571
1572
# File 'lib/stripe/resources/payment_method.rb', line 1570

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



1572
1573
1574
# File 'lib/stripe/resources/payment_method.rb', line 1572

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



1574
1575
1576
# File 'lib/stripe/resources/payment_method.rb', line 1574

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



1576
1577
1578
# File 'lib/stripe/resources/payment_method.rb', line 1576

def giropay
  @giropay
end

#gopayObject (readonly)

Attribute for field gopay



1578
1579
1580
# File 'lib/stripe/resources/payment_method.rb', line 1578

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



1580
1581
1582
# File 'lib/stripe/resources/payment_method.rb', line 1580

def grabpay
  @grabpay
end

#idObject (readonly)

Unique identifier for the object.



1582
1583
1584
# File 'lib/stripe/resources/payment_method.rb', line 1582

def id
  @id
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



1584
1585
1586
# File 'lib/stripe/resources/payment_method.rb', line 1584

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



1586
1587
1588
# File 'lib/stripe/resources/payment_method.rb', line 1586

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



1588
1589
1590
# File 'lib/stripe/resources/payment_method.rb', line 1588

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



1590
1591
1592
# File 'lib/stripe/resources/payment_method.rb', line 1590

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



1592
1593
1594
# File 'lib/stripe/resources/payment_method.rb', line 1592

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



1594
1595
1596
# File 'lib/stripe/resources/payment_method.rb', line 1594

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



1596
1597
1598
# File 'lib/stripe/resources/payment_method.rb', line 1596

def kr_card
  @kr_card
end

Attribute for field link



1598
1599
1600
# File 'lib/stripe/resources/payment_method.rb', line 1598

def link
  @link
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



1600
1601
1602
# File 'lib/stripe/resources/payment_method.rb', line 1600

def livemode
  @livemode
end

#mb_wayObject (readonly)

Attribute for field mb_way



1602
1603
1604
# File 'lib/stripe/resources/payment_method.rb', line 1602

def mb_way
  @mb_way
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



1604
1605
1606
# File 'lib/stripe/resources/payment_method.rb', line 1604

def 
  @metadata
end

#mobilepayObject (readonly)

Attribute for field mobilepay



1606
1607
1608
# File 'lib/stripe/resources/payment_method.rb', line 1606

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



1608
1609
1610
# File 'lib/stripe/resources/payment_method.rb', line 1608

def multibanco
  @multibanco
end

Attribute for field naver_pay



1610
1611
1612
# File 'lib/stripe/resources/payment_method.rb', line 1610

def naver_pay
  @naver_pay
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



1612
1613
1614
# File 'lib/stripe/resources/payment_method.rb', line 1612

def object
  @object
end

#oxxoObject (readonly)

Attribute for field oxxo



1614
1615
1616
# File 'lib/stripe/resources/payment_method.rb', line 1614

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



1616
1617
1618
# File 'lib/stripe/resources/payment_method.rb', line 1616

def p24
  @p24
end

#paycoObject (readonly)

Attribute for field payco



1618
1619
1620
# File 'lib/stripe/resources/payment_method.rb', line 1618

def payco
  @payco
end

#paynowObject (readonly)

Attribute for field paynow



1620
1621
1622
# File 'lib/stripe/resources/payment_method.rb', line 1620

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



1622
1623
1624
# File 'lib/stripe/resources/payment_method.rb', line 1622

def paypal
  @paypal
end

#paytoObject (readonly)

Attribute for field payto



1624
1625
1626
# File 'lib/stripe/resources/payment_method.rb', line 1624

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



1626
1627
1628
# File 'lib/stripe/resources/payment_method.rb', line 1626

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



1628
1629
1630
# File 'lib/stripe/resources/payment_method.rb', line 1628

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



1630
1631
1632
# File 'lib/stripe/resources/payment_method.rb', line 1630

def qris
  @qris
end

#radar_optionsObject (readonly)

Options to configure Radar. See [Radar Session](stripe.com/docs/radar/radar-session) for more information.



1632
1633
1634
# File 'lib/stripe/resources/payment_method.rb', line 1632

def radar_options
  @radar_options
end

#rechnungObject (readonly)

Attribute for field rechnung



1634
1635
1636
# File 'lib/stripe/resources/payment_method.rb', line 1634

def rechnung
  @rechnung
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



1636
1637
1638
# File 'lib/stripe/resources/payment_method.rb', line 1636

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



1638
1639
1640
# File 'lib/stripe/resources/payment_method.rb', line 1638

def samsung_pay
  @samsung_pay
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



1640
1641
1642
# File 'lib/stripe/resources/payment_method.rb', line 1640

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



1642
1643
1644
# File 'lib/stripe/resources/payment_method.rb', line 1642

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



1644
1645
1646
# File 'lib/stripe/resources/payment_method.rb', line 1644

def sofort
  @sofort
end

#swishObject (readonly)

Attribute for field swish



1646
1647
1648
# File 'lib/stripe/resources/payment_method.rb', line 1646

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



1648
1649
1650
# File 'lib/stripe/resources/payment_method.rb', line 1648

def twint
  @twint
end

#typeObject (readonly)

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



1650
1651
1652
# File 'lib/stripe/resources/payment_method.rb', line 1650

def type
  @type
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



1652
1653
1654
# File 'lib/stripe/resources/payment_method.rb', line 1652

def 
  @us_bank_account
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



1654
1655
1656
# File 'lib/stripe/resources/payment_method.rb', line 1654

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



1656
1657
1658
# File 'lib/stripe/resources/payment_method.rb', line 1656

def zip
  @zip
end

Class Method Details

.attach(payment_method, params = {}, opts = {}) ⇒ Object

Attaches a PaymentMethod object to a Customer.

To attach a new PaymentMethod to a customer for future payments, we recommend you use a [SetupIntent](stripe.com/docs/api/setup_intents) or a PaymentIntent with [setup_future_usage](stripe.com/docs/api/payment_intents/create#create_payment_intent-setup_future_usage). These approaches will perform any necessary steps to set up the PaymentMethod for future payments. Using the /v1/payment_methods/:id/attach endpoint without first using a SetupIntent or PaymentIntent with setup_future_usage does not optimize the PaymentMethod for future use, which makes later declines and payment friction more likely. See [Optimizing cards for future payments](stripe.com/docs/payments/payment-intents#future-usage) for more information about setting up future payments.

To use this PaymentMethod as the default for invoice or subscription payments, set [invoice_settings.default_payment_method](stripe.com/docs/api/customers/update#update_customer-invoice_settings-default_payment_method), on the Customer to the PaymentMethod’s ID.



1693
1694
1695
1696
1697
1698
1699
1700
# File 'lib/stripe/resources/payment_method.rb', line 1693

def self.attach(payment_method, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_methods/%<payment_method>s/attach", { payment_method: CGI.escape(payment_method) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

Creates a PaymentMethod object. Read the [Stripe.js reference](stripe.com/docs/stripe-js/reference#stripe-create-payment-method) to learn how to create PaymentMethods via Stripe.js.

Instead of creating a PaymentMethod directly, we recommend using the [PaymentIntents API to accept a payment immediately or the <a href=“/docs/payments/save-and-reuse”>SetupIntent](stripe.com/docs/payments/accept-a-payment) API to collect payment method details ahead of a future payment.



1705
1706
1707
# File 'lib/stripe/resources/payment_method.rb', line 1705

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/payment_methods", params: params, opts: opts)
end

.detach(payment_method, params = {}, opts = {}) ⇒ Object

Detaches a PaymentMethod object from a Customer. After a PaymentMethod is detached, it can no longer be used for a payment or re-attached to a Customer.



1720
1721
1722
1723
1724
1725
1726
1727
# File 'lib/stripe/resources/payment_method.rb', line 1720

def self.detach(payment_method, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_methods/%<payment_method>s/detach", { payment_method: CGI.escape(payment_method) }),
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of PaymentMethods for Treasury flows. If you want to list the PaymentMethods attached to a Customer for payments, you should use the [List a Customer’s PaymentMethods](stripe.com/docs/api/payment_methods/customer_list) API instead.



1730
1731
1732
# File 'lib/stripe/resources/payment_method.rb', line 1730

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/payment_methods", params: params, opts: opts)
end

.object_nameObject



16
17
18
# File 'lib/stripe/resources/payment_method.rb', line 16

def self.object_name
  "payment_method"
end

.update(id, params = {}, opts = {}) ⇒ Object

Updates a PaymentMethod object. A PaymentMethod must be attached a customer to be updated.



1735
1736
1737
1738
1739
1740
1741
1742
# File 'lib/stripe/resources/payment_method.rb', line 1735

def self.update(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_methods/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#attach(params = {}, opts = {}) ⇒ Object

Attaches a PaymentMethod object to a Customer.

To attach a new PaymentMethod to a customer for future payments, we recommend you use a [SetupIntent](stripe.com/docs/api/setup_intents) or a PaymentIntent with [setup_future_usage](stripe.com/docs/api/payment_intents/create#create_payment_intent-setup_future_usage). These approaches will perform any necessary steps to set up the PaymentMethod for future payments. Using the /v1/payment_methods/:id/attach endpoint without first using a SetupIntent or PaymentIntent with setup_future_usage does not optimize the PaymentMethod for future use, which makes later declines and payment friction more likely. See [Optimizing cards for future payments](stripe.com/docs/payments/payment-intents#future-usage) for more information about setting up future payments.

To use this PaymentMethod as the default for invoice or subscription payments, set [invoice_settings.default_payment_method](stripe.com/docs/api/customers/update#update_customer-invoice_settings-default_payment_method), on the Customer to the PaymentMethod’s ID.



1671
1672
1673
1674
1675
1676
1677
1678
# File 'lib/stripe/resources/payment_method.rb', line 1671

def attach(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_methods/%<payment_method>s/attach", { payment_method: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#detach(params = {}, opts = {}) ⇒ Object

Detaches a PaymentMethod object from a Customer. After a PaymentMethod is detached, it can no longer be used for a payment or re-attached to a Customer.



1710
1711
1712
1713
1714
1715
1716
1717
# File 'lib/stripe/resources/payment_method.rb', line 1710

def detach(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_methods/%<payment_method>s/detach", { payment_method: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end