Class: Stripe::PaymentMethod
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::PaymentMethod
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/payment_method.rb
Overview
PaymentMethod objects represent your customer’s payment instruments. You can use them with [PaymentIntents](stripe.com/docs/payments/payment-intents) to collect payments or save them to Customer objects to store instrument details for future payments.
Related guides: [Payment Methods](stripe.com/docs/payments/payment-methods) and [More Payment Scenarios](stripe.com/docs/payments/more-payment-scenarios).
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, Oxxo, P24, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, RadarOptions, Rechnung, RevolutPay, SamsungPay, SepaDebit, Shopeepay, Sofort, Swish, Twint, UsBankAccount, WechatPay, Zip
Constant Summary collapse
- OBJECT_NAME =
"payment_method"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#allow_redisplay ⇒ Object
readonly
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billing_details ⇒ Object
readonly
Attribute for field billing_details.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#customer ⇒ Object
readonly
The ID of the Customer to which this PaymentMethod is saved.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#interac_present ⇒ Object
readonly
Attribute for field interac_present.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#radar_options ⇒ Object
readonly
Options to configure Radar.
-
#rechnung ⇒ Object
readonly
Attribute for field rechnung.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of the PaymentMethod.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.attach(payment_method, params = {}, opts = {}) ⇒ Object
Attaches a PaymentMethod object to a Customer.
-
.create(params = {}, opts = {}) ⇒ Object
Creates a PaymentMethod object.
-
.detach(payment_method, params = {}, opts = {}) ⇒ Object
Detaches a PaymentMethod object from a Customer.
-
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of PaymentMethods for Treasury flows.
- .object_name ⇒ Object
-
.update(id, params = {}, opts = {}) ⇒ Object
Updates a PaymentMethod object.
Instance Method Summary collapse
-
#attach(params = {}, opts = {}) ⇒ Object
Attaches a PaymentMethod object to a Customer.
-
#detach(params = {}, opts = {}) ⇒ Object
Detaches a PaymentMethod object from a Customer.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
264 265 266 |
# File 'lib/stripe/resources/payment_method.rb', line 264 def acss_debit @acss_debit end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
266 267 268 |
# File 'lib/stripe/resources/payment_method.rb', line 266 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
268 269 270 |
# File 'lib/stripe/resources/payment_method.rb', line 268 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
270 271 272 |
# File 'lib/stripe/resources/payment_method.rb', line 270 def alipay @alipay end |
#allow_redisplay ⇒ Object (readonly)
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.
272 273 274 |
# File 'lib/stripe/resources/payment_method.rb', line 272 def allow_redisplay @allow_redisplay end |
#alma ⇒ Object (readonly)
Attribute for field alma
274 275 276 |
# File 'lib/stripe/resources/payment_method.rb', line 274 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
276 277 278 |
# File 'lib/stripe/resources/payment_method.rb', line 276 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
278 279 280 |
# File 'lib/stripe/resources/payment_method.rb', line 278 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
280 281 282 |
# File 'lib/stripe/resources/payment_method.rb', line 280 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
282 283 284 |
# File 'lib/stripe/resources/payment_method.rb', line 282 def bancontact @bancontact end |
#billing_details ⇒ Object (readonly)
Attribute for field billing_details
284 285 286 |
# File 'lib/stripe/resources/payment_method.rb', line 284 def billing_details @billing_details end |
#blik ⇒ Object (readonly)
Attribute for field blik
286 287 288 |
# File 'lib/stripe/resources/payment_method.rb', line 286 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
288 289 290 |
# File 'lib/stripe/resources/payment_method.rb', line 288 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
290 291 292 |
# File 'lib/stripe/resources/payment_method.rb', line 290 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
292 293 294 |
# File 'lib/stripe/resources/payment_method.rb', line 292 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
294 295 296 |
# File 'lib/stripe/resources/payment_method.rb', line 294 def cashapp @cashapp end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
296 297 298 |
# File 'lib/stripe/resources/payment_method.rb', line 296 def created @created end |
#customer ⇒ Object (readonly)
The ID of the Customer to which this PaymentMethod is saved. This will not be set when the PaymentMethod has not been saved to a Customer.
298 299 300 |
# File 'lib/stripe/resources/payment_method.rb', line 298 def customer @customer end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
300 301 302 |
# File 'lib/stripe/resources/payment_method.rb', line 300 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
302 303 304 |
# File 'lib/stripe/resources/payment_method.rb', line 302 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
304 305 306 |
# File 'lib/stripe/resources/payment_method.rb', line 304 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
306 307 308 |
# File 'lib/stripe/resources/payment_method.rb', line 306 def giropay @giropay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
308 309 310 |
# File 'lib/stripe/resources/payment_method.rb', line 308 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
310 311 312 |
# File 'lib/stripe/resources/payment_method.rb', line 310 def grabpay @grabpay end |
#id ⇒ Object (readonly)
Unique identifier for the object.
312 313 314 |
# File 'lib/stripe/resources/payment_method.rb', line 312 def id @id end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
314 315 316 |
# File 'lib/stripe/resources/payment_method.rb', line 314 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
316 317 318 |
# File 'lib/stripe/resources/payment_method.rb', line 316 def ideal @ideal end |
#interac_present ⇒ Object (readonly)
Attribute for field interac_present
318 319 320 |
# File 'lib/stripe/resources/payment_method.rb', line 318 def interac_present @interac_present end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
320 321 322 |
# File 'lib/stripe/resources/payment_method.rb', line 320 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
322 323 324 |
# File 'lib/stripe/resources/payment_method.rb', line 322 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
324 325 326 |
# File 'lib/stripe/resources/payment_method.rb', line 324 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
326 327 328 |
# File 'lib/stripe/resources/payment_method.rb', line 326 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
328 329 330 |
# File 'lib/stripe/resources/payment_method.rb', line 328 def link @link end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
330 331 332 |
# File 'lib/stripe/resources/payment_method.rb', line 330 def livemode @livemode end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
332 333 334 |
# File 'lib/stripe/resources/payment_method.rb', line 332 def mb_way @mb_way end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
334 335 336 |
# File 'lib/stripe/resources/payment_method.rb', line 334 def @metadata end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
336 337 338 |
# File 'lib/stripe/resources/payment_method.rb', line 336 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
338 339 340 |
# File 'lib/stripe/resources/payment_method.rb', line 338 def multibanco @multibanco end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
340 341 342 |
# File 'lib/stripe/resources/payment_method.rb', line 340 def naver_pay @naver_pay end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
342 343 344 |
# File 'lib/stripe/resources/payment_method.rb', line 342 def object @object end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
344 345 346 |
# File 'lib/stripe/resources/payment_method.rb', line 344 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
346 347 348 |
# File 'lib/stripe/resources/payment_method.rb', line 346 def p24 @p24 end |
#payco ⇒ Object (readonly)
Attribute for field payco
348 349 350 |
# File 'lib/stripe/resources/payment_method.rb', line 348 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
350 351 352 |
# File 'lib/stripe/resources/payment_method.rb', line 350 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
352 353 354 |
# File 'lib/stripe/resources/payment_method.rb', line 352 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
354 355 356 |
# File 'lib/stripe/resources/payment_method.rb', line 354 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
356 357 358 |
# File 'lib/stripe/resources/payment_method.rb', line 356 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
358 359 360 |
# File 'lib/stripe/resources/payment_method.rb', line 358 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
360 361 362 |
# File 'lib/stripe/resources/payment_method.rb', line 360 def qris @qris end |
#radar_options ⇒ Object (readonly)
Options to configure Radar. See [Radar Session](stripe.com/docs/radar/radar-session) for more information.
362 363 364 |
# File 'lib/stripe/resources/payment_method.rb', line 362 def @radar_options end |
#rechnung ⇒ Object (readonly)
Attribute for field rechnung
364 365 366 |
# File 'lib/stripe/resources/payment_method.rb', line 364 def rechnung @rechnung end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
366 367 368 |
# File 'lib/stripe/resources/payment_method.rb', line 366 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
368 369 370 |
# File 'lib/stripe/resources/payment_method.rb', line 368 def samsung_pay @samsung_pay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
370 371 372 |
# File 'lib/stripe/resources/payment_method.rb', line 370 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
372 373 374 |
# File 'lib/stripe/resources/payment_method.rb', line 372 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
374 375 376 |
# File 'lib/stripe/resources/payment_method.rb', line 374 def sofort @sofort end |
#swish ⇒ Object (readonly)
Attribute for field swish
376 377 378 |
# File 'lib/stripe/resources/payment_method.rb', line 376 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
378 379 380 |
# File 'lib/stripe/resources/payment_method.rb', line 378 def twint @twint end |
#type ⇒ Object (readonly)
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
380 381 382 |
# File 'lib/stripe/resources/payment_method.rb', line 380 def type @type end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
382 383 384 |
# File 'lib/stripe/resources/payment_method.rb', line 382 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
384 385 386 |
# File 'lib/stripe/resources/payment_method.rb', line 384 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
386 387 388 |
# File 'lib/stripe/resources/payment_method.rb', line 386 def zip @zip end |
Class Method Details
.attach(payment_method, params = {}, opts = {}) ⇒ Object
Attaches a PaymentMethod object to a Customer.
To attach a new PaymentMethod to a customer for future payments, we recommend you use a [SetupIntent](stripe.com/docs/api/setup_intents) or a PaymentIntent with [setup_future_usage](stripe.com/docs/api/payment_intents/create#create_payment_intent-setup_future_usage). These approaches will perform any necessary steps to set up the PaymentMethod for future payments. Using the /v1/payment_methods/:id/attach endpoint without first using a SetupIntent or PaymentIntent with setup_future_usage does not optimize the PaymentMethod for future use, which makes later declines and payment friction more likely. See [Optimizing cards for future payments](stripe.com/docs/payments/payment-intents#future-usage) for more information about setting up future payments.
To use this PaymentMethod as the default for invoice or subscription payments, set [invoice_settings.default_payment_method](stripe.com/docs/api/customers/update#update_customer-invoice_settings-default_payment_method), on the Customer to the PaymentMethod’s ID.
423 424 425 426 427 428 429 430 |
# File 'lib/stripe/resources/payment_method.rb', line 423 def self.attach(payment_method, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_methods/%<payment_method>s/attach", { payment_method: CGI.escape(payment_method) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
Creates a PaymentMethod object. Read the [Stripe.js reference](stripe.com/docs/stripe-js/reference#stripe-create-payment-method) to learn how to create PaymentMethods via Stripe.js.
Instead of creating a PaymentMethod directly, we recommend using the [PaymentIntents API to accept a payment immediately or the <a href=“/docs/payments/save-and-reuse”>SetupIntent](stripe.com/docs/payments/accept-a-payment) API to collect payment method details ahead of a future payment.
435 436 437 |
# File 'lib/stripe/resources/payment_method.rb', line 435 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/payment_methods", params: params, opts: opts) end |
.detach(payment_method, params = {}, opts = {}) ⇒ Object
Detaches a PaymentMethod object from a Customer. After a PaymentMethod is detached, it can no longer be used for a payment or re-attached to a Customer.
450 451 452 453 454 455 456 457 |
# File 'lib/stripe/resources/payment_method.rb', line 450 def self.detach(payment_method, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_methods/%<payment_method>s/detach", { payment_method: CGI.escape(payment_method) }), params: params, opts: opts ) end |
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of PaymentMethods for Treasury flows. If you want to list the PaymentMethods attached to a Customer for payments, you should use the [List a Customer’s PaymentMethods](stripe.com/docs/api/payment_methods/customer_list) API instead.
460 461 462 |
# File 'lib/stripe/resources/payment_method.rb', line 460 def self.list(filters = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/payment_methods", params: filters, opts: opts) end |
.object_name ⇒ Object
16 17 18 |
# File 'lib/stripe/resources/payment_method.rb', line 16 def self.object_name "payment_method" end |
.update(id, params = {}, opts = {}) ⇒ Object
Updates a PaymentMethod object. A PaymentMethod must be attached a customer to be updated.
465 466 467 468 469 470 471 472 |
# File 'lib/stripe/resources/payment_method.rb', line 465 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_methods/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |
Instance Method Details
#attach(params = {}, opts = {}) ⇒ Object
Attaches a PaymentMethod object to a Customer.
To attach a new PaymentMethod to a customer for future payments, we recommend you use a [SetupIntent](stripe.com/docs/api/setup_intents) or a PaymentIntent with [setup_future_usage](stripe.com/docs/api/payment_intents/create#create_payment_intent-setup_future_usage). These approaches will perform any necessary steps to set up the PaymentMethod for future payments. Using the /v1/payment_methods/:id/attach endpoint without first using a SetupIntent or PaymentIntent with setup_future_usage does not optimize the PaymentMethod for future use, which makes later declines and payment friction more likely. See [Optimizing cards for future payments](stripe.com/docs/payments/payment-intents#future-usage) for more information about setting up future payments.
To use this PaymentMethod as the default for invoice or subscription payments, set [invoice_settings.default_payment_method](stripe.com/docs/api/customers/update#update_customer-invoice_settings-default_payment_method), on the Customer to the PaymentMethod’s ID.
401 402 403 404 405 406 407 408 |
# File 'lib/stripe/resources/payment_method.rb', line 401 def attach(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_methods/%<payment_method>s/attach", { payment_method: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#detach(params = {}, opts = {}) ⇒ Object
Detaches a PaymentMethod object from a Customer. After a PaymentMethod is detached, it can no longer be used for a payment or re-attached to a Customer.
440 441 442 443 444 445 446 447 |
# File 'lib/stripe/resources/payment_method.rb', line 440 def detach(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_methods/%<payment_method>s/detach", { payment_method: CGI.escape(self["id"]) }), params: params, opts: opts ) end |