Class: Stripe::PaymentMethod::AttachParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_method.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, expand: nil) ⇒ AttachParams

Returns a new instance of AttachParams.



1386
1387
1388
1389
# File 'lib/stripe/resources/payment_method.rb', line 1386

def initialize(customer: nil, expand: nil)
  @customer = customer
  @expand = expand
end

Instance Attribute Details

#customerObject

The ID of the customer to which to attach the PaymentMethod.



1382
1383
1384
# File 'lib/stripe/resources/payment_method.rb', line 1382

def customer
  @customer
end

#expandObject

Specifies which fields in the response should be expanded.



1384
1385
1386
# File 'lib/stripe/resources/payment_method.rb', line 1384

def expand
  @expand
end