Class: Stripe::PaymentMethod::AttachParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_method.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, customer_account: nil, expand: nil) ⇒ AttachParams

Returns a new instance of AttachParams.



1558
1559
1560
1561
1562
# File 'lib/stripe/resources/payment_method.rb', line 1558

def initialize(customer: nil, customer_account: nil, expand: nil)
  @customer = customer
  @customer_account = 
  @expand = expand
end

Instance Attribute Details

#customerObject

The ID of the customer to which to attach the PaymentMethod.



1552
1553
1554
# File 'lib/stripe/resources/payment_method.rb', line 1552

def customer
  @customer
end

#customer_accountObject

The ID of the account to which to attach the PaymentMethod.



1554
1555
1556
# File 'lib/stripe/resources/payment_method.rb', line 1554

def 
  @customer_account
end

#expandObject

Specifies which fields in the response should be expanded.



1556
1557
1558
# File 'lib/stripe/resources/payment_method.rb', line 1556

def expand
  @expand
end