Class: Stripe::PaymentMethod::AttachParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethod::AttachParams
- Defined in:
- lib/stripe/resources/payment_method.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of the customer to which to attach the PaymentMethod.
-
#customer_account ⇒ Object
The ID of the account to which to attach the PaymentMethod.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(customer: nil, customer_account: nil, expand: nil) ⇒ AttachParams
constructor
A new instance of AttachParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, customer_account: nil, expand: nil) ⇒ AttachParams
Returns a new instance of AttachParams.
1552 1553 1554 1555 1556 |
# File 'lib/stripe/resources/payment_method.rb', line 1552 def initialize(customer: nil, customer_account: nil, expand: nil) @customer = customer @customer_account = customer_account @expand = end |
Instance Attribute Details
#customer ⇒ Object
The ID of the customer to which to attach the PaymentMethod.
1546 1547 1548 |
# File 'lib/stripe/resources/payment_method.rb', line 1546 def customer @customer end |
#customer_account ⇒ Object
The ID of the account to which to attach the PaymentMethod.
1548 1549 1550 |
# File 'lib/stripe/resources/payment_method.rb', line 1548 def customer_account @customer_account end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1550 1551 1552 |
# File 'lib/stripe/resources/payment_method.rb', line 1550 def @expand end |