Class: Stripe::PaymentMethod::AttachParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_method.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, customer_account: nil, expand: nil) ⇒ AttachParams

Returns a new instance of AttachParams.



1615
1616
1617
1618
1619
# File 'lib/stripe/resources/payment_method.rb', line 1615

def initialize(customer: nil, customer_account: nil, expand: nil)
  @customer = customer
  @customer_account = 
  @expand = expand
end

Instance Attribute Details

#customerObject

The ID of the customer to which to attach the PaymentMethod.



1609
1610
1611
# File 'lib/stripe/resources/payment_method.rb', line 1609

def customer
  @customer
end

#customer_accountObject

The ID of the account to which to attach the PaymentMethod.



1611
1612
1613
# File 'lib/stripe/resources/payment_method.rb', line 1611

def 
  @customer_account
end

#expandObject

Specifies which fields in the response should be expanded.



1613
1614
1615
# File 'lib/stripe/resources/payment_method.rb', line 1613

def expand
  @expand
end