Class: Stripe::PaymentMethod::AttachParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethod::AttachParams
- Defined in:
- lib/stripe/resources/payment_method.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of the customer to which to attach the PaymentMethod.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(customer: nil, expand: nil) ⇒ AttachParams
constructor
A new instance of AttachParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, expand: nil) ⇒ AttachParams
Returns a new instance of AttachParams.
1437 1438 1439 1440 |
# File 'lib/stripe/resources/payment_method.rb', line 1437 def initialize(customer: nil, expand: nil) @customer = customer @expand = end |
Instance Attribute Details
#customer ⇒ Object
The ID of the customer to which to attach the PaymentMethod.
1433 1434 1435 |
# File 'lib/stripe/resources/payment_method.rb', line 1433 def customer @customer end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1435 1436 1437 |
# File 'lib/stripe/resources/payment_method.rb', line 1435 def @expand end |