Class: Stripe::PaymentMethod::AttachParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_method.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, customer_account: nil, expand: nil) ⇒ AttachParams

Returns a new instance of AttachParams.



1605
1606
1607
1608
1609
# File 'lib/stripe/resources/payment_method.rb', line 1605

def initialize(customer: nil, customer_account: nil, expand: nil)
  @customer = customer
  @customer_account = 
  @expand = expand
end

Instance Attribute Details

#customerObject

The ID of the customer to which to attach the PaymentMethod.



1599
1600
1601
# File 'lib/stripe/resources/payment_method.rb', line 1599

def customer
  @customer
end

#customer_accountObject

The ID of the account to which to attach the PaymentMethod.



1601
1602
1603
# File 'lib/stripe/resources/payment_method.rb', line 1601

def 
  @customer_account
end

#expandObject

Specifies which fields in the response should be expanded.



1603
1604
1605
# File 'lib/stripe/resources/payment_method.rb', line 1603

def expand
  @expand
end