Class: Stripe::PaymentMethod::AttachParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethod::AttachParams
- Defined in:
- lib/stripe/resources/payment_method.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of the customer to which to attach the PaymentMethod.
-
#customer_account ⇒ Object
The ID of the account to which to attach the PaymentMethod.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(customer: nil, customer_account: nil, expand: nil) ⇒ AttachParams
constructor
A new instance of AttachParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, customer_account: nil, expand: nil) ⇒ AttachParams
Returns a new instance of AttachParams.
1613 1614 1615 1616 1617 |
# File 'lib/stripe/resources/payment_method.rb', line 1613 def initialize(customer: nil, customer_account: nil, expand: nil) @customer = customer @customer_account = customer_account @expand = end |
Instance Attribute Details
#customer ⇒ Object
The ID of the customer to which to attach the PaymentMethod.
1607 1608 1609 |
# File 'lib/stripe/resources/payment_method.rb', line 1607 def customer @customer end |
#customer_account ⇒ Object
The ID of the account to which to attach the PaymentMethod.
1609 1610 1611 |
# File 'lib/stripe/resources/payment_method.rb', line 1609 def customer_account @customer_account end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1611 1612 1613 |
# File 'lib/stripe/resources/payment_method.rb', line 1611 def @expand end |