Class: Stripe::PaymentMethod::AttachParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethod::AttachParams
- Defined in:
- lib/stripe/resources/payment_method.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of the customer to which to attach the PaymentMethod.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(customer: nil, expand: nil) ⇒ AttachParams
constructor
A new instance of AttachParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, expand: nil) ⇒ AttachParams
Returns a new instance of AttachParams.
1534 1535 1536 1537 |
# File 'lib/stripe/resources/payment_method.rb', line 1534 def initialize(customer: nil, expand: nil) @customer = customer @expand = end |
Instance Attribute Details
#customer ⇒ Object
The ID of the customer to which to attach the PaymentMethod.
1530 1531 1532 |
# File 'lib/stripe/resources/payment_method.rb', line 1530 def customer @customer end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1532 1533 1534 |
# File 'lib/stripe/resources/payment_method.rb', line 1532 def @expand end |