Class: Stripe::PaymentMethod::AttachParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethod::AttachParams
- Defined in:
- lib/stripe/resources/payment_method.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of the customer to which to attach the PaymentMethod.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(customer: nil, expand: nil) ⇒ AttachParams
constructor
A new instance of AttachParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, expand: nil) ⇒ AttachParams
Returns a new instance of AttachParams.
1519 1520 1521 1522 |
# File 'lib/stripe/resources/payment_method.rb', line 1519 def initialize(customer: nil, expand: nil) @customer = customer @expand = end |
Instance Attribute Details
#customer ⇒ Object
The ID of the customer to which to attach the PaymentMethod.
1515 1516 1517 |
# File 'lib/stripe/resources/payment_method.rb', line 1515 def customer @customer end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1517 1518 1519 |
# File 'lib/stripe/resources/payment_method.rb', line 1517 def @expand end |