Class: Stripe::PaymentMethod::Card

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_method.rb

Defined Under Namespace

Classes: Benefits, Checks, GeneratedFrom, Networks, ThreeDSecureUsage, Wallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#benefitsObject (readonly)

Attribute for field benefits



679
680
681
# File 'lib/stripe/resources/payment_method.rb', line 679

def benefits
  @benefits
end

#brandObject (readonly)

Card brand. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa` or `unknown`.



643
644
645
# File 'lib/stripe/resources/payment_method.rb', line 643

def brand
  @brand
end

#checksObject (readonly)

Checks on Card address and CVC if provided.



645
646
647
# File 'lib/stripe/resources/payment_method.rb', line 645

def checks
  @checks
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



647
648
649
# File 'lib/stripe/resources/payment_method.rb', line 647

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



649
650
651
# File 'lib/stripe/resources/payment_method.rb', line 649

def description
  @description
end

#display_brandObject (readonly)

The brand to use when displaying the card, this accounts for customer’s brand choice on dual-branded cards. Can be ‘american_express`, `cartes_bancaires`, `diners_club`, `discover`, `eftpos_australia`, `interac`, `jcb`, `mastercard`, `union_pay`, `visa`, or `other` and may contain more values in the future.



651
652
653
# File 'lib/stripe/resources/payment_method.rb', line 651

def display_brand
  @display_brand
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



653
654
655
# File 'lib/stripe/resources/payment_method.rb', line 653

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



655
656
657
# File 'lib/stripe/resources/payment_method.rb', line 655

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*



659
660
661
# File 'lib/stripe/resources/payment_method.rb', line 659

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



661
662
663
# File 'lib/stripe/resources/payment_method.rb', line 661

def funding
  @funding
end

#generated_fromObject (readonly)

Details of the original PaymentMethod that created this object.



663
664
665
# File 'lib/stripe/resources/payment_method.rb', line 663

def generated_from
  @generated_from
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



665
666
667
# File 'lib/stripe/resources/payment_method.rb', line 665

def iin
  @iin
end

#issuerObject (readonly)

The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)



667
668
669
# File 'lib/stripe/resources/payment_method.rb', line 667

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



669
670
671
# File 'lib/stripe/resources/payment_method.rb', line 669

def last4
  @last4
end

#networksObject (readonly)

Contains information about card networks that can be used to process the payment.



671
672
673
# File 'lib/stripe/resources/payment_method.rb', line 671

def networks
  @networks
end

#regulated_statusObject (readonly)

Status of a card based on the card issuer.



673
674
675
# File 'lib/stripe/resources/payment_method.rb', line 673

def regulated_status
  @regulated_status
end

#three_d_secure_usageObject (readonly)

Contains details on how this Card may be used for 3D Secure authentication.



675
676
677
# File 'lib/stripe/resources/payment_method.rb', line 675

def three_d_secure_usage
  @three_d_secure_usage
end

#walletObject (readonly)

If this Card is part of a card wallet, this contains the details of the card wallet.



677
678
679
# File 'lib/stripe/resources/payment_method.rb', line 677

def wallet
  @wallet
end

Class Method Details

.field_remappingsObject



692
693
694
# File 'lib/stripe/resources/payment_method.rb', line 692

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



681
682
683
684
685
686
687
688
689
690
# File 'lib/stripe/resources/payment_method.rb', line 681

def self.inner_class_types
  @inner_class_types = {
    checks: Checks,
    generated_from: GeneratedFrom,
    networks: Networks,
    three_d_secure_usage: ThreeDSecureUsage,
    wallet: Wallet,
    benefits: Benefits,
  }
end