Class: Stripe::PaymentMethod::Card

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_method.rb

Defined Under Namespace

Classes: Checks, GeneratedFrom, Networks, ThreeDSecureUsage, Wallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

Card brand. Can be ‘amex`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.



321
322
323
# File 'lib/stripe/resources/payment_method.rb', line 321

def brand
  @brand
end

#checksObject (readonly)

Checks on Card address and CVC if provided.



323
324
325
# File 'lib/stripe/resources/payment_method.rb', line 323

def checks
  @checks
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



325
326
327
# File 'lib/stripe/resources/payment_method.rb', line 325

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



327
328
329
# File 'lib/stripe/resources/payment_method.rb', line 327

def description
  @description
end

#display_brandObject (readonly)

The brand to use when displaying the card, this accounts for customer’s brand choice on dual-branded cards. Can be ‘american_express`, `cartes_bancaires`, `diners_club`, `discover`, `eftpos_australia`, `interac`, `jcb`, `mastercard`, `union_pay`, `visa`, or `other` and may contain more values in the future.



329
330
331
# File 'lib/stripe/resources/payment_method.rb', line 329

def display_brand
  @display_brand
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



331
332
333
# File 'lib/stripe/resources/payment_method.rb', line 331

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



333
334
335
# File 'lib/stripe/resources/payment_method.rb', line 333

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*



337
338
339
# File 'lib/stripe/resources/payment_method.rb', line 337

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



339
340
341
# File 'lib/stripe/resources/payment_method.rb', line 339

def funding
  @funding
end

#generated_fromObject (readonly)

Details of the original PaymentMethod that created this object.



341
342
343
# File 'lib/stripe/resources/payment_method.rb', line 341

def generated_from
  @generated_from
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



343
344
345
# File 'lib/stripe/resources/payment_method.rb', line 343

def iin
  @iin
end

#issuerObject (readonly)

The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)



345
346
347
# File 'lib/stripe/resources/payment_method.rb', line 345

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



347
348
349
# File 'lib/stripe/resources/payment_method.rb', line 347

def last4
  @last4
end

#networksObject (readonly)

Contains information about card networks that can be used to process the payment.



349
350
351
# File 'lib/stripe/resources/payment_method.rb', line 349

def networks
  @networks
end

#regulated_statusObject (readonly)

Status of a card based on the card issuer.



351
352
353
# File 'lib/stripe/resources/payment_method.rb', line 351

def regulated_status
  @regulated_status
end

#three_d_secure_usageObject (readonly)

Contains details on how this Card may be used for 3D Secure authentication.



353
354
355
# File 'lib/stripe/resources/payment_method.rb', line 353

def three_d_secure_usage
  @three_d_secure_usage
end

#walletObject (readonly)

If this Card is part of a card wallet, this contains the details of the card wallet.



355
356
357
# File 'lib/stripe/resources/payment_method.rb', line 355

def wallet
  @wallet
end