Class: Stripe::PaymentMethod::Card::GeneratedFrom::PaymentMethodDetails::CardPresent

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_method.rb

Defined Under Namespace

Classes: Offline, Reauthorization, Receipt, Wallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_authorizedObject (readonly)

The authorized amount



329
330
331
# File 'lib/stripe/resources/payment_method.rb', line 329

def amount_authorized
  @amount_authorized
end

#brandObject (readonly)

Card brand. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa` or `unknown`.



331
332
333
# File 'lib/stripe/resources/payment_method.rb', line 331

def brand
  @brand
end

#brand_productObject (readonly)

The [product code](stripe.com/docs/card-product-codes) that identifies the specific program or product associated with a card.



333
334
335
# File 'lib/stripe/resources/payment_method.rb', line 333

def brand_product
  @brand_product
end

#capture_beforeObject (readonly)

When using manual capture, a future timestamp after which the charge will be automatically refunded if uncaptured.



335
336
337
# File 'lib/stripe/resources/payment_method.rb', line 335

def capture_before
  @capture_before
end

#cardholder_nameObject (readonly)

The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format. May include alphanumeric characters, special characters and first/last name separator (‘/`). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.



337
338
339
# File 'lib/stripe/resources/payment_method.rb', line 337

def cardholder_name
  @cardholder_name
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



339
340
341
# File 'lib/stripe/resources/payment_method.rb', line 339

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



341
342
343
# File 'lib/stripe/resources/payment_method.rb', line 341

def description
  @description
end

#emv_auth_dataObject (readonly)

Authorization response cryptogram.



343
344
345
# File 'lib/stripe/resources/payment_method.rb', line 343

def emv_auth_data
  @emv_auth_data
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



345
346
347
# File 'lib/stripe/resources/payment_method.rb', line 345

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



347
348
349
# File 'lib/stripe/resources/payment_method.rb', line 347

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*



351
352
353
# File 'lib/stripe/resources/payment_method.rb', line 351

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



353
354
355
# File 'lib/stripe/resources/payment_method.rb', line 353

def funding
  @funding
end

#generated_cardObject (readonly)

ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions. Only present if it was possible to generate a card PaymentMethod.



355
356
357
# File 'lib/stripe/resources/payment_method.rb', line 355

def generated_card
  @generated_card
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



357
358
359
# File 'lib/stripe/resources/payment_method.rb', line 357

def iin
  @iin
end

#incremental_authorization_supportedObject (readonly)

Whether this [PaymentIntent](docs.stripe.com/api/payment_intents) is eligible for incremental authorizations. Request support using [request_incremental_authorization_support](docs.stripe.com/api/payment_intents/create#create_payment_intent-payment_method_options-card_present-request_incremental_authorization_support).



359
360
361
# File 'lib/stripe/resources/payment_method.rb', line 359

def incremental_authorization_supported
  @incremental_authorization_supported
end

#issuerObject (readonly)

The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)



361
362
363
# File 'lib/stripe/resources/payment_method.rb', line 361

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



363
364
365
# File 'lib/stripe/resources/payment_method.rb', line 363

def last4
  @last4
end

#locationObject (readonly)

ID of the [location](docs.stripe.com/api/terminal/locations) that this transaction’s reader is assigned to.



365
366
367
# File 'lib/stripe/resources/payment_method.rb', line 365

def location
  @location
end

#networkObject (readonly)

Identifies which network this charge was processed on. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `interac`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.



367
368
369
# File 'lib/stripe/resources/payment_method.rb', line 367

def network
  @network
end

#network_transaction_idObject (readonly)

This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.



369
370
371
# File 'lib/stripe/resources/payment_method.rb', line 369

def network_transaction_id
  @network_transaction_id
end

#offlineObject (readonly)

Details about payments collected offline.



371
372
373
# File 'lib/stripe/resources/payment_method.rb', line 371

def offline
  @offline
end

#overcapture_supportedObject (readonly)

Defines whether the authorized amount can be over-captured or not



373
374
375
# File 'lib/stripe/resources/payment_method.rb', line 373

def overcapture_supported
  @overcapture_supported
end

#preferred_localesObject (readonly)

The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card. Referenced from EMV tag 5F2D, data encoded on the card’s chip.



375
376
377
# File 'lib/stripe/resources/payment_method.rb', line 375

def preferred_locales
  @preferred_locales
end

#read_methodObject (readonly)

How card details were read in this transaction.



377
378
379
# File 'lib/stripe/resources/payment_method.rb', line 377

def read_method
  @read_method
end

#readerObject (readonly)

ID of the [reader](docs.stripe.com/api/terminal/readers) this transaction was made on.



379
380
381
# File 'lib/stripe/resources/payment_method.rb', line 379

def reader
  @reader
end

#reauthorizationObject (readonly)

Whether the PaymentIntent can be reauthorized or not.



381
382
383
# File 'lib/stripe/resources/payment_method.rb', line 381

def reauthorization
  @reauthorization
end

#reauthorize_beforeObject (readonly)

The time at which the associated PaymentIntent will transition to a terminal state if it is not reauthorized.



383
384
385
# File 'lib/stripe/resources/payment_method.rb', line 383

def reauthorize_before
  @reauthorize_before
end

#receiptObject (readonly)

A collection of fields required to be displayed on receipts. Only required for EMV transactions.



385
386
387
# File 'lib/stripe/resources/payment_method.rb', line 385

def receipt
  @receipt
end

#walletObject (readonly)

Attribute for field wallet



387
388
389
# File 'lib/stripe/resources/payment_method.rb', line 387

def wallet
  @wallet
end

Class Method Details

.field_remappingsObject



398
399
400
# File 'lib/stripe/resources/payment_method.rb', line 398

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



389
390
391
392
393
394
395
396
# File 'lib/stripe/resources/payment_method.rb', line 389

def self.inner_class_types
  @inner_class_types = {
    offline: Offline,
    reauthorization: Reauthorization,
    receipt: Receipt,
    wallet: Wallet,
  }
end