Class: Stripe::PaymentMethod::Card::GeneratedFrom::PaymentMethodDetails::CardPresent::Receipt
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentMethod::Card::GeneratedFrom::PaymentMethodDetails::CardPresent::Receipt
- Defined in:
- lib/stripe/resources/payment_method.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_type ⇒ Object
readonly
The type of account being debited or credited.
-
#application_cryptogram ⇒ Object
readonly
The Application Cryptogram, a unique value generated by the card to authenticate the transaction with issuers.
-
#application_preferred_name ⇒ Object
readonly
The Application Identifier (AID) on the card used to determine which networks are eligible to process the transaction.
-
#authorization_code ⇒ Object
readonly
Identifier for this transaction.
-
#authorization_response_code ⇒ Object
readonly
EMV tag 8A.
-
#cardholder_verification_method ⇒ Object
readonly
Describes the method used by the cardholder to verify ownership of the card.
-
#dedicated_file_name ⇒ Object
readonly
Similar to the application_preferred_name, identifying the applications (AIDs) available on the card.
-
#terminal_verification_results ⇒ Object
readonly
A 5-byte string that records the checks and validations that occur between the card and the terminal.
-
#transaction_status_information ⇒ Object
readonly
An indication of which steps were completed during the card read process.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_type ⇒ Object (readonly)
The type of account being debited or credited
261 262 263 |
# File 'lib/stripe/resources/payment_method.rb', line 261 def account_type @account_type end |
#application_cryptogram ⇒ Object (readonly)
The Application Cryptogram, a unique value generated by the card to authenticate the transaction with issuers.
263 264 265 |
# File 'lib/stripe/resources/payment_method.rb', line 263 def application_cryptogram @application_cryptogram end |
#application_preferred_name ⇒ Object (readonly)
The Application Identifier (AID) on the card used to determine which networks are eligible to process the transaction. Referenced from EMV tag 9F12, data encoded on the card’s chip.
265 266 267 |
# File 'lib/stripe/resources/payment_method.rb', line 265 def application_preferred_name @application_preferred_name end |
#authorization_code ⇒ Object (readonly)
Identifier for this transaction.
267 268 269 |
# File 'lib/stripe/resources/payment_method.rb', line 267 def @authorization_code end |
#authorization_response_code ⇒ Object (readonly)
EMV tag 8A. A code returned by the card issuer.
269 270 271 |
# File 'lib/stripe/resources/payment_method.rb', line 269 def @authorization_response_code end |
#cardholder_verification_method ⇒ Object (readonly)
Describes the method used by the cardholder to verify ownership of the card. One of the following: ‘approval`, `failure`, `none`, `offline_pin`, `offline_pin_and_signature`, `online_pin`, or `signature`.
271 272 273 |
# File 'lib/stripe/resources/payment_method.rb', line 271 def cardholder_verification_method @cardholder_verification_method end |
#dedicated_file_name ⇒ Object (readonly)
Similar to the application_preferred_name, identifying the applications (AIDs) available on the card. Referenced from EMV tag 84.
273 274 275 |
# File 'lib/stripe/resources/payment_method.rb', line 273 def dedicated_file_name @dedicated_file_name end |
#terminal_verification_results ⇒ Object (readonly)
A 5-byte string that records the checks and validations that occur between the card and the terminal. These checks determine how the terminal processes the transaction and what risk tolerance is acceptable. Referenced from EMV Tag 95.
275 276 277 |
# File 'lib/stripe/resources/payment_method.rb', line 275 def terminal_verification_results @terminal_verification_results end |
#transaction_status_information ⇒ Object (readonly)
An indication of which steps were completed during the card read process. Referenced from EMV Tag 9B.
277 278 279 |
# File 'lib/stripe/resources/payment_method.rb', line 277 def transaction_status_information @transaction_status_information end |
Class Method Details
.field_remappings ⇒ Object
283 284 285 |
# File 'lib/stripe/resources/payment_method.rb', line 283 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
279 280 281 |
# File 'lib/stripe/resources/payment_method.rb', line 279 def self.inner_class_types @inner_class_types = {} end |