Class: Stripe::PaymentMethod::Card::GeneratedFrom::PaymentMethodDetails::CardPresent::Receipt
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentMethod::Card::GeneratedFrom::PaymentMethodDetails::CardPresent::Receipt
- Defined in:
- lib/stripe/resources/payment_method.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_type ⇒ Object
readonly
The type of account being debited or credited.
-
#application_cryptogram ⇒ Object
readonly
EMV tag 9F26, cryptogram generated by the integrated circuit chip.
-
#application_preferred_name ⇒ Object
readonly
Mnenomic of the Application Identifier.
-
#authorization_code ⇒ Object
readonly
Identifier for this transaction.
-
#authorization_response_code ⇒ Object
readonly
EMV tag 8A.
-
#cardholder_verification_method ⇒ Object
readonly
Describes the method used by the cardholder to verify ownership of the card.
-
#dedicated_file_name ⇒ Object
readonly
EMV tag 84.
-
#terminal_verification_results ⇒ Object
readonly
The outcome of a series of EMV functions performed by the card reader.
-
#transaction_status_information ⇒ Object
readonly
An indication of various EMV functions performed during the transaction.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_type ⇒ Object (readonly)
The type of account being debited or credited
113 114 115 |
# File 'lib/stripe/resources/payment_method.rb', line 113 def account_type @account_type end |
#application_cryptogram ⇒ Object (readonly)
EMV tag 9F26, cryptogram generated by the integrated circuit chip.
115 116 117 |
# File 'lib/stripe/resources/payment_method.rb', line 115 def application_cryptogram @application_cryptogram end |
#application_preferred_name ⇒ Object (readonly)
Mnenomic of the Application Identifier.
117 118 119 |
# File 'lib/stripe/resources/payment_method.rb', line 117 def application_preferred_name @application_preferred_name end |
#authorization_code ⇒ Object (readonly)
Identifier for this transaction.
119 120 121 |
# File 'lib/stripe/resources/payment_method.rb', line 119 def @authorization_code end |
#authorization_response_code ⇒ Object (readonly)
EMV tag 8A. A code returned by the card issuer.
121 122 123 |
# File 'lib/stripe/resources/payment_method.rb', line 121 def @authorization_response_code end |
#cardholder_verification_method ⇒ Object (readonly)
Describes the method used by the cardholder to verify ownership of the card. One of the following: ‘approval`, `failure`, `none`, `offline_pin`, `offline_pin_and_signature`, `online_pin`, or `signature`.
123 124 125 |
# File 'lib/stripe/resources/payment_method.rb', line 123 def cardholder_verification_method @cardholder_verification_method end |
#dedicated_file_name ⇒ Object (readonly)
EMV tag 84. Similar to the application identifier stored on the integrated circuit chip.
125 126 127 |
# File 'lib/stripe/resources/payment_method.rb', line 125 def dedicated_file_name @dedicated_file_name end |
#terminal_verification_results ⇒ Object (readonly)
The outcome of a series of EMV functions performed by the card reader.
127 128 129 |
# File 'lib/stripe/resources/payment_method.rb', line 127 def terminal_verification_results @terminal_verification_results end |
#transaction_status_information ⇒ Object (readonly)
An indication of various EMV functions performed during the transaction.
129 130 131 |
# File 'lib/stripe/resources/payment_method.rb', line 129 def transaction_status_information @transaction_status_information end |