Class: Stripe::PaymentMethod::Card::Wallet::Masterpass

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_method.rb

Defined Under Namespace

Classes: BillingAddress, ShippingAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_addressObject (readonly)

Owner's verified billing address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



514
515
516
# File 'lib/stripe/resources/payment_method.rb', line 514

def billing_address
  @billing_address
end

#emailObject (readonly)

Owner's verified email. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



516
517
518
# File 'lib/stripe/resources/payment_method.rb', line 516

def email
  @email
end

#nameObject (readonly)

Owner's verified full name. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



518
519
520
# File 'lib/stripe/resources/payment_method.rb', line 518

def name
  @name
end

#shipping_addressObject (readonly)

Owner's verified shipping address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



520
521
522
# File 'lib/stripe/resources/payment_method.rb', line 520

def shipping_address
  @shipping_address
end

Class Method Details

.field_remappingsObject



529
530
531
# File 'lib/stripe/resources/payment_method.rb', line 529

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



522
523
524
525
526
527
# File 'lib/stripe/resources/payment_method.rb', line 522

def self.inner_class_types
  @inner_class_types = {
    billing_address: BillingAddress,
    shipping_address: ShippingAddress,
  }
end