Class: Stripe::PaymentMethod::Card::Wallet::VisaCheckout
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentMethod::Card::Wallet::VisaCheckout
- Defined in:
- lib/stripe/resources/payment_method.rb
Defined Under Namespace
Classes: BillingAddress, ShippingAddress
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_address ⇒ Object
readonly
Owner's verified billing address.
-
#email ⇒ Object
readonly
Owner's verified email.
-
#name ⇒ Object
readonly
Owner's verified full name.
-
#shipping_address ⇒ Object
readonly
Owner's verified shipping address.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_address ⇒ Object (readonly)
Owner's verified billing address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
591 592 593 |
# File 'lib/stripe/resources/payment_method.rb', line 591 def billing_address @billing_address end |
#email ⇒ Object (readonly)
Owner's verified email. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
593 594 595 |
# File 'lib/stripe/resources/payment_method.rb', line 593 def email @email end |
#name ⇒ Object (readonly)
Owner's verified full name. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
595 596 597 |
# File 'lib/stripe/resources/payment_method.rb', line 595 def name @name end |
#shipping_address ⇒ Object (readonly)
Owner's verified shipping address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
597 598 599 |
# File 'lib/stripe/resources/payment_method.rb', line 597 def shipping_address @shipping_address end |
Class Method Details
.field_remappings ⇒ Object
606 607 608 |
# File 'lib/stripe/resources/payment_method.rb', line 606 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
599 600 601 602 603 604 |
# File 'lib/stripe/resources/payment_method.rb', line 599 def self.inner_class_types @inner_class_types = { billing_address: BillingAddress, shipping_address: ShippingAddress, } end |