Class: Stripe::PaymentMethod::CardPresent

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_method.rb

Defined Under Namespace

Classes: Networks, Offline, Wallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

Card brand. Can be amex, cartes_bancaires, diners, discover, eftpos_au, jcb, link, mastercard, unionpay, visa or unknown.



801
802
803
# File 'lib/stripe/resources/payment_method.rb', line 801

def brand
  @brand
end

#brand_productObject (readonly)

The product code that identifies the specific program or product associated with a card.



803
804
805
# File 'lib/stripe/resources/payment_method.rb', line 803

def brand_product
  @brand_product
end

#cardholder_nameObject (readonly)

The cardholder name as read from the card, in ISO 7813 format. May include alphanumeric characters, special characters and first/last name separator (/). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.



805
806
807
# File 'lib/stripe/resources/payment_method.rb', line 805

def cardholder_name
  @cardholder_name
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you've collected.



807
808
809
# File 'lib/stripe/resources/payment_method.rb', line 807

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



809
810
811
# File 'lib/stripe/resources/payment_method.rb', line 809

def description
  @description
end

#exp_monthObject (readonly)

Two-digit number representing the card's expiration month.



811
812
813
# File 'lib/stripe/resources/payment_method.rb', line 811

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card's expiration year.



813
814
815
# File 'lib/stripe/resources/payment_method.rb', line 813

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card---one for India and one for the rest of the world.



817
818
819
# File 'lib/stripe/resources/payment_method.rb', line 817

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be credit, debit, prepaid, or unknown.



819
820
821
# File 'lib/stripe/resources/payment_method.rb', line 819

def funding
  @funding
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



821
822
823
# File 'lib/stripe/resources/payment_method.rb', line 821

def iin
  @iin
end

#issuerObject (readonly)

The name of the card's issuing bank. (For internal use only and not typically available in standard API requests.)



823
824
825
# File 'lib/stripe/resources/payment_method.rb', line 823

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



825
826
827
# File 'lib/stripe/resources/payment_method.rb', line 825

def last4
  @last4
end

#networksObject (readonly)

Contains information about card networks that can be used to process the payment.



827
828
829
# File 'lib/stripe/resources/payment_method.rb', line 827

def networks
  @networks
end

#offlineObject (readonly)

Details about payment methods collected offline.



829
830
831
# File 'lib/stripe/resources/payment_method.rb', line 829

def offline
  @offline
end

#preferred_localesObject (readonly)

The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card. Referenced from EMV tag 5F2D, data encoded on the card's chip.



831
832
833
# File 'lib/stripe/resources/payment_method.rb', line 831

def preferred_locales
  @preferred_locales
end

#read_methodObject (readonly)

How card details were read in this transaction.



833
834
835
# File 'lib/stripe/resources/payment_method.rb', line 833

def read_method
  @read_method
end

#walletObject (readonly)

Attribute for field wallet



835
836
837
# File 'lib/stripe/resources/payment_method.rb', line 835

def wallet
  @wallet
end

Class Method Details

.field_remappingsObject



841
842
843
# File 'lib/stripe/resources/payment_method.rb', line 841

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



837
838
839
# File 'lib/stripe/resources/payment_method.rb', line 837

def self.inner_class_types
  @inner_class_types = { networks: Networks, offline: Offline, wallet: Wallet }
end