Class: Stripe::PaymentMethod::CardPresent
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentMethod::CardPresent
- Defined in:
- lib/stripe/resources/payment_method.rb
Defined Under Namespace
Classes: Networks, Offline, Wallet
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#brand ⇒ Object
readonly
Card brand.
-
#brand_product ⇒ Object
readonly
The [product code](stripe.com/docs/card-product-codes) that identifies the specific program or product associated with a card.
-
#cardholder_name ⇒ Object
readonly
The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country of the card.
-
#description ⇒ Object
readonly
A high-level description of the type of cards issued in this range.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card’s expiration year.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular card number.
-
#funding ⇒ Object
readonly
Card funding type.
-
#iin ⇒ Object
readonly
Issuer identification number of the card.
-
#issuer ⇒ Object
readonly
The name of the card’s issuing bank.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#networks ⇒ Object
readonly
Contains information about card networks that can be used to process the payment.
-
#offline ⇒ Object
readonly
Details about payment methods collected offline.
-
#preferred_locales ⇒ Object
readonly
EMV tag 5F2D.
-
#read_method ⇒ Object
readonly
How card details were read in this transaction.
-
#wallet ⇒ Object
readonly
Attribute for field wallet.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#brand ⇒ Object (readonly)
Card brand. Can be ‘amex`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.
485 486 487 |
# File 'lib/stripe/resources/payment_method.rb', line 485 def brand @brand end |
#brand_product ⇒ Object (readonly)
The [product code](stripe.com/docs/card-product-codes) that identifies the specific program or product associated with a card.
488 489 490 |
# File 'lib/stripe/resources/payment_method.rb', line 488 def brand_product @brand_product end |
#cardholder_name ⇒ Object (readonly)
The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format. May include alphanumeric characters, special characters and first/last name separator (‘/`). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.
491 492 493 |
# File 'lib/stripe/resources/payment_method.rb', line 491 def cardholder_name @cardholder_name end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.
494 495 496 |
# File 'lib/stripe/resources/payment_method.rb', line 494 def country @country end |
#description ⇒ Object (readonly)
A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)
497 498 499 |
# File 'lib/stripe/resources/payment_method.rb', line 497 def description @description end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card’s expiration month.
500 501 502 |
# File 'lib/stripe/resources/payment_method.rb', line 500 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card’s expiration year.
503 504 505 |
# File 'lib/stripe/resources/payment_method.rb', line 503 def exp_year @exp_year end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.
*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*
508 509 510 |
# File 'lib/stripe/resources/payment_method.rb', line 508 def fingerprint @fingerprint end |
#funding ⇒ Object (readonly)
Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.
511 512 513 |
# File 'lib/stripe/resources/payment_method.rb', line 511 def funding @funding end |
#iin ⇒ Object (readonly)
Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)
514 515 516 |
# File 'lib/stripe/resources/payment_method.rb', line 514 def iin @iin end |
#issuer ⇒ Object (readonly)
The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)
517 518 519 |
# File 'lib/stripe/resources/payment_method.rb', line 517 def issuer @issuer end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
520 521 522 |
# File 'lib/stripe/resources/payment_method.rb', line 520 def last4 @last4 end |
#networks ⇒ Object (readonly)
Contains information about card networks that can be used to process the payment.
523 524 525 |
# File 'lib/stripe/resources/payment_method.rb', line 523 def networks @networks end |
#offline ⇒ Object (readonly)
Details about payment methods collected offline.
526 527 528 |
# File 'lib/stripe/resources/payment_method.rb', line 526 def offline @offline end |
#preferred_locales ⇒ Object (readonly)
EMV tag 5F2D. Preferred languages specified by the integrated circuit chip.
529 530 531 |
# File 'lib/stripe/resources/payment_method.rb', line 529 def preferred_locales @preferred_locales end |
#read_method ⇒ Object (readonly)
How card details were read in this transaction.
532 533 534 |
# File 'lib/stripe/resources/payment_method.rb', line 532 def read_method @read_method end |
#wallet ⇒ Object (readonly)
Attribute for field wallet
535 536 537 |
# File 'lib/stripe/resources/payment_method.rb', line 535 def wallet @wallet end |