Class: Stripe::PaymentMethod::CreateParams::Card

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_method.rb

Defined Under Namespace

Classes: Networks

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(cvc: nil, exp_month: nil, exp_year: nil, networks: nil, number: nil, token: nil) ⇒ Card

Returns a new instance of Card.



878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
# File 'lib/stripe/resources/payment_method.rb', line 878

def initialize(
  cvc: nil,
  exp_month: nil,
  exp_year: nil,
  networks: nil,
  number: nil,
  token: nil
)
  @cvc = cvc
  @exp_month = exp_month
  @exp_year = exp_year
  @networks = networks
  @number = number
  @token = token
end

Instance Attribute Details

#cvcObject

The card’s CVC. It is highly recommended to always include this value.



866
867
868
# File 'lib/stripe/resources/payment_method.rb', line 866

def cvc
  @cvc
end

#exp_monthObject

Two-digit number representing the card’s expiration month.



868
869
870
# File 'lib/stripe/resources/payment_method.rb', line 868

def exp_month
  @exp_month
end

#exp_yearObject

Four-digit number representing the card’s expiration year.



870
871
872
# File 'lib/stripe/resources/payment_method.rb', line 870

def exp_year
  @exp_year
end

#networksObject

Contains information about card networks used to process the payment.



872
873
874
# File 'lib/stripe/resources/payment_method.rb', line 872

def networks
  @networks
end

#numberObject

The card number, as a string without any separators.



874
875
876
# File 'lib/stripe/resources/payment_method.rb', line 874

def number
  @number
end

#tokenObject

For backwards compatibility, you can alternatively provide a Stripe token (e.g., for Apple Pay, Amex Express Checkout, or legacy Checkout) into the card hash with format card: “tok_visa”.



876
877
878
# File 'lib/stripe/resources/payment_method.rb', line 876

def token
  @token
end