Class: Stripe::PaymentMethod::CreateParams::Card

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_method.rb

Defined Under Namespace

Classes: Networks

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(cvc: nil, exp_month: nil, exp_year: nil, networks: nil, number: nil, token: nil) ⇒ Card

Returns a new instance of Card.



824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
# File 'lib/stripe/resources/payment_method.rb', line 824

def initialize(
  cvc: nil,
  exp_month: nil,
  exp_year: nil,
  networks: nil,
  number: nil,
  token: nil
)
  @cvc = cvc
  @exp_month = exp_month
  @exp_year = exp_year
  @networks = networks
  @number = number
  @token = token
end

Instance Attribute Details

#cvcObject

The card’s CVC. It is highly recommended to always include this value.



812
813
814
# File 'lib/stripe/resources/payment_method.rb', line 812

def cvc
  @cvc
end

#exp_monthObject

Two-digit number representing the card’s expiration month.



814
815
816
# File 'lib/stripe/resources/payment_method.rb', line 814

def exp_month
  @exp_month
end

#exp_yearObject

Four-digit number representing the card’s expiration year.



816
817
818
# File 'lib/stripe/resources/payment_method.rb', line 816

def exp_year
  @exp_year
end

#networksObject

Contains information about card networks used to process the payment.



818
819
820
# File 'lib/stripe/resources/payment_method.rb', line 818

def networks
  @networks
end

#numberObject

The card number, as a string without any separators.



820
821
822
# File 'lib/stripe/resources/payment_method.rb', line 820

def number
  @number
end

#tokenObject

For backwards compatibility, you can alternatively provide a Stripe token (e.g., for Apple Pay, Amex Express Checkout, or legacy Checkout) into the card hash with format card: “tok_visa”.



822
823
824
# File 'lib/stripe/resources/payment_method.rb', line 822

def token
  @token
end