Class: Stripe::PaymentMethod::CreateParams::Card

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_method.rb

Defined Under Namespace

Classes: Networks

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(cvc: nil, exp_month: nil, exp_year: nil, networks: nil, number: nil, token: nil) ⇒ Card

Returns a new instance of Card.



871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
# File 'lib/stripe/resources/payment_method.rb', line 871

def initialize(
  cvc: nil,
  exp_month: nil,
  exp_year: nil,
  networks: nil,
  number: nil,
  token: nil
)
  @cvc = cvc
  @exp_month = exp_month
  @exp_year = exp_year
  @networks = networks
  @number = number
  @token = token
end

Instance Attribute Details

#cvcObject

The card’s CVC. It is highly recommended to always include this value.



859
860
861
# File 'lib/stripe/resources/payment_method.rb', line 859

def cvc
  @cvc
end

#exp_monthObject

Two-digit number representing the card’s expiration month.



861
862
863
# File 'lib/stripe/resources/payment_method.rb', line 861

def exp_month
  @exp_month
end

#exp_yearObject

Four-digit number representing the card’s expiration year.



863
864
865
# File 'lib/stripe/resources/payment_method.rb', line 863

def exp_year
  @exp_year
end

#networksObject

Contains information about card networks used to process the payment.



865
866
867
# File 'lib/stripe/resources/payment_method.rb', line 865

def networks
  @networks
end

#numberObject

The card number, as a string without any separators.



867
868
869
# File 'lib/stripe/resources/payment_method.rb', line 867

def number
  @number
end

#tokenObject

For backwards compatibility, you can alternatively provide a Stripe token (e.g., for Apple Pay, Amex Express Checkout, or legacy Checkout) into the card hash with format card: “tok_visa”.



869
870
871
# File 'lib/stripe/resources/payment_method.rb', line 869

def token
  @token
end