Class: Stripe::PaymentMethod::CreateParams::Card

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_method.rb

Defined Under Namespace

Classes: Networks

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(cvc: nil, exp_month: nil, exp_year: nil, networks: nil, number: nil, token: nil) ⇒ Card

Returns a new instance of Card.



841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
# File 'lib/stripe/resources/payment_method.rb', line 841

def initialize(
  cvc: nil,
  exp_month: nil,
  exp_year: nil,
  networks: nil,
  number: nil,
  token: nil
)
  @cvc = cvc
  @exp_month = exp_month
  @exp_year = exp_year
  @networks = networks
  @number = number
  @token = token
end

Instance Attribute Details

#cvcObject

The card’s CVC. It is highly recommended to always include this value.



829
830
831
# File 'lib/stripe/resources/payment_method.rb', line 829

def cvc
  @cvc
end

#exp_monthObject

Two-digit number representing the card’s expiration month.



831
832
833
# File 'lib/stripe/resources/payment_method.rb', line 831

def exp_month
  @exp_month
end

#exp_yearObject

Four-digit number representing the card’s expiration year.



833
834
835
# File 'lib/stripe/resources/payment_method.rb', line 833

def exp_year
  @exp_year
end

#networksObject

Contains information about card networks used to process the payment.



835
836
837
# File 'lib/stripe/resources/payment_method.rb', line 835

def networks
  @networks
end

#numberObject

The card number, as a string without any separators.



837
838
839
# File 'lib/stripe/resources/payment_method.rb', line 837

def number
  @number
end

#tokenObject

For backwards compatibility, you can alternatively provide a Stripe token (e.g., for Apple Pay, Amex Express Checkout, or legacy Checkout) into the card hash with format card: “tok_visa”.



839
840
841
# File 'lib/stripe/resources/payment_method.rb', line 839

def token
  @token
end