Class: Stripe::PaymentMethod::CreateParams::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethod::CreateParams::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_method.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 |
# File 'lib/stripe/resources/payment_method.rb', line 1763 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1751 1752 1753 |
# File 'lib/stripe/resources/payment_method.rb', line 1751 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
1753 1754 1755 |
# File 'lib/stripe/resources/payment_method.rb', line 1753 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
1755 1756 1757 |
# File 'lib/stripe/resources/payment_method.rb', line 1755 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
1757 1758 1759 |
# File 'lib/stripe/resources/payment_method.rb', line 1757 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
1759 1760 1761 |
# File 'lib/stripe/resources/payment_method.rb', line 1759 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
1761 1762 1763 |
# File 'lib/stripe/resources/payment_method.rb', line 1761 def suffix @suffix end |