Class: Stripe::PaymentMethod::CreateParams::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_method.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
# File 'lib/stripe/resources/payment_method.rb', line 986

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



974
975
976
# File 'lib/stripe/resources/payment_method.rb', line 974

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



976
977
978
# File 'lib/stripe/resources/payment_method.rb', line 976

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



978
979
980
# File 'lib/stripe/resources/payment_method.rb', line 978

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



980
981
982
# File 'lib/stripe/resources/payment_method.rb', line 980

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



982
983
984
# File 'lib/stripe/resources/payment_method.rb', line 982

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



984
985
986
# File 'lib/stripe/resources/payment_method.rb', line 984

def suffix
  @suffix
end