Class: Stripe::PaymentMethod::CreateParams::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethod::CreateParams::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_method.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/stripe/resources/payment_method.rb', line 984 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
972 973 974 |
# File 'lib/stripe/resources/payment_method.rb', line 972 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
974 975 976 |
# File 'lib/stripe/resources/payment_method.rb', line 974 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
976 977 978 |
# File 'lib/stripe/resources/payment_method.rb', line 976 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
978 979 980 |
# File 'lib/stripe/resources/payment_method.rb', line 978 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
980 981 982 |
# File 'lib/stripe/resources/payment_method.rb', line 980 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
982 983 984 |
# File 'lib/stripe/resources/payment_method.rb', line 982 def suffix @suffix end |