Class: Stripe::PaymentMethod::CreateParams::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_method.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
# File 'lib/stripe/resources/payment_method.rb', line 919

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



907
908
909
# File 'lib/stripe/resources/payment_method.rb', line 907

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



909
910
911
# File 'lib/stripe/resources/payment_method.rb', line 909

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



911
912
913
# File 'lib/stripe/resources/payment_method.rb', line 911

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



913
914
915
# File 'lib/stripe/resources/payment_method.rb', line 913

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



915
916
917
# File 'lib/stripe/resources/payment_method.rb', line 915

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



917
918
919
# File 'lib/stripe/resources/payment_method.rb', line 917

def suffix
  @suffix
end