Class: Stripe::PaymentMethod::CreateParams::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_method.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
# File 'lib/stripe/resources/payment_method.rb', line 950

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



938
939
940
# File 'lib/stripe/resources/payment_method.rb', line 938

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



940
941
942
# File 'lib/stripe/resources/payment_method.rb', line 940

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



942
943
944
# File 'lib/stripe/resources/payment_method.rb', line 942

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



944
945
946
# File 'lib/stripe/resources/payment_method.rb', line 944

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



946
947
948
# File 'lib/stripe/resources/payment_method.rb', line 946

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



948
949
950
# File 'lib/stripe/resources/payment_method.rb', line 948

def suffix
  @suffix
end