Class: Stripe::PaymentMethod::CreateParams::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethod::CreateParams::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_method.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 |
# File 'lib/stripe/resources/payment_method.rb', line 950 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
938 939 940 |
# File 'lib/stripe/resources/payment_method.rb', line 938 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
940 941 942 |
# File 'lib/stripe/resources/payment_method.rb', line 940 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
942 943 944 |
# File 'lib/stripe/resources/payment_method.rb', line 942 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
944 945 946 |
# File 'lib/stripe/resources/payment_method.rb', line 944 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
946 947 948 |
# File 'lib/stripe/resources/payment_method.rb', line 946 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
948 949 950 |
# File 'lib/stripe/resources/payment_method.rb', line 948 def suffix @suffix end |