Class: Stripe::PaymentMethod::CreateParams::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethod::CreateParams::UsBankAccount
- Defined in:
- lib/stripe/resources/payment_method.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 |
# File 'lib/stripe/resources/payment_method.rb', line 1174 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
1164 1165 1166 |
# File 'lib/stripe/resources/payment_method.rb', line 1164 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
1166 1167 1168 |
# File 'lib/stripe/resources/payment_method.rb', line 1166 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
1168 1169 1170 |
# File 'lib/stripe/resources/payment_method.rb', line 1168 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
1170 1171 1172 |
# File 'lib/stripe/resources/payment_method.rb', line 1170 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
1172 1173 1174 |
# File 'lib/stripe/resources/payment_method.rb', line 1172 def routing_number @routing_number end |