Class: Stripe::PaymentMethod::GiftCard
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentMethod::GiftCard
- Defined in:
- lib/stripe/resources/payment_method.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#brand ⇒ Object
readonly
The brand of the gift card.
-
#exp_month ⇒ Object
readonly
The expiration month of the gift card.
-
#exp_year ⇒ Object
readonly
The expiration year of the gift card.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies the gift card.
-
#first6 ⇒ Object
readonly
The first six digits of the gift card number.
-
#last4 ⇒ Object
readonly
The last four digits of the gift card number.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#brand ⇒ Object (readonly)
The brand of the gift card.
922 923 924 |
# File 'lib/stripe/resources/payment_method.rb', line 922 def brand @brand end |
#exp_month ⇒ Object (readonly)
The expiration month of the gift card.
924 925 926 |
# File 'lib/stripe/resources/payment_method.rb', line 924 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
The expiration year of the gift card.
926 927 928 |
# File 'lib/stripe/resources/payment_method.rb', line 926 def exp_year @exp_year end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies the gift card.
928 929 930 |
# File 'lib/stripe/resources/payment_method.rb', line 928 def fingerprint @fingerprint end |
#first6 ⇒ Object (readonly)
The first six digits of the gift card number.
930 931 932 |
# File 'lib/stripe/resources/payment_method.rb', line 930 def first6 @first6 end |
#last4 ⇒ Object (readonly)
The last four digits of the gift card number.
932 933 934 |
# File 'lib/stripe/resources/payment_method.rb', line 932 def last4 @last4 end |
Class Method Details
.field_remappings ⇒ Object
938 939 940 |
# File 'lib/stripe/resources/payment_method.rb', line 938 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
934 935 936 |
# File 'lib/stripe/resources/payment_method.rb', line 934 def self.inner_class_types @inner_class_types = {} end |