Class: Stripe::PaymentMethod::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethod::ListParams
- Defined in:
- lib/stripe/resources/payment_method.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of the customer whose PaymentMethods will be retrieved.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#type ⇒ Object
An optional filter on the list, based on the object ‘type` field.
Instance Method Summary collapse
-
#initialize(customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, type: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, type: nil) ⇒ ListParams
Returns a new instance of ListParams.
661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 |
# File 'lib/stripe/resources/payment_method.rb', line 661 def initialize( customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, type: nil ) @customer = customer @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after @type = type end |
Instance Attribute Details
#customer ⇒ Object
The ID of the customer whose PaymentMethods will be retrieved.
649 650 651 |
# File 'lib/stripe/resources/payment_method.rb', line 649 def customer @customer end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
651 652 653 |
# File 'lib/stripe/resources/payment_method.rb', line 651 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
653 654 655 |
# File 'lib/stripe/resources/payment_method.rb', line 653 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
655 656 657 |
# File 'lib/stripe/resources/payment_method.rb', line 655 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
657 658 659 |
# File 'lib/stripe/resources/payment_method.rb', line 657 def starting_after @starting_after end |
#type ⇒ Object
An optional filter on the list, based on the object ‘type` field. Without the filter, the list includes all current and future payment method types. If your integration expects only one type of payment method in the response, make sure to provide a type value in the request.
659 660 661 |
# File 'lib/stripe/resources/payment_method.rb', line 659 def type @type end |