Class: Stripe::PaymentMethod::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_method.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, type: nil) ⇒ ListParams

Returns a new instance of ListParams.



711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
# File 'lib/stripe/resources/payment_method.rb', line 711

def initialize(
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  type: nil
)
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @type = type
end

Instance Attribute Details

#customerObject

The ID of the customer whose PaymentMethods will be retrieved.



699
700
701
# File 'lib/stripe/resources/payment_method.rb', line 699

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



701
702
703
# File 'lib/stripe/resources/payment_method.rb', line 701

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



703
704
705
# File 'lib/stripe/resources/payment_method.rb', line 703

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



705
706
707
# File 'lib/stripe/resources/payment_method.rb', line 705

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



707
708
709
# File 'lib/stripe/resources/payment_method.rb', line 707

def starting_after
  @starting_after
end

#typeObject

An optional filter on the list, based on the object ‘type` field. Without the filter, the list includes all current and future payment method types. If your integration expects only one type of payment method in the response, make sure to provide a type value in the request.



709
710
711
# File 'lib/stripe/resources/payment_method.rb', line 709

def type
  @type
end