Class: Stripe::PaymentMethod::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethod::ListParams
- Defined in:
- lib/stripe/resources/payment_method.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of the customer whose PaymentMethods will be retrieved.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#type ⇒ Object
An optional filter on the list, based on the object ‘type` field.
Instance Method Summary collapse
-
#initialize(customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, type: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, type: nil) ⇒ ListParams
Returns a new instance of ListParams.
713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 |
# File 'lib/stripe/resources/payment_method.rb', line 713 def initialize( customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, type: nil ) @customer = customer @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after @type = type end |
Instance Attribute Details
#customer ⇒ Object
The ID of the customer whose PaymentMethods will be retrieved.
701 702 703 |
# File 'lib/stripe/resources/payment_method.rb', line 701 def customer @customer end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
703 704 705 |
# File 'lib/stripe/resources/payment_method.rb', line 703 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
705 706 707 |
# File 'lib/stripe/resources/payment_method.rb', line 705 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
707 708 709 |
# File 'lib/stripe/resources/payment_method.rb', line 707 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
709 710 711 |
# File 'lib/stripe/resources/payment_method.rb', line 709 def starting_after @starting_after end |
#type ⇒ Object
An optional filter on the list, based on the object ‘type` field. Without the filter, the list includes all current and future payment method types. If your integration expects only one type of payment method in the response, make sure to provide a type value in the request.
711 712 713 |
# File 'lib/stripe/resources/payment_method.rb', line 711 def type @type end |