Class: Stripe::PaymentMethod::NzBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentMethod::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_method.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
readonly
The name on the bank account.
-
#bank_code ⇒ Object
readonly
The numeric code for the bank account’s bank.
-
#bank_name ⇒ Object
readonly
The name of the bank.
-
#branch_code ⇒ Object
readonly
The numeric code for the bank account’s bank branch.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#suffix ⇒ Object
readonly
The suffix of the bank account number.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_name ⇒ Object (readonly)
The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1155 1156 1157 |
# File 'lib/stripe/resources/payment_method.rb', line 1155 def account_holder_name @account_holder_name end |
#bank_code ⇒ Object (readonly)
The numeric code for the bank account’s bank.
1157 1158 1159 |
# File 'lib/stripe/resources/payment_method.rb', line 1157 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
The name of the bank.
1159 1160 1161 |
# File 'lib/stripe/resources/payment_method.rb', line 1159 def bank_name @bank_name end |
#branch_code ⇒ Object (readonly)
The numeric code for the bank account’s bank branch.
1161 1162 1163 |
# File 'lib/stripe/resources/payment_method.rb', line 1161 def branch_code @branch_code end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
1163 1164 1165 |
# File 'lib/stripe/resources/payment_method.rb', line 1163 def last4 @last4 end |
#suffix ⇒ Object (readonly)
The suffix of the bank account number.
1165 1166 1167 |
# File 'lib/stripe/resources/payment_method.rb', line 1165 def suffix @suffix end |
Class Method Details
.field_remappings ⇒ Object
1171 1172 1173 |
# File 'lib/stripe/resources/payment_method.rb', line 1171 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1167 1168 1169 |
# File 'lib/stripe/resources/payment_method.rb', line 1167 def self.inner_class_types @inner_class_types = {} end |