Class: Stripe::PaymentMethod::NzBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentMethod::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_method.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
readonly
The name on the bank account.
-
#bank_code ⇒ Object
readonly
The numeric code for the bank account’s bank.
-
#bank_name ⇒ Object
readonly
The name of the bank.
-
#branch_code ⇒ Object
readonly
The numeric code for the bank account’s bank branch.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#suffix ⇒ Object
readonly
The suffix of the bank account number.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_name ⇒ Object (readonly)
The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1107 1108 1109 |
# File 'lib/stripe/resources/payment_method.rb', line 1107 def account_holder_name @account_holder_name end |
#bank_code ⇒ Object (readonly)
The numeric code for the bank account’s bank.
1109 1110 1111 |
# File 'lib/stripe/resources/payment_method.rb', line 1109 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
The name of the bank.
1111 1112 1113 |
# File 'lib/stripe/resources/payment_method.rb', line 1111 def bank_name @bank_name end |
#branch_code ⇒ Object (readonly)
The numeric code for the bank account’s bank branch.
1113 1114 1115 |
# File 'lib/stripe/resources/payment_method.rb', line 1113 def branch_code @branch_code end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
1115 1116 1117 |
# File 'lib/stripe/resources/payment_method.rb', line 1115 def last4 @last4 end |
#suffix ⇒ Object (readonly)
The suffix of the bank account number.
1117 1118 1119 |
# File 'lib/stripe/resources/payment_method.rb', line 1117 def suffix @suffix end |
Class Method Details
.field_remappings ⇒ Object
1123 1124 1125 |
# File 'lib/stripe/resources/payment_method.rb', line 1123 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1119 1120 1121 |
# File 'lib/stripe/resources/payment_method.rb', line 1119 def self.inner_class_types @inner_class_types = {} end |