Class: Stripe::PaymentMethod::NzBankAccount

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_method.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_nameObject (readonly)

The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1094
1095
1096
# File 'lib/stripe/resources/payment_method.rb', line 1094

def 
  @account_holder_name
end

#bank_codeObject (readonly)

The numeric code for the bank account’s bank.



1096
1097
1098
# File 'lib/stripe/resources/payment_method.rb', line 1096

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

The name of the bank.



1098
1099
1100
# File 'lib/stripe/resources/payment_method.rb', line 1098

def bank_name
  @bank_name
end

#branch_codeObject (readonly)

The numeric code for the bank account’s bank branch.



1100
1101
1102
# File 'lib/stripe/resources/payment_method.rb', line 1100

def branch_code
  @branch_code
end

#last4Object (readonly)

Last four digits of the bank account number.



1102
1103
1104
# File 'lib/stripe/resources/payment_method.rb', line 1102

def last4
  @last4
end

#suffixObject (readonly)

The suffix of the bank account number.



1104
1105
1106
# File 'lib/stripe/resources/payment_method.rb', line 1104

def suffix
  @suffix
end

Class Method Details

.field_remappingsObject



1110
1111
1112
# File 'lib/stripe/resources/payment_method.rb', line 1110

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1106
1107
1108
# File 'lib/stripe/resources/payment_method.rb', line 1106

def self.inner_class_types
  @inner_class_types = {}
end