Class: Stripe::PaymentMethod::NzBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentMethod::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_method.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
readonly
The name on the bank account.
-
#bank_code ⇒ Object
readonly
The numeric code for the bank account’s bank.
-
#bank_name ⇒ Object
readonly
The name of the bank.
-
#branch_code ⇒ Object
readonly
The numeric code for the bank account’s bank branch.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#suffix ⇒ Object
readonly
The suffix of the bank account number.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_name ⇒ Object (readonly)
The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1045 1046 1047 |
# File 'lib/stripe/resources/payment_method.rb', line 1045 def account_holder_name @account_holder_name end |
#bank_code ⇒ Object (readonly)
The numeric code for the bank account’s bank.
1047 1048 1049 |
# File 'lib/stripe/resources/payment_method.rb', line 1047 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
The name of the bank.
1049 1050 1051 |
# File 'lib/stripe/resources/payment_method.rb', line 1049 def bank_name @bank_name end |
#branch_code ⇒ Object (readonly)
The numeric code for the bank account’s bank branch.
1051 1052 1053 |
# File 'lib/stripe/resources/payment_method.rb', line 1051 def branch_code @branch_code end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
1053 1054 1055 |
# File 'lib/stripe/resources/payment_method.rb', line 1053 def last4 @last4 end |
#suffix ⇒ Object (readonly)
The suffix of the bank account number.
1055 1056 1057 |
# File 'lib/stripe/resources/payment_method.rb', line 1055 def suffix @suffix end |
Class Method Details
.field_remappings ⇒ Object
1061 1062 1063 |
# File 'lib/stripe/resources/payment_method.rb', line 1061 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1057 1058 1059 |
# File 'lib/stripe/resources/payment_method.rb', line 1057 def self.inner_class_types @inner_class_types = {} end |