Class: Stripe::PaymentMethod::NzBankAccount

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_method.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_nameObject (readonly)

The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



531
532
533
# File 'lib/stripe/resources/payment_method.rb', line 531

def 
  @account_holder_name
end

#bank_codeObject (readonly)

The numeric code for the bank account’s bank.



533
534
535
# File 'lib/stripe/resources/payment_method.rb', line 533

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

The name of the bank.



535
536
537
# File 'lib/stripe/resources/payment_method.rb', line 535

def bank_name
  @bank_name
end

#branch_codeObject (readonly)

The numeric code for the bank account’s bank branch.



537
538
539
# File 'lib/stripe/resources/payment_method.rb', line 537

def branch_code
  @branch_code
end

#last4Object (readonly)

Last four digits of the bank account number.



539
540
541
# File 'lib/stripe/resources/payment_method.rb', line 539

def last4
  @last4
end

#suffixObject (readonly)

The suffix of the bank account number.



541
542
543
# File 'lib/stripe/resources/payment_method.rb', line 541

def suffix
  @suffix
end