Class: Stripe::PaymentMethod::NzBankAccount

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_method.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_nameObject (readonly)

The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



542
543
544
# File 'lib/stripe/resources/payment_method.rb', line 542

def 
  @account_holder_name
end

#bank_codeObject (readonly)

The numeric code for the bank account’s bank.



544
545
546
# File 'lib/stripe/resources/payment_method.rb', line 544

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

The name of the bank.



546
547
548
# File 'lib/stripe/resources/payment_method.rb', line 546

def bank_name
  @bank_name
end

#branch_codeObject (readonly)

The numeric code for the bank account’s bank branch.



548
549
550
# File 'lib/stripe/resources/payment_method.rb', line 548

def branch_code
  @branch_code
end

#last4Object (readonly)

Last four digits of the bank account number.



550
551
552
# File 'lib/stripe/resources/payment_method.rb', line 550

def last4
  @last4
end

#suffixObject (readonly)

The suffix of the bank account number.



552
553
554
# File 'lib/stripe/resources/payment_method.rb', line 552

def suffix
  @suffix
end