Class: Stripe::PaymentMethod::NzBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentMethod::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_method.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
readonly
The name on the bank account.
-
#bank_code ⇒ Object
readonly
The numeric code for the bank account’s bank.
-
#bank_name ⇒ Object
readonly
The name of the bank.
-
#branch_code ⇒ Object
readonly
The numeric code for the bank account’s bank branch.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#suffix ⇒ Object
readonly
The suffix of the bank account number.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_name ⇒ Object (readonly)
The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
544 545 546 |
# File 'lib/stripe/resources/payment_method.rb', line 544 def account_holder_name @account_holder_name end |
#bank_code ⇒ Object (readonly)
The numeric code for the bank account’s bank.
546 547 548 |
# File 'lib/stripe/resources/payment_method.rb', line 546 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
The name of the bank.
548 549 550 |
# File 'lib/stripe/resources/payment_method.rb', line 548 def bank_name @bank_name end |
#branch_code ⇒ Object (readonly)
The numeric code for the bank account’s bank branch.
550 551 552 |
# File 'lib/stripe/resources/payment_method.rb', line 550 def branch_code @branch_code end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
552 553 554 |
# File 'lib/stripe/resources/payment_method.rb', line 552 def last4 @last4 end |
#suffix ⇒ Object (readonly)
The suffix of the bank account number.
554 555 556 |
# File 'lib/stripe/resources/payment_method.rb', line 554 def suffix @suffix end |