Class: Stripe::PaymentMethod::SepaDebit

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_method.rb

Defined Under Namespace

Classes: GeneratedFrom

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1373
1374
1375
# File 'lib/stripe/resources/payment_method.rb', line 1373

def bank_code
  @bank_code
end

#branch_codeObject (readonly)

Branch code of bank associated with the bank account.



1375
1376
1377
# File 'lib/stripe/resources/payment_method.rb', line 1375

def branch_code
  @branch_code
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1377
1378
1379
# File 'lib/stripe/resources/payment_method.rb', line 1377

def country
  @country
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1379
1380
1381
# File 'lib/stripe/resources/payment_method.rb', line 1379

def fingerprint
  @fingerprint
end

#generated_fromObject (readonly)

Information about the object that generated this PaymentMethod.



1381
1382
1383
# File 'lib/stripe/resources/payment_method.rb', line 1381

def generated_from
  @generated_from
end

#last4Object (readonly)

Last four characters of the IBAN.



1383
1384
1385
# File 'lib/stripe/resources/payment_method.rb', line 1383

def last4
  @last4
end

Class Method Details

.field_remappingsObject



1389
1390
1391
# File 'lib/stripe/resources/payment_method.rb', line 1389

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1385
1386
1387
# File 'lib/stripe/resources/payment_method.rb', line 1385

def self.inner_class_types
  @inner_class_types = { generated_from: GeneratedFrom }
end