Class: Stripe::PaymentMethod::SepaDebit
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentMethod::SepaDebit
- Defined in:
- lib/stripe/resources/payment_method.rb
Defined Under Namespace
Classes: GeneratedFrom
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_code ⇒ Object
readonly
Bank code of bank associated with the bank account.
-
#branch_code ⇒ Object
readonly
Branch code of bank associated with the bank account.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country the bank account is located in.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular bank account.
-
#generated_from ⇒ Object
readonly
Information about the object that generated this PaymentMethod.
-
#last4 ⇒ Object
readonly
Last four characters of the IBAN.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_code ⇒ Object (readonly)
Bank code of bank associated with the bank account.
757 758 759 |
# File 'lib/stripe/resources/payment_method.rb', line 757 def bank_code @bank_code end |
#branch_code ⇒ Object (readonly)
Branch code of bank associated with the bank account.
760 761 762 |
# File 'lib/stripe/resources/payment_method.rb', line 760 def branch_code @branch_code end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country the bank account is located in.
763 764 765 |
# File 'lib/stripe/resources/payment_method.rb', line 763 def country @country end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
766 767 768 |
# File 'lib/stripe/resources/payment_method.rb', line 766 def fingerprint @fingerprint end |
#generated_from ⇒ Object (readonly)
Information about the object that generated this PaymentMethod.
769 770 771 |
# File 'lib/stripe/resources/payment_method.rb', line 769 def generated_from @generated_from end |
#last4 ⇒ Object (readonly)
Last four characters of the IBAN.
772 773 774 |
# File 'lib/stripe/resources/payment_method.rb', line 772 def last4 @last4 end |