Class: Stripe::PaymentMethod::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_method.rb

Defined Under Namespace

Classes: BillingDetails, Card, Link, PayByBank, Payto, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_redisplay: nil, billing_details: nil, card: nil, expand: nil, link: nil, metadata: nil, pay_by_bank: nil, payto: nil, us_bank_account: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
# File 'lib/stripe/resources/payment_method.rb', line 1527

def initialize(
  allow_redisplay: nil,
  billing_details: nil,
  card: nil,
  expand: nil,
  link: nil,
  metadata: nil,
  pay_by_bank: nil,
  payto: nil,
  us_bank_account: nil
)
  @allow_redisplay = allow_redisplay
  @billing_details = billing_details
  @card = card
  @expand = expand
  @link = link
  @metadata = 
  @pay_by_bank = pay_by_bank
  @payto = payto
  @us_bank_account = 
end

Instance Attribute Details

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.



1509
1510
1511
# File 'lib/stripe/resources/payment_method.rb', line 1509

def allow_redisplay
  @allow_redisplay
end

#billing_detailsObject

Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.



1511
1512
1513
# File 'lib/stripe/resources/payment_method.rb', line 1511

def billing_details
  @billing_details
end

#cardObject

If this is a ‘card` PaymentMethod, this hash contains the user’s card details.



1513
1514
1515
# File 'lib/stripe/resources/payment_method.rb', line 1513

def card
  @card
end

#expandObject

Specifies which fields in the response should be expanded.



1515
1516
1517
# File 'lib/stripe/resources/payment_method.rb', line 1515

def expand
  @expand
end

If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.



1517
1518
1519
# File 'lib/stripe/resources/payment_method.rb', line 1517

def link
  @link
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1519
1520
1521
# File 'lib/stripe/resources/payment_method.rb', line 1519

def 
  @metadata
end

#pay_by_bankObject

If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.



1521
1522
1523
# File 'lib/stripe/resources/payment_method.rb', line 1521

def pay_by_bank
  @pay_by_bank
end

#paytoObject

If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.



1523
1524
1525
# File 'lib/stripe/resources/payment_method.rb', line 1523

def payto
  @payto
end

#us_bank_accountObject

If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.



1525
1526
1527
# File 'lib/stripe/resources/payment_method.rb', line 1525

def 
  @us_bank_account
end