Class: Stripe::PaymentMethod::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_method.rb

Defined Under Namespace

Classes: BillingDetails, Card, Link, PayByBank, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_redisplay: nil, billing_details: nil, card: nil, expand: nil, link: nil, metadata: nil, pay_by_bank: nil, us_bank_account: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
# File 'lib/stripe/resources/payment_method.rb', line 1353

def initialize(
  allow_redisplay: nil,
  billing_details: nil,
  card: nil,
  expand: nil,
  link: nil,
  metadata: nil,
  pay_by_bank: nil,
  us_bank_account: nil
)
  @allow_redisplay = allow_redisplay
  @billing_details = billing_details
  @card = card
  @expand = expand
  @link = link
  @metadata = 
  @pay_by_bank = pay_by_bank
  @us_bank_account = 
end

Instance Attribute Details

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.



1337
1338
1339
# File 'lib/stripe/resources/payment_method.rb', line 1337

def allow_redisplay
  @allow_redisplay
end

#billing_detailsObject

Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.



1339
1340
1341
# File 'lib/stripe/resources/payment_method.rb', line 1339

def billing_details
  @billing_details
end

#cardObject

If this is a ‘card` PaymentMethod, this hash contains the user’s card details.



1341
1342
1343
# File 'lib/stripe/resources/payment_method.rb', line 1341

def card
  @card
end

#expandObject

Specifies which fields in the response should be expanded.



1343
1344
1345
# File 'lib/stripe/resources/payment_method.rb', line 1343

def expand
  @expand
end

If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.



1345
1346
1347
# File 'lib/stripe/resources/payment_method.rb', line 1345

def link
  @link
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1347
1348
1349
# File 'lib/stripe/resources/payment_method.rb', line 1347

def 
  @metadata
end

#pay_by_bankObject

If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.



1349
1350
1351
# File 'lib/stripe/resources/payment_method.rb', line 1349

def pay_by_bank
  @pay_by_bank
end

#us_bank_accountObject

If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.



1351
1352
1353
# File 'lib/stripe/resources/payment_method.rb', line 1351

def 
  @us_bank_account
end