Class: Stripe::PaymentMethod::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethod::UpdateParams
- Defined in:
- lib/stripe/resources/payment_method.rb
Defined Under Namespace
Classes: BillingDetails, Card, Link, PayByBank, UsBankAccount
Instance Attribute Summary collapse
-
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
-
#card ⇒ Object
If this is a ‘card` PaymentMethod, this hash contains the user’s card details.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#link ⇒ Object
If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#pay_by_bank ⇒ Object
If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.
-
#us_bank_account ⇒ Object
If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.
Instance Method Summary collapse
-
#initialize(allow_redisplay: nil, billing_details: nil, card: nil, expand: nil, link: nil, metadata: nil, pay_by_bank: nil, us_bank_account: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(allow_redisplay: nil, billing_details: nil, card: nil, expand: nil, link: nil, metadata: nil, pay_by_bank: nil, us_bank_account: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 |
# File 'lib/stripe/resources/payment_method.rb', line 1410 def initialize( allow_redisplay: nil, billing_details: nil, card: nil, expand: nil, link: nil, metadata: nil, pay_by_bank: nil, us_bank_account: nil ) @allow_redisplay = allow_redisplay @billing_details = billing_details @card = card @expand = @link = link @metadata = @pay_by_bank = pay_by_bank @us_bank_account = us_bank_account end |
Instance Attribute Details
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.
1394 1395 1396 |
# File 'lib/stripe/resources/payment_method.rb', line 1394 def allow_redisplay @allow_redisplay end |
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
1396 1397 1398 |
# File 'lib/stripe/resources/payment_method.rb', line 1396 def billing_details @billing_details end |
#card ⇒ Object
If this is a ‘card` PaymentMethod, this hash contains the user’s card details.
1398 1399 1400 |
# File 'lib/stripe/resources/payment_method.rb', line 1398 def card @card end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1400 1401 1402 |
# File 'lib/stripe/resources/payment_method.rb', line 1400 def @expand end |
#link ⇒ Object
If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.
1402 1403 1404 |
# File 'lib/stripe/resources/payment_method.rb', line 1402 def link @link end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1404 1405 1406 |
# File 'lib/stripe/resources/payment_method.rb', line 1404 def @metadata end |
#pay_by_bank ⇒ Object
If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.
1406 1407 1408 |
# File 'lib/stripe/resources/payment_method.rb', line 1406 def pay_by_bank @pay_by_bank end |
#us_bank_account ⇒ Object
If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.
1408 1409 1410 |
# File 'lib/stripe/resources/payment_method.rb', line 1408 def us_bank_account @us_bank_account end |