Class: Stripe::PaymentMethod::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethod::UpdateParams
- Defined in:
- lib/stripe/resources/payment_method.rb
Defined Under Namespace
Classes: BillingDetails, Card, Link, PayByBank, Payto, UsBankAccount
Instance Attribute Summary collapse
-
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
-
#card ⇒ Object
If this is a ‘card` PaymentMethod, this hash contains the user’s card details.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#link ⇒ Object
If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#pay_by_bank ⇒ Object
If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.
-
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.
-
#us_bank_account ⇒ Object
If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.
Instance Method Summary collapse
-
#initialize(allow_redisplay: nil, billing_details: nil, card: nil, expand: nil, link: nil, metadata: nil, pay_by_bank: nil, payto: nil, us_bank_account: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(allow_redisplay: nil, billing_details: nil, card: nil, expand: nil, link: nil, metadata: nil, pay_by_bank: nil, payto: nil, us_bank_account: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 |
# File 'lib/stripe/resources/payment_method.rb', line 1574 def initialize( allow_redisplay: nil, billing_details: nil, card: nil, expand: nil, link: nil, metadata: nil, pay_by_bank: nil, payto: nil, us_bank_account: nil ) @allow_redisplay = allow_redisplay @billing_details = billing_details @card = card @expand = @link = link @metadata = @pay_by_bank = pay_by_bank @payto = payto @us_bank_account = us_bank_account end |
Instance Attribute Details
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.
1556 1557 1558 |
# File 'lib/stripe/resources/payment_method.rb', line 1556 def allow_redisplay @allow_redisplay end |
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
1558 1559 1560 |
# File 'lib/stripe/resources/payment_method.rb', line 1558 def billing_details @billing_details end |
#card ⇒ Object
If this is a ‘card` PaymentMethod, this hash contains the user’s card details.
1560 1561 1562 |
# File 'lib/stripe/resources/payment_method.rb', line 1560 def card @card end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1562 1563 1564 |
# File 'lib/stripe/resources/payment_method.rb', line 1562 def @expand end |
#link ⇒ Object
If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.
1564 1565 1566 |
# File 'lib/stripe/resources/payment_method.rb', line 1564 def link @link end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1566 1567 1568 |
# File 'lib/stripe/resources/payment_method.rb', line 1566 def @metadata end |
#pay_by_bank ⇒ Object
If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.
1568 1569 1570 |
# File 'lib/stripe/resources/payment_method.rb', line 1568 def pay_by_bank @pay_by_bank end |
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.
1570 1571 1572 |
# File 'lib/stripe/resources/payment_method.rb', line 1570 def payto @payto end |
#us_bank_account ⇒ Object
If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.
1572 1573 1574 |
# File 'lib/stripe/resources/payment_method.rb', line 1572 def us_bank_account @us_bank_account end |