Class: Stripe::PaymentMethod::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_method.rb

Defined Under Namespace

Classes: BillingDetails, Card, Link, NaverPay, PayByBank, Payto, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_redisplay: nil, billing_details: nil, card: nil, expand: nil, link: nil, metadata: nil, naver_pay: nil, pay_by_bank: nil, payto: nil, us_bank_account: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
# File 'lib/stripe/resources/payment_method.rb', line 1503

def initialize(
  allow_redisplay: nil,
  billing_details: nil,
  card: nil,
  expand: nil,
  link: nil,
  metadata: nil,
  naver_pay: nil,
  pay_by_bank: nil,
  payto: nil,
  us_bank_account: nil
)
  @allow_redisplay = allow_redisplay
  @billing_details = billing_details
  @card = card
  @expand = expand
  @link = link
  @metadata = 
  @naver_pay = naver_pay
  @pay_by_bank = pay_by_bank
  @payto = payto
  @us_bank_account = 
end

Instance Attribute Details

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.



1483
1484
1485
# File 'lib/stripe/resources/payment_method.rb', line 1483

def allow_redisplay
  @allow_redisplay
end

#billing_detailsObject

Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.



1485
1486
1487
# File 'lib/stripe/resources/payment_method.rb', line 1485

def billing_details
  @billing_details
end

#cardObject

If this is a ‘card` PaymentMethod, this hash contains the user’s card details.



1487
1488
1489
# File 'lib/stripe/resources/payment_method.rb', line 1487

def card
  @card
end

#expandObject

Specifies which fields in the response should be expanded.



1489
1490
1491
# File 'lib/stripe/resources/payment_method.rb', line 1489

def expand
  @expand
end

If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.



1491
1492
1493
# File 'lib/stripe/resources/payment_method.rb', line 1491

def link
  @link
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1493
1494
1495
# File 'lib/stripe/resources/payment_method.rb', line 1493

def 
  @metadata
end

If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.



1495
1496
1497
# File 'lib/stripe/resources/payment_method.rb', line 1495

def naver_pay
  @naver_pay
end

#pay_by_bankObject

If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.



1497
1498
1499
# File 'lib/stripe/resources/payment_method.rb', line 1497

def pay_by_bank
  @pay_by_bank
end

#paytoObject

If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.



1499
1500
1501
# File 'lib/stripe/resources/payment_method.rb', line 1499

def payto
  @payto
end

#us_bank_accountObject

If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.



1501
1502
1503
# File 'lib/stripe/resources/payment_method.rb', line 1501

def 
  @us_bank_account
end