Class: Stripe::PaymentMethod::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_method.rb

Defined Under Namespace

Classes: BillingDetails, Card, Link, NaverPay, Payto, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_redisplay: nil, billing_details: nil, card: nil, expand: nil, link: nil, metadata: nil, naver_pay: nil, payto: nil, us_bank_account: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
# File 'lib/stripe/resources/payment_method.rb', line 1771

def initialize(
  allow_redisplay: nil,
  billing_details: nil,
  card: nil,
  expand: nil,
  link: nil,
  metadata: nil,
  naver_pay: nil,
  payto: nil,
  us_bank_account: nil
)
  @allow_redisplay = allow_redisplay
  @billing_details = billing_details
  @card = card
  @expand = expand
  @link = link
  @metadata = 
  @naver_pay = naver_pay
  @payto = payto
  @us_bank_account = 
end

Instance Attribute Details

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.



1745
1746
1747
# File 'lib/stripe/resources/payment_method.rb', line 1745

def allow_redisplay
  @allow_redisplay
end

#billing_detailsObject

Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.



1748
1749
1750
# File 'lib/stripe/resources/payment_method.rb', line 1748

def billing_details
  @billing_details
end

#cardObject

If this is a ‘card` PaymentMethod, this hash contains the user’s card details.



1751
1752
1753
# File 'lib/stripe/resources/payment_method.rb', line 1751

def card
  @card
end

#expandObject

Specifies which fields in the response should be expanded.



1754
1755
1756
# File 'lib/stripe/resources/payment_method.rb', line 1754

def expand
  @expand
end

If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.



1757
1758
1759
# File 'lib/stripe/resources/payment_method.rb', line 1757

def link
  @link
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1760
1761
1762
# File 'lib/stripe/resources/payment_method.rb', line 1760

def 
  @metadata
end

If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.



1763
1764
1765
# File 'lib/stripe/resources/payment_method.rb', line 1763

def naver_pay
  @naver_pay
end

#paytoObject

If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.



1766
1767
1768
# File 'lib/stripe/resources/payment_method.rb', line 1766

def payto
  @payto
end

#us_bank_accountObject

If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.



1769
1770
1771
# File 'lib/stripe/resources/payment_method.rb', line 1769

def 
  @us_bank_account
end