Class: Stripe::PaymentMethod::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethod::UpdateParams
- Defined in:
- lib/stripe/resources/payment_method.rb
Defined Under Namespace
Classes: BillingDetails, Card, Link, NaverPay, Payto, UsBankAccount
Instance Attribute Summary collapse
-
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
-
#card ⇒ Object
If this is a ‘card` PaymentMethod, this hash contains the user’s card details.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#link ⇒ Object
If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.
-
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.
-
#us_bank_account ⇒ Object
If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.
Instance Method Summary collapse
-
#initialize(allow_redisplay: nil, billing_details: nil, card: nil, expand: nil, link: nil, metadata: nil, naver_pay: nil, payto: nil, us_bank_account: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(allow_redisplay: nil, billing_details: nil, card: nil, expand: nil, link: nil, metadata: nil, naver_pay: nil, payto: nil, us_bank_account: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 |
# File 'lib/stripe/resources/payment_method.rb', line 1490 def initialize( allow_redisplay: nil, billing_details: nil, card: nil, expand: nil, link: nil, metadata: nil, naver_pay: nil, payto: nil, us_bank_account: nil ) @allow_redisplay = allow_redisplay @billing_details = billing_details @card = card @expand = @link = link @metadata = @naver_pay = naver_pay @payto = payto @us_bank_account = us_bank_account end |
Instance Attribute Details
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.
1472 1473 1474 |
# File 'lib/stripe/resources/payment_method.rb', line 1472 def allow_redisplay @allow_redisplay end |
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
1474 1475 1476 |
# File 'lib/stripe/resources/payment_method.rb', line 1474 def billing_details @billing_details end |
#card ⇒ Object
If this is a ‘card` PaymentMethod, this hash contains the user’s card details.
1476 1477 1478 |
# File 'lib/stripe/resources/payment_method.rb', line 1476 def card @card end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1478 1479 1480 |
# File 'lib/stripe/resources/payment_method.rb', line 1478 def @expand end |
#link ⇒ Object
If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.
1480 1481 1482 |
# File 'lib/stripe/resources/payment_method.rb', line 1480 def link @link end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1482 1483 1484 |
# File 'lib/stripe/resources/payment_method.rb', line 1482 def @metadata end |
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.
1484 1485 1486 |
# File 'lib/stripe/resources/payment_method.rb', line 1484 def naver_pay @naver_pay end |
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.
1486 1487 1488 |
# File 'lib/stripe/resources/payment_method.rb', line 1486 def payto @payto end |
#us_bank_account ⇒ Object
If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.
1488 1489 1490 |
# File 'lib/stripe/resources/payment_method.rb', line 1488 def us_bank_account @us_bank_account end |