Class: Stripe::PaymentMethod::UsBankAccount

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_method.rb

Defined Under Namespace

Classes: Networks, StatusDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Account holder type: individual or company.



1565
1566
1567
# File 'lib/stripe/resources/payment_method.rb', line 1565

def 
  @account_holder_type
end

#account_numberObject (readonly)

Account number of the bank account.



1567
1568
1569
# File 'lib/stripe/resources/payment_method.rb', line 1567

def 
  @account_number
end

#account_typeObject (readonly)

Account type: checkings or savings. Defaults to checking if omitted.



1569
1570
1571
# File 'lib/stripe/resources/payment_method.rb', line 1569

def 
  @account_type
end

#bank_nameObject (readonly)

The name of the bank.



1571
1572
1573
# File 'lib/stripe/resources/payment_method.rb', line 1571

def bank_name
  @bank_name
end

#financial_connections_accountObject (readonly)

The ID of the Financial Connections Account used to create the payment method.



1573
1574
1575
# File 'lib/stripe/resources/payment_method.rb', line 1573

def 
  @financial_connections_account
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1575
1576
1577
# File 'lib/stripe/resources/payment_method.rb', line 1575

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



1577
1578
1579
# File 'lib/stripe/resources/payment_method.rb', line 1577

def last4
  @last4
end

#networksObject (readonly)

Contains information about US bank account networks that can be used.



1579
1580
1581
# File 'lib/stripe/resources/payment_method.rb', line 1579

def networks
  @networks
end

#routing_numberObject (readonly)

Routing number of the bank account.



1581
1582
1583
# File 'lib/stripe/resources/payment_method.rb', line 1581

def routing_number
  @routing_number
end

#status_detailsObject (readonly)

Contains information about the future reusability of this PaymentMethod.



1583
1584
1585
# File 'lib/stripe/resources/payment_method.rb', line 1583

def status_details
  @status_details
end

Class Method Details

.field_remappingsObject



1589
1590
1591
# File 'lib/stripe/resources/payment_method.rb', line 1589

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1585
1586
1587
# File 'lib/stripe/resources/payment_method.rb', line 1585

def self.inner_class_types
  @inner_class_types = { networks: Networks, status_details: StatusDetails }
end