Class: Stripe::PaymentMethod::UsBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentMethod::UsBankAccount
- Defined in:
- lib/stripe/resources/payment_method.rb
Defined Under Namespace
Classes: Networks, StatusDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
readonly
Account holder type: individual or company.
-
#account_number ⇒ Object
readonly
Account number of the bank account.
-
#account_type ⇒ Object
readonly
Account type: checkings or savings.
-
#bank_name ⇒ Object
readonly
The name of the bank.
-
#financial_connections_account ⇒ Object
readonly
The ID of the Financial Connections Account used to create the payment method.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular bank account.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#networks ⇒ Object
readonly
Contains information about US bank account networks that can be used.
-
#routing_number ⇒ Object
readonly
Routing number of the bank account.
-
#status_details ⇒ Object
readonly
Contains information about the future reusability of this PaymentMethod.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_type ⇒ Object (readonly)
Account holder type: individual or company.
1496 1497 1498 |
# File 'lib/stripe/resources/payment_method.rb', line 1496 def account_holder_type @account_holder_type end |
#account_number ⇒ Object (readonly)
Account number of the bank account.
1498 1499 1500 |
# File 'lib/stripe/resources/payment_method.rb', line 1498 def account_number @account_number end |
#account_type ⇒ Object (readonly)
Account type: checkings or savings. Defaults to checking if omitted.
1500 1501 1502 |
# File 'lib/stripe/resources/payment_method.rb', line 1500 def account_type @account_type end |
#bank_name ⇒ Object (readonly)
The name of the bank.
1502 1503 1504 |
# File 'lib/stripe/resources/payment_method.rb', line 1502 def bank_name @bank_name end |
#financial_connections_account ⇒ Object (readonly)
The ID of the Financial Connections Account used to create the payment method.
1504 1505 1506 |
# File 'lib/stripe/resources/payment_method.rb', line 1504 def financial_connections_account @financial_connections_account end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
1506 1507 1508 |
# File 'lib/stripe/resources/payment_method.rb', line 1506 def fingerprint @fingerprint end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
1508 1509 1510 |
# File 'lib/stripe/resources/payment_method.rb', line 1508 def last4 @last4 end |
#networks ⇒ Object (readonly)
Contains information about US bank account networks that can be used.
1510 1511 1512 |
# File 'lib/stripe/resources/payment_method.rb', line 1510 def networks @networks end |
#routing_number ⇒ Object (readonly)
Routing number of the bank account.
1512 1513 1514 |
# File 'lib/stripe/resources/payment_method.rb', line 1512 def routing_number @routing_number end |
#status_details ⇒ Object (readonly)
Contains information about the future reusability of this PaymentMethod.
1514 1515 1516 |
# File 'lib/stripe/resources/payment_method.rb', line 1514 def status_details @status_details end |
Class Method Details
.field_remappings ⇒ Object
1520 1521 1522 |
# File 'lib/stripe/resources/payment_method.rb', line 1520 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1516 1517 1518 |
# File 'lib/stripe/resources/payment_method.rb', line 1516 def self.inner_class_types @inner_class_types = { networks: Networks, status_details: StatusDetails } end |