Class: Stripe::PaymentMethod::UsBankAccount

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_method.rb

Defined Under Namespace

Classes: Networks, StatusDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Account holder type: individual or company.



1489
1490
1491
# File 'lib/stripe/resources/payment_method.rb', line 1489

def 
  @account_holder_type
end

#account_numberObject (readonly)

Account number of the bank account.



1491
1492
1493
# File 'lib/stripe/resources/payment_method.rb', line 1491

def 
  @account_number
end

#account_typeObject (readonly)

Account type: checkings or savings. Defaults to checking if omitted.



1493
1494
1495
# File 'lib/stripe/resources/payment_method.rb', line 1493

def 
  @account_type
end

#bank_nameObject (readonly)

The name of the bank.



1495
1496
1497
# File 'lib/stripe/resources/payment_method.rb', line 1495

def bank_name
  @bank_name
end

#financial_connections_accountObject (readonly)

The ID of the Financial Connections Account used to create the payment method.



1497
1498
1499
# File 'lib/stripe/resources/payment_method.rb', line 1497

def 
  @financial_connections_account
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1499
1500
1501
# File 'lib/stripe/resources/payment_method.rb', line 1499

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



1501
1502
1503
# File 'lib/stripe/resources/payment_method.rb', line 1501

def last4
  @last4
end

#networksObject (readonly)

Contains information about US bank account networks that can be used.



1503
1504
1505
# File 'lib/stripe/resources/payment_method.rb', line 1503

def networks
  @networks
end

#routing_numberObject (readonly)

Routing number of the bank account.



1505
1506
1507
# File 'lib/stripe/resources/payment_method.rb', line 1505

def routing_number
  @routing_number
end

#status_detailsObject (readonly)

Contains information about the future reusability of this PaymentMethod.



1507
1508
1509
# File 'lib/stripe/resources/payment_method.rb', line 1507

def status_details
  @status_details
end

Class Method Details

.field_remappingsObject



1513
1514
1515
# File 'lib/stripe/resources/payment_method.rb', line 1513

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1509
1510
1511
# File 'lib/stripe/resources/payment_method.rb', line 1509

def self.inner_class_types
  @inner_class_types = { networks: Networks, status_details: StatusDetails }
end