Class: Stripe::PaymentMethod::UsBankAccount

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_method.rb

Defined Under Namespace

Classes: Networks, StatusDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Account holder type: individual or company.



647
648
649
# File 'lib/stripe/resources/payment_method.rb', line 647

def 
  @account_holder_type
end

#account_numberObject (readonly)

Account number of the bank account.



649
650
651
# File 'lib/stripe/resources/payment_method.rb', line 649

def 
  @account_number
end

#account_typeObject (readonly)

Account type: checkings or savings. Defaults to checking if omitted.



651
652
653
# File 'lib/stripe/resources/payment_method.rb', line 651

def 
  @account_type
end

#bank_nameObject (readonly)

The name of the bank.



653
654
655
# File 'lib/stripe/resources/payment_method.rb', line 653

def bank_name
  @bank_name
end

#financial_connections_accountObject (readonly)

The ID of the Financial Connections Account used to create the payment method.



655
656
657
# File 'lib/stripe/resources/payment_method.rb', line 655

def 
  @financial_connections_account
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



657
658
659
# File 'lib/stripe/resources/payment_method.rb', line 657

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



659
660
661
# File 'lib/stripe/resources/payment_method.rb', line 659

def last4
  @last4
end

#networksObject (readonly)

Contains information about US bank account networks that can be used.



661
662
663
# File 'lib/stripe/resources/payment_method.rb', line 661

def networks
  @networks
end

#routing_numberObject (readonly)

Routing number of the bank account.



663
664
665
# File 'lib/stripe/resources/payment_method.rb', line 663

def routing_number
  @routing_number
end

#status_detailsObject (readonly)

Contains information about the future reusability of this PaymentMethod.



665
666
667
# File 'lib/stripe/resources/payment_method.rb', line 665

def status_details
  @status_details
end