Class: Stripe::PaymentMethodConfiguration

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/payment_method_configuration.rb

Overview

PaymentMethodConfigurations control which payment methods are displayed to your customers when you don’t explicitly specify payment method types. You can have multiple configurations with different sets of payment methods for different scenarios.

There are two types of PaymentMethodConfigurations. Which is used depends on the [charge type](docs.stripe.com/connect/charges):

Direct configurations apply to payments created on your account, including Connect destination charges, Connect separate charges and transfers, and payments not involving Connect.

Child configurations apply to payments created on your connected accounts using direct charges, and charges with the on_behalf_of parameter.

Child configurations have a ‘parent` that sets default values and controls which settings connected accounts may override. You can specify a parent ID at payment time, and Stripe will automatically resolve the connected account’s associated child configuration. Parent configurations are [managed in the dashboard](dashboard.stripe.com/settings/payment_methods/connected_accounts) and are not available in this API.

Related guides:

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, ApplePay, AuBecsDebit, BacsDebit, Bancontact, Billie, Bizum, Blik, Boleto, Card, CartesBancaires, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, GooglePay, Gopay, Grabpay, IdBankTransfer, Ideal, Jcb, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, RevolutPay, SamsungPay, Satispay, Scalapay, SepaDebit, Shopeepay, Sofort, Sunbit, Swish, Twint, Upi, UsBankAccount, WechatPay, Zip

Constant Summary collapse

OBJECT_NAME =
"payment_method_configuration"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

Attribute for field acss_debit



1982
1983
1984
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1982

def acss_debit
  @acss_debit
end

#activeObject (readonly)

Whether the configuration can be used for new payments.



1984
1985
1986
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1984

def active
  @active
end

#affirmObject (readonly)

Attribute for field affirm



1986
1987
1988
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1986

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



1988
1989
1990
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1988

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



1990
1991
1992
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1990

def alipay
  @alipay
end

#almaObject (readonly)

Attribute for field alma



1992
1993
1994
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1992

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



1994
1995
1996
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1994

def amazon_pay
  @amazon_pay
end

#apple_payObject (readonly)

Attribute for field apple_pay



1996
1997
1998
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1996

def apple_pay
  @apple_pay
end

#applicationObject (readonly)

For child configs, the Connect application associated with the configuration.



1998
1999
2000
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1998

def application
  @application
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



2000
2001
2002
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2000

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



2002
2003
2004
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2002

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



2004
2005
2006
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2004

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



2006
2007
2008
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2006

def billie
  @billie
end

#bizumObject (readonly)

Attribute for field bizum



2008
2009
2010
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2008

def bizum
  @bizum
end

#blikObject (readonly)

Attribute for field blik



2010
2011
2012
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2010

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



2012
2013
2014
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2012

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



2014
2015
2016
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2014

def card
  @card
end

#cartes_bancairesObject (readonly)

Attribute for field cartes_bancaires



2016
2017
2018
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2016

def cartes_bancaires
  @cartes_bancaires
end

#cashappObject (readonly)

Attribute for field cashapp



2018
2019
2020
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2018

def cashapp
  @cashapp
end

#cryptoObject (readonly)

Attribute for field crypto



2020
2021
2022
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2020

def crypto
  @crypto
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



2022
2023
2024
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2022

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



2024
2025
2026
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2024

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



2026
2027
2028
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2026

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



2028
2029
2030
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2028

def giropay
  @giropay
end

#google_payObject (readonly)

Attribute for field google_pay



2030
2031
2032
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2030

def google_pay
  @google_pay
end

#gopayObject (readonly)

Attribute for field gopay



2032
2033
2034
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2032

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



2034
2035
2036
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2034

def grabpay
  @grabpay
end

#idObject (readonly)

Unique identifier for the object.



2036
2037
2038
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2036

def id
  @id
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



2038
2039
2040
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2038

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



2040
2041
2042
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2040

def ideal
  @ideal
end

#is_defaultObject (readonly)

The default configuration is used whenever a payment method configuration is not specified.



2042
2043
2044
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2042

def is_default
  @is_default
end

#jcbObject (readonly)

Attribute for field jcb



2044
2045
2046
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2044

def jcb
  @jcb
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



2046
2047
2048
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2046

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



2048
2049
2050
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2048

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



2050
2051
2052
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2050

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



2052
2053
2054
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2052

def kr_card
  @kr_card
end

Attribute for field link



2054
2055
2056
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2054

def link
  @link
end

#livemodeObject (readonly)

If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.



2056
2057
2058
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2056

def livemode
  @livemode
end

#mb_wayObject (readonly)

Attribute for field mb_way



2058
2059
2060
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2058

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



2060
2061
2062
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2060

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



2062
2063
2064
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2062

def multibanco
  @multibanco
end

#nameObject (readonly)

The configuration’s name.



2064
2065
2066
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2064

def name
  @name
end

Attribute for field naver_pay



2066
2067
2068
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2066

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



2068
2069
2070
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2068

def 
  @nz_bank_account
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



2070
2071
2072
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2070

def object
  @object
end

#oxxoObject (readonly)

Attribute for field oxxo



2072
2073
2074
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2072

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



2074
2075
2076
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2074

def p24
  @p24
end

#parentObject (readonly)

For child configs, the configuration’s parent configuration.



2076
2077
2078
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2076

def parent
  @parent
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



2078
2079
2080
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2078

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



2080
2081
2082
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2080

def payco
  @payco
end

#paynowObject (readonly)

Attribute for field paynow



2082
2083
2084
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2082

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



2084
2085
2086
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2084

def paypal
  @paypal
end

#paypayObject (readonly)

Attribute for field paypay



2086
2087
2088
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2086

def paypay
  @paypay
end

#paytoObject (readonly)

Attribute for field payto



2088
2089
2090
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2088

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



2090
2091
2092
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2090

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



2092
2093
2094
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2092

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



2094
2095
2096
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2094

def qris
  @qris
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



2096
2097
2098
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2096

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



2098
2099
2100
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2098

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



2100
2101
2102
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2100

def satispay
  @satispay
end

#scalapayObject (readonly)

Attribute for field scalapay



2102
2103
2104
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2102

def scalapay
  @scalapay
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



2104
2105
2106
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2104

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



2106
2107
2108
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2106

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



2108
2109
2110
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2108

def sofort
  @sofort
end

#sunbitObject (readonly)

Attribute for field sunbit



2110
2111
2112
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2110

def sunbit
  @sunbit
end

#swishObject (readonly)

Attribute for field swish



2112
2113
2114
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2112

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



2114
2115
2116
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2114

def twint
  @twint
end

#upiObject (readonly)

Attribute for field upi



2116
2117
2118
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2116

def upi
  @upi
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



2118
2119
2120
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2118

def 
  @us_bank_account
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



2120
2121
2122
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2120

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



2122
2123
2124
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2122

def zip
  @zip
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a payment method configuration



2125
2126
2127
2128
2129
2130
2131
2132
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2125

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/payment_method_configurations",
    params: params,
    opts: opts
  )
end

.field_remappingsObject



2222
2223
2224
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2222

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2154
2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2154

def self.inner_class_types
  @inner_class_types = {
    acss_debit: AcssDebit,
    affirm: Affirm,
    afterpay_clearpay: AfterpayClearpay,
    alipay: Alipay,
    alma: Alma,
    amazon_pay: AmazonPay,
    apple_pay: ApplePay,
    au_becs_debit: AuBecsDebit,
    bacs_debit: BacsDebit,
    bancontact: Bancontact,
    billie: Billie,
    bizum: Bizum,
    blik: Blik,
    boleto: Boleto,
    card: Card,
    cartes_bancaires: CartesBancaires,
    cashapp: Cashapp,
    crypto: Crypto,
    customer_balance: CustomerBalance,
    eps: Eps,
    fpx: Fpx,
    giropay: Giropay,
    google_pay: GooglePay,
    gopay: Gopay,
    grabpay: Grabpay,
    id_bank_transfer: IdBankTransfer,
    ideal: Ideal,
    jcb: Jcb,
    kakao_pay: KakaoPay,
    klarna: Klarna,
    konbini: Konbini,
    kr_card: KrCard,
    link: Link,
    mb_way: MbWay,
    mobilepay: Mobilepay,
    multibanco: Multibanco,
    naver_pay: NaverPay,
    nz_bank_account: NzBankAccount,
    oxxo: Oxxo,
    p24: P24,
    pay_by_bank: PayByBank,
    payco: Payco,
    paynow: Paynow,
    paypal: Paypal,
    paypay: Paypay,
    payto: Payto,
    pix: Pix,
    promptpay: Promptpay,
    qris: Qris,
    revolut_pay: RevolutPay,
    samsung_pay: SamsungPay,
    satispay: Satispay,
    scalapay: Scalapay,
    sepa_debit: SepaDebit,
    shopeepay: Shopeepay,
    sofort: Sofort,
    sunbit: Sunbit,
    swish: Swish,
    twint: Twint,
    upi: Upi,
    us_bank_account: UsBankAccount,
    wechat_pay: WechatPay,
    zip: Zip,
  }
end

.list(params = {}, opts = {}) ⇒ Object

List payment method configurations



2135
2136
2137
2138
2139
2140
2141
2142
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2135

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/payment_method_configurations",
    params: params,
    opts: opts
  )
end

.object_nameObject



25
26
27
# File 'lib/stripe/resources/payment_method_configuration.rb', line 25

def self.object_name
  "payment_method_configuration"
end

.update(configuration, params = {}, opts = {}) ⇒ Object

Update payment method configuration



2145
2146
2147
2148
2149
2150
2151
2152
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2145

def self.update(configuration, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_method_configurations/%<configuration>s", { configuration: CGI.escape(configuration) }),
    params: params,
    opts: opts
  )
end