Class: Stripe::PaymentMethodConfiguration
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::PaymentMethodConfiguration
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Overview
PaymentMethodConfigurations control which payment methods are displayed to your customers when you don’t explicitly specify payment method types. You can have multiple configurations with different sets of payment methods for different scenarios.
There are two types of PaymentMethodConfigurations. Which is used depends on the [charge type](docs.stripe.com/connect/charges):
Direct configurations apply to payments created on your account, including Connect destination charges, Connect separate charges and transfers, and payments not involving Connect.
Child configurations apply to payments created on your connected accounts using direct charges, and charges with the on_behalf_of parameter.
Child configurations have a ‘parent` that sets default values and controls which settings connected accounts may override. You can specify a parent ID at payment time, and Stripe will automatically resolve the connected account’s associated child configuration. Parent configurations are [managed in the dashboard](dashboard.stripe.com/settings/payment_methods/connected_accounts) and are not available in this API.
Related guides:
-
[Payment Method Configurations API](docs.stripe.com/connect/payment-method-configurations)
-
[Multiple configurations on dynamic payment methods](docs.stripe.com/payments/multiple-payment-method-configs)
-
[Multiple configurations for your Connect accounts](docs.stripe.com/connect/multiple-payment-method-configurations)
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, ApplePay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CartesBancaires, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, GooglePay, Gopay, Grabpay, IdBankTransfer, Ideal, Jcb, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, Swish, Twint, Upi, UsBankAccount, WechatPay, Zip
Constant Summary collapse
- OBJECT_NAME =
"payment_method_configuration"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#active ⇒ Object
readonly
Whether the configuration can be used for new payments.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#apple_pay ⇒ Object
readonly
Attribute for field apple_pay.
-
#application ⇒ Object
readonly
For child configs, the Connect application associated with the configuration.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billie ⇒ Object
readonly
Attribute for field billie.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#cartes_bancaires ⇒ Object
readonly
Attribute for field cartes_bancaires.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#crypto ⇒ Object
readonly
Attribute for field crypto.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#google_pay ⇒ Object
readonly
Attribute for field google_pay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#is_default ⇒ Object
readonly
The default configuration is used whenever a payment method configuration is not specified.
-
#jcb ⇒ Object
readonly
Attribute for field jcb.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#name ⇒ Object
readonly
The configuration’s name.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#parent ⇒ Object
readonly
For child configs, the configuration’s parent configuration.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#paypay ⇒ Object
readonly
Attribute for field paypay.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#upi ⇒ Object
readonly
Attribute for field upi.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a payment method configuration.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
List payment method configurations.
- .object_name ⇒ Object
-
.update(configuration, params = {}, opts = {}) ⇒ Object
Update payment method configuration.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
1889 1890 1891 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1889 def acss_debit @acss_debit end |
#active ⇒ Object (readonly)
Whether the configuration can be used for new payments.
1891 1892 1893 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1891 def active @active end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
1893 1894 1895 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1893 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
1895 1896 1897 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1895 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
1897 1898 1899 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1897 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
1899 1900 1901 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1899 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
1901 1902 1903 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1901 def amazon_pay @amazon_pay end |
#apple_pay ⇒ Object (readonly)
Attribute for field apple_pay
1903 1904 1905 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1903 def apple_pay @apple_pay end |
#application ⇒ Object (readonly)
For child configs, the Connect application associated with the configuration.
1905 1906 1907 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1905 def application @application end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
1907 1908 1909 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1907 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
1909 1910 1911 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1909 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
1911 1912 1913 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1911 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
Attribute for field billie
1913 1914 1915 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1913 def billie @billie end |
#blik ⇒ Object (readonly)
Attribute for field blik
1915 1916 1917 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1915 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
1917 1918 1919 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1917 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
1919 1920 1921 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1919 def card @card end |
#cartes_bancaires ⇒ Object (readonly)
Attribute for field cartes_bancaires
1921 1922 1923 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1921 def cartes_bancaires @cartes_bancaires end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
1923 1924 1925 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1923 def cashapp @cashapp end |
#crypto ⇒ Object (readonly)
Attribute for field crypto
1925 1926 1927 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1925 def crypto @crypto end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
1927 1928 1929 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1927 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
1929 1930 1931 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1929 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
1931 1932 1933 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1931 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
1933 1934 1935 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1933 def giropay @giropay end |
#google_pay ⇒ Object (readonly)
Attribute for field google_pay
1935 1936 1937 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1935 def google_pay @google_pay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
1937 1938 1939 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1937 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
1939 1940 1941 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1939 def grabpay @grabpay end |
#id ⇒ Object (readonly)
Unique identifier for the object.
1941 1942 1943 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1941 def id @id end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
1943 1944 1945 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1943 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
1945 1946 1947 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1945 def ideal @ideal end |
#is_default ⇒ Object (readonly)
The default configuration is used whenever a payment method configuration is not specified.
1947 1948 1949 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1947 def is_default @is_default end |
#jcb ⇒ Object (readonly)
Attribute for field jcb
1949 1950 1951 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1949 def jcb @jcb end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
1951 1952 1953 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1951 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
1953 1954 1955 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1953 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
1955 1956 1957 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1955 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
1957 1958 1959 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1957 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
1959 1960 1961 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1959 def link @link end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
1961 1962 1963 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1961 def livemode @livemode end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
1963 1964 1965 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1963 def mb_way @mb_way end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
1965 1966 1967 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1965 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
1967 1968 1969 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1967 def multibanco @multibanco end |
#name ⇒ Object (readonly)
The configuration’s name.
1969 1970 1971 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1969 def name @name end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
1971 1972 1973 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1971 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
1973 1974 1975 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1973 def nz_bank_account @nz_bank_account end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
1975 1976 1977 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1975 def object @object end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
1977 1978 1979 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1977 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
1979 1980 1981 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1979 def p24 @p24 end |
#parent ⇒ Object (readonly)
For child configs, the configuration’s parent configuration.
1981 1982 1983 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1981 def parent @parent end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
1983 1984 1985 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1983 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
1985 1986 1987 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1985 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
1987 1988 1989 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1987 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
1989 1990 1991 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1989 def paypal @paypal end |
#paypay ⇒ Object (readonly)
Attribute for field paypay
1991 1992 1993 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1991 def paypay @paypay end |
#payto ⇒ Object (readonly)
Attribute for field payto
1993 1994 1995 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1993 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
1995 1996 1997 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1995 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
1997 1998 1999 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1997 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
1999 2000 2001 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1999 def qris @qris end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
2001 2002 2003 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2001 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
2003 2004 2005 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2003 def samsung_pay @samsung_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
2005 2006 2007 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2005 def satispay @satispay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
2007 2008 2009 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2007 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
2009 2010 2011 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2009 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
2011 2012 2013 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2011 def sofort @sofort end |
#swish ⇒ Object (readonly)
Attribute for field swish
2013 2014 2015 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2013 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
2015 2016 2017 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2015 def twint @twint end |
#upi ⇒ Object (readonly)
Attribute for field upi
2017 2018 2019 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2017 def upi @upi end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
2019 2020 2021 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2019 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
2021 2022 2023 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2021 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
2023 2024 2025 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2023 def zip @zip end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a payment method configuration
2026 2027 2028 2029 2030 2031 2032 2033 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2026 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/payment_method_configurations", params: params, opts: opts ) end |
.field_remappings ⇒ Object
2120 2121 2122 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2120 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2055 2056 2057 2058 2059 2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2055 def self.inner_class_types @inner_class_types = { acss_debit: AcssDebit, affirm: Affirm, afterpay_clearpay: AfterpayClearpay, alipay: Alipay, alma: Alma, amazon_pay: AmazonPay, apple_pay: ApplePay, au_becs_debit: AuBecsDebit, bacs_debit: BacsDebit, bancontact: Bancontact, billie: Billie, blik: Blik, boleto: Boleto, card: Card, cartes_bancaires: CartesBancaires, cashapp: Cashapp, crypto: Crypto, customer_balance: CustomerBalance, eps: Eps, fpx: Fpx, giropay: Giropay, google_pay: GooglePay, gopay: Gopay, grabpay: Grabpay, id_bank_transfer: IdBankTransfer, ideal: Ideal, jcb: Jcb, kakao_pay: KakaoPay, klarna: Klarna, konbini: Konbini, kr_card: KrCard, link: Link, mb_way: MbWay, mobilepay: Mobilepay, multibanco: Multibanco, naver_pay: NaverPay, nz_bank_account: NzBankAccount, oxxo: Oxxo, p24: P24, pay_by_bank: PayByBank, payco: Payco, paynow: Paynow, paypal: Paypal, paypay: Paypay, payto: Payto, pix: Pix, promptpay: Promptpay, qris: Qris, revolut_pay: RevolutPay, samsung_pay: SamsungPay, satispay: Satispay, sepa_debit: SepaDebit, shopeepay: Shopeepay, sofort: Sofort, swish: Swish, twint: Twint, upi: Upi, us_bank_account: UsBankAccount, wechat_pay: WechatPay, zip: Zip, } end |
.list(params = {}, opts = {}) ⇒ Object
List payment method configurations
2036 2037 2038 2039 2040 2041 2042 2043 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2036 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/payment_method_configurations", params: params, opts: opts ) end |
.object_name ⇒ Object
25 26 27 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 25 def self.object_name "payment_method_configuration" end |
.update(configuration, params = {}, opts = {}) ⇒ Object
Update payment method configuration
2046 2047 2048 2049 2050 2051 2052 2053 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2046 def self.update(configuration, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_method_configurations/%<configuration>s", { configuration: CGI.escape(configuration) }), params: params, opts: opts ) end |