Class: Stripe::PaymentMethodConfiguration

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/payment_method_configuration.rb

Overview

PaymentMethodConfigurations control which payment methods are displayed to your customers when you don’t explicitly specify payment method types. You can have multiple configurations with different sets of payment methods for different scenarios.

There are two types of PaymentMethodConfigurations. Which is used depends on the [charge type](docs.stripe.com/connect/charges):

Direct configurations apply to payments created on your account, including Connect destination charges, Connect separate charges and transfers, and payments not involving Connect.

Child configurations apply to payments created on your connected accounts using direct charges, and charges with the on_behalf_of parameter.

Child configurations have a ‘parent` that sets default values and controls which settings connected accounts may override. You can specify a parent ID at payment time, and Stripe will automatically resolve the connected account’s associated child configuration. Parent configurations are [managed in the dashboard](dashboard.stripe.com/settings/payment_methods/connected_accounts) and are not available in this API.

Related guides:

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, ApplePay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CartesBancaires, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, GooglePay, Grabpay, Ideal, Jcb, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, RevolutPay, SamsungPay, Satispay, SepaDebit, Sofort, Swish, Twint, Upi, UsBankAccount, WechatPay, Zip

Constant Summary collapse

OBJECT_NAME =
"payment_method_configuration"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

Attribute for field acss_debit



1734
1735
1736
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1734

def acss_debit
  @acss_debit
end

#activeObject (readonly)

Whether the configuration can be used for new payments.



1736
1737
1738
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1736

def active
  @active
end

#affirmObject (readonly)

Attribute for field affirm



1738
1739
1740
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1738

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



1740
1741
1742
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1740

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



1742
1743
1744
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1742

def alipay
  @alipay
end

#almaObject (readonly)

Attribute for field alma



1744
1745
1746
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1744

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



1746
1747
1748
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1746

def amazon_pay
  @amazon_pay
end

#apple_payObject (readonly)

Attribute for field apple_pay



1748
1749
1750
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1748

def apple_pay
  @apple_pay
end

#applicationObject (readonly)

For child configs, the Connect application associated with the configuration.



1750
1751
1752
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1750

def application
  @application
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



1752
1753
1754
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1752

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



1754
1755
1756
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1754

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



1756
1757
1758
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1756

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



1758
1759
1760
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1758

def billie
  @billie
end

#blikObject (readonly)

Attribute for field blik



1760
1761
1762
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1760

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



1762
1763
1764
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1762

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



1764
1765
1766
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1764

def card
  @card
end

#cartes_bancairesObject (readonly)

Attribute for field cartes_bancaires



1766
1767
1768
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1766

def cartes_bancaires
  @cartes_bancaires
end

#cashappObject (readonly)

Attribute for field cashapp



1768
1769
1770
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1768

def cashapp
  @cashapp
end

#cryptoObject (readonly)

Attribute for field crypto



1770
1771
1772
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1770

def crypto
  @crypto
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



1772
1773
1774
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1772

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



1774
1775
1776
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1774

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



1776
1777
1778
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1776

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



1778
1779
1780
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1778

def giropay
  @giropay
end

#google_payObject (readonly)

Attribute for field google_pay



1780
1781
1782
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1780

def google_pay
  @google_pay
end

#grabpayObject (readonly)

Attribute for field grabpay



1782
1783
1784
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1782

def grabpay
  @grabpay
end

#idObject (readonly)

Unique identifier for the object.



1784
1785
1786
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1784

def id
  @id
end

#idealObject (readonly)

Attribute for field ideal



1786
1787
1788
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1786

def ideal
  @ideal
end

#is_defaultObject (readonly)

The default configuration is used whenever a payment method configuration is not specified.



1788
1789
1790
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1788

def is_default
  @is_default
end

#jcbObject (readonly)

Attribute for field jcb



1790
1791
1792
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1790

def jcb
  @jcb
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



1792
1793
1794
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1792

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



1794
1795
1796
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1794

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



1796
1797
1798
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1796

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



1798
1799
1800
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1798

def kr_card
  @kr_card
end

Attribute for field link



1800
1801
1802
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1800

def link
  @link
end

#livemodeObject (readonly)

If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.



1802
1803
1804
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1802

def livemode
  @livemode
end

#mb_wayObject (readonly)

Attribute for field mb_way



1804
1805
1806
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1804

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



1806
1807
1808
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1806

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



1808
1809
1810
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1808

def multibanco
  @multibanco
end

#nameObject (readonly)

The configuration’s name.



1810
1811
1812
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1810

def name
  @name
end

Attribute for field naver_pay



1812
1813
1814
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1812

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



1814
1815
1816
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1814

def 
  @nz_bank_account
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



1816
1817
1818
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1816

def object
  @object
end

#oxxoObject (readonly)

Attribute for field oxxo



1818
1819
1820
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1818

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



1820
1821
1822
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1820

def p24
  @p24
end

#parentObject (readonly)

For child configs, the configuration’s parent configuration.



1822
1823
1824
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1822

def parent
  @parent
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



1824
1825
1826
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1824

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



1826
1827
1828
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1826

def payco
  @payco
end

#paynowObject (readonly)

Attribute for field paynow



1828
1829
1830
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1828

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



1830
1831
1832
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1830

def paypal
  @paypal
end

#paytoObject (readonly)

Attribute for field payto



1832
1833
1834
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1832

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



1834
1835
1836
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1834

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



1836
1837
1838
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1836

def promptpay
  @promptpay
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



1838
1839
1840
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1838

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



1840
1841
1842
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1840

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



1842
1843
1844
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1842

def satispay
  @satispay
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



1844
1845
1846
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1844

def sepa_debit
  @sepa_debit
end

#sofortObject (readonly)

Attribute for field sofort



1846
1847
1848
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1846

def sofort
  @sofort
end

#swishObject (readonly)

Attribute for field swish



1848
1849
1850
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1848

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



1850
1851
1852
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1850

def twint
  @twint
end

#upiObject (readonly)

Attribute for field upi



1852
1853
1854
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1852

def upi
  @upi
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



1854
1855
1856
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1854

def 
  @us_bank_account
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



1856
1857
1858
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1856

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



1858
1859
1860
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1858

def zip
  @zip
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a payment method configuration



1861
1862
1863
1864
1865
1866
1867
1868
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1861

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/payment_method_configurations",
    params: params,
    opts: opts
  )
end

.field_remappingsObject



1950
1951
1952
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1950

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1890

def self.inner_class_types
  @inner_class_types = {
    acss_debit: AcssDebit,
    affirm: Affirm,
    afterpay_clearpay: AfterpayClearpay,
    alipay: Alipay,
    alma: Alma,
    amazon_pay: AmazonPay,
    apple_pay: ApplePay,
    au_becs_debit: AuBecsDebit,
    bacs_debit: BacsDebit,
    bancontact: Bancontact,
    billie: Billie,
    blik: Blik,
    boleto: Boleto,
    card: Card,
    cartes_bancaires: CartesBancaires,
    cashapp: Cashapp,
    crypto: Crypto,
    customer_balance: CustomerBalance,
    eps: Eps,
    fpx: Fpx,
    giropay: Giropay,
    google_pay: GooglePay,
    grabpay: Grabpay,
    ideal: Ideal,
    jcb: Jcb,
    kakao_pay: KakaoPay,
    klarna: Klarna,
    konbini: Konbini,
    kr_card: KrCard,
    link: Link,
    mb_way: MbWay,
    mobilepay: Mobilepay,
    multibanco: Multibanco,
    naver_pay: NaverPay,
    nz_bank_account: NzBankAccount,
    oxxo: Oxxo,
    p24: P24,
    pay_by_bank: PayByBank,
    payco: Payco,
    paynow: Paynow,
    paypal: Paypal,
    payto: Payto,
    pix: Pix,
    promptpay: Promptpay,
    revolut_pay: RevolutPay,
    samsung_pay: SamsungPay,
    satispay: Satispay,
    sepa_debit: SepaDebit,
    sofort: Sofort,
    swish: Swish,
    twint: Twint,
    upi: Upi,
    us_bank_account: UsBankAccount,
    wechat_pay: WechatPay,
    zip: Zip,
  }
end

.list(params = {}, opts = {}) ⇒ Object

List payment method configurations



1871
1872
1873
1874
1875
1876
1877
1878
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1871

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/payment_method_configurations",
    params: params,
    opts: opts
  )
end

.object_nameObject



25
26
27
# File 'lib/stripe/resources/payment_method_configuration.rb', line 25

def self.object_name
  "payment_method_configuration"
end

.update(configuration, params = {}, opts = {}) ⇒ Object

Update payment method configuration



1881
1882
1883
1884
1885
1886
1887
1888
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1881

def self.update(configuration, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_method_configurations/%<configuration>s", { configuration: CGI.escape(configuration) }),
    params: params,
    opts: opts
  )
end