Class: Stripe::PaymentMethodConfiguration
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::PaymentMethodConfiguration
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Overview
PaymentMethodConfigurations control which payment methods are displayed to your customers when you don’t explicitly specify payment method types. You can have multiple configurations with different sets of payment methods for different scenarios.
There are two types of PaymentMethodConfigurations. Which is used depends on the [charge type](stripe.com/docs/connect/charges):
Direct configurations apply to payments created on your account, including Connect destination charges, Connect separate charges and transfers, and payments not involving Connect.
Child configurations apply to payments created on your connected accounts using direct charges, and charges with the on_behalf_of parameter.
Child configurations have a ‘parent` that sets default values and controls which settings connected accounts may override. You can specify a parent ID at payment time, and Stripe will automatically resolve the connected account’s associated child configuration. Parent configurations are [managed in the dashboard](dashboard.stripe.com/settings/payment_methods/connected_accounts) and are not available in this API.
Related guides:
-
[Payment Method Configurations API](stripe.com/docs/connect/payment-method-configurations)
-
[Multiple configurations on dynamic payment methods](stripe.com/docs/payments/multiple-payment-method-configs)
-
[Multiple configurations for your Connect accounts](stripe.com/docs/connect/multiple-payment-method-configurations)
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, ApplePay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CartesBancaires, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, GooglePay, Gopay, Grabpay, IdBankTransfer, Ideal, Jcb, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, Swish, Twint, UsBankAccount, WechatPay, Zip
Constant Summary collapse
- OBJECT_NAME =
"payment_method_configuration"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#active ⇒ Object
readonly
Whether the configuration can be used for new payments.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#apple_pay ⇒ Object
readonly
Attribute for field apple_pay.
-
#application ⇒ Object
readonly
For child configs, the Connect application associated with the configuration.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billie ⇒ Object
readonly
Attribute for field billie.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#cartes_bancaires ⇒ Object
readonly
Attribute for field cartes_bancaires.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#crypto ⇒ Object
readonly
Attribute for field crypto.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#google_pay ⇒ Object
readonly
Attribute for field google_pay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#is_default ⇒ Object
readonly
The default configuration is used whenever a payment method configuration is not specified.
-
#jcb ⇒ Object
readonly
Attribute for field jcb.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#name ⇒ Object
readonly
The configuration’s name.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#parent ⇒ Object
readonly
For child configs, the configuration’s parent configuration.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#paypay ⇒ Object
readonly
Attribute for field paypay.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a payment method configuration.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
List payment method configurations.
- .object_name ⇒ Object
-
.update(configuration, params = {}, opts = {}) ⇒ Object
Update payment method configuration.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
1858 1859 1860 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1858 def acss_debit @acss_debit end |
#active ⇒ Object (readonly)
Whether the configuration can be used for new payments.
1860 1861 1862 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1860 def active @active end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
1862 1863 1864 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1862 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
1864 1865 1866 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1864 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
1866 1867 1868 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1866 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
1868 1869 1870 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1868 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
1870 1871 1872 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1870 def amazon_pay @amazon_pay end |
#apple_pay ⇒ Object (readonly)
Attribute for field apple_pay
1872 1873 1874 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1872 def apple_pay @apple_pay end |
#application ⇒ Object (readonly)
For child configs, the Connect application associated with the configuration.
1874 1875 1876 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1874 def application @application end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
1876 1877 1878 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1876 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
1878 1879 1880 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1878 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
1880 1881 1882 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1880 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
Attribute for field billie
1882 1883 1884 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1882 def billie @billie end |
#blik ⇒ Object (readonly)
Attribute for field blik
1884 1885 1886 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1884 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
1886 1887 1888 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1886 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
1888 1889 1890 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1888 def card @card end |
#cartes_bancaires ⇒ Object (readonly)
Attribute for field cartes_bancaires
1890 1891 1892 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1890 def cartes_bancaires @cartes_bancaires end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
1892 1893 1894 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1892 def cashapp @cashapp end |
#crypto ⇒ Object (readonly)
Attribute for field crypto
1894 1895 1896 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1894 def crypto @crypto end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
1896 1897 1898 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1896 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
1898 1899 1900 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1898 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
1900 1901 1902 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1900 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
1902 1903 1904 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1902 def giropay @giropay end |
#google_pay ⇒ Object (readonly)
Attribute for field google_pay
1904 1905 1906 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1904 def google_pay @google_pay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
1906 1907 1908 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1906 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
1908 1909 1910 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1908 def grabpay @grabpay end |
#id ⇒ Object (readonly)
Unique identifier for the object.
1910 1911 1912 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1910 def id @id end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
1912 1913 1914 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1912 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
1914 1915 1916 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1914 def ideal @ideal end |
#is_default ⇒ Object (readonly)
The default configuration is used whenever a payment method configuration is not specified.
1916 1917 1918 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1916 def is_default @is_default end |
#jcb ⇒ Object (readonly)
Attribute for field jcb
1918 1919 1920 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1918 def jcb @jcb end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
1920 1921 1922 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1920 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
1922 1923 1924 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1922 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
1924 1925 1926 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1924 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
1926 1927 1928 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1926 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
1928 1929 1930 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1928 def link @link end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
1930 1931 1932 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1930 def livemode @livemode end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
1932 1933 1934 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1932 def mb_way @mb_way end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
1934 1935 1936 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1934 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
1936 1937 1938 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1936 def multibanco @multibanco end |
#name ⇒ Object (readonly)
The configuration’s name.
1938 1939 1940 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1938 def name @name end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
1940 1941 1942 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1940 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
1942 1943 1944 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1942 def nz_bank_account @nz_bank_account end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
1944 1945 1946 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1944 def object @object end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
1946 1947 1948 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1946 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
1948 1949 1950 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1948 def p24 @p24 end |
#parent ⇒ Object (readonly)
For child configs, the configuration’s parent configuration.
1950 1951 1952 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1950 def parent @parent end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
1952 1953 1954 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1952 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
1954 1955 1956 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1954 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
1956 1957 1958 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1956 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
1958 1959 1960 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1958 def paypal @paypal end |
#paypay ⇒ Object (readonly)
Attribute for field paypay
1960 1961 1962 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1960 def paypay @paypay end |
#payto ⇒ Object (readonly)
Attribute for field payto
1962 1963 1964 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1962 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
1964 1965 1966 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1964 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
1966 1967 1968 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1966 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
1968 1969 1970 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1968 def qris @qris end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
1970 1971 1972 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1970 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
1972 1973 1974 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1972 def samsung_pay @samsung_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
1974 1975 1976 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1974 def satispay @satispay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
1976 1977 1978 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1976 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
1978 1979 1980 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1978 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
1980 1981 1982 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1980 def sofort @sofort end |
#swish ⇒ Object (readonly)
Attribute for field swish
1982 1983 1984 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1982 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
1984 1985 1986 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1984 def twint @twint end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
1986 1987 1988 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1986 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
1988 1989 1990 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1988 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
1990 1991 1992 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1990 def zip @zip end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a payment method configuration
1993 1994 1995 1996 1997 1998 1999 2000 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1993 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/payment_method_configurations", params: params, opts: opts ) end |
.field_remappings ⇒ Object
2086 2087 2088 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2086 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2022 def self.inner_class_types @inner_class_types = { acss_debit: AcssDebit, affirm: Affirm, afterpay_clearpay: AfterpayClearpay, alipay: Alipay, alma: Alma, amazon_pay: AmazonPay, apple_pay: ApplePay, au_becs_debit: AuBecsDebit, bacs_debit: BacsDebit, bancontact: Bancontact, billie: Billie, blik: Blik, boleto: Boleto, card: Card, cartes_bancaires: CartesBancaires, cashapp: Cashapp, crypto: Crypto, customer_balance: CustomerBalance, eps: Eps, fpx: Fpx, giropay: Giropay, google_pay: GooglePay, gopay: Gopay, grabpay: Grabpay, id_bank_transfer: IdBankTransfer, ideal: Ideal, jcb: Jcb, kakao_pay: KakaoPay, klarna: Klarna, konbini: Konbini, kr_card: KrCard, link: Link, mb_way: MbWay, mobilepay: Mobilepay, multibanco: Multibanco, naver_pay: NaverPay, nz_bank_account: NzBankAccount, oxxo: Oxxo, p24: P24, pay_by_bank: PayByBank, payco: Payco, paynow: Paynow, paypal: Paypal, paypay: Paypay, payto: Payto, pix: Pix, promptpay: Promptpay, qris: Qris, revolut_pay: RevolutPay, samsung_pay: SamsungPay, satispay: Satispay, sepa_debit: SepaDebit, shopeepay: Shopeepay, sofort: Sofort, swish: Swish, twint: Twint, us_bank_account: UsBankAccount, wechat_pay: WechatPay, zip: Zip, } end |
.list(params = {}, opts = {}) ⇒ Object
List payment method configurations
2003 2004 2005 2006 2007 2008 2009 2010 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2003 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/payment_method_configurations", params: params, opts: opts ) end |
.object_name ⇒ Object
25 26 27 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 25 def self.object_name "payment_method_configuration" end |
.update(configuration, params = {}, opts = {}) ⇒ Object
Update payment method configuration
2013 2014 2015 2016 2017 2018 2019 2020 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2013 def self.update(configuration, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_method_configurations/%<configuration>s", { configuration: CGI.escape(configuration) }), params: params, opts: opts ) end |