Class: Stripe::PaymentMethodConfiguration
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::PaymentMethodConfiguration
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Overview
PaymentMethodConfigurations control which payment methods are displayed to your customers when you don’t explicitly specify payment method types. You can have multiple configurations with different sets of payment methods for different scenarios.
There are two types of PaymentMethodConfigurations. Which is used depends on the [charge type](stripe.com/docs/connect/charges):
Direct configurations apply to payments created on your account, including Connect destination charges, Connect separate charges and transfers, and payments not involving Connect.
Child configurations apply to payments created on your connected accounts using direct charges, and charges with the on_behalf_of parameter.
Child configurations have a ‘parent` that sets default values and controls which settings connected accounts may override. You can specify a parent ID at payment time, and Stripe will automatically resolve the connected account’s associated child configuration. Parent configurations are [managed in the dashboard](dashboard.stripe.com/settings/payment_methods/connected_accounts) and are not available in this API.
Related guides:
-
[Payment Method Configurations API](stripe.com/docs/connect/payment-method-configurations)
-
[Multiple configurations on dynamic payment methods](stripe.com/docs/payments/multiple-payment-method-configs)
-
[Multiple configurations for your Connect accounts](stripe.com/docs/connect/multiple-payment-method-configurations)
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, ApplePay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CartesBancaires, Cashapp, CustomerBalance, Eps, Fpx, Giropay, GooglePay, Gopay, Grabpay, IdBankTransfer, Ideal, Jcb, KakaoPay, Klarna, Konbini, KrCard, Link, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, Swish, Twint, UsBankAccount, WechatPay, Zip
Constant Summary collapse
- OBJECT_NAME =
"payment_method_configuration"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#active ⇒ Object
readonly
Whether the configuration can be used for new payments.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#apple_pay ⇒ Object
readonly
Attribute for field apple_pay.
-
#application ⇒ Object
readonly
For child configs, the Connect application associated with the configuration.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billie ⇒ Object
readonly
Attribute for field billie.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#cartes_bancaires ⇒ Object
readonly
Attribute for field cartes_bancaires.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#google_pay ⇒ Object
readonly
Attribute for field google_pay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#is_default ⇒ Object
readonly
The default configuration is used whenever a payment method configuration is not specified.
-
#jcb ⇒ Object
readonly
Attribute for field jcb.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#name ⇒ Object
readonly
The configuration’s name.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#parent ⇒ Object
readonly
For child configs, the configuration’s parent configuration.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#paypay ⇒ Object
readonly
Attribute for field paypay.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a payment method configuration.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
List payment method configurations.
- .object_name ⇒ Object
-
.update(configuration, params = {}, opts = {}) ⇒ Object
Update payment method configuration.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
1796 1797 1798 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1796 def acss_debit @acss_debit end |
#active ⇒ Object (readonly)
Whether the configuration can be used for new payments.
1798 1799 1800 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1798 def active @active end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
1800 1801 1802 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1800 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
1802 1803 1804 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1802 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
1804 1805 1806 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1804 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
1806 1807 1808 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1806 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
1808 1809 1810 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1808 def amazon_pay @amazon_pay end |
#apple_pay ⇒ Object (readonly)
Attribute for field apple_pay
1810 1811 1812 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1810 def apple_pay @apple_pay end |
#application ⇒ Object (readonly)
For child configs, the Connect application associated with the configuration.
1812 1813 1814 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1812 def application @application end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
1814 1815 1816 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1814 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
1816 1817 1818 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1816 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
1818 1819 1820 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1818 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
Attribute for field billie
1820 1821 1822 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1820 def billie @billie end |
#blik ⇒ Object (readonly)
Attribute for field blik
1822 1823 1824 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1822 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
1824 1825 1826 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1824 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
1826 1827 1828 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1826 def card @card end |
#cartes_bancaires ⇒ Object (readonly)
Attribute for field cartes_bancaires
1828 1829 1830 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1828 def cartes_bancaires @cartes_bancaires end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
1830 1831 1832 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1830 def cashapp @cashapp end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
1832 1833 1834 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1832 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
1834 1835 1836 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1834 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
1836 1837 1838 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1836 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
1838 1839 1840 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1838 def giropay @giropay end |
#google_pay ⇒ Object (readonly)
Attribute for field google_pay
1840 1841 1842 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1840 def google_pay @google_pay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
1842 1843 1844 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1842 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
1844 1845 1846 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1844 def grabpay @grabpay end |
#id ⇒ Object (readonly)
Unique identifier for the object.
1846 1847 1848 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1846 def id @id end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
1848 1849 1850 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1848 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
1850 1851 1852 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1850 def ideal @ideal end |
#is_default ⇒ Object (readonly)
The default configuration is used whenever a payment method configuration is not specified.
1852 1853 1854 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1852 def is_default @is_default end |
#jcb ⇒ Object (readonly)
Attribute for field jcb
1854 1855 1856 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1854 def jcb @jcb end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
1856 1857 1858 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1856 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
1858 1859 1860 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1858 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
1860 1861 1862 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1860 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
1862 1863 1864 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1862 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
1864 1865 1866 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1864 def link @link end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
1866 1867 1868 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1866 def livemode @livemode end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
1868 1869 1870 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1868 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
1870 1871 1872 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1870 def multibanco @multibanco end |
#name ⇒ Object (readonly)
The configuration’s name.
1872 1873 1874 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1872 def name @name end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
1874 1875 1876 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1874 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
1876 1877 1878 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1876 def nz_bank_account @nz_bank_account end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
1878 1879 1880 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1878 def object @object end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
1880 1881 1882 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1880 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
1882 1883 1884 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1882 def p24 @p24 end |
#parent ⇒ Object (readonly)
For child configs, the configuration’s parent configuration.
1884 1885 1886 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1884 def parent @parent end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
1886 1887 1888 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1886 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
1888 1889 1890 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1888 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
1890 1891 1892 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1890 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
1892 1893 1894 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1892 def paypal @paypal end |
#paypay ⇒ Object (readonly)
Attribute for field paypay
1894 1895 1896 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1894 def paypay @paypay end |
#payto ⇒ Object (readonly)
Attribute for field payto
1896 1897 1898 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1896 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
1898 1899 1900 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1898 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
1900 1901 1902 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1900 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
1902 1903 1904 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1902 def qris @qris end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
1904 1905 1906 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1904 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
1906 1907 1908 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1906 def samsung_pay @samsung_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
1908 1909 1910 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1908 def satispay @satispay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
1910 1911 1912 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1910 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
1912 1913 1914 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1912 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
1914 1915 1916 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1914 def sofort @sofort end |
#swish ⇒ Object (readonly)
Attribute for field swish
1916 1917 1918 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1916 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
1918 1919 1920 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1918 def twint @twint end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
1920 1921 1922 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1920 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
1922 1923 1924 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1922 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
1924 1925 1926 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1924 def zip @zip end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a payment method configuration
1927 1928 1929 1930 1931 1932 1933 1934 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1927 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/payment_method_configurations", params: params, opts: opts ) end |
.field_remappings ⇒ Object
2018 2019 2020 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2018 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1956 def self.inner_class_types @inner_class_types = { acss_debit: AcssDebit, affirm: Affirm, afterpay_clearpay: AfterpayClearpay, alipay: Alipay, alma: Alma, amazon_pay: AmazonPay, apple_pay: ApplePay, au_becs_debit: AuBecsDebit, bacs_debit: BacsDebit, bancontact: Bancontact, billie: Billie, blik: Blik, boleto: Boleto, card: Card, cartes_bancaires: CartesBancaires, cashapp: Cashapp, customer_balance: CustomerBalance, eps: Eps, fpx: Fpx, giropay: Giropay, google_pay: GooglePay, gopay: Gopay, grabpay: Grabpay, id_bank_transfer: IdBankTransfer, ideal: Ideal, jcb: Jcb, kakao_pay: KakaoPay, klarna: Klarna, konbini: Konbini, kr_card: KrCard, link: Link, mobilepay: Mobilepay, multibanco: Multibanco, naver_pay: NaverPay, nz_bank_account: NzBankAccount, oxxo: Oxxo, p24: P24, pay_by_bank: PayByBank, payco: Payco, paynow: Paynow, paypal: Paypal, paypay: Paypay, payto: Payto, pix: Pix, promptpay: Promptpay, qris: Qris, revolut_pay: RevolutPay, samsung_pay: SamsungPay, satispay: Satispay, sepa_debit: SepaDebit, shopeepay: Shopeepay, sofort: Sofort, swish: Swish, twint: Twint, us_bank_account: UsBankAccount, wechat_pay: WechatPay, zip: Zip, } end |
.list(params = {}, opts = {}) ⇒ Object
List payment method configurations
1937 1938 1939 1940 1941 1942 1943 1944 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1937 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/payment_method_configurations", params: params, opts: opts ) end |
.object_name ⇒ Object
25 26 27 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 25 def self.object_name "payment_method_configuration" end |
.update(configuration, params = {}, opts = {}) ⇒ Object
Update payment method configuration
1947 1948 1949 1950 1951 1952 1953 1954 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1947 def self.update(configuration, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_method_configurations/%<configuration>s", { configuration: CGI.escape(configuration) }), params: params, opts: opts ) end |