Class: Stripe::PaymentMethodConfiguration
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::PaymentMethodConfiguration
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Overview
PaymentMethodConfigurations control which payment methods are displayed to your customers when you don’t explicitly specify payment method types. You can have multiple configurations with different sets of payment methods for different scenarios.
There are two types of PaymentMethodConfigurations. Which is used depends on the [charge type](stripe.com/docs/connect/charges):
Direct configurations apply to payments created on your account, including Connect destination charges, Connect separate charges and transfers, and payments not involving Connect.
Child configurations apply to payments created on your connected accounts using direct charges, and charges with the on_behalf_of parameter.
Child configurations have a ‘parent` that sets default values and controls which settings connected accounts may override. You can specify a parent ID at payment time, and Stripe will automatically resolve the connected account’s associated child configuration. Parent configurations are [managed in the dashboard](dashboard.stripe.com/settings/payment_methods/connected_accounts) and are not available in this API.
Related guides:
-
[Payment Method Configurations API](stripe.com/docs/connect/payment-method-configurations)
-
[Multiple configurations on dynamic payment methods](stripe.com/docs/payments/multiple-payment-method-configs)
-
[Multiple configurations for your Connect accounts](stripe.com/docs/connect/multiple-payment-method-configurations)
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, ApplePay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CartesBancaires, Cashapp, CreateParams, CustomerBalance, Eps, Fpx, Giropay, GooglePay, Gopay, Grabpay, IdBankTransfer, Ideal, Jcb, KakaoPay, Klarna, Konbini, KrCard, Link, ListParams, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, Swish, Twint, UpdateParams, UsBankAccount, WechatPay, Zip
Constant Summary collapse
- OBJECT_NAME =
"payment_method_configuration"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#active ⇒ Object
readonly
Whether the configuration can be used for new payments.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#apple_pay ⇒ Object
readonly
Attribute for field apple_pay.
-
#application ⇒ Object
readonly
For child configs, the Connect application associated with the configuration.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billie ⇒ Object
readonly
Attribute for field billie.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#cartes_bancaires ⇒ Object
readonly
Attribute for field cartes_bancaires.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#google_pay ⇒ Object
readonly
Attribute for field google_pay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#is_default ⇒ Object
readonly
The default configuration is used whenever a payment method configuration is not specified.
-
#jcb ⇒ Object
readonly
Attribute for field jcb.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#name ⇒ Object
readonly
The configuration’s name.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#parent ⇒ Object
readonly
For child configs, the configuration’s parent configuration.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a payment method configuration.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
List payment method configurations.
- .object_name ⇒ Object
-
.update(configuration, params = {}, opts = {}) ⇒ Object
Update payment method configuration.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
4222 4223 4224 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4222 def acss_debit @acss_debit end |
#active ⇒ Object (readonly)
Whether the configuration can be used for new payments.
4224 4225 4226 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4224 def active @active end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
4226 4227 4228 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4226 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
4228 4229 4230 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4228 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
4230 4231 4232 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4230 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
4232 4233 4234 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4232 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
4234 4235 4236 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4234 def amazon_pay @amazon_pay end |
#apple_pay ⇒ Object (readonly)
Attribute for field apple_pay
4236 4237 4238 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4236 def apple_pay @apple_pay end |
#application ⇒ Object (readonly)
For child configs, the Connect application associated with the configuration.
4238 4239 4240 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4238 def application @application end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
4240 4241 4242 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4240 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
4242 4243 4244 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4242 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
4244 4245 4246 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4244 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
Attribute for field billie
4246 4247 4248 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4246 def billie @billie end |
#blik ⇒ Object (readonly)
Attribute for field blik
4248 4249 4250 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4248 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
4250 4251 4252 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4250 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
4252 4253 4254 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4252 def card @card end |
#cartes_bancaires ⇒ Object (readonly)
Attribute for field cartes_bancaires
4254 4255 4256 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4254 def cartes_bancaires @cartes_bancaires end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
4256 4257 4258 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4256 def cashapp @cashapp end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
4258 4259 4260 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4258 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
4260 4261 4262 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4260 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
4262 4263 4264 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4262 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
4264 4265 4266 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4264 def giropay @giropay end |
#google_pay ⇒ Object (readonly)
Attribute for field google_pay
4266 4267 4268 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4266 def google_pay @google_pay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
4268 4269 4270 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4268 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
4270 4271 4272 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4270 def grabpay @grabpay end |
#id ⇒ Object (readonly)
Unique identifier for the object.
4272 4273 4274 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4272 def id @id end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
4274 4275 4276 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4274 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
4276 4277 4278 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4276 def ideal @ideal end |
#is_default ⇒ Object (readonly)
The default configuration is used whenever a payment method configuration is not specified.
4278 4279 4280 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4278 def is_default @is_default end |
#jcb ⇒ Object (readonly)
Attribute for field jcb
4280 4281 4282 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4280 def jcb @jcb end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
4282 4283 4284 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4282 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
4284 4285 4286 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4284 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
4286 4287 4288 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4286 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
4288 4289 4290 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4288 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
4290 4291 4292 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4290 def link @link end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
4292 4293 4294 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4292 def livemode @livemode end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
4294 4295 4296 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4294 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
4296 4297 4298 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4296 def multibanco @multibanco end |
#name ⇒ Object (readonly)
The configuration’s name.
4298 4299 4300 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4298 def name @name end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
4300 4301 4302 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4300 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
4302 4303 4304 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4302 def nz_bank_account @nz_bank_account end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
4304 4305 4306 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4304 def object @object end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
4306 4307 4308 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4306 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
4308 4309 4310 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4308 def p24 @p24 end |
#parent ⇒ Object (readonly)
For child configs, the configuration’s parent configuration.
4310 4311 4312 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4310 def parent @parent end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
4312 4313 4314 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4312 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
4314 4315 4316 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4314 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
4316 4317 4318 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4316 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
4318 4319 4320 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4318 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
4320 4321 4322 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4320 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
4322 4323 4324 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4322 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
4324 4325 4326 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4324 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
4326 4327 4328 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4326 def qris @qris end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
4328 4329 4330 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4328 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
4330 4331 4332 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4330 def samsung_pay @samsung_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
4332 4333 4334 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4332 def satispay @satispay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
4334 4335 4336 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4334 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
4336 4337 4338 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4336 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
4338 4339 4340 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4338 def sofort @sofort end |
#swish ⇒ Object (readonly)
Attribute for field swish
4340 4341 4342 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4340 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
4342 4343 4344 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4342 def twint @twint end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
4344 4345 4346 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4344 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
4346 4347 4348 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4346 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
4348 4349 4350 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4348 def zip @zip end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a payment method configuration
4351 4352 4353 4354 4355 4356 4357 4358 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4351 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/payment_method_configurations", params: params, opts: opts ) end |
.field_remappings ⇒ Object
4441 4442 4443 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4441 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
4380 4381 4382 4383 4384 4385 4386 4387 4388 4389 4390 4391 4392 4393 4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 4433 4434 4435 4436 4437 4438 4439 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4380 def self.inner_class_types @inner_class_types = { acss_debit: AcssDebit, affirm: Affirm, afterpay_clearpay: AfterpayClearpay, alipay: Alipay, alma: Alma, amazon_pay: AmazonPay, apple_pay: ApplePay, au_becs_debit: AuBecsDebit, bacs_debit: BacsDebit, bancontact: Bancontact, billie: Billie, blik: Blik, boleto: Boleto, card: Card, cartes_bancaires: CartesBancaires, cashapp: Cashapp, customer_balance: CustomerBalance, eps: Eps, fpx: Fpx, giropay: Giropay, google_pay: GooglePay, gopay: Gopay, grabpay: Grabpay, id_bank_transfer: IdBankTransfer, ideal: Ideal, jcb: Jcb, kakao_pay: KakaoPay, klarna: Klarna, konbini: Konbini, kr_card: KrCard, link: Link, mobilepay: Mobilepay, multibanco: Multibanco, naver_pay: NaverPay, nz_bank_account: NzBankAccount, oxxo: Oxxo, p24: P24, pay_by_bank: PayByBank, payco: Payco, paynow: Paynow, paypal: Paypal, payto: Payto, pix: Pix, promptpay: Promptpay, qris: Qris, revolut_pay: RevolutPay, samsung_pay: SamsungPay, satispay: Satispay, sepa_debit: SepaDebit, shopeepay: Shopeepay, sofort: Sofort, swish: Swish, twint: Twint, us_bank_account: UsBankAccount, wechat_pay: WechatPay, zip: Zip, } end |
.list(params = {}, opts = {}) ⇒ Object
List payment method configurations
4361 4362 4363 4364 4365 4366 4367 4368 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4361 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/payment_method_configurations", params: params, opts: opts ) end |
.object_name ⇒ Object
25 26 27 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 25 def self.object_name "payment_method_configuration" end |
.update(configuration, params = {}, opts = {}) ⇒ Object
Update payment method configuration
4371 4372 4373 4374 4375 4376 4377 4378 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 4371 def self.update(configuration, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_method_configurations/%<configuration>s", { configuration: CGI.escape(configuration) }), params: params, opts: opts ) end |