Class: Stripe::PaymentMethodConfiguration

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/payment_method_configuration.rb

Overview

PaymentMethodConfigurations control which payment methods are displayed to your customers when you don’t explicitly specify payment method types. You can have multiple configurations with different sets of payment methods for different scenarios.

There are two types of PaymentMethodConfigurations. Which is used depends on the [charge type](stripe.com/docs/connect/charges):

Direct configurations apply to payments created on your account, including Connect destination charges, Connect separate charges and transfers, and payments not involving Connect.

Child configurations apply to payments created on your connected accounts using direct charges, and charges with the on_behalf_of parameter.

Child configurations have a ‘parent` that sets default values and controls which settings connected accounts may override. You can specify a parent ID at payment time, and Stripe will automatically resolve the connected account’s associated child configuration. Parent configurations are [managed in the dashboard](dashboard.stripe.com/settings/payment_methods/connected_accounts) and are not available in this API.

Related guides:

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, ApplePay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CartesBancaires, Cashapp, CreateParams, CustomerBalance, Eps, Fpx, Giropay, GooglePay, Gopay, Grabpay, IdBankTransfer, Ideal, Jcb, KakaoPay, Klarna, Konbini, KrCard, Link, ListParams, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, Swish, Twint, UpdateParams, UsBankAccount, WechatPay, Zip

Constant Summary collapse

OBJECT_NAME =
"payment_method_configuration"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

Attribute for field acss_debit



3326
3327
3328
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3326

def acss_debit
  @acss_debit
end

#activeObject (readonly)

Whether the configuration can be used for new payments.



3328
3329
3330
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3328

def active
  @active
end

#affirmObject (readonly)

Attribute for field affirm



3330
3331
3332
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3330

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



3332
3333
3334
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3332

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



3334
3335
3336
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3334

def alipay
  @alipay
end

#almaObject (readonly)

Attribute for field alma



3336
3337
3338
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3336

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



3338
3339
3340
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3338

def amazon_pay
  @amazon_pay
end

#apple_payObject (readonly)

Attribute for field apple_pay



3340
3341
3342
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3340

def apple_pay
  @apple_pay
end

#applicationObject (readonly)

For child configs, the Connect application associated with the configuration.



3342
3343
3344
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3342

def application
  @application
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



3344
3345
3346
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3344

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



3346
3347
3348
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3346

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



3348
3349
3350
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3348

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



3350
3351
3352
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3350

def billie
  @billie
end

#blikObject (readonly)

Attribute for field blik



3352
3353
3354
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3352

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



3354
3355
3356
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3354

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



3356
3357
3358
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3356

def card
  @card
end

#cartes_bancairesObject (readonly)

Attribute for field cartes_bancaires



3358
3359
3360
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3358

def cartes_bancaires
  @cartes_bancaires
end

#cashappObject (readonly)

Attribute for field cashapp



3360
3361
3362
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3360

def cashapp
  @cashapp
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



3362
3363
3364
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3362

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



3364
3365
3366
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3364

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



3366
3367
3368
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3366

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



3368
3369
3370
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3368

def giropay
  @giropay
end

#google_payObject (readonly)

Attribute for field google_pay



3370
3371
3372
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3370

def google_pay
  @google_pay
end

#gopayObject (readonly)

Attribute for field gopay



3372
3373
3374
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3372

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



3374
3375
3376
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3374

def grabpay
  @grabpay
end

#idObject (readonly)

Unique identifier for the object.



3376
3377
3378
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3376

def id
  @id
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



3378
3379
3380
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3378

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



3380
3381
3382
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3380

def ideal
  @ideal
end

#is_defaultObject (readonly)

The default configuration is used whenever a payment method configuration is not specified.



3382
3383
3384
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3382

def is_default
  @is_default
end

#jcbObject (readonly)

Attribute for field jcb



3384
3385
3386
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3384

def jcb
  @jcb
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



3386
3387
3388
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3386

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



3388
3389
3390
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3388

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



3390
3391
3392
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3390

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



3392
3393
3394
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3392

def kr_card
  @kr_card
end

Attribute for field link



3394
3395
3396
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3394

def link
  @link
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



3396
3397
3398
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3396

def livemode
  @livemode
end

#mobilepayObject (readonly)

Attribute for field mobilepay



3398
3399
3400
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3398

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



3400
3401
3402
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3400

def multibanco
  @multibanco
end

#nameObject (readonly)

The configuration’s name.



3402
3403
3404
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3402

def name
  @name
end

Attribute for field naver_pay



3404
3405
3406
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3404

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



3406
3407
3408
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3406

def 
  @nz_bank_account
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



3408
3409
3410
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3408

def object
  @object
end

#oxxoObject (readonly)

Attribute for field oxxo



3410
3411
3412
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3410

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



3412
3413
3414
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3412

def p24
  @p24
end

#parentObject (readonly)

For child configs, the configuration’s parent configuration.



3414
3415
3416
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3414

def parent
  @parent
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



3416
3417
3418
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3416

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



3418
3419
3420
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3418

def payco
  @payco
end

#paynowObject (readonly)

Attribute for field paynow



3420
3421
3422
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3420

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



3422
3423
3424
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3422

def paypal
  @paypal
end

#paytoObject (readonly)

Attribute for field payto



3424
3425
3426
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3424

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



3426
3427
3428
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3426

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



3428
3429
3430
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3428

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



3430
3431
3432
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3430

def qris
  @qris
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



3432
3433
3434
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3432

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



3434
3435
3436
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3434

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



3436
3437
3438
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3436

def satispay
  @satispay
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



3438
3439
3440
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3438

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



3440
3441
3442
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3440

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



3442
3443
3444
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3442

def sofort
  @sofort
end

#swishObject (readonly)

Attribute for field swish



3444
3445
3446
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3444

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



3446
3447
3448
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3446

def twint
  @twint
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



3448
3449
3450
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3448

def 
  @us_bank_account
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



3450
3451
3452
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3450

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



3452
3453
3454
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3452

def zip
  @zip
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a payment method configuration



3455
3456
3457
3458
3459
3460
3461
3462
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3455

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/payment_method_configurations",
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

List payment method configurations



3465
3466
3467
3468
3469
3470
3471
3472
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3465

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/payment_method_configurations",
    params: params,
    opts: opts
  )
end

.object_nameObject



25
26
27
# File 'lib/stripe/resources/payment_method_configuration.rb', line 25

def self.object_name
  "payment_method_configuration"
end

.update(configuration, params = {}, opts = {}) ⇒ Object

Update payment method configuration



3475
3476
3477
3478
3479
3480
3481
3482
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3475

def self.update(configuration, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_method_configurations/%<configuration>s", { configuration: CGI.escape(configuration) }),
    params: params,
    opts: opts
  )
end