Class: Stripe::PaymentMethodConfiguration

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/payment_method_configuration.rb

Overview

PaymentMethodConfigurations control which payment methods are displayed to your customers when you don’t explicitly specify payment method types. You can have multiple configurations with different sets of payment methods for different scenarios.

There are two types of PaymentMethodConfigurations. Which is used depends on the [charge type](stripe.com/docs/connect/charges):

Direct configurations apply to payments created on your account, including Connect destination charges, Connect separate charges and transfers, and payments not involving Connect.

Child configurations apply to payments created on your connected accounts using direct charges, and charges with the on_behalf_of parameter.

Child configurations have a ‘parent` that sets default values and controls which settings connected accounts may override. You can specify a parent ID at payment time, and Stripe will automatically resolve the connected account’s associated child configuration. Parent configurations are [managed in the dashboard](dashboard.stripe.com/settings/payment_methods/connected_accounts) and are not available in this API.

Related guides:

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, ApplePay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CartesBancaires, Cashapp, CreateParams, CustomerBalance, Eps, Fpx, Giropay, GooglePay, Grabpay, Ideal, Jcb, Klarna, Konbini, Link, ListParams, Mobilepay, Multibanco, NzBankAccount, Oxxo, P24, PayByBank, Paynow, Paypal, Pix, Promptpay, RevolutPay, Satispay, SepaDebit, Sofort, Swish, Twint, UpdateParams, UsBankAccount, WechatPay, Zip

Constant Summary collapse

OBJECT_NAME =
"payment_method_configuration"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

Attribute for field acss_debit



2756
2757
2758
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2756

def acss_debit
  @acss_debit
end

#activeObject (readonly)

Whether the configuration can be used for new payments.



2758
2759
2760
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2758

def active
  @active
end

#affirmObject (readonly)

Attribute for field affirm



2760
2761
2762
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2760

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



2762
2763
2764
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2762

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



2764
2765
2766
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2764

def alipay
  @alipay
end

#almaObject (readonly)

Attribute for field alma



2766
2767
2768
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2766

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



2768
2769
2770
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2768

def amazon_pay
  @amazon_pay
end

#apple_payObject (readonly)

Attribute for field apple_pay



2770
2771
2772
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2770

def apple_pay
  @apple_pay
end

#applicationObject (readonly)

For child configs, the Connect application associated with the configuration.



2772
2773
2774
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2772

def application
  @application
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



2774
2775
2776
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2774

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



2776
2777
2778
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2776

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



2778
2779
2780
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2778

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



2780
2781
2782
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2780

def billie
  @billie
end

#blikObject (readonly)

Attribute for field blik



2782
2783
2784
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2782

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



2784
2785
2786
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2784

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



2786
2787
2788
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2786

def card
  @card
end

#cartes_bancairesObject (readonly)

Attribute for field cartes_bancaires



2788
2789
2790
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2788

def cartes_bancaires
  @cartes_bancaires
end

#cashappObject (readonly)

Attribute for field cashapp



2790
2791
2792
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2790

def cashapp
  @cashapp
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



2792
2793
2794
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2792

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



2794
2795
2796
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2794

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



2796
2797
2798
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2796

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



2798
2799
2800
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2798

def giropay
  @giropay
end

#google_payObject (readonly)

Attribute for field google_pay



2800
2801
2802
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2800

def google_pay
  @google_pay
end

#grabpayObject (readonly)

Attribute for field grabpay



2802
2803
2804
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2802

def grabpay
  @grabpay
end

#idObject (readonly)

Unique identifier for the object.



2804
2805
2806
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2804

def id
  @id
end

#idealObject (readonly)

Attribute for field ideal



2806
2807
2808
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2806

def ideal
  @ideal
end

#is_defaultObject (readonly)

The default configuration is used whenever a payment method configuration is not specified.



2808
2809
2810
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2808

def is_default
  @is_default
end

#jcbObject (readonly)

Attribute for field jcb



2810
2811
2812
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2810

def jcb
  @jcb
end

#klarnaObject (readonly)

Attribute for field klarna



2812
2813
2814
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2812

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



2814
2815
2816
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2814

def konbini
  @konbini
end

Attribute for field link



2816
2817
2818
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2816

def link
  @link
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



2818
2819
2820
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2818

def livemode
  @livemode
end

#mobilepayObject (readonly)

Attribute for field mobilepay



2820
2821
2822
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2820

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



2822
2823
2824
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2822

def multibanco
  @multibanco
end

#nameObject (readonly)

The configuration’s name.



2824
2825
2826
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2824

def name
  @name
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



2826
2827
2828
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2826

def 
  @nz_bank_account
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



2828
2829
2830
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2828

def object
  @object
end

#oxxoObject (readonly)

Attribute for field oxxo



2830
2831
2832
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2830

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



2832
2833
2834
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2832

def p24
  @p24
end

#parentObject (readonly)

For child configs, the configuration’s parent configuration.



2834
2835
2836
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2834

def parent
  @parent
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



2836
2837
2838
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2836

def pay_by_bank
  @pay_by_bank
end

#paynowObject (readonly)

Attribute for field paynow



2838
2839
2840
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2838

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



2840
2841
2842
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2840

def paypal
  @paypal
end

#pixObject (readonly)

Attribute for field pix



2842
2843
2844
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2842

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



2844
2845
2846
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2844

def promptpay
  @promptpay
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



2846
2847
2848
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2846

def revolut_pay
  @revolut_pay
end

#satispayObject (readonly)

Attribute for field satispay



2848
2849
2850
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2848

def satispay
  @satispay
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



2850
2851
2852
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2850

def sepa_debit
  @sepa_debit
end

#sofortObject (readonly)

Attribute for field sofort



2852
2853
2854
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2852

def sofort
  @sofort
end

#swishObject (readonly)

Attribute for field swish



2854
2855
2856
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2854

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



2856
2857
2858
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2856

def twint
  @twint
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



2858
2859
2860
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2858

def 
  @us_bank_account
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



2860
2861
2862
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2860

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



2862
2863
2864
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2862

def zip
  @zip
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a payment method configuration



2865
2866
2867
2868
2869
2870
2871
2872
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2865

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/payment_method_configurations",
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

List payment method configurations



2875
2876
2877
2878
2879
2880
2881
2882
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2875

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/payment_method_configurations",
    params: params,
    opts: opts
  )
end

.object_nameObject



25
26
27
# File 'lib/stripe/resources/payment_method_configuration.rb', line 25

def self.object_name
  "payment_method_configuration"
end

.update(configuration, params = {}, opts = {}) ⇒ Object

Update payment method configuration



2885
2886
2887
2888
2889
2890
2891
2892
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2885

def self.update(configuration, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_method_configurations/%<configuration>s", { configuration: CGI.escape(configuration) }),
    params: params,
    opts: opts
  )
end