Class: Stripe::PaymentMethodConfiguration
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::PaymentMethodConfiguration
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Overview
PaymentMethodConfigurations control which payment methods are displayed to your customers when you don’t explicitly specify payment method types. You can have multiple configurations with different sets of payment methods for different scenarios.
There are two types of PaymentMethodConfigurations. Which is used depends on the [charge type](stripe.com/docs/connect/charges):
Direct configurations apply to payments created on your account, including Connect destination charges, Connect separate charges and transfers, and payments not involving Connect.
Child configurations apply to payments created on your connected accounts using direct charges, and charges with the on_behalf_of parameter.
Child configurations have a ‘parent` that sets default values and controls which settings connected accounts may override. You can specify a parent ID at payment time, and Stripe will automatically resolve the connected account’s associated child configuration. Parent configurations are [managed in the dashboard](dashboard.stripe.com/settings/payment_methods/connected_accounts) and are not available in this API.
Related guides:
-
[Payment Method Configurations API](stripe.com/docs/connect/payment-method-configurations)
-
[Multiple configurations on dynamic payment methods](stripe.com/docs/payments/multiple-payment-method-configs)
-
[Multiple configurations for your Connect accounts](stripe.com/docs/connect/multiple-payment-method-configurations)
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, ApplePay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CartesBancaires, Cashapp, CreateParams, CustomerBalance, Eps, Fpx, Giropay, GooglePay, Gopay, Grabpay, IdBankTransfer, Ideal, Jcb, Klarna, Konbini, Link, ListParams, Mobilepay, Multibanco, NzBankAccount, Oxxo, P24, PayByBank, Paynow, Paypal, Payto, Pix, Promptpay, Qris, RevolutPay, Satispay, SepaDebit, Shopeepay, Sofort, Swish, Twint, UpdateParams, UsBankAccount, WechatPay, Zip
Constant Summary collapse
- OBJECT_NAME =
"payment_method_configuration"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#active ⇒ Object
readonly
Whether the configuration can be used for new payments.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#apple_pay ⇒ Object
readonly
Attribute for field apple_pay.
-
#application ⇒ Object
readonly
For child configs, the Connect application associated with the configuration.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billie ⇒ Object
readonly
Attribute for field billie.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#cartes_bancaires ⇒ Object
readonly
Attribute for field cartes_bancaires.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#google_pay ⇒ Object
readonly
Attribute for field google_pay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#is_default ⇒ Object
readonly
The default configuration is used whenever a payment method configuration is not specified.
-
#jcb ⇒ Object
readonly
Attribute for field jcb.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#name ⇒ Object
readonly
The configuration’s name.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#parent ⇒ Object
readonly
For child configs, the configuration’s parent configuration.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a payment method configuration.
-
.list(params = {}, opts = {}) ⇒ Object
List payment method configurations.
- .object_name ⇒ Object
-
.update(configuration, params = {}, opts = {}) ⇒ Object
Update payment method configuration.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
3041 3042 3043 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3041 def acss_debit @acss_debit end |
#active ⇒ Object (readonly)
Whether the configuration can be used for new payments.
3043 3044 3045 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3043 def active @active end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
3045 3046 3047 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3045 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
3047 3048 3049 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3047 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
3049 3050 3051 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3049 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
3051 3052 3053 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3051 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
3053 3054 3055 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3053 def amazon_pay @amazon_pay end |
#apple_pay ⇒ Object (readonly)
Attribute for field apple_pay
3055 3056 3057 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3055 def apple_pay @apple_pay end |
#application ⇒ Object (readonly)
For child configs, the Connect application associated with the configuration.
3057 3058 3059 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3057 def application @application end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
3059 3060 3061 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3059 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
3061 3062 3063 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3061 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
3063 3064 3065 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3063 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
Attribute for field billie
3065 3066 3067 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3065 def billie @billie end |
#blik ⇒ Object (readonly)
Attribute for field blik
3067 3068 3069 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3067 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
3069 3070 3071 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3069 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
3071 3072 3073 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3071 def card @card end |
#cartes_bancaires ⇒ Object (readonly)
Attribute for field cartes_bancaires
3073 3074 3075 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3073 def cartes_bancaires @cartes_bancaires end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
3075 3076 3077 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3075 def cashapp @cashapp end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
3077 3078 3079 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3077 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
3079 3080 3081 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3079 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
3081 3082 3083 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3081 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
3083 3084 3085 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3083 def giropay @giropay end |
#google_pay ⇒ Object (readonly)
Attribute for field google_pay
3085 3086 3087 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3085 def google_pay @google_pay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
3087 3088 3089 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3087 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
3089 3090 3091 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3089 def grabpay @grabpay end |
#id ⇒ Object (readonly)
Unique identifier for the object.
3091 3092 3093 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3091 def id @id end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
3093 3094 3095 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3093 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
3095 3096 3097 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3095 def ideal @ideal end |
#is_default ⇒ Object (readonly)
The default configuration is used whenever a payment method configuration is not specified.
3097 3098 3099 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3097 def is_default @is_default end |
#jcb ⇒ Object (readonly)
Attribute for field jcb
3099 3100 3101 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3099 def jcb @jcb end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
3101 3102 3103 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3101 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
3103 3104 3105 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3103 def konbini @konbini end |
#link ⇒ Object (readonly)
Attribute for field link
3105 3106 3107 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3105 def link @link end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
3107 3108 3109 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3107 def livemode @livemode end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
3109 3110 3111 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3109 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
3111 3112 3113 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3111 def multibanco @multibanco end |
#name ⇒ Object (readonly)
The configuration’s name.
3113 3114 3115 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3113 def name @name end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
3115 3116 3117 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3115 def nz_bank_account @nz_bank_account end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
3117 3118 3119 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3117 def object @object end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
3119 3120 3121 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3119 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
3121 3122 3123 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3121 def p24 @p24 end |
#parent ⇒ Object (readonly)
For child configs, the configuration’s parent configuration.
3123 3124 3125 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3123 def parent @parent end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
3125 3126 3127 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3125 def pay_by_bank @pay_by_bank end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
3127 3128 3129 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3127 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
3129 3130 3131 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3129 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
3131 3132 3133 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3131 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
3133 3134 3135 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3133 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
3135 3136 3137 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3135 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
3137 3138 3139 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3137 def qris @qris end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
3139 3140 3141 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3139 def revolut_pay @revolut_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
3141 3142 3143 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3141 def satispay @satispay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
3143 3144 3145 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3143 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
3145 3146 3147 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3145 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
3147 3148 3149 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3147 def sofort @sofort end |
#swish ⇒ Object (readonly)
Attribute for field swish
3149 3150 3151 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3149 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
3151 3152 3153 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3151 def twint @twint end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
3153 3154 3155 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3153 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
3155 3156 3157 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3155 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
3157 3158 3159 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3157 def zip @zip end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a payment method configuration
3160 3161 3162 3163 3164 3165 3166 3167 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3160 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/payment_method_configurations", params: params, opts: opts ) end |
.list(params = {}, opts = {}) ⇒ Object
List payment method configurations
3170 3171 3172 3173 3174 3175 3176 3177 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3170 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/payment_method_configurations", params: params, opts: opts ) end |
.object_name ⇒ Object
25 26 27 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 25 def self.object_name "payment_method_configuration" end |
.update(configuration, params = {}, opts = {}) ⇒ Object
Update payment method configuration
3180 3181 3182 3183 3184 3185 3186 3187 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3180 def self.update(configuration, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_method_configurations/%<configuration>s", { configuration: CGI.escape(configuration) }), params: params, opts: opts ) end |