Class: Stripe::PaymentMethodConfiguration

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/payment_method_configuration.rb

Overview

PaymentMethodConfigurations control which payment methods are displayed to your customers when you don’t explicitly specify payment method types. You can have multiple configurations with different sets of payment methods for different scenarios.

There are two types of PaymentMethodConfigurations. Which is used depends on the [charge type](stripe.com/docs/connect/charges):

Direct configurations apply to payments created on your account, including Connect destination charges, Connect separate charges and transfers, and payments not involving Connect.

Child configurations apply to payments created on your connected accounts using direct charges, and charges with the on_behalf_of parameter.

Child configurations have a ‘parent` that sets default values and controls which settings connected accounts may override. You can specify a parent ID at payment time, and Stripe will automatically resolve the connected account’s associated child configuration. Parent configurations are [managed in the dashboard](dashboard.stripe.com/settings/payment_methods/connected_accounts) and are not available in this API.

Related guides:

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, ApplePay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CartesBancaires, Cashapp, CreateParams, CustomerBalance, Eps, Fpx, Giropay, GooglePay, Gopay, Grabpay, IdBankTransfer, Ideal, Jcb, Klarna, Konbini, Link, ListParams, Mobilepay, Multibanco, NzBankAccount, Oxxo, P24, PayByBank, Paynow, Paypal, Payto, Promptpay, Qris, RevolutPay, Satispay, SepaDebit, Shopeepay, Sofort, Swish, Twint, UpdateParams, UsBankAccount, WechatPay, Zip

Constant Summary collapse

OBJECT_NAME =
"payment_method_configuration"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

Attribute for field acss_debit



2984
2985
2986
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2984

def acss_debit
  @acss_debit
end

#activeObject (readonly)

Whether the configuration can be used for new payments.



2986
2987
2988
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2986

def active
  @active
end

#affirmObject (readonly)

Attribute for field affirm



2988
2989
2990
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2988

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



2990
2991
2992
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2990

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



2992
2993
2994
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2992

def alipay
  @alipay
end

#almaObject (readonly)

Attribute for field alma



2994
2995
2996
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2994

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



2996
2997
2998
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2996

def amazon_pay
  @amazon_pay
end

#apple_payObject (readonly)

Attribute for field apple_pay



2998
2999
3000
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2998

def apple_pay
  @apple_pay
end

#applicationObject (readonly)

For child configs, the Connect application associated with the configuration.



3000
3001
3002
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3000

def application
  @application
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



3002
3003
3004
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3002

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



3004
3005
3006
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3004

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



3006
3007
3008
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3006

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



3008
3009
3010
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3008

def billie
  @billie
end

#blikObject (readonly)

Attribute for field blik



3010
3011
3012
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3010

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



3012
3013
3014
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3012

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



3014
3015
3016
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3014

def card
  @card
end

#cartes_bancairesObject (readonly)

Attribute for field cartes_bancaires



3016
3017
3018
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3016

def cartes_bancaires
  @cartes_bancaires
end

#cashappObject (readonly)

Attribute for field cashapp



3018
3019
3020
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3018

def cashapp
  @cashapp
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



3020
3021
3022
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3020

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



3022
3023
3024
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3022

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



3024
3025
3026
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3024

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



3026
3027
3028
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3026

def giropay
  @giropay
end

#google_payObject (readonly)

Attribute for field google_pay



3028
3029
3030
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3028

def google_pay
  @google_pay
end

#gopayObject (readonly)

Attribute for field gopay



3030
3031
3032
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3030

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



3032
3033
3034
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3032

def grabpay
  @grabpay
end

#idObject (readonly)

Unique identifier for the object.



3034
3035
3036
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3034

def id
  @id
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



3036
3037
3038
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3036

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



3038
3039
3040
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3038

def ideal
  @ideal
end

#is_defaultObject (readonly)

The default configuration is used whenever a payment method configuration is not specified.



3040
3041
3042
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3040

def is_default
  @is_default
end

#jcbObject (readonly)

Attribute for field jcb



3042
3043
3044
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3042

def jcb
  @jcb
end

#klarnaObject (readonly)

Attribute for field klarna



3044
3045
3046
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3044

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



3046
3047
3048
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3046

def konbini
  @konbini
end

Attribute for field link



3048
3049
3050
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3048

def link
  @link
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



3050
3051
3052
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3050

def livemode
  @livemode
end

#mobilepayObject (readonly)

Attribute for field mobilepay



3052
3053
3054
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3052

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



3054
3055
3056
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3054

def multibanco
  @multibanco
end

#nameObject (readonly)

The configuration’s name.



3056
3057
3058
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3056

def name
  @name
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



3058
3059
3060
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3058

def 
  @nz_bank_account
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



3060
3061
3062
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3060

def object
  @object
end

#oxxoObject (readonly)

Attribute for field oxxo



3062
3063
3064
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3062

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



3064
3065
3066
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3064

def p24
  @p24
end

#parentObject (readonly)

For child configs, the configuration’s parent configuration.



3066
3067
3068
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3066

def parent
  @parent
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



3068
3069
3070
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3068

def pay_by_bank
  @pay_by_bank
end

#paynowObject (readonly)

Attribute for field paynow



3070
3071
3072
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3070

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



3072
3073
3074
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3072

def paypal
  @paypal
end

#paytoObject (readonly)

Attribute for field payto



3074
3075
3076
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3074

def payto
  @payto
end

#promptpayObject (readonly)

Attribute for field promptpay



3076
3077
3078
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3076

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



3078
3079
3080
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3078

def qris
  @qris
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



3080
3081
3082
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3080

def revolut_pay
  @revolut_pay
end

#satispayObject (readonly)

Attribute for field satispay



3082
3083
3084
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3082

def satispay
  @satispay
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



3084
3085
3086
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3084

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



3086
3087
3088
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3086

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



3088
3089
3090
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3088

def sofort
  @sofort
end

#swishObject (readonly)

Attribute for field swish



3090
3091
3092
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3090

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



3092
3093
3094
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3092

def twint
  @twint
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



3094
3095
3096
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3094

def 
  @us_bank_account
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



3096
3097
3098
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3096

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



3098
3099
3100
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3098

def zip
  @zip
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a payment method configuration



3101
3102
3103
3104
3105
3106
3107
3108
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3101

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/payment_method_configurations",
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

List payment method configurations



3111
3112
3113
3114
3115
3116
3117
3118
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3111

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/payment_method_configurations",
    params: params,
    opts: opts
  )
end

.object_nameObject



25
26
27
# File 'lib/stripe/resources/payment_method_configuration.rb', line 25

def self.object_name
  "payment_method_configuration"
end

.update(configuration, params = {}, opts = {}) ⇒ Object

Update payment method configuration



3121
3122
3123
3124
3125
3126
3127
3128
# File 'lib/stripe/resources/payment_method_configuration.rb', line 3121

def self.update(configuration, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_method_configurations/%<configuration>s", { configuration: CGI.escape(configuration) }),
    params: params,
    opts: opts
  )
end