Class: Stripe::PaymentMethodConfiguration

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/payment_method_configuration.rb

Overview

PaymentMethodConfigurations control which payment methods are displayed to your customers when you don’t explicitly specify payment method types. You can have multiple configurations with different sets of payment methods for different scenarios.

There are two types of PaymentMethodConfigurations. Which is used depends on the [charge type](stripe.com/docs/connect/charges):

Direct configurations apply to payments created on your account, including Connect destination charges, Connect separate charges and transfers, and payments not involving Connect.

Child configurations apply to payments created on your connected accounts using direct charges, and charges with the on_behalf_of parameter.

Child configurations have a ‘parent` that sets default values and controls which settings connected accounts may override. You can specify a parent ID at payment time, and Stripe will automatically resolve the connected account’s associated child configuration. Parent configurations are [managed in the dashboard](dashboard.stripe.com/settings/payment_methods/connected_accounts) and are not available in this API.

Related guides:

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, ApplePay, AuBecsDebit, BacsDebit, Bancontact, Blik, Boleto, Card, CartesBancaires, Cashapp, CreateParams, CustomerBalance, Eps, Fpx, Giropay, GooglePay, Gopay, Grabpay, IdBankTransfer, Ideal, Jcb, Klarna, Konbini, Link, ListParams, Mobilepay, Multibanco, Oxxo, P24, PayByBank, Paynow, Paypal, Payto, Promptpay, Qris, RetrieveParams, RevolutPay, SepaDebit, Shopeepay, Sofort, Swish, Twint, UpdateParams, UsBankAccount, WechatPay, Zip

Constant Summary collapse

OBJECT_NAME =
"payment_method_configuration"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

Attribute for field acss_debit



2822
2823
2824
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2822

def acss_debit
  @acss_debit
end

#activeObject (readonly)

Whether the configuration can be used for new payments.



2824
2825
2826
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2824

def active
  @active
end

#affirmObject (readonly)

Attribute for field affirm



2826
2827
2828
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2826

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



2828
2829
2830
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2828

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



2830
2831
2832
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2830

def alipay
  @alipay
end

#almaObject (readonly)

Attribute for field alma



2832
2833
2834
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2832

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



2834
2835
2836
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2834

def amazon_pay
  @amazon_pay
end

#apple_payObject (readonly)

Attribute for field apple_pay



2836
2837
2838
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2836

def apple_pay
  @apple_pay
end

#applicationObject (readonly)

For child configs, the Connect application associated with the configuration.



2838
2839
2840
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2838

def application
  @application
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



2840
2841
2842
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2840

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



2842
2843
2844
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2842

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



2844
2845
2846
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2844

def bancontact
  @bancontact
end

#blikObject (readonly)

Attribute for field blik



2846
2847
2848
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2846

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



2848
2849
2850
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2848

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



2850
2851
2852
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2850

def card
  @card
end

#cartes_bancairesObject (readonly)

Attribute for field cartes_bancaires



2852
2853
2854
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2852

def cartes_bancaires
  @cartes_bancaires
end

#cashappObject (readonly)

Attribute for field cashapp



2854
2855
2856
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2854

def cashapp
  @cashapp
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



2856
2857
2858
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2856

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



2858
2859
2860
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2858

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



2860
2861
2862
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2860

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



2862
2863
2864
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2862

def giropay
  @giropay
end

#google_payObject (readonly)

Attribute for field google_pay



2864
2865
2866
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2864

def google_pay
  @google_pay
end

#gopayObject (readonly)

Attribute for field gopay



2866
2867
2868
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2866

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



2868
2869
2870
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2868

def grabpay
  @grabpay
end

#idObject (readonly)

Unique identifier for the object.



2870
2871
2872
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2870

def id
  @id
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



2872
2873
2874
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2872

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



2874
2875
2876
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2874

def ideal
  @ideal
end

#is_defaultObject (readonly)

The default configuration is used whenever a payment method configuration is not specified.



2876
2877
2878
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2876

def is_default
  @is_default
end

#jcbObject (readonly)

Attribute for field jcb



2878
2879
2880
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2878

def jcb
  @jcb
end

#klarnaObject (readonly)

Attribute for field klarna



2880
2881
2882
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2880

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



2882
2883
2884
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2882

def konbini
  @konbini
end

Attribute for field link



2884
2885
2886
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2884

def link
  @link
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



2886
2887
2888
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2886

def livemode
  @livemode
end

#mobilepayObject (readonly)

Attribute for field mobilepay



2888
2889
2890
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2888

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



2890
2891
2892
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2890

def multibanco
  @multibanco
end

#nameObject (readonly)

The configuration’s name.



2892
2893
2894
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2892

def name
  @name
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



2894
2895
2896
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2894

def object
  @object
end

#oxxoObject (readonly)

Attribute for field oxxo



2896
2897
2898
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2896

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



2898
2899
2900
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2898

def p24
  @p24
end

#parentObject (readonly)

For child configs, the configuration’s parent configuration.



2900
2901
2902
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2900

def parent
  @parent
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



2902
2903
2904
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2902

def pay_by_bank
  @pay_by_bank
end

#paynowObject (readonly)

Attribute for field paynow



2904
2905
2906
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2904

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



2906
2907
2908
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2906

def paypal
  @paypal
end

#paytoObject (readonly)

Attribute for field payto



2908
2909
2910
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2908

def payto
  @payto
end

#promptpayObject (readonly)

Attribute for field promptpay



2910
2911
2912
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2910

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



2912
2913
2914
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2912

def qris
  @qris
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



2914
2915
2916
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2914

def revolut_pay
  @revolut_pay
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



2916
2917
2918
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2916

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



2918
2919
2920
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2918

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



2920
2921
2922
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2920

def sofort
  @sofort
end

#swishObject (readonly)

Attribute for field swish



2922
2923
2924
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2922

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



2924
2925
2926
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2924

def twint
  @twint
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



2926
2927
2928
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2926

def 
  @us_bank_account
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



2928
2929
2930
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2928

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



2930
2931
2932
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2930

def zip
  @zip
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a payment method configuration



2933
2934
2935
2936
2937
2938
2939
2940
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2933

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/payment_method_configurations",
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

List payment method configurations



2943
2944
2945
2946
2947
2948
2949
2950
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2943

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/payment_method_configurations",
    params: params,
    opts: opts
  )
end

.object_nameObject



25
26
27
# File 'lib/stripe/resources/payment_method_configuration.rb', line 25

def self.object_name
  "payment_method_configuration"
end

.update(configuration, params = {}, opts = {}) ⇒ Object

Update payment method configuration



2953
2954
2955
2956
2957
2958
2959
2960
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2953

def self.update(configuration, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_method_configurations/%<configuration>s", { configuration: CGI.escape(configuration) }),
    params: params,
    opts: opts
  )
end