Class: Stripe::PaymentMethodConfiguration
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::PaymentMethodConfiguration
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Overview
PaymentMethodConfigurations control which payment methods are displayed to your customers when you don’t explicitly specify payment method types. You can have multiple configurations with different sets of payment methods for different scenarios.
There are two types of PaymentMethodConfigurations. Which is used depends on the [charge type](stripe.com/docs/connect/charges):
Direct configurations apply to payments created on your account, including Connect destination charges, Connect separate charges and transfers, and payments not involving Connect.
Child configurations apply to payments created on your connected accounts using direct charges, and charges with the on_behalf_of parameter.
Child configurations have a ‘parent` that sets default values and controls which settings connected accounts may override. You can specify a parent ID at payment time, and Stripe will automatically resolve the connected account’s associated child configuration. Parent configurations are [managed in the dashboard](dashboard.stripe.com/settings/payment_methods/connected_accounts) and are not available in this API.
Related guides:
-
[Payment Method Configurations API](stripe.com/docs/connect/payment-method-configurations)
-
[Multiple configurations on dynamic payment methods](stripe.com/docs/payments/multiple-payment-method-configs)
-
[Multiple configurations for your Connect accounts](stripe.com/docs/connect/multiple-payment-method-configurations)
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, ApplePay, AuBecsDebit, BacsDebit, Bancontact, Blik, Boleto, Card, CartesBancaires, Cashapp, CreateParams, CustomerBalance, Eps, Fpx, Giropay, GooglePay, Gopay, Grabpay, IdBankTransfer, Ideal, Jcb, Klarna, Konbini, Link, ListParams, Mobilepay, Multibanco, Oxxo, P24, Paynow, Paypal, Payto, Promptpay, Qris, RetrieveParams, RevolutPay, SepaDebit, Shopeepay, Sofort, Swish, Twint, UpdateParams, UsBankAccount, WechatPay, Zip
Constant Summary collapse
- OBJECT_NAME =
"payment_method_configuration"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#active ⇒ Object
readonly
Whether the configuration can be used for new payments.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#apple_pay ⇒ Object
readonly
Attribute for field apple_pay.
-
#application ⇒ Object
readonly
For child configs, the Connect application associated with the configuration.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#cartes_bancaires ⇒ Object
readonly
Attribute for field cartes_bancaires.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#google_pay ⇒ Object
readonly
Attribute for field google_pay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#is_default ⇒ Object
readonly
The default configuration is used whenever a payment method configuration is not specified.
-
#jcb ⇒ Object
readonly
Attribute for field jcb.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#name ⇒ Object
readonly
The configuration’s name.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#parent ⇒ Object
readonly
For child configs, the configuration’s parent configuration.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a payment method configuration.
-
.list(params = {}, opts = {}) ⇒ Object
List payment method configurations.
- .object_name ⇒ Object
-
.update(id, params = {}, opts = {}) ⇒ Object
Update payment method configuration.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
2765 2766 2767 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2765 def acss_debit @acss_debit end |
#active ⇒ Object (readonly)
Whether the configuration can be used for new payments.
2767 2768 2769 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2767 def active @active end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
2769 2770 2771 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2769 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
2771 2772 2773 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2771 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
2773 2774 2775 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2773 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
2775 2776 2777 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2775 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
2777 2778 2779 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2777 def amazon_pay @amazon_pay end |
#apple_pay ⇒ Object (readonly)
Attribute for field apple_pay
2779 2780 2781 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2779 def apple_pay @apple_pay end |
#application ⇒ Object (readonly)
For child configs, the Connect application associated with the configuration.
2781 2782 2783 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2781 def application @application end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
2783 2784 2785 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2783 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
2785 2786 2787 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2785 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
2787 2788 2789 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2787 def bancontact @bancontact end |
#blik ⇒ Object (readonly)
Attribute for field blik
2789 2790 2791 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2789 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
2791 2792 2793 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2791 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
2793 2794 2795 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2793 def card @card end |
#cartes_bancaires ⇒ Object (readonly)
Attribute for field cartes_bancaires
2795 2796 2797 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2795 def cartes_bancaires @cartes_bancaires end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
2797 2798 2799 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2797 def cashapp @cashapp end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
2799 2800 2801 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2799 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
2801 2802 2803 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2801 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
2803 2804 2805 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2803 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
2805 2806 2807 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2805 def giropay @giropay end |
#google_pay ⇒ Object (readonly)
Attribute for field google_pay
2807 2808 2809 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2807 def google_pay @google_pay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
2809 2810 2811 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2809 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
2811 2812 2813 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2811 def grabpay @grabpay end |
#id ⇒ Object (readonly)
Unique identifier for the object.
2813 2814 2815 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2813 def id @id end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
2815 2816 2817 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2815 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
2817 2818 2819 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2817 def ideal @ideal end |
#is_default ⇒ Object (readonly)
The default configuration is used whenever a payment method configuration is not specified.
2819 2820 2821 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2819 def is_default @is_default end |
#jcb ⇒ Object (readonly)
Attribute for field jcb
2821 2822 2823 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2821 def jcb @jcb end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
2823 2824 2825 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2823 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
2825 2826 2827 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2825 def konbini @konbini end |
#link ⇒ Object (readonly)
Attribute for field link
2827 2828 2829 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2827 def link @link end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
2829 2830 2831 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2829 def livemode @livemode end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
2831 2832 2833 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2831 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
2833 2834 2835 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2833 def multibanco @multibanco end |
#name ⇒ Object (readonly)
The configuration’s name.
2835 2836 2837 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2835 def name @name end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
2837 2838 2839 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2837 def object @object end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
2839 2840 2841 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2839 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
2841 2842 2843 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2841 def p24 @p24 end |
#parent ⇒ Object (readonly)
For child configs, the configuration’s parent configuration.
2843 2844 2845 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2843 def parent @parent end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
2845 2846 2847 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2845 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
2847 2848 2849 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2847 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
2849 2850 2851 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2849 def payto @payto end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
2851 2852 2853 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2851 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
2853 2854 2855 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2853 def qris @qris end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
2855 2856 2857 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2855 def revolut_pay @revolut_pay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
2857 2858 2859 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2857 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
2859 2860 2861 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2859 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
2861 2862 2863 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2861 def sofort @sofort end |
#swish ⇒ Object (readonly)
Attribute for field swish
2863 2864 2865 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2863 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
2865 2866 2867 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2865 def twint @twint end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
2867 2868 2869 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2867 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
2869 2870 2871 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2869 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
2871 2872 2873 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2871 def zip @zip end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a payment method configuration
2874 2875 2876 2877 2878 2879 2880 2881 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2874 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/payment_method_configurations", params: params, opts: opts ) end |
.list(params = {}, opts = {}) ⇒ Object
List payment method configurations
2884 2885 2886 2887 2888 2889 2890 2891 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2884 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/payment_method_configurations", params: params, opts: opts ) end |
.object_name ⇒ Object
25 26 27 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 25 def self.object_name "payment_method_configuration" end |
.update(id, params = {}, opts = {}) ⇒ Object
Update payment method configuration
2894 2895 2896 2897 2898 2899 2900 2901 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2894 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_method_configurations/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |