Class: Stripe::PaymentMethodConfiguration
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::PaymentMethodConfiguration
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Overview
PaymentMethodConfigurations control which payment methods are displayed to your customers when you don’t explicitly specify payment method types. You can have multiple configurations with different sets of payment methods for different scenarios.
There are two types of PaymentMethodConfigurations. Which is used depends on the [charge type](stripe.com/docs/connect/charges):
Direct configurations apply to payments created on your account, including Connect destination charges, Connect separate charges and transfers, and payments not involving Connect.
Child configurations apply to payments created on your connected accounts using direct charges, and charges with the on_behalf_of parameter.
Child configurations have a ‘parent` that sets default values and controls which settings connected accounts may override. You can specify a parent ID at payment time, and Stripe will automatically resolve the connected account’s associated child configuration. Parent configurations are [managed in the dashboard](dashboard.stripe.com/settings/payment_methods/connected_accounts) and are not available in this API.
Related guides:
-
[Payment Method Configurations API](stripe.com/docs/connect/payment-method-configurations)
-
[Multiple configurations on dynamic payment methods](stripe.com/docs/payments/multiple-payment-method-configs)
-
[Multiple configurations for your Connect accounts](stripe.com/docs/connect/multiple-payment-method-configurations)
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, ApplePay, AuBecsDebit, BacsDebit, Bancontact, Blik, Boleto, Card, CartesBancaires, Cashapp, CreateParams, CustomerBalance, Eps, Fpx, Giropay, GooglePay, Gopay, Grabpay, IdBankTransfer, Ideal, Jcb, Klarna, Konbini, Link, ListParams, Mobilepay, Multibanco, Oxxo, P24, PayByBank, Paynow, Paypal, Payto, Promptpay, Qris, RetrieveParams, RevolutPay, SepaDebit, Shopeepay, Sofort, Swish, Twint, UpdateParams, UsBankAccount, WechatPay, Zip
Constant Summary collapse
- OBJECT_NAME =
"payment_method_configuration"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#active ⇒ Object
readonly
Whether the configuration can be used for new payments.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#apple_pay ⇒ Object
readonly
Attribute for field apple_pay.
-
#application ⇒ Object
readonly
For child configs, the Connect application associated with the configuration.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#cartes_bancaires ⇒ Object
readonly
Attribute for field cartes_bancaires.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#google_pay ⇒ Object
readonly
Attribute for field google_pay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#is_default ⇒ Object
readonly
The default configuration is used whenever a payment method configuration is not specified.
-
#jcb ⇒ Object
readonly
Attribute for field jcb.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#name ⇒ Object
readonly
The configuration’s name.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#parent ⇒ Object
readonly
For child configs, the configuration’s parent configuration.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a payment method configuration.
-
.list(params = {}, opts = {}) ⇒ Object
List payment method configurations.
- .object_name ⇒ Object
-
.update(id, params = {}, opts = {}) ⇒ Object
Update payment method configuration.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
2822 2823 2824 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2822 def acss_debit @acss_debit end |
#active ⇒ Object (readonly)
Whether the configuration can be used for new payments.
2824 2825 2826 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2824 def active @active end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
2826 2827 2828 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2826 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
2828 2829 2830 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2828 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
2830 2831 2832 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2830 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
2832 2833 2834 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2832 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
2834 2835 2836 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2834 def amazon_pay @amazon_pay end |
#apple_pay ⇒ Object (readonly)
Attribute for field apple_pay
2836 2837 2838 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2836 def apple_pay @apple_pay end |
#application ⇒ Object (readonly)
For child configs, the Connect application associated with the configuration.
2838 2839 2840 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2838 def application @application end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
2840 2841 2842 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2840 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
2842 2843 2844 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2842 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
2844 2845 2846 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2844 def bancontact @bancontact end |
#blik ⇒ Object (readonly)
Attribute for field blik
2846 2847 2848 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2846 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
2848 2849 2850 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2848 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
2850 2851 2852 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2850 def card @card end |
#cartes_bancaires ⇒ Object (readonly)
Attribute for field cartes_bancaires
2852 2853 2854 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2852 def cartes_bancaires @cartes_bancaires end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
2854 2855 2856 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2854 def cashapp @cashapp end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
2856 2857 2858 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2856 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
2858 2859 2860 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2858 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
2860 2861 2862 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2860 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
2862 2863 2864 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2862 def giropay @giropay end |
#google_pay ⇒ Object (readonly)
Attribute for field google_pay
2864 2865 2866 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2864 def google_pay @google_pay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
2866 2867 2868 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2866 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
2868 2869 2870 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2868 def grabpay @grabpay end |
#id ⇒ Object (readonly)
Unique identifier for the object.
2870 2871 2872 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2870 def id @id end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
2872 2873 2874 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2872 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
2874 2875 2876 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2874 def ideal @ideal end |
#is_default ⇒ Object (readonly)
The default configuration is used whenever a payment method configuration is not specified.
2876 2877 2878 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2876 def is_default @is_default end |
#jcb ⇒ Object (readonly)
Attribute for field jcb
2878 2879 2880 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2878 def jcb @jcb end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
2880 2881 2882 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2880 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
2882 2883 2884 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2882 def konbini @konbini end |
#link ⇒ Object (readonly)
Attribute for field link
2884 2885 2886 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2884 def link @link end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
2886 2887 2888 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2886 def livemode @livemode end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
2888 2889 2890 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2888 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
2890 2891 2892 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2890 def multibanco @multibanco end |
#name ⇒ Object (readonly)
The configuration’s name.
2892 2893 2894 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2892 def name @name end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
2894 2895 2896 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2894 def object @object end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
2896 2897 2898 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2896 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
2898 2899 2900 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2898 def p24 @p24 end |
#parent ⇒ Object (readonly)
For child configs, the configuration’s parent configuration.
2900 2901 2902 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2900 def parent @parent end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
2902 2903 2904 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2902 def pay_by_bank @pay_by_bank end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
2904 2905 2906 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2904 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
2906 2907 2908 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2906 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
2908 2909 2910 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2908 def payto @payto end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
2910 2911 2912 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2910 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
2912 2913 2914 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2912 def qris @qris end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
2914 2915 2916 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2914 def revolut_pay @revolut_pay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
2916 2917 2918 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2916 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
2918 2919 2920 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2918 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
2920 2921 2922 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2920 def sofort @sofort end |
#swish ⇒ Object (readonly)
Attribute for field swish
2922 2923 2924 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2922 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
2924 2925 2926 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2924 def twint @twint end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
2926 2927 2928 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2926 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
2928 2929 2930 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2928 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
2930 2931 2932 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2930 def zip @zip end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a payment method configuration
2933 2934 2935 2936 2937 2938 2939 2940 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2933 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/payment_method_configurations", params: params, opts: opts ) end |
.list(params = {}, opts = {}) ⇒ Object
List payment method configurations
2943 2944 2945 2946 2947 2948 2949 2950 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2943 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/payment_method_configurations", params: params, opts: opts ) end |
.object_name ⇒ Object
25 26 27 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 25 def self.object_name "payment_method_configuration" end |
.update(id, params = {}, opts = {}) ⇒ Object
Update payment method configuration
2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2953 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_method_configurations/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |