Class: Stripe::PaymentMethodConfiguration

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/payment_method_configuration.rb

Overview

PaymentMethodConfigurations control which payment methods are displayed to your customers when you don’t explicitly specify payment method types. You can have multiple configurations with different sets of payment methods for different scenarios.

There are two types of PaymentMethodConfigurations. Which is used depends on the [charge type](stripe.com/docs/connect/charges):

Direct configurations apply to payments created on your account, including Connect destination charges, Connect separate charges and transfers, and payments not involving Connect.

Child configurations apply to payments created on your connected accounts using direct charges, and charges with the on_behalf_of parameter.

Child configurations have a ‘parent` that sets default values and controls which settings connected accounts may override. You can specify a parent ID at payment time, and Stripe will automatically resolve the connected account’s associated child configuration. Parent configurations are [managed in the dashboard](dashboard.stripe.com/settings/payment_methods/connected_accounts) and are not available in this API.

Related guides:

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, ApplePay, AuBecsDebit, BacsDebit, Bancontact, Blik, Boleto, Card, CartesBancaires, Cashapp, CustomerBalance, Eps, Fpx, Giropay, GooglePay, Gopay, Grabpay, IdBankTransfer, Ideal, Jcb, Klarna, Konbini, Link, Mobilepay, Multibanco, Oxxo, P24, Paynow, Paypal, Payto, Promptpay, Qris, RevolutPay, SepaDebit, Shopeepay, Sofort, Swish, Twint, UsBankAccount, WechatPay, Zip

Constant Summary collapse

OBJECT_NAME =
"payment_method_configuration"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

Attribute for field acss_debit



351
352
353
# File 'lib/stripe/resources/payment_method_configuration.rb', line 351

def acss_debit
  @acss_debit
end

#activeObject (readonly)

Whether the configuration can be used for new payments.



353
354
355
# File 'lib/stripe/resources/payment_method_configuration.rb', line 353

def active
  @active
end

#affirmObject (readonly)

Attribute for field affirm



355
356
357
# File 'lib/stripe/resources/payment_method_configuration.rb', line 355

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



357
358
359
# File 'lib/stripe/resources/payment_method_configuration.rb', line 357

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



359
360
361
# File 'lib/stripe/resources/payment_method_configuration.rb', line 359

def alipay
  @alipay
end

#almaObject (readonly)

Attribute for field alma



361
362
363
# File 'lib/stripe/resources/payment_method_configuration.rb', line 361

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



363
364
365
# File 'lib/stripe/resources/payment_method_configuration.rb', line 363

def amazon_pay
  @amazon_pay
end

#apple_payObject (readonly)

Attribute for field apple_pay



365
366
367
# File 'lib/stripe/resources/payment_method_configuration.rb', line 365

def apple_pay
  @apple_pay
end

#applicationObject (readonly)

For child configs, the Connect application associated with the configuration.



367
368
369
# File 'lib/stripe/resources/payment_method_configuration.rb', line 367

def application
  @application
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



369
370
371
# File 'lib/stripe/resources/payment_method_configuration.rb', line 369

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



371
372
373
# File 'lib/stripe/resources/payment_method_configuration.rb', line 371

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



373
374
375
# File 'lib/stripe/resources/payment_method_configuration.rb', line 373

def bancontact
  @bancontact
end

#blikObject (readonly)

Attribute for field blik



375
376
377
# File 'lib/stripe/resources/payment_method_configuration.rb', line 375

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



377
378
379
# File 'lib/stripe/resources/payment_method_configuration.rb', line 377

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



379
380
381
# File 'lib/stripe/resources/payment_method_configuration.rb', line 379

def card
  @card
end

#cartes_bancairesObject (readonly)

Attribute for field cartes_bancaires



381
382
383
# File 'lib/stripe/resources/payment_method_configuration.rb', line 381

def cartes_bancaires
  @cartes_bancaires
end

#cashappObject (readonly)

Attribute for field cashapp



383
384
385
# File 'lib/stripe/resources/payment_method_configuration.rb', line 383

def cashapp
  @cashapp
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



385
386
387
# File 'lib/stripe/resources/payment_method_configuration.rb', line 385

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



387
388
389
# File 'lib/stripe/resources/payment_method_configuration.rb', line 387

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



389
390
391
# File 'lib/stripe/resources/payment_method_configuration.rb', line 389

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



391
392
393
# File 'lib/stripe/resources/payment_method_configuration.rb', line 391

def giropay
  @giropay
end

#google_payObject (readonly)

Attribute for field google_pay



393
394
395
# File 'lib/stripe/resources/payment_method_configuration.rb', line 393

def google_pay
  @google_pay
end

#gopayObject (readonly)

Attribute for field gopay



395
396
397
# File 'lib/stripe/resources/payment_method_configuration.rb', line 395

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



397
398
399
# File 'lib/stripe/resources/payment_method_configuration.rb', line 397

def grabpay
  @grabpay
end

#idObject (readonly)

Unique identifier for the object.



399
400
401
# File 'lib/stripe/resources/payment_method_configuration.rb', line 399

def id
  @id
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



401
402
403
# File 'lib/stripe/resources/payment_method_configuration.rb', line 401

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



403
404
405
# File 'lib/stripe/resources/payment_method_configuration.rb', line 403

def ideal
  @ideal
end

#is_defaultObject (readonly)

The default configuration is used whenever a payment method configuration is not specified.



405
406
407
# File 'lib/stripe/resources/payment_method_configuration.rb', line 405

def is_default
  @is_default
end

#jcbObject (readonly)

Attribute for field jcb



407
408
409
# File 'lib/stripe/resources/payment_method_configuration.rb', line 407

def jcb
  @jcb
end

#klarnaObject (readonly)

Attribute for field klarna



409
410
411
# File 'lib/stripe/resources/payment_method_configuration.rb', line 409

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



411
412
413
# File 'lib/stripe/resources/payment_method_configuration.rb', line 411

def konbini
  @konbini
end

Attribute for field link



413
414
415
# File 'lib/stripe/resources/payment_method_configuration.rb', line 413

def link
  @link
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



415
416
417
# File 'lib/stripe/resources/payment_method_configuration.rb', line 415

def livemode
  @livemode
end

#mobilepayObject (readonly)

Attribute for field mobilepay



417
418
419
# File 'lib/stripe/resources/payment_method_configuration.rb', line 417

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



419
420
421
# File 'lib/stripe/resources/payment_method_configuration.rb', line 419

def multibanco
  @multibanco
end

#nameObject (readonly)

The configuration’s name.



421
422
423
# File 'lib/stripe/resources/payment_method_configuration.rb', line 421

def name
  @name
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



423
424
425
# File 'lib/stripe/resources/payment_method_configuration.rb', line 423

def object
  @object
end

#oxxoObject (readonly)

Attribute for field oxxo



425
426
427
# File 'lib/stripe/resources/payment_method_configuration.rb', line 425

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



427
428
429
# File 'lib/stripe/resources/payment_method_configuration.rb', line 427

def p24
  @p24
end

#parentObject (readonly)

For child configs, the configuration’s parent configuration.



429
430
431
# File 'lib/stripe/resources/payment_method_configuration.rb', line 429

def parent
  @parent
end

#paynowObject (readonly)

Attribute for field paynow



431
432
433
# File 'lib/stripe/resources/payment_method_configuration.rb', line 431

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



433
434
435
# File 'lib/stripe/resources/payment_method_configuration.rb', line 433

def paypal
  @paypal
end

#paytoObject (readonly)

Attribute for field payto



435
436
437
# File 'lib/stripe/resources/payment_method_configuration.rb', line 435

def payto
  @payto
end

#promptpayObject (readonly)

Attribute for field promptpay



437
438
439
# File 'lib/stripe/resources/payment_method_configuration.rb', line 437

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



439
440
441
# File 'lib/stripe/resources/payment_method_configuration.rb', line 439

def qris
  @qris
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



441
442
443
# File 'lib/stripe/resources/payment_method_configuration.rb', line 441

def revolut_pay
  @revolut_pay
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



443
444
445
# File 'lib/stripe/resources/payment_method_configuration.rb', line 443

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



445
446
447
# File 'lib/stripe/resources/payment_method_configuration.rb', line 445

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



447
448
449
# File 'lib/stripe/resources/payment_method_configuration.rb', line 447

def sofort
  @sofort
end

#swishObject (readonly)

Attribute for field swish



449
450
451
# File 'lib/stripe/resources/payment_method_configuration.rb', line 449

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



451
452
453
# File 'lib/stripe/resources/payment_method_configuration.rb', line 451

def twint
  @twint
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



453
454
455
# File 'lib/stripe/resources/payment_method_configuration.rb', line 453

def 
  @us_bank_account
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



455
456
457
# File 'lib/stripe/resources/payment_method_configuration.rb', line 455

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



457
458
459
# File 'lib/stripe/resources/payment_method_configuration.rb', line 457

def zip
  @zip
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a payment method configuration



460
461
462
463
464
465
466
467
# File 'lib/stripe/resources/payment_method_configuration.rb', line 460

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/payment_method_configurations",
    params: params,
    opts: opts
  )
end

.list(filters = {}, opts = {}) ⇒ Object

List payment method configurations



470
471
472
473
474
475
476
477
# File 'lib/stripe/resources/payment_method_configuration.rb', line 470

def self.list(filters = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/payment_method_configurations",
    params: filters,
    opts: opts
  )
end

.object_nameObject



25
26
27
# File 'lib/stripe/resources/payment_method_configuration.rb', line 25

def self.object_name
  "payment_method_configuration"
end

.update(id, params = {}, opts = {}) ⇒ Object

Update payment method configuration



480
481
482
483
484
485
486
487
# File 'lib/stripe/resources/payment_method_configuration.rb', line 480

def self.update(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_method_configurations/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end