Class: Stripe::PaymentMethodConfiguration::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_method_configuration.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, ApplePay, ApplePayLater, AuBecsDebit, BacsDebit, Bancontact, Blik, Boleto, Card, CartesBancaires, Cashapp, CustomerBalance, Eps, Fpx, Giropay, GooglePay, Gopay, Grabpay, IdBankTransfer, Ideal, Jcb, Klarna, Konbini, Link, Mobilepay, Multibanco, Oxxo, P24, PayByBank, Paynow, Paypal, Payto, Promptpay, Qris, RevolutPay, SepaDebit, Shopeepay, Sofort, Swish, Twint, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, apple_pay: nil, apple_pay_later: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, blik: nil, boleto: nil, card: nil, cartes_bancaires: nil, cashapp: nil, customer_balance: nil, eps: nil, expand: nil, fpx: nil, giropay: nil, google_pay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, jcb: nil, klarna: nil, konbini: nil, link: nil, mobilepay: nil, multibanco: nil, name: nil, oxxo: nil, p24: nil, parent: nil, pay_by_bank: nil, paynow: nil, paypal: nil, payto: nil, promptpay: nil, qris: nil, revolut_pay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1680

def initialize(
  acss_debit: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  alma: nil,
  amazon_pay: nil,
  apple_pay: nil,
  apple_pay_later: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  blik: nil,
  boleto: nil,
  card: nil,
  cartes_bancaires: nil,
  cashapp: nil,
  customer_balance: nil,
  eps: nil,
  expand: nil,
  fpx: nil,
  giropay: nil,
  google_pay: nil,
  gopay: nil,
  grabpay: nil,
  id_bank_transfer: nil,
  ideal: nil,
  jcb: nil,
  klarna: nil,
  konbini: nil,
  link: nil,
  mobilepay: nil,
  multibanco: nil,
  name: nil,
  oxxo: nil,
  p24: nil,
  parent: nil,
  pay_by_bank: nil,
  paynow: nil,
  paypal: nil,
  payto: nil,
  promptpay: nil,
  qris: nil,
  revolut_pay: nil,
  sepa_debit: nil,
  shopeepay: nil,
  sofort: nil,
  swish: nil,
  twint: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @alma = alma
  @amazon_pay = amazon_pay
  @apple_pay = apple_pay
  @apple_pay_later = apple_pay_later
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @blik = blik
  @boleto = boleto
  @card = card
  @cartes_bancaires = cartes_bancaires
  @cashapp = cashapp
  @customer_balance = customer_balance
  @eps = eps
  @expand = expand
  @fpx = fpx
  @giropay = giropay
  @google_pay = google_pay
  @gopay = gopay
  @grabpay = grabpay
  @id_bank_transfer = id_bank_transfer
  @ideal = ideal
  @jcb = jcb
  @klarna = klarna
  @konbini = konbini
  @link = link
  @mobilepay = mobilepay
  @multibanco = multibanco
  @name = name
  @oxxo = oxxo
  @p24 = p24
  @parent = parent
  @pay_by_bank = pay_by_bank
  @paynow = paynow
  @paypal = paypal
  @payto = payto
  @promptpay = promptpay
  @qris = qris
  @revolut_pay = revolut_pay
  @sepa_debit = sepa_debit
  @shopeepay = shopeepay
  @sofort = sofort
  @swish = swish
  @twint = twint
  @us_bank_account = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

Canadian pre-authorized debit payments, check this [page](stripe.com/docs/payments/acss-debit) for more details like country availability.



1578
1579
1580
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1578

def acss_debit
  @acss_debit
end

#affirmObject

[Affirm](www.affirm.com/) gives your customers a way to split purchases over a series of payments. Depending on the purchase, they can pay with four interest-free payments (Split Pay) or pay over a longer term (Installments), which might include interest. Check this [page](stripe.com/docs/payments/affirm) for more details like country availability.



1580
1581
1582
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1580

def affirm
  @affirm
end

#afterpay_clearpayObject

Afterpay gives your customers a way to pay for purchases in installments, check this [page](stripe.com/docs/payments/afterpay-clearpay) for more details like country availability. Afterpay is particularly popular among businesses selling fashion, beauty, and sports products.



1582
1583
1584
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1582

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

Alipay is a digital wallet in China that has more than a billion active users worldwide. Alipay users can pay on the web or on a mobile device using login credentials or their Alipay app. Alipay has a low dispute rate and reduces fraud by authenticating payments using the customer’s login credentials. Check this [page](stripe.com/docs/payments/alipay) for more details.



1584
1585
1586
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1584

def alipay
  @alipay
end

#almaObject

Alma is a Buy Now, Pay Later payment method that offers customers the ability to pay in 2, 3, or 4 installments.



1586
1587
1588
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1586

def alma
  @alma
end

#amazon_payObject

Amazon Pay is a wallet payment method that lets your customers check out the same way as on Amazon.



1588
1589
1590
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1588

def amazon_pay
  @amazon_pay
end

#apple_payObject

Stripe users can accept [Apple Pay](/payments/apple-pay) in iOS applications in iOS 9 and later, and on the web in Safari starting with iOS 10 or macOS Sierra. There are no additional fees to process Apple Pay payments, and the [pricing](/pricing) is the same as other card transactions. Check this [page](stripe.com/docs/apple-pay) for more details.



1590
1591
1592
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1590

def apple_pay
  @apple_pay
end

#apple_pay_laterObject

Apple Pay Later, a payment method for customers to buy now and pay later, gives your customers a way to split purchases into four installments across six weeks.



1592
1593
1594
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1592

def apple_pay_later
  @apple_pay_later
end

#au_becs_debitObject

Stripe users in Australia can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with an Australian bank account. Check this [page](stripe.com/docs/payments/au-becs-debit) for more details.



1594
1595
1596
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1594

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

Stripe users in the UK can accept Bacs Direct Debit payments from customers with a UK bank account, check this [page](stripe.com/docs/payments/payment-methods/bacs-debit) for more details.



1596
1597
1598
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1596

def bacs_debit
  @bacs_debit
end

#bancontactObject

Bancontact is the most popular online payment method in Belgium, with over 15 million cards in circulation. [Customers](stripe.com/docs/api/customers) use a Bancontact card or mobile app linked to a Belgian bank account to make online payments that are secure, guaranteed, and confirmed immediately. Check this [page](stripe.com/docs/payments/bancontact) for more details.



1598
1599
1600
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1598

def bancontact
  @bancontact
end

#blikObject

BLIK is a [single use](stripe.com/docs/payments/payment-methods#usage) payment method that requires customers to authenticate their payments. When customers want to pay online using BLIK, they request a six-digit code from their banking application and enter it into the payment collection form. Check this [page](stripe.com/docs/payments/blik) for more details.



1600
1601
1602
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1600

def blik
  @blik
end

#boletoObject

Boleto is an official (regulated by the Central Bank of Brazil) payment method in Brazil. Check this [page](stripe.com/docs/payments/boleto) for more details.



1602
1603
1604
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1602

def boleto
  @boleto
end

#cardObject

Cards are a popular way for consumers and businesses to pay online or in person. Stripe supports global and local card networks.



1604
1605
1606
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1604

def card
  @card
end

#cartes_bancairesObject

Cartes Bancaires is France’s local card network. More than 95% of these cards are co-branded with either Visa or Mastercard, meaning you can process these cards over either Cartes Bancaires or the Visa or Mastercard networks. Check this [page](stripe.com/docs/payments/cartes-bancaires) for more details.



1606
1607
1608
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1606

def cartes_bancaires
  @cartes_bancaires
end

#cashappObject

Cash App is a popular consumer app in the US that allows customers to bank, invest, send, and receive money using their digital wallet. Check this [page](stripe.com/docs/payments/cash-app-pay) for more details.



1608
1609
1610
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1608

def cashapp
  @cashapp
end

#customer_balanceObject

Uses a customer’s [cash balance](stripe.com/docs/payments/customer-balance) for the payment. The cash balance can be funded via a bank transfer. Check this [page](stripe.com/docs/payments/bank-transfers) for more details.



1610
1611
1612
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1610

def customer_balance
  @customer_balance
end

#epsObject

EPS is an Austria-based payment method that allows customers to complete transactions online using their bank credentials. EPS is supported by all Austrian banks and is accepted by over 80% of Austrian online retailers. Check this [page](stripe.com/docs/payments/eps) for more details.



1612
1613
1614
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1612

def eps
  @eps
end

#expandObject

Specifies which fields in the response should be expanded.



1614
1615
1616
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1614

def expand
  @expand
end

#fpxObject

Financial Process Exchange (FPX) is a Malaysia-based payment method that allows customers to complete transactions online using their bank credentials. Bank Negara Malaysia (BNM), the Central Bank of Malaysia, and eleven other major Malaysian financial institutions are members of the PayNet Group, which owns and operates FPX. It is one of the most popular online payment methods in Malaysia, with nearly 90 million transactions in 2018 according to BNM. Check this [page](stripe.com/docs/payments/fpx) for more details.



1616
1617
1618
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1616

def fpx
  @fpx
end

#giropayObject

giropay is a German payment method based on online banking, introduced in 2006. It allows customers to complete transactions online using their online banking environment, with funds debited from their bank account. Depending on their bank, customers confirm payments on giropay using a second factor of authentication or a PIN. giropay accounts for 10% of online checkouts in Germany. Check this [page](stripe.com/docs/payments/giropay) for more details.



1618
1619
1620
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1618

def giropay
  @giropay
end

#google_payObject

Google Pay allows customers to make payments in your app or website using any credit or debit card saved to their Google Account, including those from Google Play, YouTube, Chrome, or an Android device. Use the Google Pay API to request any credit or debit card stored in your customer’s Google account. Check this [page](stripe.com/docs/google-pay) for more details.



1620
1621
1622
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1620

def google_pay
  @google_pay
end

#gopayObject

GoPay is a [single use](stripe.com/docs/payments/payment-methods#usage) digital wallet payment method popular in Indonesia. When paying with GoPay, customers authenticate and approve payments using the Gojek app. Desktop checkout is performed by scanning a QR code. When checking out on mobile, customers are redirected to the Gojek app to confirm payment.



1622
1623
1624
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1622

def gopay
  @gopay
end

#grabpayObject

GrabPay is a payment method developed by [Grab](www.grab.com/sg/consumer/finance/pay/). GrabPay is a digital wallet - customers maintain a balance in their wallets that they pay out with. Check this [page](stripe.com/docs/payments/grabpay) for more details.



1624
1625
1626
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1624

def grabpay
  @grabpay
end

#id_bank_transferObject

Stripe users in Indonesia can receive bank transfers from customers in Indonesia. Bank transfers are a popular B2C and B2B payment method in Indonesia.



1626
1627
1628
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1626

def id_bank_transfer
  @id_bank_transfer
end

#idealObject

iDEAL is a Netherlands-based payment method that allows customers to complete transactions online using their bank credentials. All major Dutch banks are members of Currence, the scheme that operates iDEAL, making it the most popular online payment method in the Netherlands with a share of online transactions close to 55%. Check this [page](stripe.com/docs/payments/ideal) for more details.



1628
1629
1630
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1628

def ideal
  @ideal
end

#jcbObject

JCB is a credit card company based in Japan. JCB is currently available in Japan to businesses approved by JCB, and available to all businesses in Australia, Canada, Hong Kong, Japan, New Zealand, Singapore, Switzerland, United Kingdom, United States, and all countries in the European Economic Area except Iceland. Check this [page](support.stripe.com/questions/accepting-japan-credit-bureau-%28jcb%29-payments) for more details.



1630
1631
1632
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1630

def jcb
  @jcb
end

#klarnaObject

Klarna gives customers a range of [payment options](stripe.com/docs/payments/klarna#payment-options) during checkout. Available payment options vary depending on the customer’s billing address and the transaction amount. These payment options make it convenient for customers to purchase items in all price ranges. Check this [page](stripe.com/docs/payments/klarna) for more details.



1632
1633
1634
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1632

def klarna
  @klarna
end

#konbiniObject

Konbini allows customers in Japan to pay for bills and online purchases at convenience stores with cash. Check this [page](stripe.com/docs/payments/konbini) for more details.



1634
1635
1636
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1634

def konbini
  @konbini
end

[Link](stripe.com/docs/payments/link) is a payment method network. With Link, users save their payment details once, then reuse that information to pay with one click for any business on the network.



1636
1637
1638
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1636

def link
  @link
end

#mobilepayObject

MobilePay is a [single-use](stripe.com/docs/payments/payment-methods#usage) card wallet payment method used in Denmark and Finland. It allows customers to [authenticate and approve](stripe.com/docs/payments/payment-methods#customer-actions) payments using the MobilePay app. Check this [page](stripe.com/docs/payments/mobilepay) for more details.



1638
1639
1640
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1638

def mobilepay
  @mobilepay
end

#multibancoObject

Stripe users in Europe and the United States can accept Multibanco payments from customers in Portugal using [Sources](stripe.com/docs/sources)—a single integration path for creating payments using any supported method.



1640
1641
1642
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1640

def multibanco
  @multibanco
end

#nameObject

Configuration name.



1642
1643
1644
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1642

def name
  @name
end

#oxxoObject

OXXO is a Mexican chain of convenience stores with thousands of locations across Latin America and represents nearly 20% of online transactions in Mexico. OXXO allows customers to pay bills and online purchases in-store with cash. Check this [page](stripe.com/docs/payments/oxxo) for more details.



1644
1645
1646
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1644

def oxxo
  @oxxo
end

#p24Object

Przelewy24 is a Poland-based payment method aggregator that allows customers to complete transactions online using bank transfers and other methods. Bank transfers account for 30% of online payments in Poland and Przelewy24 provides a way for customers to pay with over 165 banks. Check this [page](stripe.com/docs/payments/p24) for more details.



1646
1647
1648
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1646

def p24
  @p24
end

#parentObject

Configuration’s parent configuration. Specify to create a child configuration.



1648
1649
1650
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1648

def parent
  @parent
end

#pay_by_bankObject

Pay by bank is a redirect payment method backed by bank transfers. A customer is redirected to their bank to authorize a bank transfer for a given amount. This removes a lot of the error risks inherent in waiting for the customer to initiate a transfer themselves, and is less expensive than card payments.



1650
1651
1652
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1650

def pay_by_bank
  @pay_by_bank
end

#paynowObject

PayNow is a Singapore-based payment method that allows customers to make a payment using their preferred app from participating banks and participating non-bank financial institutions. Check this [page](stripe.com/docs/payments/paynow) for more details.



1652
1653
1654
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1652

def paynow
  @paynow
end

#paypalObject

PayPal, a digital wallet popular with customers in Europe, allows your customers worldwide to pay using their PayPal account. Check this [page](stripe.com/docs/payments/paypal) for more details.



1654
1655
1656
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1654

def paypal
  @paypal
end

#paytoObject

PayTo is a [real-time](docs.stripe.com/payments/real-time) payment method that enables customers in Australia to pay by providing their bank account details. Customers must accept a mandate authorizing you to debit their account. Check this [page](docs.stripe.com/payments/payto) for more details.



1656
1657
1658
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1656

def payto
  @payto
end

#promptpayObject

PromptPay is a Thailand-based payment method that allows customers to make a payment using their preferred app from participating banks. Check this [page](stripe.com/docs/payments/promptpay) for more details.



1658
1659
1660
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1658

def promptpay
  @promptpay
end

#qrisObject

QRIS is a [real-time](docs.stripe.com/payments/real-time) payment method popular in Indonesia. When paying with QRIS, customers authenticate and approve payments by scanning a QR code in their preferred digital wallet app.



1660
1661
1662
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1660

def qris
  @qris
end

#revolut_payObject

Revolut Pay, developed by Revolut, a global finance app, is a digital wallet payment method. Revolut Pay uses the customer’s stored balance or cards to fund the payment, and offers the option for non-Revolut customers to save their details after their first purchase.



1662
1663
1664
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1662

def revolut_pay
  @revolut_pay
end

#sepa_debitObject

The [Single Euro Payments Area (SEPA)](en.wikipedia.org/wiki/Single_Euro_Payments_Area) is an initiative of the European Union to simplify payments within and across member countries. SEPA established and enforced banking standards to allow for the direct debiting of every EUR-denominated bank account within the SEPA region, check this [page](stripe.com/docs/payments/sepa-debit) for more details.



1664
1665
1666
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1664

def sepa_debit
  @sepa_debit
end

#shopeepayObject

ShopeePay is a [single use](stripe.com/docs/payments/payment-methods#usage) digital wallet payment method popular in Indonesia. When paying with GoPay, customers authenticate and approve payments using the Shopee app. Desktop checkout is performed by scanning a QR code. When checking out on mobile, customers are redirected to the Shopee app to confirm payment.



1666
1667
1668
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1666

def shopeepay
  @shopeepay
end

#sofortObject

Stripe users in Europe and the United States can use the [Payment Intents API](stripe.com/docs/payments/payment-intents)—a single integration path for creating payments using any supported method—to accept [Sofort](www.sofort.com/) payments from customers. Check this [page](stripe.com/docs/payments/sofort) for more details.



1668
1669
1670
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1668

def sofort
  @sofort
end

#swishObject

Swish is a [real-time](stripe.com/docs/payments/real-time) payment method popular in Sweden. It allows customers to [authenticate and approve](stripe.com/docs/payments/payment-methods#customer-actions) payments using the Swish mobile app and the Swedish BankID mobile app. Check this [page](stripe.com/docs/payments/swish) for more details.



1670
1671
1672
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1670

def swish
  @swish
end

#twintObject

Twint is a payment method popular in Switzerland. It allows customers to pay using their mobile phone. Check this [page](docs.stripe.com/payments/twint) for more details.



1672
1673
1674
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1672

def twint
  @twint
end

#us_bank_accountObject

Stripe users in the United States can accept ACH direct debit payments from customers with a US bank account using the Automated Clearing House (ACH) payments system operated by Nacha. Check this [page](stripe.com/docs/payments/ach-direct-debit) for more details.



1674
1675
1676
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1674

def 
  @us_bank_account
end

#wechat_payObject

WeChat, owned by Tencent, is China’s leading mobile app with over 1 billion monthly active users. Chinese consumers can use WeChat Pay to pay for goods and services inside of businesses’ apps and websites. WeChat Pay users buy most frequently in gaming, e-commerce, travel, online education, and food/nutrition. Check this [page](stripe.com/docs/payments/wechat-pay) for more details.



1676
1677
1678
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1676

def wechat_pay
  @wechat_pay
end

#zipObject

Zip gives your customers a way to split purchases over a series of payments. Check this [page](stripe.com/docs/payments/zip) for more details like country availability.



1678
1679
1680
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1678

def zip
  @zip
end