Class: Stripe::PaymentMethodConfiguration::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_method_configuration.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, ApplePay, ApplePayLater, AuBecsDebit, BacsDebit, Bancontact, Blik, Boleto, Card, CartesBancaires, Cashapp, CustomerBalance, Eps, Fpx, Giropay, GooglePay, Gopay, Grabpay, IdBankTransfer, Ideal, Jcb, Klarna, Konbini, Link, Mobilepay, Multibanco, Oxxo, P24, Paynow, Paypal, Payto, Promptpay, Qris, RevolutPay, SepaDebit, Shopeepay, Sofort, Swish, Twint, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, apple_pay: nil, apple_pay_later: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, blik: nil, boleto: nil, card: nil, cartes_bancaires: nil, cashapp: nil, customer_balance: nil, eps: nil, expand: nil, fpx: nil, giropay: nil, google_pay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, jcb: nil, klarna: nil, konbini: nil, link: nil, mobilepay: nil, multibanco: nil, name: nil, oxxo: nil, p24: nil, parent: nil, paynow: nil, paypal: nil, payto: nil, promptpay: nil, qris: nil, revolut_pay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1837

def initialize(
  acss_debit: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  alma: nil,
  amazon_pay: nil,
  apple_pay: nil,
  apple_pay_later: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  blik: nil,
  boleto: nil,
  card: nil,
  cartes_bancaires: nil,
  cashapp: nil,
  customer_balance: nil,
  eps: nil,
  expand: nil,
  fpx: nil,
  giropay: nil,
  google_pay: nil,
  gopay: nil,
  grabpay: nil,
  id_bank_transfer: nil,
  ideal: nil,
  jcb: nil,
  klarna: nil,
  konbini: nil,
  link: nil,
  mobilepay: nil,
  multibanco: nil,
  name: nil,
  oxxo: nil,
  p24: nil,
  parent: nil,
  paynow: nil,
  paypal: nil,
  payto: nil,
  promptpay: nil,
  qris: nil,
  revolut_pay: nil,
  sepa_debit: nil,
  shopeepay: nil,
  sofort: nil,
  swish: nil,
  twint: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @alma = alma
  @amazon_pay = amazon_pay
  @apple_pay = apple_pay
  @apple_pay_later = apple_pay_later
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @blik = blik
  @boleto = boleto
  @card = card
  @cartes_bancaires = cartes_bancaires
  @cashapp = cashapp
  @customer_balance = customer_balance
  @eps = eps
  @expand = expand
  @fpx = fpx
  @giropay = giropay
  @google_pay = google_pay
  @gopay = gopay
  @grabpay = grabpay
  @id_bank_transfer = id_bank_transfer
  @ideal = ideal
  @jcb = jcb
  @klarna = klarna
  @konbini = konbini
  @link = link
  @mobilepay = mobilepay
  @multibanco = multibanco
  @name = name
  @oxxo = oxxo
  @p24 = p24
  @parent = parent
  @paynow = paynow
  @paypal = paypal
  @payto = payto
  @promptpay = promptpay
  @qris = qris
  @revolut_pay = revolut_pay
  @sepa_debit = sepa_debit
  @shopeepay = shopeepay
  @sofort = sofort
  @swish = swish
  @twint = twint
  @us_bank_account = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

Canadian pre-authorized debit payments, check this [page](stripe.com/docs/payments/acss-debit) for more details like country availability.



1688
1689
1690
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1688

def acss_debit
  @acss_debit
end

#affirmObject

[Affirm](www.affirm.com/) gives your customers a way to split purchases over a series of payments. Depending on the purchase, they can pay with four interest-free payments (Split Pay) or pay over a longer term (Installments), which might include interest. Check this [page](stripe.com/docs/payments/affirm) for more details like country availability.



1691
1692
1693
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1691

def affirm
  @affirm
end

#afterpay_clearpayObject

Afterpay gives your customers a way to pay for purchases in installments, check this [page](stripe.com/docs/payments/afterpay-clearpay) for more details like country availability. Afterpay is particularly popular among businesses selling fashion, beauty, and sports products.



1694
1695
1696
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1694

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

Alipay is a digital wallet in China that has more than a billion active users worldwide. Alipay users can pay on the web or on a mobile device using login credentials or their Alipay app. Alipay has a low dispute rate and reduces fraud by authenticating payments using the customer’s login credentials. Check this [page](stripe.com/docs/payments/alipay) for more details.



1697
1698
1699
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1697

def alipay
  @alipay
end

#almaObject

Alma is a Buy Now, Pay Later payment method that offers customers the ability to pay in 2, 3, or 4 installments.



1700
1701
1702
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1700

def alma
  @alma
end

#amazon_payObject

Amazon Pay is a wallet payment method that lets your customers check out the same way as on Amazon.



1703
1704
1705
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1703

def amazon_pay
  @amazon_pay
end

#apple_payObject

Stripe users can accept [Apple Pay](/payments/apple-pay) in iOS applications in iOS 9 and later, and on the web in Safari starting with iOS 10 or macOS Sierra. There are no additional fees to process Apple Pay payments, and the [pricing](/pricing) is the same as other card transactions. Check this [page](stripe.com/docs/apple-pay) for more details.



1706
1707
1708
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1706

def apple_pay
  @apple_pay
end

#apple_pay_laterObject

Apple Pay Later, a payment method for customers to buy now and pay later, gives your customers a way to split purchases into four installments across six weeks.



1709
1710
1711
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1709

def apple_pay_later
  @apple_pay_later
end

#au_becs_debitObject

Stripe users in Australia can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with an Australian bank account. Check this [page](stripe.com/docs/payments/au-becs-debit) for more details.



1712
1713
1714
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1712

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

Stripe users in the UK can accept Bacs Direct Debit payments from customers with a UK bank account, check this [page](stripe.com/docs/payments/payment-methods/bacs-debit) for more details.



1715
1716
1717
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1715

def bacs_debit
  @bacs_debit
end

#bancontactObject

Bancontact is the most popular online payment method in Belgium, with over 15 million cards in circulation. [Customers](stripe.com/docs/api/customers) use a Bancontact card or mobile app linked to a Belgian bank account to make online payments that are secure, guaranteed, and confirmed immediately. Check this [page](stripe.com/docs/payments/bancontact) for more details.



1718
1719
1720
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1718

def bancontact
  @bancontact
end

#blikObject

BLIK is a [single use](stripe.com/docs/payments/payment-methods#usage) payment method that requires customers to authenticate their payments. When customers want to pay online using BLIK, they request a six-digit code from their banking application and enter it into the payment collection form. Check this [page](stripe.com/docs/payments/blik) for more details.



1721
1722
1723
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1721

def blik
  @blik
end

#boletoObject

Boleto is an official (regulated by the Central Bank of Brazil) payment method in Brazil. Check this [page](stripe.com/docs/payments/boleto) for more details.



1724
1725
1726
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1724

def boleto
  @boleto
end

#cardObject

Cards are a popular way for consumers and businesses to pay online or in person. Stripe supports global and local card networks.



1727
1728
1729
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1727

def card
  @card
end

#cartes_bancairesObject

Cartes Bancaires is France’s local card network. More than 95% of these cards are co-branded with either Visa or Mastercard, meaning you can process these cards over either Cartes Bancaires or the Visa or Mastercard networks. Check this [page](stripe.com/docs/payments/cartes-bancaires) for more details.



1730
1731
1732
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1730

def cartes_bancaires
  @cartes_bancaires
end

#cashappObject

Cash App is a popular consumer app in the US that allows customers to bank, invest, send, and receive money using their digital wallet. Check this [page](stripe.com/docs/payments/cash-app-pay) for more details.



1733
1734
1735
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1733

def cashapp
  @cashapp
end

#customer_balanceObject

Uses a customer’s [cash balance](stripe.com/docs/payments/customer-balance) for the payment. The cash balance can be funded via a bank transfer. Check this [page](stripe.com/docs/payments/bank-transfers) for more details.



1736
1737
1738
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1736

def customer_balance
  @customer_balance
end

#epsObject

EPS is an Austria-based payment method that allows customers to complete transactions online using their bank credentials. EPS is supported by all Austrian banks and is accepted by over 80% of Austrian online retailers. Check this [page](stripe.com/docs/payments/eps) for more details.



1739
1740
1741
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1739

def eps
  @eps
end

#expandObject

Specifies which fields in the response should be expanded.



1742
1743
1744
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1742

def expand
  @expand
end

#fpxObject

Financial Process Exchange (FPX) is a Malaysia-based payment method that allows customers to complete transactions online using their bank credentials. Bank Negara Malaysia (BNM), the Central Bank of Malaysia, and eleven other major Malaysian financial institutions are members of the PayNet Group, which owns and operates FPX. It is one of the most popular online payment methods in Malaysia, with nearly 90 million transactions in 2018 according to BNM. Check this [page](stripe.com/docs/payments/fpx) for more details.



1745
1746
1747
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1745

def fpx
  @fpx
end

#giropayObject

giropay is a German payment method based on online banking, introduced in 2006. It allows customers to complete transactions online using their online banking environment, with funds debited from their bank account. Depending on their bank, customers confirm payments on giropay using a second factor of authentication or a PIN. giropay accounts for 10% of online checkouts in Germany. Check this [page](stripe.com/docs/payments/giropay) for more details.



1748
1749
1750
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1748

def giropay
  @giropay
end

#google_payObject

Google Pay allows customers to make payments in your app or website using any credit or debit card saved to their Google Account, including those from Google Play, YouTube, Chrome, or an Android device. Use the Google Pay API to request any credit or debit card stored in your customer’s Google account. Check this [page](stripe.com/docs/google-pay) for more details.



1751
1752
1753
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1751

def google_pay
  @google_pay
end

#gopayObject

GoPay is a [single use](stripe.com/docs/payments/payment-methods#usage) digital wallet payment method popular in Indonesia. When paying with GoPay, customers authenticate and approve payments using the Gojek app. Desktop checkout is performed by scanning a QR code. When checking out on mobile, customers are redirected to the Gojek app to confirm payment.



1754
1755
1756
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1754

def gopay
  @gopay
end

#grabpayObject

GrabPay is a payment method developed by [Grab](www.grab.com/sg/consumer/finance/pay/). GrabPay is a digital wallet - customers maintain a balance in their wallets that they pay out with. Check this [page](stripe.com/docs/payments/grabpay) for more details.



1757
1758
1759
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1757

def grabpay
  @grabpay
end

#id_bank_transferObject

Stripe users in Indonesia can receive bank transfers from customers in Indonesia. Bank transfers are a popular B2C and B2B payment method in Indonesia.



1760
1761
1762
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1760

def id_bank_transfer
  @id_bank_transfer
end

#idealObject

iDEAL is a Netherlands-based payment method that allows customers to complete transactions online using their bank credentials. All major Dutch banks are members of Currence, the scheme that operates iDEAL, making it the most popular online payment method in the Netherlands with a share of online transactions close to 55%. Check this [page](stripe.com/docs/payments/ideal) for more details.



1763
1764
1765
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1763

def ideal
  @ideal
end

#jcbObject

JCB is a credit card company based in Japan. JCB is currently available in Japan to businesses approved by JCB, and available to all businesses in Australia, Canada, Hong Kong, Japan, New Zealand, Singapore, Switzerland, United Kingdom, United States, and all countries in the European Economic Area except Iceland. Check this [page](support.stripe.com/questions/accepting-japan-credit-bureau-%28jcb%29-payments) for more details.



1766
1767
1768
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1766

def jcb
  @jcb
end

#klarnaObject

Klarna gives customers a range of [payment options](stripe.com/docs/payments/klarna#payment-options) during checkout. Available payment options vary depending on the customer’s billing address and the transaction amount. These payment options make it convenient for customers to purchase items in all price ranges. Check this [page](stripe.com/docs/payments/klarna) for more details.



1769
1770
1771
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1769

def klarna
  @klarna
end

#konbiniObject

Konbini allows customers in Japan to pay for bills and online purchases at convenience stores with cash. Check this [page](stripe.com/docs/payments/konbini) for more details.



1772
1773
1774
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1772

def konbini
  @konbini
end

[Link](stripe.com/docs/payments/link) is a payment method network. With Link, users save their payment details once, then reuse that information to pay with one click for any business on the network.



1775
1776
1777
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1775

def link
  @link
end

#mobilepayObject

MobilePay is a [single-use](stripe.com/docs/payments/payment-methods#usage) card wallet payment method used in Denmark and Finland. It allows customers to [authenticate and approve](stripe.com/docs/payments/payment-methods#customer-actions) payments using the MobilePay app. Check this [page](stripe.com/docs/payments/mobilepay) for more details.



1778
1779
1780
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1778

def mobilepay
  @mobilepay
end

#multibancoObject

Stripe users in Europe and the United States can accept Multibanco payments from customers in Portugal using [Sources](stripe.com/docs/sources)—a single integration path for creating payments using any supported method.



1781
1782
1783
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1781

def multibanco
  @multibanco
end

#nameObject

Configuration name.



1784
1785
1786
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1784

def name
  @name
end

#oxxoObject

OXXO is a Mexican chain of convenience stores with thousands of locations across Latin America and represents nearly 20% of online transactions in Mexico. OXXO allows customers to pay bills and online purchases in-store with cash. Check this [page](stripe.com/docs/payments/oxxo) for more details.



1787
1788
1789
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1787

def oxxo
  @oxxo
end

#p24Object

Przelewy24 is a Poland-based payment method aggregator that allows customers to complete transactions online using bank transfers and other methods. Bank transfers account for 30% of online payments in Poland and Przelewy24 provides a way for customers to pay with over 165 banks. Check this [page](stripe.com/docs/payments/p24) for more details.



1790
1791
1792
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1790

def p24
  @p24
end

#parentObject

Configuration’s parent configuration. Specify to create a child configuration.



1793
1794
1795
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1793

def parent
  @parent
end

#paynowObject

PayNow is a Singapore-based payment method that allows customers to make a payment using their preferred app from participating banks and participating non-bank financial institutions. Check this [page](stripe.com/docs/payments/paynow) for more details.



1796
1797
1798
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1796

def paynow
  @paynow
end

#paypalObject

PayPal, a digital wallet popular with customers in Europe, allows your customers worldwide to pay using their PayPal account. Check this [page](stripe.com/docs/payments/paypal) for more details.



1799
1800
1801
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1799

def paypal
  @paypal
end

#paytoObject

PayTo is a [real-time](docs.stripe.com/payments/real-time) payment method that enables customers in Australia to pay by providing their bank account details. Customers must accept a mandate authorizing you to debit their account. Check this [page](docs.stripe.com/payments/payto) for more details.



1802
1803
1804
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1802

def payto
  @payto
end

#promptpayObject

PromptPay is a Thailand-based payment method that allows customers to make a payment using their preferred app from participating banks. Check this [page](stripe.com/docs/payments/promptpay) for more details.



1805
1806
1807
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1805

def promptpay
  @promptpay
end

#qrisObject

QRIS is a [real-time](docs.stripe.com/payments/real-time) payment method popular in Indonesia. When paying with QRIS, customers authenticate and approve payments by scanning a QR code in their preferred digital wallet app.



1808
1809
1810
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1808

def qris
  @qris
end

#revolut_payObject

Revolut Pay, developed by Revolut, a global finance app, is a digital wallet payment method. Revolut Pay uses the customer’s stored balance or cards to fund the payment, and offers the option for non-Revolut customers to save their details after their first purchase.



1811
1812
1813
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1811

def revolut_pay
  @revolut_pay
end

#sepa_debitObject

The [Single Euro Payments Area (SEPA)](en.wikipedia.org/wiki/Single_Euro_Payments_Area) is an initiative of the European Union to simplify payments within and across member countries. SEPA established and enforced banking standards to allow for the direct debiting of every EUR-denominated bank account within the SEPA region, check this [page](stripe.com/docs/payments/sepa-debit) for more details.



1814
1815
1816
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1814

def sepa_debit
  @sepa_debit
end

#shopeepayObject

ShopeePay is a [single use](stripe.com/docs/payments/payment-methods#usage) digital wallet payment method popular in Indonesia. When paying with GoPay, customers authenticate and approve payments using the Shopee app. Desktop checkout is performed by scanning a QR code. When checking out on mobile, customers are redirected to the Shopee app to confirm payment.



1817
1818
1819
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1817

def shopeepay
  @shopeepay
end

#sofortObject

Stripe users in Europe and the United States can use the [Payment Intents API](stripe.com/docs/payments/payment-intents)—a single integration path for creating payments using any supported method—to accept [Sofort](www.sofort.com/) payments from customers. Check this [page](stripe.com/docs/payments/sofort) for more details.



1820
1821
1822
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1820

def sofort
  @sofort
end

#swishObject

Swish is a [real-time](stripe.com/docs/payments/real-time) payment method popular in Sweden. It allows customers to [authenticate and approve](stripe.com/docs/payments/payment-methods#customer-actions) payments using the Swish mobile app and the Swedish BankID mobile app. Check this [page](stripe.com/docs/payments/swish) for more details.



1823
1824
1825
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1823

def swish
  @swish
end

#twintObject

Twint is a payment method popular in Switzerland. It allows customers to pay using their mobile phone. Check this [page](docs.stripe.com/payments/twint) for more details.



1826
1827
1828
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1826

def twint
  @twint
end

#us_bank_accountObject

Stripe users in the United States can accept ACH direct debit payments from customers with a US bank account using the Automated Clearing House (ACH) payments system operated by Nacha. Check this [page](stripe.com/docs/payments/ach-direct-debit) for more details.



1829
1830
1831
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1829

def 
  @us_bank_account
end

#wechat_payObject

WeChat, owned by Tencent, is China’s leading mobile app with over 1 billion monthly active users. Chinese consumers can use WeChat Pay to pay for goods and services inside of businesses’ apps and websites. WeChat Pay users buy most frequently in gaming, e-commerce, travel, online education, and food/nutrition. Check this [page](stripe.com/docs/payments/wechat-pay) for more details.



1832
1833
1834
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1832

def wechat_pay
  @wechat_pay
end

#zipObject

Zip gives your customers a way to split purchases over a series of payments. Check this [page](stripe.com/docs/payments/zip) for more details like country availability.



1835
1836
1837
# File 'lib/stripe/resources/payment_method_configuration.rb', line 1835

def zip
  @zip
end