Class: Stripe::PaymentMethodConfiguration::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_method_configuration.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(application: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



873
874
875
876
877
878
879
880
881
882
883
884
885
# File 'lib/stripe/resources/payment_method_configuration.rb', line 873

def initialize(
  application: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil
)
  @application = application
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#applicationObject

The Connect application to filter by.



859
860
861
# File 'lib/stripe/resources/payment_method_configuration.rb', line 859

def application
  @application
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



862
863
864
# File 'lib/stripe/resources/payment_method_configuration.rb', line 862

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



865
866
867
# File 'lib/stripe/resources/payment_method_configuration.rb', line 865

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



868
869
870
# File 'lib/stripe/resources/payment_method_configuration.rb', line 868

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



871
872
873
# File 'lib/stripe/resources/payment_method_configuration.rb', line 871

def starting_after
  @starting_after
end