Class: Stripe::PaymentMethodConfiguration::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::ListParams
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Instance Attribute Summary collapse
-
#application ⇒ Object
The Connect application to filter by.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(application: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(application: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
731 732 733 734 735 736 737 738 739 740 741 742 743 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 731 def initialize( application: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil ) @application = application @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#application ⇒ Object
The Connect application to filter by.
721 722 723 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 721 def application @application end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
723 724 725 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 723 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
725 726 727 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 725 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
727 728 729 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 727 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
729 730 731 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 729 def starting_after @starting_after end |