Class: Stripe::PaymentMethodConfiguration::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::UpdateParams
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, ApplePay, ApplePayLater, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CartesBancaires, Cashapp, CustomerBalance, Eps, Fpx, Giropay, GooglePay, Grabpay, Ideal, Jcb, Klarna, Konbini, Link, Mobilepay, Multibanco, NzBankAccount, Oxxo, P24, PayByBank, Paynow, Paypal, Promptpay, RevolutPay, Satispay, SepaDebit, Sofort, Swish, Twint, UsBankAccount, WechatPay, Zip
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
Canadian pre-authorized debit payments, check this [page](stripe.com/docs/payments/acss-debit) for more details like country availability.
-
#active ⇒ Object
Whether the configuration can be used for new payments.
-
#affirm ⇒ Object
[Affirm](www.affirm.com/) gives your customers a way to split purchases over a series of payments.
-
#afterpay_clearpay ⇒ Object
Afterpay gives your customers a way to pay for purchases in installments, check this [page](stripe.com/docs/payments/afterpay-clearpay) for more details like country availability.
-
#alipay ⇒ Object
Alipay is a digital wallet in China that has more than a billion active users worldwide.
-
#alma ⇒ Object
Alma is a Buy Now, Pay Later payment method that offers customers the ability to pay in 2, 3, or 4 installments.
-
#amazon_pay ⇒ Object
Amazon Pay is a wallet payment method that lets your customers check out the same way as on Amazon.
-
#apple_pay ⇒ Object
Stripe users can accept [Apple Pay](/payments/apple-pay) in iOS applications in iOS 9 and later, and on the web in Safari starting with iOS 10 or macOS Sierra.
-
#apple_pay_later ⇒ Object
Apple Pay Later, a payment method for customers to buy now and pay later, gives your customers a way to split purchases into four installments across six weeks.
-
#au_becs_debit ⇒ Object
Stripe users in Australia can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with an Australian bank account.
-
#bacs_debit ⇒ Object
Stripe users in the UK can accept Bacs Direct Debit payments from customers with a UK bank account, check this [page](stripe.com/docs/payments/payment-methods/bacs-debit) for more details.
-
#bancontact ⇒ Object
Bancontact is the most popular online payment method in Belgium, with over 15 million cards in circulation.
-
#billie ⇒ Object
Billie is a [single-use](docs.stripe.com/payments/payment-methods#usage) payment method that offers businesses Pay by Invoice where they offer payment terms ranging from 7-120 days.
-
#blik ⇒ Object
BLIK is a [single use](stripe.com/docs/payments/payment-methods#usage) payment method that requires customers to authenticate their payments.
-
#boleto ⇒ Object
Boleto is an official (regulated by the Central Bank of Brazil) payment method in Brazil.
-
#card ⇒ Object
Cards are a popular way for consumers and businesses to pay online or in person.
-
#cartes_bancaires ⇒ Object
Cartes Bancaires is France’s local card network.
-
#cashapp ⇒ Object
Cash App is a popular consumer app in the US that allows customers to bank, invest, send, and receive money using their digital wallet.
-
#customer_balance ⇒ Object
Uses a customer’s [cash balance](stripe.com/docs/payments/customer-balance) for the payment.
-
#eps ⇒ Object
EPS is an Austria-based payment method that allows customers to complete transactions online using their bank credentials.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fpx ⇒ Object
Financial Process Exchange (FPX) is a Malaysia-based payment method that allows customers to complete transactions online using their bank credentials.
-
#giropay ⇒ Object
giropay is a German payment method based on online banking, introduced in 2006.
-
#google_pay ⇒ Object
Google Pay allows customers to make payments in your app or website using any credit or debit card saved to their Google Account, including those from Google Play, YouTube, Chrome, or an Android device.
-
#grabpay ⇒ Object
GrabPay is a payment method developed by [Grab](www.grab.com/sg/consumer/finance/pay/).
-
#ideal ⇒ Object
iDEAL is a Netherlands-based payment method that allows customers to complete transactions online using their bank credentials.
-
#jcb ⇒ Object
JCB is a credit card company based in Japan.
-
#klarna ⇒ Object
Klarna gives customers a range of [payment options](stripe.com/docs/payments/klarna#payment-options) during checkout.
-
#konbini ⇒ Object
Konbini allows customers in Japan to pay for bills and online purchases at convenience stores with cash.
-
#link ⇒ Object
[Link](stripe.com/docs/payments/link) is a payment method network.
-
#mobilepay ⇒ Object
MobilePay is a [single-use](stripe.com/docs/payments/payment-methods#usage) card wallet payment method used in Denmark and Finland.
-
#multibanco ⇒ Object
Stripe users in Europe and the United States can accept Multibanco payments from customers in Portugal using [Sources](stripe.com/docs/sources)—a single integration path for creating payments using any supported method.
-
#name ⇒ Object
Configuration name.
-
#nz_bank_account ⇒ Object
Stripe users in New Zealand can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with a New Zeland bank account.
-
#oxxo ⇒ Object
OXXO is a Mexican chain of convenience stores with thousands of locations across Latin America and represents nearly 20% of online transactions in Mexico.
-
#p24 ⇒ Object
Przelewy24 is a Poland-based payment method aggregator that allows customers to complete transactions online using bank transfers and other methods.
-
#pay_by_bank ⇒ Object
Pay by bank is a redirect payment method backed by bank transfers.
-
#paynow ⇒ Object
PayNow is a Singapore-based payment method that allows customers to make a payment using their preferred app from participating banks and participating non-bank financial institutions.
-
#paypal ⇒ Object
PayPal, a digital wallet popular with customers in Europe, allows your customers worldwide to pay using their PayPal account.
-
#promptpay ⇒ Object
PromptPay is a Thailand-based payment method that allows customers to make a payment using their preferred app from participating banks.
-
#revolut_pay ⇒ Object
Revolut Pay, developed by Revolut, a global finance app, is a digital wallet payment method.
-
#satispay ⇒ Object
Satispay is a [single-use](docs.stripe.com/payments/payment-methods#usage) payment method where customers are required to [authenticate](/payments/payment-methods#customer-actions) their payment.
-
#sepa_debit ⇒ Object
The [Single Euro Payments Area (SEPA)](en.wikipedia.org/wiki/Single_Euro_Payments_Area) is an initiative of the European Union to simplify payments within and across member countries.
-
#sofort ⇒ Object
Stripe users in Europe and the United States can use the [Payment Intents API](stripe.com/docs/payments/payment-intents)—a single integration path for creating payments using any supported method—to accept [Sofort](www.sofort.com/) payments from customers.
-
#swish ⇒ Object
Swish is a [real-time](stripe.com/docs/payments/real-time) payment method popular in Sweden.
-
#twint ⇒ Object
Twint is a payment method popular in Switzerland.
-
#us_bank_account ⇒ Object
Stripe users in the United States can accept ACH direct debit payments from customers with a US bank account using the Automated Clearing House (ACH) payments system operated by Nacha.
-
#wechat_pay ⇒ Object
WeChat, owned by Tencent, is China’s leading mobile app with over 1 billion monthly active users.
-
#zip ⇒ Object
Zip gives your customers a way to split purchases over a series of payments.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, active: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, apple_pay: nil, apple_pay_later: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, blik: nil, boleto: nil, card: nil, cartes_bancaires: nil, cashapp: nil, customer_balance: nil, eps: nil, expand: nil, fpx: nil, giropay: nil, google_pay: nil, grabpay: nil, ideal: nil, jcb: nil, klarna: nil, konbini: nil, link: nil, mobilepay: nil, multibanco: nil, name: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, paynow: nil, paypal: nil, promptpay: nil, revolut_pay: nil, satispay: nil, sepa_debit: nil, sofort: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 2656 2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2596 def initialize( acss_debit: nil, active: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, apple_pay: nil, apple_pay_later: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, blik: nil, boleto: nil, card: nil, cartes_bancaires: nil, cashapp: nil, customer_balance: nil, eps: nil, expand: nil, fpx: nil, giropay: nil, google_pay: nil, grabpay: nil, ideal: nil, jcb: nil, klarna: nil, konbini: nil, link: nil, mobilepay: nil, multibanco: nil, name: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, paynow: nil, paypal: nil, promptpay: nil, revolut_pay: nil, satispay: nil, sepa_debit: nil, sofort: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil ) @acss_debit = acss_debit @active = active @affirm = affirm @afterpay_clearpay = afterpay_clearpay @alipay = alipay @alma = alma @amazon_pay = amazon_pay @apple_pay = apple_pay @apple_pay_later = apple_pay_later @au_becs_debit = au_becs_debit @bacs_debit = bacs_debit @bancontact = bancontact @billie = billie @blik = blik @boleto = boleto @card = card @cartes_bancaires = cartes_bancaires @cashapp = cashapp @customer_balance = customer_balance @eps = eps @expand = @fpx = fpx @giropay = giropay @google_pay = google_pay @grabpay = grabpay @ideal = ideal @jcb = jcb @klarna = klarna @konbini = konbini @link = link @mobilepay = mobilepay @multibanco = multibanco @name = name @nz_bank_account = nz_bank_account @oxxo = oxxo @p24 = p24 @pay_by_bank = pay_by_bank @paynow = paynow @paypal = paypal @promptpay = promptpay @revolut_pay = revolut_pay @satispay = satispay @sepa_debit = sepa_debit @sofort = sofort @swish = swish @twint = twint @us_bank_account = us_bank_account @wechat_pay = wechat_pay @zip = zip end |
Instance Attribute Details
#acss_debit ⇒ Object
Canadian pre-authorized debit payments, check this [page](stripe.com/docs/payments/acss-debit) for more details like country availability.
2498 2499 2500 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2498 def acss_debit @acss_debit end |
#active ⇒ Object
Whether the configuration can be used for new payments.
2500 2501 2502 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2500 def active @active end |
#affirm ⇒ Object
[Affirm](www.affirm.com/) gives your customers a way to split purchases over a series of payments. Depending on the purchase, they can pay with four interest-free payments (Split Pay) or pay over a longer term (Installments), which might include interest. Check this [page](stripe.com/docs/payments/affirm) for more details like country availability.
2502 2503 2504 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2502 def affirm @affirm end |
#afterpay_clearpay ⇒ Object
Afterpay gives your customers a way to pay for purchases in installments, check this [page](stripe.com/docs/payments/afterpay-clearpay) for more details like country availability. Afterpay is particularly popular among businesses selling fashion, beauty, and sports products.
2504 2505 2506 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2504 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
Alipay is a digital wallet in China that has more than a billion active users worldwide. Alipay users can pay on the web or on a mobile device using login credentials or their Alipay app. Alipay has a low dispute rate and reduces fraud by authenticating payments using the customer’s login credentials. Check this [page](stripe.com/docs/payments/alipay) for more details.
2506 2507 2508 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2506 def alipay @alipay end |
#alma ⇒ Object
Alma is a Buy Now, Pay Later payment method that offers customers the ability to pay in 2, 3, or 4 installments.
2508 2509 2510 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2508 def alma @alma end |
#amazon_pay ⇒ Object
Amazon Pay is a wallet payment method that lets your customers check out the same way as on Amazon.
2510 2511 2512 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2510 def amazon_pay @amazon_pay end |
#apple_pay ⇒ Object
Stripe users can accept [Apple Pay](/payments/apple-pay) in iOS applications in iOS 9 and later, and on the web in Safari starting with iOS 10 or macOS Sierra. There are no additional fees to process Apple Pay payments, and the [pricing](/pricing) is the same as other card transactions. Check this [page](stripe.com/docs/apple-pay) for more details.
2512 2513 2514 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2512 def apple_pay @apple_pay end |
#apple_pay_later ⇒ Object
Apple Pay Later, a payment method for customers to buy now and pay later, gives your customers a way to split purchases into four installments across six weeks.
2514 2515 2516 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2514 def apple_pay_later @apple_pay_later end |
#au_becs_debit ⇒ Object
Stripe users in Australia can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with an Australian bank account. Check this [page](stripe.com/docs/payments/au-becs-debit) for more details.
2516 2517 2518 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2516 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object
Stripe users in the UK can accept Bacs Direct Debit payments from customers with a UK bank account, check this [page](stripe.com/docs/payments/payment-methods/bacs-debit) for more details.
2518 2519 2520 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2518 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object
Bancontact is the most popular online payment method in Belgium, with over 15 million cards in circulation. [Customers](stripe.com/docs/api/customers) use a Bancontact card or mobile app linked to a Belgian bank account to make online payments that are secure, guaranteed, and confirmed immediately. Check this [page](stripe.com/docs/payments/bancontact) for more details.
2520 2521 2522 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2520 def bancontact @bancontact end |
#billie ⇒ Object
Billie is a [single-use](docs.stripe.com/payments/payment-methods#usage) payment method that offers businesses Pay by Invoice where they offer payment terms ranging from 7-120 days. Customers are redirected from your website or app, authorize the payment with Billie, then return to your website or app. You get [immediate notification](/payments/payment-methods#payment-notification) of whether the payment succeeded or failed.
2522 2523 2524 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2522 def billie @billie end |
#blik ⇒ Object
BLIK is a [single use](stripe.com/docs/payments/payment-methods#usage) payment method that requires customers to authenticate their payments. When customers want to pay online using BLIK, they request a six-digit code from their banking application and enter it into the payment collection form. Check this [page](stripe.com/docs/payments/blik) for more details.
2524 2525 2526 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2524 def blik @blik end |
#boleto ⇒ Object
Boleto is an official (regulated by the Central Bank of Brazil) payment method in Brazil. Check this [page](stripe.com/docs/payments/boleto) for more details.
2526 2527 2528 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2526 def boleto @boleto end |
#card ⇒ Object
Cards are a popular way for consumers and businesses to pay online or in person. Stripe supports global and local card networks.
2528 2529 2530 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2528 def card @card end |
#cartes_bancaires ⇒ Object
Cartes Bancaires is France’s local card network. More than 95% of these cards are co-branded with either Visa or Mastercard, meaning you can process these cards over either Cartes Bancaires or the Visa or Mastercard networks. Check this [page](stripe.com/docs/payments/cartes-bancaires) for more details.
2530 2531 2532 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2530 def cartes_bancaires @cartes_bancaires end |
#cashapp ⇒ Object
Cash App is a popular consumer app in the US that allows customers to bank, invest, send, and receive money using their digital wallet. Check this [page](stripe.com/docs/payments/cash-app-pay) for more details.
2532 2533 2534 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2532 def cashapp @cashapp end |
#customer_balance ⇒ Object
Uses a customer’s [cash balance](stripe.com/docs/payments/customer-balance) for the payment. The cash balance can be funded via a bank transfer. Check this [page](stripe.com/docs/payments/bank-transfers) for more details.
2534 2535 2536 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2534 def customer_balance @customer_balance end |
#eps ⇒ Object
EPS is an Austria-based payment method that allows customers to complete transactions online using their bank credentials. EPS is supported by all Austrian banks and is accepted by over 80% of Austrian online retailers. Check this [page](stripe.com/docs/payments/eps) for more details.
2536 2537 2538 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2536 def eps @eps end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2538 2539 2540 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2538 def @expand end |
#fpx ⇒ Object
Financial Process Exchange (FPX) is a Malaysia-based payment method that allows customers to complete transactions online using their bank credentials. Bank Negara Malaysia (BNM), the Central Bank of Malaysia, and eleven other major Malaysian financial institutions are members of the PayNet Group, which owns and operates FPX. It is one of the most popular online payment methods in Malaysia, with nearly 90 million transactions in 2018 according to BNM. Check this [page](stripe.com/docs/payments/fpx) for more details.
2540 2541 2542 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2540 def fpx @fpx end |
#giropay ⇒ Object
giropay is a German payment method based on online banking, introduced in 2006. It allows customers to complete transactions online using their online banking environment, with funds debited from their bank account. Depending on their bank, customers confirm payments on giropay using a second factor of authentication or a PIN. giropay accounts for 10% of online checkouts in Germany. Check this [page](stripe.com/docs/payments/giropay) for more details.
2542 2543 2544 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2542 def giropay @giropay end |
#google_pay ⇒ Object
Google Pay allows customers to make payments in your app or website using any credit or debit card saved to their Google Account, including those from Google Play, YouTube, Chrome, or an Android device. Use the Google Pay API to request any credit or debit card stored in your customer’s Google account. Check this [page](stripe.com/docs/google-pay) for more details.
2544 2545 2546 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2544 def google_pay @google_pay end |
#grabpay ⇒ Object
GrabPay is a payment method developed by [Grab](www.grab.com/sg/consumer/finance/pay/). GrabPay is a digital wallet - customers maintain a balance in their wallets that they pay out with. Check this [page](stripe.com/docs/payments/grabpay) for more details.
2546 2547 2548 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2546 def grabpay @grabpay end |
#ideal ⇒ Object
iDEAL is a Netherlands-based payment method that allows customers to complete transactions online using their bank credentials. All major Dutch banks are members of Currence, the scheme that operates iDEAL, making it the most popular online payment method in the Netherlands with a share of online transactions close to 55%. Check this [page](stripe.com/docs/payments/ideal) for more details.
2548 2549 2550 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2548 def ideal @ideal end |
#jcb ⇒ Object
JCB is a credit card company based in Japan. JCB is currently available in Japan to businesses approved by JCB, and available to all businesses in Australia, Canada, Hong Kong, Japan, New Zealand, Singapore, Switzerland, United Kingdom, United States, and all countries in the European Economic Area except Iceland. Check this [page](support.stripe.com/questions/accepting-japan-credit-bureau-%28jcb%29-payments) for more details.
2550 2551 2552 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2550 def jcb @jcb end |
#klarna ⇒ Object
Klarna gives customers a range of [payment options](stripe.com/docs/payments/klarna#payment-options) during checkout. Available payment options vary depending on the customer’s billing address and the transaction amount. These payment options make it convenient for customers to purchase items in all price ranges. Check this [page](stripe.com/docs/payments/klarna) for more details.
2552 2553 2554 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2552 def klarna @klarna end |
#konbini ⇒ Object
Konbini allows customers in Japan to pay for bills and online purchases at convenience stores with cash. Check this [page](stripe.com/docs/payments/konbini) for more details.
2554 2555 2556 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2554 def konbini @konbini end |
#link ⇒ Object
[Link](stripe.com/docs/payments/link) is a payment method network. With Link, users save their payment details once, then reuse that information to pay with one click for any business on the network.
2556 2557 2558 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2556 def link @link end |
#mobilepay ⇒ Object
MobilePay is a [single-use](stripe.com/docs/payments/payment-methods#usage) card wallet payment method used in Denmark and Finland. It allows customers to [authenticate and approve](stripe.com/docs/payments/payment-methods#customer-actions) payments using the MobilePay app. Check this [page](stripe.com/docs/payments/mobilepay) for more details.
2558 2559 2560 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2558 def mobilepay @mobilepay end |
#multibanco ⇒ Object
Stripe users in Europe and the United States can accept Multibanco payments from customers in Portugal using [Sources](stripe.com/docs/sources)—a single integration path for creating payments using any supported method.
2560 2561 2562 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2560 def multibanco @multibanco end |
#name ⇒ Object
Configuration name.
2562 2563 2564 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2562 def name @name end |
#nz_bank_account ⇒ Object
Stripe users in New Zealand can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with a New Zeland bank account. Check this [page](stripe.com/docs/payments/nz-bank-account) for more details.
2564 2565 2566 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2564 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object
OXXO is a Mexican chain of convenience stores with thousands of locations across Latin America and represents nearly 20% of online transactions in Mexico. OXXO allows customers to pay bills and online purchases in-store with cash. Check this [page](stripe.com/docs/payments/oxxo) for more details.
2566 2567 2568 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2566 def oxxo @oxxo end |
#p24 ⇒ Object
Przelewy24 is a Poland-based payment method aggregator that allows customers to complete transactions online using bank transfers and other methods. Bank transfers account for 30% of online payments in Poland and Przelewy24 provides a way for customers to pay with over 165 banks. Check this [page](stripe.com/docs/payments/p24) for more details.
2568 2569 2570 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2568 def p24 @p24 end |
#pay_by_bank ⇒ Object
Pay by bank is a redirect payment method backed by bank transfers. A customer is redirected to their bank to authorize a bank transfer for a given amount. This removes a lot of the error risks inherent in waiting for the customer to initiate a transfer themselves, and is less expensive than card payments.
2570 2571 2572 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2570 def pay_by_bank @pay_by_bank end |
#paynow ⇒ Object
PayNow is a Singapore-based payment method that allows customers to make a payment using their preferred app from participating banks and participating non-bank financial institutions. Check this [page](stripe.com/docs/payments/paynow) for more details.
2572 2573 2574 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2572 def paynow @paynow end |
#paypal ⇒ Object
PayPal, a digital wallet popular with customers in Europe, allows your customers worldwide to pay using their PayPal account. Check this [page](stripe.com/docs/payments/paypal) for more details.
2574 2575 2576 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2574 def paypal @paypal end |
#promptpay ⇒ Object
PromptPay is a Thailand-based payment method that allows customers to make a payment using their preferred app from participating banks. Check this [page](stripe.com/docs/payments/promptpay) for more details.
2576 2577 2578 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2576 def promptpay @promptpay end |
#revolut_pay ⇒ Object
Revolut Pay, developed by Revolut, a global finance app, is a digital wallet payment method. Revolut Pay uses the customer’s stored balance or cards to fund the payment, and offers the option for non-Revolut customers to save their details after their first purchase.
2578 2579 2580 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2578 def revolut_pay @revolut_pay end |
#satispay ⇒ Object
Satispay is a [single-use](docs.stripe.com/payments/payment-methods#usage) payment method where customers are required to [authenticate](/payments/payment-methods#customer-actions) their payment. Customers pay by being redirected from your website or app, authorizing the payment with Satispay, then returning to your website or app. You get [immediate notification](/payments/payment-methods#payment-notification) of whether the payment succeeded or failed.
2580 2581 2582 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2580 def satispay @satispay end |
#sepa_debit ⇒ Object
The [Single Euro Payments Area (SEPA)](en.wikipedia.org/wiki/Single_Euro_Payments_Area) is an initiative of the European Union to simplify payments within and across member countries. SEPA established and enforced banking standards to allow for the direct debiting of every EUR-denominated bank account within the SEPA region, check this [page](stripe.com/docs/payments/sepa-debit) for more details.
2582 2583 2584 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2582 def sepa_debit @sepa_debit end |
#sofort ⇒ Object
Stripe users in Europe and the United States can use the [Payment Intents API](stripe.com/docs/payments/payment-intents)—a single integration path for creating payments using any supported method—to accept [Sofort](www.sofort.com/) payments from customers. Check this [page](stripe.com/docs/payments/sofort) for more details.
2584 2585 2586 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2584 def sofort @sofort end |
#swish ⇒ Object
Swish is a [real-time](stripe.com/docs/payments/real-time) payment method popular in Sweden. It allows customers to [authenticate and approve](stripe.com/docs/payments/payment-methods#customer-actions) payments using the Swish mobile app and the Swedish BankID mobile app. Check this [page](stripe.com/docs/payments/swish) for more details.
2586 2587 2588 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2586 def swish @swish end |
#twint ⇒ Object
Twint is a payment method popular in Switzerland. It allows customers to pay using their mobile phone. Check this [page](docs.stripe.com/payments/twint) for more details.
2588 2589 2590 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2588 def twint @twint end |
#us_bank_account ⇒ Object
Stripe users in the United States can accept ACH direct debit payments from customers with a US bank account using the Automated Clearing House (ACH) payments system operated by Nacha. Check this [page](stripe.com/docs/payments/ach-direct-debit) for more details.
2590 2591 2592 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2590 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
WeChat, owned by Tencent, is China’s leading mobile app with over 1 billion monthly active users. Chinese consumers can use WeChat Pay to pay for goods and services inside of businesses’ apps and websites. WeChat Pay users buy most frequently in gaming, e-commerce, travel, online education, and food/nutrition. Check this [page](stripe.com/docs/payments/wechat-pay) for more details.
2592 2593 2594 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2592 def wechat_pay @wechat_pay end |
#zip ⇒ Object
Zip gives your customers a way to split purchases over a series of payments. Check this [page](stripe.com/docs/payments/zip) for more details like country availability.
2594 2595 2596 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2594 def zip @zip end |