Class: Stripe::PaymentMethodConfiguration::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfiguration::UpdateParams
- Defined in:
- lib/stripe/resources/payment_method_configuration.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, ApplePay, ApplePayLater, AuBecsDebit, BacsDebit, Bancontact, Blik, Boleto, Card, CartesBancaires, Cashapp, CustomerBalance, Eps, Fpx, Giropay, GooglePay, Gopay, Grabpay, IdBankTransfer, Ideal, Jcb, Klarna, Konbini, Link, Mobilepay, Multibanco, Oxxo, P24, Paynow, Paypal, Payto, Promptpay, Qris, RevolutPay, SepaDebit, Shopeepay, Sofort, Swish, Twint, UsBankAccount, WechatPay, Zip
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
Canadian pre-authorized debit payments, check this [page](stripe.com/docs/payments/acss-debit) for more details like country availability.
-
#active ⇒ Object
Whether the configuration can be used for new payments.
-
#affirm ⇒ Object
[Affirm](www.affirm.com/) gives your customers a way to split purchases over a series of payments.
-
#afterpay_clearpay ⇒ Object
Afterpay gives your customers a way to pay for purchases in installments, check this [page](stripe.com/docs/payments/afterpay-clearpay) for more details like country availability.
-
#alipay ⇒ Object
Alipay is a digital wallet in China that has more than a billion active users worldwide.
-
#alma ⇒ Object
Alma is a Buy Now, Pay Later payment method that offers customers the ability to pay in 2, 3, or 4 installments.
-
#amazon_pay ⇒ Object
Amazon Pay is a wallet payment method that lets your customers check out the same way as on Amazon.
-
#apple_pay ⇒ Object
Stripe users can accept [Apple Pay](/payments/apple-pay) in iOS applications in iOS 9 and later, and on the web in Safari starting with iOS 10 or macOS Sierra.
-
#apple_pay_later ⇒ Object
Apple Pay Later, a payment method for customers to buy now and pay later, gives your customers a way to split purchases into four installments across six weeks.
-
#au_becs_debit ⇒ Object
Stripe users in Australia can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with an Australian bank account.
-
#bacs_debit ⇒ Object
Stripe users in the UK can accept Bacs Direct Debit payments from customers with a UK bank account, check this [page](stripe.com/docs/payments/payment-methods/bacs-debit) for more details.
-
#bancontact ⇒ Object
Bancontact is the most popular online payment method in Belgium, with over 15 million cards in circulation.
-
#blik ⇒ Object
BLIK is a [single use](stripe.com/docs/payments/payment-methods#usage) payment method that requires customers to authenticate their payments.
-
#boleto ⇒ Object
Boleto is an official (regulated by the Central Bank of Brazil) payment method in Brazil.
-
#card ⇒ Object
Cards are a popular way for consumers and businesses to pay online or in person.
-
#cartes_bancaires ⇒ Object
Cartes Bancaires is France’s local card network.
-
#cashapp ⇒ Object
Cash App is a popular consumer app in the US that allows customers to bank, invest, send, and receive money using their digital wallet.
-
#customer_balance ⇒ Object
Uses a customer’s [cash balance](stripe.com/docs/payments/customer-balance) for the payment.
-
#eps ⇒ Object
EPS is an Austria-based payment method that allows customers to complete transactions online using their bank credentials.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fpx ⇒ Object
Financial Process Exchange (FPX) is a Malaysia-based payment method that allows customers to complete transactions online using their bank credentials.
-
#giropay ⇒ Object
giropay is a German payment method based on online banking, introduced in 2006.
-
#google_pay ⇒ Object
Google Pay allows customers to make payments in your app or website using any credit or debit card saved to their Google Account, including those from Google Play, YouTube, Chrome, or an Android device.
-
#gopay ⇒ Object
GoPay is a [single use](stripe.com/docs/payments/payment-methods#usage) digital wallet payment method popular in Indonesia.
-
#grabpay ⇒ Object
GrabPay is a payment method developed by [Grab](www.grab.com/sg/consumer/finance/pay/).
-
#id_bank_transfer ⇒ Object
Stripe users in Indonesia can receive bank transfers from customers in Indonesia.
-
#ideal ⇒ Object
iDEAL is a Netherlands-based payment method that allows customers to complete transactions online using their bank credentials.
-
#jcb ⇒ Object
JCB is a credit card company based in Japan.
-
#klarna ⇒ Object
Klarna gives customers a range of [payment options](stripe.com/docs/payments/klarna#payment-options) during checkout.
-
#konbini ⇒ Object
Konbini allows customers in Japan to pay for bills and online purchases at convenience stores with cash.
-
#link ⇒ Object
[Link](stripe.com/docs/payments/link) is a payment method network.
-
#mobilepay ⇒ Object
MobilePay is a [single-use](stripe.com/docs/payments/payment-methods#usage) card wallet payment method used in Denmark and Finland.
-
#multibanco ⇒ Object
Stripe users in Europe and the United States can accept Multibanco payments from customers in Portugal using [Sources](stripe.com/docs/sources)—a single integration path for creating payments using any supported method.
-
#name ⇒ Object
Configuration name.
-
#oxxo ⇒ Object
OXXO is a Mexican chain of convenience stores with thousands of locations across Latin America and represents nearly 20% of online transactions in Mexico.
-
#p24 ⇒ Object
Przelewy24 is a Poland-based payment method aggregator that allows customers to complete transactions online using bank transfers and other methods.
-
#paynow ⇒ Object
PayNow is a Singapore-based payment method that allows customers to make a payment using their preferred app from participating banks and participating non-bank financial institutions.
-
#paypal ⇒ Object
PayPal, a digital wallet popular with customers in Europe, allows your customers worldwide to pay using their PayPal account.
-
#payto ⇒ Object
PayTo is a [real-time](docs.stripe.com/payments/real-time) payment method that enables customers in Australia to pay by providing their bank account details.
-
#promptpay ⇒ Object
PromptPay is a Thailand-based payment method that allows customers to make a payment using their preferred app from participating banks.
-
#qris ⇒ Object
QRIS is a [real-time](docs.stripe.com/payments/real-time) payment method popular in Indonesia.
-
#revolut_pay ⇒ Object
Revolut Pay, developed by Revolut, a global finance app, is a digital wallet payment method.
-
#sepa_debit ⇒ Object
The [Single Euro Payments Area (SEPA)](en.wikipedia.org/wiki/Single_Euro_Payments_Area) is an initiative of the European Union to simplify payments within and across member countries.
-
#shopeepay ⇒ Object
ShopeePay is a [single use](stripe.com/docs/payments/payment-methods#usage) digital wallet payment method popular in Indonesia.
-
#sofort ⇒ Object
Stripe users in Europe and the United States can use the [Payment Intents API](stripe.com/docs/payments/payment-intents)—a single integration path for creating payments using any supported method—to accept [Sofort](www.sofort.com/) payments from customers.
-
#swish ⇒ Object
Swish is a [real-time](stripe.com/docs/payments/real-time) payment method popular in Sweden.
-
#twint ⇒ Object
Twint is a payment method popular in Switzerland.
-
#us_bank_account ⇒ Object
Stripe users in the United States can accept ACH direct debit payments from customers with a US bank account using the Automated Clearing House (ACH) payments system operated by Nacha.
-
#wechat_pay ⇒ Object
WeChat, owned by Tencent, is China’s leading mobile app with over 1 billion monthly active users.
-
#zip ⇒ Object
Zip gives your customers a way to split purchases over a series of payments.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, active: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, apple_pay: nil, apple_pay_later: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, blik: nil, boleto: nil, card: nil, cartes_bancaires: nil, cashapp: nil, customer_balance: nil, eps: nil, expand: nil, fpx: nil, giropay: nil, google_pay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, jcb: nil, klarna: nil, konbini: nil, link: nil, mobilepay: nil, multibanco: nil, name: nil, oxxo: nil, p24: nil, paynow: nil, paypal: nil, payto: nil, promptpay: nil, qris: nil, revolut_pay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2900 def initialize( acss_debit: nil, active: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, apple_pay: nil, apple_pay_later: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, blik: nil, boleto: nil, card: nil, cartes_bancaires: nil, cashapp: nil, customer_balance: nil, eps: nil, expand: nil, fpx: nil, giropay: nil, google_pay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, jcb: nil, klarna: nil, konbini: nil, link: nil, mobilepay: nil, multibanco: nil, name: nil, oxxo: nil, p24: nil, paynow: nil, paypal: nil, payto: nil, promptpay: nil, qris: nil, revolut_pay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil ) @acss_debit = acss_debit @active = active @affirm = affirm @afterpay_clearpay = afterpay_clearpay @alipay = alipay @alma = alma @amazon_pay = amazon_pay @apple_pay = apple_pay @apple_pay_later = apple_pay_later @au_becs_debit = au_becs_debit @bacs_debit = bacs_debit @bancontact = bancontact @blik = blik @boleto = boleto @card = card @cartes_bancaires = cartes_bancaires @cashapp = cashapp @customer_balance = customer_balance @eps = eps @expand = @fpx = fpx @giropay = giropay @google_pay = google_pay @gopay = gopay @grabpay = grabpay @id_bank_transfer = id_bank_transfer @ideal = ideal @jcb = jcb @klarna = klarna @konbini = konbini @link = link @mobilepay = mobilepay @multibanco = multibanco @name = name @oxxo = oxxo @p24 = p24 @paynow = paynow @paypal = paypal @payto = payto @promptpay = promptpay @qris = qris @revolut_pay = revolut_pay @sepa_debit = sepa_debit @shopeepay = shopeepay @sofort = sofort @swish = swish @twint = twint @us_bank_account = us_bank_account @wechat_pay = wechat_pay @zip = zip end |
Instance Attribute Details
#acss_debit ⇒ Object
Canadian pre-authorized debit payments, check this [page](stripe.com/docs/payments/acss-debit) for more details like country availability.
2751 2752 2753 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2751 def acss_debit @acss_debit end |
#active ⇒ Object
Whether the configuration can be used for new payments.
2754 2755 2756 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2754 def active @active end |
#affirm ⇒ Object
[Affirm](www.affirm.com/) gives your customers a way to split purchases over a series of payments. Depending on the purchase, they can pay with four interest-free payments (Split Pay) or pay over a longer term (Installments), which might include interest. Check this [page](stripe.com/docs/payments/affirm) for more details like country availability.
2757 2758 2759 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2757 def affirm @affirm end |
#afterpay_clearpay ⇒ Object
Afterpay gives your customers a way to pay for purchases in installments, check this [page](stripe.com/docs/payments/afterpay-clearpay) for more details like country availability. Afterpay is particularly popular among businesses selling fashion, beauty, and sports products.
2760 2761 2762 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2760 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
Alipay is a digital wallet in China that has more than a billion active users worldwide. Alipay users can pay on the web or on a mobile device using login credentials or their Alipay app. Alipay has a low dispute rate and reduces fraud by authenticating payments using the customer’s login credentials. Check this [page](stripe.com/docs/payments/alipay) for more details.
2763 2764 2765 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2763 def alipay @alipay end |
#alma ⇒ Object
Alma is a Buy Now, Pay Later payment method that offers customers the ability to pay in 2, 3, or 4 installments.
2766 2767 2768 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2766 def alma @alma end |
#amazon_pay ⇒ Object
Amazon Pay is a wallet payment method that lets your customers check out the same way as on Amazon.
2769 2770 2771 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2769 def amazon_pay @amazon_pay end |
#apple_pay ⇒ Object
Stripe users can accept [Apple Pay](/payments/apple-pay) in iOS applications in iOS 9 and later, and on the web in Safari starting with iOS 10 or macOS Sierra. There are no additional fees to process Apple Pay payments, and the [pricing](/pricing) is the same as other card transactions. Check this [page](stripe.com/docs/apple-pay) for more details.
2772 2773 2774 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2772 def apple_pay @apple_pay end |
#apple_pay_later ⇒ Object
Apple Pay Later, a payment method for customers to buy now and pay later, gives your customers a way to split purchases into four installments across six weeks.
2775 2776 2777 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2775 def apple_pay_later @apple_pay_later end |
#au_becs_debit ⇒ Object
Stripe users in Australia can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with an Australian bank account. Check this [page](stripe.com/docs/payments/au-becs-debit) for more details.
2778 2779 2780 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2778 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object
Stripe users in the UK can accept Bacs Direct Debit payments from customers with a UK bank account, check this [page](stripe.com/docs/payments/payment-methods/bacs-debit) for more details.
2781 2782 2783 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2781 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object
Bancontact is the most popular online payment method in Belgium, with over 15 million cards in circulation. [Customers](stripe.com/docs/api/customers) use a Bancontact card or mobile app linked to a Belgian bank account to make online payments that are secure, guaranteed, and confirmed immediately. Check this [page](stripe.com/docs/payments/bancontact) for more details.
2784 2785 2786 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2784 def bancontact @bancontact end |
#blik ⇒ Object
BLIK is a [single use](stripe.com/docs/payments/payment-methods#usage) payment method that requires customers to authenticate their payments. When customers want to pay online using BLIK, they request a six-digit code from their banking application and enter it into the payment collection form. Check this [page](stripe.com/docs/payments/blik) for more details.
2787 2788 2789 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2787 def blik @blik end |
#boleto ⇒ Object
Boleto is an official (regulated by the Central Bank of Brazil) payment method in Brazil. Check this [page](stripe.com/docs/payments/boleto) for more details.
2790 2791 2792 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2790 def boleto @boleto end |
#card ⇒ Object
Cards are a popular way for consumers and businesses to pay online or in person. Stripe supports global and local card networks.
2793 2794 2795 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2793 def card @card end |
#cartes_bancaires ⇒ Object
Cartes Bancaires is France’s local card network. More than 95% of these cards are co-branded with either Visa or Mastercard, meaning you can process these cards over either Cartes Bancaires or the Visa or Mastercard networks. Check this [page](stripe.com/docs/payments/cartes-bancaires) for more details.
2796 2797 2798 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2796 def cartes_bancaires @cartes_bancaires end |
#cashapp ⇒ Object
Cash App is a popular consumer app in the US that allows customers to bank, invest, send, and receive money using their digital wallet. Check this [page](stripe.com/docs/payments/cash-app-pay) for more details.
2799 2800 2801 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2799 def cashapp @cashapp end |
#customer_balance ⇒ Object
Uses a customer’s [cash balance](stripe.com/docs/payments/customer-balance) for the payment. The cash balance can be funded via a bank transfer. Check this [page](stripe.com/docs/payments/bank-transfers) for more details.
2802 2803 2804 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2802 def customer_balance @customer_balance end |
#eps ⇒ Object
EPS is an Austria-based payment method that allows customers to complete transactions online using their bank credentials. EPS is supported by all Austrian banks and is accepted by over 80% of Austrian online retailers. Check this [page](stripe.com/docs/payments/eps) for more details.
2805 2806 2807 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2805 def eps @eps end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2808 2809 2810 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2808 def @expand end |
#fpx ⇒ Object
Financial Process Exchange (FPX) is a Malaysia-based payment method that allows customers to complete transactions online using their bank credentials. Bank Negara Malaysia (BNM), the Central Bank of Malaysia, and eleven other major Malaysian financial institutions are members of the PayNet Group, which owns and operates FPX. It is one of the most popular online payment methods in Malaysia, with nearly 90 million transactions in 2018 according to BNM. Check this [page](stripe.com/docs/payments/fpx) for more details.
2811 2812 2813 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2811 def fpx @fpx end |
#giropay ⇒ Object
giropay is a German payment method based on online banking, introduced in 2006. It allows customers to complete transactions online using their online banking environment, with funds debited from their bank account. Depending on their bank, customers confirm payments on giropay using a second factor of authentication or a PIN. giropay accounts for 10% of online checkouts in Germany. Check this [page](stripe.com/docs/payments/giropay) for more details.
2814 2815 2816 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2814 def giropay @giropay end |
#google_pay ⇒ Object
Google Pay allows customers to make payments in your app or website using any credit or debit card saved to their Google Account, including those from Google Play, YouTube, Chrome, or an Android device. Use the Google Pay API to request any credit or debit card stored in your customer’s Google account. Check this [page](stripe.com/docs/google-pay) for more details.
2817 2818 2819 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2817 def google_pay @google_pay end |
#gopay ⇒ Object
GoPay is a [single use](stripe.com/docs/payments/payment-methods#usage) digital wallet payment method popular in Indonesia. When paying with GoPay, customers authenticate and approve payments using the Gojek app. Desktop checkout is performed by scanning a QR code. When checking out on mobile, customers are redirected to the Gojek app to confirm payment.
2820 2821 2822 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2820 def gopay @gopay end |
#grabpay ⇒ Object
GrabPay is a payment method developed by [Grab](www.grab.com/sg/consumer/finance/pay/). GrabPay is a digital wallet - customers maintain a balance in their wallets that they pay out with. Check this [page](stripe.com/docs/payments/grabpay) for more details.
2823 2824 2825 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2823 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object
Stripe users in Indonesia can receive bank transfers from customers in Indonesia. Bank transfers are a popular B2C and B2B payment method in Indonesia.
2826 2827 2828 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2826 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object
iDEAL is a Netherlands-based payment method that allows customers to complete transactions online using their bank credentials. All major Dutch banks are members of Currence, the scheme that operates iDEAL, making it the most popular online payment method in the Netherlands with a share of online transactions close to 55%. Check this [page](stripe.com/docs/payments/ideal) for more details.
2829 2830 2831 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2829 def ideal @ideal end |
#jcb ⇒ Object
JCB is a credit card company based in Japan. JCB is currently available in Japan to businesses approved by JCB, and available to all businesses in Australia, Canada, Hong Kong, Japan, New Zealand, Singapore, Switzerland, United Kingdom, United States, and all countries in the European Economic Area except Iceland. Check this [page](support.stripe.com/questions/accepting-japan-credit-bureau-%28jcb%29-payments) for more details.
2832 2833 2834 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2832 def jcb @jcb end |
#klarna ⇒ Object
Klarna gives customers a range of [payment options](stripe.com/docs/payments/klarna#payment-options) during checkout. Available payment options vary depending on the customer’s billing address and the transaction amount. These payment options make it convenient for customers to purchase items in all price ranges. Check this [page](stripe.com/docs/payments/klarna) for more details.
2835 2836 2837 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2835 def klarna @klarna end |
#konbini ⇒ Object
Konbini allows customers in Japan to pay for bills and online purchases at convenience stores with cash. Check this [page](stripe.com/docs/payments/konbini) for more details.
2838 2839 2840 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2838 def konbini @konbini end |
#link ⇒ Object
[Link](stripe.com/docs/payments/link) is a payment method network. With Link, users save their payment details once, then reuse that information to pay with one click for any business on the network.
2841 2842 2843 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2841 def link @link end |
#mobilepay ⇒ Object
MobilePay is a [single-use](stripe.com/docs/payments/payment-methods#usage) card wallet payment method used in Denmark and Finland. It allows customers to [authenticate and approve](stripe.com/docs/payments/payment-methods#customer-actions) payments using the MobilePay app. Check this [page](stripe.com/docs/payments/mobilepay) for more details.
2844 2845 2846 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2844 def mobilepay @mobilepay end |
#multibanco ⇒ Object
Stripe users in Europe and the United States can accept Multibanco payments from customers in Portugal using [Sources](stripe.com/docs/sources)—a single integration path for creating payments using any supported method.
2847 2848 2849 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2847 def multibanco @multibanco end |
#name ⇒ Object
Configuration name.
2850 2851 2852 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2850 def name @name end |
#oxxo ⇒ Object
OXXO is a Mexican chain of convenience stores with thousands of locations across Latin America and represents nearly 20% of online transactions in Mexico. OXXO allows customers to pay bills and online purchases in-store with cash. Check this [page](stripe.com/docs/payments/oxxo) for more details.
2853 2854 2855 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2853 def oxxo @oxxo end |
#p24 ⇒ Object
Przelewy24 is a Poland-based payment method aggregator that allows customers to complete transactions online using bank transfers and other methods. Bank transfers account for 30% of online payments in Poland and Przelewy24 provides a way for customers to pay with over 165 banks. Check this [page](stripe.com/docs/payments/p24) for more details.
2856 2857 2858 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2856 def p24 @p24 end |
#paynow ⇒ Object
PayNow is a Singapore-based payment method that allows customers to make a payment using their preferred app from participating banks and participating non-bank financial institutions. Check this [page](stripe.com/docs/payments/paynow) for more details.
2859 2860 2861 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2859 def paynow @paynow end |
#paypal ⇒ Object
PayPal, a digital wallet popular with customers in Europe, allows your customers worldwide to pay using their PayPal account. Check this [page](stripe.com/docs/payments/paypal) for more details.
2862 2863 2864 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2862 def paypal @paypal end |
#payto ⇒ Object
PayTo is a [real-time](docs.stripe.com/payments/real-time) payment method that enables customers in Australia to pay by providing their bank account details. Customers must accept a mandate authorizing you to debit their account. Check this [page](docs.stripe.com/payments/payto) for more details.
2865 2866 2867 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2865 def payto @payto end |
#promptpay ⇒ Object
PromptPay is a Thailand-based payment method that allows customers to make a payment using their preferred app from participating banks. Check this [page](stripe.com/docs/payments/promptpay) for more details.
2868 2869 2870 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2868 def promptpay @promptpay end |
#qris ⇒ Object
QRIS is a [real-time](docs.stripe.com/payments/real-time) payment method popular in Indonesia. When paying with QRIS, customers authenticate and approve payments by scanning a QR code in their preferred digital wallet app.
2871 2872 2873 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2871 def qris @qris end |
#revolut_pay ⇒ Object
Revolut Pay, developed by Revolut, a global finance app, is a digital wallet payment method. Revolut Pay uses the customer’s stored balance or cards to fund the payment, and offers the option for non-Revolut customers to save their details after their first purchase.
2874 2875 2876 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2874 def revolut_pay @revolut_pay end |
#sepa_debit ⇒ Object
The [Single Euro Payments Area (SEPA)](en.wikipedia.org/wiki/Single_Euro_Payments_Area) is an initiative of the European Union to simplify payments within and across member countries. SEPA established and enforced banking standards to allow for the direct debiting of every EUR-denominated bank account within the SEPA region, check this [page](stripe.com/docs/payments/sepa-debit) for more details.
2877 2878 2879 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2877 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object
ShopeePay is a [single use](stripe.com/docs/payments/payment-methods#usage) digital wallet payment method popular in Indonesia. When paying with GoPay, customers authenticate and approve payments using the Shopee app. Desktop checkout is performed by scanning a QR code. When checking out on mobile, customers are redirected to the Shopee app to confirm payment.
2880 2881 2882 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2880 def shopeepay @shopeepay end |
#sofort ⇒ Object
Stripe users in Europe and the United States can use the [Payment Intents API](stripe.com/docs/payments/payment-intents)—a single integration path for creating payments using any supported method—to accept [Sofort](www.sofort.com/) payments from customers. Check this [page](stripe.com/docs/payments/sofort) for more details.
2883 2884 2885 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2883 def sofort @sofort end |
#swish ⇒ Object
Swish is a [real-time](stripe.com/docs/payments/real-time) payment method popular in Sweden. It allows customers to [authenticate and approve](stripe.com/docs/payments/payment-methods#customer-actions) payments using the Swish mobile app and the Swedish BankID mobile app. Check this [page](stripe.com/docs/payments/swish) for more details.
2886 2887 2888 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2886 def swish @swish end |
#twint ⇒ Object
Twint is a payment method popular in Switzerland. It allows customers to pay using their mobile phone. Check this [page](docs.stripe.com/payments/twint) for more details.
2889 2890 2891 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2889 def twint @twint end |
#us_bank_account ⇒ Object
Stripe users in the United States can accept ACH direct debit payments from customers with a US bank account using the Automated Clearing House (ACH) payments system operated by Nacha. Check this [page](stripe.com/docs/payments/ach-direct-debit) for more details.
2892 2893 2894 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2892 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
WeChat, owned by Tencent, is China’s leading mobile app with over 1 billion monthly active users. Chinese consumers can use WeChat Pay to pay for goods and services inside of businesses’ apps and websites. WeChat Pay users buy most frequently in gaming, e-commerce, travel, online education, and food/nutrition. Check this [page](stripe.com/docs/payments/wechat-pay) for more details.
2895 2896 2897 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2895 def wechat_pay @wechat_pay end |
#zip ⇒ Object
Zip gives your customers a way to split purchases over a series of payments. Check this [page](stripe.com/docs/payments/zip) for more details like country availability.
2898 2899 2900 |
# File 'lib/stripe/resources/payment_method_configuration.rb', line 2898 def zip @zip end |