Class: Stripe::PaymentMethodConfigurationCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_method_configuration_create_params.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, ApplePay, ApplePayLater, AuBecsDebit, BacsDebit, Bancontact, Billie, Bizum, Blik, Boleto, Card, CartesBancaires, Cashapp, Crypto, CustomerBalance, Eps, Fpx, FrMealVoucherConecs, Giropay, GooglePay, Grabpay, Ideal, Jcb, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, RevolutPay, SamsungPay, Satispay, Scalapay, SepaDebit, Sofort, Sunbit, Swish, Twint, Upi, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, apple_pay: nil, apple_pay_later: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, bizum: nil, blik: nil, boleto: nil, card: nil, cartes_bancaires: nil, cashapp: nil, crypto: nil, customer_balance: nil, eps: nil, expand: nil, fpx: nil, fr_meal_voucher_conecs: nil, giropay: nil, google_pay: nil, grabpay: nil, ideal: nil, jcb: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, mobilepay: nil, multibanco: nil, name: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, parent: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, scalapay: nil, sepa_debit: nil, sofort: nil, sunbit: nil, swish: nil, twint: nil, upi: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodConfigurationCreateParams

Returns a new instance of PaymentMethodConfigurationCreateParams.



1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1152

def initialize(
  acss_debit: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  alma: nil,
  amazon_pay: nil,
  apple_pay: nil,
  apple_pay_later: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  billie: nil,
  bizum: nil,
  blik: nil,
  boleto: nil,
  card: nil,
  cartes_bancaires: nil,
  cashapp: nil,
  crypto: nil,
  customer_balance: nil,
  eps: nil,
  expand: nil,
  fpx: nil,
  fr_meal_voucher_conecs: nil,
  giropay: nil,
  google_pay: nil,
  grabpay: nil,
  ideal: nil,
  jcb: nil,
  kakao_pay: nil,
  klarna: nil,
  konbini: nil,
  kr_card: nil,
  link: nil,
  mb_way: nil,
  mobilepay: nil,
  multibanco: nil,
  name: nil,
  naver_pay: nil,
  nz_bank_account: nil,
  oxxo: nil,
  p24: nil,
  parent: nil,
  pay_by_bank: nil,
  payco: nil,
  paynow: nil,
  paypal: nil,
  payto: nil,
  pix: nil,
  promptpay: nil,
  revolut_pay: nil,
  samsung_pay: nil,
  satispay: nil,
  scalapay: nil,
  sepa_debit: nil,
  sofort: nil,
  sunbit: nil,
  swish: nil,
  twint: nil,
  upi: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @alma = alma
  @amazon_pay = amazon_pay
  @apple_pay = apple_pay
  @apple_pay_later = apple_pay_later
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @billie = billie
  @bizum = bizum
  @blik = blik
  @boleto = boleto
  @card = card
  @cartes_bancaires = cartes_bancaires
  @cashapp = cashapp
  @crypto = crypto
  @customer_balance = customer_balance
  @eps = eps
  @expand = expand
  @fpx = fpx
  @fr_meal_voucher_conecs = fr_meal_voucher_conecs
  @giropay = giropay
  @google_pay = google_pay
  @grabpay = grabpay
  @ideal = ideal
  @jcb = jcb
  @kakao_pay = kakao_pay
  @klarna = klarna
  @konbini = konbini
  @kr_card = kr_card
  @link = link
  @mb_way = mb_way
  @mobilepay = mobilepay
  @multibanco = multibanco
  @name = name
  @naver_pay = naver_pay
  @nz_bank_account = 
  @oxxo = oxxo
  @p24 = p24
  @parent = parent
  @pay_by_bank = pay_by_bank
  @payco = payco
  @paynow = paynow
  @paypal = paypal
  @payto = payto
  @pix = pix
  @promptpay = promptpay
  @revolut_pay = revolut_pay
  @samsung_pay = samsung_pay
  @satispay = satispay
  @scalapay = scalapay
  @sepa_debit = sepa_debit
  @sofort = sofort
  @sunbit = sunbit
  @swish = swish
  @twint = twint
  @upi = upi
  @us_bank_account = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

Canadian pre-authorized debit payments, check this [page](docs.stripe.com/payments/acss-debit) for more details like country availability.



1026
1027
1028
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1026

def acss_debit
  @acss_debit
end

#affirmObject

[Affirm](www.affirm.com/) gives your customers a way to split purchases over a series of payments. Depending on the purchase, they can pay with four interest-free payments (Split Pay) or pay over a longer term (Installments), which might include interest. Check this [page](docs.stripe.com/payments/affirm) for more details like country availability.



1028
1029
1030
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1028

def affirm
  @affirm
end

#afterpay_clearpayObject

Afterpay gives your customers a way to pay for purchases in installments, check this [page](docs.stripe.com/payments/afterpay-clearpay) for more details like country availability. Afterpay is particularly popular among businesses selling fashion, beauty, and sports products.



1030
1031
1032
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1030

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

Alipay is a digital wallet in China that has more than a billion active users worldwide. Alipay users can pay on the web or on a mobile device using login credentials or their Alipay app. Alipay has a low dispute rate and reduces fraud by authenticating payments using the customer’s login credentials. Check this [page](docs.stripe.com/payments/alipay) for more details.



1032
1033
1034
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1032

def alipay
  @alipay
end

#almaObject

Alma is a Buy Now, Pay Later payment method that offers customers the ability to pay in 2, 3, or 4 installments.



1034
1035
1036
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1034

def alma
  @alma
end

#amazon_payObject

Amazon Pay is a wallet payment method that lets your customers check out the same way as on Amazon.



1036
1037
1038
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1036

def amazon_pay
  @amazon_pay
end

#apple_payObject

Stripe users can accept [Apple Pay](stripe.com/payments/apple-pay) in iOS applications in iOS 9 and later, and on the web in Safari starting with iOS 10 or macOS Sierra. There are no additional fees to process Apple Pay payments, and the [pricing](stripe.com/pricing) is the same as other card transactions. Check this [page](docs.stripe.com/apple-pay) for more details.



1038
1039
1040
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1038

def apple_pay
  @apple_pay
end

#apple_pay_laterObject

Apple Pay Later, a payment method for customers to buy now and pay later, gives your customers a way to split purchases into four installments across six weeks.



1040
1041
1042
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1040

def apple_pay_later
  @apple_pay_later
end

#au_becs_debitObject

Stripe users in Australia can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with an Australian bank account. Check this [page](docs.stripe.com/payments/au-becs-debit) for more details.



1042
1043
1044
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1042

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

Stripe users in the UK can accept Bacs Direct Debit payments from customers with a UK bank account, check this [page](docs.stripe.com/payments/payment-methods/bacs-debit) for more details.



1044
1045
1046
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1044

def bacs_debit
  @bacs_debit
end

#bancontactObject

Bancontact is the most popular online payment method in Belgium, with over 15 million cards in circulation. [Customers](docs.stripe.com/api/customers) use a Bancontact card or mobile app linked to a Belgian bank account to make online payments that are secure, guaranteed, and confirmed immediately. Check this [page](docs.stripe.com/payments/bancontact) for more details.



1046
1047
1048
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1046

def bancontact
  @bancontact
end

#billieObject

Billie is a [single-use](docs.stripe.com/payments/payment-methods#usage) payment method that offers businesses Pay by Invoice where they offer payment terms ranging from 7-120 days. Customers are redirected from your website or app, authorize the payment with Billie, then return to your website or app. You get [immediate notification](/payments/payment-methods#payment-notification) of whether the payment succeeded or failed.



1048
1049
1050
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1048

def billie
  @billie
end

#bizumObject

To enable Bizum, buyers need a Spanish IBAN from a bank connected to Bizum. Within their banking app, they can enable Bizum and link their mobile number to their IBAN.



1050
1051
1052
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1050

def bizum
  @bizum
end

#blikObject

BLIK is a [single use](docs.stripe.com/payments/payment-methods#usage) payment method that requires customers to authenticate their payments. When customers want to pay online using BLIK, they request a six-digit code from their banking application and enter it into the payment collection form. Check this [page](docs.stripe.com/payments/blik) for more details.



1052
1053
1054
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1052

def blik
  @blik
end

#boletoObject

Boleto is an official (regulated by the Central Bank of Brazil) payment method in Brazil. Check this [page](docs.stripe.com/payments/boleto) for more details.



1054
1055
1056
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1054

def boleto
  @boleto
end

#cardObject

Cards are a popular way for consumers and businesses to pay online or in person. Stripe supports global and local card networks.



1056
1057
1058
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1056

def card
  @card
end

#cartes_bancairesObject

Cartes Bancaires is France’s local card network. More than 95% of these cards are co-branded with either Visa or Mastercard, meaning you can process these cards over either Cartes Bancaires or the Visa or Mastercard networks. Check this [page](docs.stripe.com/payments/cartes-bancaires) for more details.



1058
1059
1060
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1058

def cartes_bancaires
  @cartes_bancaires
end

#cashappObject

Cash App is a popular consumer app in the US that allows customers to bank, invest, send, and receive money using their digital wallet. Check this [page](docs.stripe.com/payments/cash-app-pay) for more details.



1060
1061
1062
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1060

def cashapp
  @cashapp
end

#cryptoObject

[Stablecoin payments](docs.stripe.com/payments/stablecoin-payments) enable customers to pay in stablecoins like USDC from 100s of wallets including Phantom and Metamask.



1062
1063
1064
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1062

def crypto
  @crypto
end

#customer_balanceObject

Uses a customer’s [cash balance](docs.stripe.com/payments/customer-balance) for the payment. The cash balance can be funded via a bank transfer. Check this [page](docs.stripe.com/payments/bank-transfers) for more details.



1064
1065
1066
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1064

def customer_balance
  @customer_balance
end

#epsObject

EPS is an Austria-based payment method that allows customers to complete transactions online using their bank credentials. EPS is supported by all Austrian banks and is accepted by over 80% of Austrian online retailers. Check this [page](docs.stripe.com/payments/eps) for more details.



1066
1067
1068
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1066

def eps
  @eps
end

#expandObject

Specifies which fields in the response should be expanded.



1068
1069
1070
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1068

def expand
  @expand
end

#fpxObject

Financial Process Exchange (FPX) is a Malaysia-based payment method that allows customers to complete transactions online using their bank credentials. Bank Negara Malaysia (BNM), the Central Bank of Malaysia, and eleven other major Malaysian financial institutions are members of the PayNet Group, which owns and operates FPX. It is one of the most popular online payment methods in Malaysia, with nearly 90 million transactions in 2018 according to BNM. Check this [page](docs.stripe.com/payments/fpx) for more details.



1070
1071
1072
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1070

def fpx
  @fpx
end

#fr_meal_voucher_conecsObject

Meal vouchers in France, or “titres-restaurant”, is a local benefits program commonly offered by employers for their employees to purchase prepared food and beverages on working days. Check this [page](docs.stripe.com/payments/meal-vouchers/fr-meal-vouchers) for more details.



1072
1073
1074
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1072

def fr_meal_voucher_conecs
  @fr_meal_voucher_conecs
end

#giropayObject

giropay is a German payment method based on online banking, introduced in 2006. It allows customers to complete transactions online using their online banking environment, with funds debited from their bank account. Depending on their bank, customers confirm payments on giropay using a second factor of authentication or a PIN. giropay accounts for 10% of online checkouts in Germany. Check this [page](docs.stripe.com/payments/giropay) for more details.



1074
1075
1076
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1074

def giropay
  @giropay
end

#google_payObject

Google Pay allows customers to make payments in your app or website using any credit or debit card saved to their Google Account, including those from Google Play, YouTube, Chrome, or an Android device. Use the Google Pay API to request any credit or debit card stored in your customer’s Google account. Check this [page](docs.stripe.com/google-pay) for more details.



1076
1077
1078
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1076

def google_pay
  @google_pay
end

#grabpayObject

GrabPay is a payment method developed by [Grab](www.grab.com/sg/consumer/finance/pay/). GrabPay is a digital wallet - customers maintain a balance in their wallets that they pay out with. Check this [page](docs.stripe.com/payments/grabpay) for more details.



1078
1079
1080
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1078

def grabpay
  @grabpay
end

#idealObject

iDEAL is a Netherlands-based payment method that allows customers to complete transactions online using their bank credentials. All major Dutch banks are members of Currence, the scheme that operates iDEAL, making it the most popular online payment method in the Netherlands with a share of online transactions close to 55%. Check this [page](docs.stripe.com/payments/ideal) for more details.



1080
1081
1082
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1080

def ideal
  @ideal
end

#jcbObject

JCB is a credit card company based in Japan. JCB is currently available in Japan to businesses approved by JCB, and available to all businesses in Australia, Canada, Hong Kong, Japan, New Zealand, Singapore, Switzerland, United Kingdom, United States, and all countries in the European Economic Area except Iceland. Check this [page](support.stripe.com/questions/accepting-japan-credit-bureau-%28jcb%29-payments) for more details.



1082
1083
1084
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1082

def jcb
  @jcb
end

#kakao_payObject

Kakao Pay is a popular local wallet available in South Korea.



1084
1085
1086
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1084

def kakao_pay
  @kakao_pay
end

#klarnaObject

Klarna gives customers a range of [payment options](docs.stripe.com/payments/klarna#payment-options) during checkout. Available payment options vary depending on the customer’s billing address and the transaction amount. These payment options make it convenient for customers to purchase items in all price ranges. Check this [page](docs.stripe.com/payments/klarna) for more details.



1086
1087
1088
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1086

def klarna
  @klarna
end

#konbiniObject

Konbini allows customers in Japan to pay for bills and online purchases at convenience stores with cash. Check this [page](docs.stripe.com/payments/konbini) for more details.



1088
1089
1090
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1088

def konbini
  @konbini
end

#kr_cardObject

Korean cards let users pay using locally issued cards from South Korea.



1090
1091
1092
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1090

def kr_card
  @kr_card
end

[Link](docs.stripe.com/payments/link) is a payment method network. With Link, users save their payment details once, then reuse that information to pay with one click for any business on the network.



1092
1093
1094
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1092

def link
  @link
end

#mb_wayObject

MB WAY is the most popular wallet in Portugal. After entering their phone number in your checkout, customers approve the payment directly in their MB WAY app. Check this [page](docs.stripe.com/payments/mb-way) for more details.



1094
1095
1096
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1094

def mb_way
  @mb_way
end

#mobilepayObject

MobilePay is a [single-use](docs.stripe.com/payments/payment-methods#usage) card wallet payment method used in Denmark and Finland. It allows customers to [authenticate and approve](docs.stripe.com/payments/payment-methods#customer-actions) payments using the MobilePay app. Check this [page](docs.stripe.com/payments/mobilepay) for more details.



1096
1097
1098
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1096

def mobilepay
  @mobilepay
end

#multibancoObject

Stripe users in Europe and the United States can accept Multibanco payments from customers in Portugal using [Sources](stripe.com/docs/sources)—a single integration path for creating payments using any supported method.



1098
1099
1100
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1098

def multibanco
  @multibanco
end

#nameObject

Configuration name.



1100
1101
1102
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1100

def name
  @name
end

Naver Pay is a popular local wallet available in South Korea.



1102
1103
1104
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1102

def naver_pay
  @naver_pay
end

#nz_bank_accountObject

Stripe users in New Zealand can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with a New Zeland bank account. Check this [page](docs.stripe.com/payments/nz-bank-account) for more details.



1104
1105
1106
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1104

def 
  @nz_bank_account
end

#oxxoObject

OXXO is a Mexican chain of convenience stores with thousands of locations across Latin America and represents nearly 20% of online transactions in Mexico. OXXO allows customers to pay bills and online purchases in-store with cash. Check this [page](docs.stripe.com/payments/oxxo) for more details.



1106
1107
1108
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1106

def oxxo
  @oxxo
end

#p24Object

Przelewy24 is a Poland-based payment method aggregator that allows customers to complete transactions online using bank transfers and other methods. Bank transfers account for 30% of online payments in Poland and Przelewy24 provides a way for customers to pay with over 165 banks. Check this [page](docs.stripe.com/payments/p24) for more details.



1108
1109
1110
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1108

def p24
  @p24
end

#parentObject

Configuration’s parent configuration. Specify to create a child configuration.



1110
1111
1112
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1110

def parent
  @parent
end

#pay_by_bankObject

Pay by bank is a redirect payment method backed by bank transfers. A customer is redirected to their bank to authorize a bank transfer for a given amount. This removes a lot of the error risks inherent in waiting for the customer to initiate a transfer themselves, and is less expensive than card payments.



1112
1113
1114
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1112

def pay_by_bank
  @pay_by_bank
end

#paycoObject

PAYCO is a [single-use](docs.stripe.com/payments/payment-methods#usage local wallet available in South Korea.



1114
1115
1116
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1114

def payco
  @payco
end

#paynowObject

PayNow is a Singapore-based payment method that allows customers to make a payment using their preferred app from participating banks and participating non-bank financial institutions. Check this [page](docs.stripe.com/payments/paynow) for more details.



1116
1117
1118
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1116

def paynow
  @paynow
end

#paypalObject

PayPal, a digital wallet popular with customers in Europe, allows your customers worldwide to pay using their PayPal account. Check this [page](docs.stripe.com/payments/paypal) for more details.



1118
1119
1120
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1118

def paypal
  @paypal
end

#paytoObject

PayTo is a [real-time](docs.stripe.com/payments/real-time) payment method that enables customers in Australia to pay by providing their bank account details. Customers must accept a mandate authorizing you to debit their account. Check this [page](docs.stripe.com/payments/payto) for more details.



1120
1121
1122
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1120

def payto
  @payto
end

#pixObject

Pix is a payment method popular in Brazil. When paying with Pix, customers authenticate and approve payments by scanning a QR code in their preferred banking app. Check this [page](docs.stripe.com/payments/pix) for more details.



1122
1123
1124
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1122

def pix
  @pix
end

#promptpayObject

PromptPay is a Thailand-based payment method that allows customers to make a payment using their preferred app from participating banks. Check this [page](docs.stripe.com/payments/promptpay) for more details.



1124
1125
1126
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1124

def promptpay
  @promptpay
end

#revolut_payObject

Revolut Pay, developed by Revolut, a global finance app, is a digital wallet payment method. Revolut Pay uses the customer’s stored balance or cards to fund the payment, and offers the option for non-Revolut customers to save their details after their first purchase.



1126
1127
1128
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1126

def revolut_pay
  @revolut_pay
end

#samsung_payObject

Samsung Pay is a [single-use](docs.stripe.com/payments/payment-methods#usage local wallet available in South Korea.



1128
1129
1130
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1128

def samsung_pay
  @samsung_pay
end

#satispayObject

Satispay is a [single-use](/payments/payment-methods#usage) payment method where customers are required to [authenticate](/payments/payment-methods#customer-actions) their payment. Customers pay by being redirected from your website or app, authorizing the payment with Satispay, then returning to your website or app. You get [immediate notification](/payments/payment-methods#payment-notification) of whether the payment succeeded or failed.



1130
1131
1132
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1130

def satispay
  @satispay
end

#scalapayObject

Scalapay is a [single-use](/payments/payment-methods#usage) payment method that lets customers pay in 3 or 4 installments. Customers are redirected from your website or app, authorize the payment with Scalapay, then return to your website or app. You get [immediate notification](/payments/payment-methods#payment-notification) of whether the payment succeeded or failed.



1132
1133
1134
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1132

def scalapay
  @scalapay
end

#sepa_debitObject

The [Single Euro Payments Area (SEPA)](en.wikipedia.org/wiki/Single_Euro_Payments_Area) is an initiative of the European Union to simplify payments within and across member countries. SEPA established and enforced banking standards to allow for the direct debiting of every EUR-denominated bank account within the SEPA region, check this [page](docs.stripe.com/payments/sepa-debit) for more details.



1134
1135
1136
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1134

def sepa_debit
  @sepa_debit
end

#sofortObject

Stripe users in Europe and the United States can use the [Payment Intents API](stripe.com/docs/payments/payment-intents)—a single integration path for creating payments using any supported method—to accept [Sofort](www.sofort.com/) payments from customers. Check this [page](docs.stripe.com/payments/sofort) for more details.



1136
1137
1138
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1136

def sofort
  @sofort
end

#sunbitObject

Sunbit is a [single-use](docs.stripe.com/payments/payment-methods#usage) payment method where customers choose to pay in 3, 6, or 12 installments. Customers are redirected from your website or app, authorize the payment with Sunbit, then return to your website or app. You get [immediate notification](docs.stripe.com/payments/payment-methods#payment-notification) of whether the payment succeeded or failed.



1138
1139
1140
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1138

def sunbit
  @sunbit
end

#swishObject

Swish is a [real-time](docs.stripe.com/payments/real-time) payment method popular in Sweden. It allows customers to [authenticate and approve](docs.stripe.com/payments/payment-methods#customer-actions) payments using the Swish mobile app and the Swedish BankID mobile app. Check this [page](docs.stripe.com/payments/swish) for more details.



1140
1141
1142
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1140

def swish
  @swish
end

#twintObject

Twint is a payment method popular in Switzerland. It allows customers to pay using their mobile phone. Check this [page](docs.stripe.com/payments/twint) for more details.



1142
1143
1144
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1142

def twint
  @twint
end

#upiObject

Unified Payment Interface (UPI) is India’s leading payment method with exponential growth since it launched in 2016.



1144
1145
1146
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1144

def upi
  @upi
end

#us_bank_accountObject

Stripe users in the United States can accept ACH direct debit payments from customers with a US bank account using the Automated Clearing House (ACH) payments system operated by Nacha. Check this [page](docs.stripe.com/payments/ach-direct-debit) for more details.



1146
1147
1148
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1146

def 
  @us_bank_account
end

#wechat_payObject

WeChat, owned by Tencent, is China’s leading mobile app with over 1 billion monthly active users. Chinese consumers can use WeChat Pay to pay for goods and services inside of businesses’ apps and websites. WeChat Pay users buy most frequently in gaming, e-commerce, travel, online education, and food/nutrition. Check this [page](docs.stripe.com/payments/wechat-pay) for more details.



1148
1149
1150
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1148

def wechat_pay
  @wechat_pay
end

#zipObject

Zip gives your customers a way to split purchases over a series of payments. Check this [page](docs.stripe.com/payments/zip) for more details like country availability.



1150
1151
1152
# File 'lib/stripe/params/payment_method_configuration_create_params.rb', line 1150

def zip
  @zip
end