Class: Stripe::PaymentMethodConfigurationService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_method_configuration_service.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, ApplePay, ApplePayLater, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CartesBancaires, Cashapp, CustomerBalance, Eps, Fpx, Giropay, GooglePay, Grabpay, Ideal, Jcb, KakaoPay, Klarna, Konbini, KrCard, Link, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Pix, Promptpay, RevolutPay, SamsungPay, Satispay, SepaDebit, Sofort, Swish, Twint, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acss_debit: nil, active: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, apple_pay: nil, apple_pay_later: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, blik: nil, boleto: nil, card: nil, cartes_bancaires: nil, cashapp: nil, customer_balance: nil, eps: nil, expand: nil, fpx: nil, giropay: nil, google_pay: nil, grabpay: nil, ideal: nil, jcb: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mobilepay: nil, multibanco: nil, name: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, pix: nil, promptpay: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, sofort: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
2255
2256
2257
2258
2259
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2147

def initialize(
  acss_debit: nil,
  active: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  alma: nil,
  amazon_pay: nil,
  apple_pay: nil,
  apple_pay_later: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  billie: nil,
  blik: nil,
  boleto: nil,
  card: nil,
  cartes_bancaires: nil,
  cashapp: nil,
  customer_balance: nil,
  eps: nil,
  expand: nil,
  fpx: nil,
  giropay: nil,
  google_pay: nil,
  grabpay: nil,
  ideal: nil,
  jcb: nil,
  kakao_pay: nil,
  klarna: nil,
  konbini: nil,
  kr_card: nil,
  link: nil,
  mobilepay: nil,
  multibanco: nil,
  name: nil,
  naver_pay: nil,
  nz_bank_account: nil,
  oxxo: nil,
  p24: nil,
  pay_by_bank: nil,
  payco: nil,
  paynow: nil,
  paypal: nil,
  pix: nil,
  promptpay: nil,
  revolut_pay: nil,
  samsung_pay: nil,
  satispay: nil,
  sepa_debit: nil,
  sofort: nil,
  swish: nil,
  twint: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @active = active
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @alma = alma
  @amazon_pay = amazon_pay
  @apple_pay = apple_pay
  @apple_pay_later = apple_pay_later
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @billie = billie
  @blik = blik
  @boleto = boleto
  @card = card
  @cartes_bancaires = cartes_bancaires
  @cashapp = cashapp
  @customer_balance = customer_balance
  @eps = eps
  @expand = expand
  @fpx = fpx
  @giropay = giropay
  @google_pay = google_pay
  @grabpay = grabpay
  @ideal = ideal
  @jcb = jcb
  @kakao_pay = kakao_pay
  @klarna = klarna
  @konbini = konbini
  @kr_card = kr_card
  @link = link
  @mobilepay = mobilepay
  @multibanco = multibanco
  @name = name
  @naver_pay = naver_pay
  @nz_bank_account = 
  @oxxo = oxxo
  @p24 = p24
  @pay_by_bank = pay_by_bank
  @payco = payco
  @paynow = paynow
  @paypal = paypal
  @pix = pix
  @promptpay = promptpay
  @revolut_pay = revolut_pay
  @samsung_pay = samsung_pay
  @satispay = satispay
  @sepa_debit = sepa_debit
  @sofort = sofort
  @swish = swish
  @twint = twint
  @us_bank_account = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

Canadian pre-authorized debit payments, check this [page](stripe.com/docs/payments/acss-debit) for more details like country availability.



2037
2038
2039
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2037

def acss_debit
  @acss_debit
end

#activeObject

Whether the configuration can be used for new payments.



2039
2040
2041
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2039

def active
  @active
end

#affirmObject

[Affirm](www.affirm.com/) gives your customers a way to split purchases over a series of payments. Depending on the purchase, they can pay with four interest-free payments (Split Pay) or pay over a longer term (Installments), which might include interest. Check this [page](stripe.com/docs/payments/affirm) for more details like country availability.



2041
2042
2043
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2041

def affirm
  @affirm
end

#afterpay_clearpayObject

Afterpay gives your customers a way to pay for purchases in installments, check this [page](stripe.com/docs/payments/afterpay-clearpay) for more details like country availability. Afterpay is particularly popular among businesses selling fashion, beauty, and sports products.



2043
2044
2045
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2043

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

Alipay is a digital wallet in China that has more than a billion active users worldwide. Alipay users can pay on the web or on a mobile device using login credentials or their Alipay app. Alipay has a low dispute rate and reduces fraud by authenticating payments using the customer’s login credentials. Check this [page](stripe.com/docs/payments/alipay) for more details.



2045
2046
2047
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2045

def alipay
  @alipay
end

#almaObject

Alma is a Buy Now, Pay Later payment method that offers customers the ability to pay in 2, 3, or 4 installments.



2047
2048
2049
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2047

def alma
  @alma
end

#amazon_payObject

Amazon Pay is a wallet payment method that lets your customers check out the same way as on Amazon.



2049
2050
2051
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2049

def amazon_pay
  @amazon_pay
end

#apple_payObject

Stripe users can accept [Apple Pay](stripe.com/payments/apple-pay) in iOS applications in iOS 9 and later, and on the web in Safari starting with iOS 10 or macOS Sierra. There are no additional fees to process Apple Pay payments, and the [pricing](stripe.com/pricing) is the same as other card transactions. Check this [page](stripe.com/docs/apple-pay) for more details.



2051
2052
2053
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2051

def apple_pay
  @apple_pay
end

#apple_pay_laterObject

Apple Pay Later, a payment method for customers to buy now and pay later, gives your customers a way to split purchases into four installments across six weeks.



2053
2054
2055
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2053

def apple_pay_later
  @apple_pay_later
end

#au_becs_debitObject

Stripe users in Australia can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with an Australian bank account. Check this [page](stripe.com/docs/payments/au-becs-debit) for more details.



2055
2056
2057
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2055

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

Stripe users in the UK can accept Bacs Direct Debit payments from customers with a UK bank account, check this [page](stripe.com/docs/payments/payment-methods/bacs-debit) for more details.



2057
2058
2059
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2057

def bacs_debit
  @bacs_debit
end

#bancontactObject

Bancontact is the most popular online payment method in Belgium, with over 15 million cards in circulation. [Customers](stripe.com/docs/api/customers) use a Bancontact card or mobile app linked to a Belgian bank account to make online payments that are secure, guaranteed, and confirmed immediately. Check this [page](stripe.com/docs/payments/bancontact) for more details.



2059
2060
2061
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2059

def bancontact
  @bancontact
end

#billieObject

Billie is a [single-use](docs.stripe.com/payments/payment-methods#usage) payment method that offers businesses Pay by Invoice where they offer payment terms ranging from 7-120 days. Customers are redirected from your website or app, authorize the payment with Billie, then return to your website or app. You get [immediate notification](/payments/payment-methods#payment-notification) of whether the payment succeeded or failed.



2061
2062
2063
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2061

def billie
  @billie
end

#blikObject

BLIK is a [single use](stripe.com/docs/payments/payment-methods#usage) payment method that requires customers to authenticate their payments. When customers want to pay online using BLIK, they request a six-digit code from their banking application and enter it into the payment collection form. Check this [page](stripe.com/docs/payments/blik) for more details.



2063
2064
2065
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2063

def blik
  @blik
end

#boletoObject

Boleto is an official (regulated by the Central Bank of Brazil) payment method in Brazil. Check this [page](stripe.com/docs/payments/boleto) for more details.



2065
2066
2067
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2065

def boleto
  @boleto
end

#cardObject

Cards are a popular way for consumers and businesses to pay online or in person. Stripe supports global and local card networks.



2067
2068
2069
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2067

def card
  @card
end

#cartes_bancairesObject

Cartes Bancaires is France’s local card network. More than 95% of these cards are co-branded with either Visa or Mastercard, meaning you can process these cards over either Cartes Bancaires or the Visa or Mastercard networks. Check this [page](stripe.com/docs/payments/cartes-bancaires) for more details.



2069
2070
2071
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2069

def cartes_bancaires
  @cartes_bancaires
end

#cashappObject

Cash App is a popular consumer app in the US that allows customers to bank, invest, send, and receive money using their digital wallet. Check this [page](stripe.com/docs/payments/cash-app-pay) for more details.



2071
2072
2073
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2071

def cashapp
  @cashapp
end

#customer_balanceObject

Uses a customer’s [cash balance](stripe.com/docs/payments/customer-balance) for the payment. The cash balance can be funded via a bank transfer. Check this [page](stripe.com/docs/payments/bank-transfers) for more details.



2073
2074
2075
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2073

def customer_balance
  @customer_balance
end

#epsObject

EPS is an Austria-based payment method that allows customers to complete transactions online using their bank credentials. EPS is supported by all Austrian banks and is accepted by over 80% of Austrian online retailers. Check this [page](stripe.com/docs/payments/eps) for more details.



2075
2076
2077
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2075

def eps
  @eps
end

#expandObject

Specifies which fields in the response should be expanded.



2077
2078
2079
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2077

def expand
  @expand
end

#fpxObject

Financial Process Exchange (FPX) is a Malaysia-based payment method that allows customers to complete transactions online using their bank credentials. Bank Negara Malaysia (BNM), the Central Bank of Malaysia, and eleven other major Malaysian financial institutions are members of the PayNet Group, which owns and operates FPX. It is one of the most popular online payment methods in Malaysia, with nearly 90 million transactions in 2018 according to BNM. Check this [page](stripe.com/docs/payments/fpx) for more details.



2079
2080
2081
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2079

def fpx
  @fpx
end

#giropayObject

giropay is a German payment method based on online banking, introduced in 2006. It allows customers to complete transactions online using their online banking environment, with funds debited from their bank account. Depending on their bank, customers confirm payments on giropay using a second factor of authentication or a PIN. giropay accounts for 10% of online checkouts in Germany. Check this [page](stripe.com/docs/payments/giropay) for more details.



2081
2082
2083
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2081

def giropay
  @giropay
end

#google_payObject

Google Pay allows customers to make payments in your app or website using any credit or debit card saved to their Google Account, including those from Google Play, YouTube, Chrome, or an Android device. Use the Google Pay API to request any credit or debit card stored in your customer’s Google account. Check this [page](stripe.com/docs/google-pay) for more details.



2083
2084
2085
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2083

def google_pay
  @google_pay
end

#grabpayObject

GrabPay is a payment method developed by [Grab](www.grab.com/sg/consumer/finance/pay/). GrabPay is a digital wallet - customers maintain a balance in their wallets that they pay out with. Check this [page](stripe.com/docs/payments/grabpay) for more details.



2085
2086
2087
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2085

def grabpay
  @grabpay
end

#idealObject

iDEAL is a Netherlands-based payment method that allows customers to complete transactions online using their bank credentials. All major Dutch banks are members of Currence, the scheme that operates iDEAL, making it the most popular online payment method in the Netherlands with a share of online transactions close to 55%. Check this [page](stripe.com/docs/payments/ideal) for more details.



2087
2088
2089
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2087

def ideal
  @ideal
end

#jcbObject

JCB is a credit card company based in Japan. JCB is currently available in Japan to businesses approved by JCB, and available to all businesses in Australia, Canada, Hong Kong, Japan, New Zealand, Singapore, Switzerland, United Kingdom, United States, and all countries in the European Economic Area except Iceland. Check this [page](support.stripe.com/questions/accepting-japan-credit-bureau-%28jcb%29-payments) for more details.



2089
2090
2091
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2089

def jcb
  @jcb
end

#kakao_payObject

Kakao Pay is a popular local wallet available in South Korea.



2091
2092
2093
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2091

def kakao_pay
  @kakao_pay
end

#klarnaObject

Klarna gives customers a range of [payment options](stripe.com/docs/payments/klarna#payment-options) during checkout. Available payment options vary depending on the customer’s billing address and the transaction amount. These payment options make it convenient for customers to purchase items in all price ranges. Check this [page](stripe.com/docs/payments/klarna) for more details.



2093
2094
2095
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2093

def klarna
  @klarna
end

#konbiniObject

Konbini allows customers in Japan to pay for bills and online purchases at convenience stores with cash. Check this [page](stripe.com/docs/payments/konbini) for more details.



2095
2096
2097
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2095

def konbini
  @konbini
end

#kr_cardObject

Korean cards let users pay using locally issued cards from South Korea.



2097
2098
2099
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2097

def kr_card
  @kr_card
end

[Link](stripe.com/docs/payments/link) is a payment method network. With Link, users save their payment details once, then reuse that information to pay with one click for any business on the network.



2099
2100
2101
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2099

def link
  @link
end

#mobilepayObject

MobilePay is a [single-use](stripe.com/docs/payments/payment-methods#usage) card wallet payment method used in Denmark and Finland. It allows customers to [authenticate and approve](stripe.com/docs/payments/payment-methods#customer-actions) payments using the MobilePay app. Check this [page](stripe.com/docs/payments/mobilepay) for more details.



2101
2102
2103
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2101

def mobilepay
  @mobilepay
end

#multibancoObject

Stripe users in Europe and the United States can accept Multibanco payments from customers in Portugal using [Sources](stripe.com/docs/sources)—a single integration path for creating payments using any supported method.



2103
2104
2105
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2103

def multibanco
  @multibanco
end

#nameObject

Configuration name.



2105
2106
2107
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2105

def name
  @name
end

Naver Pay is a popular local wallet available in South Korea.



2107
2108
2109
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2107

def naver_pay
  @naver_pay
end

#nz_bank_accountObject

Stripe users in New Zealand can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with a New Zeland bank account. Check this [page](stripe.com/docs/payments/nz-bank-account) for more details.



2109
2110
2111
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2109

def 
  @nz_bank_account
end

#oxxoObject

OXXO is a Mexican chain of convenience stores with thousands of locations across Latin America and represents nearly 20% of online transactions in Mexico. OXXO allows customers to pay bills and online purchases in-store with cash. Check this [page](stripe.com/docs/payments/oxxo) for more details.



2111
2112
2113
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2111

def oxxo
  @oxxo
end

#p24Object

Przelewy24 is a Poland-based payment method aggregator that allows customers to complete transactions online using bank transfers and other methods. Bank transfers account for 30% of online payments in Poland and Przelewy24 provides a way for customers to pay with over 165 banks. Check this [page](stripe.com/docs/payments/p24) for more details.



2113
2114
2115
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2113

def p24
  @p24
end

#pay_by_bankObject

Pay by bank is a redirect payment method backed by bank transfers. A customer is redirected to their bank to authorize a bank transfer for a given amount. This removes a lot of the error risks inherent in waiting for the customer to initiate a transfer themselves, and is less expensive than card payments.



2115
2116
2117
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2115

def pay_by_bank
  @pay_by_bank
end

#paycoObject

PAYCO is a [single-use](docs.stripe.com/payments/payment-methods#usage local wallet available in South Korea.



2117
2118
2119
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2117

def payco
  @payco
end

#paynowObject

PayNow is a Singapore-based payment method that allows customers to make a payment using their preferred app from participating banks and participating non-bank financial institutions. Check this [page](stripe.com/docs/payments/paynow) for more details.



2119
2120
2121
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2119

def paynow
  @paynow
end

#paypalObject

PayPal, a digital wallet popular with customers in Europe, allows your customers worldwide to pay using their PayPal account. Check this [page](stripe.com/docs/payments/paypal) for more details.



2121
2122
2123
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2121

def paypal
  @paypal
end

#pixObject

Pix is a payment method popular in Brazil. When paying with Pix, customers authenticate and approve payments by scanning a QR code in their preferred banking app. Check this [page](docs.stripe.com/payments/pix) for more details.



2123
2124
2125
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2123

def pix
  @pix
end

#promptpayObject

PromptPay is a Thailand-based payment method that allows customers to make a payment using their preferred app from participating banks. Check this [page](stripe.com/docs/payments/promptpay) for more details.



2125
2126
2127
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2125

def promptpay
  @promptpay
end

#revolut_payObject

Revolut Pay, developed by Revolut, a global finance app, is a digital wallet payment method. Revolut Pay uses the customer’s stored balance or cards to fund the payment, and offers the option for non-Revolut customers to save their details after their first purchase.



2127
2128
2129
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2127

def revolut_pay
  @revolut_pay
end

#samsung_payObject

Samsung Pay is a [single-use](docs.stripe.com/payments/payment-methods#usage local wallet available in South Korea.



2129
2130
2131
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2129

def samsung_pay
  @samsung_pay
end

#satispayObject

Satispay is a [single-use](docs.stripe.com/payments/payment-methods#usage) payment method where customers are required to [authenticate](/payments/payment-methods#customer-actions) their payment. Customers pay by being redirected from your website or app, authorizing the payment with Satispay, then returning to your website or app. You get [immediate notification](/payments/payment-methods#payment-notification) of whether the payment succeeded or failed.



2131
2132
2133
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2131

def satispay
  @satispay
end

#sepa_debitObject

The [Single Euro Payments Area (SEPA)](en.wikipedia.org/wiki/Single_Euro_Payments_Area) is an initiative of the European Union to simplify payments within and across member countries. SEPA established and enforced banking standards to allow for the direct debiting of every EUR-denominated bank account within the SEPA region, check this [page](stripe.com/docs/payments/sepa-debit) for more details.



2133
2134
2135
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2133

def sepa_debit
  @sepa_debit
end

#sofortObject

Stripe users in Europe and the United States can use the [Payment Intents API](stripe.com/docs/payments/payment-intents)—a single integration path for creating payments using any supported method—to accept [Sofort](www.sofort.com/) payments from customers. Check this [page](stripe.com/docs/payments/sofort) for more details.



2135
2136
2137
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2135

def sofort
  @sofort
end

#swishObject

Swish is a [real-time](stripe.com/docs/payments/real-time) payment method popular in Sweden. It allows customers to [authenticate and approve](stripe.com/docs/payments/payment-methods#customer-actions) payments using the Swish mobile app and the Swedish BankID mobile app. Check this [page](stripe.com/docs/payments/swish) for more details.



2137
2138
2139
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2137

def swish
  @swish
end

#twintObject

Twint is a payment method popular in Switzerland. It allows customers to pay using their mobile phone. Check this [page](docs.stripe.com/payments/twint) for more details.



2139
2140
2141
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2139

def twint
  @twint
end

#us_bank_accountObject

Stripe users in the United States can accept ACH direct debit payments from customers with a US bank account using the Automated Clearing House (ACH) payments system operated by Nacha. Check this [page](stripe.com/docs/payments/ach-direct-debit) for more details.



2141
2142
2143
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2141

def 
  @us_bank_account
end

#wechat_payObject

WeChat, owned by Tencent, is China’s leading mobile app with over 1 billion monthly active users. Chinese consumers can use WeChat Pay to pay for goods and services inside of businesses’ apps and websites. WeChat Pay users buy most frequently in gaming, e-commerce, travel, online education, and food/nutrition. Check this [page](stripe.com/docs/payments/wechat-pay) for more details.



2143
2144
2145
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2143

def wechat_pay
  @wechat_pay
end

#zipObject

Zip gives your customers a way to split purchases over a series of payments. Check this [page](stripe.com/docs/payments/zip) for more details like country availability.



2145
2146
2147
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 2145

def zip
  @zip
end