Class: Stripe::PaymentMethodConfigurationService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodConfigurationService::UpdateParams
- Defined in:
- lib/stripe/services/payment_method_configuration_service.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, ApplePay, ApplePayLater, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CartesBancaires, Cashapp, CustomerBalance, Eps, Fpx, Giropay, GooglePay, Grabpay, Ideal, Jcb, Klarna, Konbini, Link, Mobilepay, Multibanco, NzBankAccount, Oxxo, P24, PayByBank, Paynow, Paypal, Promptpay, RevolutPay, Satispay, SepaDebit, Sofort, Swish, Twint, UsBankAccount, WechatPay, Zip
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
Canadian pre-authorized debit payments, check this [page](stripe.com/docs/payments/acss-debit) for more details like country availability.
-
#active ⇒ Object
Whether the configuration can be used for new payments.
-
#affirm ⇒ Object
[Affirm](www.affirm.com/) gives your customers a way to split purchases over a series of payments.
-
#afterpay_clearpay ⇒ Object
Afterpay gives your customers a way to pay for purchases in installments, check this [page](stripe.com/docs/payments/afterpay-clearpay) for more details like country availability.
-
#alipay ⇒ Object
Alipay is a digital wallet in China that has more than a billion active users worldwide.
-
#alma ⇒ Object
Alma is a Buy Now, Pay Later payment method that offers customers the ability to pay in 2, 3, or 4 installments.
-
#amazon_pay ⇒ Object
Amazon Pay is a wallet payment method that lets your customers check out the same way as on Amazon.
-
#apple_pay ⇒ Object
Stripe users can accept [Apple Pay](/payments/apple-pay) in iOS applications in iOS 9 and later, and on the web in Safari starting with iOS 10 or macOS Sierra.
-
#apple_pay_later ⇒ Object
Apple Pay Later, a payment method for customers to buy now and pay later, gives your customers a way to split purchases into four installments across six weeks.
-
#au_becs_debit ⇒ Object
Stripe users in Australia can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with an Australian bank account.
-
#bacs_debit ⇒ Object
Stripe users in the UK can accept Bacs Direct Debit payments from customers with a UK bank account, check this [page](stripe.com/docs/payments/payment-methods/bacs-debit) for more details.
-
#bancontact ⇒ Object
Bancontact is the most popular online payment method in Belgium, with over 15 million cards in circulation.
-
#billie ⇒ Object
Billie is a [single-use](docs.stripe.com/payments/payment-methods#usage) payment method that offers businesses Pay by Invoice where they offer payment terms ranging from 7-120 days.
-
#blik ⇒ Object
BLIK is a [single use](stripe.com/docs/payments/payment-methods#usage) payment method that requires customers to authenticate their payments.
-
#boleto ⇒ Object
Boleto is an official (regulated by the Central Bank of Brazil) payment method in Brazil.
-
#card ⇒ Object
Cards are a popular way for consumers and businesses to pay online or in person.
-
#cartes_bancaires ⇒ Object
Cartes Bancaires is France’s local card network.
-
#cashapp ⇒ Object
Cash App is a popular consumer app in the US that allows customers to bank, invest, send, and receive money using their digital wallet.
-
#customer_balance ⇒ Object
Uses a customer’s [cash balance](stripe.com/docs/payments/customer-balance) for the payment.
-
#eps ⇒ Object
EPS is an Austria-based payment method that allows customers to complete transactions online using their bank credentials.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fpx ⇒ Object
Financial Process Exchange (FPX) is a Malaysia-based payment method that allows customers to complete transactions online using their bank credentials.
-
#giropay ⇒ Object
giropay is a German payment method based on online banking, introduced in 2006.
-
#google_pay ⇒ Object
Google Pay allows customers to make payments in your app or website using any credit or debit card saved to their Google Account, including those from Google Play, YouTube, Chrome, or an Android device.
-
#grabpay ⇒ Object
GrabPay is a payment method developed by [Grab](www.grab.com/sg/consumer/finance/pay/).
-
#ideal ⇒ Object
iDEAL is a Netherlands-based payment method that allows customers to complete transactions online using their bank credentials.
-
#jcb ⇒ Object
JCB is a credit card company based in Japan.
-
#klarna ⇒ Object
Klarna gives customers a range of [payment options](stripe.com/docs/payments/klarna#payment-options) during checkout.
-
#konbini ⇒ Object
Konbini allows customers in Japan to pay for bills and online purchases at convenience stores with cash.
-
#link ⇒ Object
[Link](stripe.com/docs/payments/link) is a payment method network.
-
#mobilepay ⇒ Object
MobilePay is a [single-use](stripe.com/docs/payments/payment-methods#usage) card wallet payment method used in Denmark and Finland.
-
#multibanco ⇒ Object
Stripe users in Europe and the United States can accept Multibanco payments from customers in Portugal using [Sources](stripe.com/docs/sources)—a single integration path for creating payments using any supported method.
-
#name ⇒ Object
Configuration name.
-
#nz_bank_account ⇒ Object
Stripe users in New Zealand can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with a New Zeland bank account.
-
#oxxo ⇒ Object
OXXO is a Mexican chain of convenience stores with thousands of locations across Latin America and represents nearly 20% of online transactions in Mexico.
-
#p24 ⇒ Object
Przelewy24 is a Poland-based payment method aggregator that allows customers to complete transactions online using bank transfers and other methods.
-
#pay_by_bank ⇒ Object
Pay by bank is a redirect payment method backed by bank transfers.
-
#paynow ⇒ Object
PayNow is a Singapore-based payment method that allows customers to make a payment using their preferred app from participating banks and participating non-bank financial institutions.
-
#paypal ⇒ Object
PayPal, a digital wallet popular with customers in Europe, allows your customers worldwide to pay using their PayPal account.
-
#promptpay ⇒ Object
PromptPay is a Thailand-based payment method that allows customers to make a payment using their preferred app from participating banks.
-
#revolut_pay ⇒ Object
Revolut Pay, developed by Revolut, a global finance app, is a digital wallet payment method.
-
#satispay ⇒ Object
Satispay is a [single-use](docs.stripe.com/payments/payment-methods#usage) payment method where customers are required to [authenticate](/payments/payment-methods#customer-actions) their payment.
-
#sepa_debit ⇒ Object
The [Single Euro Payments Area (SEPA)](en.wikipedia.org/wiki/Single_Euro_Payments_Area) is an initiative of the European Union to simplify payments within and across member countries.
-
#sofort ⇒ Object
Stripe users in Europe and the United States can use the [Payment Intents API](stripe.com/docs/payments/payment-intents)—a single integration path for creating payments using any supported method—to accept [Sofort](www.sofort.com/) payments from customers.
-
#swish ⇒ Object
Swish is a [real-time](stripe.com/docs/payments/real-time) payment method popular in Sweden.
-
#twint ⇒ Object
Twint is a payment method popular in Switzerland.
-
#us_bank_account ⇒ Object
Stripe users in the United States can accept ACH direct debit payments from customers with a US bank account using the Automated Clearing House (ACH) payments system operated by Nacha.
-
#wechat_pay ⇒ Object
WeChat, owned by Tencent, is China’s leading mobile app with over 1 billion monthly active users.
-
#zip ⇒ Object
Zip gives your customers a way to split purchases over a series of payments.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, active: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, apple_pay: nil, apple_pay_later: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, blik: nil, boleto: nil, card: nil, cartes_bancaires: nil, cashapp: nil, customer_balance: nil, eps: nil, expand: nil, fpx: nil, giropay: nil, google_pay: nil, grabpay: nil, ideal: nil, jcb: nil, klarna: nil, konbini: nil, link: nil, mobilepay: nil, multibanco: nil, name: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, paynow: nil, paypal: nil, promptpay: nil, revolut_pay: nil, satispay: nil, sepa_debit: nil, sofort: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
1907 1908 1909 1910 1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1907 def initialize( acss_debit: nil, active: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, apple_pay: nil, apple_pay_later: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, blik: nil, boleto: nil, card: nil, cartes_bancaires: nil, cashapp: nil, customer_balance: nil, eps: nil, expand: nil, fpx: nil, giropay: nil, google_pay: nil, grabpay: nil, ideal: nil, jcb: nil, klarna: nil, konbini: nil, link: nil, mobilepay: nil, multibanco: nil, name: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, paynow: nil, paypal: nil, promptpay: nil, revolut_pay: nil, satispay: nil, sepa_debit: nil, sofort: nil, swish: nil, twint: nil, us_bank_account: nil, wechat_pay: nil, zip: nil ) @acss_debit = acss_debit @active = active @affirm = affirm @afterpay_clearpay = afterpay_clearpay @alipay = alipay @alma = alma @amazon_pay = amazon_pay @apple_pay = apple_pay @apple_pay_later = apple_pay_later @au_becs_debit = au_becs_debit @bacs_debit = bacs_debit @bancontact = bancontact @billie = billie @blik = blik @boleto = boleto @card = card @cartes_bancaires = cartes_bancaires @cashapp = cashapp @customer_balance = customer_balance @eps = eps @expand = @fpx = fpx @giropay = giropay @google_pay = google_pay @grabpay = grabpay @ideal = ideal @jcb = jcb @klarna = klarna @konbini = konbini @link = link @mobilepay = mobilepay @multibanco = multibanco @name = name @nz_bank_account = nz_bank_account @oxxo = oxxo @p24 = p24 @pay_by_bank = pay_by_bank @paynow = paynow @paypal = paypal @promptpay = promptpay @revolut_pay = revolut_pay @satispay = satispay @sepa_debit = sepa_debit @sofort = sofort @swish = swish @twint = twint @us_bank_account = us_bank_account @wechat_pay = wechat_pay @zip = zip end |
Instance Attribute Details
#acss_debit ⇒ Object
Canadian pre-authorized debit payments, check this [page](stripe.com/docs/payments/acss-debit) for more details like country availability.
1809 1810 1811 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1809 def acss_debit @acss_debit end |
#active ⇒ Object
Whether the configuration can be used for new payments.
1811 1812 1813 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1811 def active @active end |
#affirm ⇒ Object
[Affirm](www.affirm.com/) gives your customers a way to split purchases over a series of payments. Depending on the purchase, they can pay with four interest-free payments (Split Pay) or pay over a longer term (Installments), which might include interest. Check this [page](stripe.com/docs/payments/affirm) for more details like country availability.
1813 1814 1815 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1813 def affirm @affirm end |
#afterpay_clearpay ⇒ Object
Afterpay gives your customers a way to pay for purchases in installments, check this [page](stripe.com/docs/payments/afterpay-clearpay) for more details like country availability. Afterpay is particularly popular among businesses selling fashion, beauty, and sports products.
1815 1816 1817 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1815 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
Alipay is a digital wallet in China that has more than a billion active users worldwide. Alipay users can pay on the web or on a mobile device using login credentials or their Alipay app. Alipay has a low dispute rate and reduces fraud by authenticating payments using the customer’s login credentials. Check this [page](stripe.com/docs/payments/alipay) for more details.
1817 1818 1819 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1817 def alipay @alipay end |
#alma ⇒ Object
Alma is a Buy Now, Pay Later payment method that offers customers the ability to pay in 2, 3, or 4 installments.
1819 1820 1821 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1819 def alma @alma end |
#amazon_pay ⇒ Object
Amazon Pay is a wallet payment method that lets your customers check out the same way as on Amazon.
1821 1822 1823 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1821 def amazon_pay @amazon_pay end |
#apple_pay ⇒ Object
Stripe users can accept [Apple Pay](/payments/apple-pay) in iOS applications in iOS 9 and later, and on the web in Safari starting with iOS 10 or macOS Sierra. There are no additional fees to process Apple Pay payments, and the [pricing](/pricing) is the same as other card transactions. Check this [page](stripe.com/docs/apple-pay) for more details.
1823 1824 1825 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1823 def apple_pay @apple_pay end |
#apple_pay_later ⇒ Object
Apple Pay Later, a payment method for customers to buy now and pay later, gives your customers a way to split purchases into four installments across six weeks.
1825 1826 1827 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1825 def apple_pay_later @apple_pay_later end |
#au_becs_debit ⇒ Object
Stripe users in Australia can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with an Australian bank account. Check this [page](stripe.com/docs/payments/au-becs-debit) for more details.
1827 1828 1829 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1827 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object
Stripe users in the UK can accept Bacs Direct Debit payments from customers with a UK bank account, check this [page](stripe.com/docs/payments/payment-methods/bacs-debit) for more details.
1829 1830 1831 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1829 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object
Bancontact is the most popular online payment method in Belgium, with over 15 million cards in circulation. [Customers](stripe.com/docs/api/customers) use a Bancontact card or mobile app linked to a Belgian bank account to make online payments that are secure, guaranteed, and confirmed immediately. Check this [page](stripe.com/docs/payments/bancontact) for more details.
1831 1832 1833 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1831 def bancontact @bancontact end |
#billie ⇒ Object
Billie is a [single-use](docs.stripe.com/payments/payment-methods#usage) payment method that offers businesses Pay by Invoice where they offer payment terms ranging from 7-120 days. Customers are redirected from your website or app, authorize the payment with Billie, then return to your website or app. You get [immediate notification](/payments/payment-methods#payment-notification) of whether the payment succeeded or failed.
1833 1834 1835 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1833 def billie @billie end |
#blik ⇒ Object
BLIK is a [single use](stripe.com/docs/payments/payment-methods#usage) payment method that requires customers to authenticate their payments. When customers want to pay online using BLIK, they request a six-digit code from their banking application and enter it into the payment collection form. Check this [page](stripe.com/docs/payments/blik) for more details.
1835 1836 1837 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1835 def blik @blik end |
#boleto ⇒ Object
Boleto is an official (regulated by the Central Bank of Brazil) payment method in Brazil. Check this [page](stripe.com/docs/payments/boleto) for more details.
1837 1838 1839 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1837 def boleto @boleto end |
#card ⇒ Object
Cards are a popular way for consumers and businesses to pay online or in person. Stripe supports global and local card networks.
1839 1840 1841 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1839 def card @card end |
#cartes_bancaires ⇒ Object
Cartes Bancaires is France’s local card network. More than 95% of these cards are co-branded with either Visa or Mastercard, meaning you can process these cards over either Cartes Bancaires or the Visa or Mastercard networks. Check this [page](stripe.com/docs/payments/cartes-bancaires) for more details.
1841 1842 1843 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1841 def cartes_bancaires @cartes_bancaires end |
#cashapp ⇒ Object
Cash App is a popular consumer app in the US that allows customers to bank, invest, send, and receive money using their digital wallet. Check this [page](stripe.com/docs/payments/cash-app-pay) for more details.
1843 1844 1845 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1843 def cashapp @cashapp end |
#customer_balance ⇒ Object
Uses a customer’s [cash balance](stripe.com/docs/payments/customer-balance) for the payment. The cash balance can be funded via a bank transfer. Check this [page](stripe.com/docs/payments/bank-transfers) for more details.
1845 1846 1847 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1845 def customer_balance @customer_balance end |
#eps ⇒ Object
EPS is an Austria-based payment method that allows customers to complete transactions online using their bank credentials. EPS is supported by all Austrian banks and is accepted by over 80% of Austrian online retailers. Check this [page](stripe.com/docs/payments/eps) for more details.
1847 1848 1849 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1847 def eps @eps end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1849 1850 1851 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1849 def @expand end |
#fpx ⇒ Object
Financial Process Exchange (FPX) is a Malaysia-based payment method that allows customers to complete transactions online using their bank credentials. Bank Negara Malaysia (BNM), the Central Bank of Malaysia, and eleven other major Malaysian financial institutions are members of the PayNet Group, which owns and operates FPX. It is one of the most popular online payment methods in Malaysia, with nearly 90 million transactions in 2018 according to BNM. Check this [page](stripe.com/docs/payments/fpx) for more details.
1851 1852 1853 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1851 def fpx @fpx end |
#giropay ⇒ Object
giropay is a German payment method based on online banking, introduced in 2006. It allows customers to complete transactions online using their online banking environment, with funds debited from their bank account. Depending on their bank, customers confirm payments on giropay using a second factor of authentication or a PIN. giropay accounts for 10% of online checkouts in Germany. Check this [page](stripe.com/docs/payments/giropay) for more details.
1853 1854 1855 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1853 def giropay @giropay end |
#google_pay ⇒ Object
Google Pay allows customers to make payments in your app or website using any credit or debit card saved to their Google Account, including those from Google Play, YouTube, Chrome, or an Android device. Use the Google Pay API to request any credit or debit card stored in your customer’s Google account. Check this [page](stripe.com/docs/google-pay) for more details.
1855 1856 1857 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1855 def google_pay @google_pay end |
#grabpay ⇒ Object
GrabPay is a payment method developed by [Grab](www.grab.com/sg/consumer/finance/pay/). GrabPay is a digital wallet - customers maintain a balance in their wallets that they pay out with. Check this [page](stripe.com/docs/payments/grabpay) for more details.
1857 1858 1859 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1857 def grabpay @grabpay end |
#ideal ⇒ Object
iDEAL is a Netherlands-based payment method that allows customers to complete transactions online using their bank credentials. All major Dutch banks are members of Currence, the scheme that operates iDEAL, making it the most popular online payment method in the Netherlands with a share of online transactions close to 55%. Check this [page](stripe.com/docs/payments/ideal) for more details.
1859 1860 1861 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1859 def ideal @ideal end |
#jcb ⇒ Object
JCB is a credit card company based in Japan. JCB is currently available in Japan to businesses approved by JCB, and available to all businesses in Australia, Canada, Hong Kong, Japan, New Zealand, Singapore, Switzerland, United Kingdom, United States, and all countries in the European Economic Area except Iceland. Check this [page](support.stripe.com/questions/accepting-japan-credit-bureau-%28jcb%29-payments) for more details.
1861 1862 1863 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1861 def jcb @jcb end |
#klarna ⇒ Object
Klarna gives customers a range of [payment options](stripe.com/docs/payments/klarna#payment-options) during checkout. Available payment options vary depending on the customer’s billing address and the transaction amount. These payment options make it convenient for customers to purchase items in all price ranges. Check this [page](stripe.com/docs/payments/klarna) for more details.
1863 1864 1865 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1863 def klarna @klarna end |
#konbini ⇒ Object
Konbini allows customers in Japan to pay for bills and online purchases at convenience stores with cash. Check this [page](stripe.com/docs/payments/konbini) for more details.
1865 1866 1867 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1865 def konbini @konbini end |
#link ⇒ Object
[Link](stripe.com/docs/payments/link) is a payment method network. With Link, users save their payment details once, then reuse that information to pay with one click for any business on the network.
1867 1868 1869 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1867 def link @link end |
#mobilepay ⇒ Object
MobilePay is a [single-use](stripe.com/docs/payments/payment-methods#usage) card wallet payment method used in Denmark and Finland. It allows customers to [authenticate and approve](stripe.com/docs/payments/payment-methods#customer-actions) payments using the MobilePay app. Check this [page](stripe.com/docs/payments/mobilepay) for more details.
1869 1870 1871 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1869 def mobilepay @mobilepay end |
#multibanco ⇒ Object
Stripe users in Europe and the United States can accept Multibanco payments from customers in Portugal using [Sources](stripe.com/docs/sources)—a single integration path for creating payments using any supported method.
1871 1872 1873 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1871 def multibanco @multibanco end |
#name ⇒ Object
Configuration name.
1873 1874 1875 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1873 def name @name end |
#nz_bank_account ⇒ Object
Stripe users in New Zealand can accept Bulk Electronic Clearing System (BECS) direct debit payments from customers with a New Zeland bank account. Check this [page](stripe.com/docs/payments/nz-bank-account) for more details.
1875 1876 1877 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1875 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object
OXXO is a Mexican chain of convenience stores with thousands of locations across Latin America and represents nearly 20% of online transactions in Mexico. OXXO allows customers to pay bills and online purchases in-store with cash. Check this [page](stripe.com/docs/payments/oxxo) for more details.
1877 1878 1879 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1877 def oxxo @oxxo end |
#p24 ⇒ Object
Przelewy24 is a Poland-based payment method aggregator that allows customers to complete transactions online using bank transfers and other methods. Bank transfers account for 30% of online payments in Poland and Przelewy24 provides a way for customers to pay with over 165 banks. Check this [page](stripe.com/docs/payments/p24) for more details.
1879 1880 1881 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1879 def p24 @p24 end |
#pay_by_bank ⇒ Object
Pay by bank is a redirect payment method backed by bank transfers. A customer is redirected to their bank to authorize a bank transfer for a given amount. This removes a lot of the error risks inherent in waiting for the customer to initiate a transfer themselves, and is less expensive than card payments.
1881 1882 1883 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1881 def pay_by_bank @pay_by_bank end |
#paynow ⇒ Object
PayNow is a Singapore-based payment method that allows customers to make a payment using their preferred app from participating banks and participating non-bank financial institutions. Check this [page](stripe.com/docs/payments/paynow) for more details.
1883 1884 1885 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1883 def paynow @paynow end |
#paypal ⇒ Object
PayPal, a digital wallet popular with customers in Europe, allows your customers worldwide to pay using their PayPal account. Check this [page](stripe.com/docs/payments/paypal) for more details.
1885 1886 1887 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1885 def paypal @paypal end |
#promptpay ⇒ Object
PromptPay is a Thailand-based payment method that allows customers to make a payment using their preferred app from participating banks. Check this [page](stripe.com/docs/payments/promptpay) for more details.
1887 1888 1889 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1887 def promptpay @promptpay end |
#revolut_pay ⇒ Object
Revolut Pay, developed by Revolut, a global finance app, is a digital wallet payment method. Revolut Pay uses the customer’s stored balance or cards to fund the payment, and offers the option for non-Revolut customers to save their details after their first purchase.
1889 1890 1891 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1889 def revolut_pay @revolut_pay end |
#satispay ⇒ Object
Satispay is a [single-use](docs.stripe.com/payments/payment-methods#usage) payment method where customers are required to [authenticate](/payments/payment-methods#customer-actions) their payment. Customers pay by being redirected from your website or app, authorizing the payment with Satispay, then returning to your website or app. You get [immediate notification](/payments/payment-methods#payment-notification) of whether the payment succeeded or failed.
1891 1892 1893 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1891 def satispay @satispay end |
#sepa_debit ⇒ Object
The [Single Euro Payments Area (SEPA)](en.wikipedia.org/wiki/Single_Euro_Payments_Area) is an initiative of the European Union to simplify payments within and across member countries. SEPA established and enforced banking standards to allow for the direct debiting of every EUR-denominated bank account within the SEPA region, check this [page](stripe.com/docs/payments/sepa-debit) for more details.
1893 1894 1895 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1893 def sepa_debit @sepa_debit end |
#sofort ⇒ Object
Stripe users in Europe and the United States can use the [Payment Intents API](stripe.com/docs/payments/payment-intents)—a single integration path for creating payments using any supported method—to accept [Sofort](www.sofort.com/) payments from customers. Check this [page](stripe.com/docs/payments/sofort) for more details.
1895 1896 1897 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1895 def sofort @sofort end |
#swish ⇒ Object
Swish is a [real-time](stripe.com/docs/payments/real-time) payment method popular in Sweden. It allows customers to [authenticate and approve](stripe.com/docs/payments/payment-methods#customer-actions) payments using the Swish mobile app and the Swedish BankID mobile app. Check this [page](stripe.com/docs/payments/swish) for more details.
1897 1898 1899 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1897 def swish @swish end |
#twint ⇒ Object
Twint is a payment method popular in Switzerland. It allows customers to pay using their mobile phone. Check this [page](docs.stripe.com/payments/twint) for more details.
1899 1900 1901 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1899 def twint @twint end |
#us_bank_account ⇒ Object
Stripe users in the United States can accept ACH direct debit payments from customers with a US bank account using the Automated Clearing House (ACH) payments system operated by Nacha. Check this [page](stripe.com/docs/payments/ach-direct-debit) for more details.
1901 1902 1903 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1901 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
WeChat, owned by Tencent, is China’s leading mobile app with over 1 billion monthly active users. Chinese consumers can use WeChat Pay to pay for goods and services inside of businesses’ apps and websites. WeChat Pay users buy most frequently in gaming, e-commerce, travel, online education, and food/nutrition. Check this [page](stripe.com/docs/payments/wechat-pay) for more details.
1903 1904 1905 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1903 def wechat_pay @wechat_pay end |
#zip ⇒ Object
Zip gives your customers a way to split purchases over a series of payments. Check this [page](stripe.com/docs/payments/zip) for more details like country availability.
1905 1906 1907 |
# File 'lib/stripe/services/payment_method_configuration_service.rb', line 1905 def zip @zip end |