Class: Stripe::PaymentMethodCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/payment_method_create_params.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Card, Cashapp, Crypto, Custom, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, RadarOptions, Rechnung, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, StripeBalance, Sunbit, Swish, Twint, Upi, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, billing_details: nil, blik: nil, boleto: nil, card: nil, cashapp: nil, crypto: nil, custom: nil, customer: nil, customer_balance: nil, eps: nil, expand: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, payment_method: nil, paynow: nil, paypal: nil, paypay: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, radar_options: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, sunbit: nil, swish: nil, twint: nil, type: nil, upi: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodCreateParams

Returns a new instance of PaymentMethodCreateParams.



584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
# File 'lib/stripe/params/payment_method_create_params.rb', line 584

def initialize(
  acss_debit: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  allow_redisplay: nil,
  alma: nil,
  amazon_pay: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  billie: nil,
  billing_details: nil,
  blik: nil,
  boleto: nil,
  card: nil,
  cashapp: nil,
  crypto: nil,
  custom: nil,
  customer: nil,
  customer_balance: nil,
  eps: nil,
  expand: nil,
  fpx: nil,
  giropay: nil,
  gopay: nil,
  grabpay: nil,
  id_bank_transfer: nil,
  ideal: nil,
  interac_present: nil,
  kakao_pay: nil,
  klarna: nil,
  konbini: nil,
  kr_card: nil,
  link: nil,
  mb_way: nil,
  metadata: nil,
  mobilepay: nil,
  multibanco: nil,
  naver_pay: nil,
  nz_bank_account: nil,
  oxxo: nil,
  p24: nil,
  pay_by_bank: nil,
  payco: nil,
  payment_method: nil,
  paynow: nil,
  paypal: nil,
  paypay: nil,
  payto: nil,
  pix: nil,
  promptpay: nil,
  qris: nil,
  radar_options: nil,
  rechnung: nil,
  revolut_pay: nil,
  samsung_pay: nil,
  satispay: nil,
  sepa_debit: nil,
  shopeepay: nil,
  sofort: nil,
  stripe_balance: nil,
  sunbit: nil,
  swish: nil,
  twint: nil,
  type: nil,
  upi: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @allow_redisplay = allow_redisplay
  @alma = alma
  @amazon_pay = amazon_pay
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @billie = billie
  @billing_details = billing_details
  @blik = blik
  @boleto = boleto
  @card = card
  @cashapp = cashapp
  @crypto = crypto
  @custom = custom
  @customer = customer
  @customer_balance = customer_balance
  @eps = eps
  @expand = expand
  @fpx = fpx
  @giropay = giropay
  @gopay = gopay
  @grabpay = grabpay
  @id_bank_transfer = id_bank_transfer
  @ideal = ideal
  @interac_present = interac_present
  @kakao_pay = kakao_pay
  @klarna = klarna
  @konbini = konbini
  @kr_card = kr_card
  @link = link
  @mb_way = mb_way
  @metadata = 
  @mobilepay = mobilepay
  @multibanco = multibanco
  @naver_pay = naver_pay
  @nz_bank_account = 
  @oxxo = oxxo
  @p24 = p24
  @pay_by_bank = pay_by_bank
  @payco = payco
  @payment_method = payment_method
  @paynow = paynow
  @paypal = paypal
  @paypay = paypay
  @payto = payto
  @pix = pix
  @promptpay = promptpay
  @qris = qris
  @radar_options = radar_options
  @rechnung = rechnung
  @revolut_pay = revolut_pay
  @samsung_pay = samsung_pay
  @satispay = satispay
  @sepa_debit = sepa_debit
  @shopeepay = shopeepay
  @sofort = sofort
  @stripe_balance = stripe_balance
  @sunbit = sunbit
  @swish = swish
  @twint = twint
  @type = type
  @upi = upi
  @us_bank_account = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

If this is an ‘acss_debit` PaymentMethod, this hash contains details about the ACSS Debit payment method.



446
447
448
# File 'lib/stripe/params/payment_method_create_params.rb', line 446

def acss_debit
  @acss_debit
end

#affirmObject

If this is an ‘affirm` PaymentMethod, this hash contains details about the Affirm payment method.



448
449
450
# File 'lib/stripe/params/payment_method_create_params.rb', line 448

def affirm
  @affirm
end

#afterpay_clearpayObject

If this is an ‘AfterpayClearpay` PaymentMethod, this hash contains details about the AfterpayClearpay payment method.



450
451
452
# File 'lib/stripe/params/payment_method_create_params.rb', line 450

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If this is an ‘Alipay` PaymentMethod, this hash contains details about the Alipay payment method.



452
453
454
# File 'lib/stripe/params/payment_method_create_params.rb', line 452

def alipay
  @alipay
end

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.



454
455
456
# File 'lib/stripe/params/payment_method_create_params.rb', line 454

def allow_redisplay
  @allow_redisplay
end

#almaObject

If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.



456
457
458
# File 'lib/stripe/params/payment_method_create_params.rb', line 456

def alma
  @alma
end

#amazon_payObject

If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.



458
459
460
# File 'lib/stripe/params/payment_method_create_params.rb', line 458

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject

If this is an ‘au_becs_debit` PaymentMethod, this hash contains details about the bank account.



460
461
462
# File 'lib/stripe/params/payment_method_create_params.rb', line 460

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

If this is a ‘bacs_debit` PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.



462
463
464
# File 'lib/stripe/params/payment_method_create_params.rb', line 462

def bacs_debit
  @bacs_debit
end

#bancontactObject

If this is a ‘bancontact` PaymentMethod, this hash contains details about the Bancontact payment method.



464
465
466
# File 'lib/stripe/params/payment_method_create_params.rb', line 464

def bancontact
  @bancontact
end

#billieObject

If this is a ‘billie` PaymentMethod, this hash contains details about the Billie payment method.



466
467
468
# File 'lib/stripe/params/payment_method_create_params.rb', line 466

def billie
  @billie
end

#billing_detailsObject

Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.



468
469
470
# File 'lib/stripe/params/payment_method_create_params.rb', line 468

def billing_details
  @billing_details
end

#blikObject

If this is a ‘blik` PaymentMethod, this hash contains details about the BLIK payment method.



470
471
472
# File 'lib/stripe/params/payment_method_create_params.rb', line 470

def blik
  @blik
end

#boletoObject

If this is a ‘boleto` PaymentMethod, this hash contains details about the Boleto payment method.



472
473
474
# File 'lib/stripe/params/payment_method_create_params.rb', line 472

def boleto
  @boleto
end

#cardObject

If this is a ‘card` PaymentMethod, this hash contains the user’s card details. For backwards compatibility, you can alternatively provide a Stripe token (e.g., for Apple Pay, Amex Express Checkout, or legacy Checkout) into the card hash with format ‘card: “tok_visa”`. When providing a card number, you must meet the requirements for [PCI compliance](stripe.com/docs/security#validating-pci-compliance). We strongly recommend using Stripe.js instead of interacting with this API directly.



474
475
476
# File 'lib/stripe/params/payment_method_create_params.rb', line 474

def card
  @card
end

#cashappObject

If this is a ‘cashapp` PaymentMethod, this hash contains details about the Cash App Pay payment method.



476
477
478
# File 'lib/stripe/params/payment_method_create_params.rb', line 476

def cashapp
  @cashapp
end

#cryptoObject

If this is a Crypto PaymentMethod, this hash contains details about the Crypto payment method.



478
479
480
# File 'lib/stripe/params/payment_method_create_params.rb', line 478

def crypto
  @crypto
end

#customObject

If this is a ‘custom` PaymentMethod, this hash contains details about the Custom payment method.



480
481
482
# File 'lib/stripe/params/payment_method_create_params.rb', line 480

def custom
  @custom
end

#customerObject

The ‘Customer` to whom the original PaymentMethod is attached.



482
483
484
# File 'lib/stripe/params/payment_method_create_params.rb', line 482

def customer
  @customer
end

#customer_balanceObject

If this is a ‘customer_balance` PaymentMethod, this hash contains details about the CustomerBalance payment method.



484
485
486
# File 'lib/stripe/params/payment_method_create_params.rb', line 484

def customer_balance
  @customer_balance
end

#epsObject

If this is an ‘eps` PaymentMethod, this hash contains details about the EPS payment method.



486
487
488
# File 'lib/stripe/params/payment_method_create_params.rb', line 486

def eps
  @eps
end

#expandObject

Specifies which fields in the response should be expanded.



488
489
490
# File 'lib/stripe/params/payment_method_create_params.rb', line 488

def expand
  @expand
end

#fpxObject

If this is an ‘fpx` PaymentMethod, this hash contains details about the FPX payment method.



490
491
492
# File 'lib/stripe/params/payment_method_create_params.rb', line 490

def fpx
  @fpx
end

#giropayObject

If this is a ‘giropay` PaymentMethod, this hash contains details about the Giropay payment method.



492
493
494
# File 'lib/stripe/params/payment_method_create_params.rb', line 492

def giropay
  @giropay
end

#gopayObject

If this is a Gopay PaymentMethod, this hash contains details about the Gopay payment method.



494
495
496
# File 'lib/stripe/params/payment_method_create_params.rb', line 494

def gopay
  @gopay
end

#grabpayObject

If this is a ‘grabpay` PaymentMethod, this hash contains details about the GrabPay payment method.



496
497
498
# File 'lib/stripe/params/payment_method_create_params.rb', line 496

def grabpay
  @grabpay
end

#id_bank_transferObject

If this is an ‘IdBankTransfer` PaymentMethod, this hash contains details about the IdBankTransfer payment method.



498
499
500
# File 'lib/stripe/params/payment_method_create_params.rb', line 498

def id_bank_transfer
  @id_bank_transfer
end

#idealObject

If this is an ‘ideal` PaymentMethod, this hash contains details about the iDEAL payment method.



500
501
502
# File 'lib/stripe/params/payment_method_create_params.rb', line 500

def ideal
  @ideal
end

#interac_presentObject

If this is an ‘interac_present` PaymentMethod, this hash contains details about the Interac Present payment method.



502
503
504
# File 'lib/stripe/params/payment_method_create_params.rb', line 502

def interac_present
  @interac_present
end

#kakao_payObject

If this is a ‘kakao_pay` PaymentMethod, this hash contains details about the Kakao Pay payment method.



504
505
506
# File 'lib/stripe/params/payment_method_create_params.rb', line 504

def kakao_pay
  @kakao_pay
end

#klarnaObject

If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method.



506
507
508
# File 'lib/stripe/params/payment_method_create_params.rb', line 506

def klarna
  @klarna
end

#konbiniObject

If this is a ‘konbini` PaymentMethod, this hash contains details about the Konbini payment method.



508
509
510
# File 'lib/stripe/params/payment_method_create_params.rb', line 508

def konbini
  @konbini
end

#kr_cardObject

If this is a ‘kr_card` PaymentMethod, this hash contains details about the Korean Card payment method.



510
511
512
# File 'lib/stripe/params/payment_method_create_params.rb', line 510

def kr_card
  @kr_card
end

If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.



512
513
514
# File 'lib/stripe/params/payment_method_create_params.rb', line 512

def link
  @link
end

#mb_wayObject

If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.



514
515
516
# File 'lib/stripe/params/payment_method_create_params.rb', line 514

def mb_way
  @mb_way
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



516
517
518
# File 'lib/stripe/params/payment_method_create_params.rb', line 516

def 
  @metadata
end

#mobilepayObject

If this is a ‘mobilepay` PaymentMethod, this hash contains details about the MobilePay payment method.



518
519
520
# File 'lib/stripe/params/payment_method_create_params.rb', line 518

def mobilepay
  @mobilepay
end

#multibancoObject

If this is a ‘multibanco` PaymentMethod, this hash contains details about the Multibanco payment method.



520
521
522
# File 'lib/stripe/params/payment_method_create_params.rb', line 520

def multibanco
  @multibanco
end

If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.



522
523
524
# File 'lib/stripe/params/payment_method_create_params.rb', line 522

def naver_pay
  @naver_pay
end

#nz_bank_accountObject

If this is an nz_bank_account PaymentMethod, this hash contains details about the nz_bank_account payment method.



524
525
526
# File 'lib/stripe/params/payment_method_create_params.rb', line 524

def 
  @nz_bank_account
end

#oxxoObject

If this is an ‘oxxo` PaymentMethod, this hash contains details about the OXXO payment method.



526
527
528
# File 'lib/stripe/params/payment_method_create_params.rb', line 526

def oxxo
  @oxxo
end

#p24Object

If this is a ‘p24` PaymentMethod, this hash contains details about the P24 payment method.



528
529
530
# File 'lib/stripe/params/payment_method_create_params.rb', line 528

def p24
  @p24
end

#pay_by_bankObject

If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.



530
531
532
# File 'lib/stripe/params/payment_method_create_params.rb', line 530

def pay_by_bank
  @pay_by_bank
end

#paycoObject

If this is a ‘payco` PaymentMethod, this hash contains details about the PAYCO payment method.



532
533
534
# File 'lib/stripe/params/payment_method_create_params.rb', line 532

def payco
  @payco
end

#payment_methodObject

The PaymentMethod to share.



534
535
536
# File 'lib/stripe/params/payment_method_create_params.rb', line 534

def payment_method
  @payment_method
end

#paynowObject

If this is a ‘paynow` PaymentMethod, this hash contains details about the PayNow payment method.



536
537
538
# File 'lib/stripe/params/payment_method_create_params.rb', line 536

def paynow
  @paynow
end

#paypalObject

If this is a ‘paypal` PaymentMethod, this hash contains details about the PayPal payment method.



538
539
540
# File 'lib/stripe/params/payment_method_create_params.rb', line 538

def paypal
  @paypal
end

#paypayObject

If this is a ‘paypay` PaymentMethod, this hash contains details about the PayPay payment method.



540
541
542
# File 'lib/stripe/params/payment_method_create_params.rb', line 540

def paypay
  @paypay
end

#paytoObject

If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.



542
543
544
# File 'lib/stripe/params/payment_method_create_params.rb', line 542

def payto
  @payto
end

#pixObject

If this is a ‘pix` PaymentMethod, this hash contains details about the Pix payment method.



544
545
546
# File 'lib/stripe/params/payment_method_create_params.rb', line 544

def pix
  @pix
end

#promptpayObject

If this is a ‘promptpay` PaymentMethod, this hash contains details about the PromptPay payment method.



546
547
548
# File 'lib/stripe/params/payment_method_create_params.rb', line 546

def promptpay
  @promptpay
end

#qrisObject

If this is a ‘qris` PaymentMethod, this hash contains details about the QRIS payment method.



548
549
550
# File 'lib/stripe/params/payment_method_create_params.rb', line 548

def qris
  @qris
end

#radar_optionsObject

Options to configure Radar. See [Radar Session](docs.stripe.com/radar/radar-session) for more information.



550
551
552
# File 'lib/stripe/params/payment_method_create_params.rb', line 550

def radar_options
  @radar_options
end

#rechnungObject

If this is a ‘rechnung` PaymentMethod, this hash contains details about the Rechnung payment method.



552
553
554
# File 'lib/stripe/params/payment_method_create_params.rb', line 552

def rechnung
  @rechnung
end

#revolut_payObject

If this is a ‘revolut_pay` PaymentMethod, this hash contains details about the Revolut Pay payment method.



554
555
556
# File 'lib/stripe/params/payment_method_create_params.rb', line 554

def revolut_pay
  @revolut_pay
end

#samsung_payObject

If this is a ‘samsung_pay` PaymentMethod, this hash contains details about the SamsungPay payment method.



556
557
558
# File 'lib/stripe/params/payment_method_create_params.rb', line 556

def samsung_pay
  @samsung_pay
end

#satispayObject

If this is a ‘satispay` PaymentMethod, this hash contains details about the Satispay payment method.



558
559
560
# File 'lib/stripe/params/payment_method_create_params.rb', line 558

def satispay
  @satispay
end

#sepa_debitObject

If this is a ‘sepa_debit` PaymentMethod, this hash contains details about the SEPA debit bank account.



560
561
562
# File 'lib/stripe/params/payment_method_create_params.rb', line 560

def sepa_debit
  @sepa_debit
end

#shopeepayObject

If this is a Shopeepay PaymentMethod, this hash contains details about the Shopeepay payment method.



562
563
564
# File 'lib/stripe/params/payment_method_create_params.rb', line 562

def shopeepay
  @shopeepay
end

#sofortObject

If this is a ‘sofort` PaymentMethod, this hash contains details about the SOFORT payment method.



564
565
566
# File 'lib/stripe/params/payment_method_create_params.rb', line 564

def sofort
  @sofort
end

#stripe_balanceObject

This hash contains details about the Stripe balance payment method.



566
567
568
# File 'lib/stripe/params/payment_method_create_params.rb', line 566

def stripe_balance
  @stripe_balance
end

#sunbitObject

If this is a Sunbit PaymentMethod, this hash contains details about the Sunbit payment method.



568
569
570
# File 'lib/stripe/params/payment_method_create_params.rb', line 568

def sunbit
  @sunbit
end

#swishObject

If this is a ‘swish` PaymentMethod, this hash contains details about the Swish payment method.



570
571
572
# File 'lib/stripe/params/payment_method_create_params.rb', line 570

def swish
  @swish
end

#twintObject

If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.



572
573
574
# File 'lib/stripe/params/payment_method_create_params.rb', line 572

def twint
  @twint
end

#typeObject

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



574
575
576
# File 'lib/stripe/params/payment_method_create_params.rb', line 574

def type
  @type
end

#upiObject

If this is a ‘upi` PaymentMethod, this hash contains details about the UPI payment method.



576
577
578
# File 'lib/stripe/params/payment_method_create_params.rb', line 576

def upi
  @upi
end

#us_bank_accountObject

If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.



578
579
580
# File 'lib/stripe/params/payment_method_create_params.rb', line 578

def 
  @us_bank_account
end

#wechat_payObject

If this is an ‘wechat_pay` PaymentMethod, this hash contains details about the wechat_pay payment method.



580
581
582
# File 'lib/stripe/params/payment_method_create_params.rb', line 580

def wechat_pay
  @wechat_pay
end

#zipObject

If this is a ‘zip` PaymentMethod, this hash contains details about the Zip payment method.



582
583
584
# File 'lib/stripe/params/payment_method_create_params.rb', line 582

def zip
  @zip
end