Class: Stripe::PaymentMethodCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodCreateParams
- Defined in:
- lib/stripe/params/payment_method_create_params.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Card, Cashapp, Crypto, Custom, CustomerBalance, Eps, Fpx, Giropay, Grabpay, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, RadarOptions, RevolutPay, SamsungPay, Satispay, SepaDebit, Sofort, Swish, Twint, Upi, UsBankAccount, WechatPay, Zip
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If this is an
acss_debitPaymentMethod, this hash contains details about the ACSS Debit payment method. -
#affirm ⇒ Object
If this is an
affirmPaymentMethod, this hash contains details about the Affirm payment method. -
#afterpay_clearpay ⇒ Object
If this is an
AfterpayClearpayPaymentMethod, this hash contains details about the AfterpayClearpay payment method. -
#alipay ⇒ Object
If this is an
AlipayPaymentMethod, this hash contains details about the Alipay payment method. -
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#alma ⇒ Object
If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.
-
#amazon_pay ⇒ Object
If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.
-
#au_becs_debit ⇒ Object
If this is an
au_becs_debitPaymentMethod, this hash contains details about the bank account. -
#bacs_debit ⇒ Object
If this is a
bacs_debitPaymentMethod, this hash contains details about the Bacs Direct Debit bank account. -
#bancontact ⇒ Object
If this is a
bancontactPaymentMethod, this hash contains details about the Bancontact payment method. -
#billie ⇒ Object
If this is a
billiePaymentMethod, this hash contains details about the Billie payment method. -
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
-
#blik ⇒ Object
If this is a
blikPaymentMethod, this hash contains details about the BLIK payment method. -
#boleto ⇒ Object
If this is a
boletoPaymentMethod, this hash contains details about the Boleto payment method. -
#card ⇒ Object
If this is a
cardPaymentMethod, this hash contains the user’s card details. -
#cashapp ⇒ Object
If this is a
cashappPaymentMethod, this hash contains details about the Cash App Pay payment method. -
#crypto ⇒ Object
If this is a Crypto PaymentMethod, this hash contains details about the Crypto payment method.
-
#custom ⇒ Object
If this is a
customPaymentMethod, this hash contains details about the Custom payment method. -
#customer ⇒ Object
The
Customerto whom the original PaymentMethod is attached. -
#customer_balance ⇒ Object
If this is a
customer_balancePaymentMethod, this hash contains details about the CustomerBalance payment method. -
#eps ⇒ Object
If this is an
epsPaymentMethod, this hash contains details about the EPS payment method. -
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fpx ⇒ Object
If this is an
fpxPaymentMethod, this hash contains details about the FPX payment method. -
#giropay ⇒ Object
If this is a
giropayPaymentMethod, this hash contains details about the Giropay payment method. -
#grabpay ⇒ Object
If this is a
grabpayPaymentMethod, this hash contains details about the GrabPay payment method. -
#ideal ⇒ Object
If this is an
idealPaymentMethod, this hash contains details about the iDEAL payment method. -
#interac_present ⇒ Object
If this is an
interac_presentPaymentMethod, this hash contains details about the Interac Present payment method. -
#kakao_pay ⇒ Object
If this is a
kakao_payPaymentMethod, this hash contains details about the Kakao Pay payment method. -
#klarna ⇒ Object
If this is a
klarnaPaymentMethod, this hash contains details about the Klarna payment method. -
#konbini ⇒ Object
If this is a
konbiniPaymentMethod, this hash contains details about the Konbini payment method. -
#kr_card ⇒ Object
If this is a
kr_cardPaymentMethod, this hash contains details about the Korean Card payment method. -
#link ⇒ Object
If this is an
LinkPaymentMethod, this hash contains details about the Link payment method. -
#mb_way ⇒ Object
If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#mobilepay ⇒ Object
If this is a
mobilepayPaymentMethod, this hash contains details about the MobilePay payment method. -
#multibanco ⇒ Object
If this is a
multibancoPaymentMethod, this hash contains details about the Multibanco payment method. -
#naver_pay ⇒ Object
If this is a
naver_payPaymentMethod, this hash contains details about the Naver Pay payment method. -
#nz_bank_account ⇒ Object
If this is an nz_bank_account PaymentMethod, this hash contains details about the nz_bank_account payment method.
-
#oxxo ⇒ Object
If this is an
oxxoPaymentMethod, this hash contains details about the OXXO payment method. -
#p24 ⇒ Object
If this is a
p24PaymentMethod, this hash contains details about the P24 payment method. -
#pay_by_bank ⇒ Object
If this is a
pay_by_bankPaymentMethod, this hash contains details about the PayByBank payment method. -
#payco ⇒ Object
If this is a
paycoPaymentMethod, this hash contains details about the PAYCO payment method. -
#payment_method ⇒ Object
The PaymentMethod to share.
-
#paynow ⇒ Object
If this is a
paynowPaymentMethod, this hash contains details about the PayNow payment method. -
#paypal ⇒ Object
If this is a
paypalPaymentMethod, this hash contains details about the PayPal payment method. -
#payto ⇒ Object
If this is a
paytoPaymentMethod, this hash contains details about the PayTo payment method. -
#pix ⇒ Object
If this is a
pixPaymentMethod, this hash contains details about the Pix payment method. -
#promptpay ⇒ Object
If this is a
promptpayPaymentMethod, this hash contains details about the PromptPay payment method. -
#radar_options ⇒ Object
Options to configure Radar.
-
#revolut_pay ⇒ Object
If this is a
revolut_payPaymentMethod, this hash contains details about the Revolut Pay payment method. -
#samsung_pay ⇒ Object
If this is a
samsung_payPaymentMethod, this hash contains details about the SamsungPay payment method. -
#satispay ⇒ Object
If this is a
satispayPaymentMethod, this hash contains details about the Satispay payment method. -
#sepa_debit ⇒ Object
If this is a
sepa_debitPaymentMethod, this hash contains details about the SEPA debit bank account. -
#sofort ⇒ Object
If this is a
sofortPaymentMethod, this hash contains details about the SOFORT payment method. -
#swish ⇒ Object
If this is a
swishPaymentMethod, this hash contains details about the Swish payment method. -
#twint ⇒ Object
If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.
-
#type ⇒ Object
The type of the PaymentMethod.
-
#upi ⇒ Object
If this is a
upiPaymentMethod, this hash contains details about the UPI payment method. -
#us_bank_account ⇒ Object
If this is an
us_bank_accountPaymentMethod, this hash contains details about the US bank account payment method. -
#wechat_pay ⇒ Object
If this is an
wechat_payPaymentMethod, this hash contains details about the wechat_pay payment method. -
#zip ⇒ Object
If this is a
zipPaymentMethod, this hash contains details about the Zip payment method.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, billing_details: nil, blik: nil, boleto: nil, card: nil, cashapp: nil, crypto: nil, custom: nil, customer: nil, customer_balance: nil, eps: nil, expand: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, payment_method: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, radar_options: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, sofort: nil, swish: nil, twint: nil, type: nil, upi: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodCreateParams
Returns a new instance of PaymentMethodCreateParams.
521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 521 def initialize( acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, billing_details: nil, blik: nil, boleto: nil, card: nil, cashapp: nil, crypto: nil, custom: nil, customer: nil, customer_balance: nil, eps: nil, expand: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, payment_method: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, radar_options: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, sofort: nil, swish: nil, twint: nil, type: nil, upi: nil, us_bank_account: nil, wechat_pay: nil, zip: nil ) @acss_debit = acss_debit @affirm = affirm @afterpay_clearpay = afterpay_clearpay @alipay = alipay @allow_redisplay = allow_redisplay @alma = alma @amazon_pay = amazon_pay @au_becs_debit = au_becs_debit @bacs_debit = bacs_debit @bancontact = bancontact @billie = billie @billing_details = billing_details @blik = blik @boleto = boleto @card = card @cashapp = cashapp @crypto = crypto @custom = custom @customer = customer @customer_balance = customer_balance @eps = eps = @fpx = fpx @giropay = giropay @grabpay = grabpay @ideal = ideal @interac_present = interac_present @kakao_pay = kakao_pay @klarna = klarna @konbini = konbini @kr_card = kr_card @link = link @mb_way = mb_way = @mobilepay = mobilepay @multibanco = multibanco @naver_pay = naver_pay @nz_bank_account = nz_bank_account @oxxo = oxxo @p24 = p24 @pay_by_bank = pay_by_bank @payco = payco @payment_method = payment_method @paynow = paynow @paypal = paypal @payto = payto @pix = pix @promptpay = promptpay = @revolut_pay = revolut_pay @samsung_pay = samsung_pay @satispay = satispay @sepa_debit = sepa_debit @sofort = sofort @swish = swish @twint = twint @type = type @upi = upi @us_bank_account = us_bank_account @wechat_pay = wechat_pay @zip = zip end |
Instance Attribute Details
#acss_debit ⇒ Object
If this is an acss_debit PaymentMethod, this hash contains details about the ACSS Debit payment method.
399 400 401 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 399 def acss_debit @acss_debit end |
#affirm ⇒ Object
If this is an affirm PaymentMethod, this hash contains details about the Affirm payment method.
401 402 403 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 401 def affirm @affirm end |
#afterpay_clearpay ⇒ Object
If this is an AfterpayClearpay PaymentMethod, this hash contains details about the AfterpayClearpay payment method.
403 404 405 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 403 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
If this is an Alipay PaymentMethod, this hash contains details about the Alipay payment method.
405 406 407 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 405 def alipay @alipay end |
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to unspecified.
407 408 409 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 407 def allow_redisplay @allow_redisplay end |
#alma ⇒ Object
If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.
409 410 411 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 409 def alma @alma end |
#amazon_pay ⇒ Object
If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.
411 412 413 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 411 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object
If this is an au_becs_debit PaymentMethod, this hash contains details about the bank account.
413 414 415 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 413 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object
If this is a bacs_debit PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.
415 416 417 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 415 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object
If this is a bancontact PaymentMethod, this hash contains details about the Bancontact payment method.
417 418 419 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 417 def bancontact @bancontact end |
#billie ⇒ Object
If this is a billie PaymentMethod, this hash contains details about the Billie payment method.
419 420 421 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 419 def billie @billie end |
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
421 422 423 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 421 def billing_details @billing_details end |
#blik ⇒ Object
If this is a blik PaymentMethod, this hash contains details about the BLIK payment method.
423 424 425 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 423 def blik @blik end |
#boleto ⇒ Object
If this is a boleto PaymentMethod, this hash contains details about the Boleto payment method.
425 426 427 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 425 def boleto @boleto end |
#card ⇒ Object
If this is a card PaymentMethod, this hash contains the user’s card details. For backwards compatibility, you can alternatively provide a Stripe token (e.g., for Apple Pay, Amex Express Checkout, or legacy Checkout) into the card hash with format ‘card: “tok_visa”`. When providing a card number, you must meet the requirements for [PCI compliance](stripe.com/docs/security#validating-pci-compliance). We strongly recommend using Stripe.js instead of interacting with this API directly.
427 428 429 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 427 def card @card end |
#cashapp ⇒ Object
If this is a cashapp PaymentMethod, this hash contains details about the Cash App Pay payment method.
429 430 431 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 429 def cashapp @cashapp end |
#crypto ⇒ Object
If this is a Crypto PaymentMethod, this hash contains details about the Crypto payment method.
431 432 433 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 431 def crypto @crypto end |
#custom ⇒ Object
If this is a custom PaymentMethod, this hash contains details about the Custom payment method.
433 434 435 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 433 def custom @custom end |
#customer ⇒ Object
The Customer to whom the original PaymentMethod is attached.
435 436 437 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 435 def customer @customer end |
#customer_balance ⇒ Object
If this is a customer_balance PaymentMethod, this hash contains details about the CustomerBalance payment method.
437 438 439 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 437 def customer_balance @customer_balance end |
#eps ⇒ Object
If this is an eps PaymentMethod, this hash contains details about the EPS payment method.
439 440 441 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 439 def eps @eps end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
441 442 443 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 441 def end |
#fpx ⇒ Object
If this is an fpx PaymentMethod, this hash contains details about the FPX payment method.
443 444 445 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 443 def fpx @fpx end |
#giropay ⇒ Object
If this is a giropay PaymentMethod, this hash contains details about the Giropay payment method.
445 446 447 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 445 def giropay @giropay end |
#grabpay ⇒ Object
If this is a grabpay PaymentMethod, this hash contains details about the GrabPay payment method.
447 448 449 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 447 def grabpay @grabpay end |
#ideal ⇒ Object
If this is an ideal PaymentMethod, this hash contains details about the iDEAL payment method.
449 450 451 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 449 def ideal @ideal end |
#interac_present ⇒ Object
If this is an interac_present PaymentMethod, this hash contains details about the Interac Present payment method.
451 452 453 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 451 def interac_present @interac_present end |
#kakao_pay ⇒ Object
If this is a kakao_pay PaymentMethod, this hash contains details about the Kakao Pay payment method.
453 454 455 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 453 def kakao_pay @kakao_pay end |
#klarna ⇒ Object
If this is a klarna PaymentMethod, this hash contains details about the Klarna payment method.
455 456 457 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 455 def klarna @klarna end |
#konbini ⇒ Object
If this is a konbini PaymentMethod, this hash contains details about the Konbini payment method.
457 458 459 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 457 def konbini @konbini end |
#kr_card ⇒ Object
If this is a kr_card PaymentMethod, this hash contains details about the Korean Card payment method.
459 460 461 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 459 def kr_card @kr_card end |
#link ⇒ Object
If this is an Link PaymentMethod, this hash contains details about the Link payment method.
461 462 463 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 461 def link @link end |
#mb_way ⇒ Object
If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.
463 464 465 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 463 def mb_way @mb_way end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
465 466 467 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 465 def end |
#mobilepay ⇒ Object
If this is a mobilepay PaymentMethod, this hash contains details about the MobilePay payment method.
467 468 469 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 467 def mobilepay @mobilepay end |
#multibanco ⇒ Object
If this is a multibanco PaymentMethod, this hash contains details about the Multibanco payment method.
469 470 471 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 469 def multibanco @multibanco end |
#naver_pay ⇒ Object
If this is a naver_pay PaymentMethod, this hash contains details about the Naver Pay payment method.
471 472 473 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 471 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object
If this is an nz_bank_account PaymentMethod, this hash contains details about the nz_bank_account payment method.
473 474 475 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 473 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object
If this is an oxxo PaymentMethod, this hash contains details about the OXXO payment method.
475 476 477 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 475 def oxxo @oxxo end |
#p24 ⇒ Object
If this is a p24 PaymentMethod, this hash contains details about the P24 payment method.
477 478 479 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 477 def p24 @p24 end |
#pay_by_bank ⇒ Object
If this is a pay_by_bank PaymentMethod, this hash contains details about the PayByBank payment method.
479 480 481 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 479 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object
If this is a payco PaymentMethod, this hash contains details about the PAYCO payment method.
481 482 483 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 481 def payco @payco end |
#payment_method ⇒ Object
The PaymentMethod to share.
483 484 485 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 483 def payment_method @payment_method end |
#paynow ⇒ Object
If this is a paynow PaymentMethod, this hash contains details about the PayNow payment method.
485 486 487 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 485 def paynow @paynow end |
#paypal ⇒ Object
If this is a paypal PaymentMethod, this hash contains details about the PayPal payment method.
487 488 489 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 487 def paypal @paypal end |
#payto ⇒ Object
If this is a payto PaymentMethod, this hash contains details about the PayTo payment method.
489 490 491 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 489 def payto @payto end |
#pix ⇒ Object
If this is a pix PaymentMethod, this hash contains details about the Pix payment method.
491 492 493 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 491 def pix @pix end |
#promptpay ⇒ Object
If this is a promptpay PaymentMethod, this hash contains details about the PromptPay payment method.
493 494 495 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 493 def promptpay @promptpay end |
#radar_options ⇒ Object
Options to configure Radar. See [Radar Session](docs.stripe.com/radar/radar-session) for more information.
495 496 497 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 495 def end |
#revolut_pay ⇒ Object
If this is a revolut_pay PaymentMethod, this hash contains details about the Revolut Pay payment method.
497 498 499 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 497 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object
If this is a samsung_pay PaymentMethod, this hash contains details about the SamsungPay payment method.
499 500 501 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 499 def samsung_pay @samsung_pay end |
#satispay ⇒ Object
If this is a satispay PaymentMethod, this hash contains details about the Satispay payment method.
501 502 503 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 501 def satispay @satispay end |
#sepa_debit ⇒ Object
If this is a sepa_debit PaymentMethod, this hash contains details about the SEPA debit bank account.
503 504 505 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 503 def sepa_debit @sepa_debit end |
#sofort ⇒ Object
If this is a sofort PaymentMethod, this hash contains details about the SOFORT payment method.
505 506 507 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 505 def sofort @sofort end |
#swish ⇒ Object
If this is a swish PaymentMethod, this hash contains details about the Swish payment method.
507 508 509 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 507 def swish @swish end |
#twint ⇒ Object
If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.
509 510 511 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 509 def twint @twint end |
#type ⇒ Object
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
511 512 513 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 511 def type @type end |
#upi ⇒ Object
If this is a upi PaymentMethod, this hash contains details about the UPI payment method.
513 514 515 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 513 def upi @upi end |
#us_bank_account ⇒ Object
If this is an us_bank_account PaymentMethod, this hash contains details about the US bank account payment method.
515 516 517 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 515 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
If this is an wechat_pay PaymentMethod, this hash contains details about the wechat_pay payment method.
517 518 519 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 517 def wechat_pay @wechat_pay end |
#zip ⇒ Object
If this is a zip PaymentMethod, this hash contains details about the Zip payment method.
519 520 521 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 519 def zip @zip end |