Class: Stripe::PaymentMethodCreateParams::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodCreateParams::NzBankAccount
- Defined in:
- lib/stripe/params/payment_method_create_params.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 248 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
236 237 238 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 236 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
238 239 240 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 238 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
240 241 242 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 240 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
242 243 244 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 242 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
244 245 246 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 244 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
246 247 248 |
# File 'lib/stripe/params/payment_method_create_params.rb', line 246 def suffix @suffix end |