Class: Stripe::PaymentMethodCreateParams::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_method_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



413
414
415
416
417
418
# File 'lib/stripe/params/payment_method_create_params.rb', line 413

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



405
406
407
# File 'lib/stripe/params/payment_method_create_params.rb', line 405

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



407
408
409
# File 'lib/stripe/params/payment_method_create_params.rb', line 407

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



409
410
411
# File 'lib/stripe/params/payment_method_create_params.rb', line 409

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



411
412
413
# File 'lib/stripe/params/payment_method_create_params.rb', line 411

def end_date
  @end_date
end