Class: Stripe::PaymentMethodDomain

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/payment_method_domain.rb

Overview

A payment method domain represents a web domain that you have registered with Stripe. Stripe Elements use registered payment method domains to control where certain payment methods are shown.

Related guide: [Payment method domains](stripe.com/docs/payments/payment-methods/pmd-registration).

Defined Under Namespace

Classes: AmazonPay, ApplePay, CreateParams, GooglePay, Link, ListParams, Paypal, RetrieveParams, UpdateParams, ValidateParams

Constant Summary collapse

OBJECT_NAME =
"payment_method_domain"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amazon_payObject (readonly)

Indicates the status of a specific payment method on a payment method domain.



163
164
165
# File 'lib/stripe/resources/payment_method_domain.rb', line 163

def amazon_pay
  @amazon_pay
end

#apple_payObject (readonly)

Indicates the status of a specific payment method on a payment method domain.



166
167
168
# File 'lib/stripe/resources/payment_method_domain.rb', line 166

def apple_pay
  @apple_pay
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



169
170
171
# File 'lib/stripe/resources/payment_method_domain.rb', line 169

def created
  @created
end

#domain_nameObject (readonly)

The domain name that this payment method domain object represents.



172
173
174
# File 'lib/stripe/resources/payment_method_domain.rb', line 172

def domain_name
  @domain_name
end

#enabledObject (readonly)

Whether this payment method domain is enabled. If the domain is not enabled, payment methods that require a payment method domain will not appear in Elements.



175
176
177
# File 'lib/stripe/resources/payment_method_domain.rb', line 175

def enabled
  @enabled
end

#google_payObject (readonly)

Indicates the status of a specific payment method on a payment method domain.



178
179
180
# File 'lib/stripe/resources/payment_method_domain.rb', line 178

def google_pay
  @google_pay
end

#idObject (readonly)

Unique identifier for the object.



181
182
183
# File 'lib/stripe/resources/payment_method_domain.rb', line 181

def id
  @id
end

Indicates the status of a specific payment method on a payment method domain.



184
185
186
# File 'lib/stripe/resources/payment_method_domain.rb', line 184

def link
  @link
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



187
188
189
# File 'lib/stripe/resources/payment_method_domain.rb', line 187

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



190
191
192
# File 'lib/stripe/resources/payment_method_domain.rb', line 190

def object
  @object
end

#paypalObject (readonly)

Indicates the status of a specific payment method on a payment method domain.



193
194
195
# File 'lib/stripe/resources/payment_method_domain.rb', line 193

def paypal
  @paypal
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a payment method domain.



196
197
198
199
200
201
202
203
# File 'lib/stripe/resources/payment_method_domain.rb', line 196

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/payment_method_domains",
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

Lists the details of existing payment method domains.



206
207
208
209
210
211
212
213
# File 'lib/stripe/resources/payment_method_domain.rb', line 206

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/payment_method_domains",
    params: params,
    opts: opts
  )
end

.object_nameObject



15
16
17
# File 'lib/stripe/resources/payment_method_domain.rb', line 15

def self.object_name
  "payment_method_domain"
end

.update(id, params = {}, opts = {}) ⇒ Object

Updates an existing payment method domain.



216
217
218
219
220
221
222
223
# File 'lib/stripe/resources/payment_method_domain.rb', line 216

def self.update(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_method_domains/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.validate(payment_method_domain, params = {}, opts = {}) ⇒ Object

Some payment methods such as Apple Pay require additional steps to verify a domain. If the requirements weren’t satisfied when the domain was created, the payment method will be inactive on the domain. The payment method doesn’t appear in Elements for this domain until it is active.

To activate a payment method on an existing payment method domain, complete the required validation steps specific to the payment method, and then validate the payment method domain with this endpoint.

Related guides: [Payment method domains](stripe.com/docs/payments/payment-methods/pmd-registration).



246
247
248
249
250
251
252
253
# File 'lib/stripe/resources/payment_method_domain.rb', line 246

def self.validate(payment_method_domain, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_method_domains/%<payment_method_domain>s/validate", { payment_method_domain: CGI.escape(payment_method_domain) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#validate(params = {}, opts = {}) ⇒ Object

Some payment methods such as Apple Pay require additional steps to verify a domain. If the requirements weren’t satisfied when the domain was created, the payment method will be inactive on the domain. The payment method doesn’t appear in Elements for this domain until it is active.

To activate a payment method on an existing payment method domain, complete the required validation steps specific to the payment method, and then validate the payment method domain with this endpoint.

Related guides: [Payment method domains](stripe.com/docs/payments/payment-methods/pmd-registration).



231
232
233
234
235
236
237
238
# File 'lib/stripe/resources/payment_method_domain.rb', line 231

def validate(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_method_domains/%<payment_method_domain>s/validate", { payment_method_domain: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end