Class: Stripe::PaymentMethodDomain
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::PaymentMethodDomain
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/payment_method_domain.rb
Overview
A payment method domain represents a web domain that you have registered with Stripe. Stripe Elements use registered payment method domains to control where certain payment methods are shown.
Related guide: [Payment method domains](stripe.com/docs/payments/payment-methods/pmd-registration).
Defined Under Namespace
Classes: AmazonPay, ApplePay, CreateParams, GooglePay, Link, ListParams, Paypal, RetrieveParams, UpdateParams, ValidateParams
Constant Summary collapse
- OBJECT_NAME =
"payment_method_domain"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amazon_pay ⇒ Object
readonly
Indicates the status of a specific payment method on a payment method domain.
-
#apple_pay ⇒ Object
readonly
Indicates the status of a specific payment method on a payment method domain.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#domain_name ⇒ Object
readonly
The domain name that this payment method domain object represents.
-
#enabled ⇒ Object
readonly
Whether this payment method domain is enabled.
-
#google_pay ⇒ Object
readonly
Indicates the status of a specific payment method on a payment method domain.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#link ⇒ Object
readonly
Indicates the status of a specific payment method on a payment method domain.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#paypal ⇒ Object
readonly
Indicates the status of a specific payment method on a payment method domain.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a payment method domain.
-
.list(params = {}, opts = {}) ⇒ Object
Lists the details of existing payment method domains.
- .object_name ⇒ Object
-
.update(id, params = {}, opts = {}) ⇒ Object
Updates an existing payment method domain.
-
.validate(payment_method_domain, params = {}, opts = {}) ⇒ Object
Some payment methods such as Apple Pay require additional steps to verify a domain.
Instance Method Summary collapse
-
#validate(params = {}, opts = {}) ⇒ Object
Some payment methods such as Apple Pay require additional steps to verify a domain.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amazon_pay ⇒ Object (readonly)
Indicates the status of a specific payment method on a payment method domain.
150 151 152 |
# File 'lib/stripe/resources/payment_method_domain.rb', line 150 def amazon_pay @amazon_pay end |
#apple_pay ⇒ Object (readonly)
Indicates the status of a specific payment method on a payment method domain.
152 153 154 |
# File 'lib/stripe/resources/payment_method_domain.rb', line 152 def apple_pay @apple_pay end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
154 155 156 |
# File 'lib/stripe/resources/payment_method_domain.rb', line 154 def created @created end |
#domain_name ⇒ Object (readonly)
The domain name that this payment method domain object represents.
156 157 158 |
# File 'lib/stripe/resources/payment_method_domain.rb', line 156 def domain_name @domain_name end |
#enabled ⇒ Object (readonly)
Whether this payment method domain is enabled. If the domain is not enabled, payment methods that require a payment method domain will not appear in Elements.
158 159 160 |
# File 'lib/stripe/resources/payment_method_domain.rb', line 158 def enabled @enabled end |
#google_pay ⇒ Object (readonly)
Indicates the status of a specific payment method on a payment method domain.
160 161 162 |
# File 'lib/stripe/resources/payment_method_domain.rb', line 160 def google_pay @google_pay end |
#id ⇒ Object (readonly)
Unique identifier for the object.
162 163 164 |
# File 'lib/stripe/resources/payment_method_domain.rb', line 162 def id @id end |
#link ⇒ Object (readonly)
Indicates the status of a specific payment method on a payment method domain.
164 165 166 |
# File 'lib/stripe/resources/payment_method_domain.rb', line 164 def link @link end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
166 167 168 |
# File 'lib/stripe/resources/payment_method_domain.rb', line 166 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
168 169 170 |
# File 'lib/stripe/resources/payment_method_domain.rb', line 168 def object @object end |
#paypal ⇒ Object (readonly)
Indicates the status of a specific payment method on a payment method domain.
170 171 172 |
# File 'lib/stripe/resources/payment_method_domain.rb', line 170 def paypal @paypal end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a payment method domain.
173 174 175 176 177 178 179 180 |
# File 'lib/stripe/resources/payment_method_domain.rb', line 173 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/payment_method_domains", params: params, opts: opts ) end |
.list(params = {}, opts = {}) ⇒ Object
Lists the details of existing payment method domains.
183 184 185 186 187 188 189 190 |
# File 'lib/stripe/resources/payment_method_domain.rb', line 183 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/payment_method_domains", params: params, opts: opts ) end |
.object_name ⇒ Object
15 16 17 |
# File 'lib/stripe/resources/payment_method_domain.rb', line 15 def self.object_name "payment_method_domain" end |
.update(id, params = {}, opts = {}) ⇒ Object
Updates an existing payment method domain.
193 194 195 196 197 198 199 200 |
# File 'lib/stripe/resources/payment_method_domain.rb', line 193 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_method_domains/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |
.validate(payment_method_domain, params = {}, opts = {}) ⇒ Object
Some payment methods such as Apple Pay require additional steps to verify a domain. If the requirements weren’t satisfied when the domain was created, the payment method will be inactive on the domain. The payment method doesn’t appear in Elements for this domain until it is active.
To activate a payment method on an existing payment method domain, complete the required validation steps specific to the payment method, and then validate the payment method domain with this endpoint.
Related guides: [Payment method domains](stripe.com/docs/payments/payment-methods/pmd-registration).
223 224 225 226 227 228 229 230 |
# File 'lib/stripe/resources/payment_method_domain.rb', line 223 def self.validate(payment_method_domain, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_method_domains/%<payment_method_domain>s/validate", { payment_method_domain: CGI.escape(payment_method_domain) }), params: params, opts: opts ) end |
Instance Method Details
#validate(params = {}, opts = {}) ⇒ Object
Some payment methods such as Apple Pay require additional steps to verify a domain. If the requirements weren’t satisfied when the domain was created, the payment method will be inactive on the domain. The payment method doesn’t appear in Elements for this domain until it is active.
To activate a payment method on an existing payment method domain, complete the required validation steps specific to the payment method, and then validate the payment method domain with this endpoint.
Related guides: [Payment method domains](stripe.com/docs/payments/payment-methods/pmd-registration).
208 209 210 211 212 213 214 215 |
# File 'lib/stripe/resources/payment_method_domain.rb', line 208 def validate(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_method_domains/%<payment_method_domain>s/validate", { payment_method_domain: CGI.escape(self["id"]) }), params: params, opts: opts ) end |