Class: Stripe::PaymentMethodDomain

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/payment_method_domain.rb

Overview

A payment method domain represents a web domain that you have registered with Stripe. Stripe Elements use registered payment method domains to control where certain payment methods are shown.

Related guide: [Payment method domains](stripe.com/docs/payments/payment-methods/pmd-registration).

Defined Under Namespace

Classes: AmazonPay, ApplePay, GooglePay, Link, Paypal

Constant Summary collapse

OBJECT_NAME =
"payment_method_domain"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amazon_payObject (readonly)

Indicates the status of a specific payment method on a payment method domain.



54
55
56
# File 'lib/stripe/resources/payment_method_domain.rb', line 54

def amazon_pay
  @amazon_pay
end

#apple_payObject (readonly)

Indicates the status of a specific payment method on a payment method domain.



56
57
58
# File 'lib/stripe/resources/payment_method_domain.rb', line 56

def apple_pay
  @apple_pay
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



58
59
60
# File 'lib/stripe/resources/payment_method_domain.rb', line 58

def created
  @created
end

#domain_nameObject (readonly)

The domain name that this payment method domain object represents.



60
61
62
# File 'lib/stripe/resources/payment_method_domain.rb', line 60

def domain_name
  @domain_name
end

#enabledObject (readonly)

Whether this payment method domain is enabled. If the domain is not enabled, payment methods that require a payment method domain will not appear in Elements.



62
63
64
# File 'lib/stripe/resources/payment_method_domain.rb', line 62

def enabled
  @enabled
end

#google_payObject (readonly)

Indicates the status of a specific payment method on a payment method domain.



64
65
66
# File 'lib/stripe/resources/payment_method_domain.rb', line 64

def google_pay
  @google_pay
end

#idObject (readonly)

Unique identifier for the object.



66
67
68
# File 'lib/stripe/resources/payment_method_domain.rb', line 66

def id
  @id
end

Indicates the status of a specific payment method on a payment method domain.



68
69
70
# File 'lib/stripe/resources/payment_method_domain.rb', line 68

def link
  @link
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



70
71
72
# File 'lib/stripe/resources/payment_method_domain.rb', line 70

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



72
73
74
# File 'lib/stripe/resources/payment_method_domain.rb', line 72

def object
  @object
end

#paypalObject (readonly)

Indicates the status of a specific payment method on a payment method domain.



74
75
76
# File 'lib/stripe/resources/payment_method_domain.rb', line 74

def paypal
  @paypal
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a payment method domain.



77
78
79
80
81
82
83
84
# File 'lib/stripe/resources/payment_method_domain.rb', line 77

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/payment_method_domains",
    params: params,
    opts: opts
  )
end

.list(filters = {}, opts = {}) ⇒ Object

Lists the details of existing payment method domains.



87
88
89
90
91
92
93
94
# File 'lib/stripe/resources/payment_method_domain.rb', line 87

def self.list(filters = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/payment_method_domains",
    params: filters,
    opts: opts
  )
end

.object_nameObject



15
16
17
# File 'lib/stripe/resources/payment_method_domain.rb', line 15

def self.object_name
  "payment_method_domain"
end

.update(id, params = {}, opts = {}) ⇒ Object

Updates an existing payment method domain.



97
98
99
100
101
102
103
104
# File 'lib/stripe/resources/payment_method_domain.rb', line 97

def self.update(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_method_domains/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.validate(payment_method_domain, params = {}, opts = {}) ⇒ Object

Some payment methods such as Apple Pay require additional steps to verify a domain. If the requirements weren’t satisfied when the domain was created, the payment method will be inactive on the domain. The payment method doesn’t appear in Elements for this domain until it is active.

To activate a payment method on an existing payment method domain, complete the required validation steps specific to the payment method, and then validate the payment method domain with this endpoint.

Related guides: [Payment method domains](stripe.com/docs/payments/payment-methods/pmd-registration).



127
128
129
130
131
132
133
134
# File 'lib/stripe/resources/payment_method_domain.rb', line 127

def self.validate(payment_method_domain, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_method_domains/%<payment_method_domain>s/validate", { payment_method_domain: CGI.escape(payment_method_domain) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#validate(params = {}, opts = {}) ⇒ Object

Some payment methods such as Apple Pay require additional steps to verify a domain. If the requirements weren’t satisfied when the domain was created, the payment method will be inactive on the domain. The payment method doesn’t appear in Elements for this domain until it is active.

To activate a payment method on an existing payment method domain, complete the required validation steps specific to the payment method, and then validate the payment method domain with this endpoint.

Related guides: [Payment method domains](stripe.com/docs/payments/payment-methods/pmd-registration).



112
113
114
115
116
117
118
119
# File 'lib/stripe/resources/payment_method_domain.rb', line 112

def validate(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_method_domains/%<payment_method_domain>s/validate", { payment_method_domain: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end