Class: Stripe::PaymentMethodDomain::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_method_domain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(domain_name: nil, enabled: nil, expand: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



125
126
127
128
129
# File 'lib/stripe/resources/payment_method_domain.rb', line 125

def initialize(domain_name: nil, enabled: nil, expand: nil)
  @domain_name = domain_name
  @enabled = enabled
  @expand = expand
end

Instance Attribute Details

#domain_nameObject

The domain name that this payment method domain object represents.



117
118
119
# File 'lib/stripe/resources/payment_method_domain.rb', line 117

def domain_name
  @domain_name
end

#enabledObject

Whether this payment method domain is enabled. If the domain is not enabled, payment methods that require a payment method domain will not appear in Elements.



120
121
122
# File 'lib/stripe/resources/payment_method_domain.rb', line 120

def enabled
  @enabled
end

#expandObject

Specifies which fields in the response should be expanded.



123
124
125
# File 'lib/stripe/resources/payment_method_domain.rb', line 123

def expand
  @expand
end