Class: Stripe::PaymentMethodDomain::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodDomain::CreateParams
- Defined in:
- lib/stripe/resources/payment_method_domain.rb
Instance Attribute Summary collapse
-
#domain_name ⇒ Object
The domain name that this payment method domain object represents.
-
#enabled ⇒ Object
Whether this payment method domain is enabled.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(domain_name: nil, enabled: nil, expand: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(domain_name: nil, enabled: nil, expand: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
125 126 127 128 129 |
# File 'lib/stripe/resources/payment_method_domain.rb', line 125 def initialize(domain_name: nil, enabled: nil, expand: nil) @domain_name = domain_name @enabled = enabled @expand = end |
Instance Attribute Details
#domain_name ⇒ Object
The domain name that this payment method domain object represents.
117 118 119 |
# File 'lib/stripe/resources/payment_method_domain.rb', line 117 def domain_name @domain_name end |
#enabled ⇒ Object
Whether this payment method domain is enabled. If the domain is not enabled, payment methods that require a payment method domain will not appear in Elements.
120 121 122 |
# File 'lib/stripe/resources/payment_method_domain.rb', line 120 def enabled @enabled end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
123 124 125 |
# File 'lib/stripe/resources/payment_method_domain.rb', line 123 def @expand end |