Class: Stripe::PaymentMethodDomainService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_method_domain_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(domain_name: nil, enabled: nil, expand: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



52
53
54
55
56
# File 'lib/stripe/services/payment_method_domain_service.rb', line 52

def initialize(domain_name: nil, enabled: nil, expand: nil)
  @domain_name = domain_name
  @enabled = enabled
  @expand = expand
end

Instance Attribute Details

#domain_nameObject

The domain name that this payment method domain object represents.



44
45
46
# File 'lib/stripe/services/payment_method_domain_service.rb', line 44

def domain_name
  @domain_name
end

#enabledObject

Whether this payment method domain is enabled. If the domain is not enabled, payment methods that require a payment method domain will not appear in Elements.



47
48
49
# File 'lib/stripe/services/payment_method_domain_service.rb', line 47

def enabled
  @enabled
end

#expandObject

Specifies which fields in the response should be expanded.



50
51
52
# File 'lib/stripe/services/payment_method_domain_service.rb', line 50

def expand
  @expand
end