Class: Stripe::PaymentMethodDomainService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_method_domain_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(domain_name: nil, enabled: nil, expand: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



45
46
47
48
49
# File 'lib/stripe/services/payment_method_domain_service.rb', line 45

def initialize(domain_name: nil, enabled: nil, expand: nil)
  @domain_name = domain_name
  @enabled = enabled
  @expand = expand
end

Instance Attribute Details

#domain_nameObject

The domain name that this payment method domain object represents.



39
40
41
# File 'lib/stripe/services/payment_method_domain_service.rb', line 39

def domain_name
  @domain_name
end

#enabledObject

Whether this payment method domain is enabled. If the domain is not enabled, payment methods that require a payment method domain will not appear in Elements.



41
42
43
# File 'lib/stripe/services/payment_method_domain_service.rb', line 41

def enabled
  @enabled
end

#expandObject

Specifies which fields in the response should be expanded.



43
44
45
# File 'lib/stripe/services/payment_method_domain_service.rb', line 43

def expand
  @expand
end