Class: Stripe::PaymentMethodService

Inherits:
StripeService show all
Defined in:
lib/stripe/services/payment_method_service.rb

Defined Under Namespace

Classes: AttachParams, CreateParams, DetachParams, ListParams, RetrieveParams, UpdateParams

Instance Method Summary collapse

Methods inherited from StripeService

#initialize, #request, #request_stream

Constructor Details

This class inherits a constructor from Stripe::StripeService

Instance Method Details

#attach(payment_method, params = {}, opts = {}) ⇒ Object

Attaches a PaymentMethod object to a Customer.

To attach a new PaymentMethod to a customer for future payments, we recommend you use a [SetupIntent](stripe.com/docs/api/setup_intents) or a PaymentIntent with [setup_future_usage](stripe.com/docs/api/payment_intents/create#create_payment_intent-setup_future_usage). These approaches will perform any necessary steps to set up the PaymentMethod for future payments. Using the /v1/payment_methods/:id/attach endpoint without first using a SetupIntent or PaymentIntent with setup_future_usage does not optimize the PaymentMethod for future use, which makes later declines and payment friction more likely. See [Optimizing cards for future payments](stripe.com/docs/payments/payment-intents#future-usage) for more information about setting up future payments.

To use this PaymentMethod as the default for invoice or subscription payments, set [invoice_settings.default_payment_method](stripe.com/docs/api/customers/update#update_customer-invoice_settings-default_payment_method), on the Customer to the PaymentMethod’s ID.



833
834
835
836
837
838
839
840
841
# File 'lib/stripe/services/payment_method_service.rb', line 833

def attach(payment_method, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/payment_methods/%<payment_method>s/attach", { payment_method: CGI.escape(payment_method) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#create(params = {}, opts = {}) ⇒ Object

Creates a PaymentMethod object. Read the [Stripe.js reference](stripe.com/docs/stripe-js/reference#stripe-create-payment-method) to learn how to create PaymentMethods via Stripe.js.

Instead of creating a PaymentMethod directly, we recommend using the [PaymentIntents API to accept a payment immediately or the <a href=“/docs/payments/save-and-reuse”>SetupIntent](stripe.com/docs/payments/accept-a-payment) API to collect payment method details ahead of a future payment.



846
847
848
849
850
851
852
853
854
# File 'lib/stripe/services/payment_method_service.rb', line 846

def create(params = {}, opts = {})
  request(
    method: :post,
    path: "/v1/payment_methods",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#detach(payment_method, params = {}, opts = {}) ⇒ Object

Detaches a PaymentMethod object from a Customer. After a PaymentMethod is detached, it can no longer be used for a payment or re-attached to a Customer.



857
858
859
860
861
862
863
864
865
# File 'lib/stripe/services/payment_method_service.rb', line 857

def detach(payment_method, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/payment_methods/%<payment_method>s/detach", { payment_method: CGI.escape(payment_method) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#list(params = {}, opts = {}) ⇒ Object

Returns a list of PaymentMethods for Treasury flows. If you want to list the PaymentMethods attached to a Customer for payments, you should use the [List a Customer’s PaymentMethods](stripe.com/docs/api/payment_methods/customer_list) API instead.



868
869
870
871
872
873
874
875
876
# File 'lib/stripe/services/payment_method_service.rb', line 868

def list(params = {}, opts = {})
  request(
    method: :get,
    path: "/v1/payment_methods",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#retrieve(payment_method, params = {}, opts = {}) ⇒ Object

Retrieves a PaymentMethod object attached to the StripeAccount. To retrieve a payment method attached to a Customer, you should use [Retrieve a Customer’s PaymentMethods](stripe.com/docs/api/payment_methods/customer)



879
880
881
882
883
884
885
886
887
# File 'lib/stripe/services/payment_method_service.rb', line 879

def retrieve(payment_method, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v1/payment_methods/%<payment_method>s", { payment_method: CGI.escape(payment_method) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#update(payment_method, params = {}, opts = {}) ⇒ Object

Updates a PaymentMethod object. A PaymentMethod must be attached a customer to be updated.



890
891
892
893
894
895
896
897
898
# File 'lib/stripe/services/payment_method_service.rb', line 890

def update(payment_method, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/payment_methods/%<payment_method>s", { payment_method: CGI.escape(payment_method) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end