Class: Stripe::PaymentMethodService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::PaymentMethodService
- Defined in:
- lib/stripe/services/payment_method_service.rb
Defined Under Namespace
Classes: AttachParams, CreateParams, DetachParams, ListParams, RetrieveParams, UpdateParams
Instance Method Summary collapse
-
#attach(payment_method, params = {}, opts = {}) ⇒ Object
Attaches a PaymentMethod object to a Customer.
-
#create(params = {}, opts = {}) ⇒ Object
Creates a PaymentMethod object.
-
#detach(payment_method, params = {}, opts = {}) ⇒ Object
Detaches a PaymentMethod object from a Customer.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of PaymentMethods for Treasury flows.
-
#retrieve(payment_method, params = {}, opts = {}) ⇒ Object
Retrieves a PaymentMethod object attached to the StripeAccount.
-
#update(payment_method, params = {}, opts = {}) ⇒ Object
Updates a PaymentMethod object.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#attach(payment_method, params = {}, opts = {}) ⇒ Object
Attaches a PaymentMethod object to a Customer.
To attach a new PaymentMethod to a customer for future payments, we recommend you use a [SetupIntent](stripe.com/docs/api/setup_intents) or a PaymentIntent with [setup_future_usage](stripe.com/docs/api/payment_intents/create#create_payment_intent-setup_future_usage). These approaches will perform any necessary steps to set up the PaymentMethod for future payments. Using the /v1/payment_methods/:id/attach endpoint without first using a SetupIntent or PaymentIntent with setup_future_usage does not optimize the PaymentMethod for future use, which makes later declines and payment friction more likely. See [Optimizing cards for future payments](stripe.com/docs/payments/payment-intents#future-usage) for more information about setting up future payments.
To use this PaymentMethod as the default for invoice or subscription payments, set [invoice_settings.default_payment_method](stripe.com/docs/api/customers/update#update_customer-invoice_settings-default_payment_method), on the Customer to the PaymentMethod’s ID.
958 959 960 961 962 963 964 965 966 |
# File 'lib/stripe/services/payment_method_service.rb', line 958 def attach(payment_method, params = {}, opts = {}) request( method: :post, path: format("/v1/payment_methods/%<payment_method>s/attach", { payment_method: CGI.escape(payment_method) }), params: params, opts: opts, base_address: :api ) end |
#create(params = {}, opts = {}) ⇒ Object
Creates a PaymentMethod object. Read the [Stripe.js reference](stripe.com/docs/stripe-js/reference#stripe-create-payment-method) to learn how to create PaymentMethods via Stripe.js.
Instead of creating a PaymentMethod directly, we recommend using the [PaymentIntents API to accept a payment immediately or the <a href=“/docs/payments/save-and-reuse”>SetupIntent](stripe.com/docs/payments/accept-a-payment) API to collect payment method details ahead of a future payment.
971 972 973 974 975 976 977 978 979 |
# File 'lib/stripe/services/payment_method_service.rb', line 971 def create(params = {}, opts = {}) request( method: :post, path: "/v1/payment_methods", params: params, opts: opts, base_address: :api ) end |
#detach(payment_method, params = {}, opts = {}) ⇒ Object
Detaches a PaymentMethod object from a Customer. After a PaymentMethod is detached, it can no longer be used for a payment or re-attached to a Customer.
982 983 984 985 986 987 988 989 990 |
# File 'lib/stripe/services/payment_method_service.rb', line 982 def detach(payment_method, params = {}, opts = {}) request( method: :post, path: format("/v1/payment_methods/%<payment_method>s/detach", { payment_method: CGI.escape(payment_method) }), params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of PaymentMethods for Treasury flows. If you want to list the PaymentMethods attached to a Customer for payments, you should use the [List a Customer’s PaymentMethods](stripe.com/docs/api/payment_methods/customer_list) API instead.
993 994 995 996 997 998 999 1000 1001 |
# File 'lib/stripe/services/payment_method_service.rb', line 993 def list(params = {}, opts = {}) request( method: :get, path: "/v1/payment_methods", params: params, opts: opts, base_address: :api ) end |
#retrieve(payment_method, params = {}, opts = {}) ⇒ Object
Retrieves a PaymentMethod object attached to the StripeAccount. To retrieve a payment method attached to a Customer, you should use [Retrieve a Customer’s PaymentMethods](stripe.com/docs/api/payment_methods/customer)
1004 1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/stripe/services/payment_method_service.rb', line 1004 def retrieve(payment_method, params = {}, opts = {}) request( method: :get, path: format("/v1/payment_methods/%<payment_method>s", { payment_method: CGI.escape(payment_method) }), params: params, opts: opts, base_address: :api ) end |
#update(payment_method, params = {}, opts = {}) ⇒ Object
Updates a PaymentMethod object. A PaymentMethod must be attached a customer to be updated.
1015 1016 1017 1018 1019 1020 1021 1022 1023 |
# File 'lib/stripe/services/payment_method_service.rb', line 1015 def update(payment_method, params = {}, opts = {}) request( method: :post, path: format("/v1/payment_methods/%<payment_method>s", { payment_method: CGI.escape(payment_method) }), params: params, opts: opts, base_address: :api ) end |