Class: Stripe::PaymentMethodService::AttachParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_method_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, expand: nil) ⇒ AttachParams

Returns a new instance of AttachParams.



753
754
755
756
# File 'lib/stripe/services/payment_method_service.rb', line 753

def initialize(customer: nil, expand: nil)
  @customer = customer
  @expand = expand
end

Instance Attribute Details

#customerObject

The ID of the customer to which to attach the PaymentMethod.



749
750
751
# File 'lib/stripe/services/payment_method_service.rb', line 749

def customer
  @customer
end

#expandObject

Specifies which fields in the response should be expanded.



751
752
753
# File 'lib/stripe/services/payment_method_service.rb', line 751

def expand
  @expand
end