Class: Stripe::PaymentMethodService::AttachParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodService::AttachParams
- Defined in:
- lib/stripe/services/payment_method_service.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of the customer to which to attach the PaymentMethod.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(customer: nil, expand: nil) ⇒ AttachParams
constructor
A new instance of AttachParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, expand: nil) ⇒ AttachParams
Returns a new instance of AttachParams.
753 754 755 756 |
# File 'lib/stripe/services/payment_method_service.rb', line 753 def initialize(customer: nil, expand: nil) @customer = customer @expand = end |
Instance Attribute Details
#customer ⇒ Object
The ID of the customer to which to attach the PaymentMethod.
749 750 751 |
# File 'lib/stripe/services/payment_method_service.rb', line 749 def customer @customer end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
751 752 753 |
# File 'lib/stripe/services/payment_method_service.rb', line 751 def @expand end |