Class: Stripe::PaymentMethodService::AttachParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodService::AttachParams
- Defined in:
- lib/stripe/services/payment_method_service.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of the customer to which to attach the PaymentMethod.
-
#customer_account ⇒ Object
The ID of the account to which to attach the PaymentMethod.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(customer: nil, customer_account: nil, expand: nil) ⇒ AttachParams
constructor
A new instance of AttachParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, customer_account: nil, expand: nil) ⇒ AttachParams
Returns a new instance of AttachParams.
871 872 873 874 875 |
# File 'lib/stripe/services/payment_method_service.rb', line 871 def initialize(customer: nil, customer_account: nil, expand: nil) @customer = customer @customer_account = customer_account @expand = end |
Instance Attribute Details
#customer ⇒ Object
The ID of the customer to which to attach the PaymentMethod.
865 866 867 |
# File 'lib/stripe/services/payment_method_service.rb', line 865 def customer @customer end |
#customer_account ⇒ Object
The ID of the account to which to attach the PaymentMethod.
867 868 869 |
# File 'lib/stripe/services/payment_method_service.rb', line 867 def customer_account @customer_account end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
869 870 871 |
# File 'lib/stripe/services/payment_method_service.rb', line 869 def @expand end |