Class: Stripe::PaymentMethodService::AttachParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_method_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, customer_account: nil, expand: nil) ⇒ AttachParams

Returns a new instance of AttachParams.



866
867
868
869
870
# File 'lib/stripe/services/payment_method_service.rb', line 866

def initialize(customer: nil, customer_account: nil, expand: nil)
  @customer = customer
  @customer_account = 
  @expand = expand
end

Instance Attribute Details

#customerObject

The ID of the customer to which to attach the PaymentMethod.



860
861
862
# File 'lib/stripe/services/payment_method_service.rb', line 860

def customer
  @customer
end

#customer_accountObject

The ID of the account to which to attach the PaymentMethod.



862
863
864
# File 'lib/stripe/services/payment_method_service.rb', line 862

def 
  @customer_account
end

#expandObject

Specifies which fields in the response should be expanded.



864
865
866
# File 'lib/stripe/services/payment_method_service.rb', line 864

def expand
  @expand
end