Class: Stripe::PaymentMethodService::AttachParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodService::AttachParams
- Defined in:
- lib/stripe/services/payment_method_service.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of the customer to which to attach the PaymentMethod.
-
#customer_account ⇒ Object
The ID of the account to which to attach the PaymentMethod.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(customer: nil, customer_account: nil, expand: nil) ⇒ AttachParams
constructor
A new instance of AttachParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, customer_account: nil, expand: nil) ⇒ AttachParams
Returns a new instance of AttachParams.
866 867 868 869 870 |
# File 'lib/stripe/services/payment_method_service.rb', line 866 def initialize(customer: nil, customer_account: nil, expand: nil) @customer = customer @customer_account = customer_account @expand = end |
Instance Attribute Details
#customer ⇒ Object
The ID of the customer to which to attach the PaymentMethod.
860 861 862 |
# File 'lib/stripe/services/payment_method_service.rb', line 860 def customer @customer end |
#customer_account ⇒ Object
The ID of the account to which to attach the PaymentMethod.
862 863 864 |
# File 'lib/stripe/services/payment_method_service.rb', line 862 def customer_account @customer_account end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
864 865 866 |
# File 'lib/stripe/services/payment_method_service.rb', line 864 def @expand end |