Class: Stripe::PaymentMethodService::AttachParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_method_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, customer_account: nil, expand: nil) ⇒ AttachParams

Returns a new instance of AttachParams.



929
930
931
932
933
# File 'lib/stripe/services/payment_method_service.rb', line 929

def initialize(customer: nil, customer_account: nil, expand: nil)
  @customer = customer
  @customer_account = 
  @expand = expand
end

Instance Attribute Details

#customerObject

The ID of the customer to which to attach the PaymentMethod.



923
924
925
# File 'lib/stripe/services/payment_method_service.rb', line 923

def customer
  @customer
end

#customer_accountObject

The ID of the account to which to attach the PaymentMethod.



925
926
927
# File 'lib/stripe/services/payment_method_service.rb', line 925

def 
  @customer_account
end

#expandObject

Specifies which fields in the response should be expanded.



927
928
929
# File 'lib/stripe/services/payment_method_service.rb', line 927

def expand
  @expand
end