Class: Stripe::PaymentMethodService::AttachParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodService::AttachParams
- Defined in:
- lib/stripe/services/payment_method_service.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of the customer to which to attach the PaymentMethod.
-
#customer_account ⇒ Object
The ID of the account to which to attach the PaymentMethod.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(customer: nil, customer_account: nil, expand: nil) ⇒ AttachParams
constructor
A new instance of AttachParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, customer_account: nil, expand: nil) ⇒ AttachParams
Returns a new instance of AttachParams.
929 930 931 932 933 |
# File 'lib/stripe/services/payment_method_service.rb', line 929 def initialize(customer: nil, customer_account: nil, expand: nil) @customer = customer @customer_account = customer_account @expand = end |
Instance Attribute Details
#customer ⇒ Object
The ID of the customer to which to attach the PaymentMethod.
923 924 925 |
# File 'lib/stripe/services/payment_method_service.rb', line 923 def customer @customer end |
#customer_account ⇒ Object
The ID of the account to which to attach the PaymentMethod.
925 926 927 |
# File 'lib/stripe/services/payment_method_service.rb', line 925 def customer_account @customer_account end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
927 928 929 |
# File 'lib/stripe/services/payment_method_service.rb', line 927 def @expand end |