Class: Stripe::PaymentMethodService::AttachParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_method_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, expand: nil) ⇒ AttachParams

Returns a new instance of AttachParams.



799
800
801
802
# File 'lib/stripe/services/payment_method_service.rb', line 799

def initialize(customer: nil, expand: nil)
  @customer = customer
  @expand = expand
end

Instance Attribute Details

#customerObject

The ID of the customer to which to attach the PaymentMethod.



795
796
797
# File 'lib/stripe/services/payment_method_service.rb', line 795

def customer
  @customer
end

#expandObject

Specifies which fields in the response should be expanded.



797
798
799
# File 'lib/stripe/services/payment_method_service.rb', line 797

def expand
  @expand
end