Class: Stripe::PaymentMethodService::AttachParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_method_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, expand: nil) ⇒ AttachParams

Returns a new instance of AttachParams.



869
870
871
872
# File 'lib/stripe/services/payment_method_service.rb', line 869

def initialize(customer: nil, expand: nil)
  @customer = customer
  @expand = expand
end

Instance Attribute Details

#customerObject

The ID of the customer to which to attach the PaymentMethod.



865
866
867
# File 'lib/stripe/services/payment_method_service.rb', line 865

def customer
  @customer
end

#expandObject

Specifies which fields in the response should be expanded.



867
868
869
# File 'lib/stripe/services/payment_method_service.rb', line 867

def expand
  @expand
end