Class: Stripe::PaymentMethodService::AttachParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_method_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, expand: nil) ⇒ AttachParams

Returns a new instance of AttachParams.



968
969
970
971
# File 'lib/stripe/services/payment_method_service.rb', line 968

def initialize(customer: nil, expand: nil)
  @customer = customer
  @expand = expand
end

Instance Attribute Details

#customerObject

The ID of the customer to which to attach the PaymentMethod.



963
964
965
# File 'lib/stripe/services/payment_method_service.rb', line 963

def customer
  @customer
end

#expandObject

Specifies which fields in the response should be expanded.



966
967
968
# File 'lib/stripe/services/payment_method_service.rb', line 966

def expand
  @expand
end