Class: Stripe::PaymentMethodService::CreateParams::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodService::CreateParams::NzBankAccount
- Defined in:
- lib/stripe/services/payment_method_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/stripe/services/payment_method_service.rb', line 290 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
278 279 280 |
# File 'lib/stripe/services/payment_method_service.rb', line 278 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
280 281 282 |
# File 'lib/stripe/services/payment_method_service.rb', line 280 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
282 283 284 |
# File 'lib/stripe/services/payment_method_service.rb', line 282 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
284 285 286 |
# File 'lib/stripe/services/payment_method_service.rb', line 284 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
286 287 288 |
# File 'lib/stripe/services/payment_method_service.rb', line 286 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
288 289 290 |
# File 'lib/stripe/services/payment_method_service.rb', line 288 def suffix @suffix end |