Class: Stripe::PaymentMethodService::CreateParams::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodService::CreateParams::NzBankAccount
- Defined in:
- lib/stripe/services/payment_method_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/stripe/services/payment_method_service.rb', line 306 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
294 295 296 |
# File 'lib/stripe/services/payment_method_service.rb', line 294 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
296 297 298 |
# File 'lib/stripe/services/payment_method_service.rb', line 296 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
298 299 300 |
# File 'lib/stripe/services/payment_method_service.rb', line 298 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
300 301 302 |
# File 'lib/stripe/services/payment_method_service.rb', line 300 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
302 303 304 |
# File 'lib/stripe/services/payment_method_service.rb', line 302 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
304 305 306 |
# File 'lib/stripe/services/payment_method_service.rb', line 304 def suffix @suffix end |