Class: Stripe::PaymentMethodService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_method_service.rb

Defined Under Namespace

Classes: BillingDetails, Card, Link, PayByBank, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_redisplay: nil, billing_details: nil, card: nil, expand: nil, link: nil, metadata: nil, pay_by_bank: nil, us_bank_account: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
# File 'lib/stripe/services/payment_method_service.rb', line 721

def initialize(
  allow_redisplay: nil,
  billing_details: nil,
  card: nil,
  expand: nil,
  link: nil,
  metadata: nil,
  pay_by_bank: nil,
  us_bank_account: nil
)
  @allow_redisplay = allow_redisplay
  @billing_details = billing_details
  @card = card
  @expand = expand
  @link = link
  @metadata = 
  @pay_by_bank = pay_by_bank
  @us_bank_account = 
end

Instance Attribute Details

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.



705
706
707
# File 'lib/stripe/services/payment_method_service.rb', line 705

def allow_redisplay
  @allow_redisplay
end

#billing_detailsObject

Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.



707
708
709
# File 'lib/stripe/services/payment_method_service.rb', line 707

def billing_details
  @billing_details
end

#cardObject

If this is a ‘card` PaymentMethod, this hash contains the user’s card details.



709
710
711
# File 'lib/stripe/services/payment_method_service.rb', line 709

def card
  @card
end

#expandObject

Specifies which fields in the response should be expanded.



711
712
713
# File 'lib/stripe/services/payment_method_service.rb', line 711

def expand
  @expand
end

If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.



713
714
715
# File 'lib/stripe/services/payment_method_service.rb', line 713

def link
  @link
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



715
716
717
# File 'lib/stripe/services/payment_method_service.rb', line 715

def 
  @metadata
end

#pay_by_bankObject

If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.



717
718
719
# File 'lib/stripe/services/payment_method_service.rb', line 717

def pay_by_bank
  @pay_by_bank
end

#us_bank_accountObject

If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.



719
720
721
# File 'lib/stripe/services/payment_method_service.rb', line 719

def 
  @us_bank_account
end