Class: Stripe::PaymentMethodService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_method_service.rb

Defined Under Namespace

Classes: BillingDetails, Card, Link, PayByBank, Payto, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_redisplay: nil, billing_details: nil, card: nil, expand: nil, link: nil, metadata: nil, pay_by_bank: nil, payto: nil, us_bank_account: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
# File 'lib/stripe/services/payment_method_service.rb', line 898

def initialize(
  allow_redisplay: nil,
  billing_details: nil,
  card: nil,
  expand: nil,
  link: nil,
  metadata: nil,
  pay_by_bank: nil,
  payto: nil,
  us_bank_account: nil
)
  @allow_redisplay = allow_redisplay
  @billing_details = billing_details
  @card = card
  @expand = expand
  @link = link
  @metadata = 
  @pay_by_bank = pay_by_bank
  @payto = payto
  @us_bank_account = 
end

Instance Attribute Details

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.



880
881
882
# File 'lib/stripe/services/payment_method_service.rb', line 880

def allow_redisplay
  @allow_redisplay
end

#billing_detailsObject

Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.



882
883
884
# File 'lib/stripe/services/payment_method_service.rb', line 882

def billing_details
  @billing_details
end

#cardObject

If this is a ‘card` PaymentMethod, this hash contains the user’s card details.



884
885
886
# File 'lib/stripe/services/payment_method_service.rb', line 884

def card
  @card
end

#expandObject

Specifies which fields in the response should be expanded.



886
887
888
# File 'lib/stripe/services/payment_method_service.rb', line 886

def expand
  @expand
end

If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.



888
889
890
# File 'lib/stripe/services/payment_method_service.rb', line 888

def link
  @link
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



890
891
892
# File 'lib/stripe/services/payment_method_service.rb', line 890

def 
  @metadata
end

#pay_by_bankObject

If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.



892
893
894
# File 'lib/stripe/services/payment_method_service.rb', line 892

def pay_by_bank
  @pay_by_bank
end

#paytoObject

If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.



894
895
896
# File 'lib/stripe/services/payment_method_service.rb', line 894

def payto
  @payto
end

#us_bank_accountObject

If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.



896
897
898
# File 'lib/stripe/services/payment_method_service.rb', line 896

def 
  @us_bank_account
end