Class: Stripe::PaymentMethodService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentMethodService::UpdateParams
- Defined in:
- lib/stripe/services/payment_method_service.rb
Defined Under Namespace
Classes: BillingDetails, Card, Link, NaverPay, PayByBank, Payto, UsBankAccount
Instance Attribute Summary collapse
-
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
-
#card ⇒ Object
If this is a ‘card` PaymentMethod, this hash contains the user’s card details.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#link ⇒ Object
If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.
-
#pay_by_bank ⇒ Object
If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.
-
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.
-
#us_bank_account ⇒ Object
If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.
Instance Method Summary collapse
-
#initialize(allow_redisplay: nil, billing_details: nil, card: nil, expand: nil, link: nil, metadata: nil, naver_pay: nil, pay_by_bank: nil, payto: nil, us_bank_account: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(allow_redisplay: nil, billing_details: nil, card: nil, expand: nil, link: nil, metadata: nil, naver_pay: nil, pay_by_bank: nil, payto: nil, us_bank_account: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 |
# File 'lib/stripe/services/payment_method_service.rb', line 838 def initialize( allow_redisplay: nil, billing_details: nil, card: nil, expand: nil, link: nil, metadata: nil, naver_pay: nil, pay_by_bank: nil, payto: nil, us_bank_account: nil ) @allow_redisplay = allow_redisplay @billing_details = billing_details @card = card @expand = @link = link @metadata = @naver_pay = naver_pay @pay_by_bank = pay_by_bank @payto = payto @us_bank_account = us_bank_account end |
Instance Attribute Details
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.
818 819 820 |
# File 'lib/stripe/services/payment_method_service.rb', line 818 def allow_redisplay @allow_redisplay end |
#billing_details ⇒ Object
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
820 821 822 |
# File 'lib/stripe/services/payment_method_service.rb', line 820 def billing_details @billing_details end |
#card ⇒ Object
If this is a ‘card` PaymentMethod, this hash contains the user’s card details.
822 823 824 |
# File 'lib/stripe/services/payment_method_service.rb', line 822 def card @card end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
824 825 826 |
# File 'lib/stripe/services/payment_method_service.rb', line 824 def @expand end |
#link ⇒ Object
If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.
826 827 828 |
# File 'lib/stripe/services/payment_method_service.rb', line 826 def link @link end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
828 829 830 |
# File 'lib/stripe/services/payment_method_service.rb', line 828 def @metadata end |
#naver_pay ⇒ Object
If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.
830 831 832 |
# File 'lib/stripe/services/payment_method_service.rb', line 830 def naver_pay @naver_pay end |
#pay_by_bank ⇒ Object
If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.
832 833 834 |
# File 'lib/stripe/services/payment_method_service.rb', line 832 def pay_by_bank @pay_by_bank end |
#payto ⇒ Object
If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.
834 835 836 |
# File 'lib/stripe/services/payment_method_service.rb', line 834 def payto @payto end |
#us_bank_account ⇒ Object
If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.
836 837 838 |
# File 'lib/stripe/services/payment_method_service.rb', line 836 def us_bank_account @us_bank_account end |