Class: Stripe::PaymentPlan::Installment
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentPlan::Installment
- Defined in:
- lib/stripe/resources/payment_plan.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_due ⇒ Object
readonly
Amount owed for this installment, in the smallest currency unit.
-
#amount_forgiven ⇒ Object
readonly
Amount forgiven for this installment, in the smallest currency unit.
-
#amount_paid ⇒ Object
readonly
Amount already paid toward this installment, in the smallest currency unit.
-
#currency ⇒ Object
readonly
Three-letter ISO currency code.
-
#description ⇒ Object
readonly
A description of this installment.
-
#due_date ⇒ Object
readonly
Unix timestamp when this installment is due.
-
#id ⇒ Object
readonly
Unique identifier for the installment.
-
#paid_at ⇒ Object
readonly
Unix timestamp when this installment was paid.
-
#status ⇒ Object
readonly
The status of this installment.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_due ⇒ Object (readonly)
Amount owed for this installment, in the smallest currency unit.
48 49 50 |
# File 'lib/stripe/resources/payment_plan.rb', line 48 def amount_due @amount_due end |
#amount_forgiven ⇒ Object (readonly)
Amount forgiven for this installment, in the smallest currency unit.
50 51 52 |
# File 'lib/stripe/resources/payment_plan.rb', line 50 def amount_forgiven @amount_forgiven end |
#amount_paid ⇒ Object (readonly)
Amount already paid toward this installment, in the smallest currency unit.
52 53 54 |
# File 'lib/stripe/resources/payment_plan.rb', line 52 def amount_paid @amount_paid end |
#currency ⇒ Object (readonly)
Three-letter ISO currency code.
54 55 56 |
# File 'lib/stripe/resources/payment_plan.rb', line 54 def currency @currency end |
#description ⇒ Object (readonly)
A description of this installment.
56 57 58 |
# File 'lib/stripe/resources/payment_plan.rb', line 56 def description @description end |
#due_date ⇒ Object (readonly)
Unix timestamp when this installment is due. Omitted for installments with no due date.
58 59 60 |
# File 'lib/stripe/resources/payment_plan.rb', line 58 def due_date @due_date end |
#id ⇒ Object (readonly)
Unique identifier for the installment.
60 61 62 |
# File 'lib/stripe/resources/payment_plan.rb', line 60 def id @id end |
#paid_at ⇒ Object (readonly)
Unix timestamp when this installment was paid.
62 63 64 |
# File 'lib/stripe/resources/payment_plan.rb', line 62 def paid_at @paid_at end |
#status ⇒ Object (readonly)
The status of this installment. One of open, paid, past_due, or canceled.
64 65 66 |
# File 'lib/stripe/resources/payment_plan.rb', line 64 def status @status end |
Class Method Details
.field_remappings ⇒ Object
70 71 72 |
# File 'lib/stripe/resources/payment_plan.rb', line 70 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
66 67 68 |
# File 'lib/stripe/resources/payment_plan.rb', line 66 def self.inner_class_types @inner_class_types = {} end |