Class: Stripe::PaymentRecord

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/payment_record.rb

Overview

A Payment Record is a resource that allows you to represent payments that occur on- or off-Stripe. For example, you can create a Payment Record to model a payment made on a different payment processor, in order to mark an Invoice as paid and a Subscription as active. Payment Records consist of one or more Payment Attempt Records, which represent individual attempts made on a payment network.

Defined Under Namespace

Classes: Amount, AmountAuthorized, AmountCanceled, AmountFailed, AmountGuaranteed, AmountRefunded, AmountRequested, CustomerDetails, PaymentMethodDetails, ProcessorDetails, ShippingDetails

Constant Summary collapse

OBJECT_NAME =
"payment_record"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



1915
1916
1917
# File 'lib/stripe/resources/payment_record.rb', line 1915

def amount
  @amount
end

#amount_authorizedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



1917
1918
1919
# File 'lib/stripe/resources/payment_record.rb', line 1917

def amount_authorized
  @amount_authorized
end

#amount_canceledObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



1919
1920
1921
# File 'lib/stripe/resources/payment_record.rb', line 1919

def amount_canceled
  @amount_canceled
end

#amount_failedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



1921
1922
1923
# File 'lib/stripe/resources/payment_record.rb', line 1921

def amount_failed
  @amount_failed
end

#amount_guaranteedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



1923
1924
1925
# File 'lib/stripe/resources/payment_record.rb', line 1923

def amount_guaranteed
  @amount_guaranteed
end

#amount_refundedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



1925
1926
1927
# File 'lib/stripe/resources/payment_record.rb', line 1925

def amount_refunded
  @amount_refunded
end

#amount_requestedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



1927
1928
1929
# File 'lib/stripe/resources/payment_record.rb', line 1927

def amount_requested
  @amount_requested
end

#applicationObject (readonly)

ID of the Connect application that created the PaymentRecord.



1929
1930
1931
# File 'lib/stripe/resources/payment_record.rb', line 1929

def application
  @application
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



1931
1932
1933
# File 'lib/stripe/resources/payment_record.rb', line 1931

def created
  @created
end

#customer_detailsObject (readonly)

Customer information for this payment.



1933
1934
1935
# File 'lib/stripe/resources/payment_record.rb', line 1933

def customer_details
  @customer_details
end

#customer_presenceObject (readonly)

Indicates whether the customer was present in your checkout flow during this payment.



1935
1936
1937
# File 'lib/stripe/resources/payment_record.rb', line 1935

def customer_presence
  @customer_presence
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



1937
1938
1939
# File 'lib/stripe/resources/payment_record.rb', line 1937

def description
  @description
end

#idObject (readonly)

Unique identifier for the object.



1939
1940
1941
# File 'lib/stripe/resources/payment_record.rb', line 1939

def id
  @id
end

#latest_payment_attempt_recordObject (readonly)

ID of the latest Payment Attempt Record attached to this Payment Record.



1941
1942
1943
# File 'lib/stripe/resources/payment_record.rb', line 1941

def latest_payment_attempt_record
  @latest_payment_attempt_record
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



1943
1944
1945
# File 'lib/stripe/resources/payment_record.rb', line 1943

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



1945
1946
1947
# File 'lib/stripe/resources/payment_record.rb', line 1945

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



1947
1948
1949
# File 'lib/stripe/resources/payment_record.rb', line 1947

def object
  @object
end

#payment_method_detailsObject (readonly)

Information about the Payment Method debited for this payment.



1949
1950
1951
# File 'lib/stripe/resources/payment_record.rb', line 1949

def payment_method_details
  @payment_method_details
end

#processor_detailsObject (readonly)

Processor information associated with this payment.



1951
1952
1953
# File 'lib/stripe/resources/payment_record.rb', line 1951

def processor_details
  @processor_details
end

#reported_byObject (readonly)

Indicates who reported the payment.



1953
1954
1955
# File 'lib/stripe/resources/payment_record.rb', line 1953

def reported_by
  @reported_by
end

#shipping_detailsObject (readonly)

Shipping information for this payment.



1955
1956
1957
# File 'lib/stripe/resources/payment_record.rb', line 1955

def shipping_details
  @shipping_details
end

Class Method Details

.field_remappingsObject



2115
2116
2117
# File 'lib/stripe/resources/payment_record.rb', line 2115

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
# File 'lib/stripe/resources/payment_record.rb', line 2099

def self.inner_class_types
  @inner_class_types = {
    amount: Amount,
    amount_authorized: AmountAuthorized,
    amount_canceled: AmountCanceled,
    amount_failed: AmountFailed,
    amount_guaranteed: AmountGuaranteed,
    amount_refunded: AmountRefunded,
    amount_requested: AmountRequested,
    customer_details: CustomerDetails,
    payment_method_details: PaymentMethodDetails,
    processor_details: ProcessorDetails,
    shipping_details: ShippingDetails,
  }
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/payment_record.rb', line 11

def self.object_name
  "payment_record"
end

.report_payment(params = {}, opts = {}) ⇒ Object

Report a new Payment Record. You may report a Payment Record as it is

initialized and later report updates through the other report_* methods, or report Payment
Records in a terminal state directly, through this method.


1960
1961
1962
1963
1964
1965
1966
1967
# File 'lib/stripe/resources/payment_record.rb', line 1960

def self.report_payment(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/payment_records/report_payment",
    params: params,
    opts: opts
  )
end

.report_payment_attempt(id, params = {}, opts = {}) ⇒ Object

Report a new payment attempt on the specified Payment Record. A new payment

attempt can only be specified if all other payment attempts are canceled or failed.


1982
1983
1984
1985
1986
1987
1988
1989
# File 'lib/stripe/resources/payment_record.rb', line 1982

def self.report_payment_attempt(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.report_payment_attempt_canceled(id, params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record

was canceled.


2004
2005
2006
2007
2008
2009
2010
2011
# File 'lib/stripe/resources/payment_record.rb', line 2004

def self.report_payment_attempt_canceled(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_canceled", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.report_payment_attempt_failed(id, params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record

failed or errored.


2026
2027
2028
2029
2030
2031
2032
2033
# File 'lib/stripe/resources/payment_record.rb', line 2026

def self.report_payment_attempt_failed(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_failed", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.report_payment_attempt_guaranteed(id, params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record

was guaranteed.


2048
2049
2050
2051
2052
2053
2054
2055
# File 'lib/stripe/resources/payment_record.rb', line 2048

def self.report_payment_attempt_guaranteed(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_guaranteed", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.report_payment_attempt_informational(id, params = {}, opts = {}) ⇒ Object

Report informational updates on the specified Payment Record.



2068
2069
2070
2071
2072
2073
2074
2075
# File 'lib/stripe/resources/payment_record.rb', line 2068

def self.report_payment_attempt_informational(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_informational", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.report_refund(id, params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record

was refunded.


2090
2091
2092
2093
2094
2095
2096
2097
# File 'lib/stripe/resources/payment_record.rb', line 2090

def self.report_refund(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_refund", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#report_payment_attempt(params = {}, opts = {}) ⇒ Object

Report a new payment attempt on the specified Payment Record. A new payment

attempt can only be specified if all other payment attempts are canceled or failed.


1971
1972
1973
1974
1975
1976
1977
1978
# File 'lib/stripe/resources/payment_record.rb', line 1971

def report_payment_attempt(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#report_payment_attempt_canceled(params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record

was canceled.


1993
1994
1995
1996
1997
1998
1999
2000
# File 'lib/stripe/resources/payment_record.rb', line 1993

def report_payment_attempt_canceled(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_canceled", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#report_payment_attempt_failed(params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record

failed or errored.


2015
2016
2017
2018
2019
2020
2021
2022
# File 'lib/stripe/resources/payment_record.rb', line 2015

def report_payment_attempt_failed(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_failed", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#report_payment_attempt_guaranteed(params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record

was guaranteed.


2037
2038
2039
2040
2041
2042
2043
2044
# File 'lib/stripe/resources/payment_record.rb', line 2037

def report_payment_attempt_guaranteed(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_guaranteed", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#report_payment_attempt_informational(params = {}, opts = {}) ⇒ Object

Report informational updates on the specified Payment Record.



2058
2059
2060
2061
2062
2063
2064
2065
# File 'lib/stripe/resources/payment_record.rb', line 2058

def report_payment_attempt_informational(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_informational", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#report_refund(params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record

was refunded.


2079
2080
2081
2082
2083
2084
2085
2086
# File 'lib/stripe/resources/payment_record.rb', line 2079

def report_refund(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_refund", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end