Class: Stripe::PaymentRecord

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/payment_record.rb

Overview

A Payment Record is a resource that allows you to represent payments that occur on- or off-Stripe. For example, you can create a Payment Record to model a payment made on a different payment processor, in order to mark an Invoice as paid and a Subscription as active. Payment Records consist of one or more Payment Attempt Records, which represent individual attempts made on a payment network.

Defined Under Namespace

Classes: Amount, AmountAuthorized, AmountCanceled, AmountFailed, AmountGuaranteed, AmountRefunded, AmountRequested, CustomerDetails, PaymentMethodDetails, ProcessorDetails, ShippingDetails

Constant Summary collapse

OBJECT_NAME =
"payment_record"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2091
2092
2093
# File 'lib/stripe/resources/payment_record.rb', line 2091

def amount
  @amount
end

#amount_authorizedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2093
2094
2095
# File 'lib/stripe/resources/payment_record.rb', line 2093

def amount_authorized
  @amount_authorized
end

#amount_canceledObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2095
2096
2097
# File 'lib/stripe/resources/payment_record.rb', line 2095

def amount_canceled
  @amount_canceled
end

#amount_failedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2097
2098
2099
# File 'lib/stripe/resources/payment_record.rb', line 2097

def amount_failed
  @amount_failed
end

#amount_guaranteedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2099
2100
2101
# File 'lib/stripe/resources/payment_record.rb', line 2099

def amount_guaranteed
  @amount_guaranteed
end

#amount_refundedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2101
2102
2103
# File 'lib/stripe/resources/payment_record.rb', line 2101

def amount_refunded
  @amount_refunded
end

#amount_requestedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2103
2104
2105
# File 'lib/stripe/resources/payment_record.rb', line 2103

def amount_requested
  @amount_requested
end

#applicationObject (readonly)

ID of the Connect application that created the PaymentRecord.



2105
2106
2107
# File 'lib/stripe/resources/payment_record.rb', line 2105

def application
  @application
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



2107
2108
2109
# File 'lib/stripe/resources/payment_record.rb', line 2107

def created
  @created
end

#customer_detailsObject (readonly)

Customer information for this payment.



2109
2110
2111
# File 'lib/stripe/resources/payment_record.rb', line 2109

def customer_details
  @customer_details
end

#customer_presenceObject (readonly)

Indicates whether the customer was present in your checkout flow during this payment.



2111
2112
2113
# File 'lib/stripe/resources/payment_record.rb', line 2111

def customer_presence
  @customer_presence
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



2113
2114
2115
# File 'lib/stripe/resources/payment_record.rb', line 2113

def description
  @description
end

#idObject (readonly)

Unique identifier for the object.



2115
2116
2117
# File 'lib/stripe/resources/payment_record.rb', line 2115

def id
  @id
end

#latest_payment_attempt_recordObject (readonly)

ID of the latest Payment Attempt Record attached to this Payment Record.



2117
2118
2119
# File 'lib/stripe/resources/payment_record.rb', line 2117

def latest_payment_attempt_record
  @latest_payment_attempt_record
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



2119
2120
2121
# File 'lib/stripe/resources/payment_record.rb', line 2119

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



2121
2122
2123
# File 'lib/stripe/resources/payment_record.rb', line 2121

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



2123
2124
2125
# File 'lib/stripe/resources/payment_record.rb', line 2123

def object
  @object
end

#payment_method_detailsObject (readonly)

Information about the Payment Method debited for this payment.



2125
2126
2127
# File 'lib/stripe/resources/payment_record.rb', line 2125

def payment_method_details
  @payment_method_details
end

#processor_detailsObject (readonly)

Processor information associated with this payment.



2127
2128
2129
# File 'lib/stripe/resources/payment_record.rb', line 2127

def processor_details
  @processor_details
end

#reported_byObject (readonly)

Indicates who reported the payment.



2129
2130
2131
# File 'lib/stripe/resources/payment_record.rb', line 2129

def reported_by
  @reported_by
end

#shipping_detailsObject (readonly)

Shipping information for this payment.



2131
2132
2133
# File 'lib/stripe/resources/payment_record.rb', line 2131

def shipping_details
  @shipping_details
end

Class Method Details

.field_remappingsObject



2291
2292
2293
# File 'lib/stripe/resources/payment_record.rb', line 2291

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
# File 'lib/stripe/resources/payment_record.rb', line 2275

def self.inner_class_types
  @inner_class_types = {
    amount: Amount,
    amount_authorized: AmountAuthorized,
    amount_canceled: AmountCanceled,
    amount_failed: AmountFailed,
    amount_guaranteed: AmountGuaranteed,
    amount_refunded: AmountRefunded,
    amount_requested: AmountRequested,
    customer_details: CustomerDetails,
    payment_method_details: PaymentMethodDetails,
    processor_details: ProcessorDetails,
    shipping_details: ShippingDetails,
  }
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/payment_record.rb', line 11

def self.object_name
  "payment_record"
end

.report_payment(params = {}, opts = {}) ⇒ Object

Report a new Payment Record. You may report a Payment Record as it is

initialized and later report updates through the other report_* methods, or report Payment
Records in a terminal state directly, through this method.


2136
2137
2138
2139
2140
2141
2142
2143
# File 'lib/stripe/resources/payment_record.rb', line 2136

def self.report_payment(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/payment_records/report_payment",
    params: params,
    opts: opts
  )
end

.report_payment_attempt(id, params = {}, opts = {}) ⇒ Object

Report a new payment attempt on the specified Payment Record. A new payment

attempt can only be specified if all other payment attempts are canceled or failed.


2158
2159
2160
2161
2162
2163
2164
2165
# File 'lib/stripe/resources/payment_record.rb', line 2158

def self.report_payment_attempt(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.report_payment_attempt_canceled(id, params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record

was canceled.


2180
2181
2182
2183
2184
2185
2186
2187
# File 'lib/stripe/resources/payment_record.rb', line 2180

def self.report_payment_attempt_canceled(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_canceled", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.report_payment_attempt_failed(id, params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record

failed or errored.


2202
2203
2204
2205
2206
2207
2208
2209
# File 'lib/stripe/resources/payment_record.rb', line 2202

def self.report_payment_attempt_failed(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_failed", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.report_payment_attempt_guaranteed(id, params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record

was guaranteed.


2224
2225
2226
2227
2228
2229
2230
2231
# File 'lib/stripe/resources/payment_record.rb', line 2224

def self.report_payment_attempt_guaranteed(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_guaranteed", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.report_payment_attempt_informational(id, params = {}, opts = {}) ⇒ Object

Report informational updates on the specified Payment Record.



2244
2245
2246
2247
2248
2249
2250
2251
# File 'lib/stripe/resources/payment_record.rb', line 2244

def self.report_payment_attempt_informational(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_informational", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.report_refund(id, params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record

was refunded.


2266
2267
2268
2269
2270
2271
2272
2273
# File 'lib/stripe/resources/payment_record.rb', line 2266

def self.report_refund(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_refund", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#report_payment_attempt(params = {}, opts = {}) ⇒ Object

Report a new payment attempt on the specified Payment Record. A new payment

attempt can only be specified if all other payment attempts are canceled or failed.


2147
2148
2149
2150
2151
2152
2153
2154
# File 'lib/stripe/resources/payment_record.rb', line 2147

def report_payment_attempt(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#report_payment_attempt_canceled(params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record

was canceled.


2169
2170
2171
2172
2173
2174
2175
2176
# File 'lib/stripe/resources/payment_record.rb', line 2169

def report_payment_attempt_canceled(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_canceled", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#report_payment_attempt_failed(params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record

failed or errored.


2191
2192
2193
2194
2195
2196
2197
2198
# File 'lib/stripe/resources/payment_record.rb', line 2191

def report_payment_attempt_failed(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_failed", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#report_payment_attempt_guaranteed(params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record

was guaranteed.


2213
2214
2215
2216
2217
2218
2219
2220
# File 'lib/stripe/resources/payment_record.rb', line 2213

def report_payment_attempt_guaranteed(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_guaranteed", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#report_payment_attempt_informational(params = {}, opts = {}) ⇒ Object

Report informational updates on the specified Payment Record.



2234
2235
2236
2237
2238
2239
2240
2241
# File 'lib/stripe/resources/payment_record.rb', line 2234

def report_payment_attempt_informational(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_informational", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#report_refund(params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record

was refunded.


2255
2256
2257
2258
2259
2260
2261
2262
# File 'lib/stripe/resources/payment_record.rb', line 2255

def report_refund(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_refund", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end