Class: Stripe::PaymentRecord

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/payment_record.rb

Overview

A Payment Record is a resource that allows you to represent payments that occur on- or off-Stripe. For example, you can create a Payment Record to model a payment made on a different payment processor, in order to mark an Invoice as paid and a Subscription as active. Payment Records consist of one or more Payment Attempt Records, which represent individual attempts made on a payment network.

Defined Under Namespace

Classes: AmountCanceled, AmountFailed, AmountGuaranteed, AmountRequested, CustomerDetails, PaymentMethodDetails, ReportPaymentAttemptCanceledParams, ReportPaymentAttemptFailedParams, ReportPaymentAttemptGuaranteedParams, ReportPaymentAttemptParams, ReportPaymentParams, ShippingDetails

Constant Summary collapse

OBJECT_NAME =
"payment_record"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_canceledObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



1496
1497
1498
# File 'lib/stripe/resources/payment_record.rb', line 1496

def amount_canceled
  @amount_canceled
end

#amount_failedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



1498
1499
1500
# File 'lib/stripe/resources/payment_record.rb', line 1498

def amount_failed
  @amount_failed
end

#amount_guaranteedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



1500
1501
1502
# File 'lib/stripe/resources/payment_record.rb', line 1500

def amount_guaranteed
  @amount_guaranteed
end

#amount_requestedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



1502
1503
1504
# File 'lib/stripe/resources/payment_record.rb', line 1502

def amount_requested
  @amount_requested
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



1504
1505
1506
# File 'lib/stripe/resources/payment_record.rb', line 1504

def created
  @created
end

#customer_detailsObject (readonly)

Customer information for this payment.



1506
1507
1508
# File 'lib/stripe/resources/payment_record.rb', line 1506

def customer_details
  @customer_details
end

#customer_presenceObject (readonly)

Indicates whether the customer was present in your checkout flow during this payment.



1508
1509
1510
# File 'lib/stripe/resources/payment_record.rb', line 1508

def customer_presence
  @customer_presence
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



1510
1511
1512
# File 'lib/stripe/resources/payment_record.rb', line 1510

def description
  @description
end

#idObject (readonly)

Unique identifier for the object.



1512
1513
1514
# File 'lib/stripe/resources/payment_record.rb', line 1512

def id
  @id
end

#latest_payment_attempt_recordObject (readonly)

ID of the latest Payment Attempt Record attached to this Payment Record.



1514
1515
1516
# File 'lib/stripe/resources/payment_record.rb', line 1514

def latest_payment_attempt_record
  @latest_payment_attempt_record
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



1516
1517
1518
# File 'lib/stripe/resources/payment_record.rb', line 1516

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



1518
1519
1520
# File 'lib/stripe/resources/payment_record.rb', line 1518

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



1520
1521
1522
# File 'lib/stripe/resources/payment_record.rb', line 1520

def object
  @object
end

#payment_method_detailsObject (readonly)

Information about the Payment Method debited for this payment.



1522
1523
1524
# File 'lib/stripe/resources/payment_record.rb', line 1522

def payment_method_details
  @payment_method_details
end

#payment_referenceObject (readonly)

An opaque string for manual reconciliation of this payment, for example a check number or a payment processor ID.



1524
1525
1526
# File 'lib/stripe/resources/payment_record.rb', line 1524

def payment_reference
  @payment_reference
end

#shipping_detailsObject (readonly)

Shipping information for this payment.



1526
1527
1528
# File 'lib/stripe/resources/payment_record.rb', line 1526

def shipping_details
  @shipping_details
end

Class Method Details

.object_nameObject



11
12
13
# File 'lib/stripe/resources/payment_record.rb', line 11

def self.object_name
  "payment_record"
end

.report_payment(params = {}, opts = {}) ⇒ Object

Report a new Payment Record. You may report a Payment Record as it is

initialized and later report updates through the other report_* methods, or report Payment
Records in a terminal state directly, through this method.


1531
1532
1533
1534
1535
1536
1537
1538
# File 'lib/stripe/resources/payment_record.rb', line 1531

def self.report_payment(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/payment_records/report_payment",
    params: params,
    opts: opts
  )
end

.report_payment_attempt(id, params = {}, opts = {}) ⇒ Object

Report a new payment attempt on the specified Payment Record. A new payment

attempt can only be specified if all other payment attempts are canceled or failed.


1553
1554
1555
1556
1557
1558
1559
1560
# File 'lib/stripe/resources/payment_record.rb', line 1553

def self.report_payment_attempt(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.report_payment_attempt_canceled(id, params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record

was canceled.


1575
1576
1577
1578
1579
1580
1581
1582
# File 'lib/stripe/resources/payment_record.rb', line 1575

def self.report_payment_attempt_canceled(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_canceled", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.report_payment_attempt_failed(id, params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record

failed or errored.


1597
1598
1599
1600
1601
1602
1603
1604
# File 'lib/stripe/resources/payment_record.rb', line 1597

def self.report_payment_attempt_failed(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_failed", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.report_payment_attempt_guaranteed(id, params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record

was guaranteed.


1619
1620
1621
1622
1623
1624
1625
1626
# File 'lib/stripe/resources/payment_record.rb', line 1619

def self.report_payment_attempt_guaranteed(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_guaranteed", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#report_payment_attempt(params = {}, opts = {}) ⇒ Object

Report a new payment attempt on the specified Payment Record. A new payment

attempt can only be specified if all other payment attempts are canceled or failed.


1542
1543
1544
1545
1546
1547
1548
1549
# File 'lib/stripe/resources/payment_record.rb', line 1542

def report_payment_attempt(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#report_payment_attempt_canceled(params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record

was canceled.


1564
1565
1566
1567
1568
1569
1570
1571
# File 'lib/stripe/resources/payment_record.rb', line 1564

def report_payment_attempt_canceled(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_canceled", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#report_payment_attempt_failed(params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record

failed or errored.


1586
1587
1588
1589
1590
1591
1592
1593
# File 'lib/stripe/resources/payment_record.rb', line 1586

def report_payment_attempt_failed(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_failed", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#report_payment_attempt_guaranteed(params = {}, opts = {}) ⇒ Object

Report that the most recent payment attempt on the specified Payment Record

was guaranteed.


1608
1609
1610
1611
1612
1613
1614
1615
# File 'lib/stripe/resources/payment_record.rb', line 1608

def report_payment_attempt_guaranteed(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_records/%<id>s/report_payment_attempt_guaranteed", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end