Class: Stripe::PaymentRecord::PaymentMethodDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentRecord::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/payment_record.rb
Defined Under Namespace
Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, Custom, CustomerBalance, Eps, Fpx, Giropay, Grabpay, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, RevolutPay, SamsungPay, Satispay, SepaCreditTransfer, SepaDebit, Sofort, StripeAccount, Swish, Twint, Upi, UsBankAccount, Wechat, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ach_credit_transfer ⇒ Object
readonly
Attribute for field ach_credit_transfer.
-
#ach_debit ⇒ Object
readonly
Attribute for field ach_debit.
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billie ⇒ Object
readonly
Attribute for field billie.
-
#billing_details ⇒ Object
readonly
The billing details associated with the method of payment.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Details of the card used for this payment attempt.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#crypto ⇒ Object
readonly
Attribute for field crypto.
-
#custom ⇒ Object
readonly
Custom Payment Methods represent Payment Method types not modeled directly in the Stripe API.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#interac_present ⇒ Object
readonly
Attribute for field interac_present.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#payment_method ⇒ Object
readonly
ID of the Stripe PaymentMethod used to make this payment.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#sepa_credit_transfer ⇒ Object
readonly
Attribute for field sepa_credit_transfer.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#stripe_account ⇒ Object
readonly
Attribute for field stripe_account.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of transaction-specific details of the payment method used in the payment.
-
#upi ⇒ Object
readonly
Attribute for field upi.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat ⇒ Object
readonly
Attribute for field wechat.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ach_credit_transfer ⇒ Object (readonly)
Attribute for field ach_credit_transfer
1670 1671 1672 |
# File 'lib/stripe/resources/payment_record.rb', line 1670 def ach_credit_transfer @ach_credit_transfer end |
#ach_debit ⇒ Object (readonly)
Attribute for field ach_debit
1672 1673 1674 |
# File 'lib/stripe/resources/payment_record.rb', line 1672 def ach_debit @ach_debit end |
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
1674 1675 1676 |
# File 'lib/stripe/resources/payment_record.rb', line 1674 def acss_debit @acss_debit end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
1676 1677 1678 |
# File 'lib/stripe/resources/payment_record.rb', line 1676 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
1678 1679 1680 |
# File 'lib/stripe/resources/payment_record.rb', line 1678 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
1680 1681 1682 |
# File 'lib/stripe/resources/payment_record.rb', line 1680 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
1682 1683 1684 |
# File 'lib/stripe/resources/payment_record.rb', line 1682 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
1684 1685 1686 |
# File 'lib/stripe/resources/payment_record.rb', line 1684 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
1686 1687 1688 |
# File 'lib/stripe/resources/payment_record.rb', line 1686 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
1688 1689 1690 |
# File 'lib/stripe/resources/payment_record.rb', line 1688 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
1690 1691 1692 |
# File 'lib/stripe/resources/payment_record.rb', line 1690 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
Attribute for field billie
1692 1693 1694 |
# File 'lib/stripe/resources/payment_record.rb', line 1692 def billie @billie end |
#billing_details ⇒ Object (readonly)
The billing details associated with the method of payment.
1694 1695 1696 |
# File 'lib/stripe/resources/payment_record.rb', line 1694 def billing_details @billing_details end |
#blik ⇒ Object (readonly)
Attribute for field blik
1696 1697 1698 |
# File 'lib/stripe/resources/payment_record.rb', line 1696 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
1698 1699 1700 |
# File 'lib/stripe/resources/payment_record.rb', line 1698 def boleto @boleto end |
#card ⇒ Object (readonly)
Details of the card used for this payment attempt.
1700 1701 1702 |
# File 'lib/stripe/resources/payment_record.rb', line 1700 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
1702 1703 1704 |
# File 'lib/stripe/resources/payment_record.rb', line 1702 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
1704 1705 1706 |
# File 'lib/stripe/resources/payment_record.rb', line 1704 def cashapp @cashapp end |
#crypto ⇒ Object (readonly)
Attribute for field crypto
1706 1707 1708 |
# File 'lib/stripe/resources/payment_record.rb', line 1706 def crypto @crypto end |
#custom ⇒ Object (readonly)
Custom Payment Methods represent Payment Method types not modeled directly in the Stripe API. This resource consists of details about the custom payment method used for this payment attempt.
1710 1711 1712 |
# File 'lib/stripe/resources/payment_record.rb', line 1710 def custom @custom end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
1712 1713 1714 |
# File 'lib/stripe/resources/payment_record.rb', line 1712 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
1714 1715 1716 |
# File 'lib/stripe/resources/payment_record.rb', line 1714 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
1716 1717 1718 |
# File 'lib/stripe/resources/payment_record.rb', line 1716 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
1718 1719 1720 |
# File 'lib/stripe/resources/payment_record.rb', line 1718 def giropay @giropay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
1720 1721 1722 |
# File 'lib/stripe/resources/payment_record.rb', line 1720 def grabpay @grabpay end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
1722 1723 1724 |
# File 'lib/stripe/resources/payment_record.rb', line 1722 def ideal @ideal end |
#interac_present ⇒ Object (readonly)
Attribute for field interac_present
1724 1725 1726 |
# File 'lib/stripe/resources/payment_record.rb', line 1724 def interac_present @interac_present end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
1726 1727 1728 |
# File 'lib/stripe/resources/payment_record.rb', line 1726 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
1728 1729 1730 |
# File 'lib/stripe/resources/payment_record.rb', line 1728 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
1730 1731 1732 |
# File 'lib/stripe/resources/payment_record.rb', line 1730 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
1732 1733 1734 |
# File 'lib/stripe/resources/payment_record.rb', line 1732 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
1734 1735 1736 |
# File 'lib/stripe/resources/payment_record.rb', line 1734 def link @link end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
1736 1737 1738 |
# File 'lib/stripe/resources/payment_record.rb', line 1736 def mb_way @mb_way end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
1738 1739 1740 |
# File 'lib/stripe/resources/payment_record.rb', line 1738 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
1740 1741 1742 |
# File 'lib/stripe/resources/payment_record.rb', line 1740 def multibanco @multibanco end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
1742 1743 1744 |
# File 'lib/stripe/resources/payment_record.rb', line 1742 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
1744 1745 1746 |
# File 'lib/stripe/resources/payment_record.rb', line 1744 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
1746 1747 1748 |
# File 'lib/stripe/resources/payment_record.rb', line 1746 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
1748 1749 1750 |
# File 'lib/stripe/resources/payment_record.rb', line 1748 def p24 @p24 end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
1750 1751 1752 |
# File 'lib/stripe/resources/payment_record.rb', line 1750 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
1752 1753 1754 |
# File 'lib/stripe/resources/payment_record.rb', line 1752 def payco @payco end |
#payment_method ⇒ Object (readonly)
ID of the Stripe PaymentMethod used to make this payment.
1754 1755 1756 |
# File 'lib/stripe/resources/payment_record.rb', line 1754 def payment_method @payment_method end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
1756 1757 1758 |
# File 'lib/stripe/resources/payment_record.rb', line 1756 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
1758 1759 1760 |
# File 'lib/stripe/resources/payment_record.rb', line 1758 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
1760 1761 1762 |
# File 'lib/stripe/resources/payment_record.rb', line 1760 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
1762 1763 1764 |
# File 'lib/stripe/resources/payment_record.rb', line 1762 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
1764 1765 1766 |
# File 'lib/stripe/resources/payment_record.rb', line 1764 def promptpay @promptpay end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
1766 1767 1768 |
# File 'lib/stripe/resources/payment_record.rb', line 1766 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
1768 1769 1770 |
# File 'lib/stripe/resources/payment_record.rb', line 1768 def samsung_pay @samsung_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
1770 1771 1772 |
# File 'lib/stripe/resources/payment_record.rb', line 1770 def satispay @satispay end |
#sepa_credit_transfer ⇒ Object (readonly)
Attribute for field sepa_credit_transfer
1772 1773 1774 |
# File 'lib/stripe/resources/payment_record.rb', line 1772 def sepa_credit_transfer @sepa_credit_transfer end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
1774 1775 1776 |
# File 'lib/stripe/resources/payment_record.rb', line 1774 def sepa_debit @sepa_debit end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
1776 1777 1778 |
# File 'lib/stripe/resources/payment_record.rb', line 1776 def sofort @sofort end |
#stripe_account ⇒ Object (readonly)
Attribute for field stripe_account
1778 1779 1780 |
# File 'lib/stripe/resources/payment_record.rb', line 1778 def stripe_account @stripe_account end |
#swish ⇒ Object (readonly)
Attribute for field swish
1780 1781 1782 |
# File 'lib/stripe/resources/payment_record.rb', line 1780 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
1782 1783 1784 |
# File 'lib/stripe/resources/payment_record.rb', line 1782 def twint @twint end |
#type ⇒ Object (readonly)
The type of transaction-specific details of the payment method used in the payment. See [PaymentMethod.type](docs.stripe.com/api/payment_methods/object#payment_method_object-type) for the full list of possible types. An additional hash is included on ‘payment_method_details` with a name matching this value. It contains information specific to the payment method.
1786 1787 1788 |
# File 'lib/stripe/resources/payment_record.rb', line 1786 def type @type end |
#upi ⇒ Object (readonly)
Attribute for field upi
1788 1789 1790 |
# File 'lib/stripe/resources/payment_record.rb', line 1788 def upi @upi end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
1790 1791 1792 |
# File 'lib/stripe/resources/payment_record.rb', line 1790 def us_bank_account @us_bank_account end |
#wechat ⇒ Object (readonly)
Attribute for field wechat
1792 1793 1794 |
# File 'lib/stripe/resources/payment_record.rb', line 1792 def wechat @wechat end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
1794 1795 1796 |
# File 'lib/stripe/resources/payment_record.rb', line 1794 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
1796 1797 1798 |
# File 'lib/stripe/resources/payment_record.rb', line 1796 def zip @zip end |
Class Method Details
.field_remappings ⇒ Object
1863 1864 1865 |
# File 'lib/stripe/resources/payment_record.rb', line 1863 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 |
# File 'lib/stripe/resources/payment_record.rb', line 1798 def self.inner_class_types @inner_class_types = { ach_credit_transfer: AchCreditTransfer, ach_debit: AchDebit, acss_debit: AcssDebit, affirm: Affirm, afterpay_clearpay: AfterpayClearpay, alipay: Alipay, alma: Alma, amazon_pay: AmazonPay, au_becs_debit: AuBecsDebit, bacs_debit: BacsDebit, bancontact: Bancontact, billie: Billie, billing_details: BillingDetails, blik: Blik, boleto: Boleto, card: Card, card_present: CardPresent, cashapp: Cashapp, crypto: Crypto, custom: Custom, customer_balance: CustomerBalance, eps: Eps, fpx: Fpx, giropay: Giropay, grabpay: Grabpay, ideal: Ideal, interac_present: InteracPresent, kakao_pay: KakaoPay, klarna: Klarna, konbini: Konbini, kr_card: KrCard, link: Link, mb_way: MbWay, mobilepay: Mobilepay, multibanco: Multibanco, naver_pay: NaverPay, nz_bank_account: NzBankAccount, oxxo: Oxxo, p24: P24, pay_by_bank: PayByBank, payco: Payco, paynow: Paynow, paypal: Paypal, payto: Payto, pix: Pix, promptpay: Promptpay, revolut_pay: RevolutPay, samsung_pay: SamsungPay, satispay: Satispay, sepa_credit_transfer: SepaCreditTransfer, sepa_debit: SepaDebit, sofort: Sofort, stripe_account: StripeAccount, swish: Swish, twint: Twint, upi: Upi, us_bank_account: UsBankAccount, wechat: Wechat, wechat_pay: WechatPay, zip: Zip, } end |