Class: Stripe::PaymentRecord::PaymentMethodDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentRecord::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/payment_record.rb
Defined Under Namespace
Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, Custom, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaCreditTransfer, SepaDebit, Shopeepay, Sofort, StripeAccount, StripeBalance, Swish, Twint, UsBankAccount, Wechat, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ach_credit_transfer ⇒ Object
readonly
Attribute for field ach_credit_transfer.
-
#ach_debit ⇒ Object
readonly
Attribute for field ach_debit.
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billie ⇒ Object
readonly
Attribute for field billie.
-
#billing_details ⇒ Object
readonly
The billing details associated with the method of payment.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Details of the card used for this payment attempt.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#crypto ⇒ Object
readonly
Attribute for field crypto.
-
#custom ⇒ Object
readonly
Custom Payment Methods represent Payment Method types not modeled directly in the Stripe API.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#interac_present ⇒ Object
readonly
Attribute for field interac_present.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#payment_method ⇒ Object
readonly
ID of the Stripe PaymentMethod used to make this payment.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#paypay ⇒ Object
readonly
Attribute for field paypay.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#rechnung ⇒ Object
readonly
Attribute for field rechnung.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#sepa_credit_transfer ⇒ Object
readonly
Attribute for field sepa_credit_transfer.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#stripe_account ⇒ Object
readonly
Attribute for field stripe_account.
-
#stripe_balance ⇒ Object
readonly
Attribute for field stripe_balance.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of transaction-specific details of the payment method used in the payment.
-
#us_bank_account ⇒ Object
readonly
Details of the US Bank Account used for this payment attempt.
-
#wechat ⇒ Object
readonly
Attribute for field wechat.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ach_credit_transfer ⇒ Object (readonly)
Attribute for field ach_credit_transfer
1747 1748 1749 |
# File 'lib/stripe/resources/payment_record.rb', line 1747 def ach_credit_transfer @ach_credit_transfer end |
#ach_debit ⇒ Object (readonly)
Attribute for field ach_debit
1749 1750 1751 |
# File 'lib/stripe/resources/payment_record.rb', line 1749 def ach_debit @ach_debit end |
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
1751 1752 1753 |
# File 'lib/stripe/resources/payment_record.rb', line 1751 def acss_debit @acss_debit end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
1753 1754 1755 |
# File 'lib/stripe/resources/payment_record.rb', line 1753 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
1755 1756 1757 |
# File 'lib/stripe/resources/payment_record.rb', line 1755 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
1757 1758 1759 |
# File 'lib/stripe/resources/payment_record.rb', line 1757 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
1759 1760 1761 |
# File 'lib/stripe/resources/payment_record.rb', line 1759 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
1761 1762 1763 |
# File 'lib/stripe/resources/payment_record.rb', line 1761 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
1763 1764 1765 |
# File 'lib/stripe/resources/payment_record.rb', line 1763 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
1765 1766 1767 |
# File 'lib/stripe/resources/payment_record.rb', line 1765 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
1767 1768 1769 |
# File 'lib/stripe/resources/payment_record.rb', line 1767 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
Attribute for field billie
1769 1770 1771 |
# File 'lib/stripe/resources/payment_record.rb', line 1769 def billie @billie end |
#billing_details ⇒ Object (readonly)
The billing details associated with the method of payment.
1771 1772 1773 |
# File 'lib/stripe/resources/payment_record.rb', line 1771 def billing_details @billing_details end |
#blik ⇒ Object (readonly)
Attribute for field blik
1773 1774 1775 |
# File 'lib/stripe/resources/payment_record.rb', line 1773 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
1775 1776 1777 |
# File 'lib/stripe/resources/payment_record.rb', line 1775 def boleto @boleto end |
#card ⇒ Object (readonly)
Details of the card used for this payment attempt.
1777 1778 1779 |
# File 'lib/stripe/resources/payment_record.rb', line 1777 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
1779 1780 1781 |
# File 'lib/stripe/resources/payment_record.rb', line 1779 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
1781 1782 1783 |
# File 'lib/stripe/resources/payment_record.rb', line 1781 def cashapp @cashapp end |
#crypto ⇒ Object (readonly)
Attribute for field crypto
1783 1784 1785 |
# File 'lib/stripe/resources/payment_record.rb', line 1783 def crypto @crypto end |
#custom ⇒ Object (readonly)
Custom Payment Methods represent Payment Method types not modeled directly in the Stripe API. This resource consists of details about the custom payment method used for this payment attempt.
1787 1788 1789 |
# File 'lib/stripe/resources/payment_record.rb', line 1787 def custom @custom end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
1789 1790 1791 |
# File 'lib/stripe/resources/payment_record.rb', line 1789 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
1791 1792 1793 |
# File 'lib/stripe/resources/payment_record.rb', line 1791 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
1793 1794 1795 |
# File 'lib/stripe/resources/payment_record.rb', line 1793 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
1795 1796 1797 |
# File 'lib/stripe/resources/payment_record.rb', line 1795 def giropay @giropay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
1797 1798 1799 |
# File 'lib/stripe/resources/payment_record.rb', line 1797 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
1799 1800 1801 |
# File 'lib/stripe/resources/payment_record.rb', line 1799 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
1801 1802 1803 |
# File 'lib/stripe/resources/payment_record.rb', line 1801 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
1803 1804 1805 |
# File 'lib/stripe/resources/payment_record.rb', line 1803 def ideal @ideal end |
#interac_present ⇒ Object (readonly)
Attribute for field interac_present
1805 1806 1807 |
# File 'lib/stripe/resources/payment_record.rb', line 1805 def interac_present @interac_present end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
1807 1808 1809 |
# File 'lib/stripe/resources/payment_record.rb', line 1807 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
1809 1810 1811 |
# File 'lib/stripe/resources/payment_record.rb', line 1809 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
1811 1812 1813 |
# File 'lib/stripe/resources/payment_record.rb', line 1811 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
1813 1814 1815 |
# File 'lib/stripe/resources/payment_record.rb', line 1813 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
1815 1816 1817 |
# File 'lib/stripe/resources/payment_record.rb', line 1815 def link @link end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
1817 1818 1819 |
# File 'lib/stripe/resources/payment_record.rb', line 1817 def mb_way @mb_way end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
1819 1820 1821 |
# File 'lib/stripe/resources/payment_record.rb', line 1819 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
1821 1822 1823 |
# File 'lib/stripe/resources/payment_record.rb', line 1821 def multibanco @multibanco end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
1823 1824 1825 |
# File 'lib/stripe/resources/payment_record.rb', line 1823 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
1825 1826 1827 |
# File 'lib/stripe/resources/payment_record.rb', line 1825 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
1827 1828 1829 |
# File 'lib/stripe/resources/payment_record.rb', line 1827 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
1829 1830 1831 |
# File 'lib/stripe/resources/payment_record.rb', line 1829 def p24 @p24 end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
1831 1832 1833 |
# File 'lib/stripe/resources/payment_record.rb', line 1831 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
1833 1834 1835 |
# File 'lib/stripe/resources/payment_record.rb', line 1833 def payco @payco end |
#payment_method ⇒ Object (readonly)
ID of the Stripe PaymentMethod used to make this payment.
1835 1836 1837 |
# File 'lib/stripe/resources/payment_record.rb', line 1835 def payment_method @payment_method end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
1837 1838 1839 |
# File 'lib/stripe/resources/payment_record.rb', line 1837 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
1839 1840 1841 |
# File 'lib/stripe/resources/payment_record.rb', line 1839 def paypal @paypal end |
#paypay ⇒ Object (readonly)
Attribute for field paypay
1841 1842 1843 |
# File 'lib/stripe/resources/payment_record.rb', line 1841 def paypay @paypay end |
#payto ⇒ Object (readonly)
Attribute for field payto
1843 1844 1845 |
# File 'lib/stripe/resources/payment_record.rb', line 1843 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
1845 1846 1847 |
# File 'lib/stripe/resources/payment_record.rb', line 1845 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
1847 1848 1849 |
# File 'lib/stripe/resources/payment_record.rb', line 1847 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
1849 1850 1851 |
# File 'lib/stripe/resources/payment_record.rb', line 1849 def qris @qris end |
#rechnung ⇒ Object (readonly)
Attribute for field rechnung
1851 1852 1853 |
# File 'lib/stripe/resources/payment_record.rb', line 1851 def rechnung @rechnung end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
1853 1854 1855 |
# File 'lib/stripe/resources/payment_record.rb', line 1853 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
1855 1856 1857 |
# File 'lib/stripe/resources/payment_record.rb', line 1855 def samsung_pay @samsung_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
1857 1858 1859 |
# File 'lib/stripe/resources/payment_record.rb', line 1857 def satispay @satispay end |
#sepa_credit_transfer ⇒ Object (readonly)
Attribute for field sepa_credit_transfer
1859 1860 1861 |
# File 'lib/stripe/resources/payment_record.rb', line 1859 def sepa_credit_transfer @sepa_credit_transfer end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
1861 1862 1863 |
# File 'lib/stripe/resources/payment_record.rb', line 1861 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
1863 1864 1865 |
# File 'lib/stripe/resources/payment_record.rb', line 1863 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
1865 1866 1867 |
# File 'lib/stripe/resources/payment_record.rb', line 1865 def sofort @sofort end |
#stripe_account ⇒ Object (readonly)
Attribute for field stripe_account
1867 1868 1869 |
# File 'lib/stripe/resources/payment_record.rb', line 1867 def stripe_account @stripe_account end |
#stripe_balance ⇒ Object (readonly)
Attribute for field stripe_balance
1869 1870 1871 |
# File 'lib/stripe/resources/payment_record.rb', line 1869 def stripe_balance @stripe_balance end |
#swish ⇒ Object (readonly)
Attribute for field swish
1871 1872 1873 |
# File 'lib/stripe/resources/payment_record.rb', line 1871 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
1873 1874 1875 |
# File 'lib/stripe/resources/payment_record.rb', line 1873 def twint @twint end |
#type ⇒ Object (readonly)
The type of transaction-specific details of the payment method used in the payment. See [PaymentMethod.type](stripe.com/docs/api/payment_methods/object#payment_method_object-type) for the full list of possible types. An additional hash is included on ‘payment_method_details` with a name matching this value. It contains information specific to the payment method.
1877 1878 1879 |
# File 'lib/stripe/resources/payment_record.rb', line 1877 def type @type end |
#us_bank_account ⇒ Object (readonly)
Details of the US Bank Account used for this payment attempt.
1879 1880 1881 |
# File 'lib/stripe/resources/payment_record.rb', line 1879 def us_bank_account @us_bank_account end |
#wechat ⇒ Object (readonly)
Attribute for field wechat
1881 1882 1883 |
# File 'lib/stripe/resources/payment_record.rb', line 1881 def wechat @wechat end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
1883 1884 1885 |
# File 'lib/stripe/resources/payment_record.rb', line 1883 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
1885 1886 1887 |
# File 'lib/stripe/resources/payment_record.rb', line 1885 def zip @zip end |
Class Method Details
.field_remappings ⇒ Object
1958 1959 1960 |
# File 'lib/stripe/resources/payment_record.rb', line 1958 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 1903 1904 1905 1906 1907 1908 1909 1910 1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 |
# File 'lib/stripe/resources/payment_record.rb', line 1887 def self.inner_class_types @inner_class_types = { ach_credit_transfer: AchCreditTransfer, ach_debit: AchDebit, acss_debit: AcssDebit, affirm: Affirm, afterpay_clearpay: AfterpayClearpay, alipay: Alipay, alma: Alma, amazon_pay: AmazonPay, au_becs_debit: AuBecsDebit, bacs_debit: BacsDebit, bancontact: Bancontact, billie: Billie, billing_details: BillingDetails, blik: Blik, boleto: Boleto, card: Card, card_present: CardPresent, cashapp: Cashapp, crypto: Crypto, custom: Custom, customer_balance: CustomerBalance, eps: Eps, fpx: Fpx, giropay: Giropay, gopay: Gopay, grabpay: Grabpay, id_bank_transfer: IdBankTransfer, ideal: Ideal, interac_present: InteracPresent, kakao_pay: KakaoPay, klarna: Klarna, konbini: Konbini, kr_card: KrCard, link: Link, mb_way: MbWay, mobilepay: Mobilepay, multibanco: Multibanco, naver_pay: NaverPay, nz_bank_account: NzBankAccount, oxxo: Oxxo, p24: P24, pay_by_bank: PayByBank, payco: Payco, paynow: Paynow, paypal: Paypal, paypay: Paypay, payto: Payto, pix: Pix, promptpay: Promptpay, qris: Qris, rechnung: Rechnung, revolut_pay: RevolutPay, samsung_pay: SamsungPay, satispay: Satispay, sepa_credit_transfer: SepaCreditTransfer, sepa_debit: SepaDebit, shopeepay: Shopeepay, sofort: Sofort, stripe_account: StripeAccount, stripe_balance: StripeBalance, swish: Swish, twint: Twint, us_bank_account: UsBankAccount, wechat: Wechat, wechat_pay: WechatPay, zip: Zip, } end |