Class: Stripe::PaymentRecord::PaymentMethodDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, Custom, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaCreditTransfer, SepaDebit, Shopeepay, Sofort, StripeAccount, StripeBalance, Swish, Twint, UsBankAccount, Wechat, WechatPay, Zip

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#ach_credit_transferObject (readonly)

Attribute for field ach_credit_transfer



1686
1687
1688
# File 'lib/stripe/resources/payment_record.rb', line 1686

def ach_credit_transfer
  @ach_credit_transfer
end

#ach_debitObject (readonly)

Attribute for field ach_debit



1688
1689
1690
# File 'lib/stripe/resources/payment_record.rb', line 1688

def ach_debit
  @ach_debit
end

#acss_debitObject (readonly)

Attribute for field acss_debit



1690
1691
1692
# File 'lib/stripe/resources/payment_record.rb', line 1690

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



1692
1693
1694
# File 'lib/stripe/resources/payment_record.rb', line 1692

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



1694
1695
1696
# File 'lib/stripe/resources/payment_record.rb', line 1694

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



1696
1697
1698
# File 'lib/stripe/resources/payment_record.rb', line 1696

def alipay
  @alipay
end

#almaObject (readonly)

Attribute for field alma



1698
1699
1700
# File 'lib/stripe/resources/payment_record.rb', line 1698

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



1700
1701
1702
# File 'lib/stripe/resources/payment_record.rb', line 1700

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



1702
1703
1704
# File 'lib/stripe/resources/payment_record.rb', line 1702

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



1704
1705
1706
# File 'lib/stripe/resources/payment_record.rb', line 1704

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



1706
1707
1708
# File 'lib/stripe/resources/payment_record.rb', line 1706

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



1708
1709
1710
# File 'lib/stripe/resources/payment_record.rb', line 1708

def billie
  @billie
end

#billing_detailsObject (readonly)

The billing details associated with the method of payment.



1710
1711
1712
# File 'lib/stripe/resources/payment_record.rb', line 1710

def billing_details
  @billing_details
end

#blikObject (readonly)

Attribute for field blik



1712
1713
1714
# File 'lib/stripe/resources/payment_record.rb', line 1712

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



1714
1715
1716
# File 'lib/stripe/resources/payment_record.rb', line 1714

def boleto
  @boleto
end

#cardObject (readonly)

Details of the card used for this payment attempt.



1716
1717
1718
# File 'lib/stripe/resources/payment_record.rb', line 1716

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



1718
1719
1720
# File 'lib/stripe/resources/payment_record.rb', line 1718

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



1720
1721
1722
# File 'lib/stripe/resources/payment_record.rb', line 1720

def cashapp
  @cashapp
end

#cryptoObject (readonly)

Attribute for field crypto



1722
1723
1724
# File 'lib/stripe/resources/payment_record.rb', line 1722

def crypto
  @crypto
end

#customObject (readonly)

Custom Payment Methods represent Payment Method types not modeled directly in the Stripe API. This resource consists of details about the custom payment method used for this payment attempt.



1726
1727
1728
# File 'lib/stripe/resources/payment_record.rb', line 1726

def custom
  @custom
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



1728
1729
1730
# File 'lib/stripe/resources/payment_record.rb', line 1728

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



1730
1731
1732
# File 'lib/stripe/resources/payment_record.rb', line 1730

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



1732
1733
1734
# File 'lib/stripe/resources/payment_record.rb', line 1732

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



1734
1735
1736
# File 'lib/stripe/resources/payment_record.rb', line 1734

def giropay
  @giropay
end

#gopayObject (readonly)

Attribute for field gopay



1736
1737
1738
# File 'lib/stripe/resources/payment_record.rb', line 1736

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



1738
1739
1740
# File 'lib/stripe/resources/payment_record.rb', line 1738

def grabpay
  @grabpay
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



1740
1741
1742
# File 'lib/stripe/resources/payment_record.rb', line 1740

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



1742
1743
1744
# File 'lib/stripe/resources/payment_record.rb', line 1742

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



1744
1745
1746
# File 'lib/stripe/resources/payment_record.rb', line 1744

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



1746
1747
1748
# File 'lib/stripe/resources/payment_record.rb', line 1746

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



1748
1749
1750
# File 'lib/stripe/resources/payment_record.rb', line 1748

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



1750
1751
1752
# File 'lib/stripe/resources/payment_record.rb', line 1750

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



1752
1753
1754
# File 'lib/stripe/resources/payment_record.rb', line 1752

def kr_card
  @kr_card
end

Attribute for field link



1754
1755
1756
# File 'lib/stripe/resources/payment_record.rb', line 1754

def link
  @link
end

#mb_wayObject (readonly)

Attribute for field mb_way



1756
1757
1758
# File 'lib/stripe/resources/payment_record.rb', line 1756

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



1758
1759
1760
# File 'lib/stripe/resources/payment_record.rb', line 1758

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



1760
1761
1762
# File 'lib/stripe/resources/payment_record.rb', line 1760

def multibanco
  @multibanco
end

Attribute for field naver_pay



1762
1763
1764
# File 'lib/stripe/resources/payment_record.rb', line 1762

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



1764
1765
1766
# File 'lib/stripe/resources/payment_record.rb', line 1764

def 
  @nz_bank_account
end

#oxxoObject (readonly)

Attribute for field oxxo



1766
1767
1768
# File 'lib/stripe/resources/payment_record.rb', line 1766

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



1768
1769
1770
# File 'lib/stripe/resources/payment_record.rb', line 1768

def p24
  @p24
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



1770
1771
1772
# File 'lib/stripe/resources/payment_record.rb', line 1770

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



1772
1773
1774
# File 'lib/stripe/resources/payment_record.rb', line 1772

def payco
  @payco
end

#payment_methodObject (readonly)

ID of the Stripe PaymentMethod used to make this payment.



1774
1775
1776
# File 'lib/stripe/resources/payment_record.rb', line 1774

def payment_method
  @payment_method
end

#paynowObject (readonly)

Attribute for field paynow



1776
1777
1778
# File 'lib/stripe/resources/payment_record.rb', line 1776

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



1778
1779
1780
# File 'lib/stripe/resources/payment_record.rb', line 1778

def paypal
  @paypal
end

#paytoObject (readonly)

Attribute for field payto



1780
1781
1782
# File 'lib/stripe/resources/payment_record.rb', line 1780

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



1782
1783
1784
# File 'lib/stripe/resources/payment_record.rb', line 1782

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



1784
1785
1786
# File 'lib/stripe/resources/payment_record.rb', line 1784

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



1786
1787
1788
# File 'lib/stripe/resources/payment_record.rb', line 1786

def qris
  @qris
end

#rechnungObject (readonly)

Attribute for field rechnung



1788
1789
1790
# File 'lib/stripe/resources/payment_record.rb', line 1788

def rechnung
  @rechnung
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



1790
1791
1792
# File 'lib/stripe/resources/payment_record.rb', line 1790

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



1792
1793
1794
# File 'lib/stripe/resources/payment_record.rb', line 1792

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



1794
1795
1796
# File 'lib/stripe/resources/payment_record.rb', line 1794

def satispay
  @satispay
end

#sepa_credit_transferObject (readonly)

Attribute for field sepa_credit_transfer



1796
1797
1798
# File 'lib/stripe/resources/payment_record.rb', line 1796

def sepa_credit_transfer
  @sepa_credit_transfer
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



1798
1799
1800
# File 'lib/stripe/resources/payment_record.rb', line 1798

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



1800
1801
1802
# File 'lib/stripe/resources/payment_record.rb', line 1800

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



1802
1803
1804
# File 'lib/stripe/resources/payment_record.rb', line 1802

def sofort
  @sofort
end

#stripe_accountObject (readonly)

Attribute for field stripe_account



1804
1805
1806
# File 'lib/stripe/resources/payment_record.rb', line 1804

def 
  @stripe_account
end

#stripe_balanceObject (readonly)

Attribute for field stripe_balance



1806
1807
1808
# File 'lib/stripe/resources/payment_record.rb', line 1806

def stripe_balance
  @stripe_balance
end

#swishObject (readonly)

Attribute for field swish



1808
1809
1810
# File 'lib/stripe/resources/payment_record.rb', line 1808

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



1810
1811
1812
# File 'lib/stripe/resources/payment_record.rb', line 1810

def twint
  @twint
end

#typeObject (readonly)

The type of transaction-specific details of the payment method used in the payment. See [PaymentMethod.type](stripe.com/docs/api/payment_methods/object#payment_method_object-type) for the full list of possible types. An additional hash is included on ‘payment_method_details` with a name matching this value. It contains information specific to the payment method.



1814
1815
1816
# File 'lib/stripe/resources/payment_record.rb', line 1814

def type
  @type
end

#us_bank_accountObject (readonly)

Details of the US Bank Account used for this payment attempt.



1816
1817
1818
# File 'lib/stripe/resources/payment_record.rb', line 1816

def 
  @us_bank_account
end

#wechatObject (readonly)

Attribute for field wechat



1818
1819
1820
# File 'lib/stripe/resources/payment_record.rb', line 1818

def wechat
  @wechat
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



1820
1821
1822
# File 'lib/stripe/resources/payment_record.rb', line 1820

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



1822
1823
1824
# File 'lib/stripe/resources/payment_record.rb', line 1822

def zip
  @zip
end

Class Method Details

.field_remappingsObject



1894
1895
1896
# File 'lib/stripe/resources/payment_record.rb', line 1894

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
# File 'lib/stripe/resources/payment_record.rb', line 1824

def self.inner_class_types
  @inner_class_types = {
    ach_credit_transfer: AchCreditTransfer,
    ach_debit: AchDebit,
    acss_debit: AcssDebit,
    affirm: Affirm,
    afterpay_clearpay: AfterpayClearpay,
    alipay: Alipay,
    alma: Alma,
    amazon_pay: AmazonPay,
    au_becs_debit: AuBecsDebit,
    bacs_debit: BacsDebit,
    bancontact: Bancontact,
    billie: Billie,
    billing_details: BillingDetails,
    blik: Blik,
    boleto: Boleto,
    card: Card,
    card_present: CardPresent,
    cashapp: Cashapp,
    crypto: Crypto,
    custom: Custom,
    customer_balance: CustomerBalance,
    eps: Eps,
    fpx: Fpx,
    giropay: Giropay,
    gopay: Gopay,
    grabpay: Grabpay,
    id_bank_transfer: IdBankTransfer,
    ideal: Ideal,
    interac_present: InteracPresent,
    kakao_pay: KakaoPay,
    klarna: Klarna,
    konbini: Konbini,
    kr_card: KrCard,
    link: Link,
    mb_way: MbWay,
    mobilepay: Mobilepay,
    multibanco: Multibanco,
    naver_pay: NaverPay,
    nz_bank_account: NzBankAccount,
    oxxo: Oxxo,
    p24: P24,
    pay_by_bank: PayByBank,
    payco: Payco,
    paynow: Paynow,
    paypal: Paypal,
    payto: Payto,
    pix: Pix,
    promptpay: Promptpay,
    qris: Qris,
    rechnung: Rechnung,
    revolut_pay: RevolutPay,
    samsung_pay: SamsungPay,
    satispay: Satispay,
    sepa_credit_transfer: SepaCreditTransfer,
    sepa_debit: SepaDebit,
    shopeepay: Shopeepay,
    sofort: Sofort,
    stripe_account: StripeAccount,
    stripe_balance: StripeBalance,
    swish: Swish,
    twint: Twint,
    us_bank_account: UsBankAccount,
    wechat: Wechat,
    wechat_pay: WechatPay,
    zip: Zip,
  }
end