Class: Stripe::PaymentRecord::PaymentMethodDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, Custom, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaCreditTransfer, SepaDebit, Shopeepay, Sofort, StripeAccount, StripeBalance, Swish, Twint, UsBankAccount, Wechat, WechatPay, Zip

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#ach_credit_transferObject (readonly)

Attribute for field ach_credit_transfer



879
880
881
# File 'lib/stripe/resources/payment_record.rb', line 879

def ach_credit_transfer
  @ach_credit_transfer
end

#ach_debitObject (readonly)

Attribute for field ach_debit



881
882
883
# File 'lib/stripe/resources/payment_record.rb', line 881

def ach_debit
  @ach_debit
end

#acss_debitObject (readonly)

Attribute for field acss_debit



883
884
885
# File 'lib/stripe/resources/payment_record.rb', line 883

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



885
886
887
# File 'lib/stripe/resources/payment_record.rb', line 885

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



887
888
889
# File 'lib/stripe/resources/payment_record.rb', line 887

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



889
890
891
# File 'lib/stripe/resources/payment_record.rb', line 889

def alipay
  @alipay
end

#almaObject (readonly)

Attribute for field alma



891
892
893
# File 'lib/stripe/resources/payment_record.rb', line 891

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



893
894
895
# File 'lib/stripe/resources/payment_record.rb', line 893

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



895
896
897
# File 'lib/stripe/resources/payment_record.rb', line 895

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



897
898
899
# File 'lib/stripe/resources/payment_record.rb', line 897

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



899
900
901
# File 'lib/stripe/resources/payment_record.rb', line 899

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



901
902
903
# File 'lib/stripe/resources/payment_record.rb', line 901

def billie
  @billie
end

#billing_detailsObject (readonly)

The billing details associated with the method of payment.



903
904
905
# File 'lib/stripe/resources/payment_record.rb', line 903

def billing_details
  @billing_details
end

#blikObject (readonly)

Attribute for field blik



905
906
907
# File 'lib/stripe/resources/payment_record.rb', line 905

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



907
908
909
# File 'lib/stripe/resources/payment_record.rb', line 907

def boleto
  @boleto
end

#cardObject (readonly)

Details of the card used for this payment attempt.



909
910
911
# File 'lib/stripe/resources/payment_record.rb', line 909

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



911
912
913
# File 'lib/stripe/resources/payment_record.rb', line 911

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



913
914
915
# File 'lib/stripe/resources/payment_record.rb', line 913

def cashapp
  @cashapp
end

#cryptoObject (readonly)

Attribute for field crypto



915
916
917
# File 'lib/stripe/resources/payment_record.rb', line 915

def crypto
  @crypto
end

#customObject (readonly)

Custom Payment Methods represent Payment Method types not modeled directly in the Stripe API. This resource consists of details about the custom payment method used for this payment attempt.



919
920
921
# File 'lib/stripe/resources/payment_record.rb', line 919

def custom
  @custom
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



921
922
923
# File 'lib/stripe/resources/payment_record.rb', line 921

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



923
924
925
# File 'lib/stripe/resources/payment_record.rb', line 923

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



925
926
927
# File 'lib/stripe/resources/payment_record.rb', line 925

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



927
928
929
# File 'lib/stripe/resources/payment_record.rb', line 927

def giropay
  @giropay
end

#gopayObject (readonly)

Attribute for field gopay



929
930
931
# File 'lib/stripe/resources/payment_record.rb', line 929

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



931
932
933
# File 'lib/stripe/resources/payment_record.rb', line 931

def grabpay
  @grabpay
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



933
934
935
# File 'lib/stripe/resources/payment_record.rb', line 933

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



935
936
937
# File 'lib/stripe/resources/payment_record.rb', line 935

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



937
938
939
# File 'lib/stripe/resources/payment_record.rb', line 937

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



939
940
941
# File 'lib/stripe/resources/payment_record.rb', line 939

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



941
942
943
# File 'lib/stripe/resources/payment_record.rb', line 941

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



943
944
945
# File 'lib/stripe/resources/payment_record.rb', line 943

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



945
946
947
# File 'lib/stripe/resources/payment_record.rb', line 945

def kr_card
  @kr_card
end

Attribute for field link



947
948
949
# File 'lib/stripe/resources/payment_record.rb', line 947

def link
  @link
end

#mb_wayObject (readonly)

Attribute for field mb_way



949
950
951
# File 'lib/stripe/resources/payment_record.rb', line 949

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



951
952
953
# File 'lib/stripe/resources/payment_record.rb', line 951

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



953
954
955
# File 'lib/stripe/resources/payment_record.rb', line 953

def multibanco
  @multibanco
end

Attribute for field naver_pay



955
956
957
# File 'lib/stripe/resources/payment_record.rb', line 955

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



957
958
959
# File 'lib/stripe/resources/payment_record.rb', line 957

def 
  @nz_bank_account
end

#oxxoObject (readonly)

Attribute for field oxxo



959
960
961
# File 'lib/stripe/resources/payment_record.rb', line 959

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



961
962
963
# File 'lib/stripe/resources/payment_record.rb', line 961

def p24
  @p24
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



963
964
965
# File 'lib/stripe/resources/payment_record.rb', line 963

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



965
966
967
# File 'lib/stripe/resources/payment_record.rb', line 965

def payco
  @payco
end

#payment_methodObject (readonly)

ID of the Stripe PaymentMethod used to make this payment.



967
968
969
# File 'lib/stripe/resources/payment_record.rb', line 967

def payment_method
  @payment_method
end

#paynowObject (readonly)

Attribute for field paynow



969
970
971
# File 'lib/stripe/resources/payment_record.rb', line 969

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



971
972
973
# File 'lib/stripe/resources/payment_record.rb', line 971

def paypal
  @paypal
end

#paytoObject (readonly)

Attribute for field payto



973
974
975
# File 'lib/stripe/resources/payment_record.rb', line 973

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



975
976
977
# File 'lib/stripe/resources/payment_record.rb', line 975

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



977
978
979
# File 'lib/stripe/resources/payment_record.rb', line 977

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



979
980
981
# File 'lib/stripe/resources/payment_record.rb', line 979

def qris
  @qris
end

#rechnungObject (readonly)

Attribute for field rechnung



981
982
983
# File 'lib/stripe/resources/payment_record.rb', line 981

def rechnung
  @rechnung
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



983
984
985
# File 'lib/stripe/resources/payment_record.rb', line 983

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



985
986
987
# File 'lib/stripe/resources/payment_record.rb', line 985

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



987
988
989
# File 'lib/stripe/resources/payment_record.rb', line 987

def satispay
  @satispay
end

#sepa_credit_transferObject (readonly)

Attribute for field sepa_credit_transfer



989
990
991
# File 'lib/stripe/resources/payment_record.rb', line 989

def sepa_credit_transfer
  @sepa_credit_transfer
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



991
992
993
# File 'lib/stripe/resources/payment_record.rb', line 991

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



993
994
995
# File 'lib/stripe/resources/payment_record.rb', line 993

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



995
996
997
# File 'lib/stripe/resources/payment_record.rb', line 995

def sofort
  @sofort
end

#stripe_accountObject (readonly)

Attribute for field stripe_account



997
998
999
# File 'lib/stripe/resources/payment_record.rb', line 997

def 
  @stripe_account
end

#stripe_balanceObject (readonly)

Attribute for field stripe_balance



999
1000
1001
# File 'lib/stripe/resources/payment_record.rb', line 999

def stripe_balance
  @stripe_balance
end

#swishObject (readonly)

Attribute for field swish



1001
1002
1003
# File 'lib/stripe/resources/payment_record.rb', line 1001

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



1003
1004
1005
# File 'lib/stripe/resources/payment_record.rb', line 1003

def twint
  @twint
end

#typeObject (readonly)

The type of transaction-specific details of the payment method used in the payment. See [PaymentMethod.type](stripe.com/docs/api/payment_methods/object#payment_method_object-type) for the full list of possible types. An additional hash is included on ‘payment_method_details` with a name matching this value. It contains information specific to the payment method.



1007
1008
1009
# File 'lib/stripe/resources/payment_record.rb', line 1007

def type
  @type
end

#us_bank_accountObject (readonly)

Details of the US Bank Account used for this payment attempt.



1009
1010
1011
# File 'lib/stripe/resources/payment_record.rb', line 1009

def 
  @us_bank_account
end

#wechatObject (readonly)

Attribute for field wechat



1011
1012
1013
# File 'lib/stripe/resources/payment_record.rb', line 1011

def wechat
  @wechat
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



1013
1014
1015
# File 'lib/stripe/resources/payment_record.rb', line 1013

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



1015
1016
1017
# File 'lib/stripe/resources/payment_record.rb', line 1015

def zip
  @zip
end