Class: Stripe::PaymentRecord::PaymentMethodDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, Custom, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaCreditTransfer, SepaDebit, Shopeepay, Sofort, StripeAccount, StripeBalance, Swish, Twint, UsBankAccount, Wechat, WechatPay, Zip

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#ach_credit_transferObject (readonly)

Attribute for field ach_credit_transfer



860
861
862
# File 'lib/stripe/resources/payment_record.rb', line 860

def ach_credit_transfer
  @ach_credit_transfer
end

#ach_debitObject (readonly)

Attribute for field ach_debit



862
863
864
# File 'lib/stripe/resources/payment_record.rb', line 862

def ach_debit
  @ach_debit
end

#acss_debitObject (readonly)

Attribute for field acss_debit



864
865
866
# File 'lib/stripe/resources/payment_record.rb', line 864

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



866
867
868
# File 'lib/stripe/resources/payment_record.rb', line 866

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



868
869
870
# File 'lib/stripe/resources/payment_record.rb', line 868

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



870
871
872
# File 'lib/stripe/resources/payment_record.rb', line 870

def alipay
  @alipay
end

#almaObject (readonly)

Attribute for field alma



872
873
874
# File 'lib/stripe/resources/payment_record.rb', line 872

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



874
875
876
# File 'lib/stripe/resources/payment_record.rb', line 874

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



876
877
878
# File 'lib/stripe/resources/payment_record.rb', line 876

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



878
879
880
# File 'lib/stripe/resources/payment_record.rb', line 878

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



880
881
882
# File 'lib/stripe/resources/payment_record.rb', line 880

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



882
883
884
# File 'lib/stripe/resources/payment_record.rb', line 882

def billie
  @billie
end

#billing_detailsObject (readonly)

The billing details associated with the method of payment.



884
885
886
# File 'lib/stripe/resources/payment_record.rb', line 884

def billing_details
  @billing_details
end

#blikObject (readonly)

Attribute for field blik



886
887
888
# File 'lib/stripe/resources/payment_record.rb', line 886

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



888
889
890
# File 'lib/stripe/resources/payment_record.rb', line 888

def boleto
  @boleto
end

#cardObject (readonly)

Details of the card used for this payment attempt.



890
891
892
# File 'lib/stripe/resources/payment_record.rb', line 890

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



892
893
894
# File 'lib/stripe/resources/payment_record.rb', line 892

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



894
895
896
# File 'lib/stripe/resources/payment_record.rb', line 894

def cashapp
  @cashapp
end

#customObject (readonly)

Custom Payment Methods represent Payment Method types not modeled directly in the Stripe API. This resource consists of details about the custom payment method used for this payment attempt.



898
899
900
# File 'lib/stripe/resources/payment_record.rb', line 898

def custom
  @custom
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



900
901
902
# File 'lib/stripe/resources/payment_record.rb', line 900

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



902
903
904
# File 'lib/stripe/resources/payment_record.rb', line 902

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



904
905
906
# File 'lib/stripe/resources/payment_record.rb', line 904

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



906
907
908
# File 'lib/stripe/resources/payment_record.rb', line 906

def giropay
  @giropay
end

#gopayObject (readonly)

Attribute for field gopay



908
909
910
# File 'lib/stripe/resources/payment_record.rb', line 908

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



910
911
912
# File 'lib/stripe/resources/payment_record.rb', line 910

def grabpay
  @grabpay
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



912
913
914
# File 'lib/stripe/resources/payment_record.rb', line 912

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



914
915
916
# File 'lib/stripe/resources/payment_record.rb', line 914

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



916
917
918
# File 'lib/stripe/resources/payment_record.rb', line 916

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



918
919
920
# File 'lib/stripe/resources/payment_record.rb', line 918

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



920
921
922
# File 'lib/stripe/resources/payment_record.rb', line 920

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



922
923
924
# File 'lib/stripe/resources/payment_record.rb', line 922

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



924
925
926
# File 'lib/stripe/resources/payment_record.rb', line 924

def kr_card
  @kr_card
end

Attribute for field link



926
927
928
# File 'lib/stripe/resources/payment_record.rb', line 926

def link
  @link
end

#mb_wayObject (readonly)

Attribute for field mb_way



928
929
930
# File 'lib/stripe/resources/payment_record.rb', line 928

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



930
931
932
# File 'lib/stripe/resources/payment_record.rb', line 930

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



932
933
934
# File 'lib/stripe/resources/payment_record.rb', line 932

def multibanco
  @multibanco
end

Attribute for field naver_pay



934
935
936
# File 'lib/stripe/resources/payment_record.rb', line 934

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



936
937
938
# File 'lib/stripe/resources/payment_record.rb', line 936

def 
  @nz_bank_account
end

#oxxoObject (readonly)

Attribute for field oxxo



938
939
940
# File 'lib/stripe/resources/payment_record.rb', line 938

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



940
941
942
# File 'lib/stripe/resources/payment_record.rb', line 940

def p24
  @p24
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



942
943
944
# File 'lib/stripe/resources/payment_record.rb', line 942

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



944
945
946
# File 'lib/stripe/resources/payment_record.rb', line 944

def payco
  @payco
end

#payment_methodObject (readonly)

ID of the Stripe PaymentMethod used to make this payment.



946
947
948
# File 'lib/stripe/resources/payment_record.rb', line 946

def payment_method
  @payment_method
end

#paynowObject (readonly)

Attribute for field paynow



948
949
950
# File 'lib/stripe/resources/payment_record.rb', line 948

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



950
951
952
# File 'lib/stripe/resources/payment_record.rb', line 950

def paypal
  @paypal
end

#paytoObject (readonly)

Attribute for field payto



952
953
954
# File 'lib/stripe/resources/payment_record.rb', line 952

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



954
955
956
# File 'lib/stripe/resources/payment_record.rb', line 954

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



956
957
958
# File 'lib/stripe/resources/payment_record.rb', line 956

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



958
959
960
# File 'lib/stripe/resources/payment_record.rb', line 958

def qris
  @qris
end

#rechnungObject (readonly)

Attribute for field rechnung



960
961
962
# File 'lib/stripe/resources/payment_record.rb', line 960

def rechnung
  @rechnung
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



962
963
964
# File 'lib/stripe/resources/payment_record.rb', line 962

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



964
965
966
# File 'lib/stripe/resources/payment_record.rb', line 964

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



966
967
968
# File 'lib/stripe/resources/payment_record.rb', line 966

def satispay
  @satispay
end

#sepa_credit_transferObject (readonly)

Attribute for field sepa_credit_transfer



968
969
970
# File 'lib/stripe/resources/payment_record.rb', line 968

def sepa_credit_transfer
  @sepa_credit_transfer
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



970
971
972
# File 'lib/stripe/resources/payment_record.rb', line 970

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



972
973
974
# File 'lib/stripe/resources/payment_record.rb', line 972

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



974
975
976
# File 'lib/stripe/resources/payment_record.rb', line 974

def sofort
  @sofort
end

#stripe_accountObject (readonly)

Attribute for field stripe_account



976
977
978
# File 'lib/stripe/resources/payment_record.rb', line 976

def 
  @stripe_account
end

#stripe_balanceObject (readonly)

Attribute for field stripe_balance



978
979
980
# File 'lib/stripe/resources/payment_record.rb', line 978

def stripe_balance
  @stripe_balance
end

#swishObject (readonly)

Attribute for field swish



980
981
982
# File 'lib/stripe/resources/payment_record.rb', line 980

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



982
983
984
# File 'lib/stripe/resources/payment_record.rb', line 982

def twint
  @twint
end

#typeObject (readonly)

The type of transaction-specific details of the payment method used in the payment. See [PaymentMethod.type](stripe.com/docs/api/payment_methods/object#payment_method_object-type) for the full list of possible types. An additional hash is included on ‘payment_method_details` with a name matching this value. It contains information specific to the payment method.



986
987
988
# File 'lib/stripe/resources/payment_record.rb', line 986

def type
  @type
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



988
989
990
# File 'lib/stripe/resources/payment_record.rb', line 988

def 
  @us_bank_account
end

#wechatObject (readonly)

Attribute for field wechat



990
991
992
# File 'lib/stripe/resources/payment_record.rb', line 990

def wechat
  @wechat
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



992
993
994
# File 'lib/stripe/resources/payment_record.rb', line 992

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



994
995
996
# File 'lib/stripe/resources/payment_record.rb', line 994

def zip
  @zip
end