Class: Stripe::PaymentRecord::PaymentMethodDetails::BillingDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: Address

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

A representation of a physical address.



83
84
85
# File 'lib/stripe/resources/payment_record.rb', line 83

def address
  @address
end

#emailObject (readonly)

The billing email associated with the method of payment.



86
87
88
# File 'lib/stripe/resources/payment_record.rb', line 86

def email
  @email
end

#nameObject (readonly)

The billing name associated with the method of payment.



89
90
91
# File 'lib/stripe/resources/payment_record.rb', line 89

def name
  @name
end

#phoneObject (readonly)

The billing phone number associated with the method of payment.



92
93
94
# File 'lib/stripe/resources/payment_record.rb', line 92

def phone
  @phone
end