Class: Stripe::PaymentRecord::PaymentMethodDetails::Card
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentRecord::PaymentMethodDetails::Card
- Defined in:
- lib/stripe/resources/payment_record.rb
Defined Under Namespace
Classes: Checks, NetworkToken, ThreeDSecure
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#brand ⇒ Object
readonly
Card brand.
-
#capture_before ⇒ Object
readonly
When using manual capture, a future timestamp at which the charge will be automatically refunded if uncaptured.
-
#checks ⇒ Object
readonly
Check results by Card networks on Card address and CVC at time of payment.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country of the card.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card’s expiration year.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular card number.
-
#funding ⇒ Object
readonly
Card funding type.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#moto ⇒ Object
readonly
True if this payment was marked as MOTO and out of scope for SCA.
-
#network ⇒ Object
readonly
Identifies which network this charge was processed on.
-
#network_token ⇒ Object
readonly
If this card has network token credentials, this contains the details of the network token credentials.
-
#network_transaction_id ⇒ Object
readonly
This is used by the financial networks to identify a transaction.
-
#three_d_secure ⇒ Object
readonly
Populated if this transaction used 3D Secure authentication.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#brand ⇒ Object (readonly)
Card brand. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa` or `unknown`.
291 292 293 |
# File 'lib/stripe/resources/payment_record.rb', line 291 def brand @brand end |
#capture_before ⇒ Object (readonly)
When using manual capture, a future timestamp at which the charge will be automatically refunded if uncaptured.
293 294 295 |
# File 'lib/stripe/resources/payment_record.rb', line 293 def capture_before @capture_before end |
#checks ⇒ Object (readonly)
Check results by Card networks on Card address and CVC at time of payment.
295 296 297 |
# File 'lib/stripe/resources/payment_record.rb', line 295 def checks @checks end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.
297 298 299 |
# File 'lib/stripe/resources/payment_record.rb', line 297 def country @country end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card’s expiration month.
299 300 301 |
# File 'lib/stripe/resources/payment_record.rb', line 299 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card’s expiration year.
301 302 303 |
# File 'lib/stripe/resources/payment_record.rb', line 301 def exp_year @exp_year end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.
*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*
305 306 307 |
# File 'lib/stripe/resources/payment_record.rb', line 305 def fingerprint @fingerprint end |
#funding ⇒ Object (readonly)
Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.
307 308 309 |
# File 'lib/stripe/resources/payment_record.rb', line 307 def funding @funding end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
309 310 311 |
# File 'lib/stripe/resources/payment_record.rb', line 309 def last4 @last4 end |
#moto ⇒ Object (readonly)
True if this payment was marked as MOTO and out of scope for SCA.
311 312 313 |
# File 'lib/stripe/resources/payment_record.rb', line 311 def moto @moto end |
#network ⇒ Object (readonly)
Identifies which network this charge was processed on. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `interac`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.
313 314 315 |
# File 'lib/stripe/resources/payment_record.rb', line 313 def network @network end |
#network_token ⇒ Object (readonly)
If this card has network token credentials, this contains the details of the network token credentials.
315 316 317 |
# File 'lib/stripe/resources/payment_record.rb', line 315 def network_token @network_token end |
#network_transaction_id ⇒ Object (readonly)
This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.
317 318 319 |
# File 'lib/stripe/resources/payment_record.rb', line 317 def network_transaction_id @network_transaction_id end |
#three_d_secure ⇒ Object (readonly)
Populated if this transaction used 3D Secure authentication.
319 320 321 |
# File 'lib/stripe/resources/payment_record.rb', line 319 def three_d_secure @three_d_secure end |