Class: Stripe::PaymentRecord::PaymentMethodDetails::CardPresent
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentRecord::PaymentMethodDetails::CardPresent
- Defined in:
- lib/stripe/resources/payment_record.rb
Defined Under Namespace
Classes: Offline, Reauthorization, Receipt, Wallet
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_authorized ⇒ Object
readonly
The authorized amount.
-
#brand ⇒ Object
readonly
Card brand.
-
#brand_product ⇒ Object
readonly
The [product code](stripe.com/docs/card-product-codes) that identifies the specific program or product associated with a card.
-
#capture_before ⇒ Object
readonly
When using manual capture, a future timestamp after which the charge will be automatically refunded if uncaptured.
-
#cardholder_name ⇒ Object
readonly
The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country of the card.
-
#description ⇒ Object
readonly
A high-level description of the type of cards issued in this range.
-
#emv_auth_data ⇒ Object
readonly
Authorization response cryptogram.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card’s expiration year.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular card number.
-
#funding ⇒ Object
readonly
Card funding type.
-
#generated_card ⇒ Object
readonly
ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions.
-
#iin ⇒ Object
readonly
Issuer identification number of the card.
-
#incremental_authorization_supported ⇒ Object
readonly
Whether this [PaymentIntent](docs.stripe.com/api/payment_intents) is eligible for incremental authorizations.
-
#issuer ⇒ Object
readonly
The name of the card’s issuing bank.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#location ⇒ Object
readonly
ID of the [location](docs.stripe.com/api/terminal/locations) that this transaction’s reader is assigned to.
-
#network ⇒ Object
readonly
Identifies which network this charge was processed on.
-
#network_transaction_id ⇒ Object
readonly
This is used by the financial networks to identify a transaction.
-
#offline ⇒ Object
readonly
Details about payments collected offline.
-
#overcapture_supported ⇒ Object
readonly
Defines whether the authorized amount can be over-captured or not.
-
#preferred_locales ⇒ Object
readonly
The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card.
-
#read_method ⇒ Object
readonly
How card details were read in this transaction.
-
#reader ⇒ Object
readonly
ID of the [reader](docs.stripe.com/api/terminal/readers) this transaction was made on.
-
#reauthorization ⇒ Object
readonly
Whether the PaymentIntent can be reauthorized or not.
-
#reauthorize_before ⇒ Object
readonly
The time at which the associated PaymentIntent will transition to a terminal state if it is not reauthorized.
-
#receipt ⇒ Object
readonly
A collection of fields required to be displayed on receipts.
-
#wallet ⇒ Object
readonly
Attribute for field wallet.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_authorized ⇒ Object (readonly)
The authorized amount
760 761 762 |
# File 'lib/stripe/resources/payment_record.rb', line 760 def @amount_authorized end |
#brand ⇒ Object (readonly)
Card brand. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa` or `unknown`.
762 763 764 |
# File 'lib/stripe/resources/payment_record.rb', line 762 def brand @brand end |
#brand_product ⇒ Object (readonly)
The [product code](stripe.com/docs/card-product-codes) that identifies the specific program or product associated with a card.
764 765 766 |
# File 'lib/stripe/resources/payment_record.rb', line 764 def brand_product @brand_product end |
#capture_before ⇒ Object (readonly)
When using manual capture, a future timestamp after which the charge will be automatically refunded if uncaptured.
766 767 768 |
# File 'lib/stripe/resources/payment_record.rb', line 766 def capture_before @capture_before end |
#cardholder_name ⇒ Object (readonly)
The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format. May include alphanumeric characters, special characters and first/last name separator (‘/`). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.
768 769 770 |
# File 'lib/stripe/resources/payment_record.rb', line 768 def cardholder_name @cardholder_name end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.
770 771 772 |
# File 'lib/stripe/resources/payment_record.rb', line 770 def country @country end |
#description ⇒ Object (readonly)
A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)
772 773 774 |
# File 'lib/stripe/resources/payment_record.rb', line 772 def description @description end |
#emv_auth_data ⇒ Object (readonly)
Authorization response cryptogram.
774 775 776 |
# File 'lib/stripe/resources/payment_record.rb', line 774 def emv_auth_data @emv_auth_data end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card’s expiration month.
776 777 778 |
# File 'lib/stripe/resources/payment_record.rb', line 776 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card’s expiration year.
778 779 780 |
# File 'lib/stripe/resources/payment_record.rb', line 778 def exp_year @exp_year end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.
*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*
782 783 784 |
# File 'lib/stripe/resources/payment_record.rb', line 782 def fingerprint @fingerprint end |
#funding ⇒ Object (readonly)
Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.
784 785 786 |
# File 'lib/stripe/resources/payment_record.rb', line 784 def funding @funding end |
#generated_card ⇒ Object (readonly)
ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions. Only present if it was possible to generate a card PaymentMethod.
786 787 788 |
# File 'lib/stripe/resources/payment_record.rb', line 786 def generated_card @generated_card end |
#iin ⇒ Object (readonly)
Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)
788 789 790 |
# File 'lib/stripe/resources/payment_record.rb', line 788 def iin @iin end |
#incremental_authorization_supported ⇒ Object (readonly)
Whether this [PaymentIntent](docs.stripe.com/api/payment_intents) is eligible for incremental authorizations. Request support using [request_incremental_authorization_support](docs.stripe.com/api/payment_intents/create#create_payment_intent-payment_method_options-card_present-request_incremental_authorization_support).
790 791 792 |
# File 'lib/stripe/resources/payment_record.rb', line 790 def @incremental_authorization_supported end |
#issuer ⇒ Object (readonly)
The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)
792 793 794 |
# File 'lib/stripe/resources/payment_record.rb', line 792 def issuer @issuer end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
794 795 796 |
# File 'lib/stripe/resources/payment_record.rb', line 794 def last4 @last4 end |
#location ⇒ Object (readonly)
ID of the [location](docs.stripe.com/api/terminal/locations) that this transaction’s reader is assigned to.
796 797 798 |
# File 'lib/stripe/resources/payment_record.rb', line 796 def location @location end |
#network ⇒ Object (readonly)
Identifies which network this charge was processed on. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `interac`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.
798 799 800 |
# File 'lib/stripe/resources/payment_record.rb', line 798 def network @network end |
#network_transaction_id ⇒ Object (readonly)
This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.
800 801 802 |
# File 'lib/stripe/resources/payment_record.rb', line 800 def network_transaction_id @network_transaction_id end |
#offline ⇒ Object (readonly)
Details about payments collected offline.
802 803 804 |
# File 'lib/stripe/resources/payment_record.rb', line 802 def offline @offline end |
#overcapture_supported ⇒ Object (readonly)
Defines whether the authorized amount can be over-captured or not
804 805 806 |
# File 'lib/stripe/resources/payment_record.rb', line 804 def overcapture_supported @overcapture_supported end |
#preferred_locales ⇒ Object (readonly)
The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card. Referenced from EMV tag 5F2D, data encoded on the card’s chip.
806 807 808 |
# File 'lib/stripe/resources/payment_record.rb', line 806 def preferred_locales @preferred_locales end |
#read_method ⇒ Object (readonly)
How card details were read in this transaction.
808 809 810 |
# File 'lib/stripe/resources/payment_record.rb', line 808 def read_method @read_method end |
#reader ⇒ Object (readonly)
ID of the [reader](docs.stripe.com/api/terminal/readers) this transaction was made on.
810 811 812 |
# File 'lib/stripe/resources/payment_record.rb', line 810 def reader @reader end |
#reauthorization ⇒ Object (readonly)
Whether the PaymentIntent can be reauthorized or not.
812 813 814 |
# File 'lib/stripe/resources/payment_record.rb', line 812 def @reauthorization end |
#reauthorize_before ⇒ Object (readonly)
The time at which the associated PaymentIntent will transition to a terminal state if it is not reauthorized.
814 815 816 |
# File 'lib/stripe/resources/payment_record.rb', line 814 def @reauthorize_before end |
#receipt ⇒ Object (readonly)
A collection of fields required to be displayed on receipts. Only required for EMV transactions.
816 817 818 |
# File 'lib/stripe/resources/payment_record.rb', line 816 def receipt @receipt end |
#wallet ⇒ Object (readonly)
Attribute for field wallet
818 819 820 |
# File 'lib/stripe/resources/payment_record.rb', line 818 def wallet @wallet end |
Class Method Details
.field_remappings ⇒ Object
829 830 831 |
# File 'lib/stripe/resources/payment_record.rb', line 829 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
820 821 822 823 824 825 826 827 |
# File 'lib/stripe/resources/payment_record.rb', line 820 def self.inner_class_types @inner_class_types = { offline: Offline, reauthorization: Reauthorization, receipt: Receipt, wallet: Wallet, } end |