Class: Stripe::PaymentRecord::PaymentMethodDetails::CardPresent

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: Offline, Receipt, Wallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_authorizedObject (readonly)

The authorized amount



734
735
736
# File 'lib/stripe/resources/payment_record.rb', line 734

def amount_authorized
  @amount_authorized
end

#brandObject (readonly)

Card brand. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa` or `unknown`.



736
737
738
# File 'lib/stripe/resources/payment_record.rb', line 736

def brand
  @brand
end

#brand_productObject (readonly)

The [product code](stripe.com/docs/card-product-codes) that identifies the specific program or product associated with a card.



738
739
740
# File 'lib/stripe/resources/payment_record.rb', line 738

def brand_product
  @brand_product
end

#capture_beforeObject (readonly)

When using manual capture, a future timestamp after which the charge will be automatically refunded if uncaptured.



740
741
742
# File 'lib/stripe/resources/payment_record.rb', line 740

def capture_before
  @capture_before
end

#cardholder_nameObject (readonly)

The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format. May include alphanumeric characters, special characters and first/last name separator (‘/`). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.



742
743
744
# File 'lib/stripe/resources/payment_record.rb', line 742

def cardholder_name
  @cardholder_name
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



744
745
746
# File 'lib/stripe/resources/payment_record.rb', line 744

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



746
747
748
# File 'lib/stripe/resources/payment_record.rb', line 746

def description
  @description
end

#emv_auth_dataObject (readonly)

Authorization response cryptogram.



748
749
750
# File 'lib/stripe/resources/payment_record.rb', line 748

def emv_auth_data
  @emv_auth_data
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



750
751
752
# File 'lib/stripe/resources/payment_record.rb', line 750

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



752
753
754
# File 'lib/stripe/resources/payment_record.rb', line 752

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*



756
757
758
# File 'lib/stripe/resources/payment_record.rb', line 756

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



758
759
760
# File 'lib/stripe/resources/payment_record.rb', line 758

def funding
  @funding
end

#generated_cardObject (readonly)

ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions. Only present if it was possible to generate a card PaymentMethod.



760
761
762
# File 'lib/stripe/resources/payment_record.rb', line 760

def generated_card
  @generated_card
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



762
763
764
# File 'lib/stripe/resources/payment_record.rb', line 762

def iin
  @iin
end

#incremental_authorization_supportedObject (readonly)

Whether this [PaymentIntent](docs.stripe.com/api/payment_intents) is eligible for incremental authorizations. Request support using [request_incremental_authorization_support](docs.stripe.com/api/payment_intents/create#create_payment_intent-payment_method_options-card_present-request_incremental_authorization_support).



764
765
766
# File 'lib/stripe/resources/payment_record.rb', line 764

def incremental_authorization_supported
  @incremental_authorization_supported
end

#issuerObject (readonly)

The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)



766
767
768
# File 'lib/stripe/resources/payment_record.rb', line 766

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



768
769
770
# File 'lib/stripe/resources/payment_record.rb', line 768

def last4
  @last4
end

#locationObject (readonly)

ID of the [location](docs.stripe.com/api/terminal/locations) that this transaction’s reader is assigned to.



770
771
772
# File 'lib/stripe/resources/payment_record.rb', line 770

def location
  @location
end

#networkObject (readonly)

Identifies which network this charge was processed on. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `interac`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.



772
773
774
# File 'lib/stripe/resources/payment_record.rb', line 772

def network
  @network
end

#network_transaction_idObject (readonly)

This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.



774
775
776
# File 'lib/stripe/resources/payment_record.rb', line 774

def network_transaction_id
  @network_transaction_id
end

#offlineObject (readonly)

Details about payments collected offline.



776
777
778
# File 'lib/stripe/resources/payment_record.rb', line 776

def offline
  @offline
end

#overcapture_supportedObject (readonly)

Defines whether the authorized amount can be over-captured or not



778
779
780
# File 'lib/stripe/resources/payment_record.rb', line 778

def overcapture_supported
  @overcapture_supported
end

#preferred_localesObject (readonly)

The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card. Referenced from EMV tag 5F2D, data encoded on the card’s chip.



780
781
782
# File 'lib/stripe/resources/payment_record.rb', line 780

def preferred_locales
  @preferred_locales
end

#read_methodObject (readonly)

How card details were read in this transaction.



782
783
784
# File 'lib/stripe/resources/payment_record.rb', line 782

def read_method
  @read_method
end

#readerObject (readonly)

ID of the [reader](docs.stripe.com/api/terminal/readers) this transaction was made on.



784
785
786
# File 'lib/stripe/resources/payment_record.rb', line 784

def reader
  @reader
end

#receiptObject (readonly)

A collection of fields required to be displayed on receipts. Only required for EMV transactions.



786
787
788
# File 'lib/stripe/resources/payment_record.rb', line 786

def receipt
  @receipt
end

#walletObject (readonly)

Attribute for field wallet



788
789
790
# File 'lib/stripe/resources/payment_record.rb', line 788

def wallet
  @wallet
end

Class Method Details

.field_remappingsObject



794
795
796
# File 'lib/stripe/resources/payment_record.rb', line 794

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



790
791
792
# File 'lib/stripe/resources/payment_record.rb', line 790

def self.inner_class_types
  @inner_class_types = { offline: Offline, receipt: Receipt, wallet: Wallet }
end