Class: Stripe::PaymentRecord::PaymentMethodDetails::IdBankTransfer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentRecord::PaymentMethodDetails::IdBankTransfer
- Defined in:
- lib/stripe/resources/payment_record.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_number ⇒ Object
readonly
Account number of the bank account to transfer funds to.
-
#bank ⇒ Object
readonly
Bank where the account is located.
-
#bank_code ⇒ Object
readonly
Local bank code of the bank.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#display_name ⇒ Object
readonly
Merchant name and billing details name, for the customer to check for the correct merchant when performing the bank transfer.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_number ⇒ Object (readonly)
Account number of the bank account to transfer funds to.
997 998 999 |
# File 'lib/stripe/resources/payment_record.rb', line 997 def account_number @account_number end |
#bank ⇒ Object (readonly)
Bank where the account is located.
999 1000 1001 |
# File 'lib/stripe/resources/payment_record.rb', line 999 def bank @bank end |
#bank_code ⇒ Object (readonly)
Local bank code of the bank.
1001 1002 1003 |
# File 'lib/stripe/resources/payment_record.rb', line 1001 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
1003 1004 1005 |
# File 'lib/stripe/resources/payment_record.rb', line 1003 def bank_name @bank_name end |
#display_name ⇒ Object (readonly)
Merchant name and billing details name, for the customer to check for the correct merchant when performing the bank transfer.
1005 1006 1007 |
# File 'lib/stripe/resources/payment_record.rb', line 1005 def display_name @display_name end |
Class Method Details
.field_remappings ⇒ Object
1011 1012 1013 |
# File 'lib/stripe/resources/payment_record.rb', line 1011 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1007 1008 1009 |
# File 'lib/stripe/resources/payment_record.rb', line 1007 def self.inner_class_types @inner_class_types = {} end |