Class: Stripe::PaymentRecord::PaymentMethodDetails::IdBankTransfer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_numberObject (readonly)

Account number of the bank account to transfer funds to.



426
427
428
# File 'lib/stripe/resources/payment_record.rb', line 426

def 
  @account_number
end

#bankObject (readonly)

Bank where the account is located.



428
429
430
# File 'lib/stripe/resources/payment_record.rb', line 428

def bank
  @bank
end

#bank_codeObject (readonly)

Local bank code of the bank.



430
431
432
# File 'lib/stripe/resources/payment_record.rb', line 430

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



432
433
434
# File 'lib/stripe/resources/payment_record.rb', line 432

def bank_name
  @bank_name
end

#display_nameObject (readonly)

Merchant name and billing details name, for the customer to check for the correct merchant when performing the bank transfer.



434
435
436
# File 'lib/stripe/resources/payment_record.rb', line 434

def display_name
  @display_name
end