Class: Stripe::PaymentRecord::PaymentMethodDetails::InteracPresent::Receipt

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_typeObject (readonly)

The type of account being debited or credited



1007
1008
1009
# File 'lib/stripe/resources/payment_record.rb', line 1007

def 
  @account_type
end

#application_cryptogramObject (readonly)

The Application Cryptogram, a unique value generated by the card to authenticate the transaction with issuers.



1009
1010
1011
# File 'lib/stripe/resources/payment_record.rb', line 1009

def application_cryptogram
  @application_cryptogram
end

#application_preferred_nameObject (readonly)

The Application Identifier (AID) on the card used to determine which networks are eligible to process the transaction. Referenced from EMV tag 9F12, data encoded on the card’s chip.



1011
1012
1013
# File 'lib/stripe/resources/payment_record.rb', line 1011

def application_preferred_name
  @application_preferred_name
end

#authorization_codeObject (readonly)

Identifier for this transaction.



1013
1014
1015
# File 'lib/stripe/resources/payment_record.rb', line 1013

def authorization_code
  @authorization_code
end

#authorization_response_codeObject (readonly)

EMV tag 8A. A code returned by the card issuer.



1015
1016
1017
# File 'lib/stripe/resources/payment_record.rb', line 1015

def authorization_response_code
  @authorization_response_code
end

#cardholder_verification_methodObject (readonly)

Describes the method used by the cardholder to verify ownership of the card. One of the following: ‘approval`, `failure`, `none`, `offline_pin`, `offline_pin_and_signature`, `online_pin`, or `signature`.



1017
1018
1019
# File 'lib/stripe/resources/payment_record.rb', line 1017

def cardholder_verification_method
  @cardholder_verification_method
end

#dedicated_file_nameObject (readonly)

Similar to the application_preferred_name, identifying the applications (AIDs) available on the card. Referenced from EMV tag 84.



1019
1020
1021
# File 'lib/stripe/resources/payment_record.rb', line 1019

def dedicated_file_name
  @dedicated_file_name
end

#terminal_verification_resultsObject (readonly)

A 5-byte string that records the checks and validations that occur between the card and the terminal. These checks determine how the terminal processes the transaction and what risk tolerance is acceptable. Referenced from EMV Tag 95.



1021
1022
1023
# File 'lib/stripe/resources/payment_record.rb', line 1021

def terminal_verification_results
  @terminal_verification_results
end

#transaction_status_informationObject (readonly)

An indication of which steps were completed during the card read process. Referenced from EMV Tag 9B.



1023
1024
1025
# File 'lib/stripe/resources/payment_record.rb', line 1023

def transaction_status_information
  @transaction_status_information
end

Class Method Details

.field_remappingsObject



1029
1030
1031
# File 'lib/stripe/resources/payment_record.rb', line 1029

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1025
1026
1027
# File 'lib/stripe/resources/payment_record.rb', line 1025

def self.inner_class_types
  @inner_class_types = {}
end