Class: Stripe::PaymentRecord::PaymentMethodDetails::Klarna
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentRecord::PaymentMethodDetails::Klarna
- Defined in:
- lib/stripe/resources/payment_record.rb
Defined Under Namespace
Classes: PayerDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#payer_details ⇒ Object
readonly
The payer details for this transaction.
-
#payment_method_category ⇒ Object
readonly
The Klarna payment method used for this transaction.
-
#preferred_locale ⇒ Object
readonly
Preferred language of the Klarna authorization page that the customer is redirected to.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#payer_details ⇒ Object (readonly)
The payer details for this transaction.
544 545 546 |
# File 'lib/stripe/resources/payment_record.rb', line 544 def payer_details @payer_details end |
#payment_method_category ⇒ Object (readonly)
The Klarna payment method used for this transaction. Can be one of ‘pay_later`, `pay_now`, `pay_with_financing`, or `pay_in_installments`
547 548 549 |
# File 'lib/stripe/resources/payment_record.rb', line 547 def payment_method_category @payment_method_category end |
#preferred_locale ⇒ Object (readonly)
Preferred language of the Klarna authorization page that the customer is redirected to. Can be one of ‘de-AT`, `en-AT`, `nl-BE`, `fr-BE`, `en-BE`, `de-DE`, `en-DE`, `da-DK`, `en-DK`, `es-ES`, `en-ES`, `fi-FI`, `sv-FI`, `en-FI`, `en-GB`, `en-IE`, `it-IT`, `en-IT`, `nl-NL`, `en-NL`, `nb-NO`, `en-NO`, `sv-SE`, `en-SE`, `en-US`, `es-US`, `fr-FR`, `en-FR`, `cs-CZ`, `en-CZ`, `ro-RO`, `en-RO`, `el-GR`, `en-GR`, `en-AU`, `en-NZ`, `en-CA`, `fr-CA`, `pl-PL`, `en-PL`, `pt-PT`, `en-PT`, `de-CH`, `fr-CH`, `it-CH`, or `en-CH`
550 551 552 |
# File 'lib/stripe/resources/payment_record.rb', line 550 def preferred_locale @preferred_locale end |