Class: Stripe::PaymentRecord::PaymentMethodDetails::Konbini
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentRecord::PaymentMethodDetails::Konbini
- Defined in:
- lib/stripe/resources/payment_record.rb
Defined Under Namespace
Classes: Store
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#store ⇒ Object
readonly
If the payment succeeded, this contains the details of the convenience store where the payment was completed.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#store ⇒ Object (readonly)
If the payment succeeded, this contains the details of the convenience store where the payment was completed.
1072 1073 1074 |
# File 'lib/stripe/resources/payment_record.rb', line 1072 def store @store end |
Class Method Details
.field_remappings ⇒ Object
1078 1079 1080 |
# File 'lib/stripe/resources/payment_record.rb', line 1078 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1074 1075 1076 |
# File 'lib/stripe/resources/payment_record.rb', line 1074 def self.inner_class_types @inner_class_types = { store: Store } end |