Class: Stripe::PaymentRecord::PaymentMethodDetails::NzBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_nameObject (readonly)

The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1233
1234
1235
# File 'lib/stripe/resources/payment_record.rb', line 1233

def 
  @account_holder_name
end

#bank_codeObject (readonly)

The numeric code for the bank account’s bank.



1235
1236
1237
# File 'lib/stripe/resources/payment_record.rb', line 1235

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

The name of the bank.



1237
1238
1239
# File 'lib/stripe/resources/payment_record.rb', line 1237

def bank_name
  @bank_name
end

#branch_codeObject (readonly)

The numeric code for the bank account’s bank branch.



1239
1240
1241
# File 'lib/stripe/resources/payment_record.rb', line 1239

def branch_code
  @branch_code
end

#expected_debit_dateObject (readonly)

Estimated date to debit the customer’s bank account. A date string in YYYY-MM-DD format.



1241
1242
1243
# File 'lib/stripe/resources/payment_record.rb', line 1241

def expected_debit_date
  @expected_debit_date
end

#last4Object (readonly)

Last four digits of the bank account number.



1243
1244
1245
# File 'lib/stripe/resources/payment_record.rb', line 1243

def last4
  @last4
end

#suffixObject (readonly)

The suffix of the bank account number.



1245
1246
1247
# File 'lib/stripe/resources/payment_record.rb', line 1245

def suffix
  @suffix
end

Class Method Details

.field_remappingsObject



1251
1252
1253
# File 'lib/stripe/resources/payment_record.rb', line 1251

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1247
1248
1249
# File 'lib/stripe/resources/payment_record.rb', line 1247

def self.inner_class_types
  @inner_class_types = {}
end