Class: Stripe::PaymentRecord::PaymentMethodDetails::NzBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_nameObject (readonly)

The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1189
1190
1191
# File 'lib/stripe/resources/payment_record.rb', line 1189

def 
  @account_holder_name
end

#bank_codeObject (readonly)

The numeric code for the bank account’s bank.



1191
1192
1193
# File 'lib/stripe/resources/payment_record.rb', line 1191

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

The name of the bank.



1193
1194
1195
# File 'lib/stripe/resources/payment_record.rb', line 1193

def bank_name
  @bank_name
end

#branch_codeObject (readonly)

The numeric code for the bank account’s bank branch.



1195
1196
1197
# File 'lib/stripe/resources/payment_record.rb', line 1195

def branch_code
  @branch_code
end

#last4Object (readonly)

Last four digits of the bank account number.



1197
1198
1199
# File 'lib/stripe/resources/payment_record.rb', line 1197

def last4
  @last4
end

#suffixObject (readonly)

The suffix of the bank account number.



1199
1200
1201
# File 'lib/stripe/resources/payment_record.rb', line 1199

def suffix
  @suffix
end

Class Method Details

.field_remappingsObject



1205
1206
1207
# File 'lib/stripe/resources/payment_record.rb', line 1205

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1201
1202
1203
# File 'lib/stripe/resources/payment_record.rb', line 1201

def self.inner_class_types
  @inner_class_types = {}
end