Class: Stripe::PaymentRecord::PaymentMethodDetails::Paypal

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: SellerProtection, Shipping, VerifiedAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#countryObject (readonly)

Two-letter ISO code representing the buyer’s country. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



734
735
736
# File 'lib/stripe/resources/payment_record.rb', line 734

def country
  @country
end

#payer_emailObject (readonly)

Owner’s email. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



737
738
739
# File 'lib/stripe/resources/payment_record.rb', line 737

def payer_email
  @payer_email
end

#payer_idObject (readonly)

PayPal account PayerID. This identifier uniquely identifies the PayPal customer.



739
740
741
# File 'lib/stripe/resources/payment_record.rb', line 739

def payer_id
  @payer_id
end

#payer_nameObject (readonly)

Owner’s full name. Values provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



742
743
744
# File 'lib/stripe/resources/payment_record.rb', line 742

def payer_name
  @payer_name
end

#seller_protectionObject (readonly)

The level of protection offered as defined by PayPal Seller Protection for Merchants, for this transaction.



744
745
746
# File 'lib/stripe/resources/payment_record.rb', line 744

def seller_protection
  @seller_protection
end

#shippingObject (readonly)

The shipping address for the customer, as supplied by the merchant at the point of payment execution. This shipping address will not be updated if the merchant updates the shipping address on the PaymentIntent after the PaymentIntent was successfully confirmed.



748
749
750
# File 'lib/stripe/resources/payment_record.rb', line 748

def shipping
  @shipping
end

#transaction_idObject (readonly)

A unique ID generated by PayPal for this transaction.



750
751
752
# File 'lib/stripe/resources/payment_record.rb', line 750

def transaction_id
  @transaction_id
end

#verified_addressObject (readonly)

The shipping address for the customer, as supplied by the merchant at the point of payment execution. This shipping address will not be updated if the merchant updates the shipping address on the PaymentIntent after the PaymentIntent was successfully confirmed.



754
755
756
# File 'lib/stripe/resources/payment_record.rb', line 754

def verified_address
  @verified_address
end

#verified_emailObject (readonly)

Owner’s verified email. Values are verified or provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



757
758
759
# File 'lib/stripe/resources/payment_record.rb', line 757

def verified_email
  @verified_email
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



760
761
762
# File 'lib/stripe/resources/payment_record.rb', line 760

def verified_name
  @verified_name
end