Class: Stripe::PaymentRecord::PaymentMethodDetails::Paypal

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: SellerProtection, Shipping, VerifiedAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#countryObject (readonly)

Two-letter ISO code representing the buyer’s country. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1298
1299
1300
# File 'lib/stripe/resources/payment_record.rb', line 1298

def country
  @country
end

#payer_emailObject (readonly)

Owner’s email. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1301
1302
1303
# File 'lib/stripe/resources/payment_record.rb', line 1301

def payer_email
  @payer_email
end

#payer_idObject (readonly)

PayPal account PayerID. This identifier uniquely identifies the PayPal customer.



1303
1304
1305
# File 'lib/stripe/resources/payment_record.rb', line 1303

def payer_id
  @payer_id
end

#payer_nameObject (readonly)

Owner’s full name. Values provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1306
1307
1308
# File 'lib/stripe/resources/payment_record.rb', line 1306

def payer_name
  @payer_name
end

#seller_protectionObject (readonly)

The level of protection offered as defined by PayPal Seller Protection for Merchants, for this transaction.



1308
1309
1310
# File 'lib/stripe/resources/payment_record.rb', line 1308

def seller_protection
  @seller_protection
end

#shippingObject (readonly)

The shipping address for the customer, as supplied by the merchant at the point of payment execution. This shipping address will not be updated if the merchant updates the shipping address on the PaymentIntent after the PaymentIntent was successfully confirmed.



1312
1313
1314
# File 'lib/stripe/resources/payment_record.rb', line 1312

def shipping
  @shipping
end

#transaction_idObject (readonly)

A unique ID generated by PayPal for this transaction.



1314
1315
1316
# File 'lib/stripe/resources/payment_record.rb', line 1314

def transaction_id
  @transaction_id
end

#verified_addressObject (readonly)

The shipping address for the customer, as supplied by the merchant at the point of payment execution. This shipping address will not be updated if the merchant updates the shipping address on the PaymentIntent after the PaymentIntent was successfully confirmed.



1318
1319
1320
# File 'lib/stripe/resources/payment_record.rb', line 1318

def verified_address
  @verified_address
end

#verified_emailObject (readonly)

Owner’s verified email. Values are verified or provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1321
1322
1323
# File 'lib/stripe/resources/payment_record.rb', line 1321

def verified_email
  @verified_email
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1324
1325
1326
# File 'lib/stripe/resources/payment_record.rb', line 1324

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



1334
1335
1336
# File 'lib/stripe/resources/payment_record.rb', line 1334

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1326
1327
1328
1329
1330
1331
1332
# File 'lib/stripe/resources/payment_record.rb', line 1326

def self.inner_class_types
  @inner_class_types = {
    seller_protection: SellerProtection,
    shipping: Shipping,
    verified_address: VerifiedAddress,
  }
end