Class: Stripe::PaymentRecord::PaymentMethodDetails::RevolutPay::Funding::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

Card brand. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa` or `unknown`.



1527
1528
1529
# File 'lib/stripe/resources/payment_record.rb', line 1527

def brand
  @brand
end

#brand_productObject (readonly)

The [product code](stripe.com/docs/card-product-codes) that identifies the specific program or product associated with a card. (For internal use only and not typically available in standard API requests.)



1529
1530
1531
# File 'lib/stripe/resources/payment_record.rb', line 1529

def brand_product
  @brand_product
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



1531
1532
1533
# File 'lib/stripe/resources/payment_record.rb', line 1531

def country
  @country
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



1533
1534
1535
# File 'lib/stripe/resources/payment_record.rb', line 1533

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



1535
1536
1537
# File 'lib/stripe/resources/payment_record.rb', line 1535

def exp_year
  @exp_year
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



1537
1538
1539
# File 'lib/stripe/resources/payment_record.rb', line 1537

def funding
  @funding
end

#last4Object (readonly)

The last four digits of the card.



1539
1540
1541
# File 'lib/stripe/resources/payment_record.rb', line 1539

def last4
  @last4
end

Class Method Details

.field_remappingsObject



1545
1546
1547
# File 'lib/stripe/resources/payment_record.rb', line 1545

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1541
1542
1543
# File 'lib/stripe/resources/payment_record.rb', line 1541

def self.inner_class_types
  @inner_class_types = {}
end