Class: Stripe::PaymentRecord::PaymentMethodDetails::SepaDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1656
1657
1658
# File 'lib/stripe/resources/payment_record.rb', line 1656

def bank_code
  @bank_code
end

#branch_codeObject (readonly)

Branch code of bank associated with the bank account.



1658
1659
1660
# File 'lib/stripe/resources/payment_record.rb', line 1658

def branch_code
  @branch_code
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1660
1661
1662
# File 'lib/stripe/resources/payment_record.rb', line 1660

def country
  @country
end

#expected_debit_dateObject (readonly)

Estimated date to debit the customer’s bank account. A date string in YYYY-MM-DD format.



1662
1663
1664
# File 'lib/stripe/resources/payment_record.rb', line 1662

def expected_debit_date
  @expected_debit_date
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1664
1665
1666
# File 'lib/stripe/resources/payment_record.rb', line 1664

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four characters of the IBAN.



1666
1667
1668
# File 'lib/stripe/resources/payment_record.rb', line 1666

def last4
  @last4
end

#mandateObject (readonly)

Find the ID of the mandate used for this payment under the [payment_method_details.sepa_debit.mandate](docs.stripe.com/api/charges/object#charge_object-payment_method_details-sepa_debit-mandate) property on the Charge. Use this mandate ID to [retrieve the Mandate](docs.stripe.com/api/mandates/retrieve).



1668
1669
1670
# File 'lib/stripe/resources/payment_record.rb', line 1668

def mandate
  @mandate
end

Class Method Details

.field_remappingsObject



1674
1675
1676
# File 'lib/stripe/resources/payment_record.rb', line 1674

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1670
1671
1672
# File 'lib/stripe/resources/payment_record.rb', line 1670

def self.inner_class_types
  @inner_class_types = {}
end