Class: Stripe::PaymentRecord::PaymentMethodDetails::SepaDebit
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentRecord::PaymentMethodDetails::SepaDebit
- Defined in:
- lib/stripe/resources/payment_record.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_code ⇒ Object
readonly
Bank code of bank associated with the bank account.
-
#branch_code ⇒ Object
readonly
Branch code of bank associated with the bank account.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country the bank account is located in.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular bank account.
-
#last4 ⇒ Object
readonly
Last four characters of the IBAN.
-
#mandate ⇒ Object
readonly
Find the ID of the mandate used for this payment under the [payment_method_details.sepa_debit.mandate](stripe.com/docs/api/charges/object#charge_object-payment_method_details-sepa_debit-mandate) property on the Charge.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_code ⇒ Object (readonly)
Bank code of bank associated with the bank account.
776 777 778 |
# File 'lib/stripe/resources/payment_record.rb', line 776 def bank_code @bank_code end |
#branch_code ⇒ Object (readonly)
Branch code of bank associated with the bank account.
778 779 780 |
# File 'lib/stripe/resources/payment_record.rb', line 778 def branch_code @branch_code end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country the bank account is located in.
780 781 782 |
# File 'lib/stripe/resources/payment_record.rb', line 780 def country @country end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
782 783 784 |
# File 'lib/stripe/resources/payment_record.rb', line 782 def fingerprint @fingerprint end |
#last4 ⇒ Object (readonly)
Last four characters of the IBAN.
784 785 786 |
# File 'lib/stripe/resources/payment_record.rb', line 784 def last4 @last4 end |
#mandate ⇒ Object (readonly)
Find the ID of the mandate used for this payment under the [payment_method_details.sepa_debit.mandate](stripe.com/docs/api/charges/object#charge_object-payment_method_details-sepa_debit-mandate) property on the Charge. Use this mandate ID to [retrieve the Mandate](stripe.com/docs/api/mandates/retrieve).
786 787 788 |
# File 'lib/stripe/resources/payment_record.rb', line 786 def mandate @mandate end |