Class: Stripe::PaymentRecord::PaymentMethodDetails::Sofort

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1691
1692
1693
# File 'lib/stripe/resources/payment_record.rb', line 1691

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1693
1694
1695
# File 'lib/stripe/resources/payment_record.rb', line 1693

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



1695
1696
1697
# File 'lib/stripe/resources/payment_record.rb', line 1695

def bic
  @bic
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1697
1698
1699
# File 'lib/stripe/resources/payment_record.rb', line 1697

def country
  @country
end

#generated_sepa_debitObject (readonly)

The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1699
1700
1701
# File 'lib/stripe/resources/payment_record.rb', line 1699

def generated_sepa_debit
  @generated_sepa_debit
end

#generated_sepa_debit_mandateObject (readonly)

The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1701
1702
1703
# File 'lib/stripe/resources/payment_record.rb', line 1701

def generated_sepa_debit_mandate
  @generated_sepa_debit_mandate
end

#iban_last4Object (readonly)

Last four characters of the IBAN.



1703
1704
1705
# File 'lib/stripe/resources/payment_record.rb', line 1703

def iban_last4
  @iban_last4
end

#preferred_languageObject (readonly)

Preferred language of the SOFORT authorization page that the customer is redirected to. Can be one of ‘de`, `en`, `es`, `fr`, `it`, `nl`, or `pl`



1705
1706
1707
# File 'lib/stripe/resources/payment_record.rb', line 1705

def preferred_language
  @preferred_language
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by SOFORT directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1707
1708
1709
# File 'lib/stripe/resources/payment_record.rb', line 1707

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



1713
1714
1715
# File 'lib/stripe/resources/payment_record.rb', line 1713

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1709
1710
1711
# File 'lib/stripe/resources/payment_record.rb', line 1709

def self.inner_class_types
  @inner_class_types = {}
end