Class: Stripe::PaymentRecord::PaymentMethodDetails::Sofort

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1658
1659
1660
# File 'lib/stripe/resources/payment_record.rb', line 1658

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1660
1661
1662
# File 'lib/stripe/resources/payment_record.rb', line 1660

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



1662
1663
1664
# File 'lib/stripe/resources/payment_record.rb', line 1662

def bic
  @bic
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1664
1665
1666
# File 'lib/stripe/resources/payment_record.rb', line 1664

def country
  @country
end

#generated_sepa_debitObject (readonly)

The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1666
1667
1668
# File 'lib/stripe/resources/payment_record.rb', line 1666

def generated_sepa_debit
  @generated_sepa_debit
end

#generated_sepa_debit_mandateObject (readonly)

The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1668
1669
1670
# File 'lib/stripe/resources/payment_record.rb', line 1668

def generated_sepa_debit_mandate
  @generated_sepa_debit_mandate
end

#iban_last4Object (readonly)

Last four characters of the IBAN.



1670
1671
1672
# File 'lib/stripe/resources/payment_record.rb', line 1670

def iban_last4
  @iban_last4
end

#preferred_languageObject (readonly)

Preferred language of the SOFORT authorization page that the customer is redirected to. Can be one of ‘de`, `en`, `es`, `fr`, `it`, `nl`, or `pl`



1673
1674
1675
# File 'lib/stripe/resources/payment_record.rb', line 1673

def preferred_language
  @preferred_language
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by SOFORT directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1676
1677
1678
# File 'lib/stripe/resources/payment_record.rb', line 1676

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



1682
1683
1684
# File 'lib/stripe/resources/payment_record.rb', line 1682

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1678
1679
1680
# File 'lib/stripe/resources/payment_record.rb', line 1678

def self.inner_class_types
  @inner_class_types = {}
end