Class: Stripe::PaymentRecord::PaymentMethodDetails::Sofort

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1597
1598
1599
# File 'lib/stripe/resources/payment_record.rb', line 1597

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1599
1600
1601
# File 'lib/stripe/resources/payment_record.rb', line 1599

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



1601
1602
1603
# File 'lib/stripe/resources/payment_record.rb', line 1601

def bic
  @bic
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1603
1604
1605
# File 'lib/stripe/resources/payment_record.rb', line 1603

def country
  @country
end

#generated_sepa_debitObject (readonly)

The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1605
1606
1607
# File 'lib/stripe/resources/payment_record.rb', line 1605

def generated_sepa_debit
  @generated_sepa_debit
end

#generated_sepa_debit_mandateObject (readonly)

The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1607
1608
1609
# File 'lib/stripe/resources/payment_record.rb', line 1607

def generated_sepa_debit_mandate
  @generated_sepa_debit_mandate
end

#iban_last4Object (readonly)

Last four characters of the IBAN.



1609
1610
1611
# File 'lib/stripe/resources/payment_record.rb', line 1609

def iban_last4
  @iban_last4
end

#preferred_languageObject (readonly)

Preferred language of the SOFORT authorization page that the customer is redirected to. Can be one of ‘de`, `en`, `es`, `fr`, `it`, `nl`, or `pl`



1612
1613
1614
# File 'lib/stripe/resources/payment_record.rb', line 1612

def preferred_language
  @preferred_language
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by SOFORT directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1615
1616
1617
# File 'lib/stripe/resources/payment_record.rb', line 1615

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



1621
1622
1623
# File 'lib/stripe/resources/payment_record.rb', line 1621

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1617
1618
1619
# File 'lib/stripe/resources/payment_record.rb', line 1617

def self.inner_class_types
  @inner_class_types = {}
end