Class: Stripe::PaymentRecord::PaymentMethodDetails::Sofort

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1539
1540
1541
# File 'lib/stripe/resources/payment_record.rb', line 1539

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1541
1542
1543
# File 'lib/stripe/resources/payment_record.rb', line 1541

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



1543
1544
1545
# File 'lib/stripe/resources/payment_record.rb', line 1543

def bic
  @bic
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1545
1546
1547
# File 'lib/stripe/resources/payment_record.rb', line 1545

def country
  @country
end

#generated_sepa_debitObject (readonly)

The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1547
1548
1549
# File 'lib/stripe/resources/payment_record.rb', line 1547

def generated_sepa_debit
  @generated_sepa_debit
end

#generated_sepa_debit_mandateObject (readonly)

The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1549
1550
1551
# File 'lib/stripe/resources/payment_record.rb', line 1549

def generated_sepa_debit_mandate
  @generated_sepa_debit_mandate
end

#iban_last4Object (readonly)

Last four characters of the IBAN.



1551
1552
1553
# File 'lib/stripe/resources/payment_record.rb', line 1551

def iban_last4
  @iban_last4
end

#preferred_languageObject (readonly)

Preferred language of the SOFORT authorization page that the customer is redirected to. Can be one of ‘de`, `en`, `es`, `fr`, `it`, `nl`, or `pl`



1554
1555
1556
# File 'lib/stripe/resources/payment_record.rb', line 1554

def preferred_language
  @preferred_language
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by SOFORT directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1557
1558
1559
# File 'lib/stripe/resources/payment_record.rb', line 1557

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



1563
1564
1565
# File 'lib/stripe/resources/payment_record.rb', line 1563

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1559
1560
1561
# File 'lib/stripe/resources/payment_record.rb', line 1559

def self.inner_class_types
  @inner_class_types = {}
end