Class: Stripe::PaymentRecord::PaymentMethodDetails::Sofort
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentRecord::PaymentMethodDetails::Sofort
- Defined in:
- lib/stripe/resources/payment_record.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_code ⇒ Object
readonly
Bank code of bank associated with the bank account.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#bic ⇒ Object
readonly
Bank Identifier Code of the bank associated with the bank account.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country the bank account is located in.
-
#generated_sepa_debit ⇒ Object
readonly
The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.
-
#generated_sepa_debit_mandate ⇒ Object
readonly
The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.
-
#iban_last4 ⇒ Object
readonly
Last four characters of the IBAN.
-
#preferred_language ⇒ Object
readonly
Preferred language of the SOFORT authorization page that the customer is redirected to.
-
#verified_name ⇒ Object
readonly
Owner’s verified full name.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_code ⇒ Object (readonly)
Bank code of bank associated with the bank account.
858 859 860 |
# File 'lib/stripe/resources/payment_record.rb', line 858 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
860 861 862 |
# File 'lib/stripe/resources/payment_record.rb', line 860 def bank_name @bank_name end |
#bic ⇒ Object (readonly)
Bank Identifier Code of the bank associated with the bank account.
862 863 864 |
# File 'lib/stripe/resources/payment_record.rb', line 862 def bic @bic end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country the bank account is located in.
864 865 866 |
# File 'lib/stripe/resources/payment_record.rb', line 864 def country @country end |
#generated_sepa_debit ⇒ Object (readonly)
The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.
866 867 868 |
# File 'lib/stripe/resources/payment_record.rb', line 866 def generated_sepa_debit @generated_sepa_debit end |
#generated_sepa_debit_mandate ⇒ Object (readonly)
The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.
868 869 870 |
# File 'lib/stripe/resources/payment_record.rb', line 868 def generated_sepa_debit_mandate @generated_sepa_debit_mandate end |
#iban_last4 ⇒ Object (readonly)
Last four characters of the IBAN.
870 871 872 |
# File 'lib/stripe/resources/payment_record.rb', line 870 def iban_last4 @iban_last4 end |
#preferred_language ⇒ Object (readonly)
Preferred language of the SOFORT authorization page that the customer is redirected to. Can be one of ‘de`, `en`, `es`, `fr`, `it`, `nl`, or `pl`
873 874 875 |
# File 'lib/stripe/resources/payment_record.rb', line 873 def preferred_language @preferred_language end |
#verified_name ⇒ Object (readonly)
Owner’s verified full name. Values are verified or provided by SOFORT directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
876 877 878 |
# File 'lib/stripe/resources/payment_record.rb', line 876 def verified_name @verified_name end |