Class: Stripe::PaymentRecord::ProcessorDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentRecord::ProcessorDetails
- Defined in:
- lib/stripe/resources/payment_record.rb
Defined Under Namespace
Classes: Custom, FiservValuelink, Givex, Svs
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#custom ⇒ Object
readonly
Custom processors represent payment processors not modeled directly in the Stripe API.
-
#fiserv_valuelink ⇒ Object
readonly
Represents the Fiserv ValueLink gift card processor.
-
#givex ⇒ Object
readonly
Represents the Givex gift card processor.
-
#svs ⇒ Object
readonly
Represents the SVS gift card processor.
-
#type ⇒ Object
readonly
The processor used for this payment attempt.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#custom ⇒ Object (readonly)
Custom processors represent payment processors not modeled directly in the Stripe API. This resource consists of details about the custom processor used for this payment attempt.
2277 2278 2279 |
# File 'lib/stripe/resources/payment_record.rb', line 2277 def custom @custom end |
#fiserv_valuelink ⇒ Object (readonly)
Represents the Fiserv ValueLink gift card processor.
2279 2280 2281 |
# File 'lib/stripe/resources/payment_record.rb', line 2279 def fiserv_valuelink @fiserv_valuelink end |
#givex ⇒ Object (readonly)
Represents the Givex gift card processor.
2281 2282 2283 |
# File 'lib/stripe/resources/payment_record.rb', line 2281 def givex @givex end |
#svs ⇒ Object (readonly)
Represents the SVS gift card processor.
2283 2284 2285 |
# File 'lib/stripe/resources/payment_record.rb', line 2283 def svs @svs end |
#type ⇒ Object (readonly)
The processor used for this payment attempt.
2285 2286 2287 |
# File 'lib/stripe/resources/payment_record.rb', line 2285 def type @type end |
Class Method Details
.field_remappings ⇒ Object
2296 2297 2298 |
# File 'lib/stripe/resources/payment_record.rb', line 2296 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/stripe/resources/payment_record.rb', line 2287 def self.inner_class_types @inner_class_types = { custom: Custom, fiserv_valuelink: FiservValuelink, givex: Givex, svs: Svs, } end |