Class: Stripe::PaymentRecord::ReportPaymentAttemptCanceledParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentAttemptCanceledParams
- Defined in:
- lib/stripe/resources/payment_record.rb
Instance Attribute Summary collapse
-
#canceled_at ⇒ Object
When the reported payment was canceled.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Attribute for param field metadata.
Instance Method Summary collapse
-
#initialize(canceled_at: nil, expand: nil, metadata: nil) ⇒ ReportPaymentAttemptCanceledParams
constructor
A new instance of ReportPaymentAttemptCanceledParams.
Methods inherited from RequestParams
Constructor Details
#initialize(canceled_at: nil, expand: nil, metadata: nil) ⇒ ReportPaymentAttemptCanceledParams
Returns a new instance of ReportPaymentAttemptCanceledParams.
1298 1299 1300 1301 1302 |
# File 'lib/stripe/resources/payment_record.rb', line 1298 def initialize(canceled_at: nil, expand: nil, metadata: nil) @canceled_at = canceled_at @expand = @metadata = end |
Instance Attribute Details
#canceled_at ⇒ Object
When the reported payment was canceled. Measured in seconds since the Unix epoch.
1292 1293 1294 |
# File 'lib/stripe/resources/payment_record.rb', line 1292 def canceled_at @canceled_at end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1294 1295 1296 |
# File 'lib/stripe/resources/payment_record.rb', line 1294 def @expand end |
#metadata ⇒ Object
Attribute for param field metadata
1296 1297 1298 |
# File 'lib/stripe/resources/payment_record.rb', line 1296 def @metadata end |