Class: Stripe::PaymentRecord::ReportPaymentAttemptCanceledParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentAttemptCanceledParams
- Defined in:
- lib/stripe/resources/payment_record.rb
Instance Attribute Summary collapse
-
#canceled_at ⇒ Object
When the reported payment was canceled.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Attribute for param field metadata.
Instance Method Summary collapse
-
#initialize(canceled_at: nil, expand: nil, metadata: nil) ⇒ ReportPaymentAttemptCanceledParams
constructor
A new instance of ReportPaymentAttemptCanceledParams.
Methods inherited from RequestParams
Constructor Details
#initialize(canceled_at: nil, expand: nil, metadata: nil) ⇒ ReportPaymentAttemptCanceledParams
Returns a new instance of ReportPaymentAttemptCanceledParams.
1233 1234 1235 1236 1237 |
# File 'lib/stripe/resources/payment_record.rb', line 1233 def initialize(canceled_at: nil, expand: nil, metadata: nil) @canceled_at = canceled_at @expand = @metadata = end |
Instance Attribute Details
#canceled_at ⇒ Object
When the reported payment was canceled. Measured in seconds since the Unix epoch.
1227 1228 1229 |
# File 'lib/stripe/resources/payment_record.rb', line 1227 def canceled_at @canceled_at end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1229 1230 1231 |
# File 'lib/stripe/resources/payment_record.rb', line 1229 def @expand end |
#metadata ⇒ Object
Attribute for param field metadata
1231 1232 1233 |
# File 'lib/stripe/resources/payment_record.rb', line 1231 def @metadata end |