Class: Stripe::PaymentRecord::ReportPaymentAttemptCanceledParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentAttemptCanceledParams
- Defined in:
- lib/stripe/resources/payment_record.rb
Instance Attribute Summary collapse
-
#canceled_at ⇒ Object
When the reported payment was canceled.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Attribute for param field metadata.
Instance Method Summary collapse
-
#initialize(canceled_at: nil, expand: nil, metadata: nil) ⇒ ReportPaymentAttemptCanceledParams
constructor
A new instance of ReportPaymentAttemptCanceledParams.
Methods inherited from RequestParams
Constructor Details
#initialize(canceled_at: nil, expand: nil, metadata: nil) ⇒ ReportPaymentAttemptCanceledParams
Returns a new instance of ReportPaymentAttemptCanceledParams.
1218 1219 1220 1221 1222 |
# File 'lib/stripe/resources/payment_record.rb', line 1218 def initialize(canceled_at: nil, expand: nil, metadata: nil) @canceled_at = canceled_at @expand = @metadata = end |
Instance Attribute Details
#canceled_at ⇒ Object
When the reported payment was canceled. Measured in seconds since the Unix epoch.
1212 1213 1214 |
# File 'lib/stripe/resources/payment_record.rb', line 1212 def canceled_at @canceled_at end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1214 1215 1216 |
# File 'lib/stripe/resources/payment_record.rb', line 1214 def @expand end |
#metadata ⇒ Object
Attribute for param field metadata
1216 1217 1218 |
# File 'lib/stripe/resources/payment_record.rb', line 1216 def @metadata end |