Class: Stripe::PaymentRecord::ReportPaymentAttemptCanceledParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentAttemptCanceledParams
- Defined in:
- lib/stripe/resources/payment_record.rb
Instance Attribute Summary collapse
-
#canceled_at ⇒ Object
When the reported payment was canceled.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Attribute for param field metadata.
Instance Method Summary collapse
-
#initialize(canceled_at: nil, expand: nil, metadata: nil) ⇒ ReportPaymentAttemptCanceledParams
constructor
A new instance of ReportPaymentAttemptCanceledParams.
Methods inherited from RequestParams
Constructor Details
#initialize(canceled_at: nil, expand: nil, metadata: nil) ⇒ ReportPaymentAttemptCanceledParams
Returns a new instance of ReportPaymentAttemptCanceledParams.
1210 1211 1212 1213 1214 |
# File 'lib/stripe/resources/payment_record.rb', line 1210 def initialize(canceled_at: nil, expand: nil, metadata: nil) @canceled_at = canceled_at @expand = @metadata = end |
Instance Attribute Details
#canceled_at ⇒ Object
When the reported payment was canceled. Measured in seconds since the Unix epoch.
1204 1205 1206 |
# File 'lib/stripe/resources/payment_record.rb', line 1204 def canceled_at @canceled_at end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1206 1207 1208 |
# File 'lib/stripe/resources/payment_record.rb', line 1206 def @expand end |
#metadata ⇒ Object
Attribute for param field metadata
1208 1209 1210 |
# File 'lib/stripe/resources/payment_record.rb', line 1208 def @metadata end |