Class: Stripe::PaymentRecord::ReportPaymentAttemptCanceledParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentAttemptCanceledParams
- Defined in:
- lib/stripe/resources/payment_record.rb
Instance Attribute Summary collapse
-
#canceled_at ⇒ Object
When the reported payment was canceled.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Attribute for param field metadata.
Instance Method Summary collapse
-
#initialize(canceled_at: nil, expand: nil, metadata: nil) ⇒ ReportPaymentAttemptCanceledParams
constructor
A new instance of ReportPaymentAttemptCanceledParams.
Methods inherited from RequestParams
Constructor Details
#initialize(canceled_at: nil, expand: nil, metadata: nil) ⇒ ReportPaymentAttemptCanceledParams
Returns a new instance of ReportPaymentAttemptCanceledParams.
373 374 375 376 377 |
# File 'lib/stripe/resources/payment_record.rb', line 373 def initialize(canceled_at: nil, expand: nil, metadata: nil) @canceled_at = canceled_at @expand = @metadata = end |
Instance Attribute Details
#canceled_at ⇒ Object
When the reported payment was canceled. Measured in seconds since the Unix epoch.
365 366 367 |
# File 'lib/stripe/resources/payment_record.rb', line 365 def canceled_at @canceled_at end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
368 369 370 |
# File 'lib/stripe/resources/payment_record.rb', line 368 def @expand end |
#metadata ⇒ Object
Attribute for param field metadata
371 372 373 |
# File 'lib/stripe/resources/payment_record.rb', line 371 def @metadata end |