Class: Stripe::PaymentRecord::ReportPaymentAttemptFailedParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentAttemptFailedParams
- Defined in:
- lib/stripe/resources/payment_record.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failed_at ⇒ Object
When the reported payment failed.
-
#metadata ⇒ Object
Attribute for param field metadata.
Instance Method Summary collapse
-
#initialize(expand: nil, failed_at: nil, metadata: nil) ⇒ ReportPaymentAttemptFailedParams
constructor
A new instance of ReportPaymentAttemptFailedParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, failed_at: nil, metadata: nil) ⇒ ReportPaymentAttemptFailedParams
Returns a new instance of ReportPaymentAttemptFailedParams.
1233 1234 1235 1236 1237 |
# File 'lib/stripe/resources/payment_record.rb', line 1233 def initialize(expand: nil, failed_at: nil, metadata: nil) @expand = @failed_at = failed_at @metadata = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1227 1228 1229 |
# File 'lib/stripe/resources/payment_record.rb', line 1227 def @expand end |
#failed_at ⇒ Object
When the reported payment failed. Measured in seconds since the Unix epoch.
1229 1230 1231 |
# File 'lib/stripe/resources/payment_record.rb', line 1229 def failed_at @failed_at end |
#metadata ⇒ Object
Attribute for param field metadata
1231 1232 1233 |
# File 'lib/stripe/resources/payment_record.rb', line 1231 def @metadata end |