Class: Stripe::PaymentRecord::ReportPaymentAttemptFailedParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentAttemptFailedParams
- Defined in:
- lib/stripe/resources/payment_record.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failed_at ⇒ Object
When the reported payment failed.
-
#metadata ⇒ Object
Attribute for param field metadata.
Instance Method Summary collapse
-
#initialize(expand: nil, failed_at: nil, metadata: nil) ⇒ ReportPaymentAttemptFailedParams
constructor
A new instance of ReportPaymentAttemptFailedParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, failed_at: nil, metadata: nil) ⇒ ReportPaymentAttemptFailedParams
Returns a new instance of ReportPaymentAttemptFailedParams.
390 391 392 393 394 |
# File 'lib/stripe/resources/payment_record.rb', line 390 def initialize(expand: nil, failed_at: nil, metadata: nil) @expand = @failed_at = failed_at @metadata = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
382 383 384 |
# File 'lib/stripe/resources/payment_record.rb', line 382 def @expand end |
#failed_at ⇒ Object
When the reported payment failed. Measured in seconds since the Unix epoch.
385 386 387 |
# File 'lib/stripe/resources/payment_record.rb', line 385 def failed_at @failed_at end |
#metadata ⇒ Object
Attribute for param field metadata
388 389 390 |
# File 'lib/stripe/resources/payment_record.rb', line 388 def @metadata end |