Class: Stripe::PaymentRecord::ReportPaymentAttemptGuaranteedParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentAttemptGuaranteedParams
- Defined in:
- lib/stripe/resources/payment_record.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#guaranteed_at ⇒ Object
When the reported payment was guaranteed.
-
#metadata ⇒ Object
Attribute for param field metadata.
Instance Method Summary collapse
-
#initialize(expand: nil, guaranteed_at: nil, metadata: nil) ⇒ ReportPaymentAttemptGuaranteedParams
constructor
A new instance of ReportPaymentAttemptGuaranteedParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, guaranteed_at: nil, metadata: nil) ⇒ ReportPaymentAttemptGuaranteedParams
Returns a new instance of ReportPaymentAttemptGuaranteedParams.
1328 1329 1330 1331 1332 |
# File 'lib/stripe/resources/payment_record.rb', line 1328 def initialize(expand: nil, guaranteed_at: nil, metadata: nil) @expand = @guaranteed_at = guaranteed_at @metadata = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1322 1323 1324 |
# File 'lib/stripe/resources/payment_record.rb', line 1322 def @expand end |
#guaranteed_at ⇒ Object
When the reported payment was guaranteed. Measured in seconds since the Unix epoch.
1324 1325 1326 |
# File 'lib/stripe/resources/payment_record.rb', line 1324 def guaranteed_at @guaranteed_at end |
#metadata ⇒ Object
Attribute for param field metadata
1326 1327 1328 |
# File 'lib/stripe/resources/payment_record.rb', line 1326 def @metadata end |