Class: Stripe::PaymentRecord::ReportPaymentAttemptGuaranteedParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentAttemptGuaranteedParams
- Defined in:
- lib/stripe/resources/payment_record.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#guaranteed_at ⇒ Object
When the reported payment was guaranteed.
-
#metadata ⇒ Object
Attribute for param field metadata.
Instance Method Summary collapse
-
#initialize(expand: nil, guaranteed_at: nil, metadata: nil) ⇒ ReportPaymentAttemptGuaranteedParams
constructor
A new instance of ReportPaymentAttemptGuaranteedParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, guaranteed_at: nil, metadata: nil) ⇒ ReportPaymentAttemptGuaranteedParams
Returns a new instance of ReportPaymentAttemptGuaranteedParams.
1261 1262 1263 1264 1265 |
# File 'lib/stripe/resources/payment_record.rb', line 1261 def initialize(expand: nil, guaranteed_at: nil, metadata: nil) @expand = @guaranteed_at = guaranteed_at @metadata = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1255 1256 1257 |
# File 'lib/stripe/resources/payment_record.rb', line 1255 def @expand end |
#guaranteed_at ⇒ Object
When the reported payment was guaranteed. Measured in seconds since the Unix epoch.
1257 1258 1259 |
# File 'lib/stripe/resources/payment_record.rb', line 1257 def guaranteed_at @guaranteed_at end |
#metadata ⇒ Object
Attribute for param field metadata
1259 1260 1261 |
# File 'lib/stripe/resources/payment_record.rb', line 1259 def @metadata end |