Class: Stripe::PaymentRecord::ReportPaymentAttemptGuaranteedParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentAttemptGuaranteedParams
- Defined in:
- lib/stripe/resources/payment_record.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#guaranteed_at ⇒ Object
When the reported payment was guaranteed.
-
#metadata ⇒ Object
Attribute for param field metadata.
Instance Method Summary collapse
-
#initialize(expand: nil, guaranteed_at: nil, metadata: nil) ⇒ ReportPaymentAttemptGuaranteedParams
constructor
A new instance of ReportPaymentAttemptGuaranteedParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, guaranteed_at: nil, metadata: nil) ⇒ ReportPaymentAttemptGuaranteedParams
Returns a new instance of ReportPaymentAttemptGuaranteedParams.
348 349 350 351 352 |
# File 'lib/stripe/resources/payment_record.rb', line 348 def initialize(expand: nil, guaranteed_at: nil, metadata: nil) @expand = @guaranteed_at = guaranteed_at @metadata = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
342 343 344 |
# File 'lib/stripe/resources/payment_record.rb', line 342 def @expand end |
#guaranteed_at ⇒ Object
When the reported payment was guaranteed. Measured in seconds since the Unix epoch.
344 345 346 |
# File 'lib/stripe/resources/payment_record.rb', line 344 def guaranteed_at @guaranteed_at end |
#metadata ⇒ Object
Attribute for param field metadata
346 347 348 |
# File 'lib/stripe/resources/payment_record.rb', line 346 def @metadata end |