Class: Stripe::PaymentRecord::ReportPaymentAttemptParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentAttemptParams
- Defined in:
- lib/stripe/resources/payment_record.rb
Defined Under Namespace
Classes: Failed, Guaranteed, PaymentMethodDetails, ShippingDetails
Instance Attribute Summary collapse
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failed ⇒ Object
Information about the payment attempt failure.
-
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
-
#initiated_at ⇒ Object
When the reported payment was initiated.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#outcome ⇒ Object
The outcome of the reported payment.
-
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
-
#shipping_details ⇒ Object
Shipping information for this payment.
Instance Method Summary collapse
-
#initialize(description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil) ⇒ ReportPaymentAttemptParams
constructor
A new instance of ReportPaymentAttemptParams.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil) ⇒ ReportPaymentAttemptParams
Returns a new instance of ReportPaymentAttemptParams.
2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/stripe/resources/payment_record.rb', line 2126 def initialize( description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil ) @description = description @expand = @failed = failed @guaranteed = guaranteed @initiated_at = initiated_at @metadata = @outcome = outcome @payment_method_details = payment_method_details @shipping_details = shipping_details end |
Instance Attribute Details
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
2108 2109 2110 |
# File 'lib/stripe/resources/payment_record.rb', line 2108 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2110 2111 2112 |
# File 'lib/stripe/resources/payment_record.rb', line 2110 def @expand end |
#failed ⇒ Object
Information about the payment attempt failure.
2112 2113 2114 |
# File 'lib/stripe/resources/payment_record.rb', line 2112 def failed @failed end |
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
2114 2115 2116 |
# File 'lib/stripe/resources/payment_record.rb', line 2114 def guaranteed @guaranteed end |
#initiated_at ⇒ Object
When the reported payment was initiated. Measured in seconds since the Unix epoch.
2116 2117 2118 |
# File 'lib/stripe/resources/payment_record.rb', line 2116 def initiated_at @initiated_at end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2118 2119 2120 |
# File 'lib/stripe/resources/payment_record.rb', line 2118 def @metadata end |
#outcome ⇒ Object
The outcome of the reported payment.
2120 2121 2122 |
# File 'lib/stripe/resources/payment_record.rb', line 2120 def outcome @outcome end |
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
2122 2123 2124 |
# File 'lib/stripe/resources/payment_record.rb', line 2122 def payment_method_details @payment_method_details end |
#shipping_details ⇒ Object
Shipping information for this payment.
2124 2125 2126 |
# File 'lib/stripe/resources/payment_record.rb', line 2124 def shipping_details @shipping_details end |