Class: Stripe::PaymentRecord::ReportPaymentAttemptParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: Failed, Guaranteed, PaymentMethodDetails, ShippingDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil) ⇒ ReportPaymentAttemptParams

Returns a new instance of ReportPaymentAttemptParams.



1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
# File 'lib/stripe/resources/payment_record.rb', line 1187

def initialize(
  description: nil,
  expand: nil,
  failed: nil,
  guaranteed: nil,
  initiated_at: nil,
  metadata: nil,
  outcome: nil,
  payment_method_details: nil,
  shipping_details: nil
)
  @description = description
  @expand = expand
  @failed = failed
  @guaranteed = guaranteed
  @initiated_at = initiated_at
  @metadata = 
  @outcome = outcome
  @payment_method_details = payment_method_details
  @shipping_details = shipping_details
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1169
1170
1171
# File 'lib/stripe/resources/payment_record.rb', line 1169

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



1171
1172
1173
# File 'lib/stripe/resources/payment_record.rb', line 1171

def expand
  @expand
end

#failedObject

Information about the payment attempt failure.



1173
1174
1175
# File 'lib/stripe/resources/payment_record.rb', line 1173

def failed
  @failed
end

#guaranteedObject

Information about the payment attempt guarantee.



1175
1176
1177
# File 'lib/stripe/resources/payment_record.rb', line 1175

def guaranteed
  @guaranteed
end

#initiated_atObject

When the reported payment was initiated. Measured in seconds since the Unix epoch.



1177
1178
1179
# File 'lib/stripe/resources/payment_record.rb', line 1177

def initiated_at
  @initiated_at
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1179
1180
1181
# File 'lib/stripe/resources/payment_record.rb', line 1179

def 
  @metadata
end

#outcomeObject

The outcome of the reported payment.



1181
1182
1183
# File 'lib/stripe/resources/payment_record.rb', line 1181

def outcome
  @outcome
end

#payment_method_detailsObject

Information about the Payment Method debited for this payment.



1183
1184
1185
# File 'lib/stripe/resources/payment_record.rb', line 1183

def payment_method_details
  @payment_method_details
end

#shipping_detailsObject

Shipping information for this payment.



1185
1186
1187
# File 'lib/stripe/resources/payment_record.rb', line 1185

def shipping_details
  @shipping_details
end