Class: Stripe::PaymentRecord::ReportPaymentAttemptParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentAttemptParams
- Defined in:
- lib/stripe/resources/payment_record.rb
Defined Under Namespace
Classes: Failed, Guaranteed, PaymentMethodDetails, ShippingDetails
Instance Attribute Summary collapse
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failed ⇒ Object
Information about the payment attempt failure.
-
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
-
#initiated_at ⇒ Object
When the reported payment was initiated.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#outcome ⇒ Object
The outcome of the reported payment.
-
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
-
#shipping_details ⇒ Object
Shipping information for this payment.
Instance Method Summary collapse
-
#initialize(description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil) ⇒ ReportPaymentAttemptParams
constructor
A new instance of ReportPaymentAttemptParams.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil) ⇒ ReportPaymentAttemptParams
Returns a new instance of ReportPaymentAttemptParams.
1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 |
# File 'lib/stripe/resources/payment_record.rb', line 1187 def initialize( description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil ) @description = description @expand = @failed = failed @guaranteed = guaranteed @initiated_at = initiated_at @metadata = @outcome = outcome @payment_method_details = payment_method_details @shipping_details = shipping_details end |
Instance Attribute Details
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
1169 1170 1171 |
# File 'lib/stripe/resources/payment_record.rb', line 1169 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1171 1172 1173 |
# File 'lib/stripe/resources/payment_record.rb', line 1171 def @expand end |
#failed ⇒ Object
Information about the payment attempt failure.
1173 1174 1175 |
# File 'lib/stripe/resources/payment_record.rb', line 1173 def failed @failed end |
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
1175 1176 1177 |
# File 'lib/stripe/resources/payment_record.rb', line 1175 def guaranteed @guaranteed end |
#initiated_at ⇒ Object
When the reported payment was initiated. Measured in seconds since the Unix epoch.
1177 1178 1179 |
# File 'lib/stripe/resources/payment_record.rb', line 1177 def initiated_at @initiated_at end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1179 1180 1181 |
# File 'lib/stripe/resources/payment_record.rb', line 1179 def @metadata end |
#outcome ⇒ Object
The outcome of the reported payment.
1181 1182 1183 |
# File 'lib/stripe/resources/payment_record.rb', line 1181 def outcome @outcome end |
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
1183 1184 1185 |
# File 'lib/stripe/resources/payment_record.rb', line 1183 def payment_method_details @payment_method_details end |
#shipping_details ⇒ Object
Shipping information for this payment.
1185 1186 1187 |
# File 'lib/stripe/resources/payment_record.rb', line 1185 def shipping_details @shipping_details end |