Class: Stripe::PaymentRecord::ReportPaymentAttemptParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: Failed, Guaranteed, PaymentMethodDetails, ShippingDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil) ⇒ ReportPaymentAttemptParams

Returns a new instance of ReportPaymentAttemptParams.



340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/stripe/resources/payment_record.rb', line 340

def initialize(
  description: nil,
  expand: nil,
  failed: nil,
  guaranteed: nil,
  initiated_at: nil,
  metadata: nil,
  outcome: nil,
  payment_method_details: nil,
  shipping_details: nil
)
  @description = description
  @expand = expand
  @failed = failed
  @guaranteed = guaranteed
  @initiated_at = initiated_at
  @metadata = 
  @outcome = outcome
  @payment_method_details = payment_method_details
  @shipping_details = shipping_details
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



314
315
316
# File 'lib/stripe/resources/payment_record.rb', line 314

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



317
318
319
# File 'lib/stripe/resources/payment_record.rb', line 317

def expand
  @expand
end

#failedObject

Information about the payment attempt failure.



320
321
322
# File 'lib/stripe/resources/payment_record.rb', line 320

def failed
  @failed
end

#guaranteedObject

Information about the payment attempt guarantee.



323
324
325
# File 'lib/stripe/resources/payment_record.rb', line 323

def guaranteed
  @guaranteed
end

#initiated_atObject

When the reported payment was initiated. Measured in seconds since the Unix epoch.



326
327
328
# File 'lib/stripe/resources/payment_record.rb', line 326

def initiated_at
  @initiated_at
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



329
330
331
# File 'lib/stripe/resources/payment_record.rb', line 329

def 
  @metadata
end

#outcomeObject

The outcome of the reported payment.



332
333
334
# File 'lib/stripe/resources/payment_record.rb', line 332

def outcome
  @outcome
end

#payment_method_detailsObject

Information about the Payment Method debited for this payment.



335
336
337
# File 'lib/stripe/resources/payment_record.rb', line 335

def payment_method_details
  @payment_method_details
end

#shipping_detailsObject

Shipping information for this payment.



338
339
340
# File 'lib/stripe/resources/payment_record.rb', line 338

def shipping_details
  @shipping_details
end