Class: Stripe::PaymentRecord::ReportPaymentAttemptParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: Failed, Guaranteed, PaymentMethodDetails, ShippingDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil) ⇒ ReportPaymentAttemptParams

Returns a new instance of ReportPaymentAttemptParams.



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/stripe/resources/payment_record.rb', line 287

def initialize(
  description: nil,
  expand: nil,
  failed: nil,
  guaranteed: nil,
  initiated_at: nil,
  metadata: nil,
  outcome: nil,
  payment_method_details: nil,
  shipping_details: nil
)
  @description = description
  @expand = expand
  @failed = failed
  @guaranteed = guaranteed
  @initiated_at = initiated_at
  @metadata = 
  @outcome = outcome
  @payment_method_details = payment_method_details
  @shipping_details = shipping_details
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



269
270
271
# File 'lib/stripe/resources/payment_record.rb', line 269

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



271
272
273
# File 'lib/stripe/resources/payment_record.rb', line 271

def expand
  @expand
end

#failedObject

Information about the payment attempt failure.



273
274
275
# File 'lib/stripe/resources/payment_record.rb', line 273

def failed
  @failed
end

#guaranteedObject

Information about the payment attempt guarantee.



275
276
277
# File 'lib/stripe/resources/payment_record.rb', line 275

def guaranteed
  @guaranteed
end

#initiated_atObject

When the reported payment was initiated. Measured in seconds since the Unix epoch.



277
278
279
# File 'lib/stripe/resources/payment_record.rb', line 277

def initiated_at
  @initiated_at
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



279
280
281
# File 'lib/stripe/resources/payment_record.rb', line 279

def 
  @metadata
end

#outcomeObject

The outcome of the reported payment.



281
282
283
# File 'lib/stripe/resources/payment_record.rb', line 281

def outcome
  @outcome
end

#payment_method_detailsObject

Information about the Payment Method debited for this payment.



283
284
285
# File 'lib/stripe/resources/payment_record.rb', line 283

def payment_method_details
  @payment_method_details
end

#shipping_detailsObject

Shipping information for this payment.



285
286
287
# File 'lib/stripe/resources/payment_record.rb', line 285

def shipping_details
  @shipping_details
end