Class: Stripe::PaymentRecord::ReportPaymentAttemptParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentAttemptParams
- Defined in:
- lib/stripe/resources/payment_record.rb
Defined Under Namespace
Classes: Failed, Guaranteed, PaymentMethodDetails, ShippingDetails
Instance Attribute Summary collapse
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failed ⇒ Object
Information about the payment attempt failure.
-
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
-
#initiated_at ⇒ Object
When the reported payment was initiated.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#outcome ⇒ Object
The outcome of the reported payment.
-
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
-
#shipping_details ⇒ Object
Shipping information for this payment.
Instance Method Summary collapse
-
#initialize(description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil) ⇒ ReportPaymentAttemptParams
constructor
A new instance of ReportPaymentAttemptParams.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil) ⇒ ReportPaymentAttemptParams
Returns a new instance of ReportPaymentAttemptParams.
287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/stripe/resources/payment_record.rb', line 287 def initialize( description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil ) @description = description @expand = @failed = failed @guaranteed = guaranteed @initiated_at = initiated_at @metadata = @outcome = outcome @payment_method_details = payment_method_details @shipping_details = shipping_details end |
Instance Attribute Details
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
269 270 271 |
# File 'lib/stripe/resources/payment_record.rb', line 269 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
271 272 273 |
# File 'lib/stripe/resources/payment_record.rb', line 271 def @expand end |
#failed ⇒ Object
Information about the payment attempt failure.
273 274 275 |
# File 'lib/stripe/resources/payment_record.rb', line 273 def failed @failed end |
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
275 276 277 |
# File 'lib/stripe/resources/payment_record.rb', line 275 def guaranteed @guaranteed end |
#initiated_at ⇒ Object
When the reported payment was initiated. Measured in seconds since the Unix epoch.
277 278 279 |
# File 'lib/stripe/resources/payment_record.rb', line 277 def initiated_at @initiated_at end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
279 280 281 |
# File 'lib/stripe/resources/payment_record.rb', line 279 def @metadata end |
#outcome ⇒ Object
The outcome of the reported payment.
281 282 283 |
# File 'lib/stripe/resources/payment_record.rb', line 281 def outcome @outcome end |
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
283 284 285 |
# File 'lib/stripe/resources/payment_record.rb', line 283 def payment_method_details @payment_method_details end |
#shipping_details ⇒ Object
Shipping information for this payment.
285 286 287 |
# File 'lib/stripe/resources/payment_record.rb', line 285 def shipping_details @shipping_details end |