Class: Stripe::PaymentRecord::ReportPaymentAttemptParams::PaymentMethodDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentAttemptParams::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/payment_record.rb
Defined Under Namespace
Classes: BillingDetails, Custom
Instance Attribute Summary collapse
-
#billing_details ⇒ Object
The billing details associated with the method of payment.
-
#custom ⇒ Object
Information about the custom (user-defined) payment method used to make this payment.
-
#payment_method ⇒ Object
ID of the Stripe Payment Method used to make this payment.
-
#type ⇒ Object
The type of the payment method details.
Instance Method Summary collapse
-
#initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil) ⇒ PaymentMethodDetails
constructor
A new instance of PaymentMethodDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil) ⇒ PaymentMethodDetails
Returns a new instance of PaymentMethodDetails.
1129 1130 1131 1132 1133 1134 |
# File 'lib/stripe/resources/payment_record.rb', line 1129 def initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil) @billing_details = billing_details @custom = custom @payment_method = payment_method @type = type end |
Instance Attribute Details
#billing_details ⇒ Object
The billing details associated with the method of payment.
1121 1122 1123 |
# File 'lib/stripe/resources/payment_record.rb', line 1121 def billing_details @billing_details end |
#custom ⇒ Object
Information about the custom (user-defined) payment method used to make this payment.
1123 1124 1125 |
# File 'lib/stripe/resources/payment_record.rb', line 1123 def custom @custom end |
#payment_method ⇒ Object
ID of the Stripe Payment Method used to make this payment.
1125 1126 1127 |
# File 'lib/stripe/resources/payment_record.rb', line 1125 def payment_method @payment_method end |
#type ⇒ Object
The type of the payment method details. An additional hash is included on the payment_method_details with a name matching this value. It contains additional information specific to the type.
1127 1128 1129 |
# File 'lib/stripe/resources/payment_record.rb', line 1127 def type @type end |