Class: Stripe::PaymentRecord::ReportPaymentAttemptParams::PaymentMethodDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: BillingDetails, Custom

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil) ⇒ PaymentMethodDetails

Returns a new instance of PaymentMethodDetails.



1108
1109
1110
1111
1112
1113
# File 'lib/stripe/resources/payment_record.rb', line 1108

def initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil)
  @billing_details = billing_details
  @custom = custom
  @payment_method = payment_method
  @type = type
end

Instance Attribute Details

#billing_detailsObject

The billing details associated with the method of payment.



1100
1101
1102
# File 'lib/stripe/resources/payment_record.rb', line 1100

def billing_details
  @billing_details
end

#customObject

Information about the custom (user-defined) payment method used to make this payment.



1102
1103
1104
# File 'lib/stripe/resources/payment_record.rb', line 1102

def custom
  @custom
end

#payment_methodObject

ID of the Stripe Payment Method used to make this payment.



1104
1105
1106
# File 'lib/stripe/resources/payment_record.rb', line 1104

def payment_method
  @payment_method
end

#typeObject

The type of the payment method details. An additional hash is included on the payment_method_details with a name matching this value. It contains additional information specific to the type.



1106
1107
1108
# File 'lib/stripe/resources/payment_record.rb', line 1106

def type
  @type
end