Class: Stripe::PaymentRecord::ReportPaymentAttemptParams::PaymentMethodDetails::BillingDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails

Returns a new instance of BillingDetails.



1168
1169
1170
1171
1172
1173
# File 'lib/stripe/resources/payment_record.rb', line 1168

def initialize(address: nil, email: nil, name: nil, phone: nil)
  @address = address
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#addressObject

The billing address associated with the method of payment.



1160
1161
1162
# File 'lib/stripe/resources/payment_record.rb', line 1160

def address
  @address
end

#emailObject

The billing email associated with the method of payment.



1162
1163
1164
# File 'lib/stripe/resources/payment_record.rb', line 1162

def email
  @email
end

#nameObject

The billing name associated with the method of payment.



1164
1165
1166
# File 'lib/stripe/resources/payment_record.rb', line 1164

def name
  @name
end

#phoneObject

The billing phone number associated with the method of payment.



1166
1167
1168
# File 'lib/stripe/resources/payment_record.rb', line 1166

def phone
  @phone
end