Class: Stripe::PaymentRecord::ReportPaymentAttemptParams::PaymentMethodDetails::BillingDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails

Returns a new instance of BillingDetails.



1103
1104
1105
1106
1107
1108
# File 'lib/stripe/resources/payment_record.rb', line 1103

def initialize(address: nil, email: nil, name: nil, phone: nil)
  @address = address
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#addressObject

The billing address associated with the method of payment.



1095
1096
1097
# File 'lib/stripe/resources/payment_record.rb', line 1095

def address
  @address
end

#emailObject

The billing email associated with the method of payment.



1097
1098
1099
# File 'lib/stripe/resources/payment_record.rb', line 1097

def email
  @email
end

#nameObject

The billing name associated with the method of payment.



1099
1100
1101
# File 'lib/stripe/resources/payment_record.rb', line 1099

def name
  @name
end

#phoneObject

The billing phone number associated with the method of payment.



1101
1102
1103
# File 'lib/stripe/resources/payment_record.rb', line 1101

def phone
  @phone
end