Class: Stripe::PaymentRecord::ReportPaymentAttemptParams::PaymentMethodDetails::BillingDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails

Returns a new instance of BillingDetails.



1088
1089
1090
1091
1092
1093
# File 'lib/stripe/resources/payment_record.rb', line 1088

def initialize(address: nil, email: nil, name: nil, phone: nil)
  @address = address
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#addressObject

The billing address associated with the method of payment.



1080
1081
1082
# File 'lib/stripe/resources/payment_record.rb', line 1080

def address
  @address
end

#emailObject

The billing email associated with the method of payment.



1082
1083
1084
# File 'lib/stripe/resources/payment_record.rb', line 1082

def email
  @email
end

#nameObject

The billing name associated with the method of payment.



1084
1085
1086
# File 'lib/stripe/resources/payment_record.rb', line 1084

def name
  @name
end

#phoneObject

The billing phone number associated with the method of payment.



1086
1087
1088
# File 'lib/stripe/resources/payment_record.rb', line 1086

def phone
  @phone
end