Class: Stripe::PaymentRecord::ReportPaymentAttemptParams::PaymentMethodDetails::BillingDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentAttemptParams::PaymentMethodDetails::BillingDetails
- Defined in:
- lib/stripe/resources/payment_record.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
The billing address associated with the method of payment.
-
#email ⇒ Object
The billing email associated with the method of payment.
-
#name ⇒ Object
The billing name associated with the method of payment.
-
#phone ⇒ Object
The billing phone number associated with the method of payment.
Instance Method Summary collapse
-
#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails
constructor
A new instance of BillingDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails
Returns a new instance of BillingDetails.
1080 1081 1082 1083 1084 1085 |
# File 'lib/stripe/resources/payment_record.rb', line 1080 def initialize(address: nil, email: nil, name: nil, phone: nil) @address = address @email = email @name = name @phone = phone end |
Instance Attribute Details
#address ⇒ Object
The billing address associated with the method of payment.
1072 1073 1074 |
# File 'lib/stripe/resources/payment_record.rb', line 1072 def address @address end |
#email ⇒ Object
The billing email associated with the method of payment.
1074 1075 1076 |
# File 'lib/stripe/resources/payment_record.rb', line 1074 def email @email end |
#name ⇒ Object
The billing name associated with the method of payment.
1076 1077 1078 |
# File 'lib/stripe/resources/payment_record.rb', line 1076 def name @name end |
#phone ⇒ Object
The billing phone number associated with the method of payment.
1078 1079 1080 |
# File 'lib/stripe/resources/payment_record.rb', line 1078 def phone @phone end |