Class: Stripe::PaymentRecord::ReportPaymentAttemptParams::PaymentMethodDetails::BillingDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails

Returns a new instance of BillingDetails.



222
223
224
225
226
227
# File 'lib/stripe/resources/payment_record.rb', line 222

def initialize(address: nil, email: nil, name: nil, phone: nil)
  @address = address
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#addressObject

The billing address associated with the method of payment.



211
212
213
# File 'lib/stripe/resources/payment_record.rb', line 211

def address
  @address
end

#emailObject

The billing email associated with the method of payment.



214
215
216
# File 'lib/stripe/resources/payment_record.rb', line 214

def email
  @email
end

#nameObject

The billing name associated with the method of payment.



217
218
219
# File 'lib/stripe/resources/payment_record.rb', line 217

def name
  @name
end

#phoneObject

The billing phone number associated with the method of payment.



220
221
222
# File 'lib/stripe/resources/payment_record.rb', line 220

def phone
  @phone
end