Class: Stripe::PaymentRecord::ReportPaymentAttemptParams::PaymentMethodDetails::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentAttemptParams::PaymentMethodDetails::Custom
- Defined in:
- lib/stripe/resources/payment_record.rb
Instance Attribute Summary collapse
-
#display_name ⇒ Object
Display name for the custom (user-defined) payment method type used to make this payment.
-
#type ⇒ Object
The custom payment method type associated with this payment.
Instance Method Summary collapse
-
#initialize(display_name: nil, type: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
Constructor Details
#initialize(display_name: nil, type: nil) ⇒ Custom
Returns a new instance of Custom.
1094 1095 1096 1097 |
# File 'lib/stripe/resources/payment_record.rb', line 1094 def initialize(display_name: nil, type: nil) @display_name = display_name @type = type end |
Instance Attribute Details
#display_name ⇒ Object
Display name for the custom (user-defined) payment method type used to make this payment.
1090 1091 1092 |
# File 'lib/stripe/resources/payment_record.rb', line 1090 def display_name @display_name end |
#type ⇒ Object
The custom payment method type associated with this payment.
1092 1093 1094 |
# File 'lib/stripe/resources/payment_record.rb', line 1092 def type @type end |