Class: Stripe::PaymentRecord::ReportPaymentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentParams
- Defined in:
- lib/stripe/resources/payment_record.rb
Defined Under Namespace
Classes: AmountRequested, CustomerDetails, Failed, Guaranteed, PaymentMethodDetails, ProcessorDetails, ShippingDetails
Instance Attribute Summary collapse
-
#amount_requested ⇒ Object
The amount you initially requested for this payment.
-
#customer_details ⇒ Object
Customer information for this payment.
-
#customer_presence ⇒ Object
Indicates whether the customer was present in your checkout flow during this payment.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failed ⇒ Object
Information about the payment attempt failure.
-
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
-
#initiated_at ⇒ Object
When the reported payment was initiated.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#outcome ⇒ Object
The outcome of the reported payment.
-
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
-
#processor_details ⇒ Object
Processor information for this payment.
-
#shipping_details ⇒ Object
Shipping information for this payment.
Instance Method Summary collapse
-
#initialize(amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, processor_details: nil, shipping_details: nil) ⇒ ReportPaymentParams
constructor
A new instance of ReportPaymentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, processor_details: nil, shipping_details: nil) ⇒ ReportPaymentParams
Returns a new instance of ReportPaymentParams.
2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 |
# File 'lib/stripe/resources/payment_record.rb', line 2411 def initialize( amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, processor_details: nil, shipping_details: nil ) @amount_requested = amount_requested @customer_details = customer_details @customer_presence = customer_presence @description = description @expand = @failed = failed @guaranteed = guaranteed @initiated_at = initiated_at @metadata = @outcome = outcome @payment_method_details = payment_method_details @processor_details = processor_details @shipping_details = shipping_details end |
Instance Attribute Details
#amount_requested ⇒ Object
The amount you initially requested for this payment.
2385 2386 2387 |
# File 'lib/stripe/resources/payment_record.rb', line 2385 def amount_requested @amount_requested end |
#customer_details ⇒ Object
Customer information for this payment.
2387 2388 2389 |
# File 'lib/stripe/resources/payment_record.rb', line 2387 def customer_details @customer_details end |
#customer_presence ⇒ Object
Indicates whether the customer was present in your checkout flow during this payment.
2389 2390 2391 |
# File 'lib/stripe/resources/payment_record.rb', line 2389 def customer_presence @customer_presence end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
2391 2392 2393 |
# File 'lib/stripe/resources/payment_record.rb', line 2391 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2393 2394 2395 |
# File 'lib/stripe/resources/payment_record.rb', line 2393 def @expand end |
#failed ⇒ Object
Information about the payment attempt failure.
2395 2396 2397 |
# File 'lib/stripe/resources/payment_record.rb', line 2395 def failed @failed end |
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
2397 2398 2399 |
# File 'lib/stripe/resources/payment_record.rb', line 2397 def guaranteed @guaranteed end |
#initiated_at ⇒ Object
When the reported payment was initiated. Measured in seconds since the Unix epoch.
2399 2400 2401 |
# File 'lib/stripe/resources/payment_record.rb', line 2399 def initiated_at @initiated_at end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2401 2402 2403 |
# File 'lib/stripe/resources/payment_record.rb', line 2401 def @metadata end |
#outcome ⇒ Object
The outcome of the reported payment.
2403 2404 2405 |
# File 'lib/stripe/resources/payment_record.rb', line 2403 def outcome @outcome end |
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
2405 2406 2407 |
# File 'lib/stripe/resources/payment_record.rb', line 2405 def payment_method_details @payment_method_details end |
#processor_details ⇒ Object
Processor information for this payment.
2407 2408 2409 |
# File 'lib/stripe/resources/payment_record.rb', line 2407 def processor_details @processor_details end |
#shipping_details ⇒ Object
Shipping information for this payment.
2409 2410 2411 |
# File 'lib/stripe/resources/payment_record.rb', line 2409 def shipping_details @shipping_details end |