Class: Stripe::PaymentRecord::ReportPaymentParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: AmountRequested, CustomerDetails, Failed, Guaranteed, PaymentMethodDetails, ProcessorDetails, ShippingDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, processor_details: nil, shipping_details: nil) ⇒ ReportPaymentParams

Returns a new instance of ReportPaymentParams.



1552
1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
# File 'lib/stripe/resources/payment_record.rb', line 1552

def initialize(
  amount_requested: nil,
  customer_details: nil,
  customer_presence: nil,
  description: nil,
  expand: nil,
  failed: nil,
  guaranteed: nil,
  initiated_at: nil,
  metadata: nil,
  outcome: nil,
  payment_method_details: nil,
  processor_details: nil,
  shipping_details: nil
)
  @amount_requested = amount_requested
  @customer_details = customer_details
  @customer_presence = customer_presence
  @description = description
  @expand = expand
  @failed = failed
  @guaranteed = guaranteed
  @initiated_at = initiated_at
  @metadata = 
  @outcome = outcome
  @payment_method_details = payment_method_details
  @processor_details = processor_details
  @shipping_details = shipping_details
end

Instance Attribute Details

#amount_requestedObject

The amount you initially requested for this payment.



1526
1527
1528
# File 'lib/stripe/resources/payment_record.rb', line 1526

def amount_requested
  @amount_requested
end

#customer_detailsObject

Customer information for this payment.



1528
1529
1530
# File 'lib/stripe/resources/payment_record.rb', line 1528

def customer_details
  @customer_details
end

#customer_presenceObject

Indicates whether the customer was present in your checkout flow during this payment.



1530
1531
1532
# File 'lib/stripe/resources/payment_record.rb', line 1530

def customer_presence
  @customer_presence
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1532
1533
1534
# File 'lib/stripe/resources/payment_record.rb', line 1532

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



1534
1535
1536
# File 'lib/stripe/resources/payment_record.rb', line 1534

def expand
  @expand
end

#failedObject

Information about the payment attempt failure.



1536
1537
1538
# File 'lib/stripe/resources/payment_record.rb', line 1536

def failed
  @failed
end

#guaranteedObject

Information about the payment attempt guarantee.



1538
1539
1540
# File 'lib/stripe/resources/payment_record.rb', line 1538

def guaranteed
  @guaranteed
end

#initiated_atObject

When the reported payment was initiated. Measured in seconds since the Unix epoch.



1540
1541
1542
# File 'lib/stripe/resources/payment_record.rb', line 1540

def initiated_at
  @initiated_at
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1542
1543
1544
# File 'lib/stripe/resources/payment_record.rb', line 1542

def 
  @metadata
end

#outcomeObject

The outcome of the reported payment.



1544
1545
1546
# File 'lib/stripe/resources/payment_record.rb', line 1544

def outcome
  @outcome
end

#payment_method_detailsObject

Information about the Payment Method debited for this payment.



1546
1547
1548
# File 'lib/stripe/resources/payment_record.rb', line 1546

def payment_method_details
  @payment_method_details
end

#processor_detailsObject

Processor information for this payment.



1548
1549
1550
# File 'lib/stripe/resources/payment_record.rb', line 1548

def processor_details
  @processor_details
end

#shipping_detailsObject

Shipping information for this payment.



1550
1551
1552
# File 'lib/stripe/resources/payment_record.rb', line 1550

def shipping_details
  @shipping_details
end