Class: Stripe::PaymentRecord::ReportPaymentParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: AmountRequested, CustomerDetails, Failed, Guaranteed, PaymentMethodDetails, ShippingDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, payment_reference: nil, shipping_details: nil) ⇒ ReportPaymentParams

Returns a new instance of ReportPaymentParams.



1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
# File 'lib/stripe/resources/payment_record.rb', line 1467

def initialize(
  amount_requested: nil,
  customer_details: nil,
  customer_presence: nil,
  description: nil,
  expand: nil,
  failed: nil,
  guaranteed: nil,
  initiated_at: nil,
  metadata: nil,
  outcome: nil,
  payment_method_details: nil,
  payment_reference: nil,
  shipping_details: nil
)
  @amount_requested = amount_requested
  @customer_details = customer_details
  @customer_presence = customer_presence
  @description = description
  @expand = expand
  @failed = failed
  @guaranteed = guaranteed
  @initiated_at = initiated_at
  @metadata = 
  @outcome = outcome
  @payment_method_details = payment_method_details
  @payment_reference = payment_reference
  @shipping_details = shipping_details
end

Instance Attribute Details

#amount_requestedObject

The amount you initially requested for this payment.



1441
1442
1443
# File 'lib/stripe/resources/payment_record.rb', line 1441

def amount_requested
  @amount_requested
end

#customer_detailsObject

Customer information for this payment.



1443
1444
1445
# File 'lib/stripe/resources/payment_record.rb', line 1443

def customer_details
  @customer_details
end

#customer_presenceObject

Indicates whether the customer was present in your checkout flow during this payment.



1445
1446
1447
# File 'lib/stripe/resources/payment_record.rb', line 1445

def customer_presence
  @customer_presence
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1447
1448
1449
# File 'lib/stripe/resources/payment_record.rb', line 1447

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



1449
1450
1451
# File 'lib/stripe/resources/payment_record.rb', line 1449

def expand
  @expand
end

#failedObject

Information about the payment attempt failure.



1451
1452
1453
# File 'lib/stripe/resources/payment_record.rb', line 1451

def failed
  @failed
end

#guaranteedObject

Information about the payment attempt guarantee.



1453
1454
1455
# File 'lib/stripe/resources/payment_record.rb', line 1453

def guaranteed
  @guaranteed
end

#initiated_atObject

When the reported payment was initiated. Measured in seconds since the Unix epoch.



1455
1456
1457
# File 'lib/stripe/resources/payment_record.rb', line 1455

def initiated_at
  @initiated_at
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1457
1458
1459
# File 'lib/stripe/resources/payment_record.rb', line 1457

def 
  @metadata
end

#outcomeObject

The outcome of the reported payment.



1459
1460
1461
# File 'lib/stripe/resources/payment_record.rb', line 1459

def outcome
  @outcome
end

#payment_method_detailsObject

Information about the Payment Method debited for this payment.



1461
1462
1463
# File 'lib/stripe/resources/payment_record.rb', line 1461

def payment_method_details
  @payment_method_details
end

#payment_referenceObject

An opaque string for manual reconciliation of this payment, for example a check number or a payment processor ID.



1463
1464
1465
# File 'lib/stripe/resources/payment_record.rb', line 1463

def payment_reference
  @payment_reference
end

#shipping_detailsObject

Shipping information for this payment.



1465
1466
1467
# File 'lib/stripe/resources/payment_record.rb', line 1465

def shipping_details
  @shipping_details
end