Class: Stripe::PaymentRecord::ReportPaymentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentParams
- Defined in:
- lib/stripe/resources/payment_record.rb
Defined Under Namespace
Classes: AmountRequested, CustomerDetails, Failed, Guaranteed, PaymentMethodDetails, ShippingDetails
Instance Attribute Summary collapse
-
#amount_requested ⇒ Object
The amount you intend to collect for this payment.
-
#customer_details ⇒ Object
Customer information for this payment.
-
#customer_presence ⇒ Object
Indicates whether the customer was present in your checkout flow during this payment.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failed ⇒ Object
Information about the payment attempt failure.
-
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
-
#initiated_at ⇒ Object
When the reported payment was initiated.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#outcome ⇒ Object
The outcome of the reported payment.
-
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
-
#payment_reference ⇒ Object
An opaque string for manual reconciliation of this payment, for example a check number or a payment processor ID.
-
#shipping_details ⇒ Object
Shipping information for this payment.
Instance Method Summary collapse
-
#initialize(amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, payment_reference: nil, shipping_details: nil) ⇒ ReportPaymentParams
constructor
A new instance of ReportPaymentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, payment_reference: nil, shipping_details: nil) ⇒ ReportPaymentParams
Returns a new instance of ReportPaymentParams.
1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 |
# File 'lib/stripe/resources/payment_record.rb', line 1444 def initialize( amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, payment_reference: nil, shipping_details: nil ) @amount_requested = amount_requested @customer_details = customer_details @customer_presence = customer_presence @description = description @expand = @failed = failed @guaranteed = guaranteed @initiated_at = initiated_at @metadata = @outcome = outcome @payment_method_details = payment_method_details @payment_reference = payment_reference @shipping_details = shipping_details end |
Instance Attribute Details
#amount_requested ⇒ Object
The amount you intend to collect for this payment.
1418 1419 1420 |
# File 'lib/stripe/resources/payment_record.rb', line 1418 def amount_requested @amount_requested end |
#customer_details ⇒ Object
Customer information for this payment.
1420 1421 1422 |
# File 'lib/stripe/resources/payment_record.rb', line 1420 def customer_details @customer_details end |
#customer_presence ⇒ Object
Indicates whether the customer was present in your checkout flow during this payment.
1422 1423 1424 |
# File 'lib/stripe/resources/payment_record.rb', line 1422 def customer_presence @customer_presence end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
1424 1425 1426 |
# File 'lib/stripe/resources/payment_record.rb', line 1424 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1426 1427 1428 |
# File 'lib/stripe/resources/payment_record.rb', line 1426 def @expand end |
#failed ⇒ Object
Information about the payment attempt failure.
1428 1429 1430 |
# File 'lib/stripe/resources/payment_record.rb', line 1428 def failed @failed end |
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
1430 1431 1432 |
# File 'lib/stripe/resources/payment_record.rb', line 1430 def guaranteed @guaranteed end |
#initiated_at ⇒ Object
When the reported payment was initiated. Measured in seconds since the Unix epoch.
1432 1433 1434 |
# File 'lib/stripe/resources/payment_record.rb', line 1432 def initiated_at @initiated_at end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1434 1435 1436 |
# File 'lib/stripe/resources/payment_record.rb', line 1434 def @metadata end |
#outcome ⇒ Object
The outcome of the reported payment.
1436 1437 1438 |
# File 'lib/stripe/resources/payment_record.rb', line 1436 def outcome @outcome end |
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
1438 1439 1440 |
# File 'lib/stripe/resources/payment_record.rb', line 1438 def payment_method_details @payment_method_details end |
#payment_reference ⇒ Object
An opaque string for manual reconciliation of this payment, for example a check number or a payment processor ID.
1440 1441 1442 |
# File 'lib/stripe/resources/payment_record.rb', line 1440 def payment_reference @payment_reference end |
#shipping_details ⇒ Object
Shipping information for this payment.
1442 1443 1444 |
# File 'lib/stripe/resources/payment_record.rb', line 1442 def shipping_details @shipping_details end |