Class: Stripe::PaymentRecord::ReportPaymentParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: AmountRequested, CustomerDetails, Failed, Guaranteed, PaymentMethodDetails, ShippingDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, payment_reference: nil, shipping_details: nil) ⇒ ReportPaymentParams

Returns a new instance of ReportPaymentParams.



646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
# File 'lib/stripe/resources/payment_record.rb', line 646

def initialize(
  amount_requested: nil,
  customer_details: nil,
  customer_presence: nil,
  description: nil,
  expand: nil,
  failed: nil,
  guaranteed: nil,
  initiated_at: nil,
  metadata: nil,
  outcome: nil,
  payment_method_details: nil,
  payment_reference: nil,
  shipping_details: nil
)
  @amount_requested = amount_requested
  @customer_details = customer_details
  @customer_presence = customer_presence
  @description = description
  @expand = expand
  @failed = failed
  @guaranteed = guaranteed
  @initiated_at = initiated_at
  @metadata = 
  @outcome = outcome
  @payment_method_details = payment_method_details
  @payment_reference = payment_reference
  @shipping_details = shipping_details
end

Instance Attribute Details

#amount_requestedObject

The amount you intend to collect for this payment.



608
609
610
# File 'lib/stripe/resources/payment_record.rb', line 608

def amount_requested
  @amount_requested
end

#customer_detailsObject

Customer information for this payment.



611
612
613
# File 'lib/stripe/resources/payment_record.rb', line 611

def customer_details
  @customer_details
end

#customer_presenceObject

Indicates whether the customer was present in your checkout flow during this payment.



614
615
616
# File 'lib/stripe/resources/payment_record.rb', line 614

def customer_presence
  @customer_presence
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



617
618
619
# File 'lib/stripe/resources/payment_record.rb', line 617

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



620
621
622
# File 'lib/stripe/resources/payment_record.rb', line 620

def expand
  @expand
end

#failedObject

Information about the payment attempt failure.



623
624
625
# File 'lib/stripe/resources/payment_record.rb', line 623

def failed
  @failed
end

#guaranteedObject

Information about the payment attempt guarantee.



626
627
628
# File 'lib/stripe/resources/payment_record.rb', line 626

def guaranteed
  @guaranteed
end

#initiated_atObject

When the reported payment was initiated. Measured in seconds since the Unix epoch.



629
630
631
# File 'lib/stripe/resources/payment_record.rb', line 629

def initiated_at
  @initiated_at
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



632
633
634
# File 'lib/stripe/resources/payment_record.rb', line 632

def 
  @metadata
end

#outcomeObject

The outcome of the reported payment.



635
636
637
# File 'lib/stripe/resources/payment_record.rb', line 635

def outcome
  @outcome
end

#payment_method_detailsObject

Information about the Payment Method debited for this payment.



638
639
640
# File 'lib/stripe/resources/payment_record.rb', line 638

def payment_method_details
  @payment_method_details
end

#payment_referenceObject

An opaque string for manual reconciliation of this payment, for example a check number or a payment processor ID.



641
642
643
# File 'lib/stripe/resources/payment_record.rb', line 641

def payment_reference
  @payment_reference
end

#shipping_detailsObject

Shipping information for this payment.



644
645
646
# File 'lib/stripe/resources/payment_record.rb', line 644

def shipping_details
  @shipping_details
end