Class: Stripe::PaymentRecord::ReportPaymentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentParams
- Defined in:
- lib/stripe/resources/payment_record.rb
Defined Under Namespace
Classes: AmountRequested, CustomerDetails, Failed, Guaranteed, PaymentMethodDetails, ShippingDetails
Instance Attribute Summary collapse
-
#amount_requested ⇒ Object
The amount you intend to collect for this payment.
-
#customer_details ⇒ Object
Customer information for this payment.
-
#customer_presence ⇒ Object
Indicates whether the customer was present in your checkout flow during this payment.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failed ⇒ Object
Information about the payment attempt failure.
-
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
-
#initiated_at ⇒ Object
When the reported payment was initiated.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#outcome ⇒ Object
The outcome of the reported payment.
-
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
-
#payment_reference ⇒ Object
An opaque string for manual reconciliation of this payment, for example a check number or a payment processor ID.
-
#shipping_details ⇒ Object
Shipping information for this payment.
Instance Method Summary collapse
-
#initialize(amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, payment_reference: nil, shipping_details: nil) ⇒ ReportPaymentParams
constructor
A new instance of ReportPaymentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, payment_reference: nil, shipping_details: nil) ⇒ ReportPaymentParams
Returns a new instance of ReportPaymentParams.
552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 |
# File 'lib/stripe/resources/payment_record.rb', line 552 def initialize( amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, payment_reference: nil, shipping_details: nil ) @amount_requested = amount_requested @customer_details = customer_details @customer_presence = customer_presence @description = description @expand = @failed = failed @guaranteed = guaranteed @initiated_at = initiated_at @metadata = @outcome = outcome @payment_method_details = payment_method_details @payment_reference = payment_reference @shipping_details = shipping_details end |
Instance Attribute Details
#amount_requested ⇒ Object
The amount you intend to collect for this payment.
526 527 528 |
# File 'lib/stripe/resources/payment_record.rb', line 526 def amount_requested @amount_requested end |
#customer_details ⇒ Object
Customer information for this payment.
528 529 530 |
# File 'lib/stripe/resources/payment_record.rb', line 528 def customer_details @customer_details end |
#customer_presence ⇒ Object
Indicates whether the customer was present in your checkout flow during this payment.
530 531 532 |
# File 'lib/stripe/resources/payment_record.rb', line 530 def customer_presence @customer_presence end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
532 533 534 |
# File 'lib/stripe/resources/payment_record.rb', line 532 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
534 535 536 |
# File 'lib/stripe/resources/payment_record.rb', line 534 def @expand end |
#failed ⇒ Object
Information about the payment attempt failure.
536 537 538 |
# File 'lib/stripe/resources/payment_record.rb', line 536 def failed @failed end |
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
538 539 540 |
# File 'lib/stripe/resources/payment_record.rb', line 538 def guaranteed @guaranteed end |
#initiated_at ⇒ Object
When the reported payment was initiated. Measured in seconds since the Unix epoch.
540 541 542 |
# File 'lib/stripe/resources/payment_record.rb', line 540 def initiated_at @initiated_at end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
542 543 544 |
# File 'lib/stripe/resources/payment_record.rb', line 542 def @metadata end |
#outcome ⇒ Object
The outcome of the reported payment.
544 545 546 |
# File 'lib/stripe/resources/payment_record.rb', line 544 def outcome @outcome end |
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
546 547 548 |
# File 'lib/stripe/resources/payment_record.rb', line 546 def payment_method_details @payment_method_details end |
#payment_reference ⇒ Object
An opaque string for manual reconciliation of this payment, for example a check number or a payment processor ID.
548 549 550 |
# File 'lib/stripe/resources/payment_record.rb', line 548 def payment_reference @payment_reference end |
#shipping_details ⇒ Object
Shipping information for this payment.
550 551 552 |
# File 'lib/stripe/resources/payment_record.rb', line 550 def shipping_details @shipping_details end |