Class: Stripe::PaymentRecord::ReportPaymentParams::AmountRequested
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentParams::AmountRequested
- Defined in:
- lib/stripe/resources/payment_record.rb
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#value ⇒ Object
A positive integer representing the amount in the currency’s [minor unit](stripe.com/docs/currencies#zero-decimal).
Instance Method Summary collapse
-
#initialize(currency: nil, value: nil) ⇒ AmountRequested
constructor
A new instance of AmountRequested.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, value: nil) ⇒ AmountRequested
Returns a new instance of AmountRequested.
2201 2202 2203 2204 |
# File 'lib/stripe/resources/payment_record.rb', line 2201 def initialize(currency: nil, value: nil) @currency = currency @value = value end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
2197 2198 2199 |
# File 'lib/stripe/resources/payment_record.rb', line 2197 def currency @currency end |
#value ⇒ Object
A positive integer representing the amount in the currency’s [minor unit](stripe.com/docs/currencies#zero-decimal). For example, ‘100` can represent 1 USD or 100 JPY.
2199 2200 2201 |
# File 'lib/stripe/resources/payment_record.rb', line 2199 def value @value end |