Class: Stripe::PaymentRecord::ReportPaymentParams::AmountRequested
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentParams::AmountRequested
- Defined in:
- lib/stripe/resources/payment_record.rb
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#value ⇒ Object
A positive integer representing the amount in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) for example, 100 cents for 1 USD or 100 for 100 JPY, a zero-decimal currency.
Instance Method Summary collapse
-
#initialize(currency: nil, value: nil) ⇒ AmountRequested
constructor
A new instance of AmountRequested.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, value: nil) ⇒ AmountRequested
Returns a new instance of AmountRequested.
1275 1276 1277 1278 |
# File 'lib/stripe/resources/payment_record.rb', line 1275 def initialize(currency: nil, value: nil) @currency = currency @value = value end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
1271 1272 1273 |
# File 'lib/stripe/resources/payment_record.rb', line 1271 def currency @currency end |
#value ⇒ Object
A positive integer representing the amount in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) for example, 100 cents for 1 USD or 100 for 100 JPY, a zero-decimal currency.
1273 1274 1275 |
# File 'lib/stripe/resources/payment_record.rb', line 1273 def value @value end |