Class: Stripe::PaymentRecord::ReportPaymentParams::AmountRequested
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentParams::AmountRequested
- Defined in:
- lib/stripe/resources/payment_record.rb
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#value ⇒ Object
A positive integer representing the amount in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) for example, 100 cents for 1 USD or 100 for 100 JPY, a zero-decimal currency.
Instance Method Summary collapse
-
#initialize(currency: nil, value: nil) ⇒ AmountRequested
constructor
A new instance of AmountRequested.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, value: nil) ⇒ AmountRequested
Returns a new instance of AmountRequested.
1262 1263 1264 1265 |
# File 'lib/stripe/resources/payment_record.rb', line 1262 def initialize(currency: nil, value: nil) @currency = currency @value = value end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
1258 1259 1260 |
# File 'lib/stripe/resources/payment_record.rb', line 1258 def currency @currency end |
#value ⇒ Object
A positive integer representing the amount in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) for example, 100 cents for 1 USD or 100 for 100 JPY, a zero-decimal currency.
1260 1261 1262 |
# File 'lib/stripe/resources/payment_record.rb', line 1260 def value @value end |