Class: Stripe::PaymentRecord::ReportPaymentParams::PaymentMethodDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: BillingDetails, Custom

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil) ⇒ PaymentMethodDetails

Returns a new instance of PaymentMethodDetails.



2312
2313
2314
2315
2316
2317
# File 'lib/stripe/resources/payment_record.rb', line 2312

def initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil)
  @billing_details = billing_details
  @custom = custom
  @payment_method = payment_method
  @type = type
end

Instance Attribute Details

#billing_detailsObject

The billing details associated with the method of payment.



2304
2305
2306
# File 'lib/stripe/resources/payment_record.rb', line 2304

def billing_details
  @billing_details
end

#customObject

Information about the custom (user-defined) payment method used to make this payment.



2306
2307
2308
# File 'lib/stripe/resources/payment_record.rb', line 2306

def custom
  @custom
end

#payment_methodObject

ID of the Stripe Payment Method used to make this payment.



2308
2309
2310
# File 'lib/stripe/resources/payment_record.rb', line 2308

def payment_method
  @payment_method
end

#typeObject

The type of the payment method details. An additional hash is included on the payment_method_details with a name matching this value. It contains additional information specific to the type.



2310
2311
2312
# File 'lib/stripe/resources/payment_record.rb', line 2310

def type
  @type
end