Class: Stripe::PaymentRecord::ReportPaymentParams::PaymentMethodDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: BillingDetails, Custom

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil) ⇒ PaymentMethodDetails

Returns a new instance of PaymentMethodDetails.



1373
1374
1375
1376
1377
1378
# File 'lib/stripe/resources/payment_record.rb', line 1373

def initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil)
  @billing_details = billing_details
  @custom = custom
  @payment_method = payment_method
  @type = type
end

Instance Attribute Details

#billing_detailsObject

The billing details associated with the method of payment.



1365
1366
1367
# File 'lib/stripe/resources/payment_record.rb', line 1365

def billing_details
  @billing_details
end

#customObject

Information about the custom (user-defined) payment method used to make this payment.



1367
1368
1369
# File 'lib/stripe/resources/payment_record.rb', line 1367

def custom
  @custom
end

#payment_methodObject

ID of the Stripe Payment Method used to make this payment.



1369
1370
1371
# File 'lib/stripe/resources/payment_record.rb', line 1369

def payment_method
  @payment_method
end

#typeObject

The type of the payment method details. An additional hash is included on the payment_method_details with a name matching this value. It contains additional information specific to the type.



1371
1372
1373
# File 'lib/stripe/resources/payment_record.rb', line 1371

def type
  @type
end