Class: Stripe::PaymentRecord::ReportPaymentParams::PaymentMethodDetails::BillingDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails

Returns a new instance of BillingDetails.



2284
2285
2286
2287
2288
2289
# File 'lib/stripe/resources/payment_record.rb', line 2284

def initialize(address: nil, email: nil, name: nil, phone: nil)
  @address = address
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#addressObject

The billing address associated with the method of payment.



2276
2277
2278
# File 'lib/stripe/resources/payment_record.rb', line 2276

def address
  @address
end

#emailObject

The billing email associated with the method of payment.



2278
2279
2280
# File 'lib/stripe/resources/payment_record.rb', line 2278

def email
  @email
end

#nameObject

The billing name associated with the method of payment.



2280
2281
2282
# File 'lib/stripe/resources/payment_record.rb', line 2280

def name
  @name
end

#phoneObject

The billing phone number associated with the method of payment.



2282
2283
2284
# File 'lib/stripe/resources/payment_record.rb', line 2282

def phone
  @phone
end