Class: Stripe::PaymentRecord::ReportPaymentParams::PaymentMethodDetails::BillingDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentParams::PaymentMethodDetails::BillingDetails
- Defined in:
- lib/stripe/resources/payment_record.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
The billing address associated with the method of payment.
-
#email ⇒ Object
The billing email associated with the method of payment.
-
#name ⇒ Object
The billing name associated with the method of payment.
-
#phone ⇒ Object
The billing phone number associated with the method of payment.
Instance Method Summary collapse
-
#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails
constructor
A new instance of BillingDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails
Returns a new instance of BillingDetails.
2284 2285 2286 2287 2288 2289 |
# File 'lib/stripe/resources/payment_record.rb', line 2284 def initialize(address: nil, email: nil, name: nil, phone: nil) @address = address @email = email @name = name @phone = phone end |
Instance Attribute Details
#address ⇒ Object
The billing address associated with the method of payment.
2276 2277 2278 |
# File 'lib/stripe/resources/payment_record.rb', line 2276 def address @address end |
#email ⇒ Object
The billing email associated with the method of payment.
2278 2279 2280 |
# File 'lib/stripe/resources/payment_record.rb', line 2278 def email @email end |
#name ⇒ Object
The billing name associated with the method of payment.
2280 2281 2282 |
# File 'lib/stripe/resources/payment_record.rb', line 2280 def name @name end |
#phone ⇒ Object
The billing phone number associated with the method of payment.
2282 2283 2284 |
# File 'lib/stripe/resources/payment_record.rb', line 2282 def phone @phone end |