Class: Stripe::PaymentRecord::ReportPaymentParams::PaymentMethodDetails::BillingDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentParams::PaymentMethodDetails::BillingDetails
- Defined in:
- lib/stripe/resources/payment_record.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
The billing address associated with the method of payment.
-
#email ⇒ Object
The billing email associated with the method of payment.
-
#name ⇒ Object
The billing name associated with the method of payment.
-
#phone ⇒ Object
The billing phone number associated with the method of payment.
Instance Method Summary collapse
-
#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails
constructor
A new instance of BillingDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails
Returns a new instance of BillingDetails.
1360 1361 1362 1363 1364 1365 |
# File 'lib/stripe/resources/payment_record.rb', line 1360 def initialize(address: nil, email: nil, name: nil, phone: nil) @address = address @email = email @name = name @phone = phone end |
Instance Attribute Details
#address ⇒ Object
The billing address associated with the method of payment.
1352 1353 1354 |
# File 'lib/stripe/resources/payment_record.rb', line 1352 def address @address end |
#email ⇒ Object
The billing email associated with the method of payment.
1354 1355 1356 |
# File 'lib/stripe/resources/payment_record.rb', line 1354 def email @email end |
#name ⇒ Object
The billing name associated with the method of payment.
1356 1357 1358 |
# File 'lib/stripe/resources/payment_record.rb', line 1356 def name @name end |
#phone ⇒ Object
The billing phone number associated with the method of payment.
1358 1359 1360 |
# File 'lib/stripe/resources/payment_record.rb', line 1358 def phone @phone end |