Class: Stripe::PaymentRecord::ReportPaymentParams::PaymentMethodDetails::BillingDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails

Returns a new instance of BillingDetails.



1358
1359
1360
1361
1362
1363
# File 'lib/stripe/resources/payment_record.rb', line 1358

def initialize(address: nil, email: nil, name: nil, phone: nil)
  @address = address
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#addressObject

The billing address associated with the method of payment.



1350
1351
1352
# File 'lib/stripe/resources/payment_record.rb', line 1350

def address
  @address
end

#emailObject

The billing email associated with the method of payment.



1352
1353
1354
# File 'lib/stripe/resources/payment_record.rb', line 1352

def email
  @email
end

#nameObject

The billing name associated with the method of payment.



1354
1355
1356
# File 'lib/stripe/resources/payment_record.rb', line 1354

def name
  @name
end

#phoneObject

The billing phone number associated with the method of payment.



1356
1357
1358
# File 'lib/stripe/resources/payment_record.rb', line 1356

def phone
  @phone
end