Class: Stripe::PaymentRecord::ReportPaymentParams::PaymentMethodDetails::BillingDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails

Returns a new instance of BillingDetails.



1345
1346
1347
1348
1349
1350
# File 'lib/stripe/resources/payment_record.rb', line 1345

def initialize(address: nil, email: nil, name: nil, phone: nil)
  @address = address
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#addressObject

The billing address associated with the method of payment.



1337
1338
1339
# File 'lib/stripe/resources/payment_record.rb', line 1337

def address
  @address
end

#emailObject

The billing email associated with the method of payment.



1339
1340
1341
# File 'lib/stripe/resources/payment_record.rb', line 1339

def email
  @email
end

#nameObject

The billing name associated with the method of payment.



1341
1342
1343
# File 'lib/stripe/resources/payment_record.rb', line 1341

def name
  @name
end

#phoneObject

The billing phone number associated with the method of payment.



1343
1344
1345
# File 'lib/stripe/resources/payment_record.rb', line 1343

def phone
  @phone
end