Class: Stripe::PaymentRecord::ReportPaymentParams::PaymentMethodDetails::BillingDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentParams::PaymentMethodDetails::BillingDetails
- Defined in:
- lib/stripe/resources/payment_record.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
The billing address associated with the method of payment.
-
#email ⇒ Object
The billing email associated with the method of payment.
-
#name ⇒ Object
The billing name associated with the method of payment.
-
#phone ⇒ Object
The billing phone number associated with the method of payment.
Instance Method Summary collapse
-
#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails
constructor
A new instance of BillingDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails
Returns a new instance of BillingDetails.
1345 1346 1347 1348 1349 1350 |
# File 'lib/stripe/resources/payment_record.rb', line 1345 def initialize(address: nil, email: nil, name: nil, phone: nil) @address = address @email = email @name = name @phone = phone end |
Instance Attribute Details
#address ⇒ Object
The billing address associated with the method of payment.
1337 1338 1339 |
# File 'lib/stripe/resources/payment_record.rb', line 1337 def address @address end |
#email ⇒ Object
The billing email associated with the method of payment.
1339 1340 1341 |
# File 'lib/stripe/resources/payment_record.rb', line 1339 def email @email end |
#name ⇒ Object
The billing name associated with the method of payment.
1341 1342 1343 |
# File 'lib/stripe/resources/payment_record.rb', line 1341 def name @name end |
#phone ⇒ Object
The billing phone number associated with the method of payment.
1343 1344 1345 |
# File 'lib/stripe/resources/payment_record.rb', line 1343 def phone @phone end |