Class: Stripe::PaymentRecord::ReportPaymentParams::PaymentMethodDetails::BillingDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails

Returns a new instance of BillingDetails.



445
446
447
448
449
450
# File 'lib/stripe/resources/payment_record.rb', line 445

def initialize(address: nil, email: nil, name: nil, phone: nil)
  @address = address
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#addressObject

The billing address associated with the method of payment.



437
438
439
# File 'lib/stripe/resources/payment_record.rb', line 437

def address
  @address
end

#emailObject

The billing email associated with the method of payment.



439
440
441
# File 'lib/stripe/resources/payment_record.rb', line 439

def email
  @email
end

#nameObject

The billing name associated with the method of payment.



441
442
443
# File 'lib/stripe/resources/payment_record.rb', line 441

def name
  @name
end

#phoneObject

The billing phone number associated with the method of payment.



443
444
445
# File 'lib/stripe/resources/payment_record.rb', line 443

def phone
  @phone
end