Class: Stripe::PaymentRecord::ReportPaymentParams::PaymentMethodDetails::BillingDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_record.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails

Returns a new instance of BillingDetails.



516
517
518
519
520
521
# File 'lib/stripe/resources/payment_record.rb', line 516

def initialize(address: nil, email: nil, name: nil, phone: nil)
  @address = address
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#addressObject

The billing address associated with the method of payment.



505
506
507
# File 'lib/stripe/resources/payment_record.rb', line 505

def address
  @address
end

#emailObject

The billing email associated with the method of payment.



508
509
510
# File 'lib/stripe/resources/payment_record.rb', line 508

def email
  @email
end

#nameObject

The billing name associated with the method of payment.



511
512
513
# File 'lib/stripe/resources/payment_record.rb', line 511

def name
  @name
end

#phoneObject

The billing phone number associated with the method of payment.



514
515
516
# File 'lib/stripe/resources/payment_record.rb', line 514

def phone
  @phone
end