Class: Stripe::PaymentRecord::ReportPaymentParams::ProcessorDetails::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecord::ReportPaymentParams::ProcessorDetails::Custom
- Defined in:
- lib/stripe/resources/payment_record.rb
Instance Attribute Summary collapse
-
#payment_reference ⇒ Object
An opaque string for manual reconciliation of this payment, for example a check number or a payment processor ID.
Instance Method Summary collapse
-
#initialize(payment_reference: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
Constructor Details
#initialize(payment_reference: nil) ⇒ Custom
Returns a new instance of Custom.
2325 2326 2327 |
# File 'lib/stripe/resources/payment_record.rb', line 2325 def initialize(payment_reference: nil) @payment_reference = payment_reference end |
Instance Attribute Details
#payment_reference ⇒ Object
An opaque string for manual reconciliation of this payment, for example a check number or a payment processor ID.
2323 2324 2325 |
# File 'lib/stripe/resources/payment_record.rb', line 2323 def payment_reference @payment_reference end |