Class: Stripe::PaymentRecordCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordCreateParams
- Defined in:
- lib/stripe/params/payment_record_create_params.rb
Defined Under Namespace
Classes: Amount, Closed, Funded, ProcessorDetails
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that has been lost to the customer due to disputes on this payment.
-
#closed ⇒ Object
Information about the dispute closing.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#funded ⇒ Object
Information about the dispute funding event.
-
#initiated_at ⇒ Object
When the reported payment was initiated.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#processor_details ⇒ Object
Processor information for this payment.
-
#reason ⇒ Object
The reason the payment was disputed.
Instance Method Summary collapse
-
#initialize(amount: nil, closed: nil, expand: nil, funded: nil, initiated_at: nil, metadata: nil, processor_details: nil, reason: nil) ⇒ PaymentRecordCreateParams
constructor
A new instance of PaymentRecordCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, closed: nil, expand: nil, funded: nil, initiated_at: nil, metadata: nil, processor_details: nil, reason: nil) ⇒ PaymentRecordCreateParams
Returns a new instance of PaymentRecordCreateParams.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/stripe/params/payment_record_create_params.rb', line 89 def initialize( amount: nil, closed: nil, expand: nil, funded: nil, initiated_at: nil, metadata: nil, processor_details: nil, reason: nil ) @amount = amount @closed = closed @expand = @funded = funded @initiated_at = initiated_at @metadata = @processor_details = processor_details @reason = reason end |
Instance Attribute Details
#amount ⇒ Object
The amount that has been lost to the customer due to disputes on this payment.
73 74 75 |
# File 'lib/stripe/params/payment_record_create_params.rb', line 73 def amount @amount end |
#closed ⇒ Object
Information about the dispute closing.
75 76 77 |
# File 'lib/stripe/params/payment_record_create_params.rb', line 75 def closed @closed end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
77 78 79 |
# File 'lib/stripe/params/payment_record_create_params.rb', line 77 def @expand end |
#funded ⇒ Object
Information about the dispute funding event.
79 80 81 |
# File 'lib/stripe/params/payment_record_create_params.rb', line 79 def funded @funded end |
#initiated_at ⇒ Object
When the reported payment was initiated. Measured in seconds since the Unix epoch.
81 82 83 |
# File 'lib/stripe/params/payment_record_create_params.rb', line 81 def initiated_at @initiated_at end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
83 84 85 |
# File 'lib/stripe/params/payment_record_create_params.rb', line 83 def @metadata end |
#processor_details ⇒ Object
Processor information for this payment.
85 86 87 |
# File 'lib/stripe/params/payment_record_create_params.rb', line 85 def processor_details @processor_details end |
#reason ⇒ Object
The reason the payment was disputed.
87 88 89 |
# File 'lib/stripe/params/payment_record_create_params.rb', line 87 def reason @reason end |