Class: Stripe::PaymentRecordReportPaymentAttemptFailedParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_record_report_payment_attempt_failed_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(expand: nil, failed_at: nil, metadata: nil, failure_code: nil) ⇒ PaymentRecordReportPaymentAttemptFailedParams

Returns a new instance of PaymentRecordReportPaymentAttemptFailedParams.



15
16
17
18
19
20
# File 'lib/stripe/params/payment_record_report_payment_attempt_failed_params.rb', line 15

def initialize(expand: nil, failed_at: nil, metadata: nil, failure_code: nil)
  @expand = expand
  @failed_at = failed_at
  @metadata = 
  @failure_code = failure_code
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



7
8
9
# File 'lib/stripe/params/payment_record_report_payment_attempt_failed_params.rb', line 7

def expand
  @expand
end

#failed_atObject

When the reported payment failed. Measured in seconds since the Unix epoch.



9
10
11
# File 'lib/stripe/params/payment_record_report_payment_attempt_failed_params.rb', line 9

def failed_at
  @failed_at
end

#failure_codeObject

The failure code for this payment attempt. Must be one of ‘payment_method_customer_decline` or `payment_method_provider_unknown_outcome`.



13
14
15
# File 'lib/stripe/params/payment_record_report_payment_attempt_failed_params.rb', line 13

def failure_code
  @failure_code
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



11
12
13
# File 'lib/stripe/params/payment_record_report_payment_attempt_failed_params.rb', line 11

def 
  @metadata
end