Class: Stripe::PaymentRecordReportPaymentAttemptGuaranteedParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordReportPaymentAttemptGuaranteedParams
- Defined in:
- lib/stripe/params/payment_record_report_payment_attempt_guaranteed_params.rb
Defined Under Namespace
Classes: PaymentMethodDetails, ProcessorDetails
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#guaranteed_at ⇒ Object
When the reported payment was guaranteed.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#payment_evaluations ⇒ Object
Payment evaluations associated with this reported payment.
-
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
-
#processor_details ⇒ Object
Processor information for this payment.
Instance Method Summary collapse
-
#initialize(expand: nil, guaranteed_at: nil, metadata: nil, payment_evaluations: nil, payment_method_details: nil, processor_details: nil) ⇒ PaymentRecordReportPaymentAttemptGuaranteedParams
constructor
A new instance of PaymentRecordReportPaymentAttemptGuaranteedParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expand: nil, guaranteed_at: nil, metadata: nil, payment_evaluations: nil, payment_method_details: nil, processor_details: nil) ⇒ PaymentRecordReportPaymentAttemptGuaranteedParams
Returns a new instance of PaymentRecordReportPaymentAttemptGuaranteedParams.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_guaranteed_params.rb', line 72 def initialize( expand: nil, guaranteed_at: nil, metadata: nil, payment_evaluations: nil, payment_method_details: nil, processor_details: nil ) @expand = @guaranteed_at = guaranteed_at @metadata = @payment_evaluations = payment_evaluations @payment_method_details = payment_method_details @processor_details = processor_details end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
60 61 62 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_guaranteed_params.rb', line 60 def @expand end |
#guaranteed_at ⇒ Object
When the reported payment was guaranteed. Measured in seconds since the Unix epoch.
62 63 64 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_guaranteed_params.rb', line 62 def guaranteed_at @guaranteed_at end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
64 65 66 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_guaranteed_params.rb', line 64 def @metadata end |
#payment_evaluations ⇒ Object
Payment evaluations associated with this reported payment.
66 67 68 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_guaranteed_params.rb', line 66 def payment_evaluations @payment_evaluations end |
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
68 69 70 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_guaranteed_params.rb', line 68 def payment_method_details @payment_method_details end |
#processor_details ⇒ Object
Processor information for this payment.
70 71 72 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_guaranteed_params.rb', line 70 def processor_details @processor_details end |