Class: Stripe::PaymentRecordReportPaymentAttemptGuaranteedParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordReportPaymentAttemptGuaranteedParams
- Defined in:
- lib/stripe/params/payment_record_report_payment_attempt_guaranteed_params.rb
Defined Under Namespace
Classes: ProcessorDetails
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#guaranteed_at ⇒ Object
When the reported payment was guaranteed.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#processor_details ⇒ Object
Processor information for this payment.
Instance Method Summary collapse
-
#initialize(expand: nil, guaranteed_at: nil, metadata: nil, processor_details: nil) ⇒ PaymentRecordReportPaymentAttemptGuaranteedParams
constructor
A new instance of PaymentRecordReportPaymentAttemptGuaranteedParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expand: nil, guaranteed_at: nil, metadata: nil, processor_details: nil) ⇒ PaymentRecordReportPaymentAttemptGuaranteedParams
Returns a new instance of PaymentRecordReportPaymentAttemptGuaranteedParams.
34 35 36 37 38 39 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_guaranteed_params.rb', line 34 def initialize(expand: nil, guaranteed_at: nil, metadata: nil, processor_details: nil) @expand = @guaranteed_at = guaranteed_at @metadata = @processor_details = processor_details end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
26 27 28 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_guaranteed_params.rb', line 26 def @expand end |
#guaranteed_at ⇒ Object
When the reported payment was guaranteed. Measured in seconds since the Unix epoch.
28 29 30 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_guaranteed_params.rb', line 28 def guaranteed_at @guaranteed_at end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
30 31 32 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_guaranteed_params.rb', line 30 def @metadata end |
#processor_details ⇒ Object
Processor information for this payment.
32 33 34 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_guaranteed_params.rb', line 32 def processor_details @processor_details end |