Class: Stripe::PaymentRecordReportPaymentAttemptParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_record_report_payment_attempt_params.rb

Defined Under Namespace

Classes: Failed, Guaranteed, PaymentMethodDetails, ShippingDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil) ⇒ PaymentRecordReportPaymentAttemptParams

Returns a new instance of PaymentRecordReportPaymentAttemptParams.



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 222

def initialize(
  description: nil,
  expand: nil,
  failed: nil,
  guaranteed: nil,
  initiated_at: nil,
  metadata: nil,
  outcome: nil,
  payment_method_details: nil,
  shipping_details: nil
)
  @description = description
  @expand = expand
  @failed = failed
  @guaranteed = guaranteed
  @initiated_at = initiated_at
  @metadata = 
  @outcome = outcome
  @payment_method_details = payment_method_details
  @shipping_details = shipping_details
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



204
205
206
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 204

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



206
207
208
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 206

def expand
  @expand
end

#failedObject

Information about the payment attempt failure.



208
209
210
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 208

def failed
  @failed
end

#guaranteedObject

Information about the payment attempt guarantee.



210
211
212
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 210

def guaranteed
  @guaranteed
end

#initiated_atObject

When the reported payment was initiated. Measured in seconds since the Unix epoch.



212
213
214
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 212

def initiated_at
  @initiated_at
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



214
215
216
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 214

def 
  @metadata
end

#outcomeObject

The outcome of the reported payment.



216
217
218
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 216

def outcome
  @outcome
end

#payment_method_detailsObject

Information about the Payment Method debited for this payment.



218
219
220
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 218

def payment_method_details
  @payment_method_details
end

#shipping_detailsObject

Shipping information for this payment.



220
221
222
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 220

def shipping_details
  @shipping_details
end