Class: Stripe::PaymentRecordReportPaymentAttemptParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordReportPaymentAttemptParams
- Defined in:
- lib/stripe/params/payment_record_report_payment_attempt_params.rb
Defined Under Namespace
Classes: Failed, Guaranteed, PaymentMethodDetails, ShippingDetails
Instance Attribute Summary collapse
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failed ⇒ Object
Information about the payment attempt failure.
-
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
-
#initiated_at ⇒ Object
When the reported payment was initiated.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#outcome ⇒ Object
The outcome of the reported payment.
-
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
-
#shipping_details ⇒ Object
Shipping information for this payment.
Instance Method Summary collapse
-
#initialize(description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil) ⇒ PaymentRecordReportPaymentAttemptParams
constructor
A new instance of PaymentRecordReportPaymentAttemptParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil) ⇒ PaymentRecordReportPaymentAttemptParams
Returns a new instance of PaymentRecordReportPaymentAttemptParams.
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 222 def initialize( description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil ) @description = description @expand = @failed = failed @guaranteed = guaranteed @initiated_at = initiated_at @metadata = @outcome = outcome @payment_method_details = payment_method_details @shipping_details = shipping_details end |
Instance Attribute Details
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
204 205 206 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 204 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
206 207 208 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 206 def @expand end |
#failed ⇒ Object
Information about the payment attempt failure.
208 209 210 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 208 def failed @failed end |
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
210 211 212 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 210 def guaranteed @guaranteed end |
#initiated_at ⇒ Object
When the reported payment was initiated. Measured in seconds since the Unix epoch.
212 213 214 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 212 def initiated_at @initiated_at end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
214 215 216 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 214 def @metadata end |
#outcome ⇒ Object
The outcome of the reported payment.
216 217 218 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 216 def outcome @outcome end |
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
218 219 220 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 218 def payment_method_details @payment_method_details end |
#shipping_details ⇒ Object
Shipping information for this payment.
220 221 222 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 220 def shipping_details @shipping_details end |