Class: Stripe::PaymentRecordReportPaymentAttemptParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordReportPaymentAttemptParams
- Defined in:
- lib/stripe/params/payment_record_report_payment_attempt_params.rb
Defined Under Namespace
Classes: Failed, Guaranteed, PaymentMethodDetails, ShippingDetails
Instance Attribute Summary collapse
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failed ⇒ Object
Information about the payment attempt failure.
-
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
-
#initiated_at ⇒ Object
When the reported payment was initiated.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#outcome ⇒ Object
The outcome of the reported payment.
-
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
-
#shipping_details ⇒ Object
Shipping information for this payment.
Instance Method Summary collapse
-
#initialize(description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil) ⇒ PaymentRecordReportPaymentAttemptParams
constructor
A new instance of PaymentRecordReportPaymentAttemptParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil) ⇒ PaymentRecordReportPaymentAttemptParams
Returns a new instance of PaymentRecordReportPaymentAttemptParams.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 167 def initialize( description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, shipping_details: nil ) @description = description @expand = @failed = failed @guaranteed = guaranteed @initiated_at = initiated_at @metadata = @outcome = outcome @payment_method_details = payment_method_details @shipping_details = shipping_details end |
Instance Attribute Details
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
149 150 151 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 149 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
151 152 153 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 151 def @expand end |
#failed ⇒ Object
Information about the payment attempt failure.
153 154 155 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 153 def failed @failed end |
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
155 156 157 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 155 def guaranteed @guaranteed end |
#initiated_at ⇒ Object
When the reported payment was initiated. Measured in seconds since the Unix epoch.
157 158 159 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 157 def initiated_at @initiated_at end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
159 160 161 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 159 def @metadata end |
#outcome ⇒ Object
The outcome of the reported payment.
161 162 163 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 161 def outcome @outcome end |
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
163 164 165 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 163 def payment_method_details @payment_method_details end |
#shipping_details ⇒ Object
Shipping information for this payment.
165 166 167 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 165 def shipping_details @shipping_details end |