Class: Stripe::PaymentRecordReportPaymentAttemptParams::PaymentMethodDetails::BillingDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_record_report_payment_attempt_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails

Returns a new instance of BillingDetails.



115
116
117
118
119
120
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 115

def initialize(address: nil, email: nil, name: nil, phone: nil)
  @address = address
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#addressObject

The billing address associated with the method of payment.



107
108
109
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 107

def address
  @address
end

#emailObject

The billing email associated with the method of payment.



109
110
111
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 109

def email
  @email
end

#nameObject

The billing name associated with the method of payment.



111
112
113
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 111

def name
  @name
end

#phoneObject

The billing phone number associated with the method of payment.



113
114
115
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 113

def phone
  @phone
end