Class: Stripe::PaymentRecordReportPaymentAttemptParams::PaymentMethodDetails::BillingDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordReportPaymentAttemptParams::PaymentMethodDetails::BillingDetails
- Defined in:
- lib/stripe/params/payment_record_report_payment_attempt_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
The billing address associated with the method of payment.
-
#email ⇒ Object
The billing email associated with the method of payment.
-
#name ⇒ Object
The billing name associated with the method of payment.
-
#phone ⇒ Object
The billing phone number associated with the method of payment.
Instance Method Summary collapse
-
#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails
constructor
A new instance of BillingDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails
Returns a new instance of BillingDetails.
112 113 114 115 116 117 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 112 def initialize(address: nil, email: nil, name: nil, phone: nil) @address = address @email = email @name = name @phone = phone end |
Instance Attribute Details
#address ⇒ Object
The billing address associated with the method of payment.
104 105 106 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 104 def address @address end |
#email ⇒ Object
The billing email associated with the method of payment.
106 107 108 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 106 def email @email end |
#name ⇒ Object
The billing name associated with the method of payment.
108 109 110 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 108 def name @name end |
#phone ⇒ Object
The billing phone number associated with the method of payment.
110 111 112 |
# File 'lib/stripe/params/payment_record_report_payment_attempt_params.rb', line 110 def phone @phone end |