Class: Stripe::PaymentRecordReportPaymentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordReportPaymentParams
- Defined in:
- lib/stripe/params/payment_record_report_payment_params.rb
Defined Under Namespace
Classes: AmountRequested, CustomerDetails, Failed, Guaranteed, PaymentMethodDetails, ProcessorDetails, ShippingDetails
Instance Attribute Summary collapse
-
#amount_requested ⇒ Object
The amount you initially requested for this payment.
-
#customer_details ⇒ Object
Customer information for this payment.
-
#customer_presence ⇒ Object
Indicates whether the customer was present in your checkout flow during this payment.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failed ⇒ Object
Information about the payment attempt failure.
-
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
-
#initiated_at ⇒ Object
When the reported payment was initiated.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#outcome ⇒ Object
The outcome of the reported payment.
-
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
-
#processor_details ⇒ Object
Processor information for this payment.
-
#shipping_details ⇒ Object
Shipping information for this payment.
Instance Method Summary collapse
-
#initialize(amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, processor_details: nil, shipping_details: nil) ⇒ PaymentRecordReportPaymentParams
constructor
A new instance of PaymentRecordReportPaymentParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, processor_details: nil, shipping_details: nil) ⇒ PaymentRecordReportPaymentParams
Returns a new instance of PaymentRecordReportPaymentParams.
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 306 def initialize( amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, processor_details: nil, shipping_details: nil ) @amount_requested = amount_requested @customer_details = customer_details @customer_presence = customer_presence @description = description @expand = @failed = failed @guaranteed = guaranteed @initiated_at = initiated_at @metadata = @outcome = outcome @payment_method_details = payment_method_details @processor_details = processor_details @shipping_details = shipping_details end |
Instance Attribute Details
#amount_requested ⇒ Object
The amount you initially requested for this payment.
280 281 282 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 280 def amount_requested @amount_requested end |
#customer_details ⇒ Object
Customer information for this payment.
282 283 284 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 282 def customer_details @customer_details end |
#customer_presence ⇒ Object
Indicates whether the customer was present in your checkout flow during this payment.
284 285 286 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 284 def customer_presence @customer_presence end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
286 287 288 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 286 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
288 289 290 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 288 def @expand end |
#failed ⇒ Object
Information about the payment attempt failure.
290 291 292 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 290 def failed @failed end |
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
292 293 294 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 292 def guaranteed @guaranteed end |
#initiated_at ⇒ Object
When the reported payment was initiated. Measured in seconds since the Unix epoch.
294 295 296 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 294 def initiated_at @initiated_at end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
296 297 298 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 296 def @metadata end |
#outcome ⇒ Object
The outcome of the reported payment.
298 299 300 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 298 def outcome @outcome end |
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
300 301 302 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 300 def payment_method_details @payment_method_details end |
#processor_details ⇒ Object
Processor information for this payment.
302 303 304 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 302 def processor_details @processor_details end |
#shipping_details ⇒ Object
Shipping information for this payment.
304 305 306 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 304 def shipping_details @shipping_details end |