Class: Stripe::PaymentRecordReportPaymentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordReportPaymentParams
- Defined in:
- lib/stripe/params/payment_record_report_payment_params.rb
Defined Under Namespace
Classes: AmountRequested, CustomerDetails, Failed, Guaranteed, PaymentMethodDetails, ProcessorDetails, ShippingDetails
Instance Attribute Summary collapse
-
#amount_requested ⇒ Object
The amount you initially requested for this payment.
-
#customer_details ⇒ Object
Customer information for this payment.
-
#customer_presence ⇒ Object
Indicates whether the customer was present in your checkout flow during this payment.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failed ⇒ Object
Information about the payment attempt failure.
-
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
-
#initiated_at ⇒ Object
When the reported payment was initiated.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#outcome ⇒ Object
The outcome of the reported payment.
-
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
-
#processor_details ⇒ Object
Processor information for this payment.
-
#shipping_details ⇒ Object
Shipping information for this payment.
Instance Method Summary collapse
-
#initialize(amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, processor_details: nil, shipping_details: nil) ⇒ PaymentRecordReportPaymentParams
constructor
A new instance of PaymentRecordReportPaymentParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, processor_details: nil, shipping_details: nil) ⇒ PaymentRecordReportPaymentParams
Returns a new instance of PaymentRecordReportPaymentParams.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 272 def initialize( amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, processor_details: nil, shipping_details: nil ) @amount_requested = amount_requested @customer_details = customer_details @customer_presence = customer_presence @description = description @expand = @failed = failed @guaranteed = guaranteed @initiated_at = initiated_at @metadata = @outcome = outcome @payment_method_details = payment_method_details @processor_details = processor_details @shipping_details = shipping_details end |
Instance Attribute Details
#amount_requested ⇒ Object
The amount you initially requested for this payment.
246 247 248 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 246 def amount_requested @amount_requested end |
#customer_details ⇒ Object
Customer information for this payment.
248 249 250 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 248 def customer_details @customer_details end |
#customer_presence ⇒ Object
Indicates whether the customer was present in your checkout flow during this payment.
250 251 252 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 250 def customer_presence @customer_presence end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
252 253 254 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 252 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
254 255 256 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 254 def @expand end |
#failed ⇒ Object
Information about the payment attempt failure.
256 257 258 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 256 def failed @failed end |
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
258 259 260 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 258 def guaranteed @guaranteed end |
#initiated_at ⇒ Object
When the reported payment was initiated. Measured in seconds since the Unix epoch.
260 261 262 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 260 def initiated_at @initiated_at end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
262 263 264 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 262 def @metadata end |
#outcome ⇒ Object
The outcome of the reported payment.
264 265 266 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 264 def outcome @outcome end |
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
266 267 268 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 266 def payment_method_details @payment_method_details end |
#processor_details ⇒ Object
Processor information for this payment.
268 269 270 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 268 def processor_details @processor_details end |
#shipping_details ⇒ Object
Shipping information for this payment.
270 271 272 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 270 def shipping_details @shipping_details end |