Class: Stripe::PaymentRecordReportPaymentParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/payment_record_report_payment_params.rb

Defined Under Namespace

Classes: AmountRequested, CustomerDetails, Failed, Guaranteed, PaymentMethodDetails, ProcessorDetails, ShippingDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, processor_details: nil, shipping_details: nil) ⇒ PaymentRecordReportPaymentParams

Returns a new instance of PaymentRecordReportPaymentParams.



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 269

def initialize(
  amount_requested: nil,
  customer_details: nil,
  customer_presence: nil,
  description: nil,
  expand: nil,
  failed: nil,
  guaranteed: nil,
  initiated_at: nil,
  metadata: nil,
  outcome: nil,
  payment_method_details: nil,
  processor_details: nil,
  shipping_details: nil
)
  @amount_requested = amount_requested
  @customer_details = customer_details
  @customer_presence = customer_presence
  @description = description
  @expand = expand
  @failed = failed
  @guaranteed = guaranteed
  @initiated_at = initiated_at
  @metadata = 
  @outcome = outcome
  @payment_method_details = payment_method_details
  @processor_details = processor_details
  @shipping_details = shipping_details
end

Instance Attribute Details

#amount_requestedObject

The amount you initially requested for this payment.



243
244
245
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 243

def amount_requested
  @amount_requested
end

#customer_detailsObject

Customer information for this payment.



245
246
247
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 245

def customer_details
  @customer_details
end

#customer_presenceObject

Indicates whether the customer was present in your checkout flow during this payment.



247
248
249
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 247

def customer_presence
  @customer_presence
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



249
250
251
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 249

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



251
252
253
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 251

def expand
  @expand
end

#failedObject

Information about the payment attempt failure.



253
254
255
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 253

def failed
  @failed
end

#guaranteedObject

Information about the payment attempt guarantee.



255
256
257
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 255

def guaranteed
  @guaranteed
end

#initiated_atObject

When the reported payment was initiated. Measured in seconds since the Unix epoch.



257
258
259
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 257

def initiated_at
  @initiated_at
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



259
260
261
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 259

def 
  @metadata
end

#outcomeObject

The outcome of the reported payment.



261
262
263
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 261

def outcome
  @outcome
end

#payment_method_detailsObject

Information about the Payment Method debited for this payment.



263
264
265
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 263

def payment_method_details
  @payment_method_details
end

#processor_detailsObject

Processor information for this payment.



265
266
267
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 265

def processor_details
  @processor_details
end

#shipping_detailsObject

Shipping information for this payment.



267
268
269
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 267

def shipping_details
  @shipping_details
end