Class: Stripe::PaymentRecordReportPaymentParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/payment_record_report_payment_params.rb

Defined Under Namespace

Classes: AmountRequested, CustomerDetails, Failed, Guaranteed, PaymentMethodDetails, ProcessorDetails, ShippingDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, processor_details: nil, shipping_details: nil) ⇒ PaymentRecordReportPaymentParams

Returns a new instance of PaymentRecordReportPaymentParams.



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 225

def initialize(
  amount_requested: nil,
  customer_details: nil,
  customer_presence: nil,
  description: nil,
  expand: nil,
  failed: nil,
  guaranteed: nil,
  initiated_at: nil,
  metadata: nil,
  outcome: nil,
  payment_method_details: nil,
  processor_details: nil,
  shipping_details: nil
)
  @amount_requested = amount_requested
  @customer_details = customer_details
  @customer_presence = customer_presence
  @description = description
  @expand = expand
  @failed = failed
  @guaranteed = guaranteed
  @initiated_at = initiated_at
  @metadata = 
  @outcome = outcome
  @payment_method_details = payment_method_details
  @processor_details = processor_details
  @shipping_details = shipping_details
end

Instance Attribute Details

#amount_requestedObject

The amount you initially requested for this payment.



199
200
201
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 199

def amount_requested
  @amount_requested
end

#customer_detailsObject

Customer information for this payment.



201
202
203
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 201

def customer_details
  @customer_details
end

#customer_presenceObject

Indicates whether the customer was present in your checkout flow during this payment.



203
204
205
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 203

def customer_presence
  @customer_presence
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



205
206
207
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 205

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



207
208
209
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 207

def expand
  @expand
end

#failedObject

Information about the payment attempt failure.



209
210
211
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 209

def failed
  @failed
end

#guaranteedObject

Information about the payment attempt guarantee.



211
212
213
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 211

def guaranteed
  @guaranteed
end

#initiated_atObject

When the reported payment was initiated. Measured in seconds since the Unix epoch.



213
214
215
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 213

def initiated_at
  @initiated_at
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



215
216
217
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 215

def 
  @metadata
end

#outcomeObject

The outcome of the reported payment.



217
218
219
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 217

def outcome
  @outcome
end

#payment_method_detailsObject

Information about the Payment Method debited for this payment.



219
220
221
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 219

def payment_method_details
  @payment_method_details
end

#processor_detailsObject

Processor information for this payment.



221
222
223
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 221

def processor_details
  @processor_details
end

#shipping_detailsObject

Shipping information for this payment.



223
224
225
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 223

def shipping_details
  @shipping_details
end