Class: Stripe::PaymentRecordReportPaymentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordReportPaymentParams
- Defined in:
- lib/stripe/params/payment_record_report_payment_params.rb
Defined Under Namespace
Classes: AmountRequested, CustomerDetails, Failed, Guaranteed, PaymentMethodDetails, ProcessorDetails, ShippingDetails
Instance Attribute Summary collapse
-
#amount_requested ⇒ Object
The amount you initially requested for this payment.
-
#customer_details ⇒ Object
Customer information for this payment.
-
#customer_presence ⇒ Object
Indicates whether the customer was present in your checkout flow during this payment.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failed ⇒ Object
Information about the payment attempt failure.
-
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
-
#initiated_at ⇒ Object
When the reported payment was initiated.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#outcome ⇒ Object
The outcome of the reported payment.
-
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
-
#processor_details ⇒ Object
Processor information for this payment.
-
#shipping_details ⇒ Object
Shipping information for this payment.
Instance Method Summary collapse
-
#initialize(amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, processor_details: nil, shipping_details: nil) ⇒ PaymentRecordReportPaymentParams
constructor
A new instance of PaymentRecordReportPaymentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, processor_details: nil, shipping_details: nil) ⇒ PaymentRecordReportPaymentParams
Returns a new instance of PaymentRecordReportPaymentParams.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 225 def initialize( amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, processor_details: nil, shipping_details: nil ) @amount_requested = amount_requested @customer_details = customer_details @customer_presence = customer_presence @description = description @expand = @failed = failed @guaranteed = guaranteed @initiated_at = initiated_at @metadata = @outcome = outcome @payment_method_details = payment_method_details @processor_details = processor_details @shipping_details = shipping_details end |
Instance Attribute Details
#amount_requested ⇒ Object
The amount you initially requested for this payment.
199 200 201 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 199 def amount_requested @amount_requested end |
#customer_details ⇒ Object
Customer information for this payment.
201 202 203 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 201 def customer_details @customer_details end |
#customer_presence ⇒ Object
Indicates whether the customer was present in your checkout flow during this payment.
203 204 205 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 203 def customer_presence @customer_presence end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
205 206 207 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 205 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
207 208 209 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 207 def @expand end |
#failed ⇒ Object
Information about the payment attempt failure.
209 210 211 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 209 def failed @failed end |
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
211 212 213 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 211 def guaranteed @guaranteed end |
#initiated_at ⇒ Object
When the reported payment was initiated. Measured in seconds since the Unix epoch.
213 214 215 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 213 def initiated_at @initiated_at end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
215 216 217 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 215 def @metadata end |
#outcome ⇒ Object
The outcome of the reported payment.
217 218 219 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 217 def outcome @outcome end |
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
219 220 221 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 219 def payment_method_details @payment_method_details end |
#processor_details ⇒ Object
Processor information for this payment.
221 222 223 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 221 def processor_details @processor_details end |
#shipping_details ⇒ Object
Shipping information for this payment.
223 224 225 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 223 def shipping_details @shipping_details end |