Class: Stripe::PaymentRecordReportPaymentParams::PaymentMethodDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_record_report_payment_params.rb

Defined Under Namespace

Classes: BillingDetails, Custom

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil) ⇒ PaymentMethodDetails

Returns a new instance of PaymentMethodDetails.



181
182
183
184
185
186
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 181

def initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil)
  @billing_details = billing_details
  @custom = custom
  @payment_method = payment_method
  @type = type
end

Instance Attribute Details

#billing_detailsObject

The billing details associated with the method of payment.



173
174
175
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 173

def billing_details
  @billing_details
end

#customObject

Information about the custom (user-defined) payment method used to make this payment.



175
176
177
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 175

def custom
  @custom
end

#payment_methodObject

ID of the Stripe Payment Method used to make this payment.



177
178
179
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 177

def payment_method
  @payment_method
end

#typeObject

The type of the payment method details. An additional hash is included on the payment_method_details with a name matching this value. It contains additional information specific to the type.



179
180
181
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 179

def type
  @type
end