Class: Stripe::PaymentRecordReportPaymentParams::PaymentMethodDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordReportPaymentParams::PaymentMethodDetails
- Defined in:
- lib/stripe/params/payment_record_report_payment_params.rb
Defined Under Namespace
Classes: BillingDetails, Custom
Instance Attribute Summary collapse
-
#billing_details ⇒ Object
The billing details associated with the method of payment.
-
#custom ⇒ Object
Information about the custom (user-defined) payment method used to make this payment.
-
#payment_method ⇒ Object
ID of the Stripe Payment Method used to make this payment.
-
#type ⇒ Object
The type of the payment method details.
Instance Method Summary collapse
-
#initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil) ⇒ PaymentMethodDetails
constructor
A new instance of PaymentMethodDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil) ⇒ PaymentMethodDetails
Returns a new instance of PaymentMethodDetails.
173 174 175 176 177 178 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 173 def initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil) @billing_details = billing_details @custom = custom @payment_method = payment_method @type = type end |
Instance Attribute Details
#billing_details ⇒ Object
The billing details associated with the method of payment.
165 166 167 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 165 def billing_details @billing_details end |
#custom ⇒ Object
Information about the custom (user-defined) payment method used to make this payment.
167 168 169 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 167 def custom @custom end |
#payment_method ⇒ Object
ID of the Stripe Payment Method used to make this payment.
169 170 171 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 169 def payment_method @payment_method end |
#type ⇒ Object
The type of the payment method details. An additional hash is included on the payment_method_details with a name matching this value. It contains additional information specific to the type.
171 172 173 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 171 def type @type end |