Class: Stripe::PaymentRecordReportPaymentParams::PaymentMethodDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_record_report_payment_params.rb

Defined Under Namespace

Classes: BillingDetails, Custom

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil) ⇒ PaymentMethodDetails

Returns a new instance of PaymentMethodDetails.



126
127
128
129
130
131
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 126

def initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil)
  @billing_details = billing_details
  @custom = custom
  @payment_method = payment_method
  @type = type
end

Instance Attribute Details

#billing_detailsObject

The billing details associated with the method of payment.



118
119
120
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 118

def billing_details
  @billing_details
end

#customObject

Information about the custom (user-defined) payment method used to make this payment.



120
121
122
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 120

def custom
  @custom
end

#payment_methodObject

ID of the Stripe Payment Method used to make this payment.



122
123
124
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 122

def payment_method
  @payment_method
end

#typeObject

The type of the payment method details. An additional hash is included on the payment_method_details with a name matching this value. It contains additional information specific to the type.



124
125
126
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 124

def type
  @type
end