Class: Stripe::PaymentRecordReportPaymentParams::PaymentMethodDetails::BillingDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordReportPaymentParams::PaymentMethodDetails::BillingDetails
- Defined in:
- lib/stripe/params/payment_record_report_payment_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
The billing address associated with the method of payment.
-
#email ⇒ Object
The billing email associated with the method of payment.
-
#name ⇒ Object
The billing name associated with the method of payment.
-
#phone ⇒ Object
The billing phone number associated with the method of payment.
Instance Method Summary collapse
-
#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails
constructor
A new instance of BillingDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails
Returns a new instance of BillingDetails.
145 146 147 148 149 150 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 145 def initialize(address: nil, email: nil, name: nil, phone: nil) @address = address @email = email @name = name @phone = phone end |
Instance Attribute Details
#address ⇒ Object
The billing address associated with the method of payment.
137 138 139 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 137 def address @address end |
#email ⇒ Object
The billing email associated with the method of payment.
139 140 141 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 139 def email @email end |
#name ⇒ Object
The billing name associated with the method of payment.
141 142 143 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 141 def name @name end |
#phone ⇒ Object
The billing phone number associated with the method of payment.
143 144 145 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 143 def phone @phone end |