Class: Stripe::PaymentRecordReportPaymentParams::PaymentMethodDetails::BillingDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_record_report_payment_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails

Returns a new instance of BillingDetails.



98
99
100
101
102
103
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 98

def initialize(address: nil, email: nil, name: nil, phone: nil)
  @address = address
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#addressObject

The billing address associated with the method of payment.



90
91
92
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 90

def address
  @address
end

#emailObject

The billing email associated with the method of payment.



92
93
94
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 92

def email
  @email
end

#nameObject

The billing name associated with the method of payment.



94
95
96
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 94

def name
  @name
end

#phoneObject

The billing phone number associated with the method of payment.



96
97
98
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 96

def phone
  @phone
end