Class: Stripe::PaymentRecordReportPaymentParams::PaymentMethodDetails::BillingDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordReportPaymentParams::PaymentMethodDetails::BillingDetails
- Defined in:
- lib/stripe/params/payment_record_report_payment_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
The billing address associated with the method of payment.
-
#email ⇒ Object
The billing email associated with the method of payment.
-
#name ⇒ Object
The billing name associated with the method of payment.
-
#phone ⇒ Object
The billing phone number associated with the method of payment.
Instance Method Summary collapse
-
#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails
constructor
A new instance of BillingDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails
Returns a new instance of BillingDetails.
142 143 144 145 146 147 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 142 def initialize(address: nil, email: nil, name: nil, phone: nil) @address = address @email = email @name = name @phone = phone end |
Instance Attribute Details
#address ⇒ Object
The billing address associated with the method of payment.
134 135 136 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 134 def address @address end |
#email ⇒ Object
The billing email associated with the method of payment.
136 137 138 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 136 def email @email end |
#name ⇒ Object
The billing name associated with the method of payment.
138 139 140 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 138 def name @name end |
#phone ⇒ Object
The billing phone number associated with the method of payment.
140 141 142 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 140 def phone @phone end |