Class: Stripe::PaymentRecordReportPaymentParams::PaymentMethodDetails::BillingDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordReportPaymentParams::PaymentMethodDetails::BillingDetails
- Defined in:
- lib/stripe/params/payment_record_report_payment_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
The billing address associated with the method of payment.
-
#email ⇒ Object
The billing email associated with the method of payment.
-
#name ⇒ Object
The billing name associated with the method of payment.
-
#phone ⇒ Object
The billing phone number associated with the method of payment.
Instance Method Summary collapse
-
#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails
constructor
A new instance of BillingDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails
Returns a new instance of BillingDetails.
98 99 100 101 102 103 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 98 def initialize(address: nil, email: nil, name: nil, phone: nil) @address = address @email = email @name = name @phone = phone end |
Instance Attribute Details
#address ⇒ Object
The billing address associated with the method of payment.
90 91 92 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 90 def address @address end |
#email ⇒ Object
The billing email associated with the method of payment.
92 93 94 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 92 def email @email end |
#name ⇒ Object
The billing name associated with the method of payment.
94 95 96 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 94 def name @name end |
#phone ⇒ Object
The billing phone number associated with the method of payment.
96 97 98 |
# File 'lib/stripe/params/payment_record_report_payment_params.rb', line 96 def phone @phone end |