Class: Stripe::PaymentRecordService::ReportPaymentAttemptCanceledParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordService::ReportPaymentAttemptCanceledParams
- Defined in:
- lib/stripe/services/payment_record_service.rb
Instance Attribute Summary collapse
-
#canceled_at ⇒ Object
When the reported payment was canceled.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Attribute for param field metadata.
Instance Method Summary collapse
-
#initialize(canceled_at: nil, expand: nil, metadata: nil) ⇒ ReportPaymentAttemptCanceledParams
constructor
A new instance of ReportPaymentAttemptCanceledParams.
Methods inherited from RequestParams
Constructor Details
#initialize(canceled_at: nil, expand: nil, metadata: nil) ⇒ ReportPaymentAttemptCanceledParams
Returns a new instance of ReportPaymentAttemptCanceledParams.
234 235 236 237 238 |
# File 'lib/stripe/services/payment_record_service.rb', line 234 def initialize(canceled_at: nil, expand: nil, metadata: nil) @canceled_at = canceled_at @expand = @metadata = end |
Instance Attribute Details
#canceled_at ⇒ Object
When the reported payment was canceled. Measured in seconds since the Unix epoch.
226 227 228 |
# File 'lib/stripe/services/payment_record_service.rb', line 226 def canceled_at @canceled_at end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
229 230 231 |
# File 'lib/stripe/services/payment_record_service.rb', line 229 def @expand end |
#metadata ⇒ Object
Attribute for param field metadata
232 233 234 |
# File 'lib/stripe/services/payment_record_service.rb', line 232 def @metadata end |