Class: Stripe::PaymentRecordService::ReportPaymentAttemptFailedParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordService::ReportPaymentAttemptFailedParams
- Defined in:
- lib/stripe/services/payment_record_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failed_at ⇒ Object
When the reported payment failed.
-
#metadata ⇒ Object
Attribute for param field metadata.
Instance Method Summary collapse
-
#initialize(expand: nil, failed_at: nil, metadata: nil) ⇒ ReportPaymentAttemptFailedParams
constructor
A new instance of ReportPaymentAttemptFailedParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, failed_at: nil, metadata: nil) ⇒ ReportPaymentAttemptFailedParams
Returns a new instance of ReportPaymentAttemptFailedParams.
251 252 253 254 255 |
# File 'lib/stripe/services/payment_record_service.rb', line 251 def initialize(expand: nil, failed_at: nil, metadata: nil) @expand = @failed_at = failed_at @metadata = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
243 244 245 |
# File 'lib/stripe/services/payment_record_service.rb', line 243 def @expand end |
#failed_at ⇒ Object
When the reported payment failed. Measured in seconds since the Unix epoch.
246 247 248 |
# File 'lib/stripe/services/payment_record_service.rb', line 246 def failed_at @failed_at end |
#metadata ⇒ Object
Attribute for param field metadata
249 250 251 |
# File 'lib/stripe/services/payment_record_service.rb', line 249 def @metadata end |