Class: Stripe::PaymentRecordService::ReportPaymentAttemptParams::PaymentMethodDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_record_service.rb

Defined Under Namespace

Classes: BillingDetails, Custom

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil) ⇒ PaymentMethodDetails

Returns a new instance of PaymentMethodDetails.



103
104
105
106
107
108
# File 'lib/stripe/services/payment_record_service.rb', line 103

def initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil)
  @billing_details = billing_details
  @custom = custom
  @payment_method = payment_method
  @type = type
end

Instance Attribute Details

#billing_detailsObject

The billing details associated with the method of payment.



95
96
97
# File 'lib/stripe/services/payment_record_service.rb', line 95

def billing_details
  @billing_details
end

#customObject

Information about the custom (user-defined) payment method used to make this payment.



97
98
99
# File 'lib/stripe/services/payment_record_service.rb', line 97

def custom
  @custom
end

#payment_methodObject

ID of the Stripe Payment Method used to make this payment.



99
100
101
# File 'lib/stripe/services/payment_record_service.rb', line 99

def payment_method
  @payment_method
end

#typeObject

The type of the payment method details. An additional hash is included on the payment_method_details with a name matching this value. It contains additional information specific to the type.



101
102
103
# File 'lib/stripe/services/payment_record_service.rb', line 101

def type
  @type
end