Class: Stripe::PaymentRecordService::ReportPaymentAttemptParams::PaymentMethodDetails::BillingDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_record_service.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails

Returns a new instance of BillingDetails.



75
76
77
78
79
80
# File 'lib/stripe/services/payment_record_service.rb', line 75

def initialize(address: nil, email: nil, name: nil, phone: nil)
  @address = address
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#addressObject

The billing address associated with the method of payment.



67
68
69
# File 'lib/stripe/services/payment_record_service.rb', line 67

def address
  @address
end

#emailObject

The billing email associated with the method of payment.



69
70
71
# File 'lib/stripe/services/payment_record_service.rb', line 69

def email
  @email
end

#nameObject

The billing name associated with the method of payment.



71
72
73
# File 'lib/stripe/services/payment_record_service.rb', line 71

def name
  @name
end

#phoneObject

The billing phone number associated with the method of payment.



73
74
75
# File 'lib/stripe/services/payment_record_service.rb', line 73

def phone
  @phone
end