Class: Stripe::PaymentRecordService::ReportPaymentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordService::ReportPaymentParams
- Defined in:
- lib/stripe/services/payment_record_service.rb
Defined Under Namespace
Classes: AmountRequested, CustomerDetails, Failed, Guaranteed, PaymentMethodDetails, ShippingDetails
Instance Attribute Summary collapse
-
#amount_requested ⇒ Object
The amount you intend to collect for this payment.
-
#customer_details ⇒ Object
Customer information for this payment.
-
#customer_presence ⇒ Object
Indicates whether the customer was present in your checkout flow during this payment.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failed ⇒ Object
Information about the payment attempt failure.
-
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
-
#initiated_at ⇒ Object
When the reported payment was initiated.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#outcome ⇒ Object
The outcome of the reported payment.
-
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
-
#payment_reference ⇒ Object
An opaque string for manual reconciliation of this payment, for example a check number or a payment processor ID.
-
#shipping_details ⇒ Object
Shipping information for this payment.
Instance Method Summary collapse
-
#initialize(amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, payment_reference: nil, shipping_details: nil) ⇒ ReportPaymentParams
constructor
A new instance of ReportPaymentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, payment_reference: nil, shipping_details: nil) ⇒ ReportPaymentParams
Returns a new instance of ReportPaymentParams.
439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/stripe/services/payment_record_service.rb', line 439 def initialize( amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, payment_reference: nil, shipping_details: nil ) @amount_requested = amount_requested @customer_details = customer_details @customer_presence = customer_presence @description = description @expand = @failed = failed @guaranteed = guaranteed @initiated_at = initiated_at @metadata = @outcome = outcome @payment_method_details = payment_method_details @payment_reference = payment_reference @shipping_details = shipping_details end |
Instance Attribute Details
#amount_requested ⇒ Object
The amount you intend to collect for this payment.
413 414 415 |
# File 'lib/stripe/services/payment_record_service.rb', line 413 def amount_requested @amount_requested end |
#customer_details ⇒ Object
Customer information for this payment.
415 416 417 |
# File 'lib/stripe/services/payment_record_service.rb', line 415 def customer_details @customer_details end |
#customer_presence ⇒ Object
Indicates whether the customer was present in your checkout flow during this payment.
417 418 419 |
# File 'lib/stripe/services/payment_record_service.rb', line 417 def customer_presence @customer_presence end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
419 420 421 |
# File 'lib/stripe/services/payment_record_service.rb', line 419 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
421 422 423 |
# File 'lib/stripe/services/payment_record_service.rb', line 421 def @expand end |
#failed ⇒ Object
Information about the payment attempt failure.
423 424 425 |
# File 'lib/stripe/services/payment_record_service.rb', line 423 def failed @failed end |
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
425 426 427 |
# File 'lib/stripe/services/payment_record_service.rb', line 425 def guaranteed @guaranteed end |
#initiated_at ⇒ Object
When the reported payment was initiated. Measured in seconds since the Unix epoch.
427 428 429 |
# File 'lib/stripe/services/payment_record_service.rb', line 427 def initiated_at @initiated_at end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
429 430 431 |
# File 'lib/stripe/services/payment_record_service.rb', line 429 def @metadata end |
#outcome ⇒ Object
The outcome of the reported payment.
431 432 433 |
# File 'lib/stripe/services/payment_record_service.rb', line 431 def outcome @outcome end |
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
433 434 435 |
# File 'lib/stripe/services/payment_record_service.rb', line 433 def payment_method_details @payment_method_details end |
#payment_reference ⇒ Object
An opaque string for manual reconciliation of this payment, for example a check number or a payment processor ID.
435 436 437 |
# File 'lib/stripe/services/payment_record_service.rb', line 435 def payment_reference @payment_reference end |
#shipping_details ⇒ Object
Shipping information for this payment.
437 438 439 |
# File 'lib/stripe/services/payment_record_service.rb', line 437 def shipping_details @shipping_details end |