Class: Stripe::PaymentRecordService::ReportPaymentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordService::ReportPaymentParams
- Defined in:
- lib/stripe/services/payment_record_service.rb
Defined Under Namespace
Classes: AmountRequested, CustomerDetails, Failed, Guaranteed, PaymentMethodDetails, ShippingDetails
Instance Attribute Summary collapse
-
#amount_requested ⇒ Object
The amount you intend to collect for this payment.
-
#customer_details ⇒ Object
Customer information for this payment.
-
#customer_presence ⇒ Object
Indicates whether the customer was present in your checkout flow during this payment.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failed ⇒ Object
Information about the payment attempt failure.
-
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
-
#initiated_at ⇒ Object
When the reported payment was initiated.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#outcome ⇒ Object
The outcome of the reported payment.
-
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
-
#payment_reference ⇒ Object
An opaque string for manual reconciliation of this payment, for example a check number or a payment processor ID.
-
#shipping_details ⇒ Object
Shipping information for this payment.
Instance Method Summary collapse
-
#initialize(amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, payment_reference: nil, shipping_details: nil) ⇒ ReportPaymentParams
constructor
A new instance of ReportPaymentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, payment_reference: nil, shipping_details: nil) ⇒ ReportPaymentParams
Returns a new instance of ReportPaymentParams.
507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 |
# File 'lib/stripe/services/payment_record_service.rb', line 507 def initialize( amount_requested: nil, customer_details: nil, customer_presence: nil, description: nil, expand: nil, failed: nil, guaranteed: nil, initiated_at: nil, metadata: nil, outcome: nil, payment_method_details: nil, payment_reference: nil, shipping_details: nil ) @amount_requested = amount_requested @customer_details = customer_details @customer_presence = customer_presence @description = description @expand = @failed = failed @guaranteed = guaranteed @initiated_at = initiated_at @metadata = @outcome = outcome @payment_method_details = payment_method_details @payment_reference = payment_reference @shipping_details = shipping_details end |
Instance Attribute Details
#amount_requested ⇒ Object
The amount you intend to collect for this payment.
469 470 471 |
# File 'lib/stripe/services/payment_record_service.rb', line 469 def amount_requested @amount_requested end |
#customer_details ⇒ Object
Customer information for this payment.
472 473 474 |
# File 'lib/stripe/services/payment_record_service.rb', line 472 def customer_details @customer_details end |
#customer_presence ⇒ Object
Indicates whether the customer was present in your checkout flow during this payment.
475 476 477 |
# File 'lib/stripe/services/payment_record_service.rb', line 475 def customer_presence @customer_presence end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
478 479 480 |
# File 'lib/stripe/services/payment_record_service.rb', line 478 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
481 482 483 |
# File 'lib/stripe/services/payment_record_service.rb', line 481 def @expand end |
#failed ⇒ Object
Information about the payment attempt failure.
484 485 486 |
# File 'lib/stripe/services/payment_record_service.rb', line 484 def failed @failed end |
#guaranteed ⇒ Object
Information about the payment attempt guarantee.
487 488 489 |
# File 'lib/stripe/services/payment_record_service.rb', line 487 def guaranteed @guaranteed end |
#initiated_at ⇒ Object
When the reported payment was initiated. Measured in seconds since the Unix epoch.
490 491 492 |
# File 'lib/stripe/services/payment_record_service.rb', line 490 def initiated_at @initiated_at end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
493 494 495 |
# File 'lib/stripe/services/payment_record_service.rb', line 493 def @metadata end |
#outcome ⇒ Object
The outcome of the reported payment.
496 497 498 |
# File 'lib/stripe/services/payment_record_service.rb', line 496 def outcome @outcome end |
#payment_method_details ⇒ Object
Information about the Payment Method debited for this payment.
499 500 501 |
# File 'lib/stripe/services/payment_record_service.rb', line 499 def payment_method_details @payment_method_details end |
#payment_reference ⇒ Object
An opaque string for manual reconciliation of this payment, for example a check number or a payment processor ID.
502 503 504 |
# File 'lib/stripe/services/payment_record_service.rb', line 502 def payment_reference @payment_reference end |
#shipping_details ⇒ Object
Shipping information for this payment.
505 506 507 |
# File 'lib/stripe/services/payment_record_service.rb', line 505 def shipping_details @shipping_details end |