Class: Stripe::PaymentRecordService::ReportPaymentParams::AmountRequested
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordService::ReportPaymentParams::AmountRequested
- Defined in:
- lib/stripe/services/payment_record_service.rb
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#value ⇒ Object
A positive integer representing the amount in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) e.g., 100 cents for $1.00 or 100 for ¥100, a zero-decimal currency).
Instance Method Summary collapse
-
#initialize(currency: nil, value: nil) ⇒ AmountRequested
constructor
A new instance of AmountRequested.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, value: nil) ⇒ AmountRequested
Returns a new instance of AmountRequested.
249 250 251 252 |
# File 'lib/stripe/services/payment_record_service.rb', line 249 def initialize(currency: nil, value: nil) @currency = currency @value = value end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
245 246 247 |
# File 'lib/stripe/services/payment_record_service.rb', line 245 def currency @currency end |
#value ⇒ Object
A positive integer representing the amount in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) e.g., 100 cents for $1.00 or 100 for ¥100, a zero-decimal currency).
247 248 249 |
# File 'lib/stripe/services/payment_record_service.rb', line 247 def value @value end |