Class: Stripe::PaymentRecordService::ReportPaymentParams::PaymentMethodDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentRecordService::ReportPaymentParams::PaymentMethodDetails
- Defined in:
- lib/stripe/services/payment_record_service.rb
Defined Under Namespace
Classes: BillingDetails, Custom
Instance Attribute Summary collapse
-
#billing_details ⇒ Object
The billing details associated with the method of payment.
-
#custom ⇒ Object
Information about the custom (user-defined) payment method used to make this payment.
-
#payment_method ⇒ Object
ID of the Stripe Payment Method used to make this payment.
-
#type ⇒ Object
The type of the payment method details.
Instance Method Summary collapse
-
#initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil) ⇒ PaymentMethodDetails
constructor
A new instance of PaymentMethodDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil) ⇒ PaymentMethodDetails
Returns a new instance of PaymentMethodDetails.
360 361 362 363 364 365 |
# File 'lib/stripe/services/payment_record_service.rb', line 360 def initialize(billing_details: nil, custom: nil, payment_method: nil, type: nil) @billing_details = billing_details @custom = custom @payment_method = payment_method @type = type end |
Instance Attribute Details
#billing_details ⇒ Object
The billing details associated with the method of payment.
352 353 354 |
# File 'lib/stripe/services/payment_record_service.rb', line 352 def billing_details @billing_details end |
#custom ⇒ Object
Information about the custom (user-defined) payment method used to make this payment.
354 355 356 |
# File 'lib/stripe/services/payment_record_service.rb', line 354 def custom @custom end |
#payment_method ⇒ Object
ID of the Stripe Payment Method used to make this payment.
356 357 358 |
# File 'lib/stripe/services/payment_record_service.rb', line 356 def payment_method @payment_method end |
#type ⇒ Object
The type of the payment method details. An additional hash is included on the payment_method_details with a name matching this value. It contains additional information specific to the type.
358 359 360 |
# File 'lib/stripe/services/payment_record_service.rb', line 358 def type @type end |