Class: Stripe::PaymentRecordService::ReportPaymentParams::PaymentMethodDetails::BillingDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/payment_record_service.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, email: nil, name: nil, phone: nil) ⇒ BillingDetails

Returns a new instance of BillingDetails.



377
378
379
380
381
382
# File 'lib/stripe/services/payment_record_service.rb', line 377

def initialize(address: nil, email: nil, name: nil, phone: nil)
  @address = address
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#addressObject

The billing address associated with the method of payment.



366
367
368
# File 'lib/stripe/services/payment_record_service.rb', line 366

def address
  @address
end

#emailObject

The billing email associated with the method of payment.



369
370
371
# File 'lib/stripe/services/payment_record_service.rb', line 369

def email
  @email
end

#nameObject

The billing name associated with the method of payment.



372
373
374
# File 'lib/stripe/services/payment_record_service.rb', line 372

def name
  @name
end

#phoneObject

The billing phone number associated with the method of payment.



375
376
377
# File 'lib/stripe/services/payment_record_service.rb', line 375

def phone
  @phone
end