Class: Stripe::Payout::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Payout::CreateParams
- Defined in:
- lib/stripe/resources/payout.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
A positive integer in cents representing how much to payout.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#destination ⇒ Object
The ID of a bank account or a card to send the payout to.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#method ⇒ Object
The method used to send this payout, which is ‘standard` or `instant`.
-
#source_type ⇒ Object
The balance type of your Stripe balance to draw this payout from.
-
#statement_descriptor ⇒ Object
A string that displays on the recipient’s bank or card statement (up to 22 characters).
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, description: nil, destination: nil, expand: nil, metadata: nil, method: nil, source_type: nil, statement_descriptor: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, description: nil, destination: nil, expand: nil, metadata: nil, method: nil, source_type: nil, statement_descriptor: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/stripe/resources/payout.rb', line 146 def initialize( amount: nil, currency: nil, description: nil, destination: nil, expand: nil, metadata: nil, method: nil, source_type: nil, statement_descriptor: nil ) @amount = amount @currency = currency @description = description @destination = destination @expand = @metadata = @method = method @source_type = source_type @statement_descriptor = statement_descriptor end |
Instance Attribute Details
#amount ⇒ Object
A positive integer in cents representing how much to payout.
120 121 122 |
# File 'lib/stripe/resources/payout.rb', line 120 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
123 124 125 |
# File 'lib/stripe/resources/payout.rb', line 123 def currency @currency end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
126 127 128 |
# File 'lib/stripe/resources/payout.rb', line 126 def description @description end |
#destination ⇒ Object
The ID of a bank account or a card to send the payout to. If you don’t provide a destination, we use the default external account for the specified currency.
129 130 131 |
# File 'lib/stripe/resources/payout.rb', line 129 def destination @destination end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
132 133 134 |
# File 'lib/stripe/resources/payout.rb', line 132 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
135 136 137 |
# File 'lib/stripe/resources/payout.rb', line 135 def @metadata end |
#method ⇒ Object
The method used to send this payout, which is ‘standard` or `instant`. We support `instant` for payouts to debit cards and bank accounts in certain countries. Learn more about [bank support for Instant Payouts](stripe.com/docs/payouts/instant-payouts-banks).
138 139 140 |
# File 'lib/stripe/resources/payout.rb', line 138 def method @method end |
#source_type ⇒ Object
The balance type of your Stripe balance to draw this payout from. Balances for different payment sources are kept separately. You can find the amounts with the Balances API. One of ‘bank_account`, `card`, or `fpx`.
141 142 143 |
# File 'lib/stripe/resources/payout.rb', line 141 def source_type @source_type end |
#statement_descriptor ⇒ Object
A string that displays on the recipient’s bank or card statement (up to 22 characters). A ‘statement_descriptor` that’s longer than 22 characters return an error. Most banks truncate this information and display it inconsistently. Some banks might not display it at all.
144 145 146 |
# File 'lib/stripe/resources/payout.rb', line 144 def statement_descriptor @statement_descriptor end |