Class: Stripe::PayoutService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PayoutService::CreateParams
- Defined in:
- lib/stripe/services/payout_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
A positive integer in cents representing how much to payout.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#destination ⇒ Object
The ID of a bank account or a card to send the payout to.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#method ⇒ Object
The method used to send this payout, which is ‘standard` or `instant`.
-
#source_type ⇒ Object
The balance type of your Stripe balance to draw this payout from.
-
#statement_descriptor ⇒ Object
A string that displays on the recipient’s bank or card statement (up to 22 characters).
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, description: nil, destination: nil, expand: nil, metadata: nil, method: nil, source_type: nil, statement_descriptor: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, description: nil, destination: nil, expand: nil, metadata: nil, method: nil, source_type: nil, statement_descriptor: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/stripe/services/payout_service.rb', line 100 def initialize( amount: nil, currency: nil, description: nil, destination: nil, expand: nil, metadata: nil, method: nil, source_type: nil, statement_descriptor: nil ) @amount = amount @currency = currency @description = description @destination = destination @expand = @metadata = @method = method @source_type = source_type @statement_descriptor = statement_descriptor end |
Instance Attribute Details
#amount ⇒ Object
A positive integer in cents representing how much to payout.
82 83 84 |
# File 'lib/stripe/services/payout_service.rb', line 82 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
84 85 86 |
# File 'lib/stripe/services/payout_service.rb', line 84 def currency @currency end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
86 87 88 |
# File 'lib/stripe/services/payout_service.rb', line 86 def description @description end |
#destination ⇒ Object
The ID of a bank account or a card to send the payout to. If you don’t provide a destination, we use the default external account for the specified currency.
88 89 90 |
# File 'lib/stripe/services/payout_service.rb', line 88 def destination @destination end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
90 91 92 |
# File 'lib/stripe/services/payout_service.rb', line 90 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
92 93 94 |
# File 'lib/stripe/services/payout_service.rb', line 92 def @metadata end |
#method ⇒ Object
The method used to send this payout, which is ‘standard` or `instant`. We support `instant` for payouts to debit cards and bank accounts in certain countries. Learn more about [bank support for Instant Payouts](stripe.com/docs/payouts/instant-payouts-banks).
94 95 96 |
# File 'lib/stripe/services/payout_service.rb', line 94 def method @method end |
#source_type ⇒ Object
The balance type of your Stripe balance to draw this payout from. Balances for different payment sources are kept separately. You can find the amounts with the Balances API. One of ‘bank_account`, `card`, or `fpx`.
96 97 98 |
# File 'lib/stripe/services/payout_service.rb', line 96 def source_type @source_type end |
#statement_descriptor ⇒ Object
A string that displays on the recipient’s bank or card statement (up to 22 characters). A ‘statement_descriptor` that’s longer than 22 characters return an error. Most banks truncate this information and display it inconsistently. Some banks might not display it at all.
98 99 100 |
# File 'lib/stripe/services/payout_service.rb', line 98 def statement_descriptor @statement_descriptor end |