Class: Stripe::PayoutService::ReverseParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/payout_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, metadata: nil) ⇒ ReverseParams

Returns a new instance of ReverseParams.



159
160
161
162
# File 'lib/stripe/services/payout_service.rb', line 159

def initialize(expand: nil, metadata: nil)
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



155
156
157
# File 'lib/stripe/services/payout_service.rb', line 155

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



157
158
159
# File 'lib/stripe/services/payout_service.rb', line 157

def 
  @metadata
end