Class: Stripe::PayoutService::ReverseParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PayoutService::ReverseParams
- Defined in:
- lib/stripe/services/payout_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
Instance Method Summary collapse
-
#initialize(expand: nil, metadata: nil) ⇒ ReverseParams
constructor
A new instance of ReverseParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, metadata: nil) ⇒ ReverseParams
Returns a new instance of ReverseParams.
159 160 161 162 |
# File 'lib/stripe/services/payout_service.rb', line 159 def initialize(expand: nil, metadata: nil) @expand = @metadata = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
155 156 157 |
# File 'lib/stripe/services/payout_service.rb', line 155 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
157 158 159 |
# File 'lib/stripe/services/payout_service.rb', line 157 def @metadata end |