Class: Stripe::Person
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Person
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/person.rb
Overview
This is an object representing a person associated with a Stripe account.
A platform can only access a subset of data in a person for an account where [account.controller.requirement_collection](docs.stripe.com/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`, which includes Standard and Express accounts, after creating an Account Link or Account Session to start Connect onboarding.
See the [Standard onboarding](docs.stripe.com/connect/standard-accounts) or [Express onboarding](docs.stripe.com/connect/express-accounts) documentation for information about prefilling information and account onboarding steps. Learn more about [handling identity verification with the API](docs.stripe.com/connect/handling-api-verification#person-information).
Defined Under Namespace
Classes: AdditionalTosAcceptances, Address, AddressKana, AddressKanji, Dob, FutureRequirements, RegisteredAddress, Relationship, Requirements, SelfReportedIncome, SelfReportedMonthlyHousingPayment, UsCfpbData, Verification
Constant Summary collapse
- OBJECT_NAME =
"person"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The account the person is associated with.
-
#additional_tos_acceptances ⇒ Object
readonly
Attribute for field additional_tos_acceptances.
-
#address ⇒ Object
readonly
Attribute for field address.
-
#address_kana ⇒ Object
readonly
The Kana variation of the person’s address (Japan only).
-
#address_kanji ⇒ Object
readonly
The Kanji variation of the person’s address (Japan only).
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#deleted ⇒ Object
readonly
Always true for a deleted object.
-
#dob ⇒ Object
readonly
Attribute for field dob.
-
#email ⇒ Object
readonly
The person’s email address.
-
#first_name ⇒ Object
readonly
The person’s first name.
-
#first_name_kana ⇒ Object
readonly
The Kana variation of the person’s first name (Japan only).
-
#first_name_kanji ⇒ Object
readonly
The Kanji variation of the person’s first name (Japan only).
-
#full_name_aliases ⇒ Object
readonly
A list of alternate names or aliases that the person is known by.
-
#future_requirements ⇒ Object
readonly
Information about the [upcoming new requirements for this person](docs.stripe.com/connect/custom-accounts/future-requirements), including what information needs to be collected, and by when.
-
#gender ⇒ Object
readonly
The person’s gender.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#id_number_provided ⇒ Object
readonly
Whether the person’s ‘id_number` was provided.
-
#id_number_secondary_provided ⇒ Object
readonly
Whether the person’s ‘id_number_secondary` was provided.
-
#last_name ⇒ Object
readonly
The person’s last name.
-
#last_name_kana ⇒ Object
readonly
The Kana variation of the person’s last name (Japan only).
-
#last_name_kanji ⇒ Object
readonly
The Kanji variation of the person’s last name (Japan only).
-
#maiden_name ⇒ Object
readonly
The person’s maiden name.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#nationality ⇒ Object
readonly
The country where the person is a national.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#phone ⇒ Object
readonly
The person’s phone number.
-
#political_exposure ⇒ Object
readonly
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
readonly
Attribute for field registered_address.
-
#relationship ⇒ Object
readonly
Attribute for field relationship.
-
#requirements ⇒ Object
readonly
Information about the requirements for this person, including what information needs to be collected, and by when.
-
#self_reported_income ⇒ Object
readonly
Attribute for field self_reported_income.
-
#self_reported_monthly_housing_payment ⇒ Object
readonly
Attribute for field self_reported_monthly_housing_payment.
-
#ssn_last_4_provided ⇒ Object
readonly
Whether the last four digits of the person’s Social Security number have been provided (U.S. only).
-
#us_cfpb_data ⇒ Object
readonly
Demographic data related to the person.
-
#verification ⇒ Object
readonly
Attribute for field verification.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
- .object_name ⇒ Object
- .retrieve(_id, _opts = {}) ⇒ Object
- .update(_id, _params = nil, _opts = nil) ⇒ Object
Instance Method Summary collapse
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The account the person is associated with.
429 430 431 |
# File 'lib/stripe/resources/person.rb', line 429 def account @account end |
#additional_tos_acceptances ⇒ Object (readonly)
Attribute for field additional_tos_acceptances
431 432 433 |
# File 'lib/stripe/resources/person.rb', line 431 def additional_tos_acceptances @additional_tos_acceptances end |
#address ⇒ Object (readonly)
Attribute for field address
433 434 435 |
# File 'lib/stripe/resources/person.rb', line 433 def address @address end |
#address_kana ⇒ Object (readonly)
The Kana variation of the person’s address (Japan only).
435 436 437 |
# File 'lib/stripe/resources/person.rb', line 435 def address_kana @address_kana end |
#address_kanji ⇒ Object (readonly)
The Kanji variation of the person’s address (Japan only).
437 438 439 |
# File 'lib/stripe/resources/person.rb', line 437 def address_kanji @address_kanji end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
439 440 441 |
# File 'lib/stripe/resources/person.rb', line 439 def created @created end |
#deleted ⇒ Object (readonly)
Always true for a deleted object
497 498 499 |
# File 'lib/stripe/resources/person.rb', line 497 def deleted @deleted end |
#dob ⇒ Object (readonly)
Attribute for field dob
441 442 443 |
# File 'lib/stripe/resources/person.rb', line 441 def dob @dob end |
#email ⇒ Object (readonly)
The person’s email address. Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`.
443 444 445 |
# File 'lib/stripe/resources/person.rb', line 443 def email @email end |
#first_name ⇒ Object (readonly)
The person’s first name. Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`.
445 446 447 |
# File 'lib/stripe/resources/person.rb', line 445 def first_name @first_name end |
#first_name_kana ⇒ Object (readonly)
The Kana variation of the person’s first name (Japan only). Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`.
447 448 449 |
# File 'lib/stripe/resources/person.rb', line 447 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object (readonly)
The Kanji variation of the person’s first name (Japan only). Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`.
449 450 451 |
# File 'lib/stripe/resources/person.rb', line 449 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object (readonly)
A list of alternate names or aliases that the person is known by. Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`.
451 452 453 |
# File 'lib/stripe/resources/person.rb', line 451 def full_name_aliases @full_name_aliases end |
#future_requirements ⇒ Object (readonly)
Information about the [upcoming new requirements for this person](docs.stripe.com/connect/custom-accounts/future-requirements), including what information needs to be collected, and by when.
453 454 455 |
# File 'lib/stripe/resources/person.rb', line 453 def future_requirements @future_requirements end |
#gender ⇒ Object (readonly)
The person’s gender.
455 456 457 |
# File 'lib/stripe/resources/person.rb', line 455 def gender @gender end |
#id ⇒ Object (readonly)
Unique identifier for the object.
457 458 459 |
# File 'lib/stripe/resources/person.rb', line 457 def id @id end |
#id_number_provided ⇒ Object (readonly)
Whether the person’s ‘id_number` was provided. True if either the full ID number was provided or if only the required part of the ID number was provided (ex. last four of an individual’s SSN for the US indicated by ‘ssn_last_4_provided`).
459 460 461 |
# File 'lib/stripe/resources/person.rb', line 459 def id_number_provided @id_number_provided end |
#id_number_secondary_provided ⇒ Object (readonly)
Whether the person’s ‘id_number_secondary` was provided.
461 462 463 |
# File 'lib/stripe/resources/person.rb', line 461 def id_number_secondary_provided @id_number_secondary_provided end |
#last_name ⇒ Object (readonly)
The person’s last name. Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`.
463 464 465 |
# File 'lib/stripe/resources/person.rb', line 463 def last_name @last_name end |
#last_name_kana ⇒ Object (readonly)
The Kana variation of the person’s last name (Japan only). Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`.
465 466 467 |
# File 'lib/stripe/resources/person.rb', line 465 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object (readonly)
The Kanji variation of the person’s last name (Japan only). Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`.
467 468 469 |
# File 'lib/stripe/resources/person.rb', line 467 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object (readonly)
The person’s maiden name.
469 470 471 |
# File 'lib/stripe/resources/person.rb', line 469 def maiden_name @maiden_name end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
471 472 473 |
# File 'lib/stripe/resources/person.rb', line 471 def @metadata end |
#nationality ⇒ Object (readonly)
The country where the person is a national.
473 474 475 |
# File 'lib/stripe/resources/person.rb', line 473 def nationality @nationality end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
475 476 477 |
# File 'lib/stripe/resources/person.rb', line 475 def object @object end |
#phone ⇒ Object (readonly)
The person’s phone number.
477 478 479 |
# File 'lib/stripe/resources/person.rb', line 477 def phone @phone end |
#political_exposure ⇒ Object (readonly)
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
479 480 481 |
# File 'lib/stripe/resources/person.rb', line 479 def political_exposure @political_exposure end |
#registered_address ⇒ Object (readonly)
Attribute for field registered_address
481 482 483 |
# File 'lib/stripe/resources/person.rb', line 481 def registered_address @registered_address end |
#relationship ⇒ Object (readonly)
Attribute for field relationship
483 484 485 |
# File 'lib/stripe/resources/person.rb', line 483 def relationship @relationship end |
#requirements ⇒ Object (readonly)
Information about the requirements for this person, including what information needs to be collected, and by when.
485 486 487 |
# File 'lib/stripe/resources/person.rb', line 485 def requirements @requirements end |
#self_reported_income ⇒ Object (readonly)
Attribute for field self_reported_income
487 488 489 |
# File 'lib/stripe/resources/person.rb', line 487 def self_reported_income @self_reported_income end |
#self_reported_monthly_housing_payment ⇒ Object (readonly)
Attribute for field self_reported_monthly_housing_payment
489 490 491 |
# File 'lib/stripe/resources/person.rb', line 489 def self_reported_monthly_housing_payment @self_reported_monthly_housing_payment end |
#ssn_last_4_provided ⇒ Object (readonly)
Whether the last four digits of the person’s Social Security number have been provided (U.S. only).
491 492 493 |
# File 'lib/stripe/resources/person.rb', line 491 def ssn_last_4_provided @ssn_last_4_provided end |
#us_cfpb_data ⇒ Object (readonly)
Demographic data related to the person.
493 494 495 |
# File 'lib/stripe/resources/person.rb', line 493 def us_cfpb_data @us_cfpb_data end |
#verification ⇒ Object (readonly)
Attribute for field verification
495 496 497 |
# File 'lib/stripe/resources/person.rb', line 495 def verification @verification end |
Class Method Details
.field_remappings ⇒ Object
538 539 540 |
# File 'lib/stripe/resources/person.rb', line 538 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 |
# File 'lib/stripe/resources/person.rb', line 520 def self.inner_class_types @inner_class_types = { additional_tos_acceptances: AdditionalTosAcceptances, address: Address, address_kana: AddressKana, address_kanji: AddressKanji, dob: Dob, future_requirements: FutureRequirements, registered_address: RegisteredAddress, relationship: Relationship, requirements: Requirements, self_reported_income: SelfReportedIncome, self_reported_monthly_housing_payment: SelfReportedMonthlyHousingPayment, us_cfpb_data: UsCfpbData, verification: Verification, } end |
.object_name ⇒ Object
14 15 16 |
# File 'lib/stripe/resources/person.rb', line 14 def self.object_name "person" end |
.retrieve(_id, _opts = {}) ⇒ Object
507 508 509 510 511 |
# File 'lib/stripe/resources/person.rb', line 507 def self.retrieve(_id, _opts = {}) raise NotImplementedError, "Persons cannot be retrieved without an account ID. Retrieve a " \ "person using `Account.retrieve_person('account_id', 'person_id')`" end |
.update(_id, _params = nil, _opts = nil) ⇒ Object
513 514 515 516 517 518 |
# File 'lib/stripe/resources/person.rb', line 513 def self.update(_id, _params = nil, _opts = nil) raise NotImplementedError, "Persons cannot be updated without an account ID. Update a " \ "person using `Account.update_person('account_id', 'person_id', " \ "update_params)`" end |
Instance Method Details
#resource_url ⇒ Object
499 500 501 502 503 504 505 |
# File 'lib/stripe/resources/person.rb', line 499 def resource_url if !respond_to?(:account) || account.nil? raise NotImplementedError, "Persons cannot be accessed without an account ID." end "#{Account.resource_url}/#{CGI.escape(account)}/persons/#{CGI.escape(id)}" end |