Class: Stripe::Person

Inherits:
APIResource show all
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/person.rb

Overview

This is an object representing a person associated with a Stripe account.

A platform can only access a subset of data in a person for an account where [account.controller.requirement_collection](docs.stripe.com/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`, which includes Standard and Express accounts, after creating an Account Link or Account Session to start Connect onboarding.

See the [Standard onboarding](docs.stripe.com/connect/standard-accounts) or [Express onboarding](docs.stripe.com/connect/express-accounts) documentation for information about prefilling information and account onboarding steps. Learn more about [handling identity verification with the API](docs.stripe.com/connect/handling-api-verification#person-information).

Defined Under Namespace

Classes: AdditionalTosAcceptances, Address, AddressKana, AddressKanji, Dob, FutureRequirements, RegisteredAddress, Relationship, Requirements, UsCfpbData, Verification

Constant Summary collapse

OBJECT_NAME =
"person"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The account the person is associated with.



239
240
241
# File 'lib/stripe/resources/person.rb', line 239

def 
  @account
end

#additional_tos_acceptancesObject (readonly)

Attribute for field additional_tos_acceptances



241
242
243
# File 'lib/stripe/resources/person.rb', line 241

def additional_tos_acceptances
  @additional_tos_acceptances
end

#addressObject (readonly)

Attribute for field address



243
244
245
# File 'lib/stripe/resources/person.rb', line 243

def address
  @address
end

#address_kanaObject (readonly)

The Kana variation of the person’s address (Japan only).



245
246
247
# File 'lib/stripe/resources/person.rb', line 245

def address_kana
  @address_kana
end

#address_kanjiObject (readonly)

The Kanji variation of the person’s address (Japan only).



247
248
249
# File 'lib/stripe/resources/person.rb', line 247

def address_kanji
  @address_kanji
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



249
250
251
# File 'lib/stripe/resources/person.rb', line 249

def created
  @created
end

#deletedObject (readonly)

Always true for a deleted object



303
304
305
# File 'lib/stripe/resources/person.rb', line 303

def deleted
  @deleted
end

#dobObject (readonly)

Attribute for field dob



251
252
253
# File 'lib/stripe/resources/person.rb', line 251

def dob
  @dob
end

#emailObject (readonly)

The person’s email address. Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`.



253
254
255
# File 'lib/stripe/resources/person.rb', line 253

def email
  @email
end

#first_nameObject (readonly)

The person’s first name. Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`.



255
256
257
# File 'lib/stripe/resources/person.rb', line 255

def first_name
  @first_name
end

#first_name_kanaObject (readonly)

The Kana variation of the person’s first name (Japan only). Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`.



257
258
259
# File 'lib/stripe/resources/person.rb', line 257

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject (readonly)

The Kanji variation of the person’s first name (Japan only). Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`.



259
260
261
# File 'lib/stripe/resources/person.rb', line 259

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject (readonly)

A list of alternate names or aliases that the person is known by. Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`.



261
262
263
# File 'lib/stripe/resources/person.rb', line 261

def full_name_aliases
  @full_name_aliases
end

#future_requirementsObject (readonly)

Information about the [upcoming new requirements for this person](stripe.com/docs/connect/custom-accounts/future-requirements), including what information needs to be collected, and by when.



263
264
265
# File 'lib/stripe/resources/person.rb', line 263

def future_requirements
  @future_requirements
end

#genderObject (readonly)

The person’s gender.



265
266
267
# File 'lib/stripe/resources/person.rb', line 265

def gender
  @gender
end

#idObject (readonly)

Unique identifier for the object.



267
268
269
# File 'lib/stripe/resources/person.rb', line 267

def id
  @id
end

#id_number_providedObject (readonly)

Whether the person’s ‘id_number` was provided. True if either the full ID number was provided or if only the required part of the ID number was provided (ex. last four of an individual’s SSN for the US indicated by ‘ssn_last_4_provided`).



269
270
271
# File 'lib/stripe/resources/person.rb', line 269

def id_number_provided
  @id_number_provided
end

#id_number_secondary_providedObject (readonly)

Whether the person’s ‘id_number_secondary` was provided.



271
272
273
# File 'lib/stripe/resources/person.rb', line 271

def id_number_secondary_provided
  @id_number_secondary_provided
end

#last_nameObject (readonly)

The person’s last name. Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`.



273
274
275
# File 'lib/stripe/resources/person.rb', line 273

def last_name
  @last_name
end

#last_name_kanaObject (readonly)

The Kana variation of the person’s last name (Japan only). Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`.



275
276
277
# File 'lib/stripe/resources/person.rb', line 275

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject (readonly)

The Kanji variation of the person’s last name (Japan only). Also available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`.



277
278
279
# File 'lib/stripe/resources/person.rb', line 277

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject (readonly)

The person’s maiden name.



279
280
281
# File 'lib/stripe/resources/person.rb', line 279

def maiden_name
  @maiden_name
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



281
282
283
# File 'lib/stripe/resources/person.rb', line 281

def 
  @metadata
end

#nationalityObject (readonly)

The country where the person is a national.



283
284
285
# File 'lib/stripe/resources/person.rb', line 283

def nationality
  @nationality
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



285
286
287
# File 'lib/stripe/resources/person.rb', line 285

def object
  @object
end

#phoneObject (readonly)

The person’s phone number.



287
288
289
# File 'lib/stripe/resources/person.rb', line 287

def phone
  @phone
end

#political_exposureObject (readonly)

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



289
290
291
# File 'lib/stripe/resources/person.rb', line 289

def political_exposure
  @political_exposure
end

#registered_addressObject (readonly)

Attribute for field registered_address



291
292
293
# File 'lib/stripe/resources/person.rb', line 291

def registered_address
  @registered_address
end

#relationshipObject (readonly)

Attribute for field relationship



293
294
295
# File 'lib/stripe/resources/person.rb', line 293

def relationship
  @relationship
end

#requirementsObject (readonly)

Information about the requirements for this person, including what information needs to be collected, and by when.



295
296
297
# File 'lib/stripe/resources/person.rb', line 295

def requirements
  @requirements
end

#ssn_last_4_providedObject (readonly)

Whether the last four digits of the person’s Social Security number have been provided (U.S. only).



297
298
299
# File 'lib/stripe/resources/person.rb', line 297

def ssn_last_4_provided
  @ssn_last_4_provided
end

#us_cfpb_dataObject (readonly)

Demographic data related to the person.



299
300
301
# File 'lib/stripe/resources/person.rb', line 299

def us_cfpb_data
  @us_cfpb_data
end

#verificationObject (readonly)

Attribute for field verification



301
302
303
# File 'lib/stripe/resources/person.rb', line 301

def verification
  @verification
end

Class Method Details

.object_nameObject



14
15
16
# File 'lib/stripe/resources/person.rb', line 14

def self.object_name
  "person"
end

.retrieve(_id, _opts = {}) ⇒ Object

Raises:

  • (NotImplementedError)


313
314
315
316
317
# File 'lib/stripe/resources/person.rb', line 313

def self.retrieve(_id, _opts = {})
  raise NotImplementedError,
        "Persons cannot be retrieved without an account ID. Retrieve a " \
        "person using `Account.retrieve_person('account_id', 'person_id')`"
end

.update(_id, _params = nil, _opts = nil) ⇒ Object

Raises:

  • (NotImplementedError)


319
320
321
322
323
324
# File 'lib/stripe/resources/person.rb', line 319

def self.update(_id, _params = nil, _opts = nil)
  raise NotImplementedError,
        "Persons cannot be updated without an account ID. Update a " \
        "person using `Account.update_person('account_id', 'person_id', " \
        "update_params)`"
end

Instance Method Details

#resource_urlObject



305
306
307
308
309
310
311
# File 'lib/stripe/resources/person.rb', line 305

def resource_url
  if !respond_to?(:account) || .nil?
    raise NotImplementedError,
          "Persons cannot be accessed without an account ID."
  end
  "#{Account.resource_url}/#{CGI.escape()}/persons/#{CGI.escape(id)}"
end