Class: Stripe::Person
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Person
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/person.rb
Overview
This is an object representing a person associated with a Stripe account.
A platform cannot access a person for an account where [account.controller.requirement_collection](stripe.com/api/accounts/object#account_object-controller-requirement_collection) is ‘stripe`, which includes Standard and Express accounts, after creating an Account Link or Account Session to start Connect onboarding.
See the [Standard onboarding](stripe.com/connect/standard-accounts) or [Express onboarding](stripe.com/connect/express-accounts) documentation for information about prefilling information and account onboarding steps. Learn more about [handling identity verification with the API](stripe.com/connect/handling-api-verification#person-information).
Defined Under Namespace
Classes: AdditionalTosAcceptances, Address, AddressKana, AddressKanji, Dob, FutureRequirements, RegisteredAddress, Relationship, Requirements, Verification
Constant Summary collapse
- OBJECT_NAME =
"person"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The account the person is associated with.
-
#additional_tos_acceptances ⇒ Object
readonly
Attribute for field additional_tos_acceptances.
-
#address ⇒ Object
readonly
Attribute for field address.
-
#address_kana ⇒ Object
readonly
The Kana variation of the person’s address (Japan only).
-
#address_kanji ⇒ Object
readonly
The Kanji variation of the person’s address (Japan only).
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#deleted ⇒ Object
readonly
Always true for a deleted object.
-
#dob ⇒ Object
readonly
Attribute for field dob.
-
#email ⇒ Object
readonly
The person’s email address.
-
#first_name ⇒ Object
readonly
The person’s first name.
-
#first_name_kana ⇒ Object
readonly
The Kana variation of the person’s first name (Japan only).
-
#first_name_kanji ⇒ Object
readonly
The Kanji variation of the person’s first name (Japan only).
-
#full_name_aliases ⇒ Object
readonly
A list of alternate names or aliases that the person is known by.
-
#future_requirements ⇒ Object
readonly
Information about the [upcoming new requirements for this person](stripe.com/docs/connect/custom-accounts/future-requirements), including what information needs to be collected, and by when.
-
#gender ⇒ Object
readonly
The person’s gender.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#id_number_provided ⇒ Object
readonly
Whether the person’s ‘id_number` was provided.
-
#id_number_secondary_provided ⇒ Object
readonly
Whether the person’s ‘id_number_secondary` was provided.
-
#last_name ⇒ Object
readonly
The person’s last name.
-
#last_name_kana ⇒ Object
readonly
The Kana variation of the person’s last name (Japan only).
-
#last_name_kanji ⇒ Object
readonly
The Kanji variation of the person’s last name (Japan only).
-
#maiden_name ⇒ Object
readonly
The person’s maiden name.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#nationality ⇒ Object
readonly
The country where the person is a national.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#phone ⇒ Object
readonly
The person’s phone number.
-
#political_exposure ⇒ Object
readonly
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
readonly
Attribute for field registered_address.
-
#relationship ⇒ Object
readonly
Attribute for field relationship.
-
#requirements ⇒ Object
readonly
Information about the requirements for this person, including what information needs to be collected, and by when.
-
#ssn_last_4_provided ⇒ Object
readonly
Whether the last four digits of the person’s Social Security number have been provided (U.S. only).
-
#verification ⇒ Object
readonly
Attribute for field verification.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .object_name ⇒ Object
- .retrieve(_id, _opts = {}) ⇒ Object
- .update(_id, _params = nil, _opts = nil) ⇒ Object
Instance Method Summary collapse
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The account the person is associated with.
82 83 84 |
# File 'lib/stripe/resources/person.rb', line 82 def account @account end |
#additional_tos_acceptances ⇒ Object (readonly)
Attribute for field additional_tos_acceptances
84 85 86 |
# File 'lib/stripe/resources/person.rb', line 84 def additional_tos_acceptances @additional_tos_acceptances end |
#address ⇒ Object (readonly)
Attribute for field address
86 87 88 |
# File 'lib/stripe/resources/person.rb', line 86 def address @address end |
#address_kana ⇒ Object (readonly)
The Kana variation of the person’s address (Japan only).
88 89 90 |
# File 'lib/stripe/resources/person.rb', line 88 def address_kana @address_kana end |
#address_kanji ⇒ Object (readonly)
The Kanji variation of the person’s address (Japan only).
90 91 92 |
# File 'lib/stripe/resources/person.rb', line 90 def address_kanji @address_kanji end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
92 93 94 |
# File 'lib/stripe/resources/person.rb', line 92 def created @created end |
#deleted ⇒ Object (readonly)
Always true for a deleted object
144 145 146 |
# File 'lib/stripe/resources/person.rb', line 144 def deleted @deleted end |
#dob ⇒ Object (readonly)
Attribute for field dob
94 95 96 |
# File 'lib/stripe/resources/person.rb', line 94 def dob @dob end |
#email ⇒ Object (readonly)
The person’s email address.
96 97 98 |
# File 'lib/stripe/resources/person.rb', line 96 def email @email end |
#first_name ⇒ Object (readonly)
The person’s first name.
98 99 100 |
# File 'lib/stripe/resources/person.rb', line 98 def first_name @first_name end |
#first_name_kana ⇒ Object (readonly)
The Kana variation of the person’s first name (Japan only).
100 101 102 |
# File 'lib/stripe/resources/person.rb', line 100 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object (readonly)
The Kanji variation of the person’s first name (Japan only).
102 103 104 |
# File 'lib/stripe/resources/person.rb', line 102 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object (readonly)
A list of alternate names or aliases that the person is known by.
104 105 106 |
# File 'lib/stripe/resources/person.rb', line 104 def full_name_aliases @full_name_aliases end |
#future_requirements ⇒ Object (readonly)
Information about the [upcoming new requirements for this person](stripe.com/docs/connect/custom-accounts/future-requirements), including what information needs to be collected, and by when.
106 107 108 |
# File 'lib/stripe/resources/person.rb', line 106 def future_requirements @future_requirements end |
#gender ⇒ Object (readonly)
The person’s gender.
108 109 110 |
# File 'lib/stripe/resources/person.rb', line 108 def gender @gender end |
#id ⇒ Object (readonly)
Unique identifier for the object.
110 111 112 |
# File 'lib/stripe/resources/person.rb', line 110 def id @id end |
#id_number_provided ⇒ Object (readonly)
Whether the person’s ‘id_number` was provided. True if either the full ID number was provided or if only the required part of the ID number was provided (ex. last four of an individual’s SSN for the US indicated by ‘ssn_last_4_provided`).
112 113 114 |
# File 'lib/stripe/resources/person.rb', line 112 def id_number_provided @id_number_provided end |
#id_number_secondary_provided ⇒ Object (readonly)
Whether the person’s ‘id_number_secondary` was provided.
114 115 116 |
# File 'lib/stripe/resources/person.rb', line 114 def id_number_secondary_provided @id_number_secondary_provided end |
#last_name ⇒ Object (readonly)
The person’s last name.
116 117 118 |
# File 'lib/stripe/resources/person.rb', line 116 def last_name @last_name end |
#last_name_kana ⇒ Object (readonly)
The Kana variation of the person’s last name (Japan only).
118 119 120 |
# File 'lib/stripe/resources/person.rb', line 118 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object (readonly)
The Kanji variation of the person’s last name (Japan only).
120 121 122 |
# File 'lib/stripe/resources/person.rb', line 120 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object (readonly)
The person’s maiden name.
122 123 124 |
# File 'lib/stripe/resources/person.rb', line 122 def maiden_name @maiden_name end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
124 125 126 |
# File 'lib/stripe/resources/person.rb', line 124 def @metadata end |
#nationality ⇒ Object (readonly)
The country where the person is a national.
126 127 128 |
# File 'lib/stripe/resources/person.rb', line 126 def nationality @nationality end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
128 129 130 |
# File 'lib/stripe/resources/person.rb', line 128 def object @object end |
#phone ⇒ Object (readonly)
The person’s phone number.
130 131 132 |
# File 'lib/stripe/resources/person.rb', line 130 def phone @phone end |
#political_exposure ⇒ Object (readonly)
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
132 133 134 |
# File 'lib/stripe/resources/person.rb', line 132 def political_exposure @political_exposure end |
#registered_address ⇒ Object (readonly)
Attribute for field registered_address
134 135 136 |
# File 'lib/stripe/resources/person.rb', line 134 def registered_address @registered_address end |
#relationship ⇒ Object (readonly)
Attribute for field relationship
136 137 138 |
# File 'lib/stripe/resources/person.rb', line 136 def relationship @relationship end |
#requirements ⇒ Object (readonly)
Information about the requirements for this person, including what information needs to be collected, and by when.
138 139 140 |
# File 'lib/stripe/resources/person.rb', line 138 def requirements @requirements end |
#ssn_last_4_provided ⇒ Object (readonly)
Whether the last four digits of the person’s Social Security number have been provided (U.S. only).
140 141 142 |
# File 'lib/stripe/resources/person.rb', line 140 def ssn_last_4_provided @ssn_last_4_provided end |
#verification ⇒ Object (readonly)
Attribute for field verification
142 143 144 |
# File 'lib/stripe/resources/person.rb', line 142 def verification @verification end |
Class Method Details
.object_name ⇒ Object
14 15 16 |
# File 'lib/stripe/resources/person.rb', line 14 def self.object_name "person" end |
.retrieve(_id, _opts = {}) ⇒ Object
154 155 156 157 158 |
# File 'lib/stripe/resources/person.rb', line 154 def self.retrieve(_id, _opts = {}) raise NotImplementedError, "Persons cannot be retrieved without an account ID. Retrieve a " \ "person using `Account.retrieve_person('account_id', 'person_id')`" end |
.update(_id, _params = nil, _opts = nil) ⇒ Object
160 161 162 163 164 165 |
# File 'lib/stripe/resources/person.rb', line 160 def self.update(_id, _params = nil, _opts = nil) raise NotImplementedError, "Persons cannot be updated without an account ID. Update a " \ "person using `Account.update_person('account_id', 'person_id', " \ "update_params)`" end |
Instance Method Details
#resource_url ⇒ Object
146 147 148 149 150 151 152 |
# File 'lib/stripe/resources/person.rb', line 146 def resource_url if !respond_to?(:account) || account.nil? raise NotImplementedError, "Persons cannot be accessed without an account ID." end "#{Account.resource_url}/#{CGI.escape(account)}/persons/#{CGI.escape(id)}" end |