Class: Stripe::Person::FutureRequirements
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Person::FutureRequirements
- Defined in:
- lib/stripe/resources/person.rb
Defined Under Namespace
Classes: Alternative, Error
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#alternatives ⇒ Object
readonly
Fields that are due and can be satisfied by providing the corresponding alternative fields instead.
-
#currently_due ⇒ Object
readonly
Fields that need to be collected to keep the person’s account enabled.
-
#errors ⇒ Object
readonly
Fields that are ‘currently_due` and need to be collected again because validation or verification failed.
-
#eventually_due ⇒ Object
readonly
Fields you must collect when all thresholds are reached.
-
#past_due ⇒ Object
readonly
Fields that weren’t collected by the account’s ‘requirements.current_deadline`.
-
#pending_verification ⇒ Object
readonly
Fields that might become required depending on the results of verification or review.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#alternatives ⇒ Object (readonly)
Fields that are due and can be satisfied by providing the corresponding alternative fields instead.
106 107 108 |
# File 'lib/stripe/resources/person.rb', line 106 def alternatives @alternatives end |
#currently_due ⇒ Object (readonly)
Fields that need to be collected to keep the person’s account enabled. If not collected by the account’s ‘future_requirements`, these fields will transition to the main `requirements` hash, and may immediately become `past_due`, but the account may also be given a grace period depending on the account’s enablement state prior to transition.
108 109 110 |
# File 'lib/stripe/resources/person.rb', line 108 def currently_due @currently_due end |
#errors ⇒ Object (readonly)
Fields that are ‘currently_due` and need to be collected again because validation or verification failed.
110 111 112 |
# File 'lib/stripe/resources/person.rb', line 110 def errors @errors end |
#eventually_due ⇒ Object (readonly)
Fields you must collect when all thresholds are reached. As they become required, they appear in ‘currently_due` as well, and the account’s ‘future_requirements` becomes set.
112 113 114 |
# File 'lib/stripe/resources/person.rb', line 112 def eventually_due @eventually_due end |
#past_due ⇒ Object (readonly)
Fields that weren’t collected by the account’s ‘requirements.current_deadline`. These fields need to be collected to enable the person’s account. New fields will never appear here; ‘future_requirements.past_due` will always be a subset of `requirements.past_due`.
114 115 116 |
# File 'lib/stripe/resources/person.rb', line 114 def past_due @past_due end |
#pending_verification ⇒ Object (readonly)
Fields that might become required depending on the results of verification or review. It’s an empty array unless an asynchronous verification is pending. If verification fails, these fields move to ‘eventually_due` or `currently_due`. Fields might appear in `eventually_due` or `currently_due` and in `pending_verification` if verification fails but another verification is still pending.
116 117 118 |
# File 'lib/stripe/resources/person.rb', line 116 def pending_verification @pending_verification end |