Class: Stripe::Person::Requirements
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Person::Requirements
- Defined in:
- lib/stripe/resources/person.rb
Defined Under Namespace
Classes: Alternative, Error
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#alternatives ⇒ Object
readonly
Fields that are due and can be satisfied by providing the corresponding alternative fields instead.
-
#currently_due ⇒ Object
readonly
Fields that need to be collected to keep the person’s account enabled.
-
#errors ⇒ Object
readonly
Fields that are ‘currently_due` and need to be collected again because validation or verification failed.
-
#eventually_due ⇒ Object
readonly
Fields that need to be collected assuming all volume thresholds are reached.
-
#past_due ⇒ Object
readonly
Fields that weren’t collected by the account’s ‘current_deadline`.
-
#pending_verification ⇒ Object
readonly
Fields that might become required depending on the results of verification or review.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#alternatives ⇒ Object (readonly)
Fields that are due and can be satisfied by providing the corresponding alternative fields instead.
214 215 216 |
# File 'lib/stripe/resources/person.rb', line 214 def alternatives @alternatives end |
#currently_due ⇒ Object (readonly)
Fields that need to be collected to keep the person’s account enabled. If not collected by the account’s ‘current_deadline`, these fields appear in `past_due` as well, and the account is disabled.
217 218 219 |
# File 'lib/stripe/resources/person.rb', line 217 def currently_due @currently_due end |
#errors ⇒ Object (readonly)
Fields that are ‘currently_due` and need to be collected again because validation or verification failed.
220 221 222 |
# File 'lib/stripe/resources/person.rb', line 220 def errors @errors end |
#eventually_due ⇒ Object (readonly)
Fields that need to be collected assuming all volume thresholds are reached. As they become required, they appear in ‘currently_due` as well, and the account’s ‘current_deadline` becomes set.
223 224 225 |
# File 'lib/stripe/resources/person.rb', line 223 def eventually_due @eventually_due end |
#past_due ⇒ Object (readonly)
Fields that weren’t collected by the account’s ‘current_deadline`. These fields need to be collected to enable the person’s account.
226 227 228 |
# File 'lib/stripe/resources/person.rb', line 226 def past_due @past_due end |
#pending_verification ⇒ Object (readonly)
Fields that might become required depending on the results of verification or review. It’s an empty array unless an asynchronous verification is pending. If verification fails, these fields move to ‘eventually_due`, `currently_due`, or `past_due`. Fields might appear in `eventually_due`, `currently_due`, or `past_due` and in `pending_verification` if verification fails but another verification is still pending.
229 230 231 |
# File 'lib/stripe/resources/person.rb', line 229 def pending_verification @pending_verification end |