Class: Stripe::Person::Verification
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Person::Verification
- Defined in:
- lib/stripe/resources/person.rb
Defined Under Namespace
Classes: AdditionalDocument, Document
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#additional_document ⇒ Object
readonly
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
-
#details ⇒ Object
readonly
A user-displayable string describing the verification state for the person.
-
#details_code ⇒ Object
readonly
One of ‘document_address_mismatch`, `document_dob_mismatch`, `document_duplicate_type`, `document_id_number_mismatch`, `document_name_mismatch`, `document_nationality_mismatch`, `failed_keyed_identity`, or `failed_other`.
-
#document ⇒ Object
readonly
Attribute for field document.
-
#status ⇒ Object
readonly
The state of verification for the person.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#additional_document ⇒ Object (readonly)
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
433 434 435 |
# File 'lib/stripe/resources/person.rb', line 433 def additional_document @additional_document end |
#details ⇒ Object (readonly)
A user-displayable string describing the verification state for the person. For example, this may say “Provided identity information could not be verified”.
435 436 437 |
# File 'lib/stripe/resources/person.rb', line 435 def details @details end |
#details_code ⇒ Object (readonly)
One of ‘document_address_mismatch`, `document_dob_mismatch`, `document_duplicate_type`, `document_id_number_mismatch`, `document_name_mismatch`, `document_nationality_mismatch`, `failed_keyed_identity`, or `failed_other`. A machine-readable code specifying the verification state for the person.
437 438 439 |
# File 'lib/stripe/resources/person.rb', line 437 def details_code @details_code end |
#document ⇒ Object (readonly)
Attribute for field document
439 440 441 |
# File 'lib/stripe/resources/person.rb', line 439 def document @document end |
#status ⇒ Object (readonly)
The state of verification for the person. Possible values are ‘unverified`, `pending`, or `verified`. Please refer [guide](docs.stripe.com/connect/handling-api-verification) to handle verification updates.
441 442 443 |
# File 'lib/stripe/resources/person.rb', line 441 def status @status end |
Class Method Details
.field_remappings ⇒ Object
447 448 449 |
# File 'lib/stripe/resources/person.rb', line 447 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
443 444 445 |
# File 'lib/stripe/resources/person.rb', line 443 def self.inner_class_types @inner_class_types = { additional_document: AdditionalDocument, document: Document } end |