Class: Stripe::Person::Verification

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/person.rb

Defined Under Namespace

Classes: AdditionalDocument, Document

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#additional_documentObject (readonly)

A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.



228
229
230
# File 'lib/stripe/resources/person.rb', line 228

def additional_document
  @additional_document
end

#detailsObject (readonly)

A user-displayable string describing the verification state for the person. For example, this may say “Provided identity information could not be verified”.



230
231
232
# File 'lib/stripe/resources/person.rb', line 230

def details
  @details
end

#details_codeObject (readonly)

One of ‘document_address_mismatch`, `document_dob_mismatch`, `document_duplicate_type`, `document_id_number_mismatch`, `document_name_mismatch`, `document_nationality_mismatch`, `failed_keyed_identity`, or `failed_other`. A machine-readable code specifying the verification state for the person.



232
233
234
# File 'lib/stripe/resources/person.rb', line 232

def details_code
  @details_code
end

#documentObject (readonly)

Attribute for field document



234
235
236
# File 'lib/stripe/resources/person.rb', line 234

def document
  @document
end

#statusObject (readonly)

The state of verification for the person. Possible values are ‘unverified`, `pending`, or `verified`. Please refer [guide](stripe.com/docs/connect/handling-api-verification) to handle verification updates.



236
237
238
# File 'lib/stripe/resources/person.rb', line 236

def status
  @status
end