Class: Stripe::Person::Verification
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Person::Verification
- Defined in:
- lib/stripe/resources/person.rb
Defined Under Namespace
Classes: AdditionalDocument, Document
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#additional_document ⇒ Object
readonly
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
-
#details ⇒ Object
readonly
A user-displayable string describing the verification state for the person.
-
#details_code ⇒ Object
readonly
One of ‘document_address_mismatch`, `document_dob_mismatch`, `document_duplicate_type`, `document_id_number_mismatch`, `document_name_mismatch`, `document_nationality_mismatch`, `failed_keyed_identity`, or `failed_other`.
-
#document ⇒ Object
readonly
Attribute for field document.
-
#status ⇒ Object
readonly
The state of verification for the person.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#additional_document ⇒ Object (readonly)
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
261 262 263 |
# File 'lib/stripe/resources/person.rb', line 261 def additional_document @additional_document end |
#details ⇒ Object (readonly)
A user-displayable string describing the verification state for the person. For example, this may say “Provided identity information could not be verified”.
264 265 266 |
# File 'lib/stripe/resources/person.rb', line 264 def details @details end |
#details_code ⇒ Object (readonly)
One of ‘document_address_mismatch`, `document_dob_mismatch`, `document_duplicate_type`, `document_id_number_mismatch`, `document_name_mismatch`, `document_nationality_mismatch`, `failed_keyed_identity`, or `failed_other`. A machine-readable code specifying the verification state for the person.
267 268 269 |
# File 'lib/stripe/resources/person.rb', line 267 def details_code @details_code end |
#document ⇒ Object (readonly)
Attribute for field document
270 271 272 |
# File 'lib/stripe/resources/person.rb', line 270 def document @document end |
#status ⇒ Object (readonly)
The state of verification for the person. Possible values are ‘unverified`, `pending`, or `verified`.
273 274 275 |
# File 'lib/stripe/resources/person.rb', line 273 def status @status end |