Class: Stripe::Plan::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/plan.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, created: nil, ending_before: nil, expand: nil, limit: nil, product: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/stripe/resources/plan.rb', line 110

def initialize(
  active: nil,
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  product: nil,
  starting_after: nil
)
  @active = active
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @product = product
  @starting_after = starting_after
end

Instance Attribute Details

#activeObject

Only return plans that are active or inactive (e.g., pass ‘false` to list all inactive plans).



96
97
98
# File 'lib/stripe/resources/plan.rb', line 96

def active
  @active
end

#createdObject

A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.



98
99
100
# File 'lib/stripe/resources/plan.rb', line 98

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



100
101
102
# File 'lib/stripe/resources/plan.rb', line 100

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



102
103
104
# File 'lib/stripe/resources/plan.rb', line 102

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



104
105
106
# File 'lib/stripe/resources/plan.rb', line 104

def limit
  @limit
end

#productObject

Only return plans for the given product.



106
107
108
# File 'lib/stripe/resources/plan.rb', line 106

def product
  @product
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



108
109
110
# File 'lib/stripe/resources/plan.rb', line 108

def starting_after
  @starting_after
end