Class: Stripe::Plan::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Plan::ListParams
- Defined in:
- lib/stripe/resources/plan.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#active ⇒ Object
Only return plans that are active or inactive (e.g., pass ‘false` to list all inactive plans).
-
#created ⇒ Object
A filter on the list, based on the object ‘created` field.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#product ⇒ Object
Only return plans for the given product.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(active: nil, created: nil, ending_before: nil, expand: nil, limit: nil, product: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, created: nil, ending_before: nil, expand: nil, limit: nil, product: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/stripe/resources/plan.rb', line 111 def initialize( active: nil, created: nil, ending_before: nil, expand: nil, limit: nil, product: nil, starting_after: nil ) @active = active @created = created @ending_before = ending_before @expand = @limit = limit @product = product @starting_after = starting_after end |
Instance Attribute Details
#active ⇒ Object
Only return plans that are active or inactive (e.g., pass ‘false` to list all inactive plans).
97 98 99 |
# File 'lib/stripe/resources/plan.rb', line 97 def active @active end |
#created ⇒ Object
A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.
99 100 101 |
# File 'lib/stripe/resources/plan.rb', line 99 def created @created end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
101 102 103 |
# File 'lib/stripe/resources/plan.rb', line 101 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
103 104 105 |
# File 'lib/stripe/resources/plan.rb', line 103 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
105 106 107 |
# File 'lib/stripe/resources/plan.rb', line 105 def limit @limit end |
#product ⇒ Object
Only return plans for the given product.
107 108 109 |
# File 'lib/stripe/resources/plan.rb', line 107 def product @product end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
109 110 111 |
# File 'lib/stripe/resources/plan.rb', line 109 def starting_after @starting_after end |