Class: Stripe::PlanService::CreateParams::Product

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/plan_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, id: nil, metadata: nil, name: nil, statement_descriptor: nil, tax_code: nil, unit_label: nil) ⇒ Product

Returns a new instance of Product.



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/stripe/services/plan_service.rb', line 140

def initialize(
  active: nil,
  id: nil,
  metadata: nil,
  name: nil,
  statement_descriptor: nil,
  tax_code: nil,
  unit_label: nil
)
  @active = active
  @id = id
  @metadata = 
  @name = name
  @statement_descriptor = statement_descriptor
  @tax_code = tax_code
  @unit_label = unit_label
end

Instance Attribute Details

#activeObject

Whether the product is currently available for purchase. Defaults to ‘true`.



118
119
120
# File 'lib/stripe/services/plan_service.rb', line 118

def active
  @active
end

#idObject

The identifier for the product. Must be unique. If not provided, an identifier will be randomly generated.



121
122
123
# File 'lib/stripe/services/plan_service.rb', line 121

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



124
125
126
# File 'lib/stripe/services/plan_service.rb', line 124

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



127
128
129
# File 'lib/stripe/services/plan_service.rb', line 127

def name
  @name
end

#statement_descriptorObject

An arbitrary string to be displayed on your customer’s credit card or bank statement. While most banks display this information consistently, some may display it incorrectly or not at all.

This may be up to 22 characters. The statement description may not include ‘<`, `>`, ``, `“`, `’‘ characters, and will appear on your customer’s statement in capital letters. Non-ASCII characters are automatically stripped.



132
133
134
# File 'lib/stripe/services/plan_service.rb', line 132

def statement_descriptor
  @statement_descriptor
end

#tax_codeObject



135
136
137
# File 'lib/stripe/services/plan_service.rb', line 135

def tax_code
  @tax_code
end

#unit_labelObject

A label that represents units of this product. When set, this will be included in customers’ receipts, invoices, Checkout, and the customer portal.



138
139
140
# File 'lib/stripe/services/plan_service.rb', line 138

def unit_label
  @unit_label
end