Class: Stripe::Price

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List, APIOperations::Search
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/price.rb

Overview

Prices define the unit cost, currency, and (optional) billing cycle for both recurring and one-time purchases of products. [Products](stripe.com/docs/api#products) help you track inventory or provisioning, and prices help you track payment terms. Different physical goods or levels of service should be represented by products, and pricing options should be represented by prices. This approach lets you change prices without having to change your provisioning scheme.

For example, you might have a single “gold” product that has prices for $10/month, $100/year, and €9 once.

Related guides: [Set up a subscription](stripe.com/docs/billing/subscriptions/set-up-subscription), [create an invoice](stripe.com/docs/billing/invoices/create), and more about [products and prices](stripe.com/docs/products-prices/overview).

Defined Under Namespace

Classes: CreateParams, CurrencyOptions, CustomUnitAmount, ListParams, MigrateTo, Recurring, RetrieveParams, SearchParams, Tier, TransformQuantity, UpdateParams

Constant Summary collapse

OBJECT_NAME =
"price"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Search

_search

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#activeObject (readonly)

Whether the price can be used for new purchases.



625
626
627
# File 'lib/stripe/resources/price.rb', line 625

def active
  @active
end

#billing_schemeObject (readonly)

Describes how to compute the price per period. Either ‘per_unit` or `tiered`. `per_unit` indicates that the fixed amount (specified in `unit_amount` or `unit_amount_decimal`) will be charged per unit in `quantity` (for prices with `usage_type=licensed`), or per unit of total usage (for prices with `usage_type=metered`). `tiered` indicates that the unit pricing will be computed using a tiering strategy as defined using the `tiers` and `tiers_mode` attributes.



627
628
629
# File 'lib/stripe/resources/price.rb', line 627

def billing_scheme
  @billing_scheme
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



629
630
631
# File 'lib/stripe/resources/price.rb', line 629

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



631
632
633
# File 'lib/stripe/resources/price.rb', line 631

def currency
  @currency
end

#currency_optionsObject (readonly)

Prices defined in each available currency option. Each key must be a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html) and a [supported currency](stripe.com/docs/currencies).



633
634
635
# File 'lib/stripe/resources/price.rb', line 633

def currency_options
  @currency_options
end

#custom_unit_amountObject (readonly)

When set, provides configuration for the amount to be adjusted by the customer during Checkout Sessions and Payment Links.



635
636
637
# File 'lib/stripe/resources/price.rb', line 635

def custom_unit_amount
  @custom_unit_amount
end

#deletedObject (readonly)

Always true for a deleted object



669
670
671
# File 'lib/stripe/resources/price.rb', line 669

def deleted
  @deleted
end

#idObject (readonly)

Unique identifier for the object.



637
638
639
# File 'lib/stripe/resources/price.rb', line 637

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



639
640
641
# File 'lib/stripe/resources/price.rb', line 639

def livemode
  @livemode
end

#lookup_keyObject (readonly)

A lookup key used to retrieve prices dynamically from a static string. This may be up to 200 characters.



641
642
643
# File 'lib/stripe/resources/price.rb', line 641

def lookup_key
  @lookup_key
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



643
644
645
# File 'lib/stripe/resources/price.rb', line 643

def 
  @metadata
end

#migrate_toObject (readonly)

Subscriptions using this price will be migrated to use the new referenced price.



645
646
647
# File 'lib/stripe/resources/price.rb', line 645

def migrate_to
  @migrate_to
end

#nicknameObject (readonly)

A brief description of the price, hidden from customers.



647
648
649
# File 'lib/stripe/resources/price.rb', line 647

def nickname
  @nickname
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



649
650
651
# File 'lib/stripe/resources/price.rb', line 649

def object
  @object
end

#productObject (readonly)

The ID of the product this price is associated with.



651
652
653
# File 'lib/stripe/resources/price.rb', line 651

def product
  @product
end

#recurringObject (readonly)

The recurring components of a price such as ‘interval` and `usage_type`.



653
654
655
# File 'lib/stripe/resources/price.rb', line 653

def recurring
  @recurring
end

#tax_behaviorObject (readonly)

Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.



655
656
657
# File 'lib/stripe/resources/price.rb', line 655

def tax_behavior
  @tax_behavior
end

#tiersObject (readonly)

Each element represents a pricing tier. This parameter requires ‘billing_scheme` to be set to `tiered`. See also the documentation for `billing_scheme`.



657
658
659
# File 'lib/stripe/resources/price.rb', line 657

def tiers
  @tiers
end

#tiers_modeObject (readonly)

Defines if the tiering price should be ‘graduated` or `volume` based. In `volume`-based tiering, the maximum quantity within a period determines the per unit price. In `graduated` tiering, pricing can change as the quantity grows.



659
660
661
# File 'lib/stripe/resources/price.rb', line 659

def tiers_mode
  @tiers_mode
end

#transform_quantityObject (readonly)

Apply a transformation to the reported usage or set quantity before computing the amount billed. Cannot be combined with ‘tiers`.



661
662
663
# File 'lib/stripe/resources/price.rb', line 661

def transform_quantity
  @transform_quantity
end

#typeObject (readonly)

One of ‘one_time` or `recurring` depending on whether the price is for a one-time purchase or a recurring (subscription) purchase.



663
664
665
# File 'lib/stripe/resources/price.rb', line 663

def type
  @type
end

#unit_amountObject (readonly)

The unit amount in cents (or local equivalent) to be charged, represented as a whole integer if possible. Only set if ‘billing_scheme=per_unit`.



665
666
667
# File 'lib/stripe/resources/price.rb', line 665

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject (readonly)

The unit amount in cents (or local equivalent) to be charged, represented as a decimal string with at most 12 decimal places. Only set if ‘billing_scheme=per_unit`.



667
668
669
# File 'lib/stripe/resources/price.rb', line 667

def unit_amount_decimal
  @unit_amount_decimal
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a new price for an existing product. The price can be recurring or one-time.



672
673
674
# File 'lib/stripe/resources/price.rb', line 672

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/prices", params: params, opts: opts)
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of your active prices, excluding [inline prices](stripe.com/docs/products-prices/pricing-models#inline-pricing). For the list of inactive prices, set active to false.



677
678
679
# File 'lib/stripe/resources/price.rb', line 677

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/prices", params: params, opts: opts)
end

.object_nameObject



18
19
20
# File 'lib/stripe/resources/price.rb', line 18

def self.object_name
  "price"
end

.search(params = {}, opts = {}) ⇒ Object



681
682
683
# File 'lib/stripe/resources/price.rb', line 681

def self.search(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/prices/search", params: params, opts: opts)
end

.search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object



685
686
687
# File 'lib/stripe/resources/price.rb', line 685

def self.search_auto_paging_each(params = {}, opts = {}, &blk)
  search(params, opts).auto_paging_each(&blk)
end

.update(price, params = {}, opts = {}) ⇒ Object

Updates the specified price by setting the values of the parameters passed. Any parameters not provided are left unchanged.



690
691
692
693
694
695
696
697
# File 'lib/stripe/resources/price.rb', line 690

def self.update(price, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/prices/%<price>s", { price: CGI.escape(price) }),
    params: params,
    opts: opts
  )
end