Class: Stripe::Price::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Price::CreateParams
- Defined in:
- lib/stripe/resources/price.rb
Defined Under Namespace
Classes: CurrencyOptions, CustomUnitAmount, ProductData, Recurring, Tier, TransformQuantity
Instance Attribute Summary collapse
-
#active ⇒ Object
Whether the price can be used for new purchases.
-
#billing_scheme ⇒ Object
Describes how to compute the price per period.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#currency_options ⇒ Object
Prices defined in each available currency option.
-
#custom_unit_amount ⇒ Object
When set, provides configuration for the amount to be adjusted by the customer during Checkout Sessions and Payment Links.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#lookup_key ⇒ Object
A lookup key used to retrieve prices dynamically from a static string.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#nickname ⇒ Object
A brief description of the price, hidden from customers.
-
#product ⇒ Object
The ID of the product that this price will belong to.
-
#product_data ⇒ Object
These fields can be used to create a new product that this price will belong to.
-
#recurring ⇒ Object
The recurring components of a price such as ‘interval` and `usage_type`.
-
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings.
-
#tiers ⇒ Object
Each element represents a pricing tier.
-
#tiers_mode ⇒ Object
Defines if the tiering price should be ‘graduated` or `volume` based.
-
#transfer_lookup_key ⇒ Object
If set to true, will atomically remove the lookup key from the existing price, and assign it to this price.
-
#transform_quantity ⇒ Object
Apply a transformation to the reported usage or set quantity before computing the billed price.
-
#unit_amount ⇒ Object
A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.
-
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places.
Instance Method Summary collapse
-
#initialize(active: nil, billing_scheme: nil, currency: nil, currency_options: nil, custom_unit_amount: nil, expand: nil, lookup_key: nil, metadata: nil, nickname: nil, product: nil, product_data: nil, recurring: nil, tax_behavior: nil, tiers: nil, tiers_mode: nil, transfer_lookup_key: nil, transform_quantity: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, billing_scheme: nil, currency: nil, currency_options: nil, custom_unit_amount: nil, expand: nil, lookup_key: nil, metadata: nil, nickname: nil, product: nil, product_data: nil, recurring: nil, tax_behavior: nil, tiers: nil, tiers_mode: nil, transfer_lookup_key: nil, transform_quantity: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 |
# File 'lib/stripe/resources/price.rb', line 514 def initialize( active: nil, billing_scheme: nil, currency: nil, currency_options: nil, custom_unit_amount: nil, expand: nil, lookup_key: nil, metadata: nil, nickname: nil, product: nil, product_data: nil, recurring: nil, tax_behavior: nil, tiers: nil, tiers_mode: nil, transfer_lookup_key: nil, transform_quantity: nil, unit_amount: nil, unit_amount_decimal: nil ) @active = active @billing_scheme = billing_scheme @currency = currency @currency_options = @custom_unit_amount = custom_unit_amount @expand = @lookup_key = lookup_key @metadata = @nickname = nickname @product = product @product_data = product_data @recurring = recurring @tax_behavior = tax_behavior @tiers = tiers @tiers_mode = tiers_mode @transfer_lookup_key = transfer_lookup_key @transform_quantity = transform_quantity @unit_amount = unit_amount @unit_amount_decimal = unit_amount_decimal end |
Instance Attribute Details
#active ⇒ Object
Whether the price can be used for new purchases. Defaults to ‘true`.
458 459 460 |
# File 'lib/stripe/resources/price.rb', line 458 def active @active end |
#billing_scheme ⇒ Object
Describes how to compute the price per period. Either ‘per_unit` or `tiered`. `per_unit` indicates that the fixed amount (specified in `unit_amount` or `unit_amount_decimal`) will be charged per unit in `quantity` (for prices with `usage_type=licensed`), or per unit of total usage (for prices with `usage_type=metered`). `tiered` indicates that the unit pricing will be computed using a tiering strategy as defined using the `tiers` and `tiers_mode` attributes.
461 462 463 |
# File 'lib/stripe/resources/price.rb', line 461 def billing_scheme @billing_scheme end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
464 465 466 |
# File 'lib/stripe/resources/price.rb', line 464 def currency @currency end |
#currency_options ⇒ Object
Prices defined in each available currency option. Each key must be a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html) and a [supported currency](stripe.com/docs/currencies).
467 468 469 |
# File 'lib/stripe/resources/price.rb', line 467 def @currency_options end |
#custom_unit_amount ⇒ Object
When set, provides configuration for the amount to be adjusted by the customer during Checkout Sessions and Payment Links.
470 471 472 |
# File 'lib/stripe/resources/price.rb', line 470 def custom_unit_amount @custom_unit_amount end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
473 474 475 |
# File 'lib/stripe/resources/price.rb', line 473 def @expand end |
#lookup_key ⇒ Object
A lookup key used to retrieve prices dynamically from a static string. This may be up to 200 characters.
476 477 478 |
# File 'lib/stripe/resources/price.rb', line 476 def lookup_key @lookup_key end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
479 480 481 |
# File 'lib/stripe/resources/price.rb', line 479 def @metadata end |
#nickname ⇒ Object
A brief description of the price, hidden from customers.
482 483 484 |
# File 'lib/stripe/resources/price.rb', line 482 def nickname @nickname end |
#product ⇒ Object
The ID of the product that this price will belong to.
485 486 487 |
# File 'lib/stripe/resources/price.rb', line 485 def product @product end |
#product_data ⇒ Object
These fields can be used to create a new product that this price will belong to.
488 489 490 |
# File 'lib/stripe/resources/price.rb', line 488 def product_data @product_data end |
#recurring ⇒ Object
The recurring components of a price such as ‘interval` and `usage_type`.
491 492 493 |
# File 'lib/stripe/resources/price.rb', line 491 def recurring @recurring end |
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.
494 495 496 |
# File 'lib/stripe/resources/price.rb', line 494 def tax_behavior @tax_behavior end |
#tiers ⇒ Object
Each element represents a pricing tier. This parameter requires ‘billing_scheme` to be set to `tiered`. See also the documentation for `billing_scheme`.
497 498 499 |
# File 'lib/stripe/resources/price.rb', line 497 def tiers @tiers end |
#tiers_mode ⇒ Object
Defines if the tiering price should be ‘graduated` or `volume` based. In `volume`-based tiering, the maximum quantity within a period determines the per unit price, in `graduated` tiering pricing can successively change as the quantity grows.
500 501 502 |
# File 'lib/stripe/resources/price.rb', line 500 def tiers_mode @tiers_mode end |
#transfer_lookup_key ⇒ Object
If set to true, will atomically remove the lookup key from the existing price, and assign it to this price.
503 504 505 |
# File 'lib/stripe/resources/price.rb', line 503 def transfer_lookup_key @transfer_lookup_key end |
#transform_quantity ⇒ Object
Apply a transformation to the reported usage or set quantity before computing the billed price. Cannot be combined with ‘tiers`.
506 507 508 |
# File 'lib/stripe/resources/price.rb', line 506 def transform_quantity @transform_quantity end |
#unit_amount ⇒ Object
A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge. One of ‘unit_amount`, `unit_amount_decimal`, or `custom_unit_amount` is required, unless `billing_scheme=tiered`.
509 510 511 |
# File 'lib/stripe/resources/price.rb', line 509 def unit_amount @unit_amount end |
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.
512 513 514 |
# File 'lib/stripe/resources/price.rb', line 512 def unit_amount_decimal @unit_amount_decimal end |