Class: Stripe::Price::CreateParams::ProductData

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/price.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, id: nil, metadata: nil, name: nil, statement_descriptor: nil, tax_code: nil, unit_label: nil) ⇒ ProductData

Returns a new instance of ProductData.



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/stripe/resources/price.rb', line 300

def initialize(
  active: nil,
  id: nil,
  metadata: nil,
  name: nil,
  statement_descriptor: nil,
  tax_code: nil,
  unit_label: nil
)
  @active = active
  @id = id
  @metadata = 
  @name = name
  @statement_descriptor = statement_descriptor
  @tax_code = tax_code
  @unit_label = unit_label
end

Instance Attribute Details

#activeObject

Whether the product is currently available for purchase. Defaults to ‘true`.



284
285
286
# File 'lib/stripe/resources/price.rb', line 284

def active
  @active
end

#idObject

The identifier for the product. Must be unique. If not provided, an identifier will be randomly generated.



286
287
288
# File 'lib/stripe/resources/price.rb', line 286

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



288
289
290
# File 'lib/stripe/resources/price.rb', line 288

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



290
291
292
# File 'lib/stripe/resources/price.rb', line 290

def name
  @name
end

#statement_descriptorObject

An arbitrary string to be displayed on your customer’s credit card or bank statement. While most banks display this information consistently, some may display it incorrectly or not at all.

This may be up to 22 characters. The statement description may not include ‘<`, `>`, ``, `“`, `’‘ characters, and will appear on your customer’s statement in capital letters. Non-ASCII characters are automatically stripped.



294
295
296
# File 'lib/stripe/resources/price.rb', line 294

def statement_descriptor
  @statement_descriptor
end

#tax_codeObject



296
297
298
# File 'lib/stripe/resources/price.rb', line 296

def tax_code
  @tax_code
end

#unit_labelObject

A label that represents units of this product. When set, this will be included in customers’ receipts, invoices, Checkout, and the customer portal.



298
299
300
# File 'lib/stripe/resources/price.rb', line 298

def unit_label
  @unit_label
end