Class: Stripe::Price::CreateParams::ProductData

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/price.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, id: nil, metadata: nil, name: nil, statement_descriptor: nil, tax_code: nil, unit_label: nil) ⇒ ProductData

Returns a new instance of ProductData.



359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
# File 'lib/stripe/resources/price.rb', line 359

def initialize(
  active: nil,
  id: nil,
  metadata: nil,
  name: nil,
  statement_descriptor: nil,
  tax_code: nil,
  unit_label: nil
)
  @active = active
  @id = id
  @metadata = 
  @name = name
  @statement_descriptor = statement_descriptor
  @tax_code = tax_code
  @unit_label = unit_label
end

Instance Attribute Details

#activeObject

Whether the product is currently available for purchase. Defaults to ‘true`.



337
338
339
# File 'lib/stripe/resources/price.rb', line 337

def active
  @active
end

#idObject

The identifier for the product. Must be unique. If not provided, an identifier will be randomly generated.



340
341
342
# File 'lib/stripe/resources/price.rb', line 340

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



343
344
345
# File 'lib/stripe/resources/price.rb', line 343

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



346
347
348
# File 'lib/stripe/resources/price.rb', line 346

def name
  @name
end

#statement_descriptorObject

An arbitrary string to be displayed on your customer’s credit card or bank statement. While most banks display this information consistently, some may display it incorrectly or not at all.

This may be up to 22 characters. The statement description may not include ‘<`, `>`, ``, `“`, `’‘ characters, and will appear on your customer’s statement in capital letters. Non-ASCII characters are automatically stripped.



351
352
353
# File 'lib/stripe/resources/price.rb', line 351

def statement_descriptor
  @statement_descriptor
end

#tax_codeObject



354
355
356
# File 'lib/stripe/resources/price.rb', line 354

def tax_code
  @tax_code
end

#unit_labelObject

A label that represents units of this product. When set, this will be included in customers’ receipts, invoices, Checkout, and the customer portal.



357
358
359
# File 'lib/stripe/resources/price.rb', line 357

def unit_label
  @unit_label
end