Class: Stripe::Price::CreateParams::Recurring

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/price.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil, meter: nil, trial_period_days: nil, usage_type: nil) ⇒ Recurring

Returns a new instance of Recurring.



320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/stripe/resources/price.rb', line 320

def initialize(
  interval: nil,
  interval_count: nil,
  meter: nil,
  trial_period_days: nil,
  usage_type: nil
)
  @interval = interval
  @interval_count = interval_count
  @meter = meter
  @trial_period_days = trial_period_days
  @usage_type = usage_type
end

Instance Attribute Details

#intervalObject

Specifies billing frequency. Either ‘day`, `week`, `month` or `year`.



310
311
312
# File 'lib/stripe/resources/price.rb', line 310

def interval
  @interval
end

#interval_countObject

The number of intervals between subscription billings. For example, ‘interval=month` and `interval_count=3` bills every 3 months. Maximum of three years interval allowed (3 years, 36 months, or 156 weeks).



312
313
314
# File 'lib/stripe/resources/price.rb', line 312

def interval_count
  @interval_count
end

#meterObject

The meter tracking the usage of a metered price



314
315
316
# File 'lib/stripe/resources/price.rb', line 314

def meter
  @meter
end

#trial_period_daysObject

Default number of trial days when subscribing a customer to this price using [‘trial_from_plan=true`](stripe.com/docs/api#create_subscription-trial_from_plan).



316
317
318
# File 'lib/stripe/resources/price.rb', line 316

def trial_period_days
  @trial_period_days
end

#usage_typeObject

Configures how the quantity per period should be determined. Can be either ‘metered` or `licensed`. `licensed` automatically bills the `quantity` set when adding it to a subscription. `metered` aggregates the total usage based on usage records. Defaults to `licensed`.



318
319
320
# File 'lib/stripe/resources/price.rb', line 318

def usage_type
  @usage_type
end