Class: Stripe::Price::CreateParams::Tier
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Price::CreateParams::Tier
- Defined in:
- lib/stripe/resources/price.rb
Instance Attribute Summary collapse
-
#flat_amount ⇒ Object
The flat billing amount for an entire tier, regardless of the number of units in the tier.
-
#flat_amount_decimal ⇒ Object
Same as ‘flat_amount`, but accepts a decimal value representing an integer in the minor units of the currency.
-
#unit_amount ⇒ Object
The per unit billing amount for each individual unit for which this tier applies.
-
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places.
-
#up_to ⇒ Object
Specifies the upper bound of this tier.
Instance Method Summary collapse
-
#initialize(flat_amount: nil, flat_amount_decimal: nil, unit_amount: nil, unit_amount_decimal: nil, up_to: nil) ⇒ Tier
constructor
A new instance of Tier.
Methods inherited from RequestParams
Constructor Details
#initialize(flat_amount: nil, flat_amount_decimal: nil, unit_amount: nil, unit_amount_decimal: nil, up_to: nil) ⇒ Tier
Returns a new instance of Tier.
430 431 432 433 434 435 436 437 438 439 440 441 442 |
# File 'lib/stripe/resources/price.rb', line 430 def initialize( flat_amount: nil, flat_amount_decimal: nil, unit_amount: nil, unit_amount_decimal: nil, up_to: nil ) @flat_amount = flat_amount @flat_amount_decimal = flat_amount_decimal @unit_amount = unit_amount @unit_amount_decimal = unit_amount_decimal @up_to = up_to end |
Instance Attribute Details
#flat_amount ⇒ Object
The flat billing amount for an entire tier, regardless of the number of units in the tier.
416 417 418 |
# File 'lib/stripe/resources/price.rb', line 416 def flat_amount @flat_amount end |
#flat_amount_decimal ⇒ Object
Same as ‘flat_amount`, but accepts a decimal value representing an integer in the minor units of the currency. Only one of `flat_amount` and `flat_amount_decimal` can be set.
419 420 421 |
# File 'lib/stripe/resources/price.rb', line 419 def flat_amount_decimal @flat_amount_decimal end |
#unit_amount ⇒ Object
The per unit billing amount for each individual unit for which this tier applies.
422 423 424 |
# File 'lib/stripe/resources/price.rb', line 422 def unit_amount @unit_amount end |
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.
425 426 427 |
# File 'lib/stripe/resources/price.rb', line 425 def unit_amount_decimal @unit_amount_decimal end |
#up_to ⇒ Object
Specifies the upper bound of this tier. The lower bound of a tier is the upper bound of the previous tier adding one. Use ‘inf` to define a fallback tier.
428 429 430 |
# File 'lib/stripe/resources/price.rb', line 428 def up_to @up_to end |