Class: Stripe::Price::CurrencyOptions

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/price.rb

Defined Under Namespace

Classes: CustomUnitAmount, Tier

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#custom_unit_amountObject (readonly)

When set, provides configuration for the amount to be adjusted by the customer during Checkout Sessions and Payment Links.



51
52
53
# File 'lib/stripe/resources/price.rb', line 51

def custom_unit_amount
  @custom_unit_amount
end

#tax_behaviorObject (readonly)

Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.



54
55
56
# File 'lib/stripe/resources/price.rb', line 54

def tax_behavior
  @tax_behavior
end

#tiersObject (readonly)

Each element represents a pricing tier. This parameter requires ‘billing_scheme` to be set to `tiered`. See also the documentation for `billing_scheme`.



57
58
59
# File 'lib/stripe/resources/price.rb', line 57

def tiers
  @tiers
end

#unit_amountObject (readonly)

The unit amount in cents (or local equivalent) to be charged, represented as a whole integer if possible. Only set if ‘billing_scheme=per_unit`.



60
61
62
# File 'lib/stripe/resources/price.rb', line 60

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject (readonly)

The unit amount in cents (or local equivalent) to be charged, represented as a decimal string with at most 12 decimal places. Only set if ‘billing_scheme=per_unit`.



63
64
65
# File 'lib/stripe/resources/price.rb', line 63

def unit_amount_decimal
  @unit_amount_decimal
end