Class: Stripe::Price::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Price::ListParams
- Defined in:
- lib/stripe/resources/price.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#active ⇒ Object
Only return prices that are active or inactive (e.g., pass ‘false` to list all inactive prices).
-
#created ⇒ Object
A filter on the list, based on the object ‘created` field.
-
#currency ⇒ Object
Only return prices for the given currency.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#lookup_keys ⇒ Object
Only return the price with these lookup_keys, if any exist.
-
#product ⇒ Object
Only return prices for the given product.
-
#recurring ⇒ Object
Only return prices with these recurring fields.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#type ⇒ Object
Only return prices of type ‘recurring` or `one_time`.
Instance Method Summary collapse
-
#initialize(active: nil, created: nil, currency: nil, ending_before: nil, expand: nil, limit: nil, lookup_keys: nil, product: nil, recurring: nil, starting_after: nil, type: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, created: nil, currency: nil, ending_before: nil, expand: nil, limit: nil, lookup_keys: nil, product: nil, recurring: nil, starting_after: nil, type: nil) ⇒ ListParams
Returns a new instance of ListParams.
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/stripe/resources/price.rb', line 163 def initialize( active: nil, created: nil, currency: nil, ending_before: nil, expand: nil, limit: nil, lookup_keys: nil, product: nil, recurring: nil, starting_after: nil, type: nil ) @active = active @created = created @currency = currency @ending_before = ending_before @expand = @limit = limit @lookup_keys = lookup_keys @product = product @recurring = recurring @starting_after = starting_after @type = type end |
Instance Attribute Details
#active ⇒ Object
Only return prices that are active or inactive (e.g., pass ‘false` to list all inactive prices).
141 142 143 |
# File 'lib/stripe/resources/price.rb', line 141 def active @active end |
#created ⇒ Object
A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.
143 144 145 |
# File 'lib/stripe/resources/price.rb', line 143 def created @created end |
#currency ⇒ Object
Only return prices for the given currency.
145 146 147 |
# File 'lib/stripe/resources/price.rb', line 145 def currency @currency end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
147 148 149 |
# File 'lib/stripe/resources/price.rb', line 147 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
149 150 151 |
# File 'lib/stripe/resources/price.rb', line 149 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
151 152 153 |
# File 'lib/stripe/resources/price.rb', line 151 def limit @limit end |
#lookup_keys ⇒ Object
Only return the price with these lookup_keys, if any exist. You can specify up to 10 lookup_keys.
153 154 155 |
# File 'lib/stripe/resources/price.rb', line 153 def lookup_keys @lookup_keys end |
#product ⇒ Object
Only return prices for the given product.
155 156 157 |
# File 'lib/stripe/resources/price.rb', line 155 def product @product end |
#recurring ⇒ Object
Only return prices with these recurring fields.
157 158 159 |
# File 'lib/stripe/resources/price.rb', line 157 def recurring @recurring end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
159 160 161 |
# File 'lib/stripe/resources/price.rb', line 159 def starting_after @starting_after end |
#type ⇒ Object
Only return prices of type ‘recurring` or `one_time`.
161 162 163 |
# File 'lib/stripe/resources/price.rb', line 161 def type @type end |