Class: Stripe::Price::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/price.rb

Defined Under Namespace

Classes: Created, Recurring

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, created: nil, currency: nil, ending_before: nil, expand: nil, limit: nil, lookup_keys: nil, product: nil, recurring: nil, starting_after: nil, type: nil) ⇒ ListParams

Returns a new instance of ListParams.



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/stripe/resources/price.rb', line 204

def initialize(
  active: nil,
  created: nil,
  currency: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  lookup_keys: nil,
  product: nil,
  recurring: nil,
  starting_after: nil,
  type: nil
)
  @active = active
  @created = created
  @currency = currency
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @lookup_keys = lookup_keys
  @product = product
  @recurring = recurring
  @starting_after = starting_after
  @type = type
end

Instance Attribute Details

#activeObject

Only return prices that are active or inactive (e.g., pass ‘false` to list all inactive prices).



172
173
174
# File 'lib/stripe/resources/price.rb', line 172

def active
  @active
end

#createdObject

A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.



175
176
177
# File 'lib/stripe/resources/price.rb', line 175

def created
  @created
end

#currencyObject

Only return prices for the given currency.



178
179
180
# File 'lib/stripe/resources/price.rb', line 178

def currency
  @currency
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



181
182
183
# File 'lib/stripe/resources/price.rb', line 181

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



184
185
186
# File 'lib/stripe/resources/price.rb', line 184

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



187
188
189
# File 'lib/stripe/resources/price.rb', line 187

def limit
  @limit
end

#lookup_keysObject

Only return the price with these lookup_keys, if any exist. You can specify up to 10 lookup_keys.



190
191
192
# File 'lib/stripe/resources/price.rb', line 190

def lookup_keys
  @lookup_keys
end

#productObject

Only return prices for the given product.



193
194
195
# File 'lib/stripe/resources/price.rb', line 193

def product
  @product
end

#recurringObject

Only return prices with these recurring fields.



196
197
198
# File 'lib/stripe/resources/price.rb', line 196

def recurring
  @recurring
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



199
200
201
# File 'lib/stripe/resources/price.rb', line 199

def starting_after
  @starting_after
end

#typeObject

Only return prices of type ‘recurring` or `one_time`.



202
203
204
# File 'lib/stripe/resources/price.rb', line 202

def type
  @type
end