Class: Stripe::Price::MigrateTo
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Price::MigrateTo
- Defined in:
- lib/stripe/resources/price.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#behavior ⇒ Object
readonly
The behavior controlling at what point in the subscription lifecycle to migrate the price.
-
#effective_after ⇒ Object
readonly
The unix timestamp after at which subscriptions will start to migrate to the new price.
-
#price ⇒ Object
readonly
The id of the price being migrated to.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#behavior ⇒ Object (readonly)
The behavior controlling at what point in the subscription lifecycle to migrate the price
119 120 121 |
# File 'lib/stripe/resources/price.rb', line 119 def behavior @behavior end |
#effective_after ⇒ Object (readonly)
The unix timestamp after at which subscriptions will start to migrate to the new price.
121 122 123 |
# File 'lib/stripe/resources/price.rb', line 121 def effective_after @effective_after end |
#price ⇒ Object (readonly)
The id of the price being migrated to
123 124 125 |
# File 'lib/stripe/resources/price.rb', line 123 def price @price end |
Class Method Details
.field_remappings ⇒ Object
129 130 131 |
# File 'lib/stripe/resources/price.rb', line 129 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
125 126 127 |
# File 'lib/stripe/resources/price.rb', line 125 def self.inner_class_types @inner_class_types = {} end |