Class: Stripe::Price::MigrateTo

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/price.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#behaviorObject (readonly)

The behavior controlling at what point in the subscription lifecycle to migrate the price



67
68
69
# File 'lib/stripe/resources/price.rb', line 67

def behavior
  @behavior
end

#effective_afterObject (readonly)

The unix timestamp after at which subscriptions will start to migrate to the new price.



69
70
71
# File 'lib/stripe/resources/price.rb', line 69

def effective_after
  @effective_after
end

#priceObject (readonly)

The id of the price being migrated to



71
72
73
# File 'lib/stripe/resources/price.rb', line 71

def price
  @price
end