Class: Stripe::Price::MigrateTo
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Price::MigrateTo
- Defined in:
- lib/stripe/resources/price.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#behavior ⇒ Object
readonly
The behavior controlling at what point in the subscription lifecycle to migrate the price.
-
#effective_after ⇒ Object
readonly
The unix timestamp after at which subscriptions will start to migrate to the new price.
-
#price ⇒ Object
readonly
The id of the price being migrated to.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#behavior ⇒ Object (readonly)
The behavior controlling at what point in the subscription lifecycle to migrate the price
79 80 81 |
# File 'lib/stripe/resources/price.rb', line 79 def behavior @behavior end |
#effective_after ⇒ Object (readonly)
The unix timestamp after at which subscriptions will start to migrate to the new price.
82 83 84 |
# File 'lib/stripe/resources/price.rb', line 82 def effective_after @effective_after end |
#price ⇒ Object (readonly)
The id of the price being migrated to
85 86 87 |
# File 'lib/stripe/resources/price.rb', line 85 def price @price end |