Class: Stripe::Price::SearchParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Price::SearchParams
- Defined in:
- lib/stripe/resources/price.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#page ⇒ Object
A cursor for pagination across multiple pages of results.
-
#query ⇒ Object
The search query string.
Instance Method Summary collapse
-
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
constructor
A new instance of SearchParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
Returns a new instance of SearchParams.
617 618 619 620 621 622 |
# File 'lib/stripe/resources/price.rb', line 617 def initialize(expand: nil, limit: nil, page: nil, query: nil) @expand = @limit = limit @page = page @query = query end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
609 610 611 |
# File 'lib/stripe/resources/price.rb', line 609 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
611 612 613 |
# File 'lib/stripe/resources/price.rb', line 611 def limit @limit end |
#page ⇒ Object
A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.
613 614 615 |
# File 'lib/stripe/resources/price.rb', line 613 def page @page end |
#query ⇒ Object
The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for prices](stripe.com/docs/search#query-fields-for-prices).
615 616 617 |
# File 'lib/stripe/resources/price.rb', line 615 def query @query end |