Class: Stripe::Price::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/price.rb

Defined Under Namespace

Classes: CurrencyOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, currency_options: nil, expand: nil, lookup_key: nil, metadata: nil, nickname: nil, tax_behavior: nil, transfer_lookup_key: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
# File 'lib/stripe/resources/price.rb', line 543

def initialize(
  active: nil,
  currency_options: nil,
  expand: nil,
  lookup_key: nil,
  metadata: nil,
  nickname: nil,
  tax_behavior: nil,
  transfer_lookup_key: nil
)
  @active = active
  @currency_options = currency_options
  @expand = expand
  @lookup_key = lookup_key
  @metadata = 
  @nickname = nickname
  @tax_behavior = tax_behavior
  @transfer_lookup_key = transfer_lookup_key
end

Instance Attribute Details

#activeObject

Whether the price can be used for new purchases. Defaults to ‘true`.



527
528
529
# File 'lib/stripe/resources/price.rb', line 527

def active
  @active
end

#currency_optionsObject

Prices defined in each available currency option. Each key must be a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html) and a [supported currency](stripe.com/docs/currencies).



529
530
531
# File 'lib/stripe/resources/price.rb', line 529

def currency_options
  @currency_options
end

#expandObject

Specifies which fields in the response should be expanded.



531
532
533
# File 'lib/stripe/resources/price.rb', line 531

def expand
  @expand
end

#lookup_keyObject

A lookup key used to retrieve prices dynamically from a static string. This may be up to 200 characters.



533
534
535
# File 'lib/stripe/resources/price.rb', line 533

def lookup_key
  @lookup_key
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



535
536
537
# File 'lib/stripe/resources/price.rb', line 535

def 
  @metadata
end

#nicknameObject

A brief description of the price, hidden from customers.



537
538
539
# File 'lib/stripe/resources/price.rb', line 537

def nickname
  @nickname
end

#tax_behaviorObject

Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.



539
540
541
# File 'lib/stripe/resources/price.rb', line 539

def tax_behavior
  @tax_behavior
end

#transfer_lookup_keyObject

If set to true, will atomically remove the lookup key from the existing price, and assign it to this price.



541
542
543
# File 'lib/stripe/resources/price.rb', line 541

def transfer_lookup_key
  @transfer_lookup_key
end