Class: Stripe::Price::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/price.rb

Defined Under Namespace

Classes: CurrencyOptions, MigrateTo

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, currency_options: nil, expand: nil, lookup_key: nil, metadata: nil, migrate_to: nil, nickname: nil, tax_behavior: nil, transfer_lookup_key: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
# File 'lib/stripe/resources/price.rb', line 692

def initialize(
  active: nil,
  currency_options: nil,
  expand: nil,
  lookup_key: nil,
  metadata: nil,
  migrate_to: nil,
  nickname: nil,
  tax_behavior: nil,
  transfer_lookup_key: nil
)
  @active = active
  @currency_options = currency_options
  @expand = expand
  @lookup_key = lookup_key
  @metadata = 
  @migrate_to = migrate_to
  @nickname = nickname
  @tax_behavior = tax_behavior
  @transfer_lookup_key = transfer_lookup_key
end

Instance Attribute Details

#activeObject

Whether the price can be used for new purchases. Defaults to ‘true`.



666
667
668
# File 'lib/stripe/resources/price.rb', line 666

def active
  @active
end

#currency_optionsObject

Prices defined in each available currency option. Each key must be a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html) and a [supported currency](stripe.com/docs/currencies).



669
670
671
# File 'lib/stripe/resources/price.rb', line 669

def currency_options
  @currency_options
end

#expandObject

Specifies which fields in the response should be expanded.



672
673
674
# File 'lib/stripe/resources/price.rb', line 672

def expand
  @expand
end

#lookup_keyObject

A lookup key used to retrieve prices dynamically from a static string. This may be up to 200 characters.



675
676
677
# File 'lib/stripe/resources/price.rb', line 675

def lookup_key
  @lookup_key
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



678
679
680
# File 'lib/stripe/resources/price.rb', line 678

def 
  @metadata
end

#migrate_toObject

If specified, subscriptions using this price will be updated to use the new referenced price.



681
682
683
# File 'lib/stripe/resources/price.rb', line 681

def migrate_to
  @migrate_to
end

#nicknameObject

A brief description of the price, hidden from customers.



684
685
686
# File 'lib/stripe/resources/price.rb', line 684

def nickname
  @nickname
end

#tax_behaviorObject

Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.



687
688
689
# File 'lib/stripe/resources/price.rb', line 687

def tax_behavior
  @tax_behavior
end

#transfer_lookup_keyObject

If set to true, will atomically remove the lookup key from the existing price, and assign it to this price.



690
691
692
# File 'lib/stripe/resources/price.rb', line 690

def transfer_lookup_key
  @transfer_lookup_key
end