Class: Stripe::Price::UpdateParams::CurrencyOptions::CustomUnitAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Price::UpdateParams::CurrencyOptions::CustomUnitAmount
- Defined in:
- lib/stripe/resources/price.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Pass in ‘true` to enable `custom_unit_amount`, otherwise omit `custom_unit_amount`.
-
#maximum ⇒ Object
The maximum unit amount the customer can specify for this item.
-
#minimum ⇒ Object
The minimum unit amount the customer can specify for this item.
-
#preset ⇒ Object
The starting unit amount which can be updated by the customer.
Instance Method Summary collapse
-
#initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) ⇒ CustomUnitAmount
constructor
A new instance of CustomUnitAmount.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) ⇒ CustomUnitAmount
Returns a new instance of CustomUnitAmount.
581 582 583 584 585 586 |
# File 'lib/stripe/resources/price.rb', line 581 def initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) @enabled = enabled @maximum = maximum @minimum = minimum @preset = preset end |
Instance Attribute Details
#enabled ⇒ Object
Pass in ‘true` to enable `custom_unit_amount`, otherwise omit `custom_unit_amount`.
570 571 572 |
# File 'lib/stripe/resources/price.rb', line 570 def enabled @enabled end |
#maximum ⇒ Object
The maximum unit amount the customer can specify for this item.
573 574 575 |
# File 'lib/stripe/resources/price.rb', line 573 def maximum @maximum end |
#minimum ⇒ Object
The minimum unit amount the customer can specify for this item. Must be at least the minimum charge amount.
576 577 578 |
# File 'lib/stripe/resources/price.rb', line 576 def minimum @minimum end |
#preset ⇒ Object
The starting unit amount which can be updated by the customer.
579 580 581 |
# File 'lib/stripe/resources/price.rb', line 579 def preset @preset end |