Class: Stripe::Price::UpdateParams::MigrateTo

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/price.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(behavior: nil, effective_after: nil, price: nil) ⇒ MigrateTo

Returns a new instance of MigrateTo.



544
545
546
547
548
# File 'lib/stripe/resources/price.rb', line 544

def initialize(behavior: nil, effective_after: nil, price: nil)
  @behavior = behavior
  @effective_after = effective_after
  @price = price
end

Instance Attribute Details

#behaviorObject

The behavior controlling the point in the subscription lifecycle after which to migrate the price. Currently must be ‘at_cycle_end`.



538
539
540
# File 'lib/stripe/resources/price.rb', line 538

def behavior
  @behavior
end

#effective_afterObject

The time after which subscriptions should start using the new price.



540
541
542
# File 'lib/stripe/resources/price.rb', line 540

def effective_after
  @effective_after
end

#priceObject

The ID of the price object.



542
543
544
# File 'lib/stripe/resources/price.rb', line 542

def price
  @price
end