Class: Stripe::Price::UpdateParams::MigrateTo

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/price.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(behavior: nil, effective_after: nil, price: nil) ⇒ MigrateTo

Returns a new instance of MigrateTo.



659
660
661
662
663
# File 'lib/stripe/resources/price.rb', line 659

def initialize(behavior: nil, effective_after: nil, price: nil)
  @behavior = behavior
  @effective_after = effective_after
  @price = price
end

Instance Attribute Details

#behaviorObject

The behavior controlling the point in the subscription lifecycle after which to migrate the price. Currently must be ‘at_cycle_end`.



651
652
653
# File 'lib/stripe/resources/price.rb', line 651

def behavior
  @behavior
end

#effective_afterObject

The time after which subscriptions should start using the new price.



654
655
656
# File 'lib/stripe/resources/price.rb', line 654

def effective_after
  @effective_after
end

#priceObject

The ID of the price object.



657
658
659
# File 'lib/stripe/resources/price.rb', line 657

def price
  @price
end