Class: Stripe::Price::UpdateParams::MigrateTo

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/price.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(behavior: nil, effective_after: nil, price: nil) ⇒ MigrateTo

Returns a new instance of MigrateTo.



559
560
561
562
563
# File 'lib/stripe/resources/price.rb', line 559

def initialize(behavior: nil, effective_after: nil, price: nil)
  @behavior = behavior
  @effective_after = effective_after
  @price = price
end

Instance Attribute Details

#behaviorObject

The behavior controlling the point in the subscription lifecycle after which to migrate the price. Currently must be ‘at_cycle_end`.



553
554
555
# File 'lib/stripe/resources/price.rb', line 553

def behavior
  @behavior
end

#effective_afterObject

The time after which subscriptions should start using the new price.



555
556
557
# File 'lib/stripe/resources/price.rb', line 555

def effective_after
  @effective_after
end

#priceObject

The ID of the price object.



557
558
559
# File 'lib/stripe/resources/price.rb', line 557

def price
  @price
end