Class: Stripe::PriceCreateParams::ProductData

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/price_create_params.rb

Defined Under Namespace

Classes: TaxDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, id: nil, metadata: nil, name: nil, statement_descriptor: nil, tax_code: nil, unit_label: nil, tax_details: nil) ⇒ ProductData

Returns a new instance of ProductData.



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/stripe/params/price_create_params.rb', line 126

def initialize(
  active: nil,
  id: nil,
  metadata: nil,
  name: nil,
  statement_descriptor: nil,
  tax_code: nil,
  unit_label: nil,
  tax_details: nil
)
  @active = active
  @id = id
  @metadata = 
  @name = name
  @statement_descriptor = statement_descriptor
  @tax_code = tax_code
  @unit_label = unit_label
  @tax_details = tax_details
end

Instance Attribute Details

#activeObject

Whether the product is currently available for purchase. Defaults to ‘true`.



108
109
110
# File 'lib/stripe/params/price_create_params.rb', line 108

def active
  @active
end

#idObject

The identifier for the product. Must be unique. If not provided, an identifier will be randomly generated.



110
111
112
# File 'lib/stripe/params/price_create_params.rb', line 110

def id
  @id
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



112
113
114
# File 'lib/stripe/params/price_create_params.rb', line 112

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



114
115
116
# File 'lib/stripe/params/price_create_params.rb', line 114

def name
  @name
end

#statement_descriptorObject

An arbitrary string to be displayed on your customer’s credit card or bank statement. While most banks display this information consistently, some may display it incorrectly or not at all.

This may be up to 22 characters. The statement description may not include ‘<`, `>`, ``, `“`, `’‘ characters, and will appear on your customer’s statement in capital letters. Non-ASCII characters are automatically stripped.



118
119
120
# File 'lib/stripe/params/price_create_params.rb', line 118

def statement_descriptor
  @statement_descriptor
end

#tax_codeObject



120
121
122
# File 'lib/stripe/params/price_create_params.rb', line 120

def tax_code
  @tax_code
end

#tax_detailsObject

Tax details for this product, including the [tax code](/tax/tax-codes) and an optional performance location.



124
125
126
# File 'lib/stripe/params/price_create_params.rb', line 124

def tax_details
  @tax_details
end

#unit_labelObject

A label that represents units of this product. When set, this will be included in customers’ receipts, invoices, Checkout, and the customer portal.



122
123
124
# File 'lib/stripe/params/price_create_params.rb', line 122

def unit_label
  @unit_label
end