Class: Stripe::PriceService::SearchParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PriceService::SearchParams
- Defined in:
- lib/stripe/services/price_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#page ⇒ Object
A cursor for pagination across multiple pages of results.
-
#query ⇒ Object
The search query string.
Instance Method Summary collapse
-
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
constructor
A new instance of SearchParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
Returns a new instance of SearchParams.
491 492 493 494 495 496 |
# File 'lib/stripe/services/price_service.rb', line 491 def initialize(expand: nil, limit: nil, page: nil, query: nil) @expand = @limit = limit @page = page @query = query end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
483 484 485 |
# File 'lib/stripe/services/price_service.rb', line 483 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
485 486 487 |
# File 'lib/stripe/services/price_service.rb', line 485 def limit @limit end |
#page ⇒ Object
A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.
487 488 489 |
# File 'lib/stripe/services/price_service.rb', line 487 def page @page end |
#query ⇒ Object
The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for prices](stripe.com/docs/search#query-fields-for-prices).
489 490 491 |
# File 'lib/stripe/services/price_service.rb', line 489 def query @query end |