Class: Stripe::PriceService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PriceService::UpdateParams
- Defined in:
- lib/stripe/services/price_service.rb
Defined Under Namespace
Classes: CurrencyOptions, MigrateTo
Instance Attribute Summary collapse
-
#active ⇒ Object
Whether the price can be used for new purchases.
-
#currency_options ⇒ Object
Prices defined in each available currency option.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#lookup_key ⇒ Object
A lookup key used to retrieve prices dynamically from a static string.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#migrate_to ⇒ Object
If specified, subscriptions using this price will be updated to use the new referenced price.
-
#nickname ⇒ Object
A brief description of the price, hidden from customers.
-
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings.
-
#transfer_lookup_key ⇒ Object
If set to true, will atomically remove the lookup key from the existing price, and assign it to this price.
Instance Method Summary collapse
-
#initialize(active: nil, currency_options: nil, expand: nil, lookup_key: nil, metadata: nil, migrate_to: nil, nickname: nil, tax_behavior: nil, transfer_lookup_key: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, currency_options: nil, expand: nil, lookup_key: nil, metadata: nil, migrate_to: nil, nickname: nil, tax_behavior: nil, transfer_lookup_key: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 |
# File 'lib/stripe/services/price_service.rb', line 565 def initialize( active: nil, currency_options: nil, expand: nil, lookup_key: nil, metadata: nil, migrate_to: nil, nickname: nil, tax_behavior: nil, transfer_lookup_key: nil ) @active = active @currency_options = @expand = @lookup_key = lookup_key @metadata = @migrate_to = migrate_to @nickname = nickname @tax_behavior = tax_behavior @transfer_lookup_key = transfer_lookup_key end |
Instance Attribute Details
#active ⇒ Object
Whether the price can be used for new purchases. Defaults to ‘true`.
539 540 541 |
# File 'lib/stripe/services/price_service.rb', line 539 def active @active end |
#currency_options ⇒ Object
Prices defined in each available currency option. Each key must be a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html) and a [supported currency](stripe.com/docs/currencies).
542 543 544 |
# File 'lib/stripe/services/price_service.rb', line 542 def @currency_options end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
545 546 547 |
# File 'lib/stripe/services/price_service.rb', line 545 def @expand end |
#lookup_key ⇒ Object
A lookup key used to retrieve prices dynamically from a static string. This may be up to 200 characters.
548 549 550 |
# File 'lib/stripe/services/price_service.rb', line 548 def lookup_key @lookup_key end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
551 552 553 |
# File 'lib/stripe/services/price_service.rb', line 551 def @metadata end |
#migrate_to ⇒ Object
If specified, subscriptions using this price will be updated to use the new referenced price.
554 555 556 |
# File 'lib/stripe/services/price_service.rb', line 554 def migrate_to @migrate_to end |
#nickname ⇒ Object
A brief description of the price, hidden from customers.
557 558 559 |
# File 'lib/stripe/services/price_service.rb', line 557 def nickname @nickname end |
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.
560 561 562 |
# File 'lib/stripe/services/price_service.rb', line 560 def tax_behavior @tax_behavior end |
#transfer_lookup_key ⇒ Object
If set to true, will atomically remove the lookup key from the existing price, and assign it to this price.
563 564 565 |
# File 'lib/stripe/services/price_service.rb', line 563 def transfer_lookup_key @transfer_lookup_key end |