Class: Stripe::PriceService::UpdateParams::MigrateTo

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/price_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(behavior: nil, effective_after: nil, price: nil) ⇒ MigrateTo

Returns a new instance of MigrateTo.



532
533
534
535
536
# File 'lib/stripe/services/price_service.rb', line 532

def initialize(behavior: nil, effective_after: nil, price: nil)
  @behavior = behavior
  @effective_after = effective_after
  @price = price
end

Instance Attribute Details

#behaviorObject

The behavior controlling the point in the subscription lifecycle after which to migrate the price. Currently must be ‘at_cycle_end`.



524
525
526
# File 'lib/stripe/services/price_service.rb', line 524

def behavior
  @behavior
end

#effective_afterObject

The time after which subscriptions should start using the new price.



527
528
529
# File 'lib/stripe/services/price_service.rb', line 527

def effective_after
  @effective_after
end

#priceObject

The ID of the price object.



530
531
532
# File 'lib/stripe/services/price_service.rb', line 530

def price
  @price
end