Class: Stripe::PriceService::UpdateParams::MigrateTo
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PriceService::UpdateParams::MigrateTo
- Defined in:
- lib/stripe/services/price_service.rb
Instance Attribute Summary collapse
-
#behavior ⇒ Object
The behavior controlling the point in the subscription lifecycle after which to migrate the price.
-
#effective_after ⇒ Object
The time after which subscriptions should start using the new price.
-
#price ⇒ Object
The ID of the price object.
Instance Method Summary collapse
-
#initialize(behavior: nil, effective_after: nil, price: nil) ⇒ MigrateTo
constructor
A new instance of MigrateTo.
Methods inherited from RequestParams
Constructor Details
#initialize(behavior: nil, effective_after: nil, price: nil) ⇒ MigrateTo
Returns a new instance of MigrateTo.
456 457 458 459 460 |
# File 'lib/stripe/services/price_service.rb', line 456 def initialize(behavior: nil, effective_after: nil, price: nil) @behavior = behavior @effective_after = effective_after @price = price end |
Instance Attribute Details
#behavior ⇒ Object
The behavior controlling the point in the subscription lifecycle after which to migrate the price. Currently must be ‘at_cycle_end`.
450 451 452 |
# File 'lib/stripe/services/price_service.rb', line 450 def behavior @behavior end |
#effective_after ⇒ Object
The time after which subscriptions should start using the new price.
452 453 454 |
# File 'lib/stripe/services/price_service.rb', line 452 def effective_after @effective_after end |
#price ⇒ Object
The ID of the price object.
454 455 456 |
# File 'lib/stripe/services/price_service.rb', line 454 def price @price end |