Class: Stripe::PriceUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PriceUpdateParams
- Defined in:
- lib/stripe/params/price_update_params.rb
Defined Under Namespace
Classes: CurrencyOptions, MigrateTo
Instance Attribute Summary collapse
-
#active ⇒ Object
Whether the price can be used for new purchases.
-
#currency_options ⇒ Object
Prices defined in each available currency option.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#lookup_key ⇒ Object
A lookup key used to retrieve prices dynamically from a static string.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#migrate_to ⇒ Object
If specified, subscriptions using this price will be updated to use the new referenced price.
-
#nickname ⇒ Object
A brief description of the price, hidden from customers.
-
#tax_behavior ⇒ Object
Only required if a default tax behavior was not provided in the Stripe Tax settings.
-
#transfer_lookup_key ⇒ Object
If set to true, will atomically remove the lookup key from the existing price, and assign it to this price.
Instance Method Summary collapse
-
#initialize(active: nil, currency_options: nil, expand: nil, lookup_key: nil, metadata: nil, migrate_to: nil, nickname: nil, tax_behavior: nil, transfer_lookup_key: nil) ⇒ PriceUpdateParams
constructor
A new instance of PriceUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(active: nil, currency_options: nil, expand: nil, lookup_key: nil, metadata: nil, migrate_to: nil, nickname: nil, tax_behavior: nil, transfer_lookup_key: nil) ⇒ PriceUpdateParams
Returns a new instance of PriceUpdateParams.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/stripe/params/price_update_params.rb', line 130 def initialize( active: nil, currency_options: nil, expand: nil, lookup_key: nil, metadata: nil, migrate_to: nil, nickname: nil, tax_behavior: nil, transfer_lookup_key: nil ) @active = active @currency_options = @expand = @lookup_key = lookup_key @metadata = @migrate_to = migrate_to @nickname = nickname @tax_behavior = tax_behavior @transfer_lookup_key = transfer_lookup_key end |
Instance Attribute Details
#active ⇒ Object
Whether the price can be used for new purchases. Defaults to true.
112 113 114 |
# File 'lib/stripe/params/price_update_params.rb', line 112 def active @active end |
#currency_options ⇒ Object
Prices defined in each available currency option. Each key must be a three-letter ISO currency code and a supported currency.
114 115 116 |
# File 'lib/stripe/params/price_update_params.rb', line 114 def @currency_options end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
116 117 118 |
# File 'lib/stripe/params/price_update_params.rb', line 116 def @expand end |
#lookup_key ⇒ Object
A lookup key used to retrieve prices dynamically from a static string. This may be up to 200 characters.
118 119 120 |
# File 'lib/stripe/params/price_update_params.rb', line 118 def lookup_key @lookup_key end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
120 121 122 |
# File 'lib/stripe/params/price_update_params.rb', line 120 def @metadata end |
#migrate_to ⇒ Object
If specified, subscriptions using this price will be updated to use the new referenced price.
122 123 124 |
# File 'lib/stripe/params/price_update_params.rb', line 122 def migrate_to @migrate_to end |
#nickname ⇒ Object
A brief description of the price, hidden from customers.
124 125 126 |
# File 'lib/stripe/params/price_update_params.rb', line 124 def nickname @nickname end |
#tax_behavior ⇒ Object
Only required if a default tax behavior was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of inclusive, exclusive, or unspecified. Once specified as either inclusive or exclusive, it cannot be changed.
126 127 128 |
# File 'lib/stripe/params/price_update_params.rb', line 126 def tax_behavior @tax_behavior end |
#transfer_lookup_key ⇒ Object
If set to true, will atomically remove the lookup key from the existing price, and assign it to this price.
128 129 130 |
# File 'lib/stripe/params/price_update_params.rb', line 128 def transfer_lookup_key @transfer_lookup_key end |