Class: Stripe::PriceUpdateParams::MigrateTo

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/price_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(behavior: nil, effective_after: nil, price: nil) ⇒ MigrateTo

Returns a new instance of MigrateTo.



85
86
87
88
89
# File 'lib/stripe/params/price_update_params.rb', line 85

def initialize(behavior: nil, effective_after: nil, price: nil)
  @behavior = behavior
  @effective_after = effective_after
  @price = price
end

Instance Attribute Details

#behaviorObject

The behavior controlling the point in the subscription lifecycle after which to migrate the price. Currently must be ‘at_cycle_end`.



79
80
81
# File 'lib/stripe/params/price_update_params.rb', line 79

def behavior
  @behavior
end

#effective_afterObject

The time after which subscriptions should start using the new price.



81
82
83
# File 'lib/stripe/params/price_update_params.rb', line 81

def effective_after
  @effective_after
end

#priceObject

The ID of the price object.



83
84
85
# File 'lib/stripe/params/price_update_params.rb', line 83

def price
  @price
end