Class: Stripe::Privacy::RedactionJob::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/privacy/redaction_job.rb

Defined Under Namespace

Classes: Objects

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, objects: nil, validation_behavior: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



125
126
127
128
129
# File 'lib/stripe/resources/privacy/redaction_job.rb', line 125

def initialize(expand: nil, objects: nil, validation_behavior: nil)
  @expand = expand
  @objects = objects
  @validation_behavior = validation_behavior
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



119
120
121
# File 'lib/stripe/resources/privacy/redaction_job.rb', line 119

def expand
  @expand
end

#objectsObject

The objects to redact. These root objects and their related ones will be validated for redaction.



121
122
123
# File 'lib/stripe/resources/privacy/redaction_job.rb', line 121

def objects
  @objects
end

#validation_behaviorObject

Determines the validation behavior of the job. Default is ‘error`.



123
124
125
# File 'lib/stripe/resources/privacy/redaction_job.rb', line 123

def validation_behavior
  @validation_behavior
end