Class: Stripe::Privacy::RedactionJob::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Privacy::RedactionJob::CreateParams
- Defined in:
- lib/stripe/resources/privacy/redaction_job.rb
Defined Under Namespace
Classes: Objects
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#objects ⇒ Object
The objects to redact.
-
#validation_behavior ⇒ Object
Determines the validation behavior of the job.
Instance Method Summary collapse
-
#initialize(expand: nil, objects: nil, validation_behavior: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, objects: nil, validation_behavior: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
133 134 135 136 137 |
# File 'lib/stripe/resources/privacy/redaction_job.rb', line 133 def initialize(expand: nil, objects: nil, validation_behavior: nil) @expand = @objects = objects @validation_behavior = validation_behavior end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
127 128 129 |
# File 'lib/stripe/resources/privacy/redaction_job.rb', line 127 def @expand end |
#objects ⇒ Object
The objects to redact. These root objects and their related ones will be validated for redaction.
129 130 131 |
# File 'lib/stripe/resources/privacy/redaction_job.rb', line 129 def objects @objects end |
#validation_behavior ⇒ Object
Determines the validation behavior of the job. Default is ‘error`.
131 132 133 |
# File 'lib/stripe/resources/privacy/redaction_job.rb', line 131 def validation_behavior @validation_behavior end |