Class: Stripe::Privacy::RedactionJob::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/privacy/redaction_job.rb

Defined Under Namespace

Classes: Objects

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, objects: nil, validation_behavior: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



102
103
104
105
106
# File 'lib/stripe/resources/privacy/redaction_job.rb', line 102

def initialize(expand: nil, objects: nil, validation_behavior: nil)
  @expand = expand
  @objects = objects
  @validation_behavior = validation_behavior
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



93
94
95
# File 'lib/stripe/resources/privacy/redaction_job.rb', line 93

def expand
  @expand
end

#objectsObject

The objects at the root level that are subject to redaction.



95
96
97
# File 'lib/stripe/resources/privacy/redaction_job.rb', line 95

def objects
  @objects
end

#validation_behaviorObject

Default is “error”. If “error”, we will make sure all objects in the graph are redactable in the 1st traversal, otherwise error. If “fix”, where possible, we will auto-fix any validation errors (e.g. by auto-transitioning objects to a terminal state, etc.) in the 2nd traversal before redacting



100
101
102
# File 'lib/stripe/resources/privacy/redaction_job.rb', line 100

def validation_behavior
  @validation_behavior
end