Class: Stripe::Privacy::RedactionJob::RunParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Privacy::RedactionJob::RunParams
- Defined in:
- lib/stripe/resources/privacy/redaction_job.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RunParams
constructor
A new instance of RunParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RunParams
Returns a new instance of RunParams.
158 159 160 |
# File 'lib/stripe/resources/privacy/redaction_job.rb', line 158 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
156 157 158 |
# File 'lib/stripe/resources/privacy/redaction_job.rb', line 156 def @expand end |