Class: Stripe::Privacy::RedactionJob::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Privacy::RedactionJob::UpdateParams
- Defined in:
- lib/stripe/resources/privacy/redaction_job.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#validation_behavior ⇒ Object
Attribute for param field validation_behavior.
Instance Method Summary collapse
-
#initialize(expand: nil, validation_behavior: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, validation_behavior: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
118 119 120 121 |
# File 'lib/stripe/resources/privacy/redaction_job.rb', line 118 def initialize(expand: nil, validation_behavior: nil) @expand = @validation_behavior = validation_behavior end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
114 115 116 |
# File 'lib/stripe/resources/privacy/redaction_job.rb', line 114 def @expand end |
#validation_behavior ⇒ Object
Attribute for param field validation_behavior
116 117 118 |
# File 'lib/stripe/resources/privacy/redaction_job.rb', line 116 def validation_behavior @validation_behavior end |