Class: Stripe::Privacy::RedactionJobRootObjects
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Privacy::RedactionJobRootObjects
- Defined in:
- lib/stripe/resources/privacy/redaction_job_root_objects.rb
Overview
The objects to redact, grouped by type. All redactable objects associated with these objects will be redacted as well.
Constant Summary collapse
- OBJECT_NAME =
"privacy.redaction_job_root_objects"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#charges ⇒ Object
readonly
Attribute for field charges.
-
#checkout_sessions ⇒ Object
readonly
Attribute for field checkout_sessions.
-
#customers ⇒ Object
readonly
Attribute for field customers.
-
#identity_verification_sessions ⇒ Object
readonly
Attribute for field identity_verification_sessions.
-
#invoices ⇒ Object
readonly
Attribute for field invoices.
-
#issuing_cardholders ⇒ Object
readonly
Attribute for field issuing_cardholders.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#payment_intents ⇒ Object
readonly
Attribute for field payment_intents.
-
#radar_value_list_items ⇒ Object
readonly
Attribute for field radar_value_list_items.
-
#setup_intents ⇒ Object
readonly
Attribute for field setup_intents.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#charges ⇒ Object (readonly)
Attribute for field charges
14 15 16 |
# File 'lib/stripe/resources/privacy/redaction_job_root_objects.rb', line 14 def charges @charges end |
#checkout_sessions ⇒ Object (readonly)
Attribute for field checkout_sessions
16 17 18 |
# File 'lib/stripe/resources/privacy/redaction_job_root_objects.rb', line 16 def checkout_sessions @checkout_sessions end |
#customers ⇒ Object (readonly)
Attribute for field customers
18 19 20 |
# File 'lib/stripe/resources/privacy/redaction_job_root_objects.rb', line 18 def customers @customers end |
#identity_verification_sessions ⇒ Object (readonly)
Attribute for field identity_verification_sessions
20 21 22 |
# File 'lib/stripe/resources/privacy/redaction_job_root_objects.rb', line 20 def identity_verification_sessions @identity_verification_sessions end |
#invoices ⇒ Object (readonly)
Attribute for field invoices
22 23 24 |
# File 'lib/stripe/resources/privacy/redaction_job_root_objects.rb', line 22 def invoices @invoices end |
#issuing_cardholders ⇒ Object (readonly)
Attribute for field issuing_cardholders
24 25 26 |
# File 'lib/stripe/resources/privacy/redaction_job_root_objects.rb', line 24 def issuing_cardholders @issuing_cardholders end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
26 27 28 |
# File 'lib/stripe/resources/privacy/redaction_job_root_objects.rb', line 26 def object @object end |
#payment_intents ⇒ Object (readonly)
Attribute for field payment_intents
28 29 30 |
# File 'lib/stripe/resources/privacy/redaction_job_root_objects.rb', line 28 def payment_intents @payment_intents end |
#radar_value_list_items ⇒ Object (readonly)
Attribute for field radar_value_list_items
30 31 32 |
# File 'lib/stripe/resources/privacy/redaction_job_root_objects.rb', line 30 def radar_value_list_items @radar_value_list_items end |
#setup_intents ⇒ Object (readonly)
Attribute for field setup_intents
32 33 34 |
# File 'lib/stripe/resources/privacy/redaction_job_root_objects.rb', line 32 def setup_intents @setup_intents end |
Class Method Details
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/privacy/redaction_job_root_objects.rb', line 9 def self.object_name "privacy.redaction_job_root_objects" end |