Class: Stripe::Privacy::RedactionJobService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Privacy::RedactionJobService::UpdateParams
- Defined in:
- lib/stripe/services/privacy/redaction_job_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#validation_behavior ⇒ Object
Attribute for param field validation_behavior.
Instance Method Summary collapse
-
#initialize(expand: nil, validation_behavior: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, validation_behavior: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
120 121 122 123 |
# File 'lib/stripe/services/privacy/redaction_job_service.rb', line 120 def initialize(expand: nil, validation_behavior: nil) @expand = @validation_behavior = validation_behavior end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
116 117 118 |
# File 'lib/stripe/services/privacy/redaction_job_service.rb', line 116 def @expand end |
#validation_behavior ⇒ Object
Attribute for param field validation_behavior
118 119 120 |
# File 'lib/stripe/services/privacy/redaction_job_service.rb', line 118 def validation_behavior @validation_behavior end |