Class: Stripe::Privacy::RedactionJobValidationError
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Privacy::RedactionJobValidationError
- Defined in:
- lib/stripe/resources/privacy/redaction_job_validation_error.rb
Overview
The Redaction Job validation error object contains information about errors that affect the ability to redact a specific object in a redaction job.
Defined Under Namespace
Classes: ErroringObject
Constant Summary collapse
- OBJECT_NAME =
"privacy.redaction_job_validation_error"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#code ⇒ Object
readonly
A code indicating the reason for the error.
-
#erroring_object ⇒ Object
readonly
If the error is related to a specific object, this field includes the object’s identifier and object type.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#message ⇒ Object
readonly
A human-readable message providing more details about the error.
-
#object ⇒ Object
readonly
String representing the object’s type.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#code ⇒ Object (readonly)
A code indicating the reason for the error.
30 31 32 |
# File 'lib/stripe/resources/privacy/redaction_job_validation_error.rb', line 30 def code @code end |
#erroring_object ⇒ Object (readonly)
If the error is related to a specific object, this field includes the object’s identifier and object type.
32 33 34 |
# File 'lib/stripe/resources/privacy/redaction_job_validation_error.rb', line 32 def erroring_object @erroring_object end |
#id ⇒ Object (readonly)
Unique identifier for the object.
34 35 36 |
# File 'lib/stripe/resources/privacy/redaction_job_validation_error.rb', line 34 def id @id end |
#message ⇒ Object (readonly)
A human-readable message providing more details about the error.
36 37 38 |
# File 'lib/stripe/resources/privacy/redaction_job_validation_error.rb', line 36 def @message end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
38 39 40 |
# File 'lib/stripe/resources/privacy/redaction_job_validation_error.rb', line 38 def object @object end |
Class Method Details
.field_remappings ⇒ Object
44 45 46 |
# File 'lib/stripe/resources/privacy/redaction_job_validation_error.rb', line 44 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
40 41 42 |
# File 'lib/stripe/resources/privacy/redaction_job_validation_error.rb', line 40 def self.inner_class_types @inner_class_types = { erroring_object: ErroringObject } end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/privacy/redaction_job_validation_error.rb', line 11 def self.object_name "privacy.redaction_job_validation_error" end |