Class: Stripe::Product::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Product::CreateParams
- Defined in:
- lib/stripe/resources/product.rb
Defined Under Namespace
Classes: DefaultPriceData, MarketingFeature, PackageDimensions, Provisioning
Instance Attribute Summary collapse
-
#active ⇒ Object
Whether the product is currently available for purchase.
-
#default_price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object.
-
#description ⇒ Object
The product’s description, meant to be displayable to the customer.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#id ⇒ Object
An identifier will be randomly generated by Stripe.
-
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
-
#marketing_features ⇒ Object
A list of up to 15 marketing features for this product.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
-
#package_dimensions ⇒ Object
The dimensions of this product for shipping purposes.
-
#provisioning ⇒ Object
Provisioning configuration for this product.
-
#shippable ⇒ Object
Whether this product is shipped (i.e., physical goods).
-
#statement_descriptor ⇒ Object
An arbitrary string to be displayed on your customer’s credit card or bank statement.
-
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
-
#type ⇒ Object
The type of the product.
-
#unit_label ⇒ Object
A label that represents units of this product.
-
#url ⇒ Object
A URL of a publicly-accessible webpage for this product.
Instance Method Summary collapse
-
#initialize(active: nil, default_price_data: nil, description: nil, expand: nil, id: nil, images: nil, marketing_features: nil, metadata: nil, name: nil, package_dimensions: nil, provisioning: nil, shippable: nil, statement_descriptor: nil, tax_code: nil, type: nil, unit_label: nil, url: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, default_price_data: nil, description: nil, expand: nil, id: nil, images: nil, marketing_features: nil, metadata: nil, name: nil, package_dimensions: nil, provisioning: nil, shippable: nil, statement_descriptor: nil, tax_code: nil, type: nil, unit_label: nil, url: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'lib/stripe/resources/product.rb', line 465 def initialize( active: nil, default_price_data: nil, description: nil, expand: nil, id: nil, images: nil, marketing_features: nil, metadata: nil, name: nil, package_dimensions: nil, provisioning: nil, shippable: nil, statement_descriptor: nil, tax_code: nil, type: nil, unit_label: nil, url: nil ) @active = active @default_price_data = default_price_data @description = description @expand = @id = id @images = images @marketing_features = marketing_features @metadata = @name = name @package_dimensions = package_dimensions @provisioning = provisioning @shippable = shippable @statement_descriptor = statement_descriptor @tax_code = tax_code @type = type @unit_label = unit_label @url = url end |
Instance Attribute Details
#active ⇒ Object
Whether the product is currently available for purchase. Defaults to ‘true`.
428 429 430 |
# File 'lib/stripe/resources/product.rb', line 428 def active @active end |
#default_price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object. This Price will be set as the default price for this product.
430 431 432 |
# File 'lib/stripe/resources/product.rb', line 430 def default_price_data @default_price_data end |
#description ⇒ Object
The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.
432 433 434 |
# File 'lib/stripe/resources/product.rb', line 432 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
434 435 436 |
# File 'lib/stripe/resources/product.rb', line 434 def @expand end |
#id ⇒ Object
An identifier will be randomly generated by Stripe. You can optionally override this ID, but the ID must be unique across all products in your Stripe account.
436 437 438 |
# File 'lib/stripe/resources/product.rb', line 436 def id @id end |
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
438 439 440 |
# File 'lib/stripe/resources/product.rb', line 438 def images @images end |
#marketing_features ⇒ Object
A list of up to 15 marketing features for this product. These are displayed in [pricing tables](stripe.com/docs/payments/checkout/pricing-table).
440 441 442 |
# File 'lib/stripe/resources/product.rb', line 440 def marketing_features @marketing_features end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
442 443 444 |
# File 'lib/stripe/resources/product.rb', line 442 def @metadata end |
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
444 445 446 |
# File 'lib/stripe/resources/product.rb', line 444 def name @name end |
#package_dimensions ⇒ Object
The dimensions of this product for shipping purposes.
446 447 448 |
# File 'lib/stripe/resources/product.rb', line 446 def package_dimensions @package_dimensions end |
#provisioning ⇒ Object
Provisioning configuration for this product.
448 449 450 |
# File 'lib/stripe/resources/product.rb', line 448 def provisioning @provisioning end |
#shippable ⇒ Object
Whether this product is shipped (i.e., physical goods).
450 451 452 |
# File 'lib/stripe/resources/product.rb', line 450 def shippable @shippable end |
#statement_descriptor ⇒ Object
An arbitrary string to be displayed on your customer’s credit card or bank statement. While most banks display this information consistently, some may display it incorrectly or not at all.
This may be up to 22 characters. The statement description may not include ‘<`, `>`, ``, `“`, `’‘ characters, and will appear on your customer’s statement in capital letters. Non-ASCII characters are automatically stripped.
It must contain at least one letter. Only used for subscription payments.
455 456 457 |
# File 'lib/stripe/resources/product.rb', line 455 def statement_descriptor @statement_descriptor end |
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
457 458 459 |
# File 'lib/stripe/resources/product.rb', line 457 def tax_code @tax_code end |
#type ⇒ Object
The type of the product. Defaults to ‘service` if not explicitly specified, enabling use of this product with Subscriptions and Plans. Set this parameter to `good` to use this product with Orders and SKUs. On API versions before `2018-02-05`, this field defaults to `good` for compatibility reasons.
459 460 461 |
# File 'lib/stripe/resources/product.rb', line 459 def type @type end |
#unit_label ⇒ Object
A label that represents units of this product. When set, this will be included in customers’ receipts, invoices, Checkout, and the customer portal.
461 462 463 |
# File 'lib/stripe/resources/product.rb', line 461 def unit_label @unit_label end |
#url ⇒ Object
A URL of a publicly-accessible webpage for this product.
463 464 465 |
# File 'lib/stripe/resources/product.rb', line 463 def url @url end |