Class: Stripe::Product::CreateParams::DefaultPriceData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Product::CreateParams::DefaultPriceData
- Defined in:
- lib/stripe/resources/product.rb
Defined Under Namespace
Classes: CurrencyOptions, CustomUnitAmount, Recurring
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#currency_options ⇒ Object
Prices defined in each available currency option.
-
#custom_unit_amount ⇒ Object
When set, provides configuration for the amount to be adjusted by the customer during Checkout Sessions and Payment Links.
-
#recurring ⇒ Object
The recurring components of a price such as ‘interval` and `interval_count`.
-
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings.
-
#unit_amount ⇒ Object
A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.
-
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places.
Instance Method Summary collapse
-
#initialize(currency: nil, currency_options: nil, custom_unit_amount: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ DefaultPriceData
constructor
A new instance of DefaultPriceData.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, currency_options: nil, custom_unit_amount: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ DefaultPriceData
Returns a new instance of DefaultPriceData.
403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 |
# File 'lib/stripe/resources/product.rb', line 403 def initialize( currency: nil, currency_options: nil, custom_unit_amount: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil ) @currency = currency @currency_options = @custom_unit_amount = custom_unit_amount @recurring = recurring @tax_behavior = tax_behavior @unit_amount = unit_amount @unit_amount_decimal = unit_amount_decimal end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
383 384 385 |
# File 'lib/stripe/resources/product.rb', line 383 def currency @currency end |
#currency_options ⇒ Object
Prices defined in each available currency option. Each key must be a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html) and a [supported currency](stripe.com/docs/currencies).
386 387 388 |
# File 'lib/stripe/resources/product.rb', line 386 def @currency_options end |
#custom_unit_amount ⇒ Object
When set, provides configuration for the amount to be adjusted by the customer during Checkout Sessions and Payment Links.
389 390 391 |
# File 'lib/stripe/resources/product.rb', line 389 def custom_unit_amount @custom_unit_amount end |
#recurring ⇒ Object
The recurring components of a price such as ‘interval` and `interval_count`.
392 393 394 |
# File 'lib/stripe/resources/product.rb', line 392 def recurring @recurring end |
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.
395 396 397 |
# File 'lib/stripe/resources/product.rb', line 395 def tax_behavior @tax_behavior end |
#unit_amount ⇒ Object
A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge. One of ‘unit_amount`, `unit_amount_decimal`, or `custom_unit_amount` is required.
398 399 400 |
# File 'lib/stripe/resources/product.rb', line 398 def unit_amount @unit_amount end |
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.
401 402 403 |
# File 'lib/stripe/resources/product.rb', line 401 def unit_amount_decimal @unit_amount_decimal end |