Class: Stripe::Product::CreateParams::DefaultPriceData::CurrencyOptions::CustomUnitAmount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/product.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) ⇒ CustomUnitAmount

Returns a new instance of CustomUnitAmount.



235
236
237
238
239
240
# File 'lib/stripe/resources/product.rb', line 235

def initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil)
  @enabled = enabled
  @maximum = maximum
  @minimum = minimum
  @preset = preset
end

Instance Attribute Details

#enabledObject

Pass in ‘true` to enable `custom_unit_amount`, otherwise omit `custom_unit_amount`.



227
228
229
# File 'lib/stripe/resources/product.rb', line 227

def enabled
  @enabled
end

#maximumObject

The maximum unit amount the customer can specify for this item.



229
230
231
# File 'lib/stripe/resources/product.rb', line 229

def maximum
  @maximum
end

#minimumObject

The minimum unit amount the customer can specify for this item. Must be at least the minimum charge amount.



231
232
233
# File 'lib/stripe/resources/product.rb', line 231

def minimum
  @minimum
end

#presetObject

The starting unit amount which can be updated by the customer.



233
234
235
# File 'lib/stripe/resources/product.rb', line 233

def preset
  @preset
end