Class: Stripe::Product::CreateParams::DefaultPriceData::CurrencyOptions::CustomUnitAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Product::CreateParams::DefaultPriceData::CurrencyOptions::CustomUnitAmount
- Defined in:
- lib/stripe/resources/product.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Pass in ‘true` to enable `custom_unit_amount`, otherwise omit `custom_unit_amount`.
-
#maximum ⇒ Object
The maximum unit amount the customer can specify for this item.
-
#minimum ⇒ Object
The minimum unit amount the customer can specify for this item.
-
#preset ⇒ Object
The starting unit amount which can be updated by the customer.
Instance Method Summary collapse
-
#initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) ⇒ CustomUnitAmount
constructor
A new instance of CustomUnitAmount.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) ⇒ CustomUnitAmount
Returns a new instance of CustomUnitAmount.
216 217 218 219 220 221 |
# File 'lib/stripe/resources/product.rb', line 216 def initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) @enabled = enabled @maximum = maximum @minimum = minimum @preset = preset end |
Instance Attribute Details
#enabled ⇒ Object
Pass in ‘true` to enable `custom_unit_amount`, otherwise omit `custom_unit_amount`.
208 209 210 |
# File 'lib/stripe/resources/product.rb', line 208 def enabled @enabled end |
#maximum ⇒ Object
The maximum unit amount the customer can specify for this item.
210 211 212 |
# File 'lib/stripe/resources/product.rb', line 210 def maximum @maximum end |
#minimum ⇒ Object
The minimum unit amount the customer can specify for this item. Must be at least the minimum charge amount.
212 213 214 |
# File 'lib/stripe/resources/product.rb', line 212 def minimum @minimum end |
#preset ⇒ Object
The starting unit amount which can be updated by the customer.
214 215 216 |
# File 'lib/stripe/resources/product.rb', line 214 def preset @preset end |