Class: Stripe::Product::CreateParams::DefaultPriceData::CustomUnitAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Product::CreateParams::DefaultPriceData::CustomUnitAmount
- Defined in:
- lib/stripe/resources/product.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Pass in ‘true` to enable `custom_unit_amount`, otherwise omit `custom_unit_amount`.
-
#maximum ⇒ Object
The maximum unit amount the customer can specify for this item.
-
#minimum ⇒ Object
The minimum unit amount the customer can specify for this item.
-
#preset ⇒ Object
The starting unit amount which can be updated by the customer.
Instance Method Summary collapse
-
#initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) ⇒ CustomUnitAmount
constructor
A new instance of CustomUnitAmount.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) ⇒ CustomUnitAmount
Returns a new instance of CustomUnitAmount.
285 286 287 288 289 290 |
# File 'lib/stripe/resources/product.rb', line 285 def initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) @enabled = enabled @maximum = maximum @minimum = minimum @preset = preset end |
Instance Attribute Details
#enabled ⇒ Object
Pass in ‘true` to enable `custom_unit_amount`, otherwise omit `custom_unit_amount`.
277 278 279 |
# File 'lib/stripe/resources/product.rb', line 277 def enabled @enabled end |
#maximum ⇒ Object
The maximum unit amount the customer can specify for this item.
279 280 281 |
# File 'lib/stripe/resources/product.rb', line 279 def maximum @maximum end |
#minimum ⇒ Object
The minimum unit amount the customer can specify for this item. Must be at least the minimum charge amount.
281 282 283 |
# File 'lib/stripe/resources/product.rb', line 281 def minimum @minimum end |
#preset ⇒ Object
The starting unit amount which can be updated by the customer.
283 284 285 |
# File 'lib/stripe/resources/product.rb', line 283 def preset @preset end |