Class: Stripe::Product::CreateParams::DefaultPriceData::CustomUnitAmount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/product.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) ⇒ CustomUnitAmount

Returns a new instance of CustomUnitAmount.



314
315
316
317
318
319
# File 'lib/stripe/resources/product.rb', line 314

def initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil)
  @enabled = enabled
  @maximum = maximum
  @minimum = minimum
  @preset = preset
end

Instance Attribute Details

#enabledObject

Pass in ‘true` to enable `custom_unit_amount`, otherwise omit `custom_unit_amount`.



306
307
308
# File 'lib/stripe/resources/product.rb', line 306

def enabled
  @enabled
end

#maximumObject

The maximum unit amount the customer can specify for this item.



308
309
310
# File 'lib/stripe/resources/product.rb', line 308

def maximum
  @maximum
end

#minimumObject

The minimum unit amount the customer can specify for this item. Must be at least the minimum charge amount.



310
311
312
# File 'lib/stripe/resources/product.rb', line 310

def minimum
  @minimum
end

#presetObject

The starting unit amount which can be updated by the customer.



312
313
314
# File 'lib/stripe/resources/product.rb', line 312

def preset
  @preset
end