Class: Stripe::Product::CreateParams::DefaultPriceData::CustomUnitAmount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/product.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil) ⇒ CustomUnitAmount

Returns a new instance of CustomUnitAmount.



362
363
364
365
366
367
# File 'lib/stripe/resources/product.rb', line 362

def initialize(enabled: nil, maximum: nil, minimum: nil, preset: nil)
  @enabled = enabled
  @maximum = maximum
  @minimum = minimum
  @preset = preset
end

Instance Attribute Details

#enabledObject

Pass in ‘true` to enable `custom_unit_amount`, otherwise omit `custom_unit_amount`.



351
352
353
# File 'lib/stripe/resources/product.rb', line 351

def enabled
  @enabled
end

#maximumObject

The maximum unit amount the customer can specify for this item.



354
355
356
# File 'lib/stripe/resources/product.rb', line 354

def maximum
  @maximum
end

#minimumObject

The minimum unit amount the customer can specify for this item. Must be at least the minimum charge amount.



357
358
359
# File 'lib/stripe/resources/product.rb', line 357

def minimum
  @minimum
end

#presetObject

The starting unit amount which can be updated by the customer.



360
361
362
# File 'lib/stripe/resources/product.rb', line 360

def preset
  @preset
end