Class: Stripe::Product::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Product::ListParams
- Defined in:
- lib/stripe/resources/product.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#active ⇒ Object
Only return products that are active or inactive (e.g., pass ‘false` to list all inactive products).
-
#created ⇒ Object
Only return products that were created during the given date interval.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#ids ⇒ Object
Only return products with the given IDs.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#shippable ⇒ Object
Only return products that can be shipped (i.e., physical, not digital products).
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#type ⇒ Object
Only return products of this type.
-
#url ⇒ Object
Only return products with the given url.
Instance Method Summary collapse
-
#initialize(active: nil, created: nil, ending_before: nil, expand: nil, ids: nil, limit: nil, shippable: nil, starting_after: nil, type: nil, url: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, created: nil, ending_before: nil, expand: nil, ids: nil, limit: nil, shippable: nil, starting_after: nil, type: nil, url: nil) ⇒ ListParams
Returns a new instance of ListParams.
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/stripe/resources/product.rb', line 197 def initialize( active: nil, created: nil, ending_before: nil, expand: nil, ids: nil, limit: nil, shippable: nil, starting_after: nil, type: nil, url: nil ) @active = active @created = created @ending_before = ending_before @expand = @ids = ids @limit = limit @shippable = shippable @starting_after = starting_after @type = type @url = url end |
Instance Attribute Details
#active ⇒ Object
Only return products that are active or inactive (e.g., pass ‘false` to list all inactive products).
177 178 179 |
# File 'lib/stripe/resources/product.rb', line 177 def active @active end |
#created ⇒ Object
Only return products that were created during the given date interval.
179 180 181 |
# File 'lib/stripe/resources/product.rb', line 179 def created @created end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
181 182 183 |
# File 'lib/stripe/resources/product.rb', line 181 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
183 184 185 |
# File 'lib/stripe/resources/product.rb', line 183 def @expand end |
#ids ⇒ Object
Only return products with the given IDs. Cannot be used with [starting_after](stripe.com/docs/api#list_products-starting_after) or [ending_before](stripe.com/docs/api#list_products-ending_before).
185 186 187 |
# File 'lib/stripe/resources/product.rb', line 185 def ids @ids end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
187 188 189 |
# File 'lib/stripe/resources/product.rb', line 187 def limit @limit end |
#shippable ⇒ Object
Only return products that can be shipped (i.e., physical, not digital products).
189 190 191 |
# File 'lib/stripe/resources/product.rb', line 189 def shippable @shippable end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
191 192 193 |
# File 'lib/stripe/resources/product.rb', line 191 def starting_after @starting_after end |
#type ⇒ Object
Only return products of this type.
193 194 195 |
# File 'lib/stripe/resources/product.rb', line 193 def type @type end |
#url ⇒ Object
Only return products with the given url.
195 196 197 |
# File 'lib/stripe/resources/product.rb', line 195 def url @url end |