Class: Stripe::Product::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/product.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, created: nil, ending_before: nil, expand: nil, ids: nil, limit: nil, shippable: nil, starting_after: nil, type: nil, url: nil) ⇒ ListParams

Returns a new instance of ListParams.



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/stripe/resources/product.rb', line 206

def initialize(
  active: nil,
  created: nil,
  ending_before: nil,
  expand: nil,
  ids: nil,
  limit: nil,
  shippable: nil,
  starting_after: nil,
  type: nil,
  url: nil
)
  @active = active
  @created = created
  @ending_before = ending_before
  @expand = expand
  @ids = ids
  @limit = limit
  @shippable = shippable
  @starting_after = starting_after
  @type = type
  @url = url
end

Instance Attribute Details

#activeObject

Only return products that are active or inactive (e.g., pass ‘false` to list all inactive products).



186
187
188
# File 'lib/stripe/resources/product.rb', line 186

def active
  @active
end

#createdObject

Only return products that were created during the given date interval.



188
189
190
# File 'lib/stripe/resources/product.rb', line 188

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



190
191
192
# File 'lib/stripe/resources/product.rb', line 190

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



192
193
194
# File 'lib/stripe/resources/product.rb', line 192

def expand
  @expand
end

#idsObject

Only return products with the given IDs. Cannot be used with [starting_after](stripe.com/docs/api#list_products-starting_after) or [ending_before](stripe.com/docs/api#list_products-ending_before).



194
195
196
# File 'lib/stripe/resources/product.rb', line 194

def ids
  @ids
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



196
197
198
# File 'lib/stripe/resources/product.rb', line 196

def limit
  @limit
end

#shippableObject

Only return products that can be shipped (i.e., physical, not digital products).



198
199
200
# File 'lib/stripe/resources/product.rb', line 198

def shippable
  @shippable
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



200
201
202
# File 'lib/stripe/resources/product.rb', line 200

def starting_after
  @starting_after
end

#typeObject

Only return products of this type.



202
203
204
# File 'lib/stripe/resources/product.rb', line 202

def type
  @type
end

#urlObject

Only return products with the given url.



204
205
206
# File 'lib/stripe/resources/product.rb', line 204

def url
  @url
end