Class: Stripe::Product::SearchParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Product::SearchParams
- Defined in:
- lib/stripe/resources/product.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#page ⇒ Object
A cursor for pagination across multiple pages of results.
-
#query ⇒ Object
The search query string.
Instance Method Summary collapse
-
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
constructor
A new instance of SearchParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
Returns a new instance of SearchParams.
451 452 453 454 455 456 |
# File 'lib/stripe/resources/product.rb', line 451 def initialize(expand: nil, limit: nil, page: nil, query: nil) @expand = @limit = limit @page = page @query = query end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
443 444 445 |
# File 'lib/stripe/resources/product.rb', line 443 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
445 446 447 |
# File 'lib/stripe/resources/product.rb', line 445 def limit @limit end |
#page ⇒ Object
A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.
447 448 449 |
# File 'lib/stripe/resources/product.rb', line 447 def page @page end |
#query ⇒ Object
The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for products](stripe.com/docs/search#query-fields-for-products).
449 450 451 |
# File 'lib/stripe/resources/product.rb', line 449 def query @query end |