Class: Stripe::Product::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/product.rb

Defined Under Namespace

Classes: MarketingFeature, PackageDimensions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, default_price: nil, description: nil, expand: nil, images: nil, marketing_features: nil, metadata: nil, name: nil, package_dimensions: nil, shippable: nil, statement_descriptor: nil, tax_code: nil, unit_label: nil, url: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/stripe/resources/product.rb', line 134

def initialize(
  active: nil,
  default_price: nil,
  description: nil,
  expand: nil,
  images: nil,
  marketing_features: nil,
  metadata: nil,
  name: nil,
  package_dimensions: nil,
  shippable: nil,
  statement_descriptor: nil,
  tax_code: nil,
  unit_label: nil,
  url: nil
)
  @active = active
  @default_price = default_price
  @description = description
  @expand = expand
  @images = images
  @marketing_features = marketing_features
  @metadata = 
  @name = name
  @package_dimensions = package_dimensions
  @shippable = shippable
  @statement_descriptor = statement_descriptor
  @tax_code = tax_code
  @unit_label = unit_label
  @url = url
end

Instance Attribute Details

#activeObject

Whether the product is available for purchase.



103
104
105
# File 'lib/stripe/resources/product.rb', line 103

def active
  @active
end

#default_priceObject

The ID of the [Price](stripe.com/docs/api/prices) object that is the default price for this product.



105
106
107
# File 'lib/stripe/resources/product.rb', line 105

def default_price
  @default_price
end

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



107
108
109
# File 'lib/stripe/resources/product.rb', line 107

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



109
110
111
# File 'lib/stripe/resources/product.rb', line 109

def expand
  @expand
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



111
112
113
# File 'lib/stripe/resources/product.rb', line 111

def images
  @images
end

#marketing_featuresObject

A list of up to 15 marketing features for this product. These are displayed in [pricing tables](stripe.com/docs/payments/checkout/pricing-table).



113
114
115
# File 'lib/stripe/resources/product.rb', line 113

def marketing_features
  @marketing_features
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



115
116
117
# File 'lib/stripe/resources/product.rb', line 115

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



117
118
119
# File 'lib/stripe/resources/product.rb', line 117

def name
  @name
end

#package_dimensionsObject

The dimensions of this product for shipping purposes.



119
120
121
# File 'lib/stripe/resources/product.rb', line 119

def package_dimensions
  @package_dimensions
end

#shippableObject

Whether this product is shipped (i.e., physical goods).



121
122
123
# File 'lib/stripe/resources/product.rb', line 121

def shippable
  @shippable
end

#statement_descriptorObject

An arbitrary string to be displayed on your customer’s credit card or bank statement. While most banks display this information consistently, some may display it incorrectly or not at all.

This may be up to 22 characters. The statement description may not include ‘<`, `>`, ``, `“`, `’‘ characters, and will appear on your customer’s statement in capital letters. Non-ASCII characters are automatically stripped.

It must contain at least one letter. May only be set if `type=service`. Only used for subscription payments.


126
127
128
# File 'lib/stripe/resources/product.rb', line 126

def statement_descriptor
  @statement_descriptor
end

#tax_codeObject



128
129
130
# File 'lib/stripe/resources/product.rb', line 128

def tax_code
  @tax_code
end

#unit_labelObject

A label that represents units of this product. When set, this will be included in customers’ receipts, invoices, Checkout, and the customer portal. May only be set if ‘type=service`.



130
131
132
# File 'lib/stripe/resources/product.rb', line 130

def unit_label
  @unit_label
end

#urlObject

A URL of a publicly-accessible webpage for this product.



132
133
134
# File 'lib/stripe/resources/product.rb', line 132

def url
  @url
end