Class: Stripe::ProductCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ProductCreateParams
- Defined in:
- lib/stripe/params/product_create_params.rb
Defined Under Namespace
Classes: DefaultPriceData, Identifiers, MarketingFeature, PackageDimensions, TaxDetails
Instance Attribute Summary collapse
-
#active ⇒ Object
Whether the product is currently available for purchase.
-
#default_price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object.
-
#description ⇒ Object
The product’s description, meant to be displayable to the customer.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#id ⇒ Object
An identifier will be randomly generated by Stripe.
-
#identifiers ⇒ Object
Other identifiers for this product.
-
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
-
#marketing_features ⇒ Object
A list of up to 15 marketing features for this product.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
-
#package_dimensions ⇒ Object
The dimensions of this product for shipping purposes.
-
#shippable ⇒ Object
Whether this product is shipped (i.e., physical goods).
-
#statement_descriptor ⇒ Object
An arbitrary string to be displayed on your customer’s credit card or bank statement.
-
#tax_code ⇒ Object
A [tax code](docs.stripe.com/tax/tax-categories) ID.
-
#tax_details ⇒ Object
Tax details for this product, including the [tax code](/tax/tax-codes) and an optional performance location.
-
#type ⇒ Object
The type of the product.
-
#unit_label ⇒ Object
A label that represents units of this product.
-
#url ⇒ Object
A URL of a publicly-accessible webpage for this product.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(active: nil, default_price_data: nil, description: nil, expand: nil, id: nil, identifiers: nil, images: nil, marketing_features: nil, metadata: nil, name: nil, package_dimensions: nil, shippable: nil, statement_descriptor: nil, tax_code: nil, tax_details: nil, type: nil, unit_label: nil, url: nil) ⇒ ProductCreateParams
constructor
A new instance of ProductCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(active: nil, default_price_data: nil, description: nil, expand: nil, id: nil, identifiers: nil, images: nil, marketing_features: nil, metadata: nil, name: nil, package_dimensions: nil, shippable: nil, statement_descriptor: nil, tax_code: nil, tax_details: nil, type: nil, unit_label: nil, url: nil) ⇒ ProductCreateParams
Returns a new instance of ProductCreateParams.
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/stripe/params/product_create_params.rb', line 277 def initialize( active: nil, default_price_data: nil, description: nil, expand: nil, id: nil, identifiers: nil, images: nil, marketing_features: nil, metadata: nil, name: nil, package_dimensions: nil, shippable: nil, statement_descriptor: nil, tax_code: nil, tax_details: nil, type: nil, unit_label: nil, url: nil ) @active = active @default_price_data = default_price_data @description = description @expand = @id = id @identifiers = identifiers @images = images @marketing_features = marketing_features @metadata = @name = name @package_dimensions = package_dimensions @shippable = shippable @statement_descriptor = statement_descriptor @tax_code = tax_code @tax_details = tax_details @type = type @unit_label = unit_label @url = url end |
Instance Attribute Details
#active ⇒ Object
Whether the product is currently available for purchase. Defaults to ‘true`.
238 239 240 |
# File 'lib/stripe/params/product_create_params.rb', line 238 def active @active end |
#default_price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object. This Price will be set as the default price for this product.
240 241 242 |
# File 'lib/stripe/params/product_create_params.rb', line 240 def default_price_data @default_price_data end |
#description ⇒ Object
The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.
242 243 244 |
# File 'lib/stripe/params/product_create_params.rb', line 242 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
244 245 246 |
# File 'lib/stripe/params/product_create_params.rb', line 244 def @expand end |
#id ⇒ Object
An identifier will be randomly generated by Stripe. You can optionally override this ID, but the ID must be unique across all products in your Stripe account.
246 247 248 |
# File 'lib/stripe/params/product_create_params.rb', line 246 def id @id end |
#identifiers ⇒ Object
Other identifiers for this product.
248 249 250 |
# File 'lib/stripe/params/product_create_params.rb', line 248 def identifiers @identifiers end |
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
250 251 252 |
# File 'lib/stripe/params/product_create_params.rb', line 250 def images @images end |
#marketing_features ⇒ Object
A list of up to 15 marketing features for this product. These are displayed in [pricing tables](docs.stripe.com/payments/checkout/pricing-table).
252 253 254 |
# File 'lib/stripe/params/product_create_params.rb', line 252 def marketing_features @marketing_features end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
254 255 256 |
# File 'lib/stripe/params/product_create_params.rb', line 254 def @metadata end |
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
256 257 258 |
# File 'lib/stripe/params/product_create_params.rb', line 256 def name @name end |
#package_dimensions ⇒ Object
The dimensions of this product for shipping purposes.
258 259 260 |
# File 'lib/stripe/params/product_create_params.rb', line 258 def package_dimensions @package_dimensions end |
#shippable ⇒ Object
Whether this product is shipped (i.e., physical goods).
260 261 262 |
# File 'lib/stripe/params/product_create_params.rb', line 260 def shippable @shippable end |
#statement_descriptor ⇒ Object
An arbitrary string to be displayed on your customer’s credit card or bank statement. While most banks display this information consistently, some may display it incorrectly or not at all.
This may be up to 22 characters. The statement description may not include ‘<`, `>`, ``, `“`, `’‘ characters, and will appear on your customer’s statement in capital letters. Non-ASCII characters are automatically stripped.
It must contain at least one letter. Only used for subscription payments.
265 266 267 |
# File 'lib/stripe/params/product_create_params.rb', line 265 def statement_descriptor @statement_descriptor end |
#tax_code ⇒ Object
A [tax code](docs.stripe.com/tax/tax-categories) ID.
267 268 269 |
# File 'lib/stripe/params/product_create_params.rb', line 267 def tax_code @tax_code end |
#tax_details ⇒ Object
Tax details for this product, including the [tax code](/tax/tax-codes) and an optional performance location.
269 270 271 |
# File 'lib/stripe/params/product_create_params.rb', line 269 def tax_details @tax_details end |
#type ⇒ Object
The type of the product. Defaults to ‘service` if not explicitly specified, enabling use of this product with Subscriptions and Plans. Set this parameter to `good` to use this product with Orders and SKUs. On API versions before `2018-02-05`, this field defaults to `good` for compatibility reasons.
271 272 273 |
# File 'lib/stripe/params/product_create_params.rb', line 271 def type @type end |
#unit_label ⇒ Object
A label that represents units of this product. When set, this will be included in customers’ receipts, invoices, Checkout, and the customer portal.
273 274 275 |
# File 'lib/stripe/params/product_create_params.rb', line 273 def unit_label @unit_label end |
#url ⇒ Object
A URL of a publicly-accessible webpage for this product.
275 276 277 |
# File 'lib/stripe/params/product_create_params.rb', line 275 def url @url end |
Class Method Details
.field_encodings ⇒ Object
317 318 319 320 321 |
# File 'lib/stripe/params/product_create_params.rb', line 317 def self.field_encodings @field_encodings = { default_price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |