Class: Stripe::ProductCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/product_create_params.rb

Defined Under Namespace

Classes: DefaultPriceData, MarketingFeature, PackageDimensions, TaxDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, default_price_data: nil, description: nil, expand: nil, id: nil, images: nil, marketing_features: nil, metadata: nil, name: nil, package_dimensions: nil, shippable: nil, statement_descriptor: nil, tax_code: nil, type: nil, unit_label: nil, url: nil, tax_details: nil) ⇒ ProductCreateParams

Returns a new instance of ProductCreateParams.



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/stripe/params/product_create_params.rb', line 221

def initialize(
  active: nil,
  default_price_data: nil,
  description: nil,
  expand: nil,
  id: nil,
  images: nil,
  marketing_features: nil,
  metadata: nil,
  name: nil,
  package_dimensions: nil,
  shippable: nil,
  statement_descriptor: nil,
  tax_code: nil,
  type: nil,
  unit_label: nil,
  url: nil,
  tax_details: nil
)
  @active = active
  @default_price_data = default_price_data
  @description = description
  @expand = expand
  @id = id
  @images = images
  @marketing_features = marketing_features
  @metadata = 
  @name = name
  @package_dimensions = package_dimensions
  @shippable = shippable
  @statement_descriptor = statement_descriptor
  @tax_code = tax_code
  @type = type
  @unit_label = unit_label
  @url = url
  @tax_details = tax_details
end

Instance Attribute Details

#activeObject

Whether the product is currently available for purchase. Defaults to ‘true`.



184
185
186
# File 'lib/stripe/params/product_create_params.rb', line 184

def active
  @active
end

#default_price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object. This Price will be set as the default price for this product.



186
187
188
# File 'lib/stripe/params/product_create_params.rb', line 186

def default_price_data
  @default_price_data
end

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



188
189
190
# File 'lib/stripe/params/product_create_params.rb', line 188

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



190
191
192
# File 'lib/stripe/params/product_create_params.rb', line 190

def expand
  @expand
end

#idObject

An identifier will be randomly generated by Stripe. You can optionally override this ID, but the ID must be unique across all products in your Stripe account.



192
193
194
# File 'lib/stripe/params/product_create_params.rb', line 192

def id
  @id
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



194
195
196
# File 'lib/stripe/params/product_create_params.rb', line 194

def images
  @images
end

#marketing_featuresObject

A list of up to 15 marketing features for this product. These are displayed in [pricing tables](docs.stripe.com/payments/checkout/pricing-table).



196
197
198
# File 'lib/stripe/params/product_create_params.rb', line 196

def marketing_features
  @marketing_features
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



198
199
200
# File 'lib/stripe/params/product_create_params.rb', line 198

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



200
201
202
# File 'lib/stripe/params/product_create_params.rb', line 200

def name
  @name
end

#package_dimensionsObject

The dimensions of this product for shipping purposes.



202
203
204
# File 'lib/stripe/params/product_create_params.rb', line 202

def package_dimensions
  @package_dimensions
end

#shippableObject

Whether this product is shipped (i.e., physical goods).



204
205
206
# File 'lib/stripe/params/product_create_params.rb', line 204

def shippable
  @shippable
end

#statement_descriptorObject

An arbitrary string to be displayed on your customer’s credit card or bank statement. While most banks display this information consistently, some may display it incorrectly or not at all.

This may be up to 22 characters. The statement description may not include ‘<`, `>`, ``, `“`, `’‘ characters, and will appear on your customer’s statement in capital letters. Non-ASCII characters are automatically stripped.

It must contain at least one letter. Only used for subscription payments.


209
210
211
# File 'lib/stripe/params/product_create_params.rb', line 209

def statement_descriptor
  @statement_descriptor
end

#tax_codeObject



211
212
213
# File 'lib/stripe/params/product_create_params.rb', line 211

def tax_code
  @tax_code
end

#tax_detailsObject

Tax details for this product, including the [tax code](/tax/tax-codes) and an optional performance location.



219
220
221
# File 'lib/stripe/params/product_create_params.rb', line 219

def tax_details
  @tax_details
end

#typeObject

The type of the product. Defaults to ‘service` if not explicitly specified, enabling use of this product with Subscriptions and Plans. Set this parameter to `good` to use this product with Orders and SKUs. On API versions before `2018-02-05`, this field defaults to `good` for compatibility reasons.



213
214
215
# File 'lib/stripe/params/product_create_params.rb', line 213

def type
  @type
end

#unit_labelObject

A label that represents units of this product. When set, this will be included in customers’ receipts, invoices, Checkout, and the customer portal.



215
216
217
# File 'lib/stripe/params/product_create_params.rb', line 215

def unit_label
  @unit_label
end

#urlObject

A URL of a publicly-accessible webpage for this product.



217
218
219
# File 'lib/stripe/params/product_create_params.rb', line 217

def url
  @url
end