Class: Stripe::ProductService

Inherits:
StripeService show all
Defined in:
lib/stripe/services/product_service.rb

Defined Under Namespace

Classes: CreateParams, DeleteParams, ListParams, RetrieveParams, SearchParams, UpdateParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from StripeService

#request, #request_stream

Constructor Details

#initialize(requestor) ⇒ ProductService

Returns a new instance of ProductService.



8
9
10
11
# File 'lib/stripe/services/product_service.rb', line 8

def initialize(requestor)
  super(requestor)
  @features = Stripe::ProductFeatureService.new(@requestor)
end

Instance Attribute Details

#featuresObject (readonly)

Returns the value of attribute features.



6
7
8
# File 'lib/stripe/services/product_service.rb', line 6

def features
  @features
end

Instance Method Details

#create(params = {}, opts = {}) ⇒ Object

Creates a new product object.



547
548
549
# File 'lib/stripe/services/product_service.rb', line 547

def create(params = {}, opts = {})
  request(method: :post, path: "/v1/products", params: params, opts: opts, base_address: :api)
end

#delete(id, params = {}, opts = {}) ⇒ Object

Delete a product. Deleting a product is only possible if it has no prices associated with it. Additionally, deleting a product with type=good is only possible if it has no SKUs associated with it.



552
553
554
555
556
557
558
559
560
# File 'lib/stripe/services/product_service.rb', line 552

def delete(id, params = {}, opts = {})
  request(
    method: :delete,
    path: format("/v1/products/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#list(params = {}, opts = {}) ⇒ Object

Returns a list of your products. The products are returned sorted by creation date, with the most recently created products appearing first.



563
564
565
# File 'lib/stripe/services/product_service.rb', line 563

def list(params = {}, opts = {})
  request(method: :get, path: "/v1/products", params: params, opts: opts, base_address: :api)
end

#retrieve(id, params = {}, opts = {}) ⇒ Object

Retrieves the details of an existing product. Supply the unique product ID from either a product creation request or the product list, and Stripe will return the corresponding product information.



568
569
570
571
572
573
574
575
576
# File 'lib/stripe/services/product_service.rb', line 568

def retrieve(id, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v1/products/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#search(params = {}, opts = {}) ⇒ Object

Search for products you’ve previously created using Stripe’s [Search Query Language](stripe.com/docs/search#search-query-language). Don’t use search in read-after-write flows where strict consistency is necessary. Under normal operating conditions, data is searchable in less than a minute. Occasionally, propagation of new or updated data can be up to an hour behind during outages. Search functionality is not available to merchants in India.



582
583
584
585
586
587
588
589
590
# File 'lib/stripe/services/product_service.rb', line 582

def search(params = {}, opts = {})
  request(
    method: :get,
    path: "/v1/products/search",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#update(id, params = {}, opts = {}) ⇒ Object

Updates the specific product by setting the values of the parameters passed. Any parameters not provided will be left unchanged.



593
594
595
596
597
598
599
600
601
# File 'lib/stripe/services/product_service.rb', line 593

def update(id, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/products/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end