Class: Stripe::ProductService::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/product_service.rb

Defined Under Namespace

Classes: DefaultPriceData, MarketingFeature, PackageDimensions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, default_price_data: nil, description: nil, expand: nil, id: nil, images: nil, marketing_features: nil, metadata: nil, name: nil, package_dimensions: nil, shippable: nil, statement_descriptor: nil, tax_code: nil, type: nil, unit_label: nil, url: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/stripe/services/product_service.rb', line 383

def initialize(
  active: nil,
  default_price_data: nil,
  description: nil,
  expand: nil,
  id: nil,
  images: nil,
  marketing_features: nil,
  metadata: nil,
  name: nil,
  package_dimensions: nil,
  shippable: nil,
  statement_descriptor: nil,
  tax_code: nil,
  type: nil,
  unit_label: nil,
  url: nil
)
  @active = active
  @default_price_data = default_price_data
  @description = description
  @expand = expand
  @id = id
  @images = images
  @marketing_features = marketing_features
  @metadata = 
  @name = name
  @package_dimensions = package_dimensions
  @shippable = shippable
  @statement_descriptor = statement_descriptor
  @tax_code = tax_code
  @type = type
  @unit_label = unit_label
  @url = url
end

Instance Attribute Details

#activeObject

Whether the product is currently available for purchase. Defaults to ‘true`.



348
349
350
# File 'lib/stripe/services/product_service.rb', line 348

def active
  @active
end

#default_price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object. This Price will be set as the default price for this product.



350
351
352
# File 'lib/stripe/services/product_service.rb', line 350

def default_price_data
  @default_price_data
end

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



352
353
354
# File 'lib/stripe/services/product_service.rb', line 352

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



354
355
356
# File 'lib/stripe/services/product_service.rb', line 354

def expand
  @expand
end

#idObject

An identifier will be randomly generated by Stripe. You can optionally override this ID, but the ID must be unique across all products in your Stripe account.



356
357
358
# File 'lib/stripe/services/product_service.rb', line 356

def id
  @id
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



358
359
360
# File 'lib/stripe/services/product_service.rb', line 358

def images
  @images
end

#marketing_featuresObject

A list of up to 15 marketing features for this product. These are displayed in [pricing tables](stripe.com/docs/payments/checkout/pricing-table).



360
361
362
# File 'lib/stripe/services/product_service.rb', line 360

def marketing_features
  @marketing_features
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



362
363
364
# File 'lib/stripe/services/product_service.rb', line 362

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



364
365
366
# File 'lib/stripe/services/product_service.rb', line 364

def name
  @name
end

#package_dimensionsObject

The dimensions of this product for shipping purposes.



366
367
368
# File 'lib/stripe/services/product_service.rb', line 366

def package_dimensions
  @package_dimensions
end

#shippableObject

Whether this product is shipped (i.e., physical goods).



368
369
370
# File 'lib/stripe/services/product_service.rb', line 368

def shippable
  @shippable
end

#statement_descriptorObject

An arbitrary string to be displayed on your customer’s credit card or bank statement. While most banks display this information consistently, some may display it incorrectly or not at all.

This may be up to 22 characters. The statement description may not include ‘<`, `>`, ``, `“`, `’‘ characters, and will appear on your customer’s statement in capital letters. Non-ASCII characters are automatically stripped.

It must contain at least one letter. Only used for subscription payments.


373
374
375
# File 'lib/stripe/services/product_service.rb', line 373

def statement_descriptor
  @statement_descriptor
end

#tax_codeObject



375
376
377
# File 'lib/stripe/services/product_service.rb', line 375

def tax_code
  @tax_code
end

#typeObject

The type of the product. Defaults to ‘service` if not explicitly specified, enabling use of this product with Subscriptions and Plans. Set this parameter to `good` to use this product with Orders and SKUs. On API versions before `2018-02-05`, this field defaults to `good` for compatibility reasons.



377
378
379
# File 'lib/stripe/services/product_service.rb', line 377

def type
  @type
end

#unit_labelObject

A label that represents units of this product. When set, this will be included in customers’ receipts, invoices, Checkout, and the customer portal.



379
380
381
# File 'lib/stripe/services/product_service.rb', line 379

def unit_label
  @unit_label
end

#urlObject

A URL of a publicly-accessible webpage for this product.



381
382
383
# File 'lib/stripe/services/product_service.rb', line 381

def url
  @url
end