Class: Stripe::ProductService::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/product_service.rb

Defined Under Namespace

Classes: DefaultPriceData, MarketingFeature, PackageDimensions, Provisioning

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, default_price_data: nil, description: nil, expand: nil, id: nil, images: nil, marketing_features: nil, metadata: nil, name: nil, package_dimensions: nil, provisioning: nil, shippable: nil, statement_descriptor: nil, tax_code: nil, type: nil, unit_label: nil, url: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
# File 'lib/stripe/services/product_service.rb', line 486

def initialize(
  active: nil,
  default_price_data: nil,
  description: nil,
  expand: nil,
  id: nil,
  images: nil,
  marketing_features: nil,
  metadata: nil,
  name: nil,
  package_dimensions: nil,
  provisioning: nil,
  shippable: nil,
  statement_descriptor: nil,
  tax_code: nil,
  type: nil,
  unit_label: nil,
  url: nil
)
  @active = active
  @default_price_data = default_price_data
  @description = description
  @expand = expand
  @id = id
  @images = images
  @marketing_features = marketing_features
  @metadata = 
  @name = name
  @package_dimensions = package_dimensions
  @provisioning = provisioning
  @shippable = shippable
  @statement_descriptor = statement_descriptor
  @tax_code = tax_code
  @type = type
  @unit_label = unit_label
  @url = url
end

Instance Attribute Details

#activeObject

Whether the product is currently available for purchase. Defaults to ‘true`.



433
434
435
# File 'lib/stripe/services/product_service.rb', line 433

def active
  @active
end

#default_price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object. This Price will be set as the default price for this product.



436
437
438
# File 'lib/stripe/services/product_service.rb', line 436

def default_price_data
  @default_price_data
end

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



439
440
441
# File 'lib/stripe/services/product_service.rb', line 439

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



442
443
444
# File 'lib/stripe/services/product_service.rb', line 442

def expand
  @expand
end

#idObject

An identifier will be randomly generated by Stripe. You can optionally override this ID, but the ID must be unique across all products in your Stripe account.



445
446
447
# File 'lib/stripe/services/product_service.rb', line 445

def id
  @id
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



448
449
450
# File 'lib/stripe/services/product_service.rb', line 448

def images
  @images
end

#marketing_featuresObject

A list of up to 15 marketing features for this product. These are displayed in [pricing tables](stripe.com/docs/payments/checkout/pricing-table).



451
452
453
# File 'lib/stripe/services/product_service.rb', line 451

def marketing_features
  @marketing_features
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



454
455
456
# File 'lib/stripe/services/product_service.rb', line 454

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



457
458
459
# File 'lib/stripe/services/product_service.rb', line 457

def name
  @name
end

#package_dimensionsObject

The dimensions of this product for shipping purposes.



460
461
462
# File 'lib/stripe/services/product_service.rb', line 460

def package_dimensions
  @package_dimensions
end

#provisioningObject

Provisioning configuration for this product.



463
464
465
# File 'lib/stripe/services/product_service.rb', line 463

def provisioning
  @provisioning
end

#shippableObject

Whether this product is shipped (i.e., physical goods).



466
467
468
# File 'lib/stripe/services/product_service.rb', line 466

def shippable
  @shippable
end

#statement_descriptorObject

An arbitrary string to be displayed on your customer’s credit card or bank statement. While most banks display this information consistently, some may display it incorrectly or not at all.

This may be up to 22 characters. The statement description may not include ‘<`, `>`, ``, `“`, `’‘ characters, and will appear on your customer’s statement in capital letters. Non-ASCII characters are automatically stripped.

It must contain at least one letter. Only used for subscription payments.


472
473
474
# File 'lib/stripe/services/product_service.rb', line 472

def statement_descriptor
  @statement_descriptor
end

#tax_codeObject



475
476
477
# File 'lib/stripe/services/product_service.rb', line 475

def tax_code
  @tax_code
end

#typeObject

The type of the product. Defaults to ‘service` if not explicitly specified, enabling use of this product with Subscriptions and Plans. Set this parameter to `good` to use this product with Orders and SKUs. On API versions before `2018-02-05`, this field defaults to `good` for compatibility reasons.



478
479
480
# File 'lib/stripe/services/product_service.rb', line 478

def type
  @type
end

#unit_labelObject

A label that represents units of this product. When set, this will be included in customers’ receipts, invoices, Checkout, and the customer portal.



481
482
483
# File 'lib/stripe/services/product_service.rb', line 481

def unit_label
  @unit_label
end

#urlObject

A URL of a publicly-accessible webpage for this product.



484
485
486
# File 'lib/stripe/services/product_service.rb', line 484

def url
  @url
end