Class: Stripe::ProductUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ProductUpdateParams
- Defined in:
- lib/stripe/params/product_update_params.rb
Defined Under Namespace
Classes: Identifiers, MarketingFeature, PackageDimensions, TaxDetails
Instance Attribute Summary collapse
-
#active ⇒ Object
Whether the product is available for purchase.
-
#default_price ⇒ Object
The ID of the [Price](docs.stripe.com/api/prices) object that is the default price for this product.
-
#description ⇒ Object
The product’s description, meant to be displayable to the customer.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#identifiers ⇒ Object
Other identifiers for this product.
-
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
-
#marketing_features ⇒ Object
A list of up to 15 marketing features for this product.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
-
#package_dimensions ⇒ Object
The dimensions of this product for shipping purposes.
-
#shippable ⇒ Object
Whether this product is shipped (i.e., physical goods).
-
#statement_descriptor ⇒ Object
An arbitrary string to be displayed on your customer’s credit card or bank statement.
-
#tax_code ⇒ Object
A [tax code](docs.stripe.com/tax/tax-categories) ID.
-
#tax_details ⇒ Object
Tax details for this product, including the [tax code](/tax/tax-codes) and an optional performance location.
-
#unit_label ⇒ Object
A label that represents units of this product.
-
#url ⇒ Object
A URL of a publicly-accessible webpage for this product.
Instance Method Summary collapse
-
#initialize(active: nil, default_price: nil, description: nil, expand: nil, identifiers: nil, images: nil, marketing_features: nil, metadata: nil, name: nil, package_dimensions: nil, shippable: nil, statement_descriptor: nil, tax_code: nil, tax_details: nil, unit_label: nil, url: nil) ⇒ ProductUpdateParams
constructor
A new instance of ProductUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(active: nil, default_price: nil, description: nil, expand: nil, identifiers: nil, images: nil, marketing_features: nil, metadata: nil, name: nil, package_dimensions: nil, shippable: nil, statement_descriptor: nil, tax_code: nil, tax_details: nil, unit_label: nil, url: nil) ⇒ ProductUpdateParams
Returns a new instance of ProductUpdateParams.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/stripe/params/product_update_params.rb', line 107 def initialize( active: nil, default_price: nil, description: nil, expand: nil, identifiers: nil, images: nil, marketing_features: nil, metadata: nil, name: nil, package_dimensions: nil, shippable: nil, statement_descriptor: nil, tax_code: nil, tax_details: nil, unit_label: nil, url: nil ) @active = active @default_price = default_price @description = description @expand = @identifiers = identifiers @images = images @marketing_features = marketing_features @metadata = @name = name @package_dimensions = package_dimensions @shippable = shippable @statement_descriptor = statement_descriptor @tax_code = tax_code @tax_details = tax_details @unit_label = unit_label @url = url end |
Instance Attribute Details
#active ⇒ Object
Whether the product is available for purchase.
72 73 74 |
# File 'lib/stripe/params/product_update_params.rb', line 72 def active @active end |
#default_price ⇒ Object
The ID of the [Price](docs.stripe.com/api/prices) object that is the default price for this product.
74 75 76 |
# File 'lib/stripe/params/product_update_params.rb', line 74 def default_price @default_price end |
#description ⇒ Object
The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.
76 77 78 |
# File 'lib/stripe/params/product_update_params.rb', line 76 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
78 79 80 |
# File 'lib/stripe/params/product_update_params.rb', line 78 def @expand end |
#identifiers ⇒ Object
Other identifiers for this product.
80 81 82 |
# File 'lib/stripe/params/product_update_params.rb', line 80 def identifiers @identifiers end |
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
82 83 84 |
# File 'lib/stripe/params/product_update_params.rb', line 82 def images @images end |
#marketing_features ⇒ Object
A list of up to 15 marketing features for this product. These are displayed in [pricing tables](docs.stripe.com/payments/checkout/pricing-table).
84 85 86 |
# File 'lib/stripe/params/product_update_params.rb', line 84 def marketing_features @marketing_features end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
86 87 88 |
# File 'lib/stripe/params/product_update_params.rb', line 86 def @metadata end |
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
88 89 90 |
# File 'lib/stripe/params/product_update_params.rb', line 88 def name @name end |
#package_dimensions ⇒ Object
The dimensions of this product for shipping purposes.
90 91 92 |
# File 'lib/stripe/params/product_update_params.rb', line 90 def package_dimensions @package_dimensions end |
#shippable ⇒ Object
Whether this product is shipped (i.e., physical goods).
92 93 94 |
# File 'lib/stripe/params/product_update_params.rb', line 92 def shippable @shippable end |
#statement_descriptor ⇒ Object
An arbitrary string to be displayed on your customer’s credit card or bank statement. While most banks display this information consistently, some may display it incorrectly or not at all.
This may be up to 22 characters. The statement description may not include ‘<`, `>`, ``, `“`, `’‘ characters, and will appear on your customer’s statement in capital letters. Non-ASCII characters are automatically stripped.
It must contain at least one letter. May only be set if `type=service`. Only used for subscription payments.
97 98 99 |
# File 'lib/stripe/params/product_update_params.rb', line 97 def statement_descriptor @statement_descriptor end |
#tax_code ⇒ Object
A [tax code](docs.stripe.com/tax/tax-categories) ID.
99 100 101 |
# File 'lib/stripe/params/product_update_params.rb', line 99 def tax_code @tax_code end |
#tax_details ⇒ Object
Tax details for this product, including the [tax code](/tax/tax-codes) and an optional performance location.
101 102 103 |
# File 'lib/stripe/params/product_update_params.rb', line 101 def tax_details @tax_details end |
#unit_label ⇒ Object
A label that represents units of this product. When set, this will be included in customers’ receipts, invoices, Checkout, and the customer portal. May only be set if ‘type=service`.
103 104 105 |
# File 'lib/stripe/params/product_update_params.rb', line 103 def unit_label @unit_label end |
#url ⇒ Object
A URL of a publicly-accessible webpage for this product.
105 106 107 |
# File 'lib/stripe/params/product_update_params.rb', line 105 def url @url end |