Class: Stripe::PromotionCode::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PromotionCode::ListParams
- Defined in:
- lib/stripe/resources/promotion_code.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#active ⇒ Object
Filter promotion codes by whether they are active.
-
#code ⇒ Object
Only return promotion codes that have this case-insensitive code.
-
#coupon ⇒ Object
Only return promotion codes for this coupon.
-
#created ⇒ Object
A filter on the list, based on the object ‘created` field.
-
#customer ⇒ Object
Only return promotion codes that are restricted to this customer.
-
#customer_account ⇒ Object
Only return promotion codes that are restricted to this account.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(active: nil, code: nil, coupon: nil, created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, code: nil, coupon: nil, created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/stripe/resources/promotion_code.rb', line 71 def initialize( active: nil, code: nil, coupon: nil, created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil ) @active = active @code = code @coupon = coupon @created = created @customer = customer @customer_account = customer_account @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#active ⇒ Object
Filter promotion codes by whether they are active.
51 52 53 |
# File 'lib/stripe/resources/promotion_code.rb', line 51 def active @active end |
#code ⇒ Object
Only return promotion codes that have this case-insensitive code.
53 54 55 |
# File 'lib/stripe/resources/promotion_code.rb', line 53 def code @code end |
#coupon ⇒ Object
Only return promotion codes for this coupon.
55 56 57 |
# File 'lib/stripe/resources/promotion_code.rb', line 55 def coupon @coupon end |
#created ⇒ Object
A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.
57 58 59 |
# File 'lib/stripe/resources/promotion_code.rb', line 57 def created @created end |
#customer ⇒ Object
Only return promotion codes that are restricted to this customer.
59 60 61 |
# File 'lib/stripe/resources/promotion_code.rb', line 59 def customer @customer end |
#customer_account ⇒ Object
Only return promotion codes that are restricted to this account.
61 62 63 |
# File 'lib/stripe/resources/promotion_code.rb', line 61 def customer_account @customer_account end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
63 64 65 |
# File 'lib/stripe/resources/promotion_code.rb', line 63 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
65 66 67 |
# File 'lib/stripe/resources/promotion_code.rb', line 65 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
67 68 69 |
# File 'lib/stripe/resources/promotion_code.rb', line 67 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
69 70 71 |
# File 'lib/stripe/resources/promotion_code.rb', line 69 def starting_after @starting_after end |