Class: Stripe::PromotionCode::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/promotion_code.rb

Defined Under Namespace

Classes: Restrictions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, expand: nil, metadata: nil, restrictions: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



201
202
203
204
205
206
# File 'lib/stripe/resources/promotion_code.rb', line 201

def initialize(active: nil, expand: nil, metadata: nil, restrictions: nil)
  @active = active
  @expand = expand
  @metadata = 
  @restrictions = restrictions
end

Instance Attribute Details

#activeObject

Whether the promotion code is currently active. A promotion code can only be reactivated when the coupon is still valid and the promotion code is otherwise redeemable.



193
194
195
# File 'lib/stripe/resources/promotion_code.rb', line 193

def active
  @active
end

#expandObject

Specifies which fields in the response should be expanded.



195
196
197
# File 'lib/stripe/resources/promotion_code.rb', line 195

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



197
198
199
# File 'lib/stripe/resources/promotion_code.rb', line 197

def 
  @metadata
end

#restrictionsObject

Settings that restrict the redemption of the promotion code.



199
200
201
# File 'lib/stripe/resources/promotion_code.rb', line 199

def restrictions
  @restrictions
end