Class: Stripe::PromotionCodeService::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/promotion_code_service.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, code: nil, coupon: nil, created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/stripe/services/promotion_code_service.rb', line 45

def initialize(
  active: nil,
  code: nil,
  coupon: nil,
  created: nil,
  customer: nil,
  customer_account: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil
)
  @active = active
  @code = code
  @coupon = coupon
  @created = created
  @customer = customer
  @customer_account = 
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#activeObject

Filter promotion codes by whether they are active.



25
26
27
# File 'lib/stripe/services/promotion_code_service.rb', line 25

def active
  @active
end

#codeObject

Only return promotion codes that have this case-insensitive code.



27
28
29
# File 'lib/stripe/services/promotion_code_service.rb', line 27

def code
  @code
end

#couponObject

Only return promotion codes for this coupon.



29
30
31
# File 'lib/stripe/services/promotion_code_service.rb', line 29

def coupon
  @coupon
end

#createdObject

A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.



31
32
33
# File 'lib/stripe/services/promotion_code_service.rb', line 31

def created
  @created
end

#customerObject

Only return promotion codes that are restricted to this customer.



33
34
35
# File 'lib/stripe/services/promotion_code_service.rb', line 33

def customer
  @customer
end

#customer_accountObject

Only return promotion codes that are restricted to this account.



35
36
37
# File 'lib/stripe/services/promotion_code_service.rb', line 35

def 
  @customer_account
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



37
38
39
# File 'lib/stripe/services/promotion_code_service.rb', line 37

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



39
40
41
# File 'lib/stripe/services/promotion_code_service.rb', line 39

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



41
42
43
# File 'lib/stripe/services/promotion_code_service.rb', line 41

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



43
44
45
# File 'lib/stripe/services/promotion_code_service.rb', line 43

def starting_after
  @starting_after
end