Class: Stripe::PromotionCodeService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PromotionCodeService::ListParams
- Defined in:
- lib/stripe/services/promotion_code_service.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#active ⇒ Object
Filter promotion codes by whether they are active.
-
#code ⇒ Object
Only return promotion codes that have this case-insensitive code.
-
#coupon ⇒ Object
Only return promotion codes for this coupon.
-
#created ⇒ Object
A filter on the list, based on the object ‘created` field.
-
#customer ⇒ Object
Only return promotion codes that are restricted to this customer.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(active: nil, code: nil, coupon: nil, created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, code: nil, coupon: nil, created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/stripe/services/promotion_code_service.rb', line 54 def initialize( active: nil, code: nil, coupon: nil, created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil ) @active = active @code = code @coupon = coupon @created = created @customer = customer @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#active ⇒ Object
Filter promotion codes by whether they are active.
28 29 30 |
# File 'lib/stripe/services/promotion_code_service.rb', line 28 def active @active end |
#code ⇒ Object
Only return promotion codes that have this case-insensitive code.
31 32 33 |
# File 'lib/stripe/services/promotion_code_service.rb', line 31 def code @code end |
#coupon ⇒ Object
Only return promotion codes for this coupon.
34 35 36 |
# File 'lib/stripe/services/promotion_code_service.rb', line 34 def coupon @coupon end |
#created ⇒ Object
A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.
37 38 39 |
# File 'lib/stripe/services/promotion_code_service.rb', line 37 def created @created end |
#customer ⇒ Object
Only return promotion codes that are restricted to this customer.
40 41 42 |
# File 'lib/stripe/services/promotion_code_service.rb', line 40 def customer @customer end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
43 44 45 |
# File 'lib/stripe/services/promotion_code_service.rb', line 43 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
46 47 48 |
# File 'lib/stripe/services/promotion_code_service.rb', line 46 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
49 50 51 |
# File 'lib/stripe/services/promotion_code_service.rb', line 49 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
52 53 54 |
# File 'lib/stripe/services/promotion_code_service.rb', line 52 def starting_after @starting_after end |