Class: Stripe::Quote::AcceptParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::AcceptParams
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ AcceptParams
constructor
A new instance of AcceptParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ AcceptParams
Returns a new instance of AcceptParams.
2725 2726 2727 |
# File 'lib/stripe/resources/quote.rb', line 2725 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2723 2724 2725 |
# File 'lib/stripe/resources/quote.rb', line 2723 def @expand end |