Class: Stripe::Quote::AcceptParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::AcceptParams
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ AcceptParams
constructor
A new instance of AcceptParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ AcceptParams
Returns a new instance of AcceptParams.
2711 2712 2713 |
# File 'lib/stripe/resources/quote.rb', line 2711 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2709 2710 2711 |
# File 'lib/stripe/resources/quote.rb', line 2709 def @expand end |