Class: Stripe::Quote::Computed
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::Computed
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: LastReestimationDetails, Recurring, Upfront
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#last_reestimation_details ⇒ Object
readonly
Details of the most recent reestimate of the quote’s preview schedules and upcoming invoices, including the status of Stripe’s calculation.
-
#recurring ⇒ Object
readonly
The definitive totals and line items the customer will be charged on a recurring basis.
-
#updated_at ⇒ Object
readonly
The time at which the quote’s estimated schedules and upcoming invoices were generated.
-
#upfront ⇒ Object
readonly
Attribute for field upfront.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#last_reestimation_details ⇒ Object (readonly)
Details of the most recent reestimate of the quote’s preview schedules and upcoming invoices, including the status of Stripe’s calculation.
266 267 268 |
# File 'lib/stripe/resources/quote.rb', line 266 def last_reestimation_details @last_reestimation_details end |
#recurring ⇒ Object (readonly)
The definitive totals and line items the customer will be charged on a recurring basis. Takes into account the line items with recurring prices and discounts with ‘duration=forever` coupons only. Defaults to `null` if no inputted line items with recurring prices.
268 269 270 |
# File 'lib/stripe/resources/quote.rb', line 268 def recurring @recurring end |
#updated_at ⇒ Object (readonly)
The time at which the quote’s estimated schedules and upcoming invoices were generated.
270 271 272 |
# File 'lib/stripe/resources/quote.rb', line 270 def updated_at @updated_at end |
#upfront ⇒ Object (readonly)
Attribute for field upfront
272 273 274 |
# File 'lib/stripe/resources/quote.rb', line 272 def upfront @upfront end |
Class Method Details
.field_remappings ⇒ Object
282 283 284 |
# File 'lib/stripe/resources/quote.rb', line 282 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
274 275 276 277 278 279 280 |
# File 'lib/stripe/resources/quote.rb', line 274 def self.inner_class_types @inner_class_types = { last_reestimation_details: LastReestimationDetails, recurring: Recurring, upfront: Upfront, } end |