Class: Stripe::Quote::Computed

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: LastReestimationDetails, Recurring, Upfront

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#last_reestimation_detailsObject (readonly)

Details of the most recent reestimate of the quote’s preview schedules and upcoming invoices, including the status of Stripe’s calculation.



181
182
183
# File 'lib/stripe/resources/quote.rb', line 181

def last_reestimation_details
  @last_reestimation_details
end

#recurringObject (readonly)

The definitive totals and line items the customer will be charged on a recurring basis. Takes into account the line items with recurring prices and discounts with ‘duration=forever` coupons only. Defaults to `null` if no inputted line items with recurring prices.



184
185
186
# File 'lib/stripe/resources/quote.rb', line 184

def recurring
  @recurring
end

#updated_atObject (readonly)

The time at which the quote’s estimated schedules and upcoming invoices were generated.



187
188
189
# File 'lib/stripe/resources/quote.rb', line 187

def updated_at
  @updated_at
end

#upfrontObject (readonly)

Attribute for field upfront



190
191
192
# File 'lib/stripe/resources/quote.rb', line 190

def upfront
  @upfront
end