Class: Stripe::Quote::Computed::LastReestimationDetails::Failed
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::Computed::LastReestimationDetails::Failed
- Defined in:
- lib/stripe/resources/quote.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#failure_code ⇒ Object
readonly
The failure ‘code` is more granular than the `reason` provided and may correspond to a Stripe error code.
-
#message ⇒ Object
readonly
Information derived from the ‘failure_code` or a freeform message that explains the error as a human-readable English string.
-
#reason ⇒ Object
readonly
The reason the reestimation failed.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#failure_code ⇒ Object (readonly)
The failure ‘code` is more granular than the `reason` provided and may correspond to a Stripe error code. For automation errors, this field is one of: `reverse_api_failure`, `reverse_api_deadline_exceeeded`, or `reverse_api_response_validation_error`, which are Stripe error codes and map to the error `message` field.
42 43 44 |
# File 'lib/stripe/resources/quote.rb', line 42 def failure_code @failure_code end |
#message ⇒ Object (readonly)
Information derived from the ‘failure_code` or a freeform message that explains the error as a human-readable English string. For example, “margin ID is not a valid ID”.
44 45 46 |
# File 'lib/stripe/resources/quote.rb', line 44 def @message end |
#reason ⇒ Object (readonly)
The reason the reestimation failed.
46 47 48 |
# File 'lib/stripe/resources/quote.rb', line 46 def reason @reason end |