Class: Stripe::Quote::Computed::Upfront

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: TotalDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_subtotalObject (readonly)

Total before any discounts or taxes are applied.



143
144
145
# File 'lib/stripe/resources/quote.rb', line 143

def amount_subtotal
  @amount_subtotal
end

#amount_totalObject (readonly)

Total after discounts and taxes are applied.



145
146
147
# File 'lib/stripe/resources/quote.rb', line 145

def amount_total
  @amount_total
end

#line_itemsObject (readonly)

The line items that will appear on the next invoice after this quote is accepted. This does not include pending invoice items that exist on the customer but may still be included in the next invoice.



147
148
149
# File 'lib/stripe/resources/quote.rb', line 147

def line_items
  @line_items
end

#total_detailsObject (readonly)

Attribute for field total_details



149
150
151
# File 'lib/stripe/resources/quote.rb', line 149

def total_details
  @total_details
end