Class: Stripe::Quote::Computed::Upfront
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::Computed::Upfront
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: TotalDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_subtotal ⇒ Object
readonly
Total before any discounts or taxes are applied.
-
#amount_total ⇒ Object
readonly
Total after discounts and taxes are applied.
-
#line_items ⇒ Object
readonly
The line items that will appear on the next invoice after this quote is accepted.
-
#total_details ⇒ Object
readonly
Attribute for field total_details.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_subtotal ⇒ Object (readonly)
Total before any discounts or taxes are applied.
169 170 171 |
# File 'lib/stripe/resources/quote.rb', line 169 def amount_subtotal @amount_subtotal end |
#amount_total ⇒ Object (readonly)
Total after discounts and taxes are applied.
172 173 174 |
# File 'lib/stripe/resources/quote.rb', line 172 def amount_total @amount_total end |
#line_items ⇒ Object (readonly)
The line items that will appear on the next invoice after this quote is accepted. This does not include pending invoice items that exist on the customer but may still be included in the next invoice.
175 176 177 |
# File 'lib/stripe/resources/quote.rb', line 175 def line_items @line_items end |
#total_details ⇒ Object (readonly)
Attribute for field total_details
178 179 180 |
# File 'lib/stripe/resources/quote.rb', line 178 def total_details @total_details end |