Class: Stripe::Quote::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: AutomaticTax, Discount, FromQuote, InvoiceSettings, Line, LineItem, SubscriptionData, SubscriptionDataOverride, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_backdated_lines: nil, application_fee_amount: nil, application_fee_percent: nil, automatic_tax: nil, collection_method: nil, customer: nil, customer_account: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, expires_at: nil, footer: nil, from_quote: nil, header: nil, invoice_settings: nil, line_items: nil, lines: nil, metadata: nil, on_behalf_of: nil, subscription_data: nil, subscription_data_overrides: nil, test_clock: nil, transfer_data: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
# File 'lib/stripe/resources/quote.rb', line 1958

def initialize(
  allow_backdated_lines: nil,
  application_fee_amount: nil,
  application_fee_percent: nil,
  automatic_tax: nil,
  collection_method: nil,
  customer: nil,
  customer_account: nil,
  default_tax_rates: nil,
  description: nil,
  discounts: nil,
  expand: nil,
  expires_at: nil,
  footer: nil,
  from_quote: nil,
  header: nil,
  invoice_settings: nil,
  line_items: nil,
  lines: nil,
  metadata: nil,
  on_behalf_of: nil,
  subscription_data: nil,
  subscription_data_overrides: nil,
  test_clock: nil,
  transfer_data: nil
)
  @allow_backdated_lines = allow_backdated_lines
  @application_fee_amount = application_fee_amount
  @application_fee_percent = application_fee_percent
  @automatic_tax = automatic_tax
  @collection_method = collection_method
  @customer = customer
  @customer_account = 
  @default_tax_rates = default_tax_rates
  @description = description
  @discounts = discounts
  @expand = expand
  @expires_at = expires_at
  @footer = footer
  @from_quote = from_quote
  @header = header
  @invoice_settings = invoice_settings
  @line_items = line_items
  @lines = lines
  @metadata = 
  @on_behalf_of = on_behalf_of
  @subscription_data = subscription_data
  @subscription_data_overrides = subscription_data_overrides
  @test_clock = test_clock
  @transfer_data = transfer_data
end

Instance Attribute Details

#allow_backdated_linesObject

Set to true to allow quote lines to have ‘starts_at` in the past if collection is paused between `starts_at` and now.



1910
1911
1912
# File 'lib/stripe/resources/quote.rb', line 1910

def allow_backdated_lines
  @allow_backdated_lines
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. There cannot be any line items with recurring prices when using this field.



1912
1913
1914
# File 'lib/stripe/resources/quote.rb', line 1912

def application_fee_amount
  @application_fee_amount
end

#application_fee_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. There must be at least 1 line item with a recurring price to use this field.



1914
1915
1916
# File 'lib/stripe/resources/quote.rb', line 1914

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject

Settings for automatic tax lookup for this quote and resulting invoices and subscriptions.



1916
1917
1918
# File 'lib/stripe/resources/quote.rb', line 1916

def automatic_tax
  @automatic_tax
end

#collection_methodObject

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay invoices at the end of the subscription cycle or at invoice finalization using the default payment method attached to the subscription or customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically`.



1918
1919
1920
# File 'lib/stripe/resources/quote.rb', line 1918

def collection_method
  @collection_method
end

#customerObject

The customer for which this quote belongs to. A customer is required before finalizing the quote. Once specified, it cannot be changed.



1920
1921
1922
# File 'lib/stripe/resources/quote.rb', line 1920

def customer
  @customer
end

#customer_accountObject

The account for which this quote belongs to. A customer or account is required before finalizing the quote. Once specified, it cannot be changed.



1922
1923
1924
# File 'lib/stripe/resources/quote.rb', line 1922

def 
  @customer_account
end

#default_tax_ratesObject

The tax rates that will apply to any line item that does not have ‘tax_rates` set.



1924
1925
1926
# File 'lib/stripe/resources/quote.rb', line 1924

def default_tax_rates
  @default_tax_rates
end

#descriptionObject

A description that will be displayed on the quote PDF. If no value is passed, the default description configured in your [quote template settings](dashboard.stripe.com/settings/billing/quote) will be used.



1926
1927
1928
# File 'lib/stripe/resources/quote.rb', line 1926

def description
  @description
end

#discountsObject

The discounts applied to the quote.



1928
1929
1930
# File 'lib/stripe/resources/quote.rb', line 1928

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



1930
1931
1932
# File 'lib/stripe/resources/quote.rb', line 1930

def expand
  @expand
end

#expires_atObject

A future timestamp on which the quote will be canceled if in ‘open` or `draft` status. Measured in seconds since the Unix epoch. If no value is passed, the default expiration date configured in your [quote template settings](dashboard.stripe.com/settings/billing/quote) will be used.



1932
1933
1934
# File 'lib/stripe/resources/quote.rb', line 1932

def expires_at
  @expires_at
end

A footer that will be displayed on the quote PDF. If no value is passed, the default footer configured in your [quote template settings](dashboard.stripe.com/settings/billing/quote) will be used.



1934
1935
1936
# File 'lib/stripe/resources/quote.rb', line 1934

def footer
  @footer
end

#from_quoteObject

Clone an existing quote. The new quote will be created in ‘status=draft`. When using this parameter, you cannot specify any other parameters except for `expires_at`.



1936
1937
1938
# File 'lib/stripe/resources/quote.rb', line 1936

def from_quote
  @from_quote
end

#headerObject

A header that will be displayed on the quote PDF. If no value is passed, the default header configured in your [quote template settings](dashboard.stripe.com/settings/billing/quote) will be used.



1938
1939
1940
# File 'lib/stripe/resources/quote.rb', line 1938

def header
  @header
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



1940
1941
1942
# File 'lib/stripe/resources/quote.rb', line 1940

def invoice_settings
  @invoice_settings
end

#line_itemsObject

A list of line items the customer is being quoted for. Each line item includes information about the product, the quantity, and the resulting cost.



1942
1943
1944
# File 'lib/stripe/resources/quote.rb', line 1942

def line_items
  @line_items
end

#linesObject

A list of [quote lines](docs.stripe.com/api/quote_lines) on the quote. These lines describe changes, in the order provided, that will be used to create new subscription schedules or update existing subscription schedules when the quote is accepted.



1944
1945
1946
# File 'lib/stripe/resources/quote.rb', line 1944

def lines
  @lines
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1946
1947
1948
# File 'lib/stripe/resources/quote.rb', line 1946

def 
  @metadata
end

#on_behalf_ofObject

The account on behalf of which to charge.



1948
1949
1950
# File 'lib/stripe/resources/quote.rb', line 1948

def on_behalf_of
  @on_behalf_of
end

#subscription_dataObject

When creating a subscription or subscription schedule, the specified configuration data will be used. There must be at least one line item with a recurring price for a subscription or subscription schedule to be created. A subscription schedule is created if ‘subscription_data` is present and in the future, otherwise a subscription is created.



1950
1951
1952
# File 'lib/stripe/resources/quote.rb', line 1950

def subscription_data
  @subscription_data
end

#subscription_data_overridesObject

List representing overrides for ‘subscription_data` configurations for specific subscription schedules.



1952
1953
1954
# File 'lib/stripe/resources/quote.rb', line 1952

def subscription_data_overrides
  @subscription_data_overrides
end

#test_clockObject

ID of the test clock to attach to the quote.



1954
1955
1956
# File 'lib/stripe/resources/quote.rb', line 1954

def test_clock
  @test_clock
end

#transfer_dataObject

The data with which to automatically create a Transfer for each of the invoices.



1956
1957
1958
# File 'lib/stripe/resources/quote.rb', line 1956

def transfer_data
  @transfer_data
end