Class: Stripe::Quote::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::CreateParams
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: AutomaticTax, Discount, FromQuote, InvoiceSettings, Line, LineItem, SubscriptionData, SubscriptionDataOverride, TransferData
Instance Attribute Summary collapse
-
#allow_backdated_lines ⇒ Object
Set to true to allow quote lines to have ‘starts_at` in the past if collection is paused between `starts_at` and now.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this quote and resulting invoices and subscriptions.
-
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`.
-
#customer ⇒ Object
The customer for which this quote belongs to.
-
#default_tax_rates ⇒ Object
The tax rates that will apply to any line item that does not have ‘tax_rates` set.
-
#description ⇒ Object
A description that will be displayed on the quote PDF.
-
#discounts ⇒ Object
The discounts applied to the quote.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expires_at ⇒ Object
A future timestamp on which the quote will be canceled if in ‘open` or `draft` status.
-
#footer ⇒ Object
A footer that will be displayed on the quote PDF.
-
#from_quote ⇒ Object
Clone an existing quote.
-
#header ⇒ Object
A header that will be displayed on the quote PDF.
-
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
-
#line_items ⇒ Object
A list of line items the customer is being quoted for.
-
#lines ⇒ Object
A list of [quote lines](docs.stripe.com/api/quote_lines) on the quote.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#on_behalf_of ⇒ Object
The account on behalf of which to charge.
-
#subscription_data ⇒ Object
When creating a subscription or subscription schedule, the specified configuration data will be used.
-
#subscription_data_overrides ⇒ Object
List representing overrides for ‘subscription_data` configurations for specific subscription schedules.
-
#test_clock ⇒ Object
ID of the test clock to attach to the quote.
-
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the invoices.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(allow_backdated_lines: nil, application_fee_amount: nil, application_fee_percent: nil, automatic_tax: nil, collection_method: nil, customer: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, expires_at: nil, footer: nil, from_quote: nil, header: nil, invoice_settings: nil, line_items: nil, lines: nil, metadata: nil, on_behalf_of: nil, subscription_data: nil, subscription_data_overrides: nil, test_clock: nil, transfer_data: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 |
# File 'lib/stripe/resources/quote.rb', line 1775 def initialize( allow_backdated_lines: nil, application_fee_amount: nil, application_fee_percent: nil, automatic_tax: nil, collection_method: nil, customer: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, expires_at: nil, footer: nil, from_quote: nil, header: nil, invoice_settings: nil, line_items: nil, lines: nil, metadata: nil, on_behalf_of: nil, subscription_data: nil, subscription_data_overrides: nil, test_clock: nil, transfer_data: nil ) @allow_backdated_lines = allow_backdated_lines @application_fee_amount = application_fee_amount @application_fee_percent = application_fee_percent @automatic_tax = automatic_tax @collection_method = collection_method @customer = customer @default_tax_rates = default_tax_rates @description = description @discounts = discounts @expand = @expires_at = expires_at @footer = @from_quote = from_quote @header = header @invoice_settings = invoice_settings @line_items = line_items @lines = lines @metadata = @on_behalf_of = on_behalf_of @subscription_data = subscription_data @subscription_data_overrides = subscription_data_overrides @test_clock = test_clock @transfer_data = transfer_data end |
Instance Attribute Details
#allow_backdated_lines ⇒ Object
Set to true to allow quote lines to have ‘starts_at` in the past if collection is paused between `starts_at` and now.
1707 1708 1709 |
# File 'lib/stripe/resources/quote.rb', line 1707 def allow_backdated_lines @allow_backdated_lines end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. There cannot be any line items with recurring prices when using this field.
1710 1711 1712 |
# File 'lib/stripe/resources/quote.rb', line 1710 def application_fee_amount @application_fee_amount end |
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. There must be at least 1 line item with a recurring price to use this field.
1713 1714 1715 |
# File 'lib/stripe/resources/quote.rb', line 1713 def application_fee_percent @application_fee_percent end |
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this quote and resulting invoices and subscriptions.
1716 1717 1718 |
# File 'lib/stripe/resources/quote.rb', line 1716 def automatic_tax @automatic_tax end |
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay invoices at the end of the subscription cycle or at invoice finalization using the default payment method attached to the subscription or customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically`.
1719 1720 1721 |
# File 'lib/stripe/resources/quote.rb', line 1719 def collection_method @collection_method end |
#customer ⇒ Object
The customer for which this quote belongs to. A customer is required before finalizing the quote. Once specified, it cannot be changed.
1722 1723 1724 |
# File 'lib/stripe/resources/quote.rb', line 1722 def customer @customer end |
#default_tax_rates ⇒ Object
The tax rates that will apply to any line item that does not have ‘tax_rates` set.
1725 1726 1727 |
# File 'lib/stripe/resources/quote.rb', line 1725 def default_tax_rates @default_tax_rates end |
#description ⇒ Object
A description that will be displayed on the quote PDF. If no value is passed, the default description configured in your [quote template settings](dashboard.stripe.com/settings/billing/quote) will be used.
1728 1729 1730 |
# File 'lib/stripe/resources/quote.rb', line 1728 def description @description end |
#discounts ⇒ Object
The discounts applied to the quote.
1731 1732 1733 |
# File 'lib/stripe/resources/quote.rb', line 1731 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1734 1735 1736 |
# File 'lib/stripe/resources/quote.rb', line 1734 def @expand end |
#expires_at ⇒ Object
A future timestamp on which the quote will be canceled if in ‘open` or `draft` status. Measured in seconds since the Unix epoch. If no value is passed, the default expiration date configured in your [quote template settings](dashboard.stripe.com/settings/billing/quote) will be used.
1737 1738 1739 |
# File 'lib/stripe/resources/quote.rb', line 1737 def expires_at @expires_at end |
#footer ⇒ Object
A footer that will be displayed on the quote PDF. If no value is passed, the default footer configured in your [quote template settings](dashboard.stripe.com/settings/billing/quote) will be used.
1740 1741 1742 |
# File 'lib/stripe/resources/quote.rb', line 1740 def @footer end |
#from_quote ⇒ Object
Clone an existing quote. The new quote will be created in ‘status=draft`. When using this parameter, you cannot specify any other parameters except for `expires_at`.
1743 1744 1745 |
# File 'lib/stripe/resources/quote.rb', line 1743 def from_quote @from_quote end |
#header ⇒ Object
A header that will be displayed on the quote PDF. If no value is passed, the default header configured in your [quote template settings](dashboard.stripe.com/settings/billing/quote) will be used.
1746 1747 1748 |
# File 'lib/stripe/resources/quote.rb', line 1746 def header @header end |
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
1749 1750 1751 |
# File 'lib/stripe/resources/quote.rb', line 1749 def invoice_settings @invoice_settings end |
#line_items ⇒ Object
A list of line items the customer is being quoted for. Each line item includes information about the product, the quantity, and the resulting cost.
1752 1753 1754 |
# File 'lib/stripe/resources/quote.rb', line 1752 def line_items @line_items end |
#lines ⇒ Object
A list of [quote lines](docs.stripe.com/api/quote_lines) on the quote. These lines describe changes, in the order provided, that will be used to create new subscription schedules or update existing subscription schedules when the quote is accepted.
1755 1756 1757 |
# File 'lib/stripe/resources/quote.rb', line 1755 def lines @lines end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1758 1759 1760 |
# File 'lib/stripe/resources/quote.rb', line 1758 def @metadata end |
#on_behalf_of ⇒ Object
The account on behalf of which to charge.
1761 1762 1763 |
# File 'lib/stripe/resources/quote.rb', line 1761 def on_behalf_of @on_behalf_of end |
#subscription_data ⇒ Object
When creating a subscription or subscription schedule, the specified configuration data will be used. There must be at least one line item with a recurring price for a subscription or subscription schedule to be created. A subscription schedule is created if ‘subscription_data` is present and in the future, otherwise a subscription is created.
1764 1765 1766 |
# File 'lib/stripe/resources/quote.rb', line 1764 def subscription_data @subscription_data end |
#subscription_data_overrides ⇒ Object
List representing overrides for ‘subscription_data` configurations for specific subscription schedules.
1767 1768 1769 |
# File 'lib/stripe/resources/quote.rb', line 1767 def subscription_data_overrides @subscription_data_overrides end |
#test_clock ⇒ Object
ID of the test clock to attach to the quote.
1770 1771 1772 |
# File 'lib/stripe/resources/quote.rb', line 1770 def test_clock @test_clock end |
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the invoices.
1773 1774 1775 |
# File 'lib/stripe/resources/quote.rb', line 1773 def transfer_data @transfer_data end |