Class: Stripe::Quote::CreateParams::AutomaticTax

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Liability

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax

Returns a new instance of AutomaticTax.



626
627
628
629
# File 'lib/stripe/resources/quote.rb', line 626

def initialize(enabled: nil, liability: nil)
  @enabled = enabled
  @liability = liability
end

Instance Attribute Details

#enabledObject

Controls whether Stripe will automatically compute tax on the resulting invoices or subscriptions as well as the quote itself.



621
622
623
# File 'lib/stripe/resources/quote.rb', line 621

def enabled
  @enabled
end

#liabilityObject

The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.



624
625
626
# File 'lib/stripe/resources/quote.rb', line 624

def liability
  @liability
end