Class: Stripe::Quote::CreateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::CreateParams::Discount
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
301 302 303 304 305 |
# File 'lib/stripe/resources/quote.rb', line 301 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
295 296 297 |
# File 'lib/stripe/resources/quote.rb', line 295 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
297 298 299 |
# File 'lib/stripe/resources/quote.rb', line 297 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
299 300 301 |
# File 'lib/stripe/resources/quote.rb', line 299 def promotion_code @promotion_code end |