Class: Stripe::Quote::CreateParams::Discount

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



570
571
572
573
574
575
# File 'lib/stripe/resources/quote.rb', line 570

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



562
563
564
# File 'lib/stripe/resources/quote.rb', line 562

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



564
565
566
# File 'lib/stripe/resources/quote.rb', line 564

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



566
567
568
# File 'lib/stripe/resources/quote.rb', line 566

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



568
569
570
# File 'lib/stripe/resources/quote.rb', line 568

def promotion_code
  @promotion_code
end