Class: Stripe::Quote::CreateParams::Discount

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



673
674
675
676
677
678
# File 'lib/stripe/resources/quote.rb', line 673

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



662
663
664
# File 'lib/stripe/resources/quote.rb', line 662

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



665
666
667
# File 'lib/stripe/resources/quote.rb', line 665

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



668
669
670
# File 'lib/stripe/resources/quote.rb', line 668

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



671
672
673
# File 'lib/stripe/resources/quote.rb', line 671

def promotion_code
  @promotion_code
end