Class: Stripe::Quote::CreateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



542
543
544
545
546
# File 'lib/stripe/resources/quote.rb', line 542

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



536
537
538
# File 'lib/stripe/resources/quote.rb', line 536

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



538
539
540
# File 'lib/stripe/resources/quote.rb', line 538

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



540
541
542
# File 'lib/stripe/resources/quote.rb', line 540

def type
  @type
end