Class: Stripe::Quote::CreateParams::FromQuote
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::CreateParams::FromQuote
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#is_revision ⇒ Object
Whether this quote is a revision of the previous quote.
-
#quote ⇒ Object
The ‘id` of the quote that will be cloned.
Instance Method Summary collapse
-
#initialize(is_revision: nil, quote: nil) ⇒ FromQuote
constructor
A new instance of FromQuote.
Methods inherited from RequestParams
Constructor Details
#initialize(is_revision: nil, quote: nil) ⇒ FromQuote
Returns a new instance of FromQuote.
688 689 690 691 |
# File 'lib/stripe/resources/quote.rb', line 688 def initialize(is_revision: nil, quote: nil) @is_revision = is_revision @quote = quote end |
Instance Attribute Details
#is_revision ⇒ Object
Whether this quote is a revision of the previous quote.
683 684 685 |
# File 'lib/stripe/resources/quote.rb', line 683 def is_revision @is_revision end |
#quote ⇒ Object
The ‘id` of the quote that will be cloned.
686 687 688 |
# File 'lib/stripe/resources/quote.rb', line 686 def quote @quote end |