Class: Stripe::Quote::CreateParams::Line::Action::AddDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ AddDiscount

Returns a new instance of AddDiscount.



630
631
632
633
634
635
636
637
638
639
640
641
642
# File 'lib/stripe/resources/quote.rb', line 630

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



620
621
622
# File 'lib/stripe/resources/quote.rb', line 620

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



622
623
624
# File 'lib/stripe/resources/quote.rb', line 622

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



624
625
626
# File 'lib/stripe/resources/quote.rb', line 624

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



626
627
628
# File 'lib/stripe/resources/quote.rb', line 626

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



628
629
630
# File 'lib/stripe/resources/quote.rb', line 628

def promotion_code
  @promotion_code
end