Class: Stripe::Quote::CreateParams::Line::Action::AddDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ AddDiscount

Returns a new instance of AddDiscount.



745
746
747
748
749
750
751
752
753
754
755
756
757
# File 'lib/stripe/resources/quote.rb', line 745

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



731
732
733
# File 'lib/stripe/resources/quote.rb', line 731

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



734
735
736
# File 'lib/stripe/resources/quote.rb', line 734

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



737
738
739
# File 'lib/stripe/resources/quote.rb', line 737

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



740
741
742
# File 'lib/stripe/resources/quote.rb', line 740

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



743
744
745
# File 'lib/stripe/resources/quote.rb', line 743

def promotion_code
  @promotion_code
end