Class: Stripe::Quote::CreateParams::Line::Action::AddItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ AddItem

Returns a new instance of AddItem.



711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
# File 'lib/stripe/resources/quote.rb', line 711

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



699
700
701
# File 'lib/stripe/resources/quote.rb', line 699

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



701
702
703
# File 'lib/stripe/resources/quote.rb', line 701

def 
  @metadata
end

#priceObject

The ID of the price object.



703
704
705
# File 'lib/stripe/resources/quote.rb', line 703

def price
  @price
end

#quantityObject

Quantity for this item.



705
706
707
# File 'lib/stripe/resources/quote.rb', line 705

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



707
708
709
# File 'lib/stripe/resources/quote.rb', line 707

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



709
710
711
# File 'lib/stripe/resources/quote.rb', line 709

def trial
  @trial
end