Class: Stripe::Quote::CreateParams::Line::Action::AddItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::CreateParams::Line::Action::AddItem
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to the item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates that apply to this subscription item.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ AddItem
constructor
A new instance of AddItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ AddItem
Returns a new instance of AddItem.
840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 |
# File 'lib/stripe/resources/quote.rb', line 840 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to the item. Subscription item discounts are applied before subscription discounts.
823 824 825 |
# File 'lib/stripe/resources/quote.rb', line 823 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
826 827 828 |
# File 'lib/stripe/resources/quote.rb', line 826 def @metadata end |
#price ⇒ Object
The ID of the price object.
829 830 831 |
# File 'lib/stripe/resources/quote.rb', line 829 def price @price end |
#quantity ⇒ Object
Quantity for this item.
832 833 834 |
# File 'lib/stripe/resources/quote.rb', line 832 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.
835 836 837 |
# File 'lib/stripe/resources/quote.rb', line 835 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
838 839 840 |
# File 'lib/stripe/resources/quote.rb', line 838 def trial @trial end |