Class: Stripe::Quote::CreateParams::Line::Action::AddItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



664
665
666
667
668
# File 'lib/stripe/resources/quote.rb', line 664

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



658
659
660
# File 'lib/stripe/resources/quote.rb', line 658

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



660
661
662
# File 'lib/stripe/resources/quote.rb', line 660

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



662
663
664
# File 'lib/stripe/resources/quote.rb', line 662

def type
  @type
end