Class: Stripe::Quote::CreateParams::Line::Action::AddItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



784
785
786
787
788
# File 'lib/stripe/resources/quote.rb', line 784

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



776
777
778
# File 'lib/stripe/resources/quote.rb', line 776

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



779
780
781
# File 'lib/stripe/resources/quote.rb', line 779

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



782
783
784
# File 'lib/stripe/resources/quote.rb', line 782

def type
  @type
end