Class: Stripe::Quote::CreateParams::Line::Action::RemoveDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ RemoveDiscount

Returns a new instance of RemoveDiscount.



730
731
732
733
734
# File 'lib/stripe/resources/quote.rb', line 730

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



724
725
726
# File 'lib/stripe/resources/quote.rb', line 724

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



726
727
728
# File 'lib/stripe/resources/quote.rb', line 726

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



728
729
730
# File 'lib/stripe/resources/quote.rb', line 728

def promotion_code
  @promotion_code
end