Class: Stripe::Quote::CreateParams::Line::Action::RemoveDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ RemoveDiscount

Returns a new instance of RemoveDiscount.



867
868
869
870
871
# File 'lib/stripe/resources/quote.rb', line 867

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



859
860
861
# File 'lib/stripe/resources/quote.rb', line 859

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



862
863
864
# File 'lib/stripe/resources/quote.rb', line 862

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



865
866
867
# File 'lib/stripe/resources/quote.rb', line 865

def promotion_code
  @promotion_code
end