Class: Stripe::Quote::CreateParams::Line::Action::SetDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount

Returns a new instance of SetDiscount.



767
768
769
770
771
# File 'lib/stripe/resources/quote.rb', line 767

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



761
762
763
# File 'lib/stripe/resources/quote.rb', line 761

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



763
764
765
# File 'lib/stripe/resources/quote.rb', line 763

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



765
766
767
# File 'lib/stripe/resources/quote.rb', line 765

def promotion_code
  @promotion_code
end