Class: Stripe::Quote::CreateParams::Line::Action::SetDiscount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::CreateParams::Line::Action::SetDiscount
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
-
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
-
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount
constructor
A new instance of SetDiscount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount
Returns a new instance of SetDiscount.
760 761 762 763 764 |
# File 'lib/stripe/resources/quote.rb', line 760 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
754 755 756 |
# File 'lib/stripe/resources/quote.rb', line 754 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
756 757 758 |
# File 'lib/stripe/resources/quote.rb', line 756 def discount @discount end |
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
758 759 760 |
# File 'lib/stripe/resources/quote.rb', line 758 def promotion_code @promotion_code end |