Class: Stripe::Quote::CreateParams::Line::Action::SetDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount

Returns a new instance of SetDiscount.



754
755
756
757
758
# File 'lib/stripe/resources/quote.rb', line 754

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



748
749
750
# File 'lib/stripe/resources/quote.rb', line 748

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



750
751
752
# File 'lib/stripe/resources/quote.rb', line 750

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



752
753
754
# File 'lib/stripe/resources/quote.rb', line 752

def promotion_code
  @promotion_code
end