Class: Stripe::Quote::CreateParams::Line::Action::SetDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount

Returns a new instance of SetDiscount.



893
894
895
896
897
# File 'lib/stripe/resources/quote.rb', line 893

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



885
886
887
# File 'lib/stripe/resources/quote.rb', line 885

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



888
889
890
# File 'lib/stripe/resources/quote.rb', line 888

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



891
892
893
# File 'lib/stripe/resources/quote.rb', line 891

def promotion_code
  @promotion_code
end