Class: Stripe::Quote::CreateParams::Line::Action::SetItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::CreateParams::Line::Action::SetItem
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
If an item with the ‘price` already exists, passing this will override the `discounts` array on the subscription item that matches that price.
-
#metadata ⇒ Object
If an item with the ‘price` already exists, passing this will override the `metadata` on the subscription item that matches that price.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
If an item with the ‘price` already exists, passing this will override the quantity on the subscription item that matches that price.
-
#tax_rates ⇒ Object
If an item with the ‘price` already exists, passing this will override the `tax_rates` array on the subscription item that matches that price.
-
#trial ⇒ Object
If an item with the ‘price` already exists, passing this will override the `trial` configuration on the subscription item that matches that price.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ SetItem
constructor
A new instance of SetItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ SetItem
Returns a new instance of SetItem.
837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 |
# File 'lib/stripe/resources/quote.rb', line 837 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#discounts ⇒ Object
If an item with the ‘price` already exists, passing this will override the `discounts` array on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `discounts`.
825 826 827 |
# File 'lib/stripe/resources/quote.rb', line 825 def discounts @discounts end |
#metadata ⇒ Object
If an item with the ‘price` already exists, passing this will override the `metadata` on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `metadata`.
827 828 829 |
# File 'lib/stripe/resources/quote.rb', line 827 def @metadata end |
#price ⇒ Object
The ID of the price object.
829 830 831 |
# File 'lib/stripe/resources/quote.rb', line 829 def price @price end |
#quantity ⇒ Object
If an item with the ‘price` already exists, passing this will override the quantity on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `quantity`.
831 832 833 |
# File 'lib/stripe/resources/quote.rb', line 831 def quantity @quantity end |
#tax_rates ⇒ Object
If an item with the ‘price` already exists, passing this will override the `tax_rates` array on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `tax_rates`.
833 834 835 |
# File 'lib/stripe/resources/quote.rb', line 833 def tax_rates @tax_rates end |
#trial ⇒ Object
If an item with the ‘price` already exists, passing this will override the `trial` configuration on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `trial`.
835 836 837 |
# File 'lib/stripe/resources/quote.rb', line 835 def trial @trial end |