Class: Stripe::Quote::CreateParams::Line::Action::SetItem::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::CreateParams::Line::Action::SetItem::Discount
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1222 1223 1224 1225 1226 1227 |
# File 'lib/stripe/resources/quote.rb', line 1222 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1214 1215 1216 |
# File 'lib/stripe/resources/quote.rb', line 1214 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1216 1217 1218 |
# File 'lib/stripe/resources/quote.rb', line 1216 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1218 1219 1220 |
# File 'lib/stripe/resources/quote.rb', line 1218 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1220 1221 1222 |
# File 'lib/stripe/resources/quote.rb', line 1220 def promotion_code @promotion_code end |