Class: Stripe::Quote::CreateParams::Line::EndsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::CreateParams::Line::EndsAt
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: DiscountEnd, Duration
Instance Attribute Summary collapse
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
Select a way to pass in ‘ends_at`.
Instance Method Summary collapse
-
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
constructor
A new instance of EndsAt.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
Returns a new instance of EndsAt.
1119 1120 1121 1122 1123 1124 |
# File 'lib/stripe/resources/quote.rb', line 1119 def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) @discount_end = discount_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
1108 1109 1110 |
# File 'lib/stripe/resources/quote.rb', line 1108 def discount_end @discount_end end |
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
1111 1112 1113 |
# File 'lib/stripe/resources/quote.rb', line 1111 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp.
1114 1115 1116 |
# File 'lib/stripe/resources/quote.rb', line 1114 def @timestamp end |
#type ⇒ Object
Select a way to pass in ‘ends_at`.
1117 1118 1119 |
# File 'lib/stripe/resources/quote.rb', line 1117 def type @type end |