Class: Stripe::Quote::CreateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::CreateParams::LineItem
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to this line item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
The quantity of the line item.
-
#tax_rates ⇒ Object
The tax rates which apply to the line item.
Instance Method Summary collapse
-
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
Returns a new instance of LineItem.
1597 1598 1599 1600 1601 1602 1603 |
# File 'lib/stripe/resources/quote.rb', line 1597 def initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) @discounts = discounts @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to this line item.
1587 1588 1589 |
# File 'lib/stripe/resources/quote.rb', line 1587 def discounts @discounts end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
1589 1590 1591 |
# File 'lib/stripe/resources/quote.rb', line 1589 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
1591 1592 1593 |
# File 'lib/stripe/resources/quote.rb', line 1591 def price_data @price_data end |
#quantity ⇒ Object
The quantity of the line item.
1593 1594 1595 |
# File 'lib/stripe/resources/quote.rb', line 1593 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the quote do not apply to this line item.
1595 1596 1597 |
# File 'lib/stripe/resources/quote.rb', line 1595 def tax_rates @tax_rates end |