Class: Stripe::Quote::CreateParams::LineItem

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



1369
1370
1371
1372
1373
1374
1375
# File 'lib/stripe/resources/quote.rb', line 1369

def initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil)
  @discounts = discounts
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The discounts applied to this line item.



1355
1356
1357
# File 'lib/stripe/resources/quote.rb', line 1355

def discounts
  @discounts
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



1358
1359
1360
# File 'lib/stripe/resources/quote.rb', line 1358

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



1361
1362
1363
# File 'lib/stripe/resources/quote.rb', line 1361

def price_data
  @price_data
end

#quantityObject

The quantity of the line item.



1364
1365
1366
# File 'lib/stripe/resources/quote.rb', line 1364

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the quote do not apply to this line item.



1367
1368
1369
# File 'lib/stripe/resources/quote.rb', line 1367

def tax_rates
  @tax_rates
end