Class: Stripe::Quote::CreateParams::LineItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1125
1126
1127
1128
1129
1130
# File 'lib/stripe/resources/quote.rb', line 1125

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1117
1118
1119
# File 'lib/stripe/resources/quote.rb', line 1117

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1119
1120
1121
# File 'lib/stripe/resources/quote.rb', line 1119

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1121
1122
1123
# File 'lib/stripe/resources/quote.rb', line 1121

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1123
1124
1125
# File 'lib/stripe/resources/quote.rb', line 1123

def promotion_code
  @promotion_code
end