Class: Stripe::Quote::CreateParams::LineItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



346
347
348
349
350
# File 'lib/stripe/resources/quote.rb', line 346

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



340
341
342
# File 'lib/stripe/resources/quote.rb', line 340

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



342
343
344
# File 'lib/stripe/resources/quote.rb', line 342

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



344
345
346
# File 'lib/stripe/resources/quote.rb', line 344

def promotion_code
  @promotion_code
end