Class: Stripe::Quote::CreateParams::LineItem::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::CreateParams::LineItem::Discount
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1112 1113 1114 1115 1116 1117 |
# File 'lib/stripe/resources/quote.rb', line 1112 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1104 1105 1106 |
# File 'lib/stripe/resources/quote.rb', line 1104 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1106 1107 1108 |
# File 'lib/stripe/resources/quote.rb', line 1106 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1108 1109 1110 |
# File 'lib/stripe/resources/quote.rb', line 1108 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1110 1111 1112 |
# File 'lib/stripe/resources/quote.rb', line 1110 def promotion_code @promotion_code end |