Class: Stripe::Quote::CreateParams::LineItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1103
1104
1105
1106
1107
# File 'lib/stripe/resources/quote.rb', line 1103

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1097
1098
1099
# File 'lib/stripe/resources/quote.rb', line 1097

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1099
1100
1101
# File 'lib/stripe/resources/quote.rb', line 1099

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1101
1102
1103
# File 'lib/stripe/resources/quote.rb', line 1101

def type
  @type
end