Class: Stripe::Quote::CreateParams::SubscriptionData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::CreateParams::SubscriptionData
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: BillOnAcceptance, Prebilling
Instance Attribute Summary collapse
-
#bill_on_acceptance ⇒ Object
Describes the period to bill for upon accepting the quote.
-
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions.
-
#billing_cycle_anchor ⇒ Object
When specified as ‘reset`, the subscription will always start a new billing period when the quote is accepted.
-
#billing_mode ⇒ Object
Configure billing_mode to opt in improved credit proration behavior.Once a quote that creates a subscription or subscription schedule is accepted,all future operations on the subscription or subscription schedule will be processed based on this billing_mode.
-
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer.
-
#effective_date ⇒ Object
When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted.
-
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
-
#from_subscription ⇒ Object
The id of a subscription that the quote will update.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that will set metadata on the subscription or subscription schedule when the quote is accepted.
-
#prebilling ⇒ Object
If specified, the invoicing for the given billing cycle iterations will be processed when the quote is accepted.
-
#proration_behavior ⇒ Object
Determines how to handle [prorations](stripe.com/docs/subscriptions/billing-cycle#prorations).
-
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time.
Instance Method Summary collapse
-
#initialize(bill_on_acceptance: nil, billing_behavior: nil, billing_cycle_anchor: nil, billing_mode: nil, description: nil, effective_date: nil, end_behavior: nil, from_subscription: nil, metadata: nil, prebilling: nil, proration_behavior: nil, trial_period_days: nil) ⇒ SubscriptionData
constructor
A new instance of SubscriptionData.
Methods inherited from RequestParams
Constructor Details
#initialize(bill_on_acceptance: nil, billing_behavior: nil, billing_cycle_anchor: nil, billing_mode: nil, description: nil, effective_date: nil, end_behavior: nil, from_subscription: nil, metadata: nil, prebilling: nil, proration_behavior: nil, trial_period_days: nil) ⇒ SubscriptionData
Returns a new instance of SubscriptionData.
1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 |
# File 'lib/stripe/resources/quote.rb', line 1307 def initialize( bill_on_acceptance: nil, billing_behavior: nil, billing_cycle_anchor: nil, billing_mode: nil, description: nil, effective_date: nil, end_behavior: nil, from_subscription: nil, metadata: nil, prebilling: nil, proration_behavior: nil, trial_period_days: nil ) @bill_on_acceptance = bill_on_acceptance @billing_behavior = billing_behavior @billing_cycle_anchor = billing_cycle_anchor @billing_mode = billing_mode @description = description @effective_date = effective_date @end_behavior = end_behavior @from_subscription = from_subscription @metadata = @prebilling = prebilling @proration_behavior = proration_behavior @trial_period_days = trial_period_days end |
Instance Attribute Details
#bill_on_acceptance ⇒ Object
Describes the period to bill for upon accepting the quote.
1277 1278 1279 |
# File 'lib/stripe/resources/quote.rb', line 1277 def bill_on_acceptance @bill_on_acceptance end |
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.
1279 1280 1281 |
# File 'lib/stripe/resources/quote.rb', line 1279 def billing_behavior @billing_behavior end |
#billing_cycle_anchor ⇒ Object
When specified as ‘reset`, the subscription will always start a new billing period when the quote is accepted.
1281 1282 1283 |
# File 'lib/stripe/resources/quote.rb', line 1281 def billing_cycle_anchor @billing_cycle_anchor end |
#billing_mode ⇒ Object
Configure billing_mode to opt in improved credit proration behavior.Once a quote that creates a subscription or subscription schedule is accepted,all future operations on the subscription or subscription schedule will be processed based on this billing_mode.
1283 1284 1285 |
# File 'lib/stripe/resources/quote.rb', line 1283 def billing_mode @billing_mode end |
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
1285 1286 1287 |
# File 'lib/stripe/resources/quote.rb', line 1285 def description @description end |
#effective_date ⇒ Object
When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted. When updating a subscription, the date of which the subscription will be updated using a subscription schedule. The special value ‘current_period_end` can be provided to update a subscription at the end of its current period. The `effective_date` is ignored if it is in the past when the quote is accepted.
1287 1288 1289 |
# File 'lib/stripe/resources/quote.rb', line 1287 def effective_date @effective_date end |
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
1289 1290 1291 |
# File 'lib/stripe/resources/quote.rb', line 1289 def end_behavior @end_behavior end |
#from_subscription ⇒ Object
The id of a subscription that the quote will update. By default, the quote will contain the state of the subscription (such as line items, collection method and billing thresholds) unless overridden.
1291 1292 1293 |
# File 'lib/stripe/resources/quote.rb', line 1291 def from_subscription @from_subscription end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that will set metadata on the subscription or subscription schedule when the quote is accepted. If a recurring price is included in ‘line_items`, this field will be passed to the resulting subscription’s ‘metadata` field. If `subscription_data.effective_date` is used, this field will be passed to the resulting subscription schedule’s ‘phases.metadata` field. Unlike object-level metadata, this field is declarative. Updates will clear prior values.
1293 1294 1295 |
# File 'lib/stripe/resources/quote.rb', line 1293 def @metadata end |
#prebilling ⇒ Object
If specified, the invoicing for the given billing cycle iterations will be processed when the quote is accepted. Cannot be used with ‘effective_date`.
1295 1296 1297 |
# File 'lib/stripe/resources/quote.rb', line 1295 def prebilling @prebilling end |
#proration_behavior ⇒ Object
Determines how to handle [prorations](stripe.com/docs/subscriptions/billing-cycle#prorations). When creating a subscription, valid values are ‘create_prorations` or `none`.
When updating a subscription, valid values are ‘create_prorations`, `none`, or `always_invoice`.
Passing ‘create_prorations` will cause proration invoice items to be created when applicable. These proration items will only be invoiced immediately under [certain conditions](stripe.com/docs/subscriptions/upgrading-downgrading#immediate-payment). In order to always invoice immediately for prorations, pass `always_invoice`.
Prorations can be disabled by passing ‘none`.
1303 1304 1305 |
# File 'lib/stripe/resources/quote.rb', line 1303 def proration_behavior @proration_behavior end |
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time.
1305 1306 1307 |
# File 'lib/stripe/resources/quote.rb', line 1305 def trial_period_days @trial_period_days end |