Class: Stripe::Quote::CreateParams::SubscriptionData::BillOnAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::CreateParams::SubscriptionData::BillOnAcceptance
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#bill_from ⇒ Object
The start of the period to bill from when the Quote is accepted.
-
#bill_until ⇒ Object
The end of the period to bill until when the Quote is accepted.
Instance Method Summary collapse
-
#initialize(bill_from: nil, bill_until: nil) ⇒ BillOnAcceptance
constructor
A new instance of BillOnAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(bill_from: nil, bill_until: nil) ⇒ BillOnAcceptance
Returns a new instance of BillOnAcceptance.
1254 1255 1256 1257 |
# File 'lib/stripe/resources/quote.rb', line 1254 def initialize(bill_from: nil, bill_until: nil) @bill_from = bill_from @bill_until = bill_until end |
Instance Attribute Details
#bill_from ⇒ Object
The start of the period to bill from when the Quote is accepted.
1250 1251 1252 |
# File 'lib/stripe/resources/quote.rb', line 1250 def bill_from @bill_from end |
#bill_until ⇒ Object
The end of the period to bill until when the Quote is accepted.
1252 1253 1254 |
# File 'lib/stripe/resources/quote.rb', line 1252 def bill_until @bill_until end |