Class: Stripe::Quote::CreateParams::SubscriptionDataOverride
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::CreateParams::SubscriptionDataOverride
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: AppliesTo, BillOnAcceptance
Instance Attribute Summary collapse
-
#applies_to ⇒ Object
Whether the override applies to an existing Subscription Schedule or a new Subscription Schedule.
-
#bill_on_acceptance ⇒ Object
Describes the period to bill for upon accepting the quote.
-
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions.
-
#customer ⇒ Object
The customer the Subscription Data override applies to.
-
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer.
-
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
-
#proration_behavior ⇒ Object
Determines how to handle [prorations](stripe.com/docs/subscriptions/billing-cycle#prorations).
Instance Method Summary collapse
-
#initialize(applies_to: nil, bill_on_acceptance: nil, billing_behavior: nil, customer: nil, description: nil, end_behavior: nil, proration_behavior: nil) ⇒ SubscriptionDataOverride
constructor
A new instance of SubscriptionDataOverride.
Methods inherited from RequestParams
Constructor Details
#initialize(applies_to: nil, bill_on_acceptance: nil, billing_behavior: nil, customer: nil, description: nil, end_behavior: nil, proration_behavior: nil) ⇒ SubscriptionDataOverride
Returns a new instance of SubscriptionDataOverride.
1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 |
# File 'lib/stripe/resources/quote.rb', line 1444 def initialize( applies_to: nil, bill_on_acceptance: nil, billing_behavior: nil, customer: nil, description: nil, end_behavior: nil, proration_behavior: nil ) @applies_to = applies_to @bill_on_acceptance = bill_on_acceptance @billing_behavior = billing_behavior @customer = customer @description = description @end_behavior = end_behavior @proration_behavior = proration_behavior end |
Instance Attribute Details
#applies_to ⇒ Object
Whether the override applies to an existing Subscription Schedule or a new Subscription Schedule.
1424 1425 1426 |
# File 'lib/stripe/resources/quote.rb', line 1424 def applies_to @applies_to end |
#bill_on_acceptance ⇒ Object
Describes the period to bill for upon accepting the quote.
1426 1427 1428 |
# File 'lib/stripe/resources/quote.rb', line 1426 def bill_on_acceptance @bill_on_acceptance end |
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.
1428 1429 1430 |
# File 'lib/stripe/resources/quote.rb', line 1428 def billing_behavior @billing_behavior end |
#customer ⇒ Object
The customer the Subscription Data override applies to. This is only relevant when ‘applies_to.type=new_reference`.
1430 1431 1432 |
# File 'lib/stripe/resources/quote.rb', line 1430 def customer @customer end |
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
1432 1433 1434 |
# File 'lib/stripe/resources/quote.rb', line 1432 def description @description end |
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
1434 1435 1436 |
# File 'lib/stripe/resources/quote.rb', line 1434 def end_behavior @end_behavior end |
#proration_behavior ⇒ Object
Determines how to handle [prorations](stripe.com/docs/subscriptions/billing-cycle#prorations). When creating a subscription, valid values are ‘create_prorations` or `none`.
When updating a subscription, valid values are ‘create_prorations`, `none`, or `always_invoice`.
Passing ‘create_prorations` will cause proration invoice items to be created when applicable. These proration items will only be invoiced immediately under [certain conditions](stripe.com/docs/subscriptions/upgrading-downgrading#immediate-payment). In order to always invoice immediately for prorations, pass `always_invoice`.
Prorations can be disabled by passing ‘none`.
1442 1443 1444 |
# File 'lib/stripe/resources/quote.rb', line 1442 def proration_behavior @proration_behavior end |