Class: Stripe::Quote::CreateParams::SubscriptionDataOverride::BillOnAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: BillFrom, BillUntil

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bill_from: nil, bill_until: nil) ⇒ BillOnAcceptance

Returns a new instance of BillOnAcceptance.



1418
1419
1420
1421
# File 'lib/stripe/resources/quote.rb', line 1418

def initialize(bill_from: nil, bill_until: nil)
  @bill_from = bill_from
  @bill_until = bill_until
end

Instance Attribute Details

#bill_fromObject

The start of the period to bill from when the Quote is accepted.



1414
1415
1416
# File 'lib/stripe/resources/quote.rb', line 1414

def bill_from
  @bill_from
end

#bill_untilObject

The end of the period to bill until when the Quote is accepted.



1416
1417
1418
# File 'lib/stripe/resources/quote.rb', line 1416

def bill_until
  @bill_until
end