Class: Stripe::Quote::CreateParams::SubscriptionDataOverride::BillOnAcceptance::BillFrom::LineStartsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::CreateParams::SubscriptionDataOverride::BillOnAcceptance::BillFrom::LineStartsAt
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of a quote line.
-
#index ⇒ Object
The position of the previous quote line in the ‘lines` array after which this line should begin.
Instance Method Summary collapse
-
#initialize(id: nil, index: nil) ⇒ LineStartsAt
constructor
A new instance of LineStartsAt.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, index: nil) ⇒ LineStartsAt
Returns a new instance of LineStartsAt.
1567 1568 1569 1570 |
# File 'lib/stripe/resources/quote.rb', line 1567 def initialize(id: nil, index: nil) @id = id @index = index end |
Instance Attribute Details
#id ⇒ Object
The ID of a quote line.
1562 1563 1564 |
# File 'lib/stripe/resources/quote.rb', line 1562 def id @id end |
#index ⇒ Object
The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.
1565 1566 1567 |
# File 'lib/stripe/resources/quote.rb', line 1565 def index @index end |