Class: Stripe::Quote::CreateParams::TransferData

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1471
1472
1473
1474
1475
# File 'lib/stripe/resources/quote.rb', line 1471

def initialize(amount: nil, amount_percent: nil, destination: nil)
  @amount = amount
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



1465
1466
1467
# File 'lib/stripe/resources/quote.rb', line 1465

def amount
  @amount
end

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination. There must be at least 1 line item with a recurring price to use this field.



1467
1468
1469
# File 'lib/stripe/resources/quote.rb', line 1467

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



1469
1470
1471
# File 'lib/stripe/resources/quote.rb', line 1469

def destination
  @destination
end