Class: Stripe::Quote::FinalizeQuoteParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, expires_at: nil) ⇒ FinalizeQuoteParams

Returns a new instance of FinalizeQuoteParams.



3135
3136
3137
3138
# File 'lib/stripe/resources/quote.rb', line 3135

def initialize(expand: nil, expires_at: nil)
  @expand = expand
  @expires_at = expires_at
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



3130
3131
3132
# File 'lib/stripe/resources/quote.rb', line 3130

def expand
  @expand
end

#expires_atObject

A future timestamp on which the quote will be canceled if in ‘open` or `draft` status. Measured in seconds since the Unix epoch.



3133
3134
3135
# File 'lib/stripe/resources/quote.rb', line 3133

def expires_at
  @expires_at
end