Class: Stripe::Quote::FinalizeQuoteParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::FinalizeQuoteParams
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expires_at ⇒ Object
A future timestamp on which the quote will be canceled if in ‘open` or `draft` status.
Instance Method Summary collapse
-
#initialize(expand: nil, expires_at: nil) ⇒ FinalizeQuoteParams
constructor
A new instance of FinalizeQuoteParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, expires_at: nil) ⇒ FinalizeQuoteParams
Returns a new instance of FinalizeQuoteParams.
2720 2721 2722 2723 |
# File 'lib/stripe/resources/quote.rb', line 2720 def initialize(expand: nil, expires_at: nil) @expand = @expires_at = expires_at end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2716 2717 2718 |
# File 'lib/stripe/resources/quote.rb', line 2716 def @expand end |
#expires_at ⇒ Object
A future timestamp on which the quote will be canceled if in ‘open` or `draft` status. Measured in seconds since the Unix epoch.
2718 2719 2720 |
# File 'lib/stripe/resources/quote.rb', line 2718 def expires_at @expires_at end |