Class: Stripe::Quote::InvoiceSettings

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: CustomField, Issuer

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#custom_fieldsObject (readonly)

A list of up to 4 custom fields to be displayed on the invoice.



333
334
335
# File 'lib/stripe/resources/quote.rb', line 333

def custom_fields
  @custom_fields
end

#days_until_dueObject (readonly)

Number of days within which a customer must pay invoices generated by this quote. This value will be null for quotes where collection_method=charge_automatically.



335
336
337
# File 'lib/stripe/resources/quote.rb', line 335

def days_until_due
  @days_until_due
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



337
338
339
# File 'lib/stripe/resources/quote.rb', line 337

def description
  @description
end

Footer to be displayed on the invoice.



339
340
341
# File 'lib/stripe/resources/quote.rb', line 339

def footer
  @footer
end

#issuerObject (readonly)

Attribute for field issuer



341
342
343
# File 'lib/stripe/resources/quote.rb', line 341

def issuer
  @issuer
end

Class Method Details

.field_remappingsObject



347
348
349
# File 'lib/stripe/resources/quote.rb', line 347

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



343
344
345
# File 'lib/stripe/resources/quote.rb', line 343

def self.inner_class_types
  @inner_class_types = { custom_fields: CustomField, issuer: Issuer }
end