Class: Stripe::Quote::InvoiceSettings
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::InvoiceSettings
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: Issuer
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#days_until_due ⇒ Object
readonly
Number of days within which a customer must pay invoices generated by this quote.
-
#issuer ⇒ Object
readonly
Attribute for field issuer.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#days_until_due ⇒ Object (readonly)
Number of days within which a customer must pay invoices generated by this quote. This value will be ‘null` for quotes where `collection_method=charge_automatically`.
153 154 155 |
# File 'lib/stripe/resources/quote.rb', line 153 def days_until_due @days_until_due end |
#issuer ⇒ Object (readonly)
Attribute for field issuer
155 156 157 |
# File 'lib/stripe/resources/quote.rb', line 155 def issuer @issuer end |