Class: Stripe::Quote::ListComputedUpfrontLineItemsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListComputedUpfrontLineItemsParams

Returns a new instance of ListComputedUpfrontLineItemsParams.



2677
2678
2679
2680
2681
2682
# File 'lib/stripe/resources/quote.rb', line 2677

def initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil)
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



2669
2670
2671
# File 'lib/stripe/resources/quote.rb', line 2669

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



2671
2672
2673
# File 'lib/stripe/resources/quote.rb', line 2671

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



2673
2674
2675
# File 'lib/stripe/resources/quote.rb', line 2673

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



2675
2676
2677
# File 'lib/stripe/resources/quote.rb', line 2675

def starting_after
  @starting_after
end