Class: Stripe::Quote::ListLinesParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::ListLinesParams
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListLinesParams
constructor
A new instance of ListLinesParams.
Methods inherited from RequestParams
Constructor Details
#initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListLinesParams
Returns a new instance of ListLinesParams.
2688 2689 2690 2691 2692 2693 |
# File 'lib/stripe/resources/quote.rb', line 2688 def initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil) @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
2680 2681 2682 |
# File 'lib/stripe/resources/quote.rb', line 2680 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2682 2683 2684 |
# File 'lib/stripe/resources/quote.rb', line 2682 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
2684 2685 2686 |
# File 'lib/stripe/resources/quote.rb', line 2684 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
2686 2687 2688 |
# File 'lib/stripe/resources/quote.rb', line 2686 def starting_after @starting_after end |