Class: Stripe::Quote::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::ListParams
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of the customer whose quotes will be retrieved.
-
#customer_account ⇒ Object
The ID of the account whose quotes will be retrieved.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#from_subscription ⇒ Object
The subscription which the quote updates.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
The status of the quote.
-
#test_clock ⇒ Object
Provides a list of quotes that are associated with the specified test clock.
Instance Method Summary collapse
-
#initialize(customer: nil, customer_account: nil, ending_before: nil, expand: nil, from_subscription: nil, limit: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, customer_account: nil, ending_before: nil, expand: nil, from_subscription: nil, limit: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams
Returns a new instance of ListParams.
900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 |
# File 'lib/stripe/resources/quote.rb', line 900 def initialize( customer: nil, customer_account: nil, ending_before: nil, expand: nil, from_subscription: nil, limit: nil, starting_after: nil, status: nil, test_clock: nil ) @customer = customer @customer_account = customer_account @ending_before = ending_before @expand = @from_subscription = from_subscription @limit = limit @starting_after = starting_after @status = status @test_clock = test_clock end |
Instance Attribute Details
#customer ⇒ Object
The ID of the customer whose quotes will be retrieved.
882 883 884 |
# File 'lib/stripe/resources/quote.rb', line 882 def customer @customer end |
#customer_account ⇒ Object
The ID of the account whose quotes will be retrieved.
884 885 886 |
# File 'lib/stripe/resources/quote.rb', line 884 def customer_account @customer_account end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
886 887 888 |
# File 'lib/stripe/resources/quote.rb', line 886 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
888 889 890 |
# File 'lib/stripe/resources/quote.rb', line 888 def @expand end |
#from_subscription ⇒ Object
The subscription which the quote updates.
890 891 892 |
# File 'lib/stripe/resources/quote.rb', line 890 def from_subscription @from_subscription end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
892 893 894 |
# File 'lib/stripe/resources/quote.rb', line 892 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
894 895 896 |
# File 'lib/stripe/resources/quote.rb', line 894 def starting_after @starting_after end |
#status ⇒ Object
The status of the quote.
896 897 898 |
# File 'lib/stripe/resources/quote.rb', line 896 def status @status end |
#test_clock ⇒ Object
Provides a list of quotes that are associated with the specified test clock. The response will not include quotes with test clocks if this and the customer parameter is not set.
898 899 900 |
# File 'lib/stripe/resources/quote.rb', line 898 def test_clock @test_clock end |