Class: Stripe::Quote::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams

Returns a new instance of ListParams.



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/stripe/resources/quote.rb', line 250

def initialize(
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  status: nil,
  test_clock: nil
)
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @status = status
  @test_clock = test_clock
end

Instance Attribute Details

#customerObject

The ID of the customer whose quotes will be retrieved.



236
237
238
# File 'lib/stripe/resources/quote.rb', line 236

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



238
239
240
# File 'lib/stripe/resources/quote.rb', line 238

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



240
241
242
# File 'lib/stripe/resources/quote.rb', line 240

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



242
243
244
# File 'lib/stripe/resources/quote.rb', line 242

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



244
245
246
# File 'lib/stripe/resources/quote.rb', line 244

def starting_after
  @starting_after
end

#statusObject

The status of the quote.



246
247
248
# File 'lib/stripe/resources/quote.rb', line 246

def status
  @status
end

#test_clockObject

Provides a list of quotes that are associated with the specified test clock. The response will not include quotes with test clocks if this and the customer parameter is not set.



248
249
250
# File 'lib/stripe/resources/quote.rb', line 248

def test_clock
  @test_clock
end