Class: Stripe::Quote::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::ListParams
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of the customer whose quotes will be retrieved.
-
#customer_account ⇒ Object
The ID of the account whose quotes will be retrieved.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#from_subscription ⇒ Object
The subscription which the quote updates.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
The status of the quote.
-
#test_clock ⇒ Object
Provides a list of quotes that are associated with the specified test clock.
Instance Method Summary collapse
-
#initialize(customer: nil, customer_account: nil, ending_before: nil, expand: nil, from_subscription: nil, limit: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, customer_account: nil, ending_before: nil, expand: nil, from_subscription: nil, limit: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams
Returns a new instance of ListParams.
483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 |
# File 'lib/stripe/resources/quote.rb', line 483 def initialize( customer: nil, customer_account: nil, ending_before: nil, expand: nil, from_subscription: nil, limit: nil, starting_after: nil, status: nil, test_clock: nil ) @customer = customer @customer_account = customer_account @ending_before = ending_before @expand = @from_subscription = from_subscription @limit = limit @starting_after = starting_after @status = status @test_clock = test_clock end |
Instance Attribute Details
#customer ⇒ Object
The ID of the customer whose quotes will be retrieved.
465 466 467 |
# File 'lib/stripe/resources/quote.rb', line 465 def customer @customer end |
#customer_account ⇒ Object
The ID of the account whose quotes will be retrieved.
467 468 469 |
# File 'lib/stripe/resources/quote.rb', line 467 def customer_account @customer_account end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
469 470 471 |
# File 'lib/stripe/resources/quote.rb', line 469 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
471 472 473 |
# File 'lib/stripe/resources/quote.rb', line 471 def @expand end |
#from_subscription ⇒ Object
The subscription which the quote updates.
473 474 475 |
# File 'lib/stripe/resources/quote.rb', line 473 def from_subscription @from_subscription end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
475 476 477 |
# File 'lib/stripe/resources/quote.rb', line 475 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
477 478 479 |
# File 'lib/stripe/resources/quote.rb', line 477 def starting_after @starting_after end |
#status ⇒ Object
The status of the quote.
479 480 481 |
# File 'lib/stripe/resources/quote.rb', line 479 def status @status end |
#test_clock ⇒ Object
Provides a list of quotes that are associated with the specified test clock. The response will not include quotes with test clocks if this and the customer parameter is not set.
481 482 483 |
# File 'lib/stripe/resources/quote.rb', line 481 def test_clock @test_clock end |