Class: Stripe::Quote::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, customer_account: nil, ending_before: nil, expand: nil, from_subscription: nil, limit: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams

Returns a new instance of ListParams.



481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/stripe/resources/quote.rb', line 481

def initialize(
  customer: nil,
  customer_account: nil,
  ending_before: nil,
  expand: nil,
  from_subscription: nil,
  limit: nil,
  starting_after: nil,
  status: nil,
  test_clock: nil
)
  @customer = customer
  @customer_account = 
  @ending_before = ending_before
  @expand = expand
  @from_subscription = from_subscription
  @limit = limit
  @starting_after = starting_after
  @status = status
  @test_clock = test_clock
end

Instance Attribute Details

#customerObject

The ID of the customer whose quotes will be retrieved.



463
464
465
# File 'lib/stripe/resources/quote.rb', line 463

def customer
  @customer
end

#customer_accountObject

The ID of the account whose quotes will be retrieved.



465
466
467
# File 'lib/stripe/resources/quote.rb', line 465

def 
  @customer_account
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



467
468
469
# File 'lib/stripe/resources/quote.rb', line 467

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



469
470
471
# File 'lib/stripe/resources/quote.rb', line 469

def expand
  @expand
end

#from_subscriptionObject

The subscription which the quote updates.



471
472
473
# File 'lib/stripe/resources/quote.rb', line 471

def from_subscription
  @from_subscription
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



473
474
475
# File 'lib/stripe/resources/quote.rb', line 473

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



475
476
477
# File 'lib/stripe/resources/quote.rb', line 475

def starting_after
  @starting_after
end

#statusObject

The status of the quote.



477
478
479
# File 'lib/stripe/resources/quote.rb', line 477

def status
  @status
end

#test_clockObject

Provides a list of quotes that are associated with the specified test clock. The response will not include quotes with test clocks if this and the customer parameter is not set.



479
480
481
# File 'lib/stripe/resources/quote.rb', line 479

def test_clock
  @test_clock
end