Class: Stripe::Quote::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::ListParams
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of the customer whose quotes will be retrieved.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
The status of the quote.
-
#test_clock ⇒ Object
Provides a list of quotes that are associated with the specified test clock.
Instance Method Summary collapse
-
#initialize(customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams
Returns a new instance of ListParams.
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/stripe/resources/quote.rb', line 242 def initialize( customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, test_clock: nil ) @customer = customer @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after @status = status @test_clock = test_clock end |
Instance Attribute Details
#customer ⇒ Object
The ID of the customer whose quotes will be retrieved.
228 229 230 |
# File 'lib/stripe/resources/quote.rb', line 228 def customer @customer end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
230 231 232 |
# File 'lib/stripe/resources/quote.rb', line 230 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
232 233 234 |
# File 'lib/stripe/resources/quote.rb', line 232 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
234 235 236 |
# File 'lib/stripe/resources/quote.rb', line 234 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
236 237 238 |
# File 'lib/stripe/resources/quote.rb', line 236 def starting_after @starting_after end |
#status ⇒ Object
The status of the quote.
238 239 240 |
# File 'lib/stripe/resources/quote.rb', line 238 def status @status end |
#test_clock ⇒ Object
Provides a list of quotes that are associated with the specified test clock. The response will not include quotes with test clocks if this and the customer parameter is not set.
240 241 242 |
# File 'lib/stripe/resources/quote.rb', line 240 def test_clock @test_clock end |