Class: Stripe::Quote::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, ending_before: nil, expand: nil, from_subscription: nil, limit: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams

Returns a new instance of ListParams.



585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
# File 'lib/stripe/resources/quote.rb', line 585

def initialize(
  customer: nil,
  ending_before: nil,
  expand: nil,
  from_subscription: nil,
  limit: nil,
  starting_after: nil,
  status: nil,
  test_clock: nil
)
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @from_subscription = from_subscription
  @limit = limit
  @starting_after = starting_after
  @status = status
  @test_clock = test_clock
end

Instance Attribute Details

#customerObject

The ID of the customer whose quotes will be retrieved.



562
563
564
# File 'lib/stripe/resources/quote.rb', line 562

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



565
566
567
# File 'lib/stripe/resources/quote.rb', line 565

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



568
569
570
# File 'lib/stripe/resources/quote.rb', line 568

def expand
  @expand
end

#from_subscriptionObject

The subscription which the quote updates.



571
572
573
# File 'lib/stripe/resources/quote.rb', line 571

def from_subscription
  @from_subscription
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



574
575
576
# File 'lib/stripe/resources/quote.rb', line 574

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



577
578
579
# File 'lib/stripe/resources/quote.rb', line 577

def starting_after
  @starting_after
end

#statusObject

The status of the quote.



580
581
582
# File 'lib/stripe/resources/quote.rb', line 580

def status
  @status
end

#test_clockObject

Provides a list of quotes that are associated with the specified test clock. The response will not include quotes with test clocks if this and the customer parameter is not set.



583
584
585
# File 'lib/stripe/resources/quote.rb', line 583

def test_clock
  @test_clock
end