Class: Stripe::Quote::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::ListParams
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of the customer whose quotes will be retrieved.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#from_subscription ⇒ Object
The subscription which the quote updates.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
The status of the quote.
-
#test_clock ⇒ Object
Provides a list of quotes that are associated with the specified test clock.
Instance Method Summary collapse
-
#initialize(customer: nil, ending_before: nil, expand: nil, from_subscription: nil, limit: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, ending_before: nil, expand: nil, from_subscription: nil, limit: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams
Returns a new instance of ListParams.
477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 |
# File 'lib/stripe/resources/quote.rb', line 477 def initialize( customer: nil, ending_before: nil, expand: nil, from_subscription: nil, limit: nil, starting_after: nil, status: nil, test_clock: nil ) @customer = customer @ending_before = ending_before @expand = @from_subscription = from_subscription @limit = limit @starting_after = starting_after @status = status @test_clock = test_clock end |
Instance Attribute Details
#customer ⇒ Object
The ID of the customer whose quotes will be retrieved.
461 462 463 |
# File 'lib/stripe/resources/quote.rb', line 461 def customer @customer end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
463 464 465 |
# File 'lib/stripe/resources/quote.rb', line 463 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
465 466 467 |
# File 'lib/stripe/resources/quote.rb', line 465 def @expand end |
#from_subscription ⇒ Object
The subscription which the quote updates.
467 468 469 |
# File 'lib/stripe/resources/quote.rb', line 467 def from_subscription @from_subscription end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
469 470 471 |
# File 'lib/stripe/resources/quote.rb', line 469 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
471 472 473 |
# File 'lib/stripe/resources/quote.rb', line 471 def starting_after @starting_after end |
#status ⇒ Object
The status of the quote.
473 474 475 |
# File 'lib/stripe/resources/quote.rb', line 473 def status @status end |
#test_clock ⇒ Object
Provides a list of quotes that are associated with the specified test clock. The response will not include quotes with test clocks if this and the customer parameter is not set.
475 476 477 |
# File 'lib/stripe/resources/quote.rb', line 475 def test_clock @test_clock end |