Class: Stripe::Quote::MarkDraftParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::MarkDraftParams
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ MarkDraftParams
constructor
A new instance of MarkDraftParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ MarkDraftParams
Returns a new instance of MarkDraftParams.
2741 2742 2743 |
# File 'lib/stripe/resources/quote.rb', line 2741 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2739 2740 2741 |
# File 'lib/stripe/resources/quote.rb', line 2739 def @expand end |