Class: Stripe::Quote::MarkDraftParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::MarkDraftParams
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ MarkDraftParams
constructor
A new instance of MarkDraftParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ MarkDraftParams
Returns a new instance of MarkDraftParams.
2730 2731 2732 |
# File 'lib/stripe/resources/quote.rb', line 2730 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2728 2729 2730 |
# File 'lib/stripe/resources/quote.rb', line 2728 def @expand end |