Class: Stripe::Quote::MarkStaleParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::MarkStaleParams
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#reason ⇒ Object
Reason the Quote is being marked stale.
Instance Method Summary collapse
-
#initialize(expand: nil, reason: nil) ⇒ MarkStaleParams
constructor
A new instance of MarkStaleParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, reason: nil) ⇒ MarkStaleParams
Returns a new instance of MarkStaleParams.
2766 2767 2768 2769 |
# File 'lib/stripe/resources/quote.rb', line 2766 def initialize(expand: nil, reason: nil) @expand = @reason = reason end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2762 2763 2764 |
# File 'lib/stripe/resources/quote.rb', line 2762 def @expand end |
#reason ⇒ Object
Reason the Quote is being marked stale.
2764 2765 2766 |
# File 'lib/stripe/resources/quote.rb', line 2764 def reason @reason end |