Class: Stripe::Quote::MarkStaleParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::MarkStaleParams
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#reason ⇒ Object
Reason the Quote is being marked stale.
Instance Method Summary collapse
-
#initialize(expand: nil, reason: nil) ⇒ MarkStaleParams
constructor
A new instance of MarkStaleParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, reason: nil) ⇒ MarkStaleParams
Returns a new instance of MarkStaleParams.
2746 2747 2748 2749 |
# File 'lib/stripe/resources/quote.rb', line 2746 def initialize(expand: nil, reason: nil) @expand = @reason = reason end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2742 2743 2744 |
# File 'lib/stripe/resources/quote.rb', line 2742 def @expand end |
#reason ⇒ Object
Reason the Quote is being marked stale.
2744 2745 2746 |
# File 'lib/stripe/resources/quote.rb', line 2744 def reason @reason end |