Class: Stripe::Quote::MarkStaleParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::MarkStaleParams
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#reason ⇒ Object
Reason the Quote is being marked stale.
Instance Method Summary collapse
-
#initialize(expand: nil, reason: nil) ⇒ MarkStaleParams
constructor
A new instance of MarkStaleParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, reason: nil) ⇒ MarkStaleParams
Returns a new instance of MarkStaleParams.
2741 2742 2743 2744 |
# File 'lib/stripe/resources/quote.rb', line 2741 def initialize(expand: nil, reason: nil) @expand = @reason = reason end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2737 2738 2739 |
# File 'lib/stripe/resources/quote.rb', line 2737 def @expand end |
#reason ⇒ Object
Reason the Quote is being marked stale.
2739 2740 2741 |
# File 'lib/stripe/resources/quote.rb', line 2739 def reason @reason end |