Class: Stripe::Quote::StatusDetails::Stale
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::StatusDetails::Stale
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: LastReason
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#expires_at ⇒ Object
readonly
Time at which the quote expires.
-
#last_reason ⇒ Object
readonly
The most recent reason this quote was marked as stale.
-
#last_updated_at ⇒ Object
readonly
Time at which the stale reason was updated.
-
#transitioned_at ⇒ Object
readonly
Time at which the quote was marked as stale.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#expires_at ⇒ Object (readonly)
Time at which the quote expires. Measured in seconds since the Unix epoch.
423 424 425 |
# File 'lib/stripe/resources/quote.rb', line 423 def expires_at @expires_at end |
#last_reason ⇒ Object (readonly)
The most recent reason this quote was marked as stale.
425 426 427 |
# File 'lib/stripe/resources/quote.rb', line 425 def last_reason @last_reason end |
#last_updated_at ⇒ Object (readonly)
Time at which the stale reason was updated. Measured in seconds since the Unix epoch.
427 428 429 |
# File 'lib/stripe/resources/quote.rb', line 427 def last_updated_at @last_updated_at end |
#transitioned_at ⇒ Object (readonly)
Time at which the quote was marked as stale. Measured in seconds since the Unix epoch.
429 430 431 |
# File 'lib/stripe/resources/quote.rb', line 429 def transitioned_at @transitioned_at end |
Class Method Details
.field_remappings ⇒ Object
435 436 437 |
# File 'lib/stripe/resources/quote.rb', line 435 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
431 432 433 |
# File 'lib/stripe/resources/quote.rb', line 431 def self.inner_class_types @inner_class_types = { last_reason: LastReason } end |