Class: Stripe::Quote::StatusDetails::Stale::LastReason
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::StatusDetails::Stale::LastReason
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: LinesInvalid, SubscriptionChanged, SubscriptionScheduleChanged
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#line_invalid ⇒ Object
readonly
The ID of the line that is invalid if the stale reason type is
line_invalid. -
#lines_invalid ⇒ Object
readonly
The IDs of the lines that are invalid if the stale reason type is
lines_invalid. -
#marked_stale ⇒ Object
readonly
The user supplied mark stale reason.
-
#subscription_canceled ⇒ Object
readonly
The ID of the subscription that was canceled.
-
#subscription_changed ⇒ Object
readonly
Attribute for field subscription_changed.
-
#subscription_expired ⇒ Object
readonly
The ID of the subscription that was expired.
-
#subscription_schedule_canceled ⇒ Object
readonly
The ID of the subscription schedule that was canceled.
-
#subscription_schedule_changed ⇒ Object
readonly
Attribute for field subscription_schedule_changed.
-
#subscription_schedule_released ⇒ Object
readonly
The ID of the subscription schedule that was released.
-
#type ⇒ Object
readonly
The reason the quote was marked as stale.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#line_invalid ⇒ Object (readonly)
The ID of the line that is invalid if the stale reason type is line_invalid.
411 412 413 |
# File 'lib/stripe/resources/quote.rb', line 411 def line_invalid @line_invalid end |
#lines_invalid ⇒ Object (readonly)
The IDs of the lines that are invalid if the stale reason type is lines_invalid.
413 414 415 |
# File 'lib/stripe/resources/quote.rb', line 413 def lines_invalid @lines_invalid end |
#marked_stale ⇒ Object (readonly)
The user supplied mark stale reason.
415 416 417 |
# File 'lib/stripe/resources/quote.rb', line 415 def marked_stale @marked_stale end |
#subscription_canceled ⇒ Object (readonly)
The ID of the subscription that was canceled.
417 418 419 |
# File 'lib/stripe/resources/quote.rb', line 417 def subscription_canceled @subscription_canceled end |
#subscription_changed ⇒ Object (readonly)
Attribute for field subscription_changed
419 420 421 |
# File 'lib/stripe/resources/quote.rb', line 419 def subscription_changed @subscription_changed end |
#subscription_expired ⇒ Object (readonly)
The ID of the subscription that was expired.
421 422 423 |
# File 'lib/stripe/resources/quote.rb', line 421 def subscription_expired @subscription_expired end |
#subscription_schedule_canceled ⇒ Object (readonly)
The ID of the subscription schedule that was canceled.
423 424 425 |
# File 'lib/stripe/resources/quote.rb', line 423 def subscription_schedule_canceled @subscription_schedule_canceled end |
#subscription_schedule_changed ⇒ Object (readonly)
Attribute for field subscription_schedule_changed
425 426 427 |
# File 'lib/stripe/resources/quote.rb', line 425 def subscription_schedule_changed @subscription_schedule_changed end |
#subscription_schedule_released ⇒ Object (readonly)
The ID of the subscription schedule that was released.
427 428 429 |
# File 'lib/stripe/resources/quote.rb', line 427 def subscription_schedule_released @subscription_schedule_released end |
#type ⇒ Object (readonly)
The reason the quote was marked as stale.
429 430 431 |
# File 'lib/stripe/resources/quote.rb', line 429 def type @type end |
Class Method Details
.field_remappings ⇒ Object
439 440 441 |
# File 'lib/stripe/resources/quote.rb', line 439 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
431 432 433 434 435 436 437 |
# File 'lib/stripe/resources/quote.rb', line 431 def self.inner_class_types @inner_class_types = { lines_invalid: LinesInvalid, subscription_changed: SubscriptionChanged, subscription_schedule_changed: SubscriptionScheduleChanged, } end |