Class: Stripe::Quote::StatusDetails::Stale::LastReason

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: LinesInvalid, SubscriptionChanged, SubscriptionScheduleChanged

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#line_invalidObject (readonly)

The ID of the line that is invalid if the stale reason type is ‘line_invalid`.



390
391
392
# File 'lib/stripe/resources/quote.rb', line 390

def line_invalid
  @line_invalid
end

#lines_invalidObject (readonly)

The IDs of the lines that are invalid if the stale reason type is ‘lines_invalid`.



392
393
394
# File 'lib/stripe/resources/quote.rb', line 392

def lines_invalid
  @lines_invalid
end

#marked_staleObject (readonly)

The user supplied mark stale reason.



394
395
396
# File 'lib/stripe/resources/quote.rb', line 394

def marked_stale
  @marked_stale
end

#subscription_canceledObject (readonly)

The ID of the subscription that was canceled.



396
397
398
# File 'lib/stripe/resources/quote.rb', line 396

def subscription_canceled
  @subscription_canceled
end

#subscription_changedObject (readonly)

Attribute for field subscription_changed



398
399
400
# File 'lib/stripe/resources/quote.rb', line 398

def subscription_changed
  @subscription_changed
end

#subscription_expiredObject (readonly)

The ID of the subscription that was expired.



400
401
402
# File 'lib/stripe/resources/quote.rb', line 400

def subscription_expired
  @subscription_expired
end

#subscription_schedule_canceledObject (readonly)

The ID of the subscription schedule that was canceled.



402
403
404
# File 'lib/stripe/resources/quote.rb', line 402

def subscription_schedule_canceled
  @subscription_schedule_canceled
end

#subscription_schedule_changedObject (readonly)

Attribute for field subscription_schedule_changed



404
405
406
# File 'lib/stripe/resources/quote.rb', line 404

def subscription_schedule_changed
  @subscription_schedule_changed
end

#subscription_schedule_releasedObject (readonly)

The ID of the subscription schedule that was released.



406
407
408
# File 'lib/stripe/resources/quote.rb', line 406

def subscription_schedule_released
  @subscription_schedule_released
end

#typeObject (readonly)

The reason the quote was marked as stale.



408
409
410
# File 'lib/stripe/resources/quote.rb', line 408

def type
  @type
end

Class Method Details

.field_remappingsObject



418
419
420
# File 'lib/stripe/resources/quote.rb', line 418

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



410
411
412
413
414
415
416
# File 'lib/stripe/resources/quote.rb', line 410

def self.inner_class_types
  @inner_class_types = {
    lines_invalid: LinesInvalid,
    subscription_changed: SubscriptionChanged,
    subscription_schedule_changed: SubscriptionScheduleChanged,
  }
end