Class: Stripe::Quote::StatusDetails::Stale::LastReason

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: LinesInvalid, SubscriptionChanged, SubscriptionScheduleChanged

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#line_invalidObject (readonly)

The ID of the line that is invalid if the stale reason type is ‘line_invalid`.



210
211
212
# File 'lib/stripe/resources/quote.rb', line 210

def line_invalid
  @line_invalid
end

#lines_invalidObject (readonly)

The IDs of the lines that are invalid if the stale reason type is ‘lines_invalid`.



212
213
214
# File 'lib/stripe/resources/quote.rb', line 212

def lines_invalid
  @lines_invalid
end

#marked_staleObject (readonly)

The user supplied mark stale reason.



214
215
216
# File 'lib/stripe/resources/quote.rb', line 214

def marked_stale
  @marked_stale
end

#subscription_canceledObject (readonly)

The ID of the subscription that was canceled.



216
217
218
# File 'lib/stripe/resources/quote.rb', line 216

def subscription_canceled
  @subscription_canceled
end

#subscription_changedObject (readonly)

Attribute for field subscription_changed



218
219
220
# File 'lib/stripe/resources/quote.rb', line 218

def subscription_changed
  @subscription_changed
end

#subscription_expiredObject (readonly)

The ID of the subscription that was expired.



220
221
222
# File 'lib/stripe/resources/quote.rb', line 220

def subscription_expired
  @subscription_expired
end

#subscription_schedule_canceledObject (readonly)

The ID of the subscription schedule that was canceled.



222
223
224
# File 'lib/stripe/resources/quote.rb', line 222

def subscription_schedule_canceled
  @subscription_schedule_canceled
end

#subscription_schedule_changedObject (readonly)

Attribute for field subscription_schedule_changed



224
225
226
# File 'lib/stripe/resources/quote.rb', line 224

def subscription_schedule_changed
  @subscription_schedule_changed
end

#subscription_schedule_releasedObject (readonly)

The ID of the subscription schedule that was released.



226
227
228
# File 'lib/stripe/resources/quote.rb', line 226

def subscription_schedule_released
  @subscription_schedule_released
end

#typeObject (readonly)

The reason the quote was marked as stale.



228
229
230
# File 'lib/stripe/resources/quote.rb', line 228

def type
  @type
end