Class: Stripe::Quote::StatusDetails::Stale::LastReason
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::StatusDetails::Stale::LastReason
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: LinesInvalid, SubscriptionChanged, SubscriptionScheduleChanged
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#line_invalid ⇒ Object
readonly
The ID of the line that is invalid if the stale reason type is ‘line_invalid`.
-
#lines_invalid ⇒ Object
readonly
The IDs of the lines that are invalid if the stale reason type is ‘lines_invalid`.
-
#marked_stale ⇒ Object
readonly
The user supplied mark stale reason.
-
#subscription_canceled ⇒ Object
readonly
The ID of the subscription that was canceled.
-
#subscription_changed ⇒ Object
readonly
Attribute for field subscription_changed.
-
#subscription_expired ⇒ Object
readonly
The ID of the subscription that was expired.
-
#subscription_schedule_canceled ⇒ Object
readonly
The ID of the subscription schedule that was canceled.
-
#subscription_schedule_changed ⇒ Object
readonly
Attribute for field subscription_schedule_changed.
-
#subscription_schedule_released ⇒ Object
readonly
The ID of the subscription schedule that was released.
-
#type ⇒ Object
readonly
The reason the quote was marked as stale.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#line_invalid ⇒ Object (readonly)
The ID of the line that is invalid if the stale reason type is ‘line_invalid`.
245 246 247 |
# File 'lib/stripe/resources/quote.rb', line 245 def line_invalid @line_invalid end |
#lines_invalid ⇒ Object (readonly)
The IDs of the lines that are invalid if the stale reason type is ‘lines_invalid`.
248 249 250 |
# File 'lib/stripe/resources/quote.rb', line 248 def lines_invalid @lines_invalid end |
#marked_stale ⇒ Object (readonly)
The user supplied mark stale reason.
251 252 253 |
# File 'lib/stripe/resources/quote.rb', line 251 def marked_stale @marked_stale end |
#subscription_canceled ⇒ Object (readonly)
The ID of the subscription that was canceled.
254 255 256 |
# File 'lib/stripe/resources/quote.rb', line 254 def subscription_canceled @subscription_canceled end |
#subscription_changed ⇒ Object (readonly)
Attribute for field subscription_changed
257 258 259 |
# File 'lib/stripe/resources/quote.rb', line 257 def subscription_changed @subscription_changed end |
#subscription_expired ⇒ Object (readonly)
The ID of the subscription that was expired.
260 261 262 |
# File 'lib/stripe/resources/quote.rb', line 260 def subscription_expired @subscription_expired end |
#subscription_schedule_canceled ⇒ Object (readonly)
The ID of the subscription schedule that was canceled.
263 264 265 |
# File 'lib/stripe/resources/quote.rb', line 263 def subscription_schedule_canceled @subscription_schedule_canceled end |
#subscription_schedule_changed ⇒ Object (readonly)
Attribute for field subscription_schedule_changed
266 267 268 |
# File 'lib/stripe/resources/quote.rb', line 266 def subscription_schedule_changed @subscription_schedule_changed end |
#subscription_schedule_released ⇒ Object (readonly)
The ID of the subscription schedule that was released.
269 270 271 |
# File 'lib/stripe/resources/quote.rb', line 269 def subscription_schedule_released @subscription_schedule_released end |
#type ⇒ Object (readonly)
The reason the quote was marked as stale.
272 273 274 |
# File 'lib/stripe/resources/quote.rb', line 272 def type @type end |