Class: Stripe::Quote::SubscriptionData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::SubscriptionData
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: BillingMode
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_mode ⇒ Object
readonly
The billing mode of the quote.
-
#description ⇒ Object
readonly
The subscription's description, meant to be displayable to the customer.
-
#effective_date ⇒ Object
readonly
When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted.
-
#metadata ⇒ Object
readonly
Set of key-value pairs that will set metadata on the subscription or subscription schedule when the quote is accepted.
-
#trial_period_days ⇒ Object
readonly
Integer representing the number of trial period days before the customer is charged for the first time.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_mode ⇒ Object (readonly)
The billing mode of the quote.
354 355 356 |
# File 'lib/stripe/resources/quote.rb', line 354 def billing_mode @billing_mode end |
#description ⇒ Object (readonly)
The subscription's description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
356 357 358 |
# File 'lib/stripe/resources/quote.rb', line 356 def description @description end |
#effective_date ⇒ Object (readonly)
When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted. This date is ignored if it is in the past when the quote is accepted. Measured in seconds since the Unix epoch.
358 359 360 |
# File 'lib/stripe/resources/quote.rb', line 358 def effective_date @effective_date end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that will set metadata on the subscription or subscription schedule when the quote is accepted. If a recurring price is included in line_items, this field will be passed to the resulting subscription's metadata field. If subscription_data.effective_date is used, this field will be passed to the resulting subscription schedule's phases.metadata field. Unlike object-level metadata, this field is declarative. Updates will clear prior values.
360 361 362 |
# File 'lib/stripe/resources/quote.rb', line 360 def @metadata end |
#trial_period_days ⇒ Object (readonly)
Integer representing the number of trial period days before the customer is charged for the first time.
362 363 364 |
# File 'lib/stripe/resources/quote.rb', line 362 def trial_period_days @trial_period_days end |
Class Method Details
.field_remappings ⇒ Object
368 369 370 |
# File 'lib/stripe/resources/quote.rb', line 368 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
364 365 366 |
# File 'lib/stripe/resources/quote.rb', line 364 def self.inner_class_types @inner_class_types = { billing_mode: BillingMode } end |