Class: Stripe::Quote::SubscriptionData

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: BillOnAcceptance, BillingMode, BillingSchedule, Prebilling

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bill_on_acceptanceObject (readonly)

Describes the period to bill for upon accepting the quote.



771
772
773
# File 'lib/stripe/resources/quote.rb', line 771

def bill_on_acceptance
  @bill_on_acceptance
end

#billing_behaviorObject (readonly)

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



773
774
775
# File 'lib/stripe/resources/quote.rb', line 773

def billing_behavior
  @billing_behavior
end

#billing_cycle_anchorObject (readonly)

Whether the subscription will always start a new billing period when the quote is accepted.



775
776
777
# File 'lib/stripe/resources/quote.rb', line 775

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_modeObject (readonly)

The billing mode of the quote.



777
778
779
# File 'lib/stripe/resources/quote.rb', line 777

def billing_mode
  @billing_mode
end

#billing_schedulesObject (readonly)

Billing schedules that will be applied to the subscription or subscription schedule created from this quote.



779
780
781
# File 'lib/stripe/resources/quote.rb', line 779

def billing_schedules
  @billing_schedules
end

#descriptionObject (readonly)

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



781
782
783
# File 'lib/stripe/resources/quote.rb', line 781

def description
  @description
end

#effective_dateObject (readonly)

When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted. This date is ignored if it is in the past when the quote is accepted. Measured in seconds since the Unix epoch.



783
784
785
# File 'lib/stripe/resources/quote.rb', line 783

def effective_date
  @effective_date
end

#end_behaviorObject (readonly)

Behavior of the subscription schedule and underlying subscription when it ends.



785
786
787
# File 'lib/stripe/resources/quote.rb', line 785

def end_behavior
  @end_behavior
end

#from_subscriptionObject (readonly)

The id of the subscription that will be updated when the quote is accepted.



787
788
789
# File 'lib/stripe/resources/quote.rb', line 787

def from_subscription
  @from_subscription
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that will set metadata on the subscription or subscription schedule when the quote is accepted. If a recurring price is included in ‘line_items`, this field will be passed to the resulting subscription’s ‘metadata` field. If `subscription_data.effective_date` is used, this field will be passed to the resulting subscription schedule’s ‘phases.metadata` field. Unlike object-level metadata, this field is declarative. Updates will clear prior values.



789
790
791
# File 'lib/stripe/resources/quote.rb', line 789

def 
  @metadata
end

#phase_effective_atObject (readonly)

Configures how the subscription schedule handles billing for phase transitions. Possible values are ‘phase_start` (default) or `billing_period_start`. `phase_start` bills based on the current state of the subscription, ignoring changes scheduled in future phases. `billing_period_start` bills predictively for upcoming phase transitions within the current billing cycle, including pricing changes and service period adjustments that will occur before the next invoice.



791
792
793
# File 'lib/stripe/resources/quote.rb', line 791

def phase_effective_at
  @phase_effective_at
end

#prebillingObject (readonly)

If specified, the invoicing for the given billing cycle iterations will be processed when the quote is accepted. Cannot be used with ‘effective_date`.



793
794
795
# File 'lib/stripe/resources/quote.rb', line 793

def prebilling
  @prebilling
end

#proration_behaviorObject (readonly)

Determines how to handle [prorations](stripe.com/docs/subscriptions/billing-cycle#prorations) when the quote is accepted.



795
796
797
# File 'lib/stripe/resources/quote.rb', line 795

def proration_behavior
  @proration_behavior
end

#trial_period_daysObject (readonly)

Integer representing the number of trial period days before the customer is charged for the first time.



797
798
799
# File 'lib/stripe/resources/quote.rb', line 797

def trial_period_days
  @trial_period_days
end

Class Method Details

.field_remappingsObject



808
809
810
# File 'lib/stripe/resources/quote.rb', line 808

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



799
800
801
802
803
804
805
806
# File 'lib/stripe/resources/quote.rb', line 799

def self.inner_class_types
  @inner_class_types = {
    bill_on_acceptance: BillOnAcceptance,
    billing_mode: BillingMode,
    billing_schedules: BillingSchedule,
    prebilling: Prebilling,
  }
end