Class: Stripe::Quote::SubscriptionData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::SubscriptionData
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: BillOnAcceptance, BillingMode, BillingSchedule, Prebilling
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bill_on_acceptance ⇒ Object
readonly
Describes the period to bill for upon accepting the quote.
-
#billing_behavior ⇒ Object
readonly
Configures when the subscription schedule generates prorations for phase transitions.
-
#billing_cycle_anchor ⇒ Object
readonly
Whether the subscription will always start a new billing period when the quote is accepted.
-
#billing_mode ⇒ Object
readonly
The billing mode of the quote.
-
#billing_schedules ⇒ Object
readonly
Billing schedules that will be applied to the subscription or subscription schedule created from this quote.
-
#description ⇒ Object
readonly
The subscription’s description, meant to be displayable to the customer.
-
#effective_date ⇒ Object
readonly
When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted.
-
#end_behavior ⇒ Object
readonly
Behavior of the subscription schedule and underlying subscription when it ends.
-
#from_subscription ⇒ Object
readonly
The id of the subscription that will be updated when the quote is accepted.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that will set metadata on the subscription or subscription schedule when the quote is accepted.
-
#phase_effective_at ⇒ Object
readonly
Configures how the quote handles billing for line transitions.
-
#prebilling ⇒ Object
readonly
If specified, the invoicing for the given billing cycle iterations will be processed when the quote is accepted.
-
#proration_behavior ⇒ Object
readonly
Determines how to handle [prorations](stripe.com/docs/subscriptions/billing-cycle#prorations) when the quote is accepted.
-
#trial_period_days ⇒ Object
readonly
Integer representing the number of trial period days before the customer is charged for the first time.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bill_on_acceptance ⇒ Object (readonly)
Describes the period to bill for upon accepting the quote.
716 717 718 |
# File 'lib/stripe/resources/quote.rb', line 716 def bill_on_acceptance @bill_on_acceptance end |
#billing_behavior ⇒ Object (readonly)
Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.
718 719 720 |
# File 'lib/stripe/resources/quote.rb', line 718 def billing_behavior @billing_behavior end |
#billing_cycle_anchor ⇒ Object (readonly)
Whether the subscription will always start a new billing period when the quote is accepted.
720 721 722 |
# File 'lib/stripe/resources/quote.rb', line 720 def billing_cycle_anchor @billing_cycle_anchor end |
#billing_mode ⇒ Object (readonly)
The billing mode of the quote.
722 723 724 |
# File 'lib/stripe/resources/quote.rb', line 722 def billing_mode @billing_mode end |
#billing_schedules ⇒ Object (readonly)
Billing schedules that will be applied to the subscription or subscription schedule created from this quote.
724 725 726 |
# File 'lib/stripe/resources/quote.rb', line 724 def billing_schedules @billing_schedules end |
#description ⇒ Object (readonly)
The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
726 727 728 |
# File 'lib/stripe/resources/quote.rb', line 726 def description @description end |
#effective_date ⇒ Object (readonly)
When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted. This date is ignored if it is in the past when the quote is accepted. Measured in seconds since the Unix epoch.
728 729 730 |
# File 'lib/stripe/resources/quote.rb', line 728 def effective_date @effective_date end |
#end_behavior ⇒ Object (readonly)
Behavior of the subscription schedule and underlying subscription when it ends.
730 731 732 |
# File 'lib/stripe/resources/quote.rb', line 730 def end_behavior @end_behavior end |
#from_subscription ⇒ Object (readonly)
The id of the subscription that will be updated when the quote is accepted.
732 733 734 |
# File 'lib/stripe/resources/quote.rb', line 732 def from_subscription @from_subscription end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that will set metadata on the subscription or subscription schedule when the quote is accepted. If a recurring price is included in ‘line_items`, this field will be passed to the resulting subscription’s ‘metadata` field. If `subscription_data.effective_date` is used, this field will be passed to the resulting subscription schedule’s ‘phases.metadata` field. Unlike object-level metadata, this field is declarative. Updates will clear prior values.
734 735 736 |
# File 'lib/stripe/resources/quote.rb', line 734 def @metadata end |
#phase_effective_at ⇒ Object (readonly)
Configures how the quote handles billing for line transitions. Possible values are ‘line_start` (default) or `billing_period_start`. `line_start` bills based on the current state of the line, ignoring changes scheduled for future lines. `billing_period_start` bills predictively for upcoming line transitions within the current billing cycle, including pricing changes and service period adjustments that will occur before the next invoice.
736 737 738 |
# File 'lib/stripe/resources/quote.rb', line 736 def phase_effective_at @phase_effective_at end |
#prebilling ⇒ Object (readonly)
If specified, the invoicing for the given billing cycle iterations will be processed when the quote is accepted. Cannot be used with ‘effective_date`.
738 739 740 |
# File 'lib/stripe/resources/quote.rb', line 738 def prebilling @prebilling end |
#proration_behavior ⇒ Object (readonly)
Determines how to handle [prorations](stripe.com/docs/subscriptions/billing-cycle#prorations) when the quote is accepted.
740 741 742 |
# File 'lib/stripe/resources/quote.rb', line 740 def proration_behavior @proration_behavior end |
#trial_period_days ⇒ Object (readonly)
Integer representing the number of trial period days before the customer is charged for the first time.
742 743 744 |
# File 'lib/stripe/resources/quote.rb', line 742 def trial_period_days @trial_period_days end |
Class Method Details
.field_remappings ⇒ Object
753 754 755 |
# File 'lib/stripe/resources/quote.rb', line 753 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
744 745 746 747 748 749 750 751 |
# File 'lib/stripe/resources/quote.rb', line 744 def self.inner_class_types @inner_class_types = { bill_on_acceptance: BillOnAcceptance, billing_mode: BillingMode, billing_schedules: BillingSchedule, prebilling: Prebilling, } end |