Class: Stripe::Quote::SubscriptionData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::SubscriptionData
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: BillOnAcceptance, Prebilling
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bill_on_acceptance ⇒ Object
readonly
Describes the period to bill for upon accepting the quote.
-
#billing_behavior ⇒ Object
readonly
Configures when the subscription schedule generates prorations for phase transitions.
-
#billing_cycle_anchor ⇒ Object
readonly
Whether the subscription will always start a new billing period when the quote is accepted.
-
#description ⇒ Object
readonly
The subscription’s description, meant to be displayable to the customer.
-
#effective_date ⇒ Object
readonly
When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted.
-
#end_behavior ⇒ Object
readonly
Behavior of the subscription schedule and underlying subscription when it ends.
-
#from_subscription ⇒ Object
readonly
The id of the subscription that will be updated when the quote is accepted.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that will set metadata on the subscription or subscription schedule when the quote is accepted.
-
#prebilling ⇒ Object
readonly
If specified, the invoicing for the given billing cycle iterations will be processed when the quote is accepted.
-
#proration_behavior ⇒ Object
readonly
Determines how to handle [prorations](stripe.com/docs/subscriptions/billing-cycle#prorations) when the quote is accepted.
-
#trial_period_days ⇒ Object
readonly
Integer representing the number of trial period days before the customer is charged for the first time.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bill_on_acceptance ⇒ Object (readonly)
Describes the period to bill for upon accepting the quote.
303 304 305 |
# File 'lib/stripe/resources/quote.rb', line 303 def bill_on_acceptance @bill_on_acceptance end |
#billing_behavior ⇒ Object (readonly)
Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.
305 306 307 |
# File 'lib/stripe/resources/quote.rb', line 305 def billing_behavior @billing_behavior end |
#billing_cycle_anchor ⇒ Object (readonly)
Whether the subscription will always start a new billing period when the quote is accepted.
307 308 309 |
# File 'lib/stripe/resources/quote.rb', line 307 def billing_cycle_anchor @billing_cycle_anchor end |
#description ⇒ Object (readonly)
The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
309 310 311 |
# File 'lib/stripe/resources/quote.rb', line 309 def description @description end |
#effective_date ⇒ Object (readonly)
When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted. This date is ignored if it is in the past when the quote is accepted. Measured in seconds since the Unix epoch.
311 312 313 |
# File 'lib/stripe/resources/quote.rb', line 311 def effective_date @effective_date end |
#end_behavior ⇒ Object (readonly)
Behavior of the subscription schedule and underlying subscription when it ends.
313 314 315 |
# File 'lib/stripe/resources/quote.rb', line 313 def end_behavior @end_behavior end |
#from_subscription ⇒ Object (readonly)
The id of the subscription that will be updated when the quote is accepted.
315 316 317 |
# File 'lib/stripe/resources/quote.rb', line 315 def from_subscription @from_subscription end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that will set metadata on the subscription or subscription schedule when the quote is accepted. If a recurring price is included in ‘line_items`, this field will be passed to the resulting subscription’s ‘metadata` field. If `subscription_data.effective_date` is used, this field will be passed to the resulting subscription schedule’s ‘phases.metadata` field. Unlike object-level metadata, this field is declarative. Updates will clear prior values.
317 318 319 |
# File 'lib/stripe/resources/quote.rb', line 317 def @metadata end |
#prebilling ⇒ Object (readonly)
If specified, the invoicing for the given billing cycle iterations will be processed when the quote is accepted. Cannot be used with ‘effective_date`.
319 320 321 |
# File 'lib/stripe/resources/quote.rb', line 319 def prebilling @prebilling end |
#proration_behavior ⇒ Object (readonly)
Determines how to handle [prorations](stripe.com/docs/subscriptions/billing-cycle#prorations) when the quote is accepted.
321 322 323 |
# File 'lib/stripe/resources/quote.rb', line 321 def proration_behavior @proration_behavior end |
#trial_period_days ⇒ Object (readonly)
Integer representing the number of trial period days before the customer is charged for the first time.
323 324 325 |
# File 'lib/stripe/resources/quote.rb', line 323 def trial_period_days @trial_period_days end |