Class: Stripe::Quote::SubscriptionData::BillOnAcceptance::BillUntil
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::SubscriptionData::BillOnAcceptance::BillUntil
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: Duration, LineEndsAt
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#computed ⇒ Object
readonly
The materialized time.
-
#duration ⇒ Object
readonly
Time span for the quote line starting from the ‘starts_at` date.
-
#line_ends_at ⇒ Object
readonly
The timestamp the given line ends at.
-
#timestamp ⇒ Object
readonly
A precise Unix timestamp.
-
#type ⇒ Object
readonly
The type of method to specify the ‘bill_until` time.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#computed ⇒ Object (readonly)
The materialized time.
338 339 340 |
# File 'lib/stripe/resources/quote.rb', line 338 def computed @computed end |
#duration ⇒ Object (readonly)
Time span for the quote line starting from the ‘starts_at` date.
341 342 343 |
# File 'lib/stripe/resources/quote.rb', line 341 def duration @duration end |
#line_ends_at ⇒ Object (readonly)
The timestamp the given line ends at.
344 345 346 |
# File 'lib/stripe/resources/quote.rb', line 344 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object (readonly)
A precise Unix timestamp.
347 348 349 |
# File 'lib/stripe/resources/quote.rb', line 347 def @timestamp end |
#type ⇒ Object (readonly)
The type of method to specify the ‘bill_until` time.
350 351 352 |
# File 'lib/stripe/resources/quote.rb', line 350 def type @type end |