Class: Stripe::Quote::SubscriptionData::BillingSchedule::BillUntil
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::SubscriptionData::BillingSchedule::BillUntil
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: Duration, LineEndsAt
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#computed_timestamp ⇒ Object
readonly
The timestamp the billing schedule will apply until.
-
#duration ⇒ Object
readonly
Specifies the billing period.
-
#line_ends_at ⇒ Object
readonly
Lets you bill the period ending at a particular Quote line.
-
#timestamp ⇒ Object
readonly
If specified, the billing schedule will apply until the specified timestamp.
-
#type ⇒ Object
readonly
Describes how the billing schedule will determine the end date.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#computed_timestamp ⇒ Object (readonly)
The timestamp the billing schedule will apply until.
667 668 669 |
# File 'lib/stripe/resources/quote.rb', line 667 def @computed_timestamp end |
#duration ⇒ Object (readonly)
Specifies the billing period.
669 670 671 |
# File 'lib/stripe/resources/quote.rb', line 669 def duration @duration end |
#line_ends_at ⇒ Object (readonly)
Lets you bill the period ending at a particular Quote line.
671 672 673 |
# File 'lib/stripe/resources/quote.rb', line 671 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object (readonly)
If specified, the billing schedule will apply until the specified timestamp.
673 674 675 |
# File 'lib/stripe/resources/quote.rb', line 673 def @timestamp end |
#type ⇒ Object (readonly)
Describes how the billing schedule will determine the end date. Either ‘duration` or `timestamp`.
675 676 677 |
# File 'lib/stripe/resources/quote.rb', line 675 def type @type end |
Class Method Details
.field_remappings ⇒ Object
681 682 683 |
# File 'lib/stripe/resources/quote.rb', line 681 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
677 678 679 |
# File 'lib/stripe/resources/quote.rb', line 677 def self.inner_class_types @inner_class_types = { duration: Duration, line_ends_at: LineEndsAt } end |