Class: Stripe::Quote::SubscriptionData::BillingSchedule::BillUntil
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::SubscriptionData::BillingSchedule::BillUntil
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: AmendmentEnd, Duration, LineEndsAt
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amendment_end ⇒ Object
readonly
Use an index to specify the position of an amendment to end prebilling with.
-
#computed_timestamp ⇒ Object
readonly
The timestamp the billing schedule will apply until.
-
#duration ⇒ Object
readonly
Specifies the billing period.
-
#line_ends_at ⇒ Object
readonly
Lets you bill the period ending at a particular Quote line.
-
#timestamp ⇒ Object
readonly
If specified, the billing schedule will apply until the specified timestamp.
-
#type ⇒ Object
readonly
Describes how the billing schedule will determine the end date.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amendment_end ⇒ Object (readonly)
Use an index to specify the position of an amendment to end prebilling with.
716 717 718 |
# File 'lib/stripe/resources/quote.rb', line 716 def amendment_end @amendment_end end |
#computed_timestamp ⇒ Object (readonly)
The timestamp the billing schedule will apply until.
718 719 720 |
# File 'lib/stripe/resources/quote.rb', line 718 def @computed_timestamp end |
#duration ⇒ Object (readonly)
Specifies the billing period.
720 721 722 |
# File 'lib/stripe/resources/quote.rb', line 720 def duration @duration end |
#line_ends_at ⇒ Object (readonly)
Lets you bill the period ending at a particular Quote line.
722 723 724 |
# File 'lib/stripe/resources/quote.rb', line 722 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object (readonly)
If specified, the billing schedule will apply until the specified timestamp.
724 725 726 |
# File 'lib/stripe/resources/quote.rb', line 724 def @timestamp end |
#type ⇒ Object (readonly)
Describes how the billing schedule will determine the end date. Either ‘duration` or `timestamp`.
726 727 728 |
# File 'lib/stripe/resources/quote.rb', line 726 def type @type end |
Class Method Details
.field_remappings ⇒ Object
736 737 738 |
# File 'lib/stripe/resources/quote.rb', line 736 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
728 729 730 731 732 733 734 |
# File 'lib/stripe/resources/quote.rb', line 728 def self.inner_class_types @inner_class_types = { amendment_end: AmendmentEnd, duration: Duration, line_ends_at: LineEndsAt, } end |