Class: Stripe::Quote::SubscriptionDataOverride

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: AppliesTo, BillOnAcceptance

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applies_toObject (readonly)

Attribute for field applies_to



773
774
775
# File 'lib/stripe/resources/quote.rb', line 773

def applies_to
  @applies_to
end

#bill_on_acceptanceObject (readonly)

Describes the period to bill for upon accepting the quote.



775
776
777
# File 'lib/stripe/resources/quote.rb', line 775

def bill_on_acceptance
  @bill_on_acceptance
end

#billing_behaviorObject (readonly)

Configures when the subscription schedule generates prorations for phase transitions. Possible values are prorate_on_next_phase or prorate_up_front with the default being prorate_on_next_phase. prorate_on_next_phase will apply phase changes and generate prorations at transition time. prorate_up_front will bill for all phases within the current billing cycle up front.



777
778
779
# File 'lib/stripe/resources/quote.rb', line 777

def billing_behavior
  @billing_behavior
end

#customerObject (readonly)

The customer who received this quote. A customer is required to finalize the quote. Once specified, you can't change it.



779
780
781
# File 'lib/stripe/resources/quote.rb', line 779

def customer
  @customer
end

#descriptionObject (readonly)

The subscription's description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



781
782
783
# File 'lib/stripe/resources/quote.rb', line 781

def description
  @description
end

#end_behaviorObject (readonly)

Behavior of the subscription schedule and underlying subscription when it ends.



783
784
785
# File 'lib/stripe/resources/quote.rb', line 783

def end_behavior
  @end_behavior
end

#proration_behaviorObject (readonly)

Determines how to handle prorations when the quote is accepted.



785
786
787
# File 'lib/stripe/resources/quote.rb', line 785

def proration_behavior
  @proration_behavior
end

Class Method Details

.field_remappingsObject



791
792
793
# File 'lib/stripe/resources/quote.rb', line 791

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



787
788
789
# File 'lib/stripe/resources/quote.rb', line 787

def self.inner_class_types
  @inner_class_types = { applies_to: AppliesTo, bill_on_acceptance: BillOnAcceptance }
end