Class: Stripe::Quote::SubscriptionDataOverride

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: AppliesTo, BillOnAcceptance

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applies_toObject (readonly)

Attribute for field applies_to



752
753
754
# File 'lib/stripe/resources/quote.rb', line 752

def applies_to
  @applies_to
end

#bill_on_acceptanceObject (readonly)

Describes the period to bill for upon accepting the quote.



754
755
756
# File 'lib/stripe/resources/quote.rb', line 754

def bill_on_acceptance
  @bill_on_acceptance
end

#billing_behaviorObject (readonly)

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



756
757
758
# File 'lib/stripe/resources/quote.rb', line 756

def billing_behavior
  @billing_behavior
end

#customerObject (readonly)

The customer who received this quote. A customer is required to finalize the quote. Once specified, you can’t change it.



758
759
760
# File 'lib/stripe/resources/quote.rb', line 758

def customer
  @customer
end

#descriptionObject (readonly)

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



760
761
762
# File 'lib/stripe/resources/quote.rb', line 760

def description
  @description
end

#end_behaviorObject (readonly)

Behavior of the subscription schedule and underlying subscription when it ends.



762
763
764
# File 'lib/stripe/resources/quote.rb', line 762

def end_behavior
  @end_behavior
end

#proration_behaviorObject (readonly)

Determines how to handle [prorations](docs.stripe.com/subscriptions/billing-cycle#prorations) when the quote is accepted.



764
765
766
# File 'lib/stripe/resources/quote.rb', line 764

def proration_behavior
  @proration_behavior
end

Class Method Details

.field_remappingsObject



770
771
772
# File 'lib/stripe/resources/quote.rb', line 770

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



766
767
768
# File 'lib/stripe/resources/quote.rb', line 766

def self.inner_class_types
  @inner_class_types = { applies_to: AppliesTo, bill_on_acceptance: BillOnAcceptance }
end