Class: Stripe::Quote::SubscriptionDataOverride
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::SubscriptionDataOverride
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: AppliesTo, BillOnAcceptance, BillingSchedule
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applies_to ⇒ Object
readonly
Attribute for field applies_to.
-
#bill_on_acceptance ⇒ Object
readonly
Describes the period to bill for upon accepting the quote.
-
#billing_behavior ⇒ Object
readonly
Configures when the subscription schedule generates prorations for phase transitions.
-
#billing_schedules ⇒ Object
readonly
Billing schedules that will be applied to the subscription or subscription schedule created from this quote.
-
#customer ⇒ Object
readonly
The customer who received this quote.
-
#description ⇒ Object
readonly
The subscription’s description, meant to be displayable to the customer.
-
#end_behavior ⇒ Object
readonly
Behavior of the subscription schedule and underlying subscription when it ends.
-
#phase_effective_at ⇒ Object
readonly
Configures how the subscription schedule handles billing for phase transitions when the quote is accepted.
-
#proration_behavior ⇒ Object
readonly
Determines how to handle [prorations](docs.stripe.com/subscriptions/billing-cycle#prorations) when the quote is accepted.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applies_to ⇒ Object (readonly)
Attribute for field applies_to
981 982 983 |
# File 'lib/stripe/resources/quote.rb', line 981 def applies_to @applies_to end |
#bill_on_acceptance ⇒ Object (readonly)
Describes the period to bill for upon accepting the quote.
983 984 985 |
# File 'lib/stripe/resources/quote.rb', line 983 def bill_on_acceptance @bill_on_acceptance end |
#billing_behavior ⇒ Object (readonly)
Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.
985 986 987 |
# File 'lib/stripe/resources/quote.rb', line 985 def billing_behavior @billing_behavior end |
#billing_schedules ⇒ Object (readonly)
Billing schedules that will be applied to the subscription or subscription schedule created from this quote.
987 988 989 |
# File 'lib/stripe/resources/quote.rb', line 987 def billing_schedules @billing_schedules end |
#customer ⇒ Object (readonly)
The customer who received this quote. A customer is required to finalize the quote. Once specified, you can’t change it.
989 990 991 |
# File 'lib/stripe/resources/quote.rb', line 989 def customer @customer end |
#description ⇒ Object (readonly)
The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
991 992 993 |
# File 'lib/stripe/resources/quote.rb', line 991 def description @description end |
#end_behavior ⇒ Object (readonly)
Behavior of the subscription schedule and underlying subscription when it ends.
993 994 995 |
# File 'lib/stripe/resources/quote.rb', line 993 def end_behavior @end_behavior end |
#phase_effective_at ⇒ Object (readonly)
Configures how the subscription schedule handles billing for phase transitions when the quote is accepted.
995 996 997 |
# File 'lib/stripe/resources/quote.rb', line 995 def phase_effective_at @phase_effective_at end |
#proration_behavior ⇒ Object (readonly)
Determines how to handle [prorations](docs.stripe.com/subscriptions/billing-cycle#prorations) when the quote is accepted.
997 998 999 |
# File 'lib/stripe/resources/quote.rb', line 997 def proration_behavior @proration_behavior end |
Class Method Details
.field_remappings ⇒ Object
1007 1008 1009 |
# File 'lib/stripe/resources/quote.rb', line 1007 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
999 1000 1001 1002 1003 1004 1005 |
# File 'lib/stripe/resources/quote.rb', line 999 def self.inner_class_types @inner_class_types = { applies_to: AppliesTo, bill_on_acceptance: BillOnAcceptance, billing_schedules: BillingSchedule, } end |