Class: Stripe::Quote::SubscriptionDataOverride
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::SubscriptionDataOverride
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: AppliesTo, BillOnAcceptance, BillingSchedule
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applies_to ⇒ Object
readonly
Attribute for field applies_to.
-
#bill_on_acceptance ⇒ Object
readonly
Describes the period to bill for upon accepting the quote.
-
#billing_behavior ⇒ Object
readonly
Configures when the subscription schedule generates prorations for phase transitions.
-
#billing_schedules ⇒ Object
readonly
Billing schedules that will be applied to the subscription or subscription schedule created from this quote.
-
#customer ⇒ Object
readonly
The customer which this quote belongs to.
-
#description ⇒ Object
readonly
The subscription’s description, meant to be displayable to the customer.
-
#end_behavior ⇒ Object
readonly
Behavior of the subscription schedule and underlying subscription when it ends.
-
#phase_effective_at ⇒ Object
readonly
Configures how the subscription schedule handles billing for phase transitions.
-
#proration_behavior ⇒ Object
readonly
Determines how to handle [prorations](stripe.com/docs/subscriptions/billing-cycle#prorations) when the quote is accepted.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applies_to ⇒ Object (readonly)
Attribute for field applies_to
1091 1092 1093 |
# File 'lib/stripe/resources/quote.rb', line 1091 def applies_to @applies_to end |
#bill_on_acceptance ⇒ Object (readonly)
Describes the period to bill for upon accepting the quote.
1093 1094 1095 |
# File 'lib/stripe/resources/quote.rb', line 1093 def bill_on_acceptance @bill_on_acceptance end |
#billing_behavior ⇒ Object (readonly)
Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.
1095 1096 1097 |
# File 'lib/stripe/resources/quote.rb', line 1095 def billing_behavior @billing_behavior end |
#billing_schedules ⇒ Object (readonly)
Billing schedules that will be applied to the subscription or subscription schedule created from this quote.
1097 1098 1099 |
# File 'lib/stripe/resources/quote.rb', line 1097 def billing_schedules @billing_schedules end |
#customer ⇒ Object (readonly)
The customer which this quote belongs to. A customer is required before finalizing the quote. Once specified, it cannot be changed.
1099 1100 1101 |
# File 'lib/stripe/resources/quote.rb', line 1099 def customer @customer end |
#description ⇒ Object (readonly)
The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
1101 1102 1103 |
# File 'lib/stripe/resources/quote.rb', line 1101 def description @description end |
#end_behavior ⇒ Object (readonly)
Behavior of the subscription schedule and underlying subscription when it ends.
1103 1104 1105 |
# File 'lib/stripe/resources/quote.rb', line 1103 def end_behavior @end_behavior end |
#phase_effective_at ⇒ Object (readonly)
Configures how the subscription schedule handles billing for phase transitions. Possible values are ‘phase_start` (default) or `billing_period_start`. `phase_start` bills based on the current state of the subscription, ignoring changes scheduled in future phases. `billing_period_start` bills predictively for upcoming phase transitions within the current billing cycle, including pricing changes and service period adjustments that will occur before the next invoice.
1105 1106 1107 |
# File 'lib/stripe/resources/quote.rb', line 1105 def phase_effective_at @phase_effective_at end |
#proration_behavior ⇒ Object (readonly)
Determines how to handle [prorations](stripe.com/docs/subscriptions/billing-cycle#prorations) when the quote is accepted.
1107 1108 1109 |
# File 'lib/stripe/resources/quote.rb', line 1107 def proration_behavior @proration_behavior end |
Class Method Details
.field_remappings ⇒ Object
1117 1118 1119 |
# File 'lib/stripe/resources/quote.rb', line 1117 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1109 1110 1111 1112 1113 1114 1115 |
# File 'lib/stripe/resources/quote.rb', line 1109 def self.inner_class_types @inner_class_types = { applies_to: AppliesTo, bill_on_acceptance: BillOnAcceptance, billing_schedules: BillingSchedule, } end |