Class: Stripe::Quote::SubscriptionDataOverride

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: AppliesTo, BillOnAcceptance

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applies_toObject (readonly)

Attribute for field applies_to



738
739
740
# File 'lib/stripe/resources/quote.rb', line 738

def applies_to
  @applies_to
end

#bill_on_acceptanceObject (readonly)

Describes the period to bill for upon accepting the quote.



740
741
742
# File 'lib/stripe/resources/quote.rb', line 740

def bill_on_acceptance
  @bill_on_acceptance
end

#billing_behaviorObject (readonly)

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



742
743
744
# File 'lib/stripe/resources/quote.rb', line 742

def billing_behavior
  @billing_behavior
end

#customerObject (readonly)

The customer which this quote belongs to. A customer is required before finalizing the quote. Once specified, it cannot be changed.



744
745
746
# File 'lib/stripe/resources/quote.rb', line 744

def customer
  @customer
end

#descriptionObject (readonly)

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



746
747
748
# File 'lib/stripe/resources/quote.rb', line 746

def description
  @description
end

#end_behaviorObject (readonly)

Behavior of the subscription schedule and underlying subscription when it ends.



748
749
750
# File 'lib/stripe/resources/quote.rb', line 748

def end_behavior
  @end_behavior
end

#proration_behaviorObject (readonly)

Determines how to handle [prorations](stripe.com/docs/subscriptions/billing-cycle#prorations) when the quote is accepted.



750
751
752
# File 'lib/stripe/resources/quote.rb', line 750

def proration_behavior
  @proration_behavior
end

Class Method Details

.field_remappingsObject



756
757
758
# File 'lib/stripe/resources/quote.rb', line 756

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



752
753
754
# File 'lib/stripe/resources/quote.rb', line 752

def self.inner_class_types
  @inner_class_types = { applies_to: AppliesTo, bill_on_acceptance: BillOnAcceptance }
end