Class: Stripe::Quote::SubscriptionDataOverride

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: AppliesTo, BillOnAcceptance

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applies_toObject (readonly)

Attribute for field applies_to



383
384
385
# File 'lib/stripe/resources/quote.rb', line 383

def applies_to
  @applies_to
end

#bill_on_acceptanceObject (readonly)

Describes the period to bill for upon accepting the quote.



385
386
387
# File 'lib/stripe/resources/quote.rb', line 385

def bill_on_acceptance
  @bill_on_acceptance
end

#billing_behaviorObject (readonly)

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



387
388
389
# File 'lib/stripe/resources/quote.rb', line 387

def billing_behavior
  @billing_behavior
end

#customerObject (readonly)

The customer which this quote belongs to. A customer is required before finalizing the quote. Once specified, it cannot be changed.



389
390
391
# File 'lib/stripe/resources/quote.rb', line 389

def customer
  @customer
end

#descriptionObject (readonly)

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



391
392
393
# File 'lib/stripe/resources/quote.rb', line 391

def description
  @description
end

#end_behaviorObject (readonly)

Behavior of the subscription schedule and underlying subscription when it ends.



393
394
395
# File 'lib/stripe/resources/quote.rb', line 393

def end_behavior
  @end_behavior
end

#proration_behaviorObject (readonly)

Determines how to handle [prorations](stripe.com/docs/subscriptions/billing-cycle#prorations) when the quote is accepted.



395
396
397
# File 'lib/stripe/resources/quote.rb', line 395

def proration_behavior
  @proration_behavior
end