Class: Stripe::Quote::SubscriptionDataOverride::BillingSchedule::BillFrom
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::SubscriptionDataOverride::BillingSchedule::BillFrom
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: LineStartsAt
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#computed_timestamp ⇒ Object
readonly
The time the billing schedule applies from.
-
#line_starts_at ⇒ Object
readonly
Lets you bill the period starting from a particular Quote line.
-
#timestamp ⇒ Object
readonly
Use a precise Unix timestamp for prebilling to start.
-
#type ⇒ Object
readonly
Describes how the billing schedule determines the start date.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#computed_timestamp ⇒ Object (readonly)
The time the billing schedule applies from.
899 900 901 |
# File 'lib/stripe/resources/quote.rb', line 899 def @computed_timestamp end |
#line_starts_at ⇒ Object (readonly)
Lets you bill the period starting from a particular Quote line.
901 902 903 |
# File 'lib/stripe/resources/quote.rb', line 901 def line_starts_at @line_starts_at end |
#timestamp ⇒ Object (readonly)
Use a precise Unix timestamp for prebilling to start. Must be earlier than ‘bill_until`.
903 904 905 |
# File 'lib/stripe/resources/quote.rb', line 903 def @timestamp end |
#type ⇒ Object (readonly)
Describes how the billing schedule determines the start date. Possible values are ‘timestamp`, `relative`, `amendment_start`, `now`, `quote_acceptance_date`, `line_starts_at`, or `pause_collection_start`.
905 906 907 |
# File 'lib/stripe/resources/quote.rb', line 905 def type @type end |
Class Method Details
.field_remappings ⇒ Object
911 912 913 |
# File 'lib/stripe/resources/quote.rb', line 911 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
907 908 909 |
# File 'lib/stripe/resources/quote.rb', line 907 def self.inner_class_types @inner_class_types = { line_starts_at: LineStartsAt } end |