Class: Stripe::Quote::SubscriptionDataOverride::BillingSchedule::BillUntil
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::SubscriptionDataOverride::BillingSchedule::BillUntil
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: AmendmentEnd, Duration, LineEndsAt
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amendment_end ⇒ Object
readonly
Use an index to specify the position of an amendment to end prebilling with.
-
#computed_timestamp ⇒ Object
readonly
The timestamp the billing schedule will apply until.
-
#duration ⇒ Object
readonly
Specifies the billing period.
-
#line_ends_at ⇒ Object
readonly
Lets you bill the period ending at a particular Quote line.
-
#timestamp ⇒ Object
readonly
If specified, the billing schedule will apply until the specified timestamp.
-
#type ⇒ Object
readonly
Describes how the billing schedule will determine the end date.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amendment_end ⇒ Object (readonly)
Use an index to specify the position of an amendment to end prebilling with.
1049 1050 1051 |
# File 'lib/stripe/resources/quote.rb', line 1049 def amendment_end @amendment_end end |
#computed_timestamp ⇒ Object (readonly)
The timestamp the billing schedule will apply until.
1051 1052 1053 |
# File 'lib/stripe/resources/quote.rb', line 1051 def @computed_timestamp end |
#duration ⇒ Object (readonly)
Specifies the billing period.
1053 1054 1055 |
# File 'lib/stripe/resources/quote.rb', line 1053 def duration @duration end |
#line_ends_at ⇒ Object (readonly)
Lets you bill the period ending at a particular Quote line.
1055 1056 1057 |
# File 'lib/stripe/resources/quote.rb', line 1055 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object (readonly)
If specified, the billing schedule will apply until the specified timestamp.
1057 1058 1059 |
# File 'lib/stripe/resources/quote.rb', line 1057 def @timestamp end |
#type ⇒ Object (readonly)
Describes how the billing schedule will determine the end date. Either ‘duration` or `timestamp`.
1059 1060 1061 |
# File 'lib/stripe/resources/quote.rb', line 1059 def type @type end |
Class Method Details
.field_remappings ⇒ Object
1069 1070 1071 |
# File 'lib/stripe/resources/quote.rb', line 1069 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1061 1062 1063 1064 1065 1066 1067 |
# File 'lib/stripe/resources/quote.rb', line 1061 def self.inner_class_types @inner_class_types = { amendment_end: AmendmentEnd, duration: Duration, line_ends_at: LineEndsAt, } end |