Class: Stripe::Quote::SubscriptionSchedule::AppliesTo

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#new_referenceObject (readonly)

A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same ‘new_reference` field will be applied to the creation of a new subscription schedule.



1125
1126
1127
# File 'lib/stripe/resources/quote.rb', line 1125

def new_reference
  @new_reference
end

#subscription_scheduleObject (readonly)

The ID of the schedule the line applies to.



1127
1128
1129
# File 'lib/stripe/resources/quote.rb', line 1127

def subscription_schedule
  @subscription_schedule
end

#typeObject (readonly)

Describes whether the quote line is affecting a new schedule or an existing schedule.



1129
1130
1131
# File 'lib/stripe/resources/quote.rb', line 1129

def type
  @type
end

Class Method Details

.field_remappingsObject



1135
1136
1137
# File 'lib/stripe/resources/quote.rb', line 1135

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1131
1132
1133
# File 'lib/stripe/resources/quote.rb', line 1131

def self.inner_class_types
  @inner_class_types = {}
end