Class: Stripe::Quote::TotalDetails::Breakdown::Tax

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount of tax applied for this rate.



395
396
397
# File 'lib/stripe/resources/quote.rb', line 395

def amount
  @amount
end

#rateObject (readonly)

Tax rates can be applied to invoices, subscriptions and Checkout Sessions to collect tax.

Related guide: Tax rates



399
400
401
# File 'lib/stripe/resources/quote.rb', line 399

def rate
  @rate
end

#taxability_reasonObject (readonly)

The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.



401
402
403
# File 'lib/stripe/resources/quote.rb', line 401

def taxability_reason
  @taxability_reason
end

#taxable_amountObject (readonly)

The amount on which tax is calculated, in cents (or local equivalent).



403
404
405
# File 'lib/stripe/resources/quote.rb', line 403

def taxable_amount
  @taxable_amount
end

Class Method Details

.field_remappingsObject



409
410
411
# File 'lib/stripe/resources/quote.rb', line 409

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



405
406
407
# File 'lib/stripe/resources/quote.rb', line 405

def self.inner_class_types
  @inner_class_types = {}
end