Class: Stripe::Quote::TransferData

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/quote.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount in cents (or local equivalent) that will be transferred to the destination account when the invoice is paid. By default, the entire amount is transferred to the destination.



1226
1227
1228
# File 'lib/stripe/resources/quote.rb', line 1226

def amount
  @amount
end

#amount_percentObject (readonly)

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount will be transferred to the destination.



1228
1229
1230
# File 'lib/stripe/resources/quote.rb', line 1228

def amount_percent
  @amount_percent
end

#destinationObject (readonly)

The account where funds from the payment will be transferred to upon payment success.



1230
1231
1232
# File 'lib/stripe/resources/quote.rb', line 1230

def destination
  @destination
end

Class Method Details

.field_remappingsObject



1236
1237
1238
# File 'lib/stripe/resources/quote.rb', line 1236

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1232
1233
1234
# File 'lib/stripe/resources/quote.rb', line 1232

def self.inner_class_types
  @inner_class_types = {}
end