Class: Stripe::Quote::TransferData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Quote::TransferData
- Defined in:
- lib/stripe/resources/quote.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount in cents (or local equivalent) that will be transferred to the destination account when the invoice is paid.
-
#amount_percent ⇒ Object
readonly
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#destination ⇒ Object
readonly
The account where funds from the payment will be transferred to upon payment success.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount in cents (or local equivalent) that will be transferred to the destination account when the invoice is paid. By default, the entire amount is transferred to the destination.
865 866 867 |
# File 'lib/stripe/resources/quote.rb', line 865 def amount @amount end |
#amount_percent ⇒ Object (readonly)
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount will be transferred to the destination.
867 868 869 |
# File 'lib/stripe/resources/quote.rb', line 867 def amount_percent @amount_percent end |
#destination ⇒ Object (readonly)
The account where funds from the payment will be transferred to upon payment success.
869 870 871 |
# File 'lib/stripe/resources/quote.rb', line 869 def destination @destination end |
Class Method Details
.field_remappings ⇒ Object
875 876 877 |
# File 'lib/stripe/resources/quote.rb', line 875 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
871 872 873 |
# File 'lib/stripe/resources/quote.rb', line 871 def self.inner_class_types @inner_class_types = {} end |