Class: Stripe::Quote::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: AutomaticTax, Discount, InvoiceSettings, LineItem, SubscriptionData, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(application_fee_amount: nil, application_fee_percent: nil, automatic_tax: nil, collection_method: nil, customer: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, expires_at: nil, footer: nil, header: nil, invoice_settings: nil, line_items: nil, metadata: nil, on_behalf_of: nil, subscription_data: nil, transfer_data: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
# File 'lib/stripe/resources/quote.rb', line 773

def initialize(
  application_fee_amount: nil,
  application_fee_percent: nil,
  automatic_tax: nil,
  collection_method: nil,
  customer: nil,
  default_tax_rates: nil,
  description: nil,
  discounts: nil,
  expand: nil,
  expires_at: nil,
  footer: nil,
  header: nil,
  invoice_settings: nil,
  line_items: nil,
  metadata: nil,
  on_behalf_of: nil,
  subscription_data: nil,
  transfer_data: nil
)
  @application_fee_amount = application_fee_amount
  @application_fee_percent = application_fee_percent
  @automatic_tax = automatic_tax
  @collection_method = collection_method
  @customer = customer
  @default_tax_rates = default_tax_rates
  @description = description
  @discounts = discounts
  @expand = expand
  @expires_at = expires_at
  @footer = footer
  @header = header
  @invoice_settings = invoice_settings
  @line_items = line_items
  @metadata = 
  @on_behalf_of = on_behalf_of
  @subscription_data = subscription_data
  @transfer_data = transfer_data
end

Instance Attribute Details

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. There cannot be any line items with recurring prices when using this field.



737
738
739
# File 'lib/stripe/resources/quote.rb', line 737

def application_fee_amount
  @application_fee_amount
end

#application_fee_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. There must be at least 1 line item with a recurring price to use this field.



739
740
741
# File 'lib/stripe/resources/quote.rb', line 739

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject

Settings for automatic tax lookup for this quote and resulting invoices and subscriptions.



741
742
743
# File 'lib/stripe/resources/quote.rb', line 741

def automatic_tax
  @automatic_tax
end

#collection_methodObject

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay invoices at the end of the subscription cycle or at invoice finalization using the default payment method attached to the subscription or customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically`.



743
744
745
# File 'lib/stripe/resources/quote.rb', line 743

def collection_method
  @collection_method
end

#customerObject

The customer for which this quote belongs to. A customer is required before finalizing the quote. Once specified, it cannot be changed.



745
746
747
# File 'lib/stripe/resources/quote.rb', line 745

def customer
  @customer
end

#default_tax_ratesObject

The tax rates that will apply to any line item that does not have ‘tax_rates` set.



747
748
749
# File 'lib/stripe/resources/quote.rb', line 747

def default_tax_rates
  @default_tax_rates
end

#descriptionObject

A description that will be displayed on the quote PDF.



749
750
751
# File 'lib/stripe/resources/quote.rb', line 749

def description
  @description
end

#discountsObject

The discounts applied to the quote.



751
752
753
# File 'lib/stripe/resources/quote.rb', line 751

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



753
754
755
# File 'lib/stripe/resources/quote.rb', line 753

def expand
  @expand
end

#expires_atObject

A future timestamp on which the quote will be canceled if in ‘open` or `draft` status. Measured in seconds since the Unix epoch.



755
756
757
# File 'lib/stripe/resources/quote.rb', line 755

def expires_at
  @expires_at
end

A footer that will be displayed on the quote PDF.



757
758
759
# File 'lib/stripe/resources/quote.rb', line 757

def footer
  @footer
end

#headerObject

A header that will be displayed on the quote PDF.



759
760
761
# File 'lib/stripe/resources/quote.rb', line 759

def header
  @header
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



761
762
763
# File 'lib/stripe/resources/quote.rb', line 761

def invoice_settings
  @invoice_settings
end

#line_itemsObject

A list of line items the customer is being quoted for. Each line item includes information about the product, the quantity, and the resulting cost.



763
764
765
# File 'lib/stripe/resources/quote.rb', line 763

def line_items
  @line_items
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



765
766
767
# File 'lib/stripe/resources/quote.rb', line 765

def 
  @metadata
end

#on_behalf_ofObject

The account on behalf of which to charge.



767
768
769
# File 'lib/stripe/resources/quote.rb', line 767

def on_behalf_of
  @on_behalf_of
end

#subscription_dataObject

When creating a subscription or subscription schedule, the specified configuration data will be used. There must be at least one line item with a recurring price for a subscription or subscription schedule to be created. A subscription schedule is created if ‘subscription_data` is present and in the future, otherwise a subscription is created.



769
770
771
# File 'lib/stripe/resources/quote.rb', line 769

def subscription_data
  @subscription_data
end

#transfer_dataObject

The data with which to automatically create a Transfer for each of the invoices.



771
772
773
# File 'lib/stripe/resources/quote.rb', line 771

def transfer_data
  @transfer_data
end