Class: Stripe::Quote::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: AutomaticTax, Discount, InvoiceSettings, Line, LineItem, SubscriptionData, SubscriptionDataOverride, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_backdated_lines: nil, application_fee_amount: nil, application_fee_percent: nil, automatic_tax: nil, collection_method: nil, customer: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, expires_at: nil, footer: nil, header: nil, invoice_settings: nil, line_items: nil, lines: nil, metadata: nil, on_behalf_of: nil, subscription_data: nil, subscription_data_overrides: nil, transfer_data: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
3021
3022
3023
3024
3025
3026
3027
3028
3029
3030
3031
3032
3033
3034
3035
3036
3037
3038
3039
3040
3041
3042
3043
3044
# File 'lib/stripe/resources/quote.rb', line 3000

def initialize(
  allow_backdated_lines: nil,
  application_fee_amount: nil,
  application_fee_percent: nil,
  automatic_tax: nil,
  collection_method: nil,
  customer: nil,
  default_tax_rates: nil,
  description: nil,
  discounts: nil,
  expand: nil,
  expires_at: nil,
  footer: nil,
  header: nil,
  invoice_settings: nil,
  line_items: nil,
  lines: nil,
  metadata: nil,
  on_behalf_of: nil,
  subscription_data: nil,
  subscription_data_overrides: nil,
  transfer_data: nil
)
  @allow_backdated_lines = allow_backdated_lines
  @application_fee_amount = application_fee_amount
  @application_fee_percent = application_fee_percent
  @automatic_tax = automatic_tax
  @collection_method = collection_method
  @customer = customer
  @default_tax_rates = default_tax_rates
  @description = description
  @discounts = discounts
  @expand = expand
  @expires_at = expires_at
  @footer = footer
  @header = header
  @invoice_settings = invoice_settings
  @line_items = line_items
  @lines = lines
  @metadata = 
  @on_behalf_of = on_behalf_of
  @subscription_data = subscription_data
  @subscription_data_overrides = subscription_data_overrides
  @transfer_data = transfer_data
end

Instance Attribute Details

#allow_backdated_linesObject

Set to true to allow quote lines to have ‘starts_at` in the past if collection is paused between `starts_at` and now.



2938
2939
2940
# File 'lib/stripe/resources/quote.rb', line 2938

def allow_backdated_lines
  @allow_backdated_lines
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. There cannot be any line items with recurring prices when using this field.



2941
2942
2943
# File 'lib/stripe/resources/quote.rb', line 2941

def application_fee_amount
  @application_fee_amount
end

#application_fee_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. There must be at least 1 line item with a recurring price to use this field.



2944
2945
2946
# File 'lib/stripe/resources/quote.rb', line 2944

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject

Settings for automatic tax lookup for this quote and resulting invoices and subscriptions.



2947
2948
2949
# File 'lib/stripe/resources/quote.rb', line 2947

def automatic_tax
  @automatic_tax
end

#collection_methodObject

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay invoices at the end of the subscription cycle or at invoice finalization using the default payment method attached to the subscription or customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically`.



2950
2951
2952
# File 'lib/stripe/resources/quote.rb', line 2950

def collection_method
  @collection_method
end

#customerObject

The customer for which this quote belongs to. A customer is required before finalizing the quote. Once specified, it cannot be changed.



2953
2954
2955
# File 'lib/stripe/resources/quote.rb', line 2953

def customer
  @customer
end

#default_tax_ratesObject

The tax rates that will apply to any line item that does not have ‘tax_rates` set.



2956
2957
2958
# File 'lib/stripe/resources/quote.rb', line 2956

def default_tax_rates
  @default_tax_rates
end

#descriptionObject

A description that will be displayed on the quote PDF.



2959
2960
2961
# File 'lib/stripe/resources/quote.rb', line 2959

def description
  @description
end

#discountsObject

The discounts applied to the quote.



2962
2963
2964
# File 'lib/stripe/resources/quote.rb', line 2962

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



2965
2966
2967
# File 'lib/stripe/resources/quote.rb', line 2965

def expand
  @expand
end

#expires_atObject

A future timestamp on which the quote will be canceled if in ‘open` or `draft` status. Measured in seconds since the Unix epoch.



2968
2969
2970
# File 'lib/stripe/resources/quote.rb', line 2968

def expires_at
  @expires_at
end

A footer that will be displayed on the quote PDF.



2971
2972
2973
# File 'lib/stripe/resources/quote.rb', line 2971

def footer
  @footer
end

#headerObject

A header that will be displayed on the quote PDF.



2974
2975
2976
# File 'lib/stripe/resources/quote.rb', line 2974

def header
  @header
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



2977
2978
2979
# File 'lib/stripe/resources/quote.rb', line 2977

def invoice_settings
  @invoice_settings
end

#line_itemsObject

A list of line items the customer is being quoted for. Each line item includes information about the product, the quantity, and the resulting cost.



2980
2981
2982
# File 'lib/stripe/resources/quote.rb', line 2980

def line_items
  @line_items
end

#linesObject

A list of [quote lines](docs.stripe.com/api/quote_lines) on the quote. These lines describe changes, in the order provided, that will be used to create new subscription schedules or update existing subscription schedules when the quote is accepted.



2983
2984
2985
# File 'lib/stripe/resources/quote.rb', line 2983

def lines
  @lines
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2986
2987
2988
# File 'lib/stripe/resources/quote.rb', line 2986

def 
  @metadata
end

#on_behalf_ofObject

The account on behalf of which to charge.



2989
2990
2991
# File 'lib/stripe/resources/quote.rb', line 2989

def on_behalf_of
  @on_behalf_of
end

#subscription_dataObject

When creating a subscription or subscription schedule, the specified configuration data will be used. There must be at least one line item with a recurring price for a subscription or subscription schedule to be created. A subscription schedule is created if ‘subscription_data` is present and in the future, otherwise a subscription is created.



2992
2993
2994
# File 'lib/stripe/resources/quote.rb', line 2992

def subscription_data
  @subscription_data
end

#subscription_data_overridesObject

List representing overrides for ‘subscription_data` configurations for specific subscription schedules.



2995
2996
2997
# File 'lib/stripe/resources/quote.rb', line 2995

def subscription_data_overrides
  @subscription_data_overrides
end

#transfer_dataObject

The data with which to automatically create a Transfer for each of the invoices.



2998
2999
3000
# File 'lib/stripe/resources/quote.rb', line 2998

def transfer_data
  @transfer_data
end