Class: Stripe::Quote::UpdateParams::AutomaticTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::AutomaticTax
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: Liability
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Controls whether Stripe will automatically compute tax on the resulting invoices or subscriptions as well as the quote itself.
-
#liability ⇒ Object
The account that’s liable for tax.
Instance Method Summary collapse
-
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
constructor
A new instance of AutomaticTax.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
Returns a new instance of AutomaticTax.
2029 2030 2031 2032 |
# File 'lib/stripe/resources/quote.rb', line 2029 def initialize(enabled: nil, liability: nil) @enabled = enabled @liability = liability end |
Instance Attribute Details
#enabled ⇒ Object
Controls whether Stripe will automatically compute tax on the resulting invoices or subscriptions as well as the quote itself.
2025 2026 2027 |
# File 'lib/stripe/resources/quote.rb', line 2025 def enabled @enabled end |
#liability ⇒ Object
The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
2027 2028 2029 |
# File 'lib/stripe/resources/quote.rb', line 2027 def liability @liability end |