Class: Stripe::Quote::UpdateParams::Discount

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1638
1639
1640
1641
1642
1643
# File 'lib/stripe/resources/quote.rb', line 1638

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1630
1631
1632
# File 'lib/stripe/resources/quote.rb', line 1630

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1632
1633
1634
# File 'lib/stripe/resources/quote.rb', line 1632

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1634
1635
1636
# File 'lib/stripe/resources/quote.rb', line 1634

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1636
1637
1638
# File 'lib/stripe/resources/quote.rb', line 1636

def promotion_code
  @promotion_code
end