Class: Stripe::Quote::UpdateParams::Discount

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1902
1903
1904
1905
1906
1907
# File 'lib/stripe/resources/quote.rb', line 1902

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1891
1892
1893
# File 'lib/stripe/resources/quote.rb', line 1891

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1894
1895
1896
# File 'lib/stripe/resources/quote.rb', line 1894

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1897
1898
1899
# File 'lib/stripe/resources/quote.rb', line 1897

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1900
1901
1902
# File 'lib/stripe/resources/quote.rb', line 1900

def promotion_code
  @promotion_code
end