Class: Stripe::Quote::UpdateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1622
1623
1624
1625
1626
# File 'lib/stripe/resources/quote.rb', line 1622

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1616
1617
1618
# File 'lib/stripe/resources/quote.rb', line 1616

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1618
1619
1620
# File 'lib/stripe/resources/quote.rb', line 1618

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1620
1621
1622
# File 'lib/stripe/resources/quote.rb', line 1620

def type
  @type
end