Class: Stripe::Quote::UpdateParams::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1884 1885 1886 1887 1888 |
# File 'lib/stripe/resources/quote.rb', line 1884 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1876 1877 1878 |
# File 'lib/stripe/resources/quote.rb', line 1876 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1879 1880 1881 |
# File 'lib/stripe/resources/quote.rb', line 1879 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1882 1883 1884 |
# File 'lib/stripe/resources/quote.rb', line 1882 def type @type end |