Class: Stripe::Quote::UpdateParams::Line::Action::AddDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ AddDiscount

Returns a new instance of AddDiscount.



1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
# File 'lib/stripe/resources/quote.rb', line 1697

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



1687
1688
1689
# File 'lib/stripe/resources/quote.rb', line 1687

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



1689
1690
1691
# File 'lib/stripe/resources/quote.rb', line 1689

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1691
1692
1693
# File 'lib/stripe/resources/quote.rb', line 1691

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



1693
1694
1695
# File 'lib/stripe/resources/quote.rb', line 1693

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



1695
1696
1697
# File 'lib/stripe/resources/quote.rb', line 1695

def promotion_code
  @promotion_code
end