Class: Stripe::Quote::UpdateParams::Line::Action::AddDiscount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::Line::Action::AddDiscount::DiscountEnd
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1942 1943 1944 |
# File 'lib/stripe/resources/quote.rb', line 1942 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1940 1941 1942 |
# File 'lib/stripe/resources/quote.rb', line 1940 def type @type end |