Class: Stripe::Quote::UpdateParams::Line::Action::AddItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::Line::Action::AddItem
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to the item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates that apply to this subscription item.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ AddItem
constructor
A new instance of AddItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ AddItem
Returns a new instance of AddItem.
2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 |
# File 'lib/stripe/resources/quote.rb', line 2206 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to the item. Subscription item discounts are applied before subscription discounts.
2194 2195 2196 |
# File 'lib/stripe/resources/quote.rb', line 2194 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2196 2197 2198 |
# File 'lib/stripe/resources/quote.rb', line 2196 def @metadata end |
#price ⇒ Object
The ID of the price object.
2198 2199 2200 |
# File 'lib/stripe/resources/quote.rb', line 2198 def price @price end |
#quantity ⇒ Object
Quantity for this item.
2200 2201 2202 |
# File 'lib/stripe/resources/quote.rb', line 2200 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.
2202 2203 2204 |
# File 'lib/stripe/resources/quote.rb', line 2202 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
2204 2205 2206 |
# File 'lib/stripe/resources/quote.rb', line 2204 def trial @trial end |