Class: Stripe::Quote::UpdateParams::Line::Action::AddItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ AddItem

Returns a new instance of AddItem.



1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
# File 'lib/stripe/resources/quote.rb', line 1794

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



1782
1783
1784
# File 'lib/stripe/resources/quote.rb', line 1782

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1784
1785
1786
# File 'lib/stripe/resources/quote.rb', line 1784

def 
  @metadata
end

#priceObject

The ID of the price object.



1786
1787
1788
# File 'lib/stripe/resources/quote.rb', line 1786

def price
  @price
end

#quantityObject

Quantity for this item.



1788
1789
1790
# File 'lib/stripe/resources/quote.rb', line 1788

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



1790
1791
1792
# File 'lib/stripe/resources/quote.rb', line 1790

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



1792
1793
1794
# File 'lib/stripe/resources/quote.rb', line 1792

def trial
  @trial
end