Class: Stripe::Quote::UpdateParams::Line::Action::AddItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ AddItem

Returns a new instance of AddItem.



1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
# File 'lib/stripe/resources/quote.rb', line 1780

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



1768
1769
1770
# File 'lib/stripe/resources/quote.rb', line 1768

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1770
1771
1772
# File 'lib/stripe/resources/quote.rb', line 1770

def 
  @metadata
end

#priceObject

The ID of the price object.



1772
1773
1774
# File 'lib/stripe/resources/quote.rb', line 1772

def price
  @price
end

#quantityObject

Quantity for this item.



1774
1775
1776
# File 'lib/stripe/resources/quote.rb', line 1774

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



1776
1777
1778
# File 'lib/stripe/resources/quote.rb', line 1776

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



1778
1779
1780
# File 'lib/stripe/resources/quote.rb', line 1778

def trial
  @trial
end