Class: Stripe::Quote::UpdateParams::Line::Action::AddItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ AddItem

Returns a new instance of AddItem.



1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
# File 'lib/stripe/resources/quote.rb', line 1773

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



1761
1762
1763
# File 'lib/stripe/resources/quote.rb', line 1761

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1763
1764
1765
# File 'lib/stripe/resources/quote.rb', line 1763

def 
  @metadata
end

#priceObject

The ID of the price object.



1765
1766
1767
# File 'lib/stripe/resources/quote.rb', line 1765

def price
  @price
end

#quantityObject

Quantity for this item.



1767
1768
1769
# File 'lib/stripe/resources/quote.rb', line 1767

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



1769
1770
1771
# File 'lib/stripe/resources/quote.rb', line 1769

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



1771
1772
1773
# File 'lib/stripe/resources/quote.rb', line 1771

def trial
  @trial
end