Class: Stripe::Quote::UpdateParams::Line::Action::AddItem::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::Line::Action::AddItem::Discount
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1741 1742 1743 1744 1745 1746 |
# File 'lib/stripe/resources/quote.rb', line 1741 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1733 1734 1735 |
# File 'lib/stripe/resources/quote.rb', line 1733 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1735 1736 1737 |
# File 'lib/stripe/resources/quote.rb', line 1735 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1737 1738 1739 |
# File 'lib/stripe/resources/quote.rb', line 1737 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1739 1740 1741 |
# File 'lib/stripe/resources/quote.rb', line 1739 def promotion_code @promotion_code end |