Class: Stripe::Quote::UpdateParams::Line::Action::AddItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1726
1727
1728
1729
1730
# File 'lib/stripe/resources/quote.rb', line 1726

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1720
1721
1722
# File 'lib/stripe/resources/quote.rb', line 1720

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1722
1723
1724
# File 'lib/stripe/resources/quote.rb', line 1722

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1724
1725
1726
# File 'lib/stripe/resources/quote.rb', line 1724

def type
  @type
end