Class: Stripe::Quote::UpdateParams::Line::Action::RemoveDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ RemoveDiscount

Returns a new instance of RemoveDiscount.



1799
1800
1801
1802
1803
# File 'lib/stripe/resources/quote.rb', line 1799

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



1793
1794
1795
# File 'lib/stripe/resources/quote.rb', line 1793

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



1795
1796
1797
# File 'lib/stripe/resources/quote.rb', line 1795

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



1797
1798
1799
# File 'lib/stripe/resources/quote.rb', line 1797

def promotion_code
  @promotion_code
end