Class: Stripe::Quote::UpdateParams::Line::Action::RemoveDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ RemoveDiscount

Returns a new instance of RemoveDiscount.



2083
2084
2085
2086
2087
# File 'lib/stripe/resources/quote.rb', line 2083

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



2075
2076
2077
# File 'lib/stripe/resources/quote.rb', line 2075

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



2078
2079
2080
# File 'lib/stripe/resources/quote.rb', line 2078

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



2081
2082
2083
# File 'lib/stripe/resources/quote.rb', line 2081

def promotion_code
  @promotion_code
end