Class: Stripe::Quote::UpdateParams::Line::Action::RemoveDiscount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::Line::Action::RemoveDiscount
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to remove from the ‘discounts` array.
-
#discount ⇒ Object
The ID of a discount to remove from the ‘discounts` array.
-
#promotion_code ⇒ Object
The ID of a promotion code to remove from the ‘discounts` array.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ RemoveDiscount
constructor
A new instance of RemoveDiscount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ RemoveDiscount
Returns a new instance of RemoveDiscount.
1798 1799 1800 1801 1802 |
# File 'lib/stripe/resources/quote.rb', line 1798 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to remove from the ‘discounts` array.
1792 1793 1794 |
# File 'lib/stripe/resources/quote.rb', line 1792 def coupon @coupon end |
#discount ⇒ Object
The ID of a discount to remove from the ‘discounts` array.
1794 1795 1796 |
# File 'lib/stripe/resources/quote.rb', line 1794 def discount @discount end |
#promotion_code ⇒ Object
The ID of a promotion code to remove from the ‘discounts` array.
1796 1797 1798 |
# File 'lib/stripe/resources/quote.rb', line 1796 def promotion_code @promotion_code end |