Class: Stripe::Quote::UpdateParams::Line::Action::SetDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount

Returns a new instance of SetDiscount.



1843
1844
1845
1846
1847
# File 'lib/stripe/resources/quote.rb', line 1843

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



1837
1838
1839
# File 'lib/stripe/resources/quote.rb', line 1837

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



1839
1840
1841
# File 'lib/stripe/resources/quote.rb', line 1839

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



1841
1842
1843
# File 'lib/stripe/resources/quote.rb', line 1841

def promotion_code
  @promotion_code
end