Class: Stripe::Quote::UpdateParams::Line::Action::SetDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount

Returns a new instance of SetDiscount.



1823
1824
1825
1826
1827
# File 'lib/stripe/resources/quote.rb', line 1823

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



1817
1818
1819
# File 'lib/stripe/resources/quote.rb', line 1817

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



1819
1820
1821
# File 'lib/stripe/resources/quote.rb', line 1819

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



1821
1822
1823
# File 'lib/stripe/resources/quote.rb', line 1821

def promotion_code
  @promotion_code
end