Class: Stripe::Quote::UpdateParams::Line::Action::SetDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount

Returns a new instance of SetDiscount.



2109
2110
2111
2112
2113
# File 'lib/stripe/resources/quote.rb', line 2109

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



2101
2102
2103
# File 'lib/stripe/resources/quote.rb', line 2101

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



2104
2105
2106
# File 'lib/stripe/resources/quote.rb', line 2104

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



2107
2108
2109
# File 'lib/stripe/resources/quote.rb', line 2107

def promotion_code
  @promotion_code
end