Class: Stripe::Quote::UpdateParams::Line::Action::SetDiscount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::Line::Action::SetDiscount
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
-
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
-
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount
constructor
A new instance of SetDiscount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount
Returns a new instance of SetDiscount.
1822 1823 1824 1825 1826 |
# File 'lib/stripe/resources/quote.rb', line 1822 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
1816 1817 1818 |
# File 'lib/stripe/resources/quote.rb', line 1816 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
1818 1819 1820 |
# File 'lib/stripe/resources/quote.rb', line 1818 def discount @discount end |
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
1820 1821 1822 |
# File 'lib/stripe/resources/quote.rb', line 1820 def promotion_code @promotion_code end |