Class: Stripe::Quote::UpdateParams::Line::Action::SetItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2158
2159
2160
2161
2162
2163
# File 'lib/stripe/resources/quote.rb', line 2158

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2147
2148
2149
# File 'lib/stripe/resources/quote.rb', line 2147

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2150
2151
2152
# File 'lib/stripe/resources/quote.rb', line 2150

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2153
2154
2155
# File 'lib/stripe/resources/quote.rb', line 2153

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2156
2157
2158
# File 'lib/stripe/resources/quote.rb', line 2156

def promotion_code
  @promotion_code
end