Class: Stripe::Quote::UpdateParams::Line::Action::SetItem::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::Line::Action::SetItem::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1857 1858 1859 1860 1861 |
# File 'lib/stripe/resources/quote.rb', line 1857 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1851 1852 1853 |
# File 'lib/stripe/resources/quote.rb', line 1851 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1853 1854 1855 |
# File 'lib/stripe/resources/quote.rb', line 1853 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1855 1856 1857 |
# File 'lib/stripe/resources/quote.rb', line 1855 def type @type end |