Class: Stripe::Quote::UpdateParams::Line::Action::SetItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1851
1852
1853
1854
1855
# File 'lib/stripe/resources/quote.rb', line 1851

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1845
1846
1847
# File 'lib/stripe/resources/quote.rb', line 1845

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1847
1848
1849
# File 'lib/stripe/resources/quote.rb', line 1847

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1849
1850
1851
# File 'lib/stripe/resources/quote.rb', line 1849

def type
  @type
end