Class: Stripe::Quote::UpdateParams::Line::Action::SetItem::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::Line::Action::SetItem::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1850 1851 1852 1853 1854 |
# File 'lib/stripe/resources/quote.rb', line 1850 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1844 1845 1846 |
# File 'lib/stripe/resources/quote.rb', line 1844 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1846 1847 1848 |
# File 'lib/stripe/resources/quote.rb', line 1846 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1848 1849 1850 |
# File 'lib/stripe/resources/quote.rb', line 1848 def type @type end |