Class: Stripe::Quote::UpdateParams::Line::Action::SetItem::Discount::DiscountEnd::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



1845
1846
1847
1848
# File 'lib/stripe/resources/quote.rb', line 1845

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1841
1842
1843
# File 'lib/stripe/resources/quote.rb', line 1841

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1843
1844
1845
# File 'lib/stripe/resources/quote.rb', line 1843

def interval_count
  @interval_count
end