Class: Stripe::Quote::UpdateParams::Line::CancelSubscriptionSchedule
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::Line::CancelSubscriptionSchedule
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#cancel_at ⇒ Object
Timestamp helper to cancel the underlying schedule on the accompanying line’s start date.
-
#invoice_now ⇒ Object
If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items.
-
#prorate ⇒ Object
If the subscription schedule is ‘active`, indicates if the cancellation should be prorated.
Instance Method Summary collapse
-
#initialize(cancel_at: nil, invoice_now: nil, prorate: nil) ⇒ CancelSubscriptionSchedule
constructor
A new instance of CancelSubscriptionSchedule.
Methods inherited from RequestParams
Constructor Details
#initialize(cancel_at: nil, invoice_now: nil, prorate: nil) ⇒ CancelSubscriptionSchedule
Returns a new instance of CancelSubscriptionSchedule.
2294 2295 2296 2297 2298 |
# File 'lib/stripe/resources/quote.rb', line 2294 def initialize(cancel_at: nil, invoice_now: nil, prorate: nil) @cancel_at = cancel_at @invoice_now = invoice_now @prorate = prorate end |
Instance Attribute Details
#cancel_at ⇒ Object
Timestamp helper to cancel the underlying schedule on the accompanying line’s start date. Must be set to ‘line_starts_at`.
2286 2287 2288 |
# File 'lib/stripe/resources/quote.rb', line 2286 def cancel_at @cancel_at end |
#invoice_now ⇒ Object
If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items. Boolean that defaults to `true`.
2289 2290 2291 |
# File 'lib/stripe/resources/quote.rb', line 2289 def invoice_now @invoice_now end |
#prorate ⇒ Object
If the subscription schedule is ‘active`, indicates if the cancellation should be prorated. Boolean that defaults to `true`.
2292 2293 2294 |
# File 'lib/stripe/resources/quote.rb', line 2292 def prorate @prorate end |