Class: Stripe::Quote::UpdateParams::Line::EndsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::Line::EndsAt
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: DiscountEnd, Duration
Instance Attribute Summary collapse
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
Select a way to pass in ‘ends_at`.
Instance Method Summary collapse
-
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
constructor
A new instance of EndsAt.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
Returns a new instance of EndsAt.
2020 2021 2022 2023 2024 2025 |
# File 'lib/stripe/resources/quote.rb', line 2020 def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) @discount_end = discount_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
2012 2013 2014 |
# File 'lib/stripe/resources/quote.rb', line 2012 def discount_end @discount_end end |
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
2014 2015 2016 |
# File 'lib/stripe/resources/quote.rb', line 2014 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp.
2016 2017 2018 |
# File 'lib/stripe/resources/quote.rb', line 2016 def @timestamp end |
#type ⇒ Object
Select a way to pass in ‘ends_at`.
2018 2019 2020 |
# File 'lib/stripe/resources/quote.rb', line 2018 def type @type end |