Class: Stripe::Quote::UpdateParams::Line::EndsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::Line::EndsAt
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: DiscountEnd, Duration
Instance Attribute Summary collapse
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
Select a way to pass in ‘ends_at`.
Instance Method Summary collapse
-
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
constructor
A new instance of EndsAt.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
Returns a new instance of EndsAt.
2335 2336 2337 2338 2339 2340 |
# File 'lib/stripe/resources/quote.rb', line 2335 def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) @discount_end = discount_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
2324 2325 2326 |
# File 'lib/stripe/resources/quote.rb', line 2324 def discount_end @discount_end end |
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
2327 2328 2329 |
# File 'lib/stripe/resources/quote.rb', line 2327 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp.
2330 2331 2332 |
# File 'lib/stripe/resources/quote.rb', line 2330 def @timestamp end |
#type ⇒ Object
Select a way to pass in ‘ends_at`.
2333 2334 2335 |
# File 'lib/stripe/resources/quote.rb', line 2333 def type @type end |