Class: Stripe::Quote::UpdateParams::Line::EndsAt::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



2012
2013
2014
2015
# File 'lib/stripe/resources/quote.rb', line 2012

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



2008
2009
2010
# File 'lib/stripe/resources/quote.rb', line 2008

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



2010
2011
2012
# File 'lib/stripe/resources/quote.rb', line 2010

def interval_count
  @interval_count
end