Class: Stripe::Quote::UpdateParams::Line::EndsAt::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



2318
2319
2320
2321
# File 'lib/stripe/resources/quote.rb', line 2318

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



2313
2314
2315
# File 'lib/stripe/resources/quote.rb', line 2313

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



2316
2317
2318
# File 'lib/stripe/resources/quote.rb', line 2316

def interval_count
  @interval_count
end