Class: Stripe::Quote::UpdateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::LineItem
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to this line item.
-
#id ⇒ Object
The ID of an existing line item on the quote.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
The quantity of the line item.
-
#tax_rates ⇒ Object
The tax rates which apply to the line item.
Instance Method Summary collapse
-
#initialize(discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
Returns a new instance of LineItem.
2270 2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 |
# File 'lib/stripe/resources/quote.rb', line 2270 def initialize( discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @discounts = discounts @id = id @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to this line item.
2258 2259 2260 |
# File 'lib/stripe/resources/quote.rb', line 2258 def discounts @discounts end |
#id ⇒ Object
The ID of an existing line item on the quote.
2260 2261 2262 |
# File 'lib/stripe/resources/quote.rb', line 2260 def id @id end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
2262 2263 2264 |
# File 'lib/stripe/resources/quote.rb', line 2262 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
2264 2265 2266 |
# File 'lib/stripe/resources/quote.rb', line 2264 def price_data @price_data end |
#quantity ⇒ Object
The quantity of the line item.
2266 2267 2268 |
# File 'lib/stripe/resources/quote.rb', line 2266 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the quote do not apply to this line item.
2268 2269 2270 |
# File 'lib/stripe/resources/quote.rb', line 2268 def tax_rates @tax_rates end |