Class: Stripe::Quote::UpdateParams::LineItem

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
# File 'lib/stripe/resources/quote.rb', line 687

def initialize(
  discounts: nil,
  id: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discounts = discounts
  @id = id
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The discounts applied to this line item.



675
676
677
# File 'lib/stripe/resources/quote.rb', line 675

def discounts
  @discounts
end

#idObject

The ID of an existing line item on the quote.



677
678
679
# File 'lib/stripe/resources/quote.rb', line 677

def id
  @id
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



679
680
681
# File 'lib/stripe/resources/quote.rb', line 679

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



681
682
683
# File 'lib/stripe/resources/quote.rb', line 681

def price_data
  @price_data
end

#quantityObject

The quantity of the line item.



683
684
685
# File 'lib/stripe/resources/quote.rb', line 683

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the quote do not apply to this line item.



685
686
687
# File 'lib/stripe/resources/quote.rb', line 685

def tax_rates
  @tax_rates
end