Class: Stripe::Quote::UpdateParams::LineItem

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
# File 'lib/stripe/resources/quote.rb', line 2270

def initialize(
  discounts: nil,
  id: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discounts = discounts
  @id = id
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The discounts applied to this line item.



2258
2259
2260
# File 'lib/stripe/resources/quote.rb', line 2258

def discounts
  @discounts
end

#idObject

The ID of an existing line item on the quote.



2260
2261
2262
# File 'lib/stripe/resources/quote.rb', line 2260

def id
  @id
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



2262
2263
2264
# File 'lib/stripe/resources/quote.rb', line 2262

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



2264
2265
2266
# File 'lib/stripe/resources/quote.rb', line 2264

def price_data
  @price_data
end

#quantityObject

The quantity of the line item.



2266
2267
2268
# File 'lib/stripe/resources/quote.rb', line 2266

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the quote do not apply to this line item.



2268
2269
2270
# File 'lib/stripe/resources/quote.rb', line 2268

def tax_rates
  @tax_rates
end