Class: Stripe::Quote::UpdateParams::LineItem

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



2597
2598
2599
2600
2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
# File 'lib/stripe/resources/quote.rb', line 2597

def initialize(
  discounts: nil,
  id: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discounts = discounts
  @id = id
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The discounts applied to this line item.



2580
2581
2582
# File 'lib/stripe/resources/quote.rb', line 2580

def discounts
  @discounts
end

#idObject

The ID of an existing line item on the quote.



2583
2584
2585
# File 'lib/stripe/resources/quote.rb', line 2583

def id
  @id
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



2586
2587
2588
# File 'lib/stripe/resources/quote.rb', line 2586

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



2589
2590
2591
# File 'lib/stripe/resources/quote.rb', line 2589

def price_data
  @price_data
end

#quantityObject

The quantity of the line item.



2592
2593
2594
# File 'lib/stripe/resources/quote.rb', line 2592

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the quote do not apply to this line item.



2595
2596
2597
# File 'lib/stripe/resources/quote.rb', line 2595

def tax_rates
  @tax_rates
end