Class: Stripe::Quote::UpdateParams::LineItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2208
2209
2210
2211
2212
2213
# File 'lib/stripe/resources/quote.rb', line 2208

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2200
2201
2202
# File 'lib/stripe/resources/quote.rb', line 2200

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2202
2203
2204
# File 'lib/stripe/resources/quote.rb', line 2202

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2204
2205
2206
# File 'lib/stripe/resources/quote.rb', line 2204

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2206
2207
2208
# File 'lib/stripe/resources/quote.rb', line 2206

def promotion_code
  @promotion_code
end