Class: Stripe::Quote::UpdateParams::LineItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2188
2189
2190
2191
2192
2193
# File 'lib/stripe/resources/quote.rb', line 2188

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2180
2181
2182
# File 'lib/stripe/resources/quote.rb', line 2180

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2182
2183
2184
# File 'lib/stripe/resources/quote.rb', line 2182

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2184
2185
2186
# File 'lib/stripe/resources/quote.rb', line 2184

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2186
2187
2188
# File 'lib/stripe/resources/quote.rb', line 2186

def promotion_code
  @promotion_code
end