Class: Stripe::Quote::UpdateParams::LineItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2524
2525
2526
2527
2528
2529
# File 'lib/stripe/resources/quote.rb', line 2524

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2513
2514
2515
# File 'lib/stripe/resources/quote.rb', line 2513

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2516
2517
2518
# File 'lib/stripe/resources/quote.rb', line 2516

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2519
2520
2521
# File 'lib/stripe/resources/quote.rb', line 2519

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2522
2523
2524
# File 'lib/stripe/resources/quote.rb', line 2522

def promotion_code
  @promotion_code
end