Class: Stripe::Quote::UpdateParams::LineItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2172
2173
2174
2175
2176
# File 'lib/stripe/resources/quote.rb', line 2172

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2166
2167
2168
# File 'lib/stripe/resources/quote.rb', line 2166

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2168
2169
2170
# File 'lib/stripe/resources/quote.rb', line 2168

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2170
2171
2172
# File 'lib/stripe/resources/quote.rb', line 2170

def type
  @type
end