Class: Stripe::Quote::UpdateParams::LineItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2506
2507
2508
2509
2510
# File 'lib/stripe/resources/quote.rb', line 2506

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2498
2499
2500
# File 'lib/stripe/resources/quote.rb', line 2498

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2501
2502
2503
# File 'lib/stripe/resources/quote.rb', line 2501

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2504
2505
2506
# File 'lib/stripe/resources/quote.rb', line 2504

def type
  @type
end