Class: Stripe::Quote::UpdateParams::LineItem::PriceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: Recurring

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, product: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData

Returns a new instance of PriceData.



2220
2221
2222
2223
2224
2225
2226
2227
2228
2229
2230
2231
2232
2233
2234
# File 'lib/stripe/resources/quote.rb', line 2220

def initialize(
  currency: nil,
  product: nil,
  recurring: nil,
  tax_behavior: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @currency = currency
  @product = product
  @recurring = recurring
  @tax_behavior = tax_behavior
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



2208
2209
2210
# File 'lib/stripe/resources/quote.rb', line 2208

def currency
  @currency
end

#productObject

The ID of the product that this price will belong to.



2210
2211
2212
# File 'lib/stripe/resources/quote.rb', line 2210

def product
  @product
end

#recurringObject

The recurring components of a price such as ‘interval` and `interval_count`.



2212
2213
2214
# File 'lib/stripe/resources/quote.rb', line 2212

def recurring
  @recurring
end

#tax_behaviorObject

Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.



2214
2215
2216
# File 'lib/stripe/resources/quote.rb', line 2214

def tax_behavior
  @tax_behavior
end

#unit_amountObject

A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.



2216
2217
2218
# File 'lib/stripe/resources/quote.rb', line 2216

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.



2218
2219
2220
# File 'lib/stripe/resources/quote.rb', line 2218

def unit_amount_decimal
  @unit_amount_decimal
end