Class: Stripe::Quote::UpdateParams::SubscriptionData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::SubscriptionData
- Defined in:
- lib/stripe/resources/quote.rb
Defined Under Namespace
Classes: BillOnAcceptance, Prebilling
Instance Attribute Summary collapse
-
#bill_on_acceptance ⇒ Object
Describes the period to bill for upon accepting the quote.
-
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions.
-
#billing_cycle_anchor ⇒ Object
When specified as ‘reset`, the subscription will always start a new billing period when the quote is accepted.
-
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer.
-
#effective_date ⇒ Object
When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted.
-
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that will set metadata on the subscription or subscription schedule when the quote is accepted.
-
#prebilling ⇒ Object
If specified, the invoicing for the given billing cycle iterations will be processed when the quote is accepted.
-
#proration_behavior ⇒ Object
Determines how to handle [prorations](stripe.com/docs/subscriptions/billing-cycle#prorations).
-
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time.
Instance Method Summary collapse
-
#initialize(bill_on_acceptance: nil, billing_behavior: nil, billing_cycle_anchor: nil, description: nil, effective_date: nil, end_behavior: nil, metadata: nil, prebilling: nil, proration_behavior: nil, trial_period_days: nil) ⇒ SubscriptionData
constructor
A new instance of SubscriptionData.
Methods inherited from RequestParams
Constructor Details
#initialize(bill_on_acceptance: nil, billing_behavior: nil, billing_cycle_anchor: nil, description: nil, effective_date: nil, end_behavior: nil, metadata: nil, prebilling: nil, proration_behavior: nil, trial_period_days: nil) ⇒ SubscriptionData
Returns a new instance of SubscriptionData.
2381 2382 2383 2384 2385 2386 2387 2388 2389 2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 |
# File 'lib/stripe/resources/quote.rb', line 2381 def initialize( bill_on_acceptance: nil, billing_behavior: nil, billing_cycle_anchor: nil, description: nil, effective_date: nil, end_behavior: nil, metadata: nil, prebilling: nil, proration_behavior: nil, trial_period_days: nil ) @bill_on_acceptance = bill_on_acceptance @billing_behavior = billing_behavior @billing_cycle_anchor = billing_cycle_anchor @description = description @effective_date = effective_date @end_behavior = end_behavior @metadata = @prebilling = prebilling @proration_behavior = proration_behavior @trial_period_days = trial_period_days end |
Instance Attribute Details
#bill_on_acceptance ⇒ Object
Describes the period to bill for upon accepting the quote.
2355 2356 2357 |
# File 'lib/stripe/resources/quote.rb', line 2355 def bill_on_acceptance @bill_on_acceptance end |
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.
2357 2358 2359 |
# File 'lib/stripe/resources/quote.rb', line 2357 def billing_behavior @billing_behavior end |
#billing_cycle_anchor ⇒ Object
When specified as ‘reset`, the subscription will always start a new billing period when the quote is accepted.
2359 2360 2361 |
# File 'lib/stripe/resources/quote.rb', line 2359 def billing_cycle_anchor @billing_cycle_anchor end |
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
2361 2362 2363 |
# File 'lib/stripe/resources/quote.rb', line 2361 def description @description end |
#effective_date ⇒ Object
When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted. When updating a subscription, the date of which the subscription will be updated using a subscription schedule. The special value ‘current_period_end` can be provided to update a subscription at the end of its current period. The `effective_date` is ignored if it is in the past when the quote is accepted.
2363 2364 2365 |
# File 'lib/stripe/resources/quote.rb', line 2363 def effective_date @effective_date end |
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
2365 2366 2367 |
# File 'lib/stripe/resources/quote.rb', line 2365 def end_behavior @end_behavior end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that will set metadata on the subscription or subscription schedule when the quote is accepted. If a recurring price is included in ‘line_items`, this field will be passed to the resulting subscription’s ‘metadata` field. If `subscription_data.effective_date` is used, this field will be passed to the resulting subscription schedule’s ‘phases.metadata` field. Unlike object-level metadata, this field is declarative. Updates will clear prior values.
2367 2368 2369 |
# File 'lib/stripe/resources/quote.rb', line 2367 def @metadata end |
#prebilling ⇒ Object
If specified, the invoicing for the given billing cycle iterations will be processed when the quote is accepted. Cannot be used with ‘effective_date`.
2369 2370 2371 |
# File 'lib/stripe/resources/quote.rb', line 2369 def prebilling @prebilling end |
#proration_behavior ⇒ Object
Determines how to handle [prorations](stripe.com/docs/subscriptions/billing-cycle#prorations). When creating a subscription, valid values are ‘create_prorations` or `none`.
When updating a subscription, valid values are ‘create_prorations`, `none`, or `always_invoice`.
Passing ‘create_prorations` will cause proration invoice items to be created when applicable. These proration items will only be invoiced immediately under [certain conditions](stripe.com/docs/subscriptions/upgrading-downgrading#immediate-payment). In order to always invoice immediately for prorations, pass `always_invoice`.
Prorations can be disabled by passing ‘none`.
2377 2378 2379 |
# File 'lib/stripe/resources/quote.rb', line 2377 def proration_behavior @proration_behavior end |
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time.
2379 2380 2381 |
# File 'lib/stripe/resources/quote.rb', line 2379 def trial_period_days @trial_period_days end |