Class: Stripe::Quote::UpdateParams::SubscriptionData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, effective_date: nil, metadata: nil, trial_period_days: nil) ⇒ SubscriptionData

Returns a new instance of SubscriptionData.



689
690
691
692
693
694
# File 'lib/stripe/resources/quote.rb', line 689

def initialize(description: nil, effective_date: nil, metadata: nil, trial_period_days: nil)
  @description = description
  @effective_date = effective_date
  @metadata = 
  @trial_period_days = trial_period_days
end

Instance Attribute Details

#descriptionObject

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



681
682
683
# File 'lib/stripe/resources/quote.rb', line 681

def description
  @description
end

#effective_dateObject

When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted. When updating a subscription, the date of which the subscription will be updated using a subscription schedule. The special value ‘current_period_end` can be provided to update a subscription at the end of its current period. The `effective_date` is ignored if it is in the past when the quote is accepted.



683
684
685
# File 'lib/stripe/resources/quote.rb', line 683

def effective_date
  @effective_date
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that will set metadata on the subscription or subscription schedule when the quote is accepted. If a recurring price is included in ‘line_items`, this field will be passed to the resulting subscription’s ‘metadata` field. If `subscription_data.effective_date` is used, this field will be passed to the resulting subscription schedule’s ‘phases.metadata` field. Unlike object-level metadata, this field is declarative. Updates will clear prior values.



685
686
687
# File 'lib/stripe/resources/quote.rb', line 685

def 
  @metadata
end

#trial_period_daysObject

Integer representing the number of trial period days before the customer is charged for the first time.



687
688
689
# File 'lib/stripe/resources/quote.rb', line 687

def trial_period_days
  @trial_period_days
end