Class: Stripe::Quote::UpdateParams::SubscriptionData::BillOnAcceptance::BillFrom::LineStartsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineStartsAt

Returns a new instance of LineStartsAt.



2275
2276
2277
2278
# File 'lib/stripe/resources/quote.rb', line 2275

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



2271
2272
2273
# File 'lib/stripe/resources/quote.rb', line 2271

def id
  @id
end

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



2273
2274
2275
# File 'lib/stripe/resources/quote.rb', line 2273

def index
  @index
end