Class: Stripe::Quote::UpdateParams::SubscriptionDataOverride::AppliesTo

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(new_reference: nil, subscription_schedule: nil, type: nil) ⇒ AppliesTo

Returns a new instance of AppliesTo.



2415
2416
2417
2418
2419
# File 'lib/stripe/resources/quote.rb', line 2415

def initialize(new_reference: nil, subscription_schedule: nil, type: nil)
  @new_reference = new_reference
  @subscription_schedule = subscription_schedule
  @type = type
end

Instance Attribute Details

#new_referenceObject

A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same ‘new_reference` field will be applied to the creation of a new subscription schedule.



2409
2410
2411
# File 'lib/stripe/resources/quote.rb', line 2409

def new_reference
  @new_reference
end

#subscription_scheduleObject

The ID of the schedule the line applies to.



2411
2412
2413
# File 'lib/stripe/resources/quote.rb', line 2411

def subscription_schedule
  @subscription_schedule
end

#typeObject

Describes whether the quote line is affecting a new schedule or an existing schedule.



2413
2414
2415
# File 'lib/stripe/resources/quote.rb', line 2413

def type
  @type
end