Class: Stripe::Quote::UpdateParams::SubscriptionDataOverride::AppliesTo

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(new_reference: nil, subscription_schedule: nil, type: nil) ⇒ AppliesTo

Returns a new instance of AppliesTo.



2782
2783
2784
2785
2786
# File 'lib/stripe/resources/quote.rb', line 2782

def initialize(new_reference: nil, subscription_schedule: nil, type: nil)
  @new_reference = new_reference
  @subscription_schedule = subscription_schedule
  @type = type
end

Instance Attribute Details

#new_referenceObject

A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same ‘new_reference` field will be applied to the creation of a new subscription schedule.



2774
2775
2776
# File 'lib/stripe/resources/quote.rb', line 2774

def new_reference
  @new_reference
end

#subscription_scheduleObject

The ID of the schedule the line applies to.



2777
2778
2779
# File 'lib/stripe/resources/quote.rb', line 2777

def subscription_schedule
  @subscription_schedule
end

#typeObject

Describes whether the quote line is affecting a new schedule or an existing schedule.



2780
2781
2782
# File 'lib/stripe/resources/quote.rb', line 2780

def type
  @type
end