Class: Stripe::Quote::UpdateParams::SubscriptionDataOverride::BillOnAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/quote.rb

Defined Under Namespace

Classes: BillFrom, BillUntil

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bill_from: nil, bill_until: nil) ⇒ BillOnAcceptance

Returns a new instance of BillOnAcceptance.



2493
2494
2495
2496
# File 'lib/stripe/resources/quote.rb', line 2493

def initialize(bill_from: nil, bill_until: nil)
  @bill_from = bill_from
  @bill_until = bill_until
end

Instance Attribute Details

#bill_fromObject

The start of the period to bill from when the Quote is accepted.



2489
2490
2491
# File 'lib/stripe/resources/quote.rb', line 2489

def bill_from
  @bill_from
end

#bill_untilObject

The end of the period to bill until when the Quote is accepted.



2491
2492
2493
# File 'lib/stripe/resources/quote.rb', line 2491

def bill_until
  @bill_until
end