Class: Stripe::Quote::UpdateParams::SubscriptionDataOverride::BillOnAcceptance::BillUntil::LineEndsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Quote::UpdateParams::SubscriptionDataOverride::BillOnAcceptance::BillUntil::LineEndsAt
- Defined in:
- lib/stripe/resources/quote.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of a quote line.
-
#index ⇒ Object
The position of the previous quote line in the ‘lines` array after which this line should begin.
Instance Method Summary collapse
-
#initialize(id: nil, index: nil) ⇒ LineEndsAt
constructor
A new instance of LineEndsAt.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, index: nil) ⇒ LineEndsAt
Returns a new instance of LineEndsAt.
2840 2841 2842 2843 |
# File 'lib/stripe/resources/quote.rb', line 2840 def initialize(id: nil, index: nil) @id = id @index = index end |
Instance Attribute Details
#id ⇒ Object
The ID of a quote line.
2835 2836 2837 |
# File 'lib/stripe/resources/quote.rb', line 2835 def id @id end |
#index ⇒ Object
The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.
2838 2839 2840 |
# File 'lib/stripe/resources/quote.rb', line 2838 def index @index end |