Class: Stripe::QuoteCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: AutomaticTax, Discount, FromQuote, InvoiceSettings, Line, LineItem, SubscriptionData, SubscriptionDataOverride, TransferData
Instance Attribute Summary collapse
-
#allow_backdated_lines ⇒ Object
Set to true to allow quote lines to have
starts_atin the past if collection is paused betweenstarts_atand now. -
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account.
-
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this quote and resulting invoices and subscriptions.
-
#collection_method ⇒ Object
Either
charge_automatically, orsend_invoice. -
#customer ⇒ Object
The customer for which this quote belongs to.
-
#customer_account ⇒ Object
The account for which this quote belongs to.
-
#default_tax_rates ⇒ Object
The tax rates that will apply to any line item that does not have
tax_ratesset. -
#description ⇒ Object
A description that will be displayed on the quote PDF.
-
#discounts ⇒ Object
The discounts applied to the quote.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expires_at ⇒ Object
A future timestamp on which the quote will be canceled if in
openordraftstatus. -
#footer ⇒ Object
A footer that will be displayed on the quote PDF.
-
#from_quote ⇒ Object
Clone an existing quote.
-
#header ⇒ Object
A header that will be displayed on the quote PDF.
-
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
-
#line_items ⇒ Object
A list of line items the customer is being quoted for.
-
#lines ⇒ Object
A list of quote lines on the quote.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#on_behalf_of ⇒ Object
The account on behalf of which to charge.
-
#subscription_data ⇒ Object
When creating a subscription or subscription schedule, the specified configuration data will be used.
-
#subscription_data_overrides ⇒ Object
List representing overrides for
subscription_dataconfigurations for specific subscription schedules. -
#test_clock ⇒ Object
ID of the test clock to attach to the quote.
-
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the invoices.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(allow_backdated_lines: nil, application_fee_amount: nil, application_fee_percent: nil, automatic_tax: nil, collection_method: nil, customer: nil, customer_account: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, expires_at: nil, footer: nil, from_quote: nil, header: nil, invoice_settings: nil, line_items: nil, lines: nil, metadata: nil, on_behalf_of: nil, subscription_data: nil, subscription_data_overrides: nil, test_clock: nil, transfer_data: nil) ⇒ QuoteCreateParams
Returns a new instance of QuoteCreateParams.
1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 |
# File 'lib/stripe/params/quote_create_params.rb', line 1504 def initialize( allow_backdated_lines: nil, application_fee_amount: nil, application_fee_percent: nil, automatic_tax: nil, collection_method: nil, customer: nil, customer_account: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, expires_at: nil, footer: nil, from_quote: nil, header: nil, invoice_settings: nil, line_items: nil, lines: nil, metadata: nil, on_behalf_of: nil, subscription_data: nil, subscription_data_overrides: nil, test_clock: nil, transfer_data: nil ) @allow_backdated_lines = allow_backdated_lines @application_fee_amount = application_fee_amount @application_fee_percent = application_fee_percent @automatic_tax = automatic_tax @collection_method = collection_method @customer = customer @customer_account = customer_account @default_tax_rates = default_tax_rates @description = description @discounts = discounts @expand = @expires_at = expires_at @footer = @from_quote = from_quote @header = header @invoice_settings = invoice_settings @line_items = line_items @lines = lines @metadata = @on_behalf_of = on_behalf_of @subscription_data = subscription_data @subscription_data_overrides = subscription_data_overrides @test_clock = test_clock @transfer_data = transfer_data end |
Instance Attribute Details
#allow_backdated_lines ⇒ Object
Set to true to allow quote lines to have starts_at in the past if collection is paused between starts_at and now.
1456 1457 1458 |
# File 'lib/stripe/params/quote_create_params.rb', line 1456 def allow_backdated_lines @allow_backdated_lines end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. There cannot be any line items with recurring prices when using this field.
1458 1459 1460 |
# File 'lib/stripe/params/quote_create_params.rb', line 1458 def application_fee_amount @application_fee_amount end |
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner's Stripe account. There must be at least 1 line item with a recurring price to use this field.
1460 1461 1462 |
# File 'lib/stripe/params/quote_create_params.rb', line 1460 def application_fee_percent @application_fee_percent end |
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this quote and resulting invoices and subscriptions.
1462 1463 1464 |
# File 'lib/stripe/params/quote_create_params.rb', line 1462 def automatic_tax @automatic_tax end |
#collection_method ⇒ Object
Either charge_automatically, or send_invoice. When charging automatically, Stripe will attempt to pay invoices at the end of the subscription cycle or at invoice finalization using the default payment method attached to the subscription or customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as active. Defaults to charge_automatically.
1464 1465 1466 |
# File 'lib/stripe/params/quote_create_params.rb', line 1464 def collection_method @collection_method end |
#customer ⇒ Object
The customer for which this quote belongs to. A customer is required before finalizing the quote. Once specified, it cannot be changed.
1466 1467 1468 |
# File 'lib/stripe/params/quote_create_params.rb', line 1466 def customer @customer end |
#customer_account ⇒ Object
The account for which this quote belongs to. A customer or account is required before finalizing the quote. Once specified, it cannot be changed.
1468 1469 1470 |
# File 'lib/stripe/params/quote_create_params.rb', line 1468 def customer_account @customer_account end |
#default_tax_rates ⇒ Object
The tax rates that will apply to any line item that does not have tax_rates set.
1470 1471 1472 |
# File 'lib/stripe/params/quote_create_params.rb', line 1470 def default_tax_rates @default_tax_rates end |
#description ⇒ Object
A description that will be displayed on the quote PDF. If no value is passed, the default description configured in your quote template settings will be used.
1472 1473 1474 |
# File 'lib/stripe/params/quote_create_params.rb', line 1472 def description @description end |
#discounts ⇒ Object
The discounts applied to the quote.
1474 1475 1476 |
# File 'lib/stripe/params/quote_create_params.rb', line 1474 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1476 1477 1478 |
# File 'lib/stripe/params/quote_create_params.rb', line 1476 def @expand end |
#expires_at ⇒ Object
A future timestamp on which the quote will be canceled if in open or draft status. Measured in seconds since the Unix epoch. If no value is passed, the default expiration date configured in your quote template settings will be used.
1478 1479 1480 |
# File 'lib/stripe/params/quote_create_params.rb', line 1478 def expires_at @expires_at end |
#footer ⇒ Object
A footer that will be displayed on the quote PDF. If no value is passed, the default footer configured in your quote template settings will be used.
1480 1481 1482 |
# File 'lib/stripe/params/quote_create_params.rb', line 1480 def @footer end |
#from_quote ⇒ Object
Clone an existing quote. The new quote will be created in status=draft. When using this parameter, you cannot specify any other parameters except for expires_at.
1482 1483 1484 |
# File 'lib/stripe/params/quote_create_params.rb', line 1482 def from_quote @from_quote end |
#header ⇒ Object
A header that will be displayed on the quote PDF. If no value is passed, the default header configured in your quote template settings will be used.
1484 1485 1486 |
# File 'lib/stripe/params/quote_create_params.rb', line 1484 def header @header end |
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
1486 1487 1488 |
# File 'lib/stripe/params/quote_create_params.rb', line 1486 def invoice_settings @invoice_settings end |
#line_items ⇒ Object
A list of line items the customer is being quoted for. Each line item includes information about the product, the quantity, and the resulting cost.
1488 1489 1490 |
# File 'lib/stripe/params/quote_create_params.rb', line 1488 def line_items @line_items end |
#lines ⇒ Object
A list of quote lines on the quote. These lines describe changes, in the order provided, that will be used to create new subscription schedules or update existing subscription schedules when the quote is accepted.
1490 1491 1492 |
# File 'lib/stripe/params/quote_create_params.rb', line 1490 def lines @lines end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
1492 1493 1494 |
# File 'lib/stripe/params/quote_create_params.rb', line 1492 def @metadata end |
#on_behalf_of ⇒ Object
The account on behalf of which to charge.
1494 1495 1496 |
# File 'lib/stripe/params/quote_create_params.rb', line 1494 def on_behalf_of @on_behalf_of end |
#subscription_data ⇒ Object
When creating a subscription or subscription schedule, the specified configuration data will be used. There must be at least one line item with a recurring price for a subscription or subscription schedule to be created. A subscription schedule is created if subscription_data[effective_date] is present and in the future, otherwise a subscription is created.
1496 1497 1498 |
# File 'lib/stripe/params/quote_create_params.rb', line 1496 def subscription_data @subscription_data end |
#subscription_data_overrides ⇒ Object
List representing overrides for subscription_data configurations for specific subscription schedules.
1498 1499 1500 |
# File 'lib/stripe/params/quote_create_params.rb', line 1498 def subscription_data_overrides @subscription_data_overrides end |
#test_clock ⇒ Object
ID of the test clock to attach to the quote.
1500 1501 1502 |
# File 'lib/stripe/params/quote_create_params.rb', line 1500 def test_clock @test_clock end |
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the invoices.
1502 1503 1504 |
# File 'lib/stripe/params/quote_create_params.rb', line 1502 def transfer_data @transfer_data end |
Class Method Details
.field_encodings ⇒ Object
1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 |
# File 'lib/stripe/params/quote_create_params.rb', line 1556 def self.field_encodings @field_encodings = { line_items: { kind: :array, element: { kind: :object, fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } }, }, }, } end |