Class: Stripe::QuoteCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: AutomaticTax, Discount, FromQuote, InvoiceSettings, LineItem, SubscriptionData, TransferData
Instance Attribute Summary collapse
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account.
-
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this quote and resulting invoices and subscriptions.
-
#collection_method ⇒ Object
Either
charge_automatically, orsend_invoice. -
#customer ⇒ Object
The customer for which this quote belongs to.
-
#customer_account ⇒ Object
The account for which this quote belongs to.
-
#default_tax_rates ⇒ Object
The tax rates that will apply to any line item that does not have
tax_ratesset. -
#description ⇒ Object
A description that will be displayed on the quote PDF.
-
#discounts ⇒ Object
The discounts applied to the quote.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expires_at ⇒ Object
A future timestamp on which the quote will be canceled if in
openordraftstatus. -
#footer ⇒ Object
A footer that will be displayed on the quote PDF.
-
#from_quote ⇒ Object
Clone an existing quote.
-
#header ⇒ Object
A header that will be displayed on the quote PDF.
-
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
-
#line_items ⇒ Object
A list of line items the customer is being quoted for.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#on_behalf_of ⇒ Object
The account on behalf of which to charge.
-
#subscription_data ⇒ Object
When creating a subscription or subscription schedule, the specified configuration data will be used.
-
#test_clock ⇒ Object
ID of the test clock to attach to the quote.
-
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the invoices.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(application_fee_amount: nil, application_fee_percent: nil, automatic_tax: nil, collection_method: nil, customer: nil, customer_account: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, expires_at: nil, footer: nil, from_quote: nil, header: nil, invoice_settings: nil, line_items: nil, metadata: nil, on_behalf_of: nil, subscription_data: nil, test_clock: nil, transfer_data: nil) ⇒ QuoteCreateParams
constructor
A new instance of QuoteCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(application_fee_amount: nil, application_fee_percent: nil, automatic_tax: nil, collection_method: nil, customer: nil, customer_account: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, expires_at: nil, footer: nil, from_quote: nil, header: nil, invoice_settings: nil, line_items: nil, metadata: nil, on_behalf_of: nil, subscription_data: nil, test_clock: nil, transfer_data: nil) ⇒ QuoteCreateParams
Returns a new instance of QuoteCreateParams.
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/stripe/params/quote_create_params.rb', line 296 def initialize( application_fee_amount: nil, application_fee_percent: nil, automatic_tax: nil, collection_method: nil, customer: nil, customer_account: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, expires_at: nil, footer: nil, from_quote: nil, header: nil, invoice_settings: nil, line_items: nil, metadata: nil, on_behalf_of: nil, subscription_data: nil, test_clock: nil, transfer_data: nil ) @application_fee_amount = application_fee_amount @application_fee_percent = application_fee_percent @automatic_tax = automatic_tax @collection_method = collection_method @customer = customer @customer_account = customer_account @default_tax_rates = default_tax_rates @description = description @discounts = discounts @expand = @expires_at = expires_at @footer = @from_quote = from_quote @header = header @invoice_settings = invoice_settings @line_items = line_items @metadata = @on_behalf_of = on_behalf_of @subscription_data = subscription_data @test_clock = test_clock @transfer_data = transfer_data end |
Instance Attribute Details
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. There cannot be any line items with recurring prices when using this field.
254 255 256 |
# File 'lib/stripe/params/quote_create_params.rb', line 254 def application_fee_amount @application_fee_amount end |
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner's Stripe account. There must be at least 1 line item with a recurring price to use this field.
256 257 258 |
# File 'lib/stripe/params/quote_create_params.rb', line 256 def application_fee_percent @application_fee_percent end |
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this quote and resulting invoices and subscriptions.
258 259 260 |
# File 'lib/stripe/params/quote_create_params.rb', line 258 def automatic_tax @automatic_tax end |
#collection_method ⇒ Object
Either charge_automatically, or send_invoice. When charging automatically, Stripe will attempt to pay invoices at the end of the subscription cycle or at invoice finalization using the default payment method attached to the subscription or customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as active. Defaults to charge_automatically.
260 261 262 |
# File 'lib/stripe/params/quote_create_params.rb', line 260 def collection_method @collection_method end |
#customer ⇒ Object
The customer for which this quote belongs to. A customer is required before finalizing the quote. Once specified, it cannot be changed.
262 263 264 |
# File 'lib/stripe/params/quote_create_params.rb', line 262 def customer @customer end |
#customer_account ⇒ Object
The account for which this quote belongs to. A customer or account is required before finalizing the quote. Once specified, it cannot be changed.
264 265 266 |
# File 'lib/stripe/params/quote_create_params.rb', line 264 def customer_account @customer_account end |
#default_tax_rates ⇒ Object
The tax rates that will apply to any line item that does not have tax_rates set.
266 267 268 |
# File 'lib/stripe/params/quote_create_params.rb', line 266 def default_tax_rates @default_tax_rates end |
#description ⇒ Object
A description that will be displayed on the quote PDF. If no value is passed, the default description configured in your quote template settings will be used.
268 269 270 |
# File 'lib/stripe/params/quote_create_params.rb', line 268 def description @description end |
#discounts ⇒ Object
The discounts applied to the quote.
270 271 272 |
# File 'lib/stripe/params/quote_create_params.rb', line 270 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
272 273 274 |
# File 'lib/stripe/params/quote_create_params.rb', line 272 def @expand end |
#expires_at ⇒ Object
A future timestamp on which the quote will be canceled if in open or draft status. Measured in seconds since the Unix epoch. If no value is passed, the default expiration date configured in your quote template settings will be used.
274 275 276 |
# File 'lib/stripe/params/quote_create_params.rb', line 274 def expires_at @expires_at end |
#footer ⇒ Object
A footer that will be displayed on the quote PDF. If no value is passed, the default footer configured in your quote template settings will be used.
276 277 278 |
# File 'lib/stripe/params/quote_create_params.rb', line 276 def @footer end |
#from_quote ⇒ Object
Clone an existing quote. The new quote will be created in status=draft. When using this parameter, you cannot specify any other parameters except for expires_at.
278 279 280 |
# File 'lib/stripe/params/quote_create_params.rb', line 278 def from_quote @from_quote end |
#header ⇒ Object
A header that will be displayed on the quote PDF. If no value is passed, the default header configured in your quote template settings will be used.
280 281 282 |
# File 'lib/stripe/params/quote_create_params.rb', line 280 def header @header end |
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
282 283 284 |
# File 'lib/stripe/params/quote_create_params.rb', line 282 def invoice_settings @invoice_settings end |
#line_items ⇒ Object
A list of line items the customer is being quoted for. Each line item includes information about the product, the quantity, and the resulting cost.
284 285 286 |
# File 'lib/stripe/params/quote_create_params.rb', line 284 def line_items @line_items end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
286 287 288 |
# File 'lib/stripe/params/quote_create_params.rb', line 286 def @metadata end |
#on_behalf_of ⇒ Object
The account on behalf of which to charge.
288 289 290 |
# File 'lib/stripe/params/quote_create_params.rb', line 288 def on_behalf_of @on_behalf_of end |
#subscription_data ⇒ Object
When creating a subscription or subscription schedule, the specified configuration data will be used. There must be at least one line item with a recurring price for a subscription or subscription schedule to be created. A subscription schedule is created if subscription_data[effective_date] is present and in the future, otherwise a subscription is created.
290 291 292 |
# File 'lib/stripe/params/quote_create_params.rb', line 290 def subscription_data @subscription_data end |
#test_clock ⇒ Object
ID of the test clock to attach to the quote.
292 293 294 |
# File 'lib/stripe/params/quote_create_params.rb', line 292 def test_clock @test_clock end |
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the invoices.
294 295 296 |
# File 'lib/stripe/params/quote_create_params.rb', line 294 def transfer_data @transfer_data end |
Class Method Details
.field_encodings ⇒ Object
342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/stripe/params/quote_create_params.rb', line 342 def self.field_encodings @field_encodings = { line_items: { kind: :array, element: { kind: :object, fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } }, }, }, } end |