Class: Stripe::QuoteCreateParams::InvoiceSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::InvoiceSettings
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: CustomField, Issuer
Instance Attribute Summary collapse
-
#custom_fields ⇒ Object
A list of up to 4 custom fields to be displayed on the invoice.
-
#days_until_due ⇒ Object
Number of days within which a customer must pay the invoice generated by this quote.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#footer ⇒ Object
Footer to be displayed on the invoice.
-
#issuer ⇒ Object
The connected account that issues the invoice.
Instance Method Summary collapse
-
#initialize(custom_fields: nil, days_until_due: nil, description: nil, footer: nil, issuer: nil) ⇒ InvoiceSettings
constructor
A new instance of InvoiceSettings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(custom_fields: nil, days_until_due: nil, description: nil, footer: nil, issuer: nil) ⇒ InvoiceSettings
Returns a new instance of InvoiceSettings.
119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/stripe/params/quote_create_params.rb', line 119 def initialize( custom_fields: nil, days_until_due: nil, description: nil, footer: nil, issuer: nil ) @custom_fields = custom_fields @days_until_due = days_until_due @description = description @footer = @issuer = issuer end |
Instance Attribute Details
#custom_fields ⇒ Object
A list of up to 4 custom fields to be displayed on the invoice.
109 110 111 |
# File 'lib/stripe/params/quote_create_params.rb', line 109 def custom_fields @custom_fields end |
#days_until_due ⇒ Object
Number of days within which a customer must pay the invoice generated by this quote. This value will be null for quotes where collection_method=charge_automatically.
111 112 113 |
# File 'lib/stripe/params/quote_create_params.rb', line 111 def days_until_due @days_until_due end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
113 114 115 |
# File 'lib/stripe/params/quote_create_params.rb', line 113 def description @description end |
#footer ⇒ Object
Footer to be displayed on the invoice.
115 116 117 |
# File 'lib/stripe/params/quote_create_params.rb', line 115 def @footer end |
#issuer ⇒ Object
The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
117 118 119 |
# File 'lib/stripe/params/quote_create_params.rb', line 117 def issuer @issuer end |