Class: Stripe::QuoteCreateParams::Line
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::Line
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: Action, AppliesTo, CancelSubscriptionSchedule, EndsAt, SetPauseCollection, StartsAt, TrialSettings
Instance Attribute Summary collapse
-
#actions ⇒ Object
An array of operations the quote line performs.
-
#applies_to ⇒ Object
Details to identify the subscription schedule the quote line applies to.
-
#billing_cycle_anchor ⇒ Object
For point-in-time quote lines (having no
ends_attimestamp), this attribute lets you set or remove whether the subscription's billing cycle anchor is reset at the Quote Linestarts_attimestamp.For time-span based quote lines (having bothstarts_atandends_at), the only valid value isautomatic, which removes any previously configured billing cycle anchor resets during the window of time spanning the quote line. -
#cancel_subscription_schedule ⇒ Object
A point-in-time operation that cancels an existing subscription schedule at the line's starts_at timestamp.
-
#ends_at ⇒ Object
Details to identify the end of the time range modified by the proposed change.
-
#proration_behavior ⇒ Object
Changes to how Stripe handles prorations during the quote line's time span.
-
#set_pause_collection ⇒ Object
Defines how to pause collection for the underlying subscription throughout the duration of the amendment.
-
#set_schedule_end ⇒ Object
Timestamp helper to end the underlying schedule early, based on the acompanying line's start or end date.
-
#starts_at ⇒ Object
Details to identify the earliest timestamp where the proposed change should take effect.
-
#trial_settings ⇒ Object
Settings related to subscription trials.
Instance Method Summary collapse
-
#initialize(actions: nil, applies_to: nil, billing_cycle_anchor: nil, cancel_subscription_schedule: nil, ends_at: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, starts_at: nil, trial_settings: nil) ⇒ Line
constructor
A new instance of Line.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(actions: nil, applies_to: nil, billing_cycle_anchor: nil, cancel_subscription_schedule: nil, ends_at: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, starts_at: nil, trial_settings: nil) ⇒ Line
Returns a new instance of Line.
593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 |
# File 'lib/stripe/params/quote_create_params.rb', line 593 def initialize( actions: nil, applies_to: nil, billing_cycle_anchor: nil, cancel_subscription_schedule: nil, ends_at: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, starts_at: nil, trial_settings: nil ) @actions = actions @applies_to = applies_to @billing_cycle_anchor = billing_cycle_anchor @cancel_subscription_schedule = cancel_subscription_schedule @ends_at = ends_at @proration_behavior = proration_behavior @set_pause_collection = set_pause_collection @set_schedule_end = set_schedule_end @starts_at = starts_at @trial_settings = trial_settings end |
Instance Attribute Details
#actions ⇒ Object
An array of operations the quote line performs.
573 574 575 |
# File 'lib/stripe/params/quote_create_params.rb', line 573 def actions @actions end |
#applies_to ⇒ Object
Details to identify the subscription schedule the quote line applies to.
575 576 577 |
# File 'lib/stripe/params/quote_create_params.rb', line 575 def applies_to @applies_to end |
#billing_cycle_anchor ⇒ Object
For point-in-time quote lines (having no ends_at timestamp), this attribute lets you set or remove whether the subscription's billing cycle anchor is reset at the Quote Line starts_at timestamp.For time-span based quote lines (having both starts_at and ends_at), the only valid value is automatic, which removes any previously configured billing cycle anchor resets during the window of time spanning the quote line.
577 578 579 |
# File 'lib/stripe/params/quote_create_params.rb', line 577 def billing_cycle_anchor @billing_cycle_anchor end |
#cancel_subscription_schedule ⇒ Object
A point-in-time operation that cancels an existing subscription schedule at the line's starts_at timestamp. Currently only compatible with quote_acceptance_date for starts_at. When using cancel_subscription_schedule, the subscription schedule on the quote remains unalterable, except for modifications to the metadata, collection_method or invoice_settings.
579 580 581 |
# File 'lib/stripe/params/quote_create_params.rb', line 579 def cancel_subscription_schedule @cancel_subscription_schedule end |
#ends_at ⇒ Object
Details to identify the end of the time range modified by the proposed change. If not supplied, the quote line is considered a point-in-time operation that only affects the exact timestamp at starts_at, and a restricted set of attributes is supported on the quote line.
581 582 583 |
# File 'lib/stripe/params/quote_create_params.rb', line 581 def ends_at @ends_at end |
#proration_behavior ⇒ Object
Changes to how Stripe handles prorations during the quote line's time span. Affects if and how prorations are created when a future phase starts.
583 584 585 |
# File 'lib/stripe/params/quote_create_params.rb', line 583 def proration_behavior @proration_behavior end |
#set_pause_collection ⇒ Object
Defines how to pause collection for the underlying subscription throughout the duration of the amendment.
585 586 587 |
# File 'lib/stripe/params/quote_create_params.rb', line 585 def set_pause_collection @set_pause_collection end |
#set_schedule_end ⇒ Object
Timestamp helper to end the underlying schedule early, based on the acompanying line's start or end date.
587 588 589 |
# File 'lib/stripe/params/quote_create_params.rb', line 587 def set_schedule_end @set_schedule_end end |
#starts_at ⇒ Object
Details to identify the earliest timestamp where the proposed change should take effect.
589 590 591 |
# File 'lib/stripe/params/quote_create_params.rb', line 589 def starts_at @starts_at end |
#trial_settings ⇒ Object
Settings related to subscription trials.
591 592 593 |
# File 'lib/stripe/params/quote_create_params.rb', line 591 def trial_settings @trial_settings end |