Class: Stripe::QuoteCreateParams::Line::Action::AddDiscount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::Line::Action::AddDiscount
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: DiscountEnd, Settings
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
-
#settings ⇒ Object
Settings for discount application including service period anchoring.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil, settings: nil) ⇒ AddDiscount
constructor
A new instance of AddDiscount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil, settings: nil) ⇒ AddDiscount
Returns a new instance of AddDiscount.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/stripe/params/quote_create_params.rb', line 201 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil, settings: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code @settings = settings end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
189 190 191 |
# File 'lib/stripe/params/quote_create_params.rb', line 189 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
191 192 193 |
# File 'lib/stripe/params/quote_create_params.rb', line 191 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
193 194 195 |
# File 'lib/stripe/params/quote_create_params.rb', line 193 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the discounts array.
195 196 197 |
# File 'lib/stripe/params/quote_create_params.rb', line 195 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
197 198 199 |
# File 'lib/stripe/params/quote_create_params.rb', line 197 def promotion_code @promotion_code end |
#settings ⇒ Object
Settings for discount application including service period anchoring.
199 200 201 |
# File 'lib/stripe/params/quote_create_params.rb', line 199 def settings @settings end |