Class: Stripe::QuoteCreateParams::Line::Action::AddDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ AddDiscount

Returns a new instance of AddDiscount.



156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/stripe/params/quote_create_params.rb', line 156

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



146
147
148
# File 'lib/stripe/params/quote_create_params.rb', line 146

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



148
149
150
# File 'lib/stripe/params/quote_create_params.rb', line 148

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



150
151
152
# File 'lib/stripe/params/quote_create_params.rb', line 150

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the discounts array.



152
153
154
# File 'lib/stripe/params/quote_create_params.rb', line 152

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



154
155
156
# File 'lib/stripe/params/quote_create_params.rb', line 154

def promotion_code
  @promotion_code
end