Class: Stripe::QuoteCreateParams::Line::Action::AddDiscount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::Line::Action::AddDiscount
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: DiscountEnd, Settings
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
-
#settings ⇒ Object
Settings for discount application including service period anchoring.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil, settings: nil) ⇒ AddDiscount
constructor
A new instance of AddDiscount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil, settings: nil) ⇒ AddDiscount
Returns a new instance of AddDiscount.
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/stripe/params/quote_create_params.rb', line 174 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil, settings: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code @settings = settings end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
162 163 164 |
# File 'lib/stripe/params/quote_create_params.rb', line 162 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
164 165 166 |
# File 'lib/stripe/params/quote_create_params.rb', line 164 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
166 167 168 |
# File 'lib/stripe/params/quote_create_params.rb', line 166 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
168 169 170 |
# File 'lib/stripe/params/quote_create_params.rb', line 168 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
170 171 172 |
# File 'lib/stripe/params/quote_create_params.rb', line 170 def promotion_code @promotion_code end |
#settings ⇒ Object
Settings for discount application including service period anchoring.
172 173 174 |
# File 'lib/stripe/params/quote_create_params.rb', line 172 def settings @settings end |