Class: Stripe::QuoteCreateParams::Line::Action::AddDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ AddDiscount

Returns a new instance of AddDiscount.



129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/stripe/params/quote_create_params.rb', line 129

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



119
120
121
# File 'lib/stripe/params/quote_create_params.rb', line 119

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



121
122
123
# File 'lib/stripe/params/quote_create_params.rb', line 121

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



123
124
125
# File 'lib/stripe/params/quote_create_params.rb', line 123

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



125
126
127
# File 'lib/stripe/params/quote_create_params.rb', line 125

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



127
128
129
# File 'lib/stripe/params/quote_create_params.rb', line 127

def promotion_code
  @promotion_code
end