Class: Stripe::QuoteCreateParams::Line::Action::AddDiscount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::Line::Action::AddDiscount
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ AddDiscount
constructor
A new instance of AddDiscount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ AddDiscount
Returns a new instance of AddDiscount.
129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/stripe/params/quote_create_params.rb', line 129 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
119 120 121 |
# File 'lib/stripe/params/quote_create_params.rb', line 119 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
121 122 123 |
# File 'lib/stripe/params/quote_create_params.rb', line 121 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
123 124 125 |
# File 'lib/stripe/params/quote_create_params.rb', line 123 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
125 126 127 |
# File 'lib/stripe/params/quote_create_params.rb', line 125 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
127 128 129 |
# File 'lib/stripe/params/quote_create_params.rb', line 127 def promotion_code @promotion_code end |