Class: Stripe::QuoteCreateParams::Line::Action::AddDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: DiscountEnd, Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil, settings: nil) ⇒ AddDiscount

Returns a new instance of AddDiscount.



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/stripe/params/quote_create_params.rb', line 174

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil,
  settings: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
  @settings = settings
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



162
163
164
# File 'lib/stripe/params/quote_create_params.rb', line 162

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



164
165
166
# File 'lib/stripe/params/quote_create_params.rb', line 164

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



166
167
168
# File 'lib/stripe/params/quote_create_params.rb', line 166

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



168
169
170
# File 'lib/stripe/params/quote_create_params.rb', line 168

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



170
171
172
# File 'lib/stripe/params/quote_create_params.rb', line 170

def promotion_code
  @promotion_code
end

#settingsObject

Settings for discount application including service period anchoring.



172
173
174
# File 'lib/stripe/params/quote_create_params.rb', line 172

def settings
  @settings
end