Class: Stripe::QuoteCreateParams::Line::Action::AddItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::Line::Action::AddItem
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to the item.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates that apply to this subscription item.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
-
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ AddItem
constructor
A new instance of AddItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ AddItem
Returns a new instance of AddItem.
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/stripe/params/quote_create_params.rb', line 214 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial @trial_offer = trial_offer end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to the item. Subscription item discounts are applied before subscription discounts.
200 201 202 |
# File 'lib/stripe/params/quote_create_params.rb', line 200 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
202 203 204 |
# File 'lib/stripe/params/quote_create_params.rb', line 202 def @metadata end |
#price ⇒ Object
The ID of the price object.
204 205 206 |
# File 'lib/stripe/params/quote_create_params.rb', line 204 def price @price end |
#quantity ⇒ Object
Quantity for this item.
206 207 208 |
# File 'lib/stripe/params/quote_create_params.rb', line 206 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.
208 209 210 |
# File 'lib/stripe/params/quote_create_params.rb', line 208 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
210 211 212 |
# File 'lib/stripe/params/quote_create_params.rb', line 210 def trial @trial end |
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
212 213 214 |
# File 'lib/stripe/params/quote_create_params.rb', line 212 def trial_offer @trial_offer end |