Class: Stripe::QuoteCreateParams::Line::Action::AddItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::Line::Action::AddItem
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to the item.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates that apply to this subscription item.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
-
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ AddItem
constructor
A new instance of AddItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ AddItem
Returns a new instance of AddItem.
313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/stripe/params/quote_create_params.rb', line 313 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial @trial_offer = trial_offer end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to the item. Subscription item discounts are applied before subscription discounts.
299 300 301 |
# File 'lib/stripe/params/quote_create_params.rb', line 299 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
301 302 303 |
# File 'lib/stripe/params/quote_create_params.rb', line 301 def @metadata end |
#price ⇒ Object
The ID of the price object.
303 304 305 |
# File 'lib/stripe/params/quote_create_params.rb', line 303 def price @price end |
#quantity ⇒ Object
Quantity for this item.
305 306 307 |
# File 'lib/stripe/params/quote_create_params.rb', line 305 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.
307 308 309 |
# File 'lib/stripe/params/quote_create_params.rb', line 307 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
309 310 311 |
# File 'lib/stripe/params/quote_create_params.rb', line 309 def trial @trial end |
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
311 312 313 |
# File 'lib/stripe/params/quote_create_params.rb', line 311 def trial_offer @trial_offer end |