Class: Stripe::QuoteCreateParams::Line::Action::AddItem::Discount::DiscountEnd::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



200
201
202
203
# File 'lib/stripe/params/quote_create_params.rb', line 200

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



196
197
198
# File 'lib/stripe/params/quote_create_params.rb', line 196

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



198
199
200
# File 'lib/stripe/params/quote_create_params.rb', line 198

def interval_count
  @interval_count
end