Class: Stripe::QuoteCreateParams::Line::Action::AddItem::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



233
234
235
236
237
238
239
# File 'lib/stripe/params/quote_create_params.rb', line 233

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



223
224
225
# File 'lib/stripe/params/quote_create_params.rb', line 223

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



225
226
227
# File 'lib/stripe/params/quote_create_params.rb', line 225

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



227
228
229
# File 'lib/stripe/params/quote_create_params.rb', line 227

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



229
230
231
# File 'lib/stripe/params/quote_create_params.rb', line 229

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



231
232
233
# File 'lib/stripe/params/quote_create_params.rb', line 231

def second
  @second
end