Class: Stripe::QuoteCreateParams::Line::Action::AddItem::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::Line::Action::AddItem::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Defined in:
- lib/stripe/params/quote_create_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
Returns a new instance of Custom.
233 234 235 236 237 238 239 |
# File 'lib/stripe/params/quote_create_params.rb', line 233 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
223 224 225 |
# File 'lib/stripe/params/quote_create_params.rb', line 223 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
225 226 227 |
# File 'lib/stripe/params/quote_create_params.rb', line 225 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
227 228 229 |
# File 'lib/stripe/params/quote_create_params.rb', line 227 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
229 230 231 |
# File 'lib/stripe/params/quote_create_params.rb', line 229 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
231 232 233 |
# File 'lib/stripe/params/quote_create_params.rb', line 231 def second @second end |