Class: Stripe::QuoteCreateParams::Line::Action::RemoveDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ RemoveDiscount

Returns a new instance of RemoveDiscount.



241
242
243
244
245
# File 'lib/stripe/params/quote_create_params.rb', line 241

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



235
236
237
# File 'lib/stripe/params/quote_create_params.rb', line 235

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



237
238
239
# File 'lib/stripe/params/quote_create_params.rb', line 237

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



239
240
241
# File 'lib/stripe/params/quote_create_params.rb', line 239

def promotion_code
  @promotion_code
end