Class: Stripe::QuoteCreateParams::Line::Action::RemoveDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ RemoveDiscount

Returns a new instance of RemoveDiscount.



340
341
342
343
344
# File 'lib/stripe/params/quote_create_params.rb', line 340

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



334
335
336
# File 'lib/stripe/params/quote_create_params.rb', line 334

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



336
337
338
# File 'lib/stripe/params/quote_create_params.rb', line 336

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



338
339
340
# File 'lib/stripe/params/quote_create_params.rb', line 338

def promotion_code
  @promotion_code
end