Class: Stripe::QuoteCreateParams::Line::Action::SetDiscount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::Line::Action::SetDiscount
- Defined in:
- lib/stripe/params/quote_create_params.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to replace the
discountsarray with. -
#discount ⇒ Object
An ID of an existing discount to replace the
discountsarray with. -
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the
discountsarray with.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount
constructor
A new instance of SetDiscount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount
Returns a new instance of SetDiscount.
292 293 294 295 296 |
# File 'lib/stripe/params/quote_create_params.rb', line 292 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to replace the discounts array with.
286 287 288 |
# File 'lib/stripe/params/quote_create_params.rb', line 286 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount to replace the discounts array with.
288 289 290 |
# File 'lib/stripe/params/quote_create_params.rb', line 288 def discount @discount end |
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the discounts array with.
290 291 292 |
# File 'lib/stripe/params/quote_create_params.rb', line 290 def promotion_code @promotion_code end |