Class: Stripe::QuoteCreateParams::Line::Action::SetDiscount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::Line::Action::SetDiscount
- Defined in:
- lib/stripe/params/quote_create_params.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
-
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
-
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount
constructor
A new instance of SetDiscount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount
Returns a new instance of SetDiscount.
265 266 267 268 269 |
# File 'lib/stripe/params/quote_create_params.rb', line 265 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
259 260 261 |
# File 'lib/stripe/params/quote_create_params.rb', line 259 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
261 262 263 |
# File 'lib/stripe/params/quote_create_params.rb', line 261 def discount @discount end |
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
263 264 265 |
# File 'lib/stripe/params/quote_create_params.rb', line 263 def promotion_code @promotion_code end |