Class: Stripe::QuoteCreateParams::Line::Action::SetDiscount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::Line::Action::SetDiscount
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: Settings
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
-
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
-
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
-
#settings ⇒ Object
Settings for discount application including service period anchoring.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil, settings: nil) ⇒ SetDiscount
constructor
A new instance of SetDiscount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil, settings: nil) ⇒ SetDiscount
Returns a new instance of SetDiscount.
408 409 410 411 412 413 |
# File 'lib/stripe/params/quote_create_params.rb', line 408 def initialize(coupon: nil, discount: nil, promotion_code: nil, settings: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code @settings = settings end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
400 401 402 |
# File 'lib/stripe/params/quote_create_params.rb', line 400 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
402 403 404 |
# File 'lib/stripe/params/quote_create_params.rb', line 402 def discount @discount end |
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
404 405 406 |
# File 'lib/stripe/params/quote_create_params.rb', line 404 def promotion_code @promotion_code end |
#settings ⇒ Object
Settings for discount application including service period anchoring.
406 407 408 |
# File 'lib/stripe/params/quote_create_params.rb', line 406 def settings @settings end |