Class: Stripe::QuoteCreateParams::Line::Action::SetDiscount::Settings::ServicePeriodAnchorConfig::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::Line::Action::SetDiscount::Settings::ServicePeriodAnchorConfig::Custom
- Defined in:
- lib/stripe/params/quote_create_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
Returns a new instance of Custom.
371 372 373 374 375 376 377 |
# File 'lib/stripe/params/quote_create_params.rb', line 371 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
361 362 363 |
# File 'lib/stripe/params/quote_create_params.rb', line 361 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
363 364 365 |
# File 'lib/stripe/params/quote_create_params.rb', line 363 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
365 366 367 |
# File 'lib/stripe/params/quote_create_params.rb', line 365 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
367 368 369 |
# File 'lib/stripe/params/quote_create_params.rb', line 367 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
369 370 371 |
# File 'lib/stripe/params/quote_create_params.rb', line 369 def second @second end |