Class: Stripe::QuoteCreateParams::Line::Action::SetDiscount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



371
372
373
374
375
376
377
# File 'lib/stripe/params/quote_create_params.rb', line 371

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



361
362
363
# File 'lib/stripe/params/quote_create_params.rb', line 361

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



363
364
365
# File 'lib/stripe/params/quote_create_params.rb', line 363

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



365
366
367
# File 'lib/stripe/params/quote_create_params.rb', line 365

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



367
368
369
# File 'lib/stripe/params/quote_create_params.rb', line 367

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



369
370
371
# File 'lib/stripe/params/quote_create_params.rb', line 369

def second
  @second
end