Class: Stripe::QuoteCreateParams::Line::Action::SetItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::Line::Action::SetItem
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
If an item with the
pricealready exists, passing this will override thediscountsarray on the subscription item that matches that price. -
#metadata ⇒ Object
If an item with the
pricealready exists, passing this will override themetadataon the subscription item that matches that price. -
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
If an item with the
pricealready exists, passing this will override the quantity on the subscription item that matches that price. -
#tax_rates ⇒ Object
If an item with the
pricealready exists, passing this will override thetax_ratesarray on the subscription item that matches that price. -
#trial ⇒ Object
If an item with the
pricealready exists, passing this will override thetrialconfiguration on the subscription item that matches that price. -
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ SetItem
constructor
A new instance of SetItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ SetItem
Returns a new instance of SetItem.
565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 |
# File 'lib/stripe/params/quote_create_params.rb', line 565 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial @trial_offer = trial_offer end |
Instance Attribute Details
#discounts ⇒ Object
If an item with the price already exists, passing this will override the discounts array on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied discounts.
551 552 553 |
# File 'lib/stripe/params/quote_create_params.rb', line 551 def discounts @discounts end |
#metadata ⇒ Object
If an item with the price already exists, passing this will override the metadata on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied metadata.
553 554 555 |
# File 'lib/stripe/params/quote_create_params.rb', line 553 def @metadata end |
#price ⇒ Object
The ID of the price object.
555 556 557 |
# File 'lib/stripe/params/quote_create_params.rb', line 555 def price @price end |
#quantity ⇒ Object
If an item with the price already exists, passing this will override the quantity on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied quantity.
557 558 559 |
# File 'lib/stripe/params/quote_create_params.rb', line 557 def quantity @quantity end |
#tax_rates ⇒ Object
If an item with the price already exists, passing this will override the tax_rates array on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied tax_rates.
559 560 561 |
# File 'lib/stripe/params/quote_create_params.rb', line 559 def tax_rates @tax_rates end |
#trial ⇒ Object
If an item with the price already exists, passing this will override the trial configuration on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied trial.
561 562 563 |
# File 'lib/stripe/params/quote_create_params.rb', line 561 def trial @trial end |
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
563 564 565 |
# File 'lib/stripe/params/quote_create_params.rb', line 563 def trial_offer @trial_offer end |