Class: Stripe::QuoteCreateParams::Line::Action::SetItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ SetItem

Returns a new instance of SetItem.



538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
# File 'lib/stripe/params/quote_create_params.rb', line 538

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil,
  trial_offer: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
  @trial_offer = trial_offer
end

Instance Attribute Details

#discountsObject

If an item with the ‘price` already exists, passing this will override the `discounts` array on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `discounts`.



524
525
526
# File 'lib/stripe/params/quote_create_params.rb', line 524

def discounts
  @discounts
end

#metadataObject

If an item with the ‘price` already exists, passing this will override the `metadata` on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `metadata`.



526
527
528
# File 'lib/stripe/params/quote_create_params.rb', line 526

def 
  @metadata
end

#priceObject

The ID of the price object.



528
529
530
# File 'lib/stripe/params/quote_create_params.rb', line 528

def price
  @price
end

#quantityObject

If an item with the ‘price` already exists, passing this will override the quantity on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `quantity`.



530
531
532
# File 'lib/stripe/params/quote_create_params.rb', line 530

def quantity
  @quantity
end

#tax_ratesObject

If an item with the ‘price` already exists, passing this will override the `tax_rates` array on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `tax_rates`.



532
533
534
# File 'lib/stripe/params/quote_create_params.rb', line 532

def tax_rates
  @tax_rates
end

#trialObject

If an item with the ‘price` already exists, passing this will override the `trial` configuration on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `trial`.



534
535
536
# File 'lib/stripe/params/quote_create_params.rb', line 534

def trial
  @trial
end

#trial_offerObject

The ID of the trial offer to apply to the configuration item.



536
537
538
# File 'lib/stripe/params/quote_create_params.rb', line 536

def trial_offer
  @trial_offer
end