Class: Stripe::QuoteCreateParams::Line::Action::SetItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



293
294
295
296
297
# File 'lib/stripe/params/quote_create_params.rb', line 293

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



287
288
289
# File 'lib/stripe/params/quote_create_params.rb', line 287

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



289
290
291
# File 'lib/stripe/params/quote_create_params.rb', line 289

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



291
292
293
# File 'lib/stripe/params/quote_create_params.rb', line 291

def type
  @type
end