Class: Stripe::QuoteCreateParams::Line::Action::SetItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



437
438
439
440
441
# File 'lib/stripe/params/quote_create_params.rb', line 437

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



431
432
433
# File 'lib/stripe/params/quote_create_params.rb', line 431

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



433
434
435
# File 'lib/stripe/params/quote_create_params.rb', line 433

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



435
436
437
# File 'lib/stripe/params/quote_create_params.rb', line 435

def type
  @type
end