Class: Stripe::QuoteCreateParams::Line::Action::SetItem::Discount::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::Line::Action::SetItem::Discount::Settings
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: ServicePeriodAnchorConfig
Instance Attribute Summary collapse
-
#service_period_anchor_config ⇒ Object
Configures service period cycle anchoring.
-
#start_date ⇒ Object
The start date of the discount’s service period when applying a coupon or promotion code with a service period duration.
Instance Method Summary collapse
-
#initialize(service_period_anchor_config: nil, start_date: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(service_period_anchor_config: nil, start_date: nil) ⇒ Settings
Returns a new instance of Settings.
481 482 483 484 |
# File 'lib/stripe/params/quote_create_params.rb', line 481 def initialize(service_period_anchor_config: nil, start_date: nil) @service_period_anchor_config = service_period_anchor_config @start_date = start_date end |
Instance Attribute Details
#service_period_anchor_config ⇒ Object
Configures service period cycle anchoring.
477 478 479 |
# File 'lib/stripe/params/quote_create_params.rb', line 477 def service_period_anchor_config @service_period_anchor_config end |
#start_date ⇒ Object
The start date of the discount’s service period when applying a coupon or promotion code with a service period duration. Defaults to ‘line_start` if omitted.
479 480 481 |
# File 'lib/stripe/params/quote_create_params.rb', line 479 def start_date @start_date end |