Class: Stripe::QuoteCreateParams::Line::EndsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::Line::EndsAt
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: DiscountEnd, Duration
Instance Attribute Summary collapse
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
Select a way to pass in ‘ends_at`.
Instance Method Summary collapse
-
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
constructor
A new instance of EndsAt.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
Returns a new instance of EndsAt.
458 459 460 461 462 463 |
# File 'lib/stripe/params/quote_create_params.rb', line 458 def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) @discount_end = discount_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
450 451 452 |
# File 'lib/stripe/params/quote_create_params.rb', line 450 def discount_end @discount_end end |
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
452 453 454 |
# File 'lib/stripe/params/quote_create_params.rb', line 452 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp.
454 455 456 |
# File 'lib/stripe/params/quote_create_params.rb', line 454 def @timestamp end |
#type ⇒ Object
Select a way to pass in ‘ends_at`.
456 457 458 |
# File 'lib/stripe/params/quote_create_params.rb', line 456 def type @type end |