Class: Stripe::QuoteCreateParams::Line::StartsAt::LineEndsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::Line::StartsAt::LineEndsAt
- Defined in:
- lib/stripe/params/quote_create_params.rb
Instance Attribute Summary collapse
-
#index ⇒ Object
The position of the previous quote line in the ‘lines` array after which this line should begin.
Instance Method Summary collapse
-
#initialize(index: nil) ⇒ LineEndsAt
constructor
A new instance of LineEndsAt.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(index: nil) ⇒ LineEndsAt
Returns a new instance of LineEndsAt.
508 509 510 |
# File 'lib/stripe/params/quote_create_params.rb', line 508 def initialize(index: nil) @index = index end |
Instance Attribute Details
#index ⇒ Object
The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.
506 507 508 |
# File 'lib/stripe/params/quote_create_params.rb', line 506 def index @index end |