Class: Stripe::QuoteCreateParams::LineItem

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: Discount, PriceData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



918
919
920
921
922
923
924
# File 'lib/stripe/params/quote_create_params.rb', line 918

def initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil)
  @discounts = discounts
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The discounts applied to this line item.



908
909
910
# File 'lib/stripe/params/quote_create_params.rb', line 908

def discounts
  @discounts
end

#priceObject

The ID of the price object. One of price or price_data is required.



910
911
912
# File 'lib/stripe/params/quote_create_params.rb', line 910

def price
  @price
end

#price_dataObject

Data used to generate a new Price object inline. One of price or price_data is required.



912
913
914
# File 'lib/stripe/params/quote_create_params.rb', line 912

def price_data
  @price_data
end

#quantityObject

The quantity of the line item.



914
915
916
# File 'lib/stripe/params/quote_create_params.rb', line 914

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the default_tax_rates on the quote do not apply to this line item.



916
917
918
# File 'lib/stripe/params/quote_create_params.rb', line 916

def tax_rates
  @tax_rates
end

Class Method Details

.field_encodingsObject



926
927
928
929
930
# File 'lib/stripe/params/quote_create_params.rb', line 926

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end