Class: Stripe::QuoteCreateParams::LineItem

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: Discount, PriceData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



718
719
720
721
722
723
724
# File 'lib/stripe/params/quote_create_params.rb', line 718

def initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil)
  @discounts = discounts
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The discounts applied to this line item.



708
709
710
# File 'lib/stripe/params/quote_create_params.rb', line 708

def discounts
  @discounts
end

#priceObject

The ID of the price object. One of price or price_data is required.



710
711
712
# File 'lib/stripe/params/quote_create_params.rb', line 710

def price
  @price
end

#price_dataObject

Data used to generate a new Price object inline. One of price or price_data is required.



712
713
714
# File 'lib/stripe/params/quote_create_params.rb', line 712

def price_data
  @price_data
end

#quantityObject

The quantity of the line item.



714
715
716
# File 'lib/stripe/params/quote_create_params.rb', line 714

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the default_tax_rates on the quote do not apply to this line item.



716
717
718
# File 'lib/stripe/params/quote_create_params.rb', line 716

def tax_rates
  @tax_rates
end

Class Method Details

.field_encodingsObject



726
727
728
729
730
# File 'lib/stripe/params/quote_create_params.rb', line 726

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end