Class: Stripe::QuoteCreateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::LineItem
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to this line item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new Price object inline.
-
#quantity ⇒ Object
The quantity of the line item.
-
#tax_rates ⇒ Object
The tax rates which apply to the line item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
Returns a new instance of LineItem.
718 719 720 721 722 723 724 |
# File 'lib/stripe/params/quote_create_params.rb', line 718 def initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) @discounts = discounts @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to this line item.
708 709 710 |
# File 'lib/stripe/params/quote_create_params.rb', line 708 def discounts @discounts end |
#price ⇒ Object
The ID of the price object. One of price or price_data is required.
710 711 712 |
# File 'lib/stripe/params/quote_create_params.rb', line 710 def price @price end |
#price_data ⇒ Object
Data used to generate a new Price object inline. One of price or price_data is required.
712 713 714 |
# File 'lib/stripe/params/quote_create_params.rb', line 712 def price_data @price_data end |
#quantity ⇒ Object
The quantity of the line item.
714 715 716 |
# File 'lib/stripe/params/quote_create_params.rb', line 714 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the line item. When set, the default_tax_rates on the quote do not apply to this line item.
716 717 718 |
# File 'lib/stripe/params/quote_create_params.rb', line 716 def tax_rates @tax_rates end |
Class Method Details
.field_encodings ⇒ Object
726 727 728 729 730 |
# File 'lib/stripe/params/quote_create_params.rb', line 726 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |