Class: Stripe::QuoteCreateParams::LineItem

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: Discount, PriceData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



691
692
693
694
695
696
697
# File 'lib/stripe/params/quote_create_params.rb', line 691

def initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil)
  @discounts = discounts
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The discounts applied to this line item.



681
682
683
# File 'lib/stripe/params/quote_create_params.rb', line 681

def discounts
  @discounts
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



683
684
685
# File 'lib/stripe/params/quote_create_params.rb', line 683

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.



685
686
687
# File 'lib/stripe/params/quote_create_params.rb', line 685

def price_data
  @price_data
end

#quantityObject

The quantity of the line item.



687
688
689
# File 'lib/stripe/params/quote_create_params.rb', line 687

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the quote do not apply to this line item.



689
690
691
# File 'lib/stripe/params/quote_create_params.rb', line 689

def tax_rates
  @tax_rates
end

Class Method Details

.field_encodingsObject



699
700
701
702
703
# File 'lib/stripe/params/quote_create_params.rb', line 699

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end