Class: Stripe::QuoteCreateParams::LineItem

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



679
680
681
682
683
684
685
# File 'lib/stripe/params/quote_create_params.rb', line 679

def initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil)
  @discounts = discounts
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The discounts applied to this line item.



669
670
671
# File 'lib/stripe/params/quote_create_params.rb', line 669

def discounts
  @discounts
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



671
672
673
# File 'lib/stripe/params/quote_create_params.rb', line 671

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.



673
674
675
# File 'lib/stripe/params/quote_create_params.rb', line 673

def price_data
  @price_data
end

#quantityObject

The quantity of the line item.



675
676
677
# File 'lib/stripe/params/quote_create_params.rb', line 675

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the quote do not apply to this line item.



677
678
679
# File 'lib/stripe/params/quote_create_params.rb', line 677

def tax_rates
  @tax_rates
end