Class: Stripe::QuoteCreateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::LineItem
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to this line item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
-
#quantity ⇒ Object
The quantity of the line item.
-
#tax_rates ⇒ Object
The tax rates which apply to the line item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
Returns a new instance of LineItem.
151 152 153 154 155 156 157 |
# File 'lib/stripe/params/quote_create_params.rb', line 151 def initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) @discounts = discounts @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to this line item.
141 142 143 |
# File 'lib/stripe/params/quote_create_params.rb', line 141 def discounts @discounts end |
#price ⇒ Object
The ID of the price object. One of price or price_data is required.
143 144 145 |
# File 'lib/stripe/params/quote_create_params.rb', line 143 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of price or price_data is required.
145 146 147 |
# File 'lib/stripe/params/quote_create_params.rb', line 145 def price_data @price_data end |
#quantity ⇒ Object
The quantity of the line item.
147 148 149 |
# File 'lib/stripe/params/quote_create_params.rb', line 147 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the line item. When set, the default_tax_rates on the quote do not apply to this line item.
149 150 151 |
# File 'lib/stripe/params/quote_create_params.rb', line 149 def tax_rates @tax_rates end |
Class Method Details
.field_encodings ⇒ Object
159 160 161 162 163 |
# File 'lib/stripe/params/quote_create_params.rb', line 159 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |