Class: Stripe::QuoteCreateParams::LineItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



619
620
621
622
623
624
# File 'lib/stripe/params/quote_create_params.rb', line 619

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



611
612
613
# File 'lib/stripe/params/quote_create_params.rb', line 611

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



613
614
615
# File 'lib/stripe/params/quote_create_params.rb', line 613

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



615
616
617
# File 'lib/stripe/params/quote_create_params.rb', line 615

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



617
618
619
# File 'lib/stripe/params/quote_create_params.rb', line 617

def promotion_code
  @promotion_code
end