Class: Stripe::QuoteCreateParams::LineItem::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::LineItem::Discount::DiscountEnd
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
612 613 614 615 616 |
# File 'lib/stripe/params/quote_create_params.rb', line 612 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
606 607 608 |
# File 'lib/stripe/params/quote_create_params.rb', line 606 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
608 609 610 |
# File 'lib/stripe/params/quote_create_params.rb', line 608 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
610 611 612 |
# File 'lib/stripe/params/quote_create_params.rb', line 610 def type @type end |