Class: Stripe::QuoteCreateParams::LineItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



812
813
814
815
816
# File 'lib/stripe/params/quote_create_params.rb', line 812

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



806
807
808
# File 'lib/stripe/params/quote_create_params.rb', line 806

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



808
809
810
# File 'lib/stripe/params/quote_create_params.rb', line 808

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



810
811
812
# File 'lib/stripe/params/quote_create_params.rb', line 810

def type
  @type
end