Class: Stripe::QuoteCreateParams::LineItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



604
605
606
607
608
# File 'lib/stripe/params/quote_create_params.rb', line 604

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



598
599
600
# File 'lib/stripe/params/quote_create_params.rb', line 598

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



600
601
602
# File 'lib/stripe/params/quote_create_params.rb', line 600

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



602
603
604
# File 'lib/stripe/params/quote_create_params.rb', line 602

def type
  @type
end