Class: Stripe::QuoteCreateParams::LineItem::PriceData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::LineItem::PriceData
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: Recurring
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter ISO currency code, in lowercase.
- #product ⇒ Object
-
#recurring ⇒ Object
The recurring components of a price such as
intervalandinterval_count. -
#tax_behavior ⇒ Object
Only required if a default tax behavior was not provided in the Stripe Tax settings.
-
#unit_amount ⇒ Object
A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.
-
#unit_amount_decimal ⇒ Object
Same as
unit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(currency: nil, product: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData
constructor
A new instance of PriceData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(currency: nil, product: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData
Returns a new instance of PriceData.
687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 |
# File 'lib/stripe/params/quote_create_params.rb', line 687 def initialize( currency: nil, product: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil ) @currency = currency @product = product @recurring = recurring @tax_behavior = tax_behavior @unit_amount = unit_amount @unit_amount_decimal = unit_amount_decimal end |
Instance Attribute Details
#currency ⇒ Object
Three-letter ISO currency code, in lowercase. Must be a supported currency.
675 676 677 |
# File 'lib/stripe/params/quote_create_params.rb', line 675 def currency @currency end |
#product ⇒ Object
677 678 679 |
# File 'lib/stripe/params/quote_create_params.rb', line 677 def product @product end |
#recurring ⇒ Object
The recurring components of a price such as interval and interval_count.
679 680 681 |
# File 'lib/stripe/params/quote_create_params.rb', line 679 def recurring @recurring end |
#tax_behavior ⇒ Object
Only required if a default tax behavior was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of inclusive, exclusive, or unspecified. Once specified as either inclusive or exclusive, it cannot be changed.
681 682 683 |
# File 'lib/stripe/params/quote_create_params.rb', line 681 def tax_behavior @tax_behavior end |
#unit_amount ⇒ Object
A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.
683 684 685 |
# File 'lib/stripe/params/quote_create_params.rb', line 683 def unit_amount @unit_amount end |
#unit_amount_decimal ⇒ Object
Same as unit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of unit_amount and unit_amount_decimal can be set.
685 686 687 |
# File 'lib/stripe/params/quote_create_params.rb', line 685 def unit_amount_decimal @unit_amount_decimal end |
Class Method Details
.field_encodings ⇒ Object
703 704 705 |
# File 'lib/stripe/params/quote_create_params.rb', line 703 def self.field_encodings @field_encodings = { unit_amount_decimal: :decimal_string } end |