Class: Stripe::QuoteCreateParams::SubscriptionData::BillOnAcceptance::BillUntil::LineEndsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineEndsAt

Returns a new instance of LineEndsAt.



953
954
955
956
# File 'lib/stripe/params/quote_create_params.rb', line 953

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



949
950
951
# File 'lib/stripe/params/quote_create_params.rb', line 949

def id
  @id
end

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



951
952
953
# File 'lib/stripe/params/quote_create_params.rb', line 951

def index
  @index
end