Class: Stripe::QuoteCreateParams::SubscriptionData::BillOnAcceptance::BillUntil::LineEndsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineEndsAt

Returns a new instance of LineEndsAt.



747
748
749
750
# File 'lib/stripe/params/quote_create_params.rb', line 747

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



743
744
745
# File 'lib/stripe/params/quote_create_params.rb', line 743

def id
  @id
end

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



745
746
747
# File 'lib/stripe/params/quote_create_params.rb', line 745

def index
  @index
end