Class: Stripe::QuoteCreateParams::SubscriptionData::BillingMode

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: Flexible

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(flexible: nil, type: nil) ⇒ BillingMode

Returns a new instance of BillingMode.



793
794
795
796
# File 'lib/stripe/params/quote_create_params.rb', line 793

def initialize(flexible: nil, type: nil)
  @flexible = flexible
  @type = type
end

Instance Attribute Details

#flexibleObject

Configure behavior for flexible billing mode.



789
790
791
# File 'lib/stripe/params/quote_create_params.rb', line 789

def flexible
  @flexible
end

#typeObject

Controls the calculation and orchestration of prorations and invoices for subscriptions. If no value is passed, the default is ‘flexible`.



791
792
793
# File 'lib/stripe/params/quote_create_params.rb', line 791

def type
  @type
end