Class: Stripe::QuoteCreateParams::SubscriptionData::BillingSchedule

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: AppliesTo, BillFrom, BillUntil

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(applies_to: nil, bill_from: nil, bill_until: nil, key: nil) ⇒ BillingSchedule

Returns a new instance of BillingSchedule.



1083
1084
1085
1086
1087
1088
# File 'lib/stripe/params/quote_create_params.rb', line 1083

def initialize(applies_to: nil, bill_from: nil, bill_until: nil, key: nil)
  @applies_to = applies_to
  @bill_from = bill_from
  @bill_until = bill_until
  @key = key
end

Instance Attribute Details

#applies_toObject

Configure billing schedule differently for individual subscription items.



1075
1076
1077
# File 'lib/stripe/params/quote_create_params.rb', line 1075

def applies_to
  @applies_to
end

#bill_fromObject

The start of the period to bill from when the Quote is accepted.



1077
1078
1079
# File 'lib/stripe/params/quote_create_params.rb', line 1077

def bill_from
  @bill_from
end

#bill_untilObject

The end of the period to bill until when the Quote is accepted.



1079
1080
1081
# File 'lib/stripe/params/quote_create_params.rb', line 1079

def bill_until
  @bill_until
end

#keyObject

Specify a key for the billing schedule. Must be unique to this field, alphanumeric, and up to 200 characters. If not provided, a unique key will be generated.



1081
1082
1083
# File 'lib/stripe/params/quote_create_params.rb', line 1081

def key
  @key
end