Class: Stripe::QuoteCreateParams::SubscriptionData::BillingSchedule

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: AppliesTo, BillFrom, BillUntil

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(applies_to: nil, bill_from: nil, bill_until: nil, key: nil) ⇒ BillingSchedule

Returns a new instance of BillingSchedule.



887
888
889
890
891
892
# File 'lib/stripe/params/quote_create_params.rb', line 887

def initialize(applies_to: nil, bill_from: nil, bill_until: nil, key: nil)
  @applies_to = applies_to
  @bill_from = bill_from
  @bill_until = bill_until
  @key = key
end

Instance Attribute Details

#applies_toObject

Configure billing schedule differently for individual subscription items.



879
880
881
# File 'lib/stripe/params/quote_create_params.rb', line 879

def applies_to
  @applies_to
end

#bill_fromObject

The start of the period to bill from when the Quote is accepted.



881
882
883
# File 'lib/stripe/params/quote_create_params.rb', line 881

def bill_from
  @bill_from
end

#bill_untilObject

The end of the period to bill until when the Quote is accepted.



883
884
885
# File 'lib/stripe/params/quote_create_params.rb', line 883

def bill_until
  @bill_until
end

#keyObject

Specify a key for the billing schedule. Must be unique to this field, alphanumeric, and up to 200 characters. If not provided, a unique key will be generated.



885
886
887
# File 'lib/stripe/params/quote_create_params.rb', line 885

def key
  @key
end