Class: Stripe::QuoteCreateParams::SubscriptionData::BillingSchedule::BillFrom::LineStartsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineStartsAt

Returns a new instance of LineStartsAt.



1015
1016
1017
1018
# File 'lib/stripe/params/quote_create_params.rb', line 1015

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



1011
1012
1013
# File 'lib/stripe/params/quote_create_params.rb', line 1011

def id
  @id
end

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



1013
1014
1015
# File 'lib/stripe/params/quote_create_params.rb', line 1013

def index
  @index
end