Class: Stripe::QuoteCreateParams::SubscriptionData::BillingSchedule::BillFrom::LineStartsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::SubscriptionData::BillingSchedule::BillFrom::LineStartsAt
- Defined in:
- lib/stripe/params/quote_create_params.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of a quote line.
-
#index ⇒ Object
The position of the previous quote line in the ‘lines` array after which this line should begin.
Instance Method Summary collapse
-
#initialize(id: nil, index: nil) ⇒ LineStartsAt
constructor
A new instance of LineStartsAt.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, index: nil) ⇒ LineStartsAt
Returns a new instance of LineStartsAt.
807 808 809 810 |
# File 'lib/stripe/params/quote_create_params.rb', line 807 def initialize(id: nil, index: nil) @id = id @index = index end |
Instance Attribute Details
#id ⇒ Object
The ID of a quote line.
803 804 805 |
# File 'lib/stripe/params/quote_create_params.rb', line 803 def id @id end |
#index ⇒ Object
The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.
805 806 807 |
# File 'lib/stripe/params/quote_create_params.rb', line 805 def index @index end |