Class: Stripe::QuoteCreateParams::SubscriptionData::BillingSchedule::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::SubscriptionData::BillingSchedule::BillUntil
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: Duration, LineEndsAt
Instance Attribute Summary collapse
-
#duration ⇒ Object
Details of the duration over which to bill.
-
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
Instance Method Summary collapse
-
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
859 860 861 862 863 864 |
# File 'lib/stripe/params/quote_create_params.rb', line 859 def initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) @duration = duration @line_ends_at = line_ends_at @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Details of the duration over which to bill.
851 852 853 |
# File 'lib/stripe/params/quote_create_params.rb', line 851 def duration @duration end |
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
853 854 855 |
# File 'lib/stripe/params/quote_create_params.rb', line 853 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
855 856 857 |
# File 'lib/stripe/params/quote_create_params.rb', line 855 def @timestamp end |
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
857 858 859 |
# File 'lib/stripe/params/quote_create_params.rb', line 857 def type @type end |