Class: Stripe::QuoteCreateParams::SubscriptionData::BillingSchedule::BillUntil::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



1051
1052
1053
1054
# File 'lib/stripe/params/quote_create_params.rb', line 1051

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1047
1048
1049
# File 'lib/stripe/params/quote_create_params.rb', line 1047

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1049
1050
1051
# File 'lib/stripe/params/quote_create_params.rb', line 1049

def interval_count
  @interval_count
end