Class: Stripe::QuoteCreateParams::SubscriptionData::BillingSchedule::BillUntil::LineEndsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineEndsAt

Returns a new instance of LineEndsAt.



1053
1054
1055
1056
# File 'lib/stripe/params/quote_create_params.rb', line 1053

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



1049
1050
1051
# File 'lib/stripe/params/quote_create_params.rb', line 1049

def id
  @id
end

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



1051
1052
1053
# File 'lib/stripe/params/quote_create_params.rb', line 1051

def index
  @index
end