Class: Stripe::QuoteCreateParams::SubscriptionData::BillingSchedule::BillUntil::LineEndsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineEndsAt

Returns a new instance of LineEndsAt.



845
846
847
848
# File 'lib/stripe/params/quote_create_params.rb', line 845

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



841
842
843
# File 'lib/stripe/params/quote_create_params.rb', line 841

def id
  @id
end

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



843
844
845
# File 'lib/stripe/params/quote_create_params.rb', line 843

def index
  @index
end