Class: Stripe::QuoteCreateParams::SubscriptionData::Prebilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::SubscriptionData::Prebilling
- Defined in:
- lib/stripe/params/quote_create_params.rb
Instance Attribute Summary collapse
-
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
Instance Method Summary collapse
-
#initialize(iterations: nil) ⇒ Prebilling
constructor
A new instance of Prebilling.
Methods inherited from RequestParams
Constructor Details
#initialize(iterations: nil) ⇒ Prebilling
Returns a new instance of Prebilling.
1095 1096 1097 |
# File 'lib/stripe/params/quote_create_params.rb', line 1095 def initialize(iterations: nil) @iterations = iterations end |
Instance Attribute Details
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
1093 1094 1095 |
# File 'lib/stripe/params/quote_create_params.rb', line 1093 def iterations @iterations end |