Class: Stripe::QuoteCreateParams::SubscriptionDataOverride
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::SubscriptionDataOverride
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: AppliesTo, BillOnAcceptance, BillingSchedule
Instance Attribute Summary collapse
-
#applies_to ⇒ Object
Whether the override applies to an existing Subscription Schedule or a new Subscription Schedule.
-
#bill_on_acceptance ⇒ Object
Describes the period to bill for upon accepting the quote.
-
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions.
-
#billing_schedules ⇒ Object
Billing schedules that will be applied to the subscription or subscription schedule created when the quote is accepted.
-
#customer ⇒ Object
The customer the Subscription Data override applies to.
-
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer.
-
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
-
#phase_effective_at ⇒ Object
Configures how the subscription schedule handles billing for phase transitions when the quote is accepted.
-
#proration_behavior ⇒ Object
Determines how to handle [prorations](stripe.com/docs/subscriptions/billing-cycle#prorations).
Instance Method Summary collapse
-
#initialize(applies_to: nil, bill_on_acceptance: nil, billing_behavior: nil, billing_schedules: nil, customer: nil, description: nil, end_behavior: nil, phase_effective_at: nil, proration_behavior: nil) ⇒ SubscriptionDataOverride
constructor
A new instance of SubscriptionDataOverride.
Methods inherited from RequestParams
Constructor Details
#initialize(applies_to: nil, bill_on_acceptance: nil, billing_behavior: nil, billing_schedules: nil, customer: nil, description: nil, end_behavior: nil, phase_effective_at: nil, proration_behavior: nil) ⇒ SubscriptionDataOverride
Returns a new instance of SubscriptionDataOverride.
1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 |
# File 'lib/stripe/params/quote_create_params.rb', line 1173 def initialize( applies_to: nil, bill_on_acceptance: nil, billing_behavior: nil, billing_schedules: nil, customer: nil, description: nil, end_behavior: nil, phase_effective_at: nil, proration_behavior: nil ) @applies_to = applies_to @bill_on_acceptance = bill_on_acceptance @billing_behavior = billing_behavior @billing_schedules = billing_schedules @customer = customer @description = description @end_behavior = end_behavior @phase_effective_at = phase_effective_at @proration_behavior = proration_behavior end |
Instance Attribute Details
#applies_to ⇒ Object
Whether the override applies to an existing Subscription Schedule or a new Subscription Schedule.
1149 1150 1151 |
# File 'lib/stripe/params/quote_create_params.rb', line 1149 def applies_to @applies_to end |
#bill_on_acceptance ⇒ Object
Describes the period to bill for upon accepting the quote.
1151 1152 1153 |
# File 'lib/stripe/params/quote_create_params.rb', line 1151 def bill_on_acceptance @bill_on_acceptance end |
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.
1153 1154 1155 |
# File 'lib/stripe/params/quote_create_params.rb', line 1153 def billing_behavior @billing_behavior end |
#billing_schedules ⇒ Object
Billing schedules that will be applied to the subscription or subscription schedule created when the quote is accepted.
1155 1156 1157 |
# File 'lib/stripe/params/quote_create_params.rb', line 1155 def billing_schedules @billing_schedules end |
#customer ⇒ Object
The customer the Subscription Data override applies to. This is only relevant when ‘applies_to.type=new_reference`.
1157 1158 1159 |
# File 'lib/stripe/params/quote_create_params.rb', line 1157 def customer @customer end |
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
1159 1160 1161 |
# File 'lib/stripe/params/quote_create_params.rb', line 1159 def description @description end |
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
1161 1162 1163 |
# File 'lib/stripe/params/quote_create_params.rb', line 1161 def end_behavior @end_behavior end |
#phase_effective_at ⇒ Object
Configures how the subscription schedule handles billing for phase transitions when the quote is accepted. Possible values are ‘phase_start` (default) or `billing_period_start`. `phase_start` bills based on the current state of the subscription, ignoring changes scheduled in future phases. `billing_period_start` bills predictively for upcoming phase transitions within the current billing cycle, including pricing changes and service period adjustments that will occur before the next invoice.
1163 1164 1165 |
# File 'lib/stripe/params/quote_create_params.rb', line 1163 def phase_effective_at @phase_effective_at end |
#proration_behavior ⇒ Object
Determines how to handle [prorations](stripe.com/docs/subscriptions/billing-cycle#prorations). When creating a subscription, valid values are ‘create_prorations` or `none`.
When updating a subscription, valid values are ‘create_prorations`, `none`, or `always_invoice`.
Passing ‘create_prorations` will cause proration invoice items to be created when applicable. These proration items will only be invoiced immediately under [certain conditions](stripe.com/docs/subscriptions/upgrading-downgrading#immediate-payment). In order to always invoice immediately for prorations, pass `always_invoice`.
Prorations can be disabled by passing ‘none`.
1171 1172 1173 |
# File 'lib/stripe/params/quote_create_params.rb', line 1171 def proration_behavior @proration_behavior end |