Class: Stripe::QuoteCreateParams::SubscriptionDataOverride::AppliesTo

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(new_reference: nil, subscription_schedule: nil, type: nil) ⇒ AppliesTo

Returns a new instance of AppliesTo.



1176
1177
1178
1179
1180
# File 'lib/stripe/params/quote_create_params.rb', line 1176

def initialize(new_reference: nil, subscription_schedule: nil, type: nil)
  @new_reference = new_reference
  @subscription_schedule = subscription_schedule
  @type = type
end

Instance Attribute Details

#new_referenceObject

A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same ‘new_reference` field will be applied to the creation of a new subscription schedule.



1170
1171
1172
# File 'lib/stripe/params/quote_create_params.rb', line 1170

def new_reference
  @new_reference
end

#subscription_scheduleObject

The ID of the schedule the line applies to.



1172
1173
1174
# File 'lib/stripe/params/quote_create_params.rb', line 1172

def subscription_schedule
  @subscription_schedule
end

#typeObject

Describes whether the quote line is affecting a new schedule or an existing schedule.



1174
1175
1176
# File 'lib/stripe/params/quote_create_params.rb', line 1174

def type
  @type
end