Class: Stripe::QuoteCreateParams::SubscriptionDataOverride::AppliesTo

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(new_reference: nil, subscription_schedule: nil, type: nil) ⇒ AppliesTo

Returns a new instance of AppliesTo.



968
969
970
971
972
# File 'lib/stripe/params/quote_create_params.rb', line 968

def initialize(new_reference: nil, subscription_schedule: nil, type: nil)
  @new_reference = new_reference
  @subscription_schedule = subscription_schedule
  @type = type
end

Instance Attribute Details

#new_referenceObject

A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same ‘new_reference` field will be applied to the creation of a new subscription schedule.



962
963
964
# File 'lib/stripe/params/quote_create_params.rb', line 962

def new_reference
  @new_reference
end

#subscription_scheduleObject

The ID of the schedule the line applies to.



964
965
966
# File 'lib/stripe/params/quote_create_params.rb', line 964

def subscription_schedule
  @subscription_schedule
end

#typeObject

Describes whether the quote line is affecting a new schedule or an existing schedule.



966
967
968
# File 'lib/stripe/params/quote_create_params.rb', line 966

def type
  @type
end