Class: Stripe::QuoteCreateParams::SubscriptionDataOverride::BillOnAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::SubscriptionDataOverride::BillOnAcceptance
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#bill_from ⇒ Object
The start of the period to bill from when the Quote is accepted.
-
#bill_until ⇒ Object
The end of the period to bill until when the Quote is accepted.
Instance Method Summary collapse
-
#initialize(bill_from: nil, bill_until: nil) ⇒ BillOnAcceptance
constructor
A new instance of BillOnAcceptance.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bill_from: nil, bill_until: nil) ⇒ BillOnAcceptance
Returns a new instance of BillOnAcceptance.
1265 1266 1267 1268 |
# File 'lib/stripe/params/quote_create_params.rb', line 1265 def initialize(bill_from: nil, bill_until: nil) @bill_from = bill_from @bill_until = bill_until end |
Instance Attribute Details
#bill_from ⇒ Object
The start of the period to bill from when the Quote is accepted.
1261 1262 1263 |
# File 'lib/stripe/params/quote_create_params.rb', line 1261 def bill_from @bill_from end |
#bill_until ⇒ Object
The end of the period to bill until when the Quote is accepted.
1263 1264 1265 |
# File 'lib/stripe/params/quote_create_params.rb', line 1263 def bill_until @bill_until end |