Class: Stripe::QuoteCreateParams::SubscriptionDataOverride::BillOnAcceptance::BillFrom::LineStartsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineStartsAt

Returns a new instance of LineStartsAt.



897
898
899
900
# File 'lib/stripe/params/quote_create_params.rb', line 897

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



893
894
895
# File 'lib/stripe/params/quote_create_params.rb', line 893

def id
  @id
end

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



895
896
897
# File 'lib/stripe/params/quote_create_params.rb', line 895

def index
  @index
end