Class: Stripe::QuoteCreateParams::SubscriptionDataOverride::BillOnAcceptance::BillUntil::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



1217
1218
1219
1220
# File 'lib/stripe/params/quote_create_params.rb', line 1217

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1213
1214
1215
# File 'lib/stripe/params/quote_create_params.rb', line 1213

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1215
1216
1217
# File 'lib/stripe/params/quote_create_params.rb', line 1215

def interval_count
  @interval_count
end