Class: Stripe::QuoteCreateParams::SubscriptionDataOverride::BillOnAcceptance::BillUntil::LineEndsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineEndsAt

Returns a new instance of LineEndsAt.



1021
1022
1023
1024
# File 'lib/stripe/params/quote_create_params.rb', line 1021

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



1017
1018
1019
# File 'lib/stripe/params/quote_create_params.rb', line 1017

def id
  @id
end

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



1019
1020
1021
# File 'lib/stripe/params/quote_create_params.rb', line 1019

def index
  @index
end