Class: Stripe::QuoteCreateParams::SubscriptionDataOverride::BillingSchedule

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_create_params.rb

Defined Under Namespace

Classes: AppliesTo, BillFrom, BillUntil

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(applies_to: nil, bill_from: nil, bill_until: nil, key: nil) ⇒ BillingSchedule

Returns a new instance of BillingSchedule.



1359
1360
1361
1362
1363
1364
# File 'lib/stripe/params/quote_create_params.rb', line 1359

def initialize(applies_to: nil, bill_from: nil, bill_until: nil, key: nil)
  @applies_to = applies_to
  @bill_from = bill_from
  @bill_until = bill_until
  @key = key
end

Instance Attribute Details

#applies_toObject

Configure billing schedule differently for individual subscription items.



1351
1352
1353
# File 'lib/stripe/params/quote_create_params.rb', line 1351

def applies_to
  @applies_to
end

#bill_fromObject

The start of the period to bill from when the Quote is accepted.



1353
1354
1355
# File 'lib/stripe/params/quote_create_params.rb', line 1353

def bill_from
  @bill_from
end

#bill_untilObject

The end of the period to bill until when the Quote is accepted.



1355
1356
1357
# File 'lib/stripe/params/quote_create_params.rb', line 1355

def bill_until
  @bill_until
end

#keyObject

Specify a key for the billing schedule. Must be unique to this field, alphanumeric, and up to 200 characters. If not provided, a unique key will be generated.



1357
1358
1359
# File 'lib/stripe/params/quote_create_params.rb', line 1357

def key
  @key
end