Class: Stripe::QuoteCreateParams::SubscriptionDataOverride::BillingSchedule
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::SubscriptionDataOverride::BillingSchedule
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: AppliesTo, BillFrom, BillUntil
Instance Attribute Summary collapse
-
#applies_to ⇒ Object
Configure billing schedule differently for individual subscription items.
-
#bill_from ⇒ Object
The start of the period to bill from when the Quote is accepted.
-
#bill_until ⇒ Object
The end of the period to bill until when the Quote is accepted.
-
#key ⇒ Object
Specify a key for the billing schedule.
Instance Method Summary collapse
-
#initialize(applies_to: nil, bill_from: nil, bill_until: nil, key: nil) ⇒ BillingSchedule
constructor
A new instance of BillingSchedule.
Methods inherited from RequestParams
Constructor Details
#initialize(applies_to: nil, bill_from: nil, bill_until: nil, key: nil) ⇒ BillingSchedule
Returns a new instance of BillingSchedule.
1349 1350 1351 1352 1353 1354 |
# File 'lib/stripe/params/quote_create_params.rb', line 1349 def initialize(applies_to: nil, bill_from: nil, bill_until: nil, key: nil) @applies_to = applies_to @bill_from = bill_from @bill_until = bill_until @key = key end |
Instance Attribute Details
#applies_to ⇒ Object
Configure billing schedule differently for individual subscription items.
1341 1342 1343 |
# File 'lib/stripe/params/quote_create_params.rb', line 1341 def applies_to @applies_to end |
#bill_from ⇒ Object
The start of the period to bill from when the Quote is accepted.
1343 1344 1345 |
# File 'lib/stripe/params/quote_create_params.rb', line 1343 def bill_from @bill_from end |
#bill_until ⇒ Object
The end of the period to bill until when the Quote is accepted.
1345 1346 1347 |
# File 'lib/stripe/params/quote_create_params.rb', line 1345 def bill_until @bill_until end |
#key ⇒ Object
Specify a key for the billing schedule. Must be unique to this field, alphanumeric, and up to 200 characters. If not provided, a unique key will be generated.
1347 1348 1349 |
# File 'lib/stripe/params/quote_create_params.rb', line 1347 def key @key end |