Class: Stripe::QuoteCreateParams::SubscriptionDataOverride::BillingSchedule::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteCreateParams::SubscriptionDataOverride::BillingSchedule::BillUntil
- Defined in:
- lib/stripe/params/quote_create_params.rb
Defined Under Namespace
Classes: Duration, LineEndsAt
Instance Attribute Summary collapse
-
#duration ⇒ Object
Details of the duration over which to bill.
-
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
Instance Method Summary collapse
-
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
1333 1334 1335 1336 1337 1338 |
# File 'lib/stripe/params/quote_create_params.rb', line 1333 def initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) @duration = duration @line_ends_at = line_ends_at @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Details of the duration over which to bill.
1325 1326 1327 |
# File 'lib/stripe/params/quote_create_params.rb', line 1325 def duration @duration end |
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
1327 1328 1329 |
# File 'lib/stripe/params/quote_create_params.rb', line 1327 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
1329 1330 1331 |
# File 'lib/stripe/params/quote_create_params.rb', line 1329 def @timestamp end |
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
1331 1332 1333 |
# File 'lib/stripe/params/quote_create_params.rb', line 1331 def type @type end |