Class: Stripe::QuoteCreateParams::TransferData

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1449
1450
1451
1452
1453
# File 'lib/stripe/params/quote_create_params.rb', line 1449

def initialize(amount: nil, amount_percent: nil, destination: nil)
  @amount = amount
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



1443
1444
1445
# File 'lib/stripe/params/quote_create_params.rb', line 1443

def amount
  @amount
end

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination. There must be at least 1 line item with a recurring price to use this field.



1445
1446
1447
# File 'lib/stripe/params/quote_create_params.rb', line 1445

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



1447
1448
1449
# File 'lib/stripe/params/quote_create_params.rb', line 1447

def destination
  @destination
end