Class: Stripe::QuoteCreateParams::TransferData

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1422
1423
1424
1425
1426
# File 'lib/stripe/params/quote_create_params.rb', line 1422

def initialize(amount: nil, amount_percent: nil, destination: nil)
  @amount = amount
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



1416
1417
1418
# File 'lib/stripe/params/quote_create_params.rb', line 1416

def amount
  @amount
end

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination. There must be at least 1 line item with a recurring price to use this field.



1418
1419
1420
# File 'lib/stripe/params/quote_create_params.rb', line 1418

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



1420
1421
1422
# File 'lib/stripe/params/quote_create_params.rb', line 1420

def destination
  @destination
end