Class: Stripe::QuoteCreateParams::TransferData

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1014
1015
1016
1017
1018
# File 'lib/stripe/params/quote_create_params.rb', line 1014

def initialize(amount: nil, amount_percent: nil, destination: nil)
  @amount = amount
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



1008
1009
1010
# File 'lib/stripe/params/quote_create_params.rb', line 1008

def amount
  @amount
end

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination. There must be at least 1 line item with a recurring price to use this field.



1010
1011
1012
# File 'lib/stripe/params/quote_create_params.rb', line 1010

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



1012
1013
1014
# File 'lib/stripe/params/quote_create_params.rb', line 1012

def destination
  @destination
end