Class: Stripe::QuoteLine::Action::AddDiscount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuoteLine::Action::AddDiscount
- Defined in:
- lib/stripe/resources/quote_line.rb
Defined Under Namespace
Classes: DiscountEnd, Settings
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#coupon ⇒ Object
readonly
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
readonly
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
readonly
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
readonly
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
readonly
ID of the promotion code to create a new discount for.
-
#settings ⇒ Object
readonly
Attribute for field settings.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#coupon ⇒ Object (readonly)
ID of the coupon to create a new discount for.
76 77 78 |
# File 'lib/stripe/resources/quote_line.rb', line 76 def coupon @coupon end |
#discount ⇒ Object (readonly)
ID of an existing discount on the object (or one of its ancestors) to reuse.
78 79 80 |
# File 'lib/stripe/resources/quote_line.rb', line 78 def discount @discount end |
#discount_end ⇒ Object (readonly)
Details to determine how long the discount should be applied for.
80 81 82 |
# File 'lib/stripe/resources/quote_line.rb', line 80 def discount_end @discount_end end |
#index ⇒ Object (readonly)
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the discounts array.
82 83 84 |
# File 'lib/stripe/resources/quote_line.rb', line 82 def index @index end |
#promotion_code ⇒ Object (readonly)
ID of the promotion code to create a new discount for.
84 85 86 |
# File 'lib/stripe/resources/quote_line.rb', line 84 def promotion_code @promotion_code end |
#settings ⇒ Object (readonly)
Attribute for field settings
86 87 88 |
# File 'lib/stripe/resources/quote_line.rb', line 86 def settings @settings end |
Class Method Details
.field_remappings ⇒ Object
92 93 94 |
# File 'lib/stripe/resources/quote_line.rb', line 92 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
88 89 90 |
# File 'lib/stripe/resources/quote_line.rb', line 88 def self.inner_class_types @inner_class_types = { discount_end: DiscountEnd, settings: Settings } end |