Class: Stripe::QuoteLine::Action::AddDiscount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_line.rb

Defined Under Namespace

Classes: DiscountEnd

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#couponObject (readonly)

ID of the coupon to create a new discount for.



27
28
29
# File 'lib/stripe/resources/quote_line.rb', line 27

def coupon
  @coupon
end

#discountObject (readonly)

ID of an existing discount on the object (or one of its ancestors) to reuse.



29
30
31
# File 'lib/stripe/resources/quote_line.rb', line 29

def discount
  @discount
end

#discount_endObject (readonly)

Details to determine how long the discount should be applied for.



31
32
33
# File 'lib/stripe/resources/quote_line.rb', line 31

def discount_end
  @discount_end
end

#indexObject (readonly)

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



33
34
35
# File 'lib/stripe/resources/quote_line.rb', line 33

def index
  @index
end

#promotion_codeObject (readonly)

ID of the promotion code to create a new discount for.



35
36
37
# File 'lib/stripe/resources/quote_line.rb', line 35

def promotion_code
  @promotion_code
end

Class Method Details

.field_remappingsObject



41
42
43
# File 'lib/stripe/resources/quote_line.rb', line 41

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



37
38
39
# File 'lib/stripe/resources/quote_line.rb', line 37

def self.inner_class_types
  @inner_class_types = { discount_end: DiscountEnd }
end