Class: Stripe::QuoteLine::Action::AddDiscount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuoteLine::Action::AddDiscount
- Defined in:
- lib/stripe/resources/quote_line.rb
Defined Under Namespace
Classes: DiscountEnd
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#coupon ⇒ Object
readonly
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
readonly
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
readonly
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
readonly
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
readonly
ID of the promotion code to create a new discount for.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#coupon ⇒ Object (readonly)
ID of the coupon to create a new discount for.
19 20 21 |
# File 'lib/stripe/resources/quote_line.rb', line 19 def coupon @coupon end |
#discount ⇒ Object (readonly)
ID of an existing discount on the object (or one of its ancestors) to reuse.
22 23 24 |
# File 'lib/stripe/resources/quote_line.rb', line 22 def discount @discount end |
#discount_end ⇒ Object (readonly)
Details to determine how long the discount should be applied for.
25 26 27 |
# File 'lib/stripe/resources/quote_line.rb', line 25 def discount_end @discount_end end |
#index ⇒ Object (readonly)
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
28 29 30 |
# File 'lib/stripe/resources/quote_line.rb', line 28 def index @index end |
#promotion_code ⇒ Object (readonly)
ID of the promotion code to create a new discount for.
31 32 33 |
# File 'lib/stripe/resources/quote_line.rb', line 31 def promotion_code @promotion_code end |