Class: Stripe::QuoteLine::Action::AddItem

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/quote_line.rb

Defined Under Namespace

Classes: Discount, Trial

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#discountsObject (readonly)

The discounts applied to the subscription item. Subscription item discounts are applied before subscription discounts. Use ‘expand[]=discounts` to expand each discount.



55
56
57
# File 'lib/stripe/resources/quote_line.rb', line 55

def discounts
  @discounts
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an item. Metadata on this item will update the underlying subscription item’s ‘metadata` when the phase is entered.



57
58
59
# File 'lib/stripe/resources/quote_line.rb', line 57

def 
  @metadata
end

#priceObject (readonly)

ID of the price to which the customer should be subscribed.



59
60
61
# File 'lib/stripe/resources/quote_line.rb', line 59

def price
  @price
end

#quantityObject (readonly)

Quantity of the plan to which the customer should be subscribed.



61
62
63
# File 'lib/stripe/resources/quote_line.rb', line 61

def quantity
  @quantity
end

#tax_ratesObject (readonly)

The tax rates which apply to this ‘phase_item`. When set, the `default_tax_rates` on the phase do not apply to this `phase_item`.



63
64
65
# File 'lib/stripe/resources/quote_line.rb', line 63

def tax_rates
  @tax_rates
end

#trialObject (readonly)

Options that configure the trial on the subscription item.



65
66
67
# File 'lib/stripe/resources/quote_line.rb', line 65

def trial
  @trial
end