Class: Stripe::QuoteLine::Action::RemoveDiscount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuoteLine::Action::RemoveDiscount
- Defined in:
- lib/stripe/resources/quote_line.rb
Defined Under Namespace
Classes: DiscountEnd
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#coupon ⇒ Object
readonly
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
readonly
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
readonly
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
readonly
ID of the promotion code to create a new discount for.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#coupon ⇒ Object (readonly)
ID of the coupon to create a new discount for.
134 135 136 |
# File 'lib/stripe/resources/quote_line.rb', line 134 def coupon @coupon end |
#discount ⇒ Object (readonly)
ID of an existing discount on the object (or one of its ancestors) to reuse.
136 137 138 |
# File 'lib/stripe/resources/quote_line.rb', line 136 def discount @discount end |
#discount_end ⇒ Object (readonly)
Details to determine how long the discount should be applied for.
138 139 140 |
# File 'lib/stripe/resources/quote_line.rb', line 138 def discount_end @discount_end end |
#promotion_code ⇒ Object (readonly)
ID of the promotion code to create a new discount for.
140 141 142 |
# File 'lib/stripe/resources/quote_line.rb', line 140 def promotion_code @promotion_code end |
Class Method Details
.field_remappings ⇒ Object
146 147 148 |
# File 'lib/stripe/resources/quote_line.rb', line 146 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
142 143 144 |
# File 'lib/stripe/resources/quote_line.rb', line 142 def self.inner_class_types @inner_class_types = { discount_end: DiscountEnd } end |