Class: Stripe::QuoteLine::CancelSubscriptionSchedule
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuoteLine::CancelSubscriptionSchedule
- Defined in:
- lib/stripe/resources/quote_line.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#cancel_at ⇒ Object
readonly
Timestamp helper to cancel the underlying schedule on the accompanying line’s start date.
-
#invoice_now ⇒ Object
readonly
If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items.
-
#prorate ⇒ Object
readonly
If the subscription schedule is ‘active`, indicates if the cancellation should be prorated.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#cancel_at ⇒ Object (readonly)
Timestamp helper to cancel the underlying schedule on the accompanying line’s start date. Must be set to ‘line_starts_at`.
324 325 326 |
# File 'lib/stripe/resources/quote_line.rb', line 324 def cancel_at @cancel_at end |
#invoice_now ⇒ Object (readonly)
If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items. Boolean that defaults to `true`.
326 327 328 |
# File 'lib/stripe/resources/quote_line.rb', line 326 def invoice_now @invoice_now end |
#prorate ⇒ Object (readonly)
If the subscription schedule is ‘active`, indicates if the cancellation should be prorated. Boolean that defaults to `true`.
328 329 330 |
# File 'lib/stripe/resources/quote_line.rb', line 328 def prorate @prorate end |
Class Method Details
.field_remappings ⇒ Object
334 335 336 |
# File 'lib/stripe/resources/quote_line.rb', line 334 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
330 331 332 |
# File 'lib/stripe/resources/quote_line.rb', line 330 def self.inner_class_types @inner_class_types = {} end |