Class: Stripe::QuoteLine::CancelSubscriptionSchedule

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_line.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#cancel_atObject (readonly)

Timestamp helper to cancel the underlying schedule on the accompanying line’s start date. Must be set to ‘line_starts_at`.



177
178
179
# File 'lib/stripe/resources/quote_line.rb', line 177

def cancel_at
  @cancel_at
end

#invoice_nowObject (readonly)

If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items. Boolean that defaults to `true`.



179
180
181
# File 'lib/stripe/resources/quote_line.rb', line 179

def invoice_now
  @invoice_now
end

#prorateObject (readonly)

If the subscription schedule is ‘active`, indicates if the cancellation should be prorated. Boolean that defaults to `true`.



181
182
183
# File 'lib/stripe/resources/quote_line.rb', line 181

def prorate
  @prorate
end