Class: Stripe::QuoteLine::SetPauseCollection

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/quote_line.rb

Defined Under Namespace

Classes: Set

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#setObject (readonly)

If specified, payment collection for this subscription will be paused. Note that the subscription status will be unchanged and will not be updated to ‘paused`. Learn more about [pausing collection](docs.stripe.com/billing/subscriptions/pause-payment).



605
606
607
# File 'lib/stripe/resources/quote_line.rb', line 605

def set
  @set
end

#typeObject (readonly)

Defines the type of the pause_collection behavior for the quote line.



607
608
609
# File 'lib/stripe/resources/quote_line.rb', line 607

def type
  @type
end

Class Method Details

.field_remappingsObject



613
614
615
# File 'lib/stripe/resources/quote_line.rb', line 613

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



609
610
611
# File 'lib/stripe/resources/quote_line.rb', line 609

def self.inner_class_types
  @inner_class_types = { set: Set }
end