Class: Stripe::QuoteLine::SetPauseCollection

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/quote_line.rb

Defined Under Namespace

Classes: Set

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#setObject (readonly)

If specified, payment collection for this subscription will be paused. Note that the subscription status will be unchanged and will not be updated to ‘paused`. Learn more about [pausing collection](stripe.com/docs/billing/subscriptions/pause-payment).



214
215
216
# File 'lib/stripe/resources/quote_line.rb', line 214

def set
  @set
end

#typeObject (readonly)

Defines the type of the pause_collection behavior for the quote line.



216
217
218
# File 'lib/stripe/resources/quote_line.rb', line 216

def type
  @type
end