Class: Stripe::QuoteLine::StartsAt
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuoteLine::StartsAt
- Defined in:
- lib/stripe/resources/quote_line.rb
Defined Under Namespace
Classes: DiscountEnd, LineEndsAt
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#computed ⇒ Object
readonly
The timestamp value that will be used to determine when to make changes to the subscription schedule, as computed from the ‘starts_at` field.
-
#discount_end ⇒ Object
readonly
Use the ‘end` time of a given discount.
-
#line_ends_at ⇒ Object
readonly
The timestamp the given line ends at.
-
#timestamp ⇒ Object
readonly
A precise Unix timestamp.
-
#type ⇒ Object
readonly
Select a way to pass in ‘starts_at`.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#computed ⇒ Object (readonly)
The timestamp value that will be used to determine when to make changes to the subscription schedule, as computed from the ‘starts_at` field. For example, if `starts_at=upcoming_invoice`, the upcoming invoice date will be computed at the time the `starts_at` field was specified and saved. This field will not be recomputed upon future requests to update or finalize the quote unless `starts_at` is respecified. This field is guaranteed to be populated after quote acceptance.
441 442 443 |
# File 'lib/stripe/resources/quote_line.rb', line 441 def computed @computed end |
#discount_end ⇒ Object (readonly)
Use the ‘end` time of a given discount.
443 444 445 |
# File 'lib/stripe/resources/quote_line.rb', line 443 def discount_end @discount_end end |
#line_ends_at ⇒ Object (readonly)
The timestamp the given line ends at.
445 446 447 |
# File 'lib/stripe/resources/quote_line.rb', line 445 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object (readonly)
A precise Unix timestamp.
447 448 449 |
# File 'lib/stripe/resources/quote_line.rb', line 447 def @timestamp end |
#type ⇒ Object (readonly)
Select a way to pass in ‘starts_at`.
449 450 451 |
# File 'lib/stripe/resources/quote_line.rb', line 449 def type @type end |
Class Method Details
.field_remappings ⇒ Object
455 456 457 |
# File 'lib/stripe/resources/quote_line.rb', line 455 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
451 452 453 |
# File 'lib/stripe/resources/quote_line.rb', line 451 def self.inner_class_types @inner_class_types = { discount_end: DiscountEnd, line_ends_at: LineEndsAt } end |