Class: Stripe::QuoteLine::StartsAt

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/quote_line.rb

Defined Under Namespace

Classes: DiscountEnd, LineEndsAt

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#computedObject (readonly)

The timestamp value that will be used to determine when to make changes to the subscription schedule, as computed from the ‘starts_at` field. For example, if `starts_at=upcoming_invoice`, the upcoming invoice date will be computed at the time the `starts_at` field was specified and saved. This field will not be recomputed upon future requests to update or finalize the quote unless `starts_at` is respecified. This field is guaranteed to be populated after quote acceptance.



645
646
647
# File 'lib/stripe/resources/quote_line.rb', line 645

def computed
  @computed
end

#discount_endObject (readonly)

Use the ‘end` time of a given discount.



647
648
649
# File 'lib/stripe/resources/quote_line.rb', line 647

def discount_end
  @discount_end
end

#line_ends_atObject (readonly)

The timestamp the given line ends at.



649
650
651
# File 'lib/stripe/resources/quote_line.rb', line 649

def line_ends_at
  @line_ends_at
end

#timestampObject (readonly)

A precise Unix timestamp.



651
652
653
# File 'lib/stripe/resources/quote_line.rb', line 651

def timestamp
  @timestamp
end

#typeObject (readonly)

Select a way to pass in ‘starts_at`.



653
654
655
# File 'lib/stripe/resources/quote_line.rb', line 653

def type
  @type
end

Class Method Details

.field_remappingsObject



659
660
661
# File 'lib/stripe/resources/quote_line.rb', line 659

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



655
656
657
# File 'lib/stripe/resources/quote_line.rb', line 655

def self.inner_class_types
  @inner_class_types = { discount_end: DiscountEnd, line_ends_at: LineEndsAt }
end