Class: Stripe::QuoteLine::StartsAt
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuoteLine::StartsAt
- Defined in:
- lib/stripe/resources/quote_line.rb
Defined Under Namespace
Classes: DiscountEnd, LineEndsAt
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#computed ⇒ Object
readonly
The timestamp value that will be used to determine when to make changes to the subscription schedule, as computed from the ‘starts_at` field.
-
#discount_end ⇒ Object
readonly
Use the ‘end` time of a given discount.
-
#line_ends_at ⇒ Object
readonly
The timestamp the given line ends at.
-
#timestamp ⇒ Object
readonly
A precise Unix timestamp.
-
#type ⇒ Object
readonly
Select a way to pass in ‘starts_at`.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#computed ⇒ Object (readonly)
The timestamp value that will be used to determine when to make changes to the subscription schedule, as computed from the ‘starts_at` field. For example, if `starts_at=upcoming_invoice`, the upcoming invoice date will be computed at the time the `starts_at` field was specified and saved. This field will not be recomputed upon future requests to update or finalize the quote unless `starts_at` is respecified. This field is guaranteed to be populated after quote acceptance.
230 231 232 |
# File 'lib/stripe/resources/quote_line.rb', line 230 def computed @computed end |
#discount_end ⇒ Object (readonly)
Use the ‘end` time of a given discount.
232 233 234 |
# File 'lib/stripe/resources/quote_line.rb', line 232 def discount_end @discount_end end |
#line_ends_at ⇒ Object (readonly)
The timestamp the given line ends at.
234 235 236 |
# File 'lib/stripe/resources/quote_line.rb', line 234 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object (readonly)
A precise Unix timestamp.
236 237 238 |
# File 'lib/stripe/resources/quote_line.rb', line 236 def @timestamp end |
#type ⇒ Object (readonly)
Select a way to pass in ‘starts_at`.
238 239 240 |
# File 'lib/stripe/resources/quote_line.rb', line 238 def type @type end |