Class: Stripe::QuoteLineService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::QuoteLineService
- Defined in:
- lib/stripe/services/quote_line_service.rb
Defined Under Namespace
Classes: ListParams
Instance Method Summary collapse
-
#list(quote, params = {}, opts = {}) ⇒ Object
Retrieves a paginated list of lines for a quote.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#list(quote, params = {}, opts = {}) ⇒ Object
Retrieves a paginated list of lines for a quote. These lines describe changes that will be used to create new subscription schedules or update existing subscription schedules when the quote is accepted.
25 26 27 28 29 30 31 32 33 |
# File 'lib/stripe/services/quote_line_service.rb', line 25 def list(quote, params = {}, opts = {}) request( method: :get, path: format("/v1/quotes/%<quote>s/lines", { quote: CGI.escape(quote) }), params: params, opts: opts, base_address: :api ) end |