Class: Stripe::QuotePreviewInvoice

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/quote_preview_invoice.rb

Overview

Invoices are statements of amounts owed by a customer, and are either generated one-off, or generated periodically from a subscription.

They contain [invoice items](stripe.com/docs/api#invoiceitems), and proration adjustments that may be caused by subscription upgrades/downgrades (if necessary).

If your invoice is configured to be billed through automatic charges, Stripe automatically finalizes your invoice and attempts payment. Note that finalizing the invoice, [when automatic](stripe.com/docs/invoicing/integration/automatic-advancement-collection), does not happen immediately as the invoice is created. Stripe waits until one hour after the last webhook was successfully sent (or the last webhook timed out after failing). If you (and the platforms you may have connected to) have no webhooks configured, Stripe waits one hour after creation to finalize the invoice.

If your invoice is configured to be billed by sending an email, then based on your [email settings](dashboard.stripe.com/account/billing/automatic), Stripe will email the invoice to your customer and await payment. These emails can contain a link to a hosted page to pay the invoice.

Stripe applies any customer credit on the account before determining the amount due for the invoice (i.e., the amount that will be actually charged). If the amount due for the invoice is less than Stripe’s [minimum allowed charge per currency](docs.stripe.com/docs/currencies#minimum-and-maximum-charge-amounts), the invoice is automatically marked paid, and we add the amount due to the customer’s credit balance which is applied to the next invoice.

More details on the customer’s credit balance are [here](stripe.com/docs/billing/customer/balance).

Related guide: [Send invoices to customers](stripe.com/docs/billing/invoices/sending)

Defined Under Namespace

Classes: AmountsDue, AppliesTo, AutomaticTax, ConfirmationSecret, CustomField, CustomerAddress, CustomerShipping, CustomerTaxId, FromInvoice, Issuer, LastFinalizationError, Parent, PaymentSettings, Rendering, ShippingCost, ShippingDetails, StatusTransitions, ThresholdReason, TotalDiscountAmount, TotalMarginAmount, TotalPretaxCreditAmount, TotalTax

Constant Summary collapse

OBJECT_NAME =
"quote_preview_invoice"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_countryObject (readonly)

The country of the business associated with this invoice, most often the business creating the invoice.



499
500
501
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 499

def 
  @account_country
end

#account_nameObject (readonly)

The public name of the business associated with this invoice, most often the business creating the invoice.



501
502
503
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 501

def 
  @account_name
end

#account_tax_idsObject (readonly)

The account tax IDs associated with the invoice. Only editable when the invoice is a draft.



503
504
505
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 503

def 
  @account_tax_ids
end

#amount_dueObject (readonly)

Final amount due at this time for this invoice. If the invoice’s total is smaller than the minimum charge amount, for example, or if there is account credit that can be applied to the invoice, the ‘amount_due` may be 0. If there is a positive `starting_balance` for the invoice (the customer owes money), the `amount_due` will also take that into account. The charge that gets generated for the invoice will be for the amount specified in `amount_due`.



505
506
507
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 505

def amount_due
  @amount_due
end

#amount_overpaidObject (readonly)

Amount that was overpaid on the invoice. The amount overpaid is credited to the customer’s credit balance.



507
508
509
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 507

def amount_overpaid
  @amount_overpaid
end

#amount_paidObject (readonly)

The amount, in cents (or local equivalent), that was paid.



509
510
511
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 509

def amount_paid
  @amount_paid
end

#amount_remainingObject (readonly)

The difference between amount_due and amount_paid, in cents (or local equivalent).



511
512
513
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 511

def amount_remaining
  @amount_remaining
end

#amount_shippingObject (readonly)

This is the sum of all the shipping amounts.



513
514
515
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 513

def amount_shipping
  @amount_shipping
end

#amounts_dueObject (readonly)

List of expected payments and corresponding due dates. This value will be null for invoices where collection_method=charge_automatically.



515
516
517
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 515

def amounts_due
  @amounts_due
end

#applicationObject (readonly)

ID of the Connect Application that created the invoice.



517
518
519
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 517

def application
  @application
end

#applies_toObject (readonly)

Attribute for field applies_to



519
520
521
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 519

def applies_to
  @applies_to
end

#attempt_countObject (readonly)

Number of payment attempts made for this invoice, from the perspective of the payment retry schedule. Any payment attempt counts as the first attempt, and subsequently only automatic retries increment the attempt count. In other words, manual payment attempts after the first attempt do not affect the retry schedule. If a failure is returned with a non-retryable return code, the invoice can no longer be retried unless a new payment method is obtained. Retries will continue to be scheduled, and attempt_count will continue to increment, but retries will only be executed if a new payment method is obtained.



521
522
523
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 521

def attempt_count
  @attempt_count
end

#attemptedObject (readonly)

Whether an attempt has been made to pay the invoice. An invoice is not attempted until 1 hour after the ‘invoice.created` webhook, for example, so you might not want to display that invoice as unpaid to your users.



523
524
525
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 523

def attempted
  @attempted
end

#automatic_taxObject (readonly)

Attribute for field automatic_tax



525
526
527
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 525

def automatic_tax
  @automatic_tax
end

#automatically_finalizes_atObject (readonly)

The time when this invoice is currently scheduled to be automatically finalized. The field will be ‘null` if the invoice is not scheduled to finalize in the future. If the invoice is not in the draft state, this field will always be `null` - see `finalized_at` for the time when an already-finalized invoice was finalized.



527
528
529
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 527

def automatically_finalizes_at
  @automatically_finalizes_at
end

#billing_reasonObject (readonly)

Indicates the reason why the invoice was created.

  • ‘manual`: Unrelated to a subscription, for example, created via the invoice editor.

  • ‘subscription`: No longer in use. Applies to subscriptions from before May 2018 where no distinction was made between updates, cycles, and thresholds.

  • ‘subscription_create`: A new subscription was created.

  • ‘subscription_cycle`: A subscription advanced into a new period.

  • ‘subscription_threshold`: A subscription reached a billing threshold.

  • ‘subscription_update`: A subscription was updated.

  • ‘upcoming`: Reserved for simulated invoices, per the upcoming invoice endpoint.



537
538
539
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 537

def billing_reason
  @billing_reason
end

#collection_methodObject (readonly)

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay this invoice using the default source attached to the customer. When sending an invoice, Stripe will email this invoice to the customer with payment instructions.



539
540
541
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 539

def collection_method
  @collection_method
end

#confirmation_secretObject (readonly)

The confirmation secret associated with this invoice. Currently, this contains the client_secret of the PaymentIntent that Stripe creates during invoice finalization.



541
542
543
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 541

def confirmation_secret
  @confirmation_secret
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



543
544
545
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 543

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



545
546
547
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 545

def currency
  @currency
end

#custom_fieldsObject (readonly)

Custom fields displayed on the invoice.



547
548
549
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 547

def custom_fields
  @custom_fields
end

#customer_accountObject (readonly)

The ID of the account who will be billed.



549
550
551
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 549

def 
  @customer_account
end

#customer_addressObject (readonly)

The customer’s address. Until the invoice is finalized, this field will equal ‘customer.address`. Once the invoice is finalized, this field will no longer be updated.



551
552
553
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 551

def customer_address
  @customer_address
end

#customer_emailObject (readonly)

The customer’s email. Until the invoice is finalized, this field will equal ‘customer.email`. Once the invoice is finalized, this field will no longer be updated.



553
554
555
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 553

def customer_email
  @customer_email
end

#customer_nameObject (readonly)

The customer’s name. Until the invoice is finalized, this field will equal ‘customer.name`. Once the invoice is finalized, this field will no longer be updated.



555
556
557
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 555

def customer_name
  @customer_name
end

#customer_phoneObject (readonly)

The customer’s phone number. Until the invoice is finalized, this field will equal ‘customer.phone`. Once the invoice is finalized, this field will no longer be updated.



557
558
559
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 557

def customer_phone
  @customer_phone
end

#customer_shippingObject (readonly)

The customer’s shipping information. Until the invoice is finalized, this field will equal ‘customer.shipping`. Once the invoice is finalized, this field will no longer be updated.



559
560
561
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 559

def customer_shipping
  @customer_shipping
end

#customer_tax_exemptObject (readonly)

The customer’s tax exempt status. Until the invoice is finalized, this field will equal ‘customer.tax_exempt`. Once the invoice is finalized, this field will no longer be updated.



561
562
563
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 561

def customer_tax_exempt
  @customer_tax_exempt
end

#customer_tax_idsObject (readonly)

The customer’s tax IDs. Until the invoice is finalized, this field will contain the same tax IDs as ‘customer.tax_ids`. Once the invoice is finalized, this field will no longer be updated.



563
564
565
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 563

def customer_tax_ids
  @customer_tax_ids
end

#default_marginsObject (readonly)

The margins applied to the invoice. Can be overridden by line item ‘margins`. Use `expand[]=default_margins` to expand each margin.



565
566
567
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 565

def default_margins
  @default_margins
end

#default_payment_methodObject (readonly)

ID of the default payment method for the invoice. It must belong to the customer associated with the invoice. If not set, defaults to the subscription’s default payment method, if any, or to the default payment method in the customer’s invoice settings.



567
568
569
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 567

def default_payment_method
  @default_payment_method
end

#default_sourceObject (readonly)

ID of the default payment source for the invoice. It must belong to the customer associated with the invoice and be in a chargeable state. If not set, defaults to the subscription’s default source, if any, or to the customer’s default source.



569
570
571
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 569

def default_source
  @default_source
end

#default_tax_ratesObject (readonly)

The tax rates applied to this invoice, if any.



571
572
573
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 571

def default_tax_rates
  @default_tax_rates
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users. Referenced as ‘memo’ in the Dashboard.



573
574
575
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 573

def description
  @description
end

#discountsObject (readonly)

The discounts applied to the invoice. Line item discounts are applied before invoice discounts. Use ‘expand[]=discounts` to expand each discount.



575
576
577
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 575

def discounts
  @discounts
end

#due_dateObject (readonly)

The date on which payment for this invoice is due. This value will be ‘null` for invoices where `collection_method=charge_automatically`.



577
578
579
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 577

def due_date
  @due_date
end

#effective_atObject (readonly)

The date when this invoice is in effect. Same as ‘finalized_at` unless overwritten. When defined, this value replaces the system-generated ’Date of issue’ printed on the invoice PDF and receipt.



579
580
581
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 579

def effective_at
  @effective_at
end

#ending_balanceObject (readonly)

Ending customer balance after the invoice is finalized. Invoices are finalized approximately an hour after successful webhook delivery or when payment collection is attempted for the invoice. If the invoice has not been finalized yet, this will be null.



581
582
583
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 581

def ending_balance
  @ending_balance
end

Footer displayed on the invoice.



583
584
585
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 583

def footer
  @footer
end

#from_invoiceObject (readonly)

Details of the invoice that was cloned. See the [revision documentation](stripe.com/docs/invoicing/invoice-revisions) for more details.



585
586
587
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 585

def from_invoice
  @from_invoice
end

#idObject (readonly)

Unique identifier for the object. For preview invoices created using the [create preview](stripe.com/docs/api/invoices/create_preview) endpoint, this id will be prefixed with ‘upcoming_in`.



587
588
589
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 587

def id
  @id
end

#issuerObject (readonly)

Attribute for field issuer



589
590
591
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 589

def issuer
  @issuer
end

#last_finalization_errorObject (readonly)

The error encountered during the previous attempt to finalize the invoice. This field is cleared when the invoice is successfully finalized.



591
592
593
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 591

def last_finalization_error
  @last_finalization_error
end

#latest_revisionObject (readonly)

The ID of the most recent non-draft revision of this invoice



593
594
595
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 593

def latest_revision
  @latest_revision
end

#linesObject (readonly)

The individual line items that make up the invoice. ‘lines` is sorted as follows: (1) pending invoice items (including prorations) in reverse chronological order, (2) subscription items in reverse chronological order, and (3) invoice items added after invoice creation in chronological order.



595
596
597
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 595

def lines
  @lines
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



597
598
599
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 597

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



599
600
601
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 599

def 
  @metadata
end

#next_payment_attemptObject (readonly)

The time at which payment will next be attempted. This value will be ‘null` for invoices where `collection_method=send_invoice`.



601
602
603
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 601

def next_payment_attempt
  @next_payment_attempt
end

#numberObject (readonly)

A unique, identifying string that appears on emails sent to the customer for this invoice. This starts with the customer’s unique invoice_prefix if it is specified.



603
604
605
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 603

def number
  @number
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



605
606
607
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 605

def object
  @object
end

#on_behalf_ofObject (readonly)

The account (if any) for which the funds of the invoice payment are intended. If set, the invoice will be presented with the branding and support information of the specified account. See the [Invoices with Connect](stripe.com/docs/billing/invoices/connect) documentation for details.



607
608
609
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 607

def on_behalf_of
  @on_behalf_of
end

#parentObject (readonly)

The parent that generated this invoice



609
610
611
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 609

def parent
  @parent
end

#payment_settingsObject (readonly)

Attribute for field payment_settings



611
612
613
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 611

def payment_settings
  @payment_settings
end

#paymentsObject (readonly)

Payments for this invoice



613
614
615
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 613

def payments
  @payments
end

#period_endObject (readonly)

End of the usage period during which invoice items were added to this invoice. This looks back one period for a subscription invoice. Use the [line item period](/api/invoices/line_item#invoice_line_item_object-period) to get the service period for each price.



615
616
617
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 615

def period_end
  @period_end
end

#period_startObject (readonly)

Start of the usage period during which invoice items were added to this invoice. This looks back one period for a subscription invoice. Use the [line item period](/api/invoices/line_item#invoice_line_item_object-period) to get the service period for each price.



617
618
619
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 617

def period_start
  @period_start
end

#post_payment_credit_notes_amountObject (readonly)

Total amount of all post-payment credit notes issued for this invoice.



619
620
621
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 619

def post_payment_credit_notes_amount
  @post_payment_credit_notes_amount
end

#pre_payment_credit_notes_amountObject (readonly)

Total amount of all pre-payment credit notes issued for this invoice.



621
622
623
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 621

def pre_payment_credit_notes_amount
  @pre_payment_credit_notes_amount
end

#receipt_numberObject (readonly)

This is the transaction number that appears on email receipts sent for this invoice.



623
624
625
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 623

def receipt_number
  @receipt_number
end

#renderingObject (readonly)

The rendering-related settings that control how the invoice is displayed on customer-facing surfaces such as PDF and Hosted Invoice Page.



625
626
627
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 625

def rendering
  @rendering
end

#shipping_costObject (readonly)

The details of the cost of shipping, including the ShippingRate applied on the invoice.



627
628
629
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 627

def shipping_cost
  @shipping_cost
end

#shipping_detailsObject (readonly)

Shipping details for the invoice. The Invoice PDF will use the ‘shipping_details` value if it is set, otherwise the PDF will render the shipping address from the customer.



629
630
631
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 629

def shipping_details
  @shipping_details
end

#starting_balanceObject (readonly)

Starting customer balance before the invoice is finalized. If the invoice has not been finalized yet, this will be the current customer balance. For revision invoices, this also includes any customer balance that was applied to the original invoice.



631
632
633
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 631

def starting_balance
  @starting_balance
end

#statement_descriptorObject (readonly)

Extra information about an invoice for the customer’s credit card statement.



633
634
635
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 633

def statement_descriptor
  @statement_descriptor
end

#statusObject (readonly)

The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`. [Learn more](stripe.com/docs/billing/invoices/workflow#workflow-overview)



635
636
637
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 635

def status
  @status
end

#status_transitionsObject (readonly)

Attribute for field status_transitions



637
638
639
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 637

def status_transitions
  @status_transitions
end

#subscriptionObject (readonly)

Attribute for field subscription



639
640
641
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 639

def subscription
  @subscription
end

#subtotalObject (readonly)

Total of all subscriptions, invoice items, and prorations on the invoice before any invoice level discount or exclusive tax is applied. Item discounts are already incorporated



641
642
643
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 641

def subtotal
  @subtotal
end

#subtotal_excluding_taxObject (readonly)

The integer amount in cents (or local equivalent) representing the subtotal of the invoice before any invoice level discount or tax is applied. Item discounts are already incorporated



643
644
645
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 643

def subtotal_excluding_tax
  @subtotal_excluding_tax
end

#test_clockObject (readonly)

ID of the test clock this invoice belongs to.



645
646
647
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 645

def test_clock
  @test_clock
end

#threshold_reasonObject (readonly)

Attribute for field threshold_reason



647
648
649
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 647

def threshold_reason
  @threshold_reason
end

#totalObject (readonly)

Total after discounts and taxes.



649
650
651
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 649

def total
  @total
end

#total_discount_amountsObject (readonly)

The aggregate amounts calculated per discount across all line items.



651
652
653
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 651

def total_discount_amounts
  @total_discount_amounts
end

#total_excluding_taxObject (readonly)

The integer amount in cents (or local equivalent) representing the total amount of the invoice including all discounts but excluding all tax.



653
654
655
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 653

def total_excluding_tax
  @total_excluding_tax
end

#total_margin_amountsObject (readonly)

The aggregate amounts calculated per margin across all line items.



655
656
657
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 655

def total_margin_amounts
  @total_margin_amounts
end

#total_pretax_credit_amountsObject (readonly)

Contains pretax credit amounts (ex: discount, credit grants, etc) that apply to this invoice. This is a combined list of total_pretax_credit_amounts across all invoice line items.



657
658
659
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 657

def total_pretax_credit_amounts
  @total_pretax_credit_amounts
end

#total_taxesObject (readonly)

The aggregate tax information of all line items.



659
660
661
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 659

def total_taxes
  @total_taxes
end

#webhooks_delivered_atObject (readonly)

Invoices are automatically paid or sent 1 hour after webhooks are delivered, or until all webhook delivery attempts have [been exhausted](stripe.com/docs/billing/webhooks#understand). This field tracks the time when webhooks for this invoice were successfully delivered. If the invoice had no webhooks to deliver, this will be set while the invoice is being created.



661
662
663
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 661

def webhooks_delivered_at
  @webhooks_delivered_at
end

Class Method Details

.object_nameObject



39
40
41
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 39

def self.object_name
  "quote_preview_invoice"
end