Class: Stripe::QuotePreviewInvoice

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/quote_preview_invoice.rb

Overview

Invoices are statements of amounts owed by a customer, and are either generated one-off, or generated periodically from a subscription.

They contain [invoice items](stripe.com/docs/api#invoiceitems), and proration adjustments that may be caused by subscription upgrades/downgrades (if necessary).

If your invoice is configured to be billed through automatic charges, Stripe automatically finalizes your invoice and attempts payment. Note that finalizing the invoice, [when automatic](stripe.com/docs/invoicing/integration/automatic-advancement-collection), does not happen immediately as the invoice is created. Stripe waits until one hour after the last webhook was successfully sent (or the last webhook timed out after failing). If you (and the platforms you may have connected to) have no webhooks configured, Stripe waits one hour after creation to finalize the invoice.

If your invoice is configured to be billed by sending an email, then based on your [email settings](dashboard.stripe.com/account/billing/automatic), Stripe will email the invoice to your customer and await payment. These emails can contain a link to a hosted page to pay the invoice.

Stripe applies any customer credit on the account before determining the amount due for the invoice (i.e., the amount that will be actually charged). If the amount due for the invoice is less than Stripe’s [minimum allowed charge per currency](stripe.com/docs/currencies#minimum-and-maximum-charge-amounts), the invoice is automatically marked paid, and we add the amount due to the customer’s credit balance which is applied to the next invoice.

More details on the customer’s credit balance are [here](stripe.com/docs/billing/customer/balance).

Related guide: [Send invoices to customers](stripe.com/docs/billing/invoices/sending)

Defined Under Namespace

Classes: AmountsDue, AppliesTo, AutomaticTax, CustomField, CustomerAddress, CustomerShipping, CustomerTaxId, FromInvoice, Issuer, LastFinalizationError, PaymentSettings, Rendering, ShippingCost, ShippingDetails, StatusTransitions, SubscriptionDetails, ThresholdReason, TotalDiscountAmount, TotalMarginAmount, TotalPretaxCreditAmount, TotalTaxAmount, TransferData

Constant Summary collapse

OBJECT_NAME =
"quote_preview_invoice"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_countryObject (readonly)

The country of the business associated with this invoice, most often the business creating the invoice.



196
197
198
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 196

def 
  @account_country
end

#account_nameObject (readonly)

The public name of the business associated with this invoice, most often the business creating the invoice.



198
199
200
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 198

def 
  @account_name
end

#account_tax_idsObject (readonly)

The account tax IDs associated with the invoice. Only editable when the invoice is a draft.



200
201
202
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 200

def 
  @account_tax_ids
end

#amount_dueObject (readonly)

Final amount due at this time for this invoice. If the invoice’s total is smaller than the minimum charge amount, for example, or if there is account credit that can be applied to the invoice, the ‘amount_due` may be 0. If there is a positive `starting_balance` for the invoice (the customer owes money), the `amount_due` will also take that into account. The charge that gets generated for the invoice will be for the amount specified in `amount_due`.



202
203
204
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 202

def amount_due
  @amount_due
end

#amount_overpaidObject (readonly)

Amount that was overpaid on the invoice. Overpayments are debited to the customer’s credit balance.



204
205
206
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 204

def amount_overpaid
  @amount_overpaid
end

#amount_paidObject (readonly)

The amount, in cents (or local equivalent), that was paid.



206
207
208
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 206

def amount_paid
  @amount_paid
end

#amount_remainingObject (readonly)

The difference between amount_due and amount_paid, in cents (or local equivalent).



208
209
210
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 208

def amount_remaining
  @amount_remaining
end

#amount_shippingObject (readonly)

This is the sum of all the shipping amounts.



210
211
212
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 210

def amount_shipping
  @amount_shipping
end

#amounts_dueObject (readonly)

List of expected payments and corresponding due dates. This value will be null for invoices where collection_method=charge_automatically.



212
213
214
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 212

def amounts_due
  @amounts_due
end

#applicationObject (readonly)

ID of the Connect Application that created the invoice.



214
215
216
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 214

def application
  @application
end

#application_fee_amountObject (readonly)

The fee in cents (or local equivalent) that will be applied to the invoice and transferred to the application owner’s Stripe account when the invoice is paid.



216
217
218
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 216

def application_fee_amount
  @application_fee_amount
end

#applies_toObject (readonly)

Attribute for field applies_to



218
219
220
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 218

def applies_to
  @applies_to
end

#attempt_countObject (readonly)

Number of payment attempts made for this invoice, from the perspective of the payment retry schedule. Any payment attempt counts as the first attempt, and subsequently only automatic retries increment the attempt count. In other words, manual payment attempts after the first attempt do not affect the retry schedule. If a failure is returned with a non-retryable return code, the invoice can no longer be retried unless a new payment method is obtained. Retries will continue to be scheduled, and attempt_count will continue to increment, but retries will only be executed if a new payment method is obtained.



220
221
222
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 220

def attempt_count
  @attempt_count
end

#attemptedObject (readonly)

Whether an attempt has been made to pay the invoice. An invoice is not attempted until 1 hour after the ‘invoice.created` webhook, for example, so you might not want to display that invoice as unpaid to your users.



222
223
224
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 222

def attempted
  @attempted
end

#automatic_taxObject (readonly)

Attribute for field automatic_tax



224
225
226
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 224

def automatic_tax
  @automatic_tax
end

#automatically_finalizes_atObject (readonly)

The time when this invoice is currently scheduled to be automatically finalized. The field will be ‘null` if the invoice is not scheduled to finalize in the future. If the invoice is not in the draft state, this field will always be `null` - see `finalized_at` for the time when an already-finalized invoice was finalized.



226
227
228
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 226

def automatically_finalizes_at
  @automatically_finalizes_at
end

#billing_reasonObject (readonly)

Indicates the reason why the invoice was created.

  • ‘manual`: Unrelated to a subscription, for example, created via the invoice editor.

  • ‘subscription`: No longer in use. Applies to subscriptions from before May 2018 where no distinction was made between updates, cycles, and thresholds.

  • ‘subscription_create`: A new subscription was created.

  • ‘subscription_cycle`: A subscription advanced into a new period.

  • ‘subscription_threshold`: A subscription reached a billing threshold.

  • ‘subscription_update`: A subscription was updated.

  • ‘upcoming`: Reserved for simulated invoices, per the upcoming invoice endpoint.



236
237
238
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 236

def billing_reason
  @billing_reason
end

#collection_methodObject (readonly)

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay this invoice using the default source attached to the customer. When sending an invoice, Stripe will email this invoice to the customer with payment instructions.



238
239
240
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 238

def collection_method
  @collection_method
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



240
241
242
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 240

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



242
243
244
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 242

def currency
  @currency
end

#custom_fieldsObject (readonly)

Custom fields displayed on the invoice.



244
245
246
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 244

def custom_fields
  @custom_fields
end

#customer_addressObject (readonly)

The customer’s address. Until the invoice is finalized, this field will equal ‘customer.address`. Once the invoice is finalized, this field will no longer be updated.



246
247
248
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 246

def customer_address
  @customer_address
end

#customer_emailObject (readonly)

The customer’s email. Until the invoice is finalized, this field will equal ‘customer.email`. Once the invoice is finalized, this field will no longer be updated.



248
249
250
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 248

def customer_email
  @customer_email
end

#customer_nameObject (readonly)

The customer’s name. Until the invoice is finalized, this field will equal ‘customer.name`. Once the invoice is finalized, this field will no longer be updated.



250
251
252
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 250

def customer_name
  @customer_name
end

#customer_phoneObject (readonly)

The customer’s phone number. Until the invoice is finalized, this field will equal ‘customer.phone`. Once the invoice is finalized, this field will no longer be updated.



252
253
254
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 252

def customer_phone
  @customer_phone
end

#customer_shippingObject (readonly)

The customer’s shipping information. Until the invoice is finalized, this field will equal ‘customer.shipping`. Once the invoice is finalized, this field will no longer be updated.



254
255
256
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 254

def customer_shipping
  @customer_shipping
end

#customer_tax_exemptObject (readonly)

The customer’s tax exempt status. Until the invoice is finalized, this field will equal ‘customer.tax_exempt`. Once the invoice is finalized, this field will no longer be updated.



256
257
258
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 256

def customer_tax_exempt
  @customer_tax_exempt
end

#customer_tax_idsObject (readonly)

The customer’s tax IDs. Until the invoice is finalized, this field will contain the same tax IDs as ‘customer.tax_ids`. Once the invoice is finalized, this field will no longer be updated.



258
259
260
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 258

def customer_tax_ids
  @customer_tax_ids
end

#default_marginsObject (readonly)

The margins applied to the invoice. Can be overridden by line item ‘margins`. Use `expand[]=default_margins` to expand each margin.



260
261
262
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 260

def default_margins
  @default_margins
end

#default_payment_methodObject (readonly)

ID of the default payment method for the invoice. It must belong to the customer associated with the invoice. If not set, defaults to the subscription’s default payment method, if any, or to the default payment method in the customer’s invoice settings.



262
263
264
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 262

def default_payment_method
  @default_payment_method
end

#default_sourceObject (readonly)

ID of the default payment source for the invoice. It must belong to the customer associated with the invoice and be in a chargeable state. If not set, defaults to the subscription’s default source, if any, or to the customer’s default source.



264
265
266
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 264

def default_source
  @default_source
end

#default_tax_ratesObject (readonly)

The tax rates applied to this invoice, if any.



266
267
268
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 266

def default_tax_rates
  @default_tax_rates
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users. Referenced as ‘memo’ in the Dashboard.



268
269
270
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 268

def description
  @description
end

#discountObject (readonly)

Describes the current discount applied to this invoice, if there is one. Not populated if there are multiple discounts.



270
271
272
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 270

def discount
  @discount
end

#discountsObject (readonly)

The discounts applied to the invoice. Line item discounts are applied before invoice discounts. Use ‘expand[]=discounts` to expand each discount.



272
273
274
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 272

def discounts
  @discounts
end

#due_dateObject (readonly)

The date on which payment for this invoice is due. This value will be ‘null` for invoices where `collection_method=charge_automatically`.



274
275
276
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 274

def due_date
  @due_date
end

#effective_atObject (readonly)

The date when this invoice is in effect. Same as ‘finalized_at` unless overwritten. When defined, this value replaces the system-generated ’Date of issue’ printed on the invoice PDF and receipt.



276
277
278
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 276

def effective_at
  @effective_at
end

#ending_balanceObject (readonly)

Ending customer balance after the invoice is finalized. Invoices are finalized approximately an hour after successful webhook delivery or when payment collection is attempted for the invoice. If the invoice has not been finalized yet, this will be null.



278
279
280
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 278

def ending_balance
  @ending_balance
end

Footer displayed on the invoice.



280
281
282
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 280

def footer
  @footer
end

#from_invoiceObject (readonly)

Details of the invoice that was cloned. See the [revision documentation](stripe.com/docs/invoicing/invoice-revisions) for more details.



282
283
284
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 282

def from_invoice
  @from_invoice
end

#idObject (readonly)

Unique identifier for the object. This property is always present unless the invoice is an upcoming invoice. See [Retrieve an upcoming invoice](stripe.com/docs/api/invoices/upcoming) for more details.



284
285
286
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 284

def id
  @id
end

#issuerObject (readonly)

Attribute for field issuer



286
287
288
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 286

def issuer
  @issuer
end

#last_finalization_errorObject (readonly)

The error encountered during the previous attempt to finalize the invoice. This field is cleared when the invoice is successfully finalized.



288
289
290
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 288

def last_finalization_error
  @last_finalization_error
end

#latest_revisionObject (readonly)

The ID of the most recent non-draft revision of this invoice



290
291
292
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 290

def latest_revision
  @latest_revision
end

#linesObject (readonly)

The individual line items that make up the invoice. ‘lines` is sorted as follows: (1) pending invoice items (including prorations) in reverse chronological order, (2) subscription items in reverse chronological order, and (3) invoice items added after invoice creation in chronological order.



292
293
294
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 292

def lines
  @lines
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



294
295
296
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 294

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



296
297
298
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 296

def 
  @metadata
end

#next_payment_attemptObject (readonly)

The time at which payment will next be attempted. This value will be ‘null` for invoices where `collection_method=send_invoice`.



298
299
300
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 298

def next_payment_attempt
  @next_payment_attempt
end

#numberObject (readonly)

A unique, identifying string that appears on emails sent to the customer for this invoice. This starts with the customer’s unique invoice_prefix if it is specified.



300
301
302
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 300

def number
  @number
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



302
303
304
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 302

def object
  @object
end

#on_behalf_ofObject (readonly)

The account (if any) for which the funds of the invoice payment are intended. If set, the invoice will be presented with the branding and support information of the specified account. See the [Invoices with Connect](stripe.com/docs/billing/invoices/connect) documentation for details.



304
305
306
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 304

def on_behalf_of
  @on_behalf_of
end

Whether payment was successfully collected for this invoice. An invoice can be paid (most commonly) with a charge or with credit from the customer’s account balance.



306
307
308
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 306

def paid
  @paid
end

Returns true if the invoice was manually marked paid, returns false if the invoice hasn’t been paid yet or was paid on Stripe.



308
309
310
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 308

def paid_out_of_band
  @paid_out_of_band
end

#payment_intentObject (readonly)

The PaymentIntent associated with this invoice. The PaymentIntent is generated when the invoice is finalized, and can then be used to pay the invoice. Note that voiding an invoice will cancel the PaymentIntent.



310
311
312
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 310

def payment_intent
  @payment_intent
end

#payment_settingsObject (readonly)

Attribute for field payment_settings



312
313
314
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 312

def payment_settings
  @payment_settings
end

#paymentsObject (readonly)

Payments for this invoice



314
315
316
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 314

def payments
  @payments
end

#period_endObject (readonly)

End of the usage period during which invoice items were added to this invoice. This looks back one period for a subscription invoice. Use the [line item period](/api/invoices/line_item#invoice_line_item_object-period) to get the service period for each price.



316
317
318
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 316

def period_end
  @period_end
end

#period_startObject (readonly)

Start of the usage period during which invoice items were added to this invoice. This looks back one period for a subscription invoice. Use the [line item period](/api/invoices/line_item#invoice_line_item_object-period) to get the service period for each price.



318
319
320
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 318

def period_start
  @period_start
end

#post_payment_credit_notes_amountObject (readonly)

Total amount of all post-payment credit notes issued for this invoice.



320
321
322
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 320

def post_payment_credit_notes_amount
  @post_payment_credit_notes_amount
end

#pre_payment_credit_notes_amountObject (readonly)

Total amount of all pre-payment credit notes issued for this invoice.



322
323
324
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 322

def pre_payment_credit_notes_amount
  @pre_payment_credit_notes_amount
end

#quoteObject (readonly)

The quote this invoice was generated from.



324
325
326
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 324

def quote
  @quote
end

#receipt_numberObject (readonly)

This is the transaction number that appears on email receipts sent for this invoice.



326
327
328
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 326

def receipt_number
  @receipt_number
end

#renderingObject (readonly)

The rendering-related settings that control how the invoice is displayed on customer-facing surfaces such as PDF and Hosted Invoice Page.



328
329
330
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 328

def rendering
  @rendering
end

#shipping_costObject (readonly)

The details of the cost of shipping, including the ShippingRate applied on the invoice.



330
331
332
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 330

def shipping_cost
  @shipping_cost
end

#shipping_detailsObject (readonly)

Shipping details for the invoice. The Invoice PDF will use the ‘shipping_details` value if it is set, otherwise the PDF will render the shipping address from the customer.



332
333
334
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 332

def shipping_details
  @shipping_details
end

#starting_balanceObject (readonly)

Starting customer balance before the invoice is finalized. If the invoice has not been finalized yet, this will be the current customer balance. For revision invoices, this also includes any customer balance that was applied to the original invoice.



334
335
336
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 334

def starting_balance
  @starting_balance
end

#statement_descriptorObject (readonly)

Extra information about an invoice for the customer’s credit card statement.



336
337
338
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 336

def statement_descriptor
  @statement_descriptor
end

#statusObject (readonly)

The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`. [Learn more](stripe.com/docs/billing/invoices/workflow#workflow-overview)



338
339
340
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 338

def status
  @status
end

#status_transitionsObject (readonly)

Attribute for field status_transitions



340
341
342
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 340

def status_transitions
  @status_transitions
end

#subscriptionObject (readonly)

Attribute for field subscription



342
343
344
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 342

def subscription
  @subscription
end

#subscription_detailsObject (readonly)

Details about the subscription that created this invoice.



344
345
346
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 344

def subscription_details
  @subscription_details
end

#subscription_proration_dateObject (readonly)

Only set for upcoming invoices that preview prorations. The time used to calculate prorations.



346
347
348
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 346

def subscription_proration_date
  @subscription_proration_date
end

#subtotalObject (readonly)

Total of all subscriptions, invoice items, and prorations on the invoice before any invoice level discount or exclusive tax is applied. Item discounts are already incorporated



348
349
350
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 348

def subtotal
  @subtotal
end

#subtotal_excluding_taxObject (readonly)

The integer amount in cents (or local equivalent) representing the subtotal of the invoice before any invoice level discount or tax is applied. Item discounts are already incorporated



350
351
352
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 350

def subtotal_excluding_tax
  @subtotal_excluding_tax
end

#taxObject (readonly)

The amount of tax on this invoice. This is the sum of all the tax amounts on this invoice.



352
353
354
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 352

def tax
  @tax
end

#test_clockObject (readonly)

ID of the test clock this invoice belongs to.



354
355
356
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 354

def test_clock
  @test_clock
end

#threshold_reasonObject (readonly)

Attribute for field threshold_reason



356
357
358
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 356

def threshold_reason
  @threshold_reason
end

#totalObject (readonly)

Total after discounts and taxes.



358
359
360
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 358

def total
  @total
end

#total_discount_amountsObject (readonly)

The aggregate amounts calculated per discount across all line items.



360
361
362
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 360

def total_discount_amounts
  @total_discount_amounts
end

#total_excluding_taxObject (readonly)

The integer amount in cents (or local equivalent) representing the total amount of the invoice including all discounts but excluding all tax.



362
363
364
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 362

def total_excluding_tax
  @total_excluding_tax
end

#total_margin_amountsObject (readonly)

The aggregate amounts calculated per margin across all line items.



364
365
366
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 364

def total_margin_amounts
  @total_margin_amounts
end

#total_pretax_credit_amountsObject (readonly)

Contains pretax credit amounts (ex: discount, credit grants, etc) that apply to this invoice. This is a combined list of total_pretax_credit_amounts across all invoice line items.



366
367
368
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 366

def total_pretax_credit_amounts
  @total_pretax_credit_amounts
end

#total_tax_amountsObject (readonly)

The aggregate amounts calculated per tax rate for all line items.



368
369
370
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 368

def total_tax_amounts
  @total_tax_amounts
end

#transfer_dataObject (readonly)

The account (if any) the payment will be attributed to for tax reporting, and where funds from the payment will be transferred to for the invoice.



370
371
372
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 370

def transfer_data
  @transfer_data
end

#webhooks_delivered_atObject (readonly)

Invoices are automatically paid or sent 1 hour after webhooks are delivered, or until all webhook delivery attempts have [been exhausted](stripe.com/docs/billing/webhooks#understand). This field tracks the time when webhooks for this invoice were successfully delivered. If the invoice had no webhooks to deliver, this will be set while the invoice is being created.



372
373
374
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 372

def webhooks_delivered_at
  @webhooks_delivered_at
end

Class Method Details

.object_nameObject



39
40
41
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 39

def self.object_name
  "quote_preview_invoice"
end