Class: Stripe::QuotePreviewInvoice::AmountsDue

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_invoice.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Incremental amount due for this payment in cents (or local equivalent).



45
46
47
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 45

def amount
  @amount
end

#amount_paidObject (readonly)

The amount in cents (or local equivalent) that was paid for this payment.



48
49
50
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 48

def amount_paid
  @amount_paid
end

#amount_remainingObject (readonly)

The difference between the payment’s amount and amount_paid, in cents (or local equivalent).



51
52
53
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 51

def amount_remaining
  @amount_remaining
end

#days_until_dueObject (readonly)

Number of days from when invoice is finalized until the payment is due.



54
55
56
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 54

def days_until_due
  @days_until_due
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



57
58
59
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 57

def description
  @description
end

#due_dateObject (readonly)

Date on which a payment plan’s payment is due.



60
61
62
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 60

def due_date
  @due_date
end

Timestamp when the payment was paid.



63
64
65
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 63

def paid_at
  @paid_at
end

#statusObject (readonly)

The status of the payment, one of ‘open`, `paid`, or `past_due`



66
67
68
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 66

def status
  @status
end