Class: Stripe::QuotePreviewInvoice::AppliesTo

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_invoice.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#new_referenceObject (readonly)

A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same ‘new_reference` field will be applied to the creation of a new subscription schedule.



71
72
73
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 71

def new_reference
  @new_reference
end

#subscription_scheduleObject (readonly)

The ID of the schedule the line applies to.



74
75
76
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 74

def subscription_schedule
  @subscription_schedule
end

#typeObject (readonly)

Describes whether the quote line is affecting a new schedule or an existing schedule.



77
78
79
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 77

def type
  @type
end