Class: Stripe::QuotePreviewInvoice::PaymentSettings

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_invoice.rb

Defined Under Namespace

Classes: PaymentMethodOptions

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#default_mandateObject (readonly)

ID of the mandate to be used for this invoice. It must correspond to the payment method used to pay the invoice, including the invoice’s default_payment_method or default_source, if set.



743
744
745
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 743

def default_mandate
  @default_mandate
end

#payment_method_optionsObject (readonly)

Payment-method-specific configuration to provide to the invoice’s PaymentIntent.



745
746
747
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 745

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject (readonly)

The list of payment method types (e.g. card) to provide to the invoice’s PaymentIntent. If not set, Stripe attempts to automatically determine the types to use by looking at the invoice’s default payment method, the subscription’s default payment method, the customer’s default payment method, and your [invoice template settings](dashboard.stripe.com/settings/billing/invoice).



747
748
749
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 747

def payment_method_types
  @payment_method_types
end

Class Method Details

.field_remappingsObject



753
754
755
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 753

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



749
750
751
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 749

def self.inner_class_types
  @inner_class_types = { payment_method_options: PaymentMethodOptions }
end