Class: Stripe::QuotePreviewInvoice::PaymentSettings::PaymentMethodOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_invoice.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Bizum, Card, CheckScan, CustomerBalance, IdBankTransfer, Konbini, Payto, Pix, SepaDebit, Upi, UsBankAccount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

If paying by ‘acss_debit`, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.



745
746
747
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 745

def acss_debit
  @acss_debit
end

#bancontactObject (readonly)

If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.



747
748
749
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 747

def bancontact
  @bancontact
end

#bizumObject (readonly)

If paying by ‘bizum`, this sub-hash contains details about the Bizum payment method options to pass to the invoice’s PaymentIntent.



749
750
751
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 749

def bizum
  @bizum
end

#cardObject (readonly)

If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.



751
752
753
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 751

def card
  @card
end

#check_scanObject (readonly)

If paying by ‘check_scan`, this sub-hash contains details about the Check Scan payment method options to pass to the invoice’s PaymentIntent.



753
754
755
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 753

def check_scan
  @check_scan
end

#customer_balanceObject (readonly)

If paying by ‘customer_balance`, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.



755
756
757
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 755

def customer_balance
  @customer_balance
end

#id_bank_transferObject (readonly)

If paying by ‘id_bank_transfer`, this sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.



757
758
759
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 757

def id_bank_transfer
  @id_bank_transfer
end

#konbiniObject (readonly)

If paying by ‘konbini`, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.



759
760
761
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 759

def konbini
  @konbini
end

#paytoObject (readonly)

If paying by ‘payto`, this sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.



761
762
763
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 761

def payto
  @payto
end

#pixObject (readonly)

If paying by ‘pix`, this sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.



763
764
765
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 763

def pix
  @pix
end

#sepa_debitObject (readonly)

If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.



765
766
767
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 765

def sepa_debit
  @sepa_debit
end

#upiObject (readonly)

If paying by ‘upi`, this sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.



767
768
769
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 767

def upi
  @upi
end

#us_bank_accountObject (readonly)

If paying by ‘us_bank_account`, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.



769
770
771
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 769

def 
  @us_bank_account
end

Class Method Details

.field_remappingsObject



789
790
791
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 789

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 771

def self.inner_class_types
  @inner_class_types = {
    acss_debit: AcssDebit,
    bancontact: Bancontact,
    bizum: Bizum,
    card: Card,
    check_scan: CheckScan,
    customer_balance: CustomerBalance,
    id_bank_transfer: IdBankTransfer,
    konbini: Konbini,
    payto: Payto,
    pix: Pix,
    sepa_debit: SepaDebit,
    upi: Upi,
    us_bank_account: UsBankAccount,
  }
end