Class: Stripe::QuotePreviewInvoice::PaymentSettings::PaymentMethodOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewInvoice::PaymentSettings::PaymentMethodOptions
- Defined in:
- lib/stripe/resources/quote_preview_invoice.rb
Defined Under Namespace
Classes: AcssDebit, Bancontact, Card, CustomerBalance, IdBankTransfer, Konbini, Pix, SepaDebit, Upi, UsBankAccount
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
If paying by ‘acss_debit`, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
-
#bancontact ⇒ Object
readonly
If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
-
#card ⇒ Object
readonly
If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
-
#customer_balance ⇒ Object
readonly
If paying by ‘customer_balance`, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
-
#id_bank_transfer ⇒ Object
readonly
If paying by ‘id_bank_transfer`, this sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.
-
#konbini ⇒ Object
readonly
If paying by ‘konbini`, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
-
#pix ⇒ Object
readonly
If paying by ‘pix`, this sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.
-
#sepa_debit ⇒ Object
readonly
If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
-
#upi ⇒ Object
readonly
If paying by ‘upi`, this sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.
-
#us_bank_account ⇒ Object
readonly
If paying by ‘us_bank_account`, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
If paying by ‘acss_debit`, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
667 668 669 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 667 def acss_debit @acss_debit end |
#bancontact ⇒ Object (readonly)
If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
669 670 671 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 669 def bancontact @bancontact end |
#card ⇒ Object (readonly)
If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
671 672 673 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 671 def card @card end |
#customer_balance ⇒ Object (readonly)
If paying by ‘customer_balance`, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
673 674 675 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 673 def customer_balance @customer_balance end |
#id_bank_transfer ⇒ Object (readonly)
If paying by ‘id_bank_transfer`, this sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.
675 676 677 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 675 def id_bank_transfer @id_bank_transfer end |
#konbini ⇒ Object (readonly)
If paying by ‘konbini`, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
677 678 679 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 677 def konbini @konbini end |
#pix ⇒ Object (readonly)
If paying by ‘pix`, this sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.
679 680 681 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 679 def pix @pix end |
#sepa_debit ⇒ Object (readonly)
If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
681 682 683 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 681 def sepa_debit @sepa_debit end |
#upi ⇒ Object (readonly)
If paying by ‘upi`, this sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.
683 684 685 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 683 def upi @upi end |
#us_bank_account ⇒ Object (readonly)
If paying by ‘us_bank_account`, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
685 686 687 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 685 def us_bank_account @us_bank_account end |
Class Method Details
.field_remappings ⇒ Object
702 703 704 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 702 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
687 688 689 690 691 692 693 694 695 696 697 698 699 700 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 687 def self.inner_class_types @inner_class_types = { acss_debit: AcssDebit, bancontact: Bancontact, card: Card, customer_balance: CustomerBalance, id_bank_transfer: IdBankTransfer, konbini: Konbini, pix: Pix, sepa_debit: SepaDebit, upi: Upi, us_bank_account: UsBankAccount, } end |