Class: Stripe::QuotePreviewInvoice::PaymentSettings::PaymentMethodOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_invoice.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Card, CustomerBalance, IdBankTransfer, Konbini, Pix, SepaDebit, Upi, UsBankAccount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

If paying by ‘acss_debit`, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.



651
652
653
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 651

def acss_debit
  @acss_debit
end

#bancontactObject (readonly)

If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.



653
654
655
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 653

def bancontact
  @bancontact
end

#cardObject (readonly)

If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.



655
656
657
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 655

def card
  @card
end

#customer_balanceObject (readonly)

If paying by ‘customer_balance`, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.



657
658
659
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 657

def customer_balance
  @customer_balance
end

#id_bank_transferObject (readonly)

If paying by ‘id_bank_transfer`, this sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.



659
660
661
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 659

def id_bank_transfer
  @id_bank_transfer
end

#konbiniObject (readonly)

If paying by ‘konbini`, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.



661
662
663
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 661

def konbini
  @konbini
end

#pixObject (readonly)

If paying by ‘pix`, this sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.



663
664
665
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 663

def pix
  @pix
end

#sepa_debitObject (readonly)

If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.



665
666
667
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 665

def sepa_debit
  @sepa_debit
end

#upiObject (readonly)

If paying by ‘upi`, this sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.



667
668
669
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 667

def upi
  @upi
end

#us_bank_accountObject (readonly)

If paying by ‘us_bank_account`, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.



669
670
671
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 669

def 
  @us_bank_account
end

Class Method Details

.field_remappingsObject



686
687
688
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 686

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



671
672
673
674
675
676
677
678
679
680
681
682
683
684
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 671

def self.inner_class_types
  @inner_class_types = {
    acss_debit: AcssDebit,
    bancontact: Bancontact,
    card: Card,
    customer_balance: CustomerBalance,
    id_bank_transfer: IdBankTransfer,
    konbini: Konbini,
    pix: Pix,
    sepa_debit: SepaDebit,
    upi: Upi,
    us_bank_account: UsBankAccount,
  }
end