Class: Stripe::QuotePreviewInvoice::PaymentSettings::PaymentMethodOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_invoice.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Card, CustomerBalance, IdBankTransfer, Konbini, SepaDebit, Upi, UsBankAccount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

If paying by ‘acss_debit`, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.



638
639
640
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 638

def acss_debit
  @acss_debit
end

#bancontactObject (readonly)

If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.



640
641
642
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 640

def bancontact
  @bancontact
end

#cardObject (readonly)

If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.



642
643
644
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 642

def card
  @card
end

#customer_balanceObject (readonly)

If paying by ‘customer_balance`, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.



644
645
646
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 644

def customer_balance
  @customer_balance
end

#id_bank_transferObject (readonly)

If paying by ‘id_bank_transfer`, this sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.



646
647
648
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 646

def id_bank_transfer
  @id_bank_transfer
end

#konbiniObject (readonly)

If paying by ‘konbini`, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.



648
649
650
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 648

def konbini
  @konbini
end

#sepa_debitObject (readonly)

If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.



650
651
652
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 650

def sepa_debit
  @sepa_debit
end

#upiObject (readonly)

If paying by ‘upi`, this sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.



652
653
654
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 652

def upi
  @upi
end

#us_bank_accountObject (readonly)

If paying by ‘us_bank_account`, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.



654
655
656
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 654

def 
  @us_bank_account
end

Class Method Details

.field_remappingsObject



670
671
672
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 670

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



656
657
658
659
660
661
662
663
664
665
666
667
668
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 656

def self.inner_class_types
  @inner_class_types = {
    acss_debit: AcssDebit,
    bancontact: Bancontact,
    card: Card,
    customer_balance: CustomerBalance,
    id_bank_transfer: IdBankTransfer,
    konbini: Konbini,
    sepa_debit: SepaDebit,
    upi: Upi,
    us_bank_account: UsBankAccount,
  }
end