Class: Stripe::QuotePreviewInvoice::PaymentSettings::PaymentMethodOptions::Card
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewInvoice::PaymentSettings::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/resources/quote_preview_invoice.rb
Defined Under Namespace
Classes: Installments
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#installments ⇒ Object
readonly
Attribute for field installments.
-
#request_three_d_secure ⇒ Object
readonly
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#installments ⇒ Object (readonly)
Attribute for field installments
546 547 548 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 546 def installments @installments end |
#request_three_d_secure ⇒ Object (readonly)
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements. However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. Read our guide on manually requesting 3D Secure for more information on how this configuration interacts with Radar and our SCA Engine.
548 549 550 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 548 def request_three_d_secure @request_three_d_secure end |
Class Method Details
.field_remappings ⇒ Object
554 555 556 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 554 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
550 551 552 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 550 def self.inner_class_types @inner_class_types = { installments: Installments } end |