Class: Stripe::QuotePreviewInvoice::PaymentSettings::PaymentMethodOptions::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_invoice.rb

Defined Under Namespace

Classes: Installments

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#installmentsObject (readonly)

Attribute for field installments



496
497
498
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 496

def installments
  @installments
end

#request_three_d_secureObject (readonly)

We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](docs.stripe.com/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. Read our guide on [manually requesting 3D Secure](docs.stripe.com/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.



498
499
500
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 498

def request_three_d_secure
  @request_three_d_secure
end

Class Method Details

.field_remappingsObject



504
505
506
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 504

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



500
501
502
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 500

def self.inner_class_types
  @inner_class_types = { installments: Installments }
end