Class: Stripe::QuotePreviewInvoice::PaymentSettings::PaymentMethodOptions::CustomerBalance
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewInvoice::PaymentSettings::PaymentMethodOptions::CustomerBalance
- Defined in:
- lib/stripe/resources/quote_preview_invoice.rb
Defined Under Namespace
Classes: BankTransfer
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_transfer ⇒ Object
readonly
Attribute for field bank_transfer.
-
#funding_type ⇒ Object
readonly
The funding method type to be used when there are not enough funds in the customer balance.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_transfer ⇒ Object (readonly)
Attribute for field bank_transfer
592 593 594 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 592 def bank_transfer @bank_transfer end |
#funding_type ⇒ Object (readonly)
The funding method type to be used when there are not enough funds in the customer balance. Permitted values include: ‘bank_transfer`.
594 595 596 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 594 def funding_type @funding_type end |
Class Method Details
.field_remappings ⇒ Object
600 601 602 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 600 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
596 597 598 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 596 def self.inner_class_types @inner_class_types = { bank_transfer: BankTransfer } end |