Class: Stripe::QuotePreviewInvoice::Rendering

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_invoice.rb

Defined Under Namespace

Classes: Pdf

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_tax_displayObject (readonly)

How line-item prices and amounts will be displayed with respect to tax on invoice PDFs.



751
752
753
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 751

def amount_tax_display
  @amount_tax_display
end

#pdfObject (readonly)

Invoice pdf rendering options



753
754
755
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 753

def pdf
  @pdf
end

#templateObject (readonly)

ID of the rendering template that the invoice is formatted by.



755
756
757
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 755

def template
  @template
end

#template_versionObject (readonly)

Version of the rendering template that the invoice is using.



757
758
759
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 757

def template_version
  @template_version
end

Class Method Details

.field_remappingsObject



763
764
765
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 763

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



759
760
761
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 759

def self.inner_class_types
  @inner_class_types = { pdf: Pdf }
end