Class: Stripe::QuotePreviewInvoice::Rendering

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_invoice.rb

Defined Under Namespace

Classes: Pdf

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_tax_displayObject (readonly)

How line-item prices and amounts will be displayed with respect to tax on invoice PDFs.



810
811
812
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 810

def amount_tax_display
  @amount_tax_display
end

#pdfObject (readonly)

Invoice pdf rendering options



812
813
814
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 812

def pdf
  @pdf
end

#templateObject (readonly)

ID of the rendering template that the invoice is formatted by.



814
815
816
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 814

def template
  @template
end

#template_versionObject (readonly)

Version of the rendering template that the invoice is using.



816
817
818
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 816

def template_version
  @template_version
end

Class Method Details

.field_remappingsObject



822
823
824
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 822

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



818
819
820
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 818

def self.inner_class_types
  @inner_class_types = { pdf: Pdf }
end