Class: Stripe::QuotePreviewInvoice::Rendering

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_invoice.rb

Defined Under Namespace

Classes: Pdf

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_tax_displayObject (readonly)

How line-item prices and amounts will be displayed with respect to tax on invoice PDFs.



385
386
387
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 385

def amount_tax_display
  @amount_tax_display
end

#pdfObject (readonly)

Invoice pdf rendering options



387
388
389
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 387

def pdf
  @pdf
end

#templateObject (readonly)

ID of the rendering template that the invoice is formatted by.



389
390
391
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 389

def template
  @template
end

#template_versionObject (readonly)

Version of the rendering template that the invoice is using.



391
392
393
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 391

def template_version
  @template_version
end