Class: Stripe::QuotePreviewInvoice::ShippingCost::Tax
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewInvoice::ShippingCost::Tax
- Defined in:
- lib/stripe/resources/quote_preview_invoice.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount of tax applied for this rate.
-
#rate ⇒ Object
readonly
Tax rates can be applied to invoices, subscriptions and Checkout Sessions to collect tax.
-
#taxability_reason ⇒ Object
readonly
The reasoning behind this tax, for example, if the product is tax exempt.
-
#taxable_amount ⇒ Object
readonly
The amount on which tax is calculated, in cents (or local equivalent).
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount of tax applied for this rate.
895 896 897 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 895 def amount @amount end |
#rate ⇒ Object (readonly)
Tax rates can be applied to invoices, subscriptions and Checkout Sessions to collect tax.
Related guide: Tax rates
899 900 901 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 899 def rate @rate end |
#taxability_reason ⇒ Object (readonly)
The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.
901 902 903 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 901 def taxability_reason @taxability_reason end |
#taxable_amount ⇒ Object (readonly)
The amount on which tax is calculated, in cents (or local equivalent).
903 904 905 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 903 def taxable_amount @taxable_amount end |
Class Method Details
.field_remappings ⇒ Object
909 910 911 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 909 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
905 906 907 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 905 def self.inner_class_types @inner_class_types = {} end |