Class: Stripe::QuotePreviewInvoice::ThresholdReason::ItemReason

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_invoice.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#line_item_idsObject (readonly)

The IDs of the line items that triggered the threshold invoice.



893
894
895
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 893

def line_item_ids
  @line_item_ids
end

#usage_gteObject (readonly)

The quantity threshold boundary that applied to the given line item.



895
896
897
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 895

def usage_gte
  @usage_gte
end

Class Method Details

.field_remappingsObject



901
902
903
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 901

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



897
898
899
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 897

def self.inner_class_types
  @inner_class_types = {}
end