Class: Stripe::QuotePreviewInvoice::TotalTax
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewInvoice::TotalTax
- Defined in:
- lib/stripe/resources/quote_preview_invoice.rb
Defined Under Namespace
Classes: TaxRateDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount of the tax, in cents (or local equivalent).
-
#tax_behavior ⇒ Object
readonly
Whether this tax is inclusive or exclusive.
-
#tax_rate_details ⇒ Object
readonly
Additional details about the tax rate.
-
#taxability_reason ⇒ Object
readonly
The reasoning behind this tax, for example, if the product is tax exempt.
-
#taxable_amount ⇒ Object
readonly
The amount on which tax is calculated, in cents (or local equivalent).
-
#type ⇒ Object
readonly
The type of tax information.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount of the tax, in cents (or local equivalent).
950 951 952 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 950 def amount @amount end |
#tax_behavior ⇒ Object (readonly)
Whether this tax is inclusive or exclusive.
952 953 954 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 952 def tax_behavior @tax_behavior end |
#tax_rate_details ⇒ Object (readonly)
Additional details about the tax rate. Only present when ‘type` is `tax_rate_details`.
954 955 956 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 954 def tax_rate_details @tax_rate_details end |
#taxability_reason ⇒ Object (readonly)
The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.
956 957 958 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 956 def taxability_reason @taxability_reason end |
#taxable_amount ⇒ Object (readonly)
The amount on which tax is calculated, in cents (or local equivalent).
958 959 960 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 958 def taxable_amount @taxable_amount end |
#type ⇒ Object (readonly)
The type of tax information.
960 961 962 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 960 def type @type end |
Class Method Details
.field_remappings ⇒ Object
966 967 968 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 966 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
962 963 964 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 962 def self.inner_class_types @inner_class_types = { tax_rate_details: TaxRateDetails } end |