Class: Stripe::QuotePreviewInvoice::TotalTax
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewInvoice::TotalTax
- Defined in:
- lib/stripe/resources/quote_preview_invoice.rb
Defined Under Namespace
Classes: TaxRateDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount of the tax, in cents (or local equivalent).
-
#tax_behavior ⇒ Object
readonly
Whether this tax is inclusive or exclusive.
-
#tax_rate_details ⇒ Object
readonly
Additional details about the tax rate.
-
#taxability_reason ⇒ Object
readonly
The reasoning behind this tax, for example, if the product is tax exempt.
-
#taxable_amount ⇒ Object
readonly
The amount on which tax is calculated, in cents (or local equivalent).
-
#type ⇒ Object
readonly
The type of tax information.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount of the tax, in cents (or local equivalent).
510 511 512 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 510 def amount @amount end |
#tax_behavior ⇒ Object (readonly)
Whether this tax is inclusive or exclusive.
512 513 514 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 512 def tax_behavior @tax_behavior end |
#tax_rate_details ⇒ Object (readonly)
Additional details about the tax rate. Only present when ‘type` is `tax_rate_details`.
514 515 516 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 514 def tax_rate_details @tax_rate_details end |
#taxability_reason ⇒ Object (readonly)
The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.
516 517 518 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 516 def taxability_reason @taxability_reason end |
#taxable_amount ⇒ Object (readonly)
The amount on which tax is calculated, in cents (or local equivalent).
518 519 520 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 518 def taxable_amount @taxable_amount end |
#type ⇒ Object (readonly)
The type of tax information.
520 521 522 |
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 520 def type @type end |