Class: Stripe::QuotePreviewInvoice::TotalTaxAmount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_invoice.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount, in cents (or local equivalent), of the tax.



456
457
458
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 456

def amount
  @amount
end

#inclusiveObject (readonly)

Whether this tax amount is inclusive or exclusive.



458
459
460
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 458

def inclusive
  @inclusive
end

#tax_rateObject (readonly)

The tax rate that was applied to get this tax amount.



460
461
462
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 460

def tax_rate
  @tax_rate
end

#taxability_reasonObject (readonly)

The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.



462
463
464
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 462

def taxability_reason
  @taxability_reason
end

#taxable_amountObject (readonly)

The amount on which tax is calculated, in cents (or local equivalent).



464
465
466
# File 'lib/stripe/resources/quote_preview_invoice.rb', line 464

def taxable_amount
  @taxable_amount
end