Class: Stripe::QuotePreviewSubscriptionSchedule

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Defined Under Namespace

Classes: AppliesTo, BillingMode, CurrentPhase, DefaultSettings, LastPriceMigrationError, Phase, Prebilling

Constant Summary collapse

OBJECT_NAME =
"quote_preview_subscription_schedule"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applicationObject (readonly)

ID of the Connect Application that created the schedule.



716
717
718
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 716

def application
  @application
end

#applies_toObject (readonly)

Attribute for field applies_to



718
719
720
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 718

def applies_to
  @applies_to
end

#billing_behaviorObject (readonly)

Configures when the subscription schedule generates prorations for phase transitions. Possible values are prorate_on_next_phase or prorate_up_front with the default being prorate_on_next_phase. prorate_on_next_phase will apply phase changes and generate prorations at transition time. prorate_up_front will bill for all phases within the current billing cycle up front.



720
721
722
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 720

def billing_behavior
  @billing_behavior
end

#billing_modeObject (readonly)

The billing mode of the subscription.



722
723
724
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 722

def billing_mode
  @billing_mode
end

#canceled_atObject (readonly)

Time at which the subscription schedule was canceled. Measured in seconds since the Unix epoch.



724
725
726
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 724

def canceled_at
  @canceled_at
end

#completed_atObject (readonly)

Time at which the subscription schedule was completed. Measured in seconds since the Unix epoch.



726
727
728
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 726

def completed_at
  @completed_at
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



728
729
730
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 728

def created
  @created
end

#current_phaseObject (readonly)

Object representing the start and end dates for the current phase of the subscription schedule, if it is active.



730
731
732
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 730

def current_phase
  @current_phase
end

#customerObject (readonly)

ID of the customer who owns the subscription schedule.



732
733
734
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 732

def customer
  @customer
end

#customer_accountObject (readonly)

ID of the account who owns the subscription schedule.



734
735
736
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 734

def 
  @customer_account
end

#default_settingsObject (readonly)

Attribute for field default_settings



736
737
738
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 736

def default_settings
  @default_settings
end

#end_behaviorObject (readonly)

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are release or cancel with the default being release. release will end the subscription schedule and keep the underlying subscription running. cancel will end the subscription schedule and cancel the underlying subscription.



738
739
740
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 738

def end_behavior
  @end_behavior
end

#idObject (readonly)

Unique identifier for the object.



740
741
742
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 740

def id
  @id
end

#last_price_migration_errorObject (readonly)

Details of the most recent price migration that failed for the subscription schedule.



742
743
744
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 742

def last_price_migration_error
  @last_price_migration_error
end

#livemodeObject (readonly)

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.



744
745
746
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 744

def livemode
  @livemode
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



746
747
748
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 746

def 
  @metadata
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value.



748
749
750
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 748

def object
  @object
end

#phasesObject (readonly)

Configuration for the subscription schedule's phases.



750
751
752
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 750

def phases
  @phases
end

#prebillingObject (readonly)

Time period and invoice for a Subscription billed in advance.



752
753
754
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 752

def prebilling
  @prebilling
end

#released_atObject (readonly)

Time at which the subscription schedule was released. Measured in seconds since the Unix epoch.



754
755
756
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 754

def released_at
  @released_at
end

#released_subscriptionObject (readonly)

ID of the subscription once managed by the subscription schedule (if it is released).



756
757
758
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 756

def released_subscription
  @released_subscription
end

#statusObject (readonly)

The present status of the subscription schedule. Possible values are not_started, active, completed, released, and canceled. You can read more about the different states in our behavior guide.



758
759
760
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 758

def status
  @status
end

#subscriptionObject (readonly)

ID of the subscription managed by the subscription schedule.



760
761
762
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 760

def subscription
  @subscription
end

#test_clockObject (readonly)

ID of the test clock this subscription schedule belongs to.



762
763
764
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 762

def test_clock
  @test_clock
end

Class Method Details

.field_remappingsObject



776
777
778
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 776

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



764
765
766
767
768
769
770
771
772
773
774
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 764

def self.inner_class_types
  @inner_class_types = {
    applies_to: AppliesTo,
    billing_mode: BillingMode,
    current_phase: CurrentPhase,
    default_settings: DefaultSettings,
    last_price_migration_error: LastPriceMigrationError,
    phases: Phase,
    prebilling: Prebilling,
  }
end

.object_nameObject



7
8
9
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 7

def self.object_name
  "quote_preview_subscription_schedule"
end