Class: Stripe::QuotePreviewSubscriptionSchedule
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::QuotePreviewSubscriptionSchedule
- Defined in:
- lib/stripe/resources/quote_preview_subscription_schedule.rb
Defined Under Namespace
Classes: AppliesTo, BillingMode, CurrentPhase, DefaultSettings, LastPriceMigrationError, Phase, Prebilling
Constant Summary collapse
- OBJECT_NAME =
"quote_preview_subscription_schedule"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#application ⇒ Object
readonly
ID of the Connect Application that created the schedule.
-
#applies_to ⇒ Object
readonly
Attribute for field applies_to.
-
#billing_behavior ⇒ Object
readonly
Configures when the subscription schedule generates prorations for phase transitions.
-
#billing_mode ⇒ Object
readonly
The billing mode of the subscription.
-
#canceled_at ⇒ Object
readonly
Time at which the subscription schedule was canceled.
-
#completed_at ⇒ Object
readonly
Time at which the subscription schedule was completed.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#current_phase ⇒ Object
readonly
Object representing the start and end dates for the current phase of the subscription schedule, if it is ‘active`.
-
#customer ⇒ Object
readonly
ID of the customer who owns the subscription schedule.
-
#customer_account ⇒ Object
readonly
ID of the account who owns the subscription schedule.
-
#default_settings ⇒ Object
readonly
Attribute for field default_settings.
-
#end_behavior ⇒ Object
readonly
Behavior of the subscription schedule and underlying subscription when it ends.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#last_price_migration_error ⇒ Object
readonly
Details of the most recent price migration that failed for the subscription schedule.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#phases ⇒ Object
readonly
Configuration for the subscription schedule’s phases.
-
#prebilling ⇒ Object
readonly
Time period and invoice for a Subscription billed in advance.
-
#released_at ⇒ Object
readonly
Time at which the subscription schedule was released.
-
#released_subscription ⇒ Object
readonly
ID of the subscription once managed by the subscription schedule (if it is released).
-
#status ⇒ Object
readonly
The present status of the subscription schedule.
-
#subscription ⇒ Object
readonly
ID of the subscription managed by the subscription schedule.
-
#test_clock ⇒ Object
readonly
ID of the test clock this subscription schedule belongs to.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#application ⇒ Object (readonly)
ID of the Connect Application that created the schedule.
670 671 672 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 670 def application @application end |
#applies_to ⇒ Object (readonly)
Attribute for field applies_to
672 673 674 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 672 def applies_to @applies_to end |
#billing_behavior ⇒ Object (readonly)
Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.
674 675 676 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 674 def billing_behavior @billing_behavior end |
#billing_mode ⇒ Object (readonly)
The billing mode of the subscription.
676 677 678 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 676 def billing_mode @billing_mode end |
#canceled_at ⇒ Object (readonly)
Time at which the subscription schedule was canceled. Measured in seconds since the Unix epoch.
678 679 680 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 678 def canceled_at @canceled_at end |
#completed_at ⇒ Object (readonly)
Time at which the subscription schedule was completed. Measured in seconds since the Unix epoch.
680 681 682 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 680 def completed_at @completed_at end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
682 683 684 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 682 def created @created end |
#current_phase ⇒ Object (readonly)
Object representing the start and end dates for the current phase of the subscription schedule, if it is ‘active`.
684 685 686 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 684 def current_phase @current_phase end |
#customer ⇒ Object (readonly)
ID of the customer who owns the subscription schedule.
686 687 688 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 686 def customer @customer end |
#customer_account ⇒ Object (readonly)
ID of the account who owns the subscription schedule.
688 689 690 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 688 def customer_account @customer_account end |
#default_settings ⇒ Object (readonly)
Attribute for field default_settings
690 691 692 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 690 def default_settings @default_settings end |
#end_behavior ⇒ Object (readonly)
Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.
692 693 694 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 692 def end_behavior @end_behavior end |
#id ⇒ Object (readonly)
Unique identifier for the object.
694 695 696 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 694 def id @id end |
#last_price_migration_error ⇒ Object (readonly)
Details of the most recent price migration that failed for the subscription schedule.
696 697 698 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 696 def last_price_migration_error @last_price_migration_error end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
698 699 700 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 698 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
700 701 702 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 700 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
702 703 704 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 702 def object @object end |
#phases ⇒ Object (readonly)
Configuration for the subscription schedule’s phases.
704 705 706 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 704 def phases @phases end |
#prebilling ⇒ Object (readonly)
Time period and invoice for a Subscription billed in advance.
706 707 708 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 706 def prebilling @prebilling end |
#released_at ⇒ Object (readonly)
Time at which the subscription schedule was released. Measured in seconds since the Unix epoch.
708 709 710 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 708 def released_at @released_at end |
#released_subscription ⇒ Object (readonly)
ID of the subscription once managed by the subscription schedule (if it is released).
710 711 712 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 710 def released_subscription @released_subscription end |
#status ⇒ Object (readonly)
The present status of the subscription schedule. Possible values are ‘not_started`, `active`, `completed`, `released`, and `canceled`. You can read more about the different states in our [behavior guide](docs.stripe.com/billing/subscriptions/subscription-schedules).
712 713 714 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 712 def status @status end |
#subscription ⇒ Object (readonly)
ID of the subscription managed by the subscription schedule.
714 715 716 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 714 def subscription @subscription end |
#test_clock ⇒ Object (readonly)
ID of the test clock this subscription schedule belongs to.
716 717 718 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 716 def test_clock @test_clock end |
Class Method Details
.field_remappings ⇒ Object
730 731 732 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 730 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
718 719 720 721 722 723 724 725 726 727 728 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 718 def self.inner_class_types @inner_class_types = { applies_to: AppliesTo, billing_mode: BillingMode, current_phase: CurrentPhase, default_settings: DefaultSettings, last_price_migration_error: LastPriceMigrationError, phases: Phase, prebilling: Prebilling, } end |
.object_name ⇒ Object
7 8 9 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 7 def self.object_name "quote_preview_subscription_schedule" end |