Class: Stripe::QuotePreviewSubscriptionSchedule

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Defined Under Namespace

Classes: AppliesTo, BillingMode, BillingSchedule, CurrentPhase, DefaultSettings, LastPriceMigrationError, Phase, Prebilling

Constant Summary collapse

OBJECT_NAME =
"quote_preview_subscription_schedule"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applicationObject (readonly)

ID of the Connect Application that created the schedule.



859
860
861
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 859

def application
  @application
end

#applies_toObject (readonly)

Attribute for field applies_to



861
862
863
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 861

def applies_to
  @applies_to
end

#billing_behaviorObject (readonly)

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



863
864
865
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 863

def billing_behavior
  @billing_behavior
end

#billing_modeObject (readonly)

The billing mode of the subscription.



865
866
867
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 865

def billing_mode
  @billing_mode
end

#billing_schedulesObject (readonly)

Billing schedules for this subscription schedule.



867
868
869
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 867

def billing_schedules
  @billing_schedules
end

#canceled_atObject (readonly)

Time at which the subscription schedule was canceled. Measured in seconds since the Unix epoch.



869
870
871
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 869

def canceled_at
  @canceled_at
end

#completed_atObject (readonly)

Time at which the subscription schedule was completed. Measured in seconds since the Unix epoch.



871
872
873
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 871

def completed_at
  @completed_at
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



873
874
875
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 873

def created
  @created
end

#current_phaseObject (readonly)

Object representing the start and end dates for the current phase of the subscription schedule, if it is ‘active`.



875
876
877
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 875

def current_phase
  @current_phase
end

#customerObject (readonly)

ID of the customer who owns the subscription schedule.



877
878
879
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 877

def customer
  @customer
end

#customer_accountObject (readonly)

ID of the account who owns the subscription schedule.



879
880
881
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 879

def 
  @customer_account
end

#default_settingsObject (readonly)

Attribute for field default_settings



881
882
883
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 881

def default_settings
  @default_settings
end

#end_behaviorObject (readonly)

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



883
884
885
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 883

def end_behavior
  @end_behavior
end

#idObject (readonly)

Unique identifier for the object.



885
886
887
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 885

def id
  @id
end

#last_price_migration_errorObject (readonly)

Details of the most recent price migration that failed for the subscription schedule.



887
888
889
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 887

def last_price_migration_error
  @last_price_migration_error
end

#latest_invoiceObject (readonly)

The most recent invoice this subscription schedule has generated.



889
890
891
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 889

def latest_invoice
  @latest_invoice
end

#livemodeObject (readonly)

If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.



891
892
893
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 891

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



893
894
895
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 893

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



895
896
897
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 895

def object
  @object
end

#phasesObject (readonly)

Configuration for the subscription schedule’s phases.



897
898
899
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 897

def phases
  @phases
end

#prebillingObject (readonly)

Time period and invoice for a Subscription billed in advance.



899
900
901
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 899

def prebilling
  @prebilling
end

#released_atObject (readonly)

Time at which the subscription schedule was released. Measured in seconds since the Unix epoch.



901
902
903
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 901

def released_at
  @released_at
end

#released_subscriptionObject (readonly)

ID of the subscription once managed by the subscription schedule (if it is released).



903
904
905
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 903

def released_subscription
  @released_subscription
end

#statusObject (readonly)

The present status of the subscription schedule. Possible values are ‘not_started`, `active`, `completed`, `released`, and `canceled`. You can read more about the different states in our [behavior guide](docs.stripe.com/billing/subscriptions/subscription-schedules).



905
906
907
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 905

def status
  @status
end

#subscriptionObject (readonly)

ID of the subscription managed by the subscription schedule.



907
908
909
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 907

def subscription
  @subscription
end

#test_clockObject (readonly)

ID of the test clock this subscription schedule belongs to.



909
910
911
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 909

def test_clock
  @test_clock
end

Class Method Details

.field_remappingsObject



924
925
926
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 924

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



911
912
913
914
915
916
917
918
919
920
921
922
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 911

def self.inner_class_types
  @inner_class_types = {
    applies_to: AppliesTo,
    billing_mode: BillingMode,
    billing_schedules: BillingSchedule,
    current_phase: CurrentPhase,
    default_settings: DefaultSettings,
    last_price_migration_error: LastPriceMigrationError,
    phases: Phase,
    prebilling: Prebilling,
  }
end

.object_nameObject



7
8
9
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 7

def self.object_name
  "quote_preview_subscription_schedule"
end