Class: Stripe::QuotePreviewSubscriptionSchedule

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Defined Under Namespace

Classes: AppliesTo, BillingMode, BillingSchedule, CurrentPhase, DefaultSettings, LastPriceMigrationError, Phase, Prebilling

Constant Summary collapse

OBJECT_NAME =
"quote_preview_subscription_schedule"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applicationObject (readonly)

ID of the Connect Application that created the schedule.



757
758
759
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 757

def application
  @application
end

#applies_toObject (readonly)

Attribute for field applies_to



759
760
761
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 759

def applies_to
  @applies_to
end

#billing_behaviorObject (readonly)

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



761
762
763
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 761

def billing_behavior
  @billing_behavior
end

#billing_modeObject (readonly)

The billing mode of the subscription.



763
764
765
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 763

def billing_mode
  @billing_mode
end

#billing_schedulesObject (readonly)

Billing schedules for this subscription schedule.



765
766
767
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 765

def billing_schedules
  @billing_schedules
end

#canceled_atObject (readonly)

Time at which the subscription schedule was canceled. Measured in seconds since the Unix epoch.



767
768
769
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 767

def canceled_at
  @canceled_at
end

#completed_atObject (readonly)

Time at which the subscription schedule was completed. Measured in seconds since the Unix epoch.



769
770
771
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 769

def completed_at
  @completed_at
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



771
772
773
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 771

def created
  @created
end

#current_phaseObject (readonly)

Object representing the start and end dates for the current phase of the subscription schedule, if it is ‘active`.



773
774
775
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 773

def current_phase
  @current_phase
end

#customerObject (readonly)

ID of the customer who owns the subscription schedule.



775
776
777
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 775

def customer
  @customer
end

#customer_accountObject (readonly)

ID of the account who owns the subscription schedule.



777
778
779
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 777

def 
  @customer_account
end

#default_settingsObject (readonly)

Attribute for field default_settings



779
780
781
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 779

def default_settings
  @default_settings
end

#end_behaviorObject (readonly)

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



781
782
783
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 781

def end_behavior
  @end_behavior
end

#idObject (readonly)

Unique identifier for the object.



783
784
785
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 783

def id
  @id
end

#last_price_migration_errorObject (readonly)

Details of the most recent price migration that failed for the subscription schedule.



785
786
787
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 785

def last_price_migration_error
  @last_price_migration_error
end

#latest_invoiceObject (readonly)

The most recent invoice this subscription schedule has generated.



787
788
789
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 787

def latest_invoice
  @latest_invoice
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



789
790
791
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 789

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



791
792
793
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 791

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



793
794
795
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 793

def object
  @object
end

#phasesObject (readonly)

Configuration for the subscription schedule’s phases.



795
796
797
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 795

def phases
  @phases
end

#prebillingObject (readonly)

Time period and invoice for a Subscription billed in advance.



797
798
799
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 797

def prebilling
  @prebilling
end

#released_atObject (readonly)

Time at which the subscription schedule was released. Measured in seconds since the Unix epoch.



799
800
801
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 799

def released_at
  @released_at
end

#released_subscriptionObject (readonly)

ID of the subscription once managed by the subscription schedule (if it is released).



801
802
803
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 801

def released_subscription
  @released_subscription
end

#statusObject (readonly)

The present status of the subscription schedule. Possible values are ‘not_started`, `active`, `completed`, `released`, and `canceled`. You can read more about the different states in our [behavior guide](docs.stripe.com/billing/subscriptions/subscription-schedules).



803
804
805
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 803

def status
  @status
end

#subscriptionObject (readonly)

ID of the subscription managed by the subscription schedule.



805
806
807
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 805

def subscription
  @subscription
end

#test_clockObject (readonly)

ID of the test clock this subscription schedule belongs to.



807
808
809
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 807

def test_clock
  @test_clock
end

Class Method Details

.field_remappingsObject



822
823
824
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 822

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



809
810
811
812
813
814
815
816
817
818
819
820
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 809

def self.inner_class_types
  @inner_class_types = {
    applies_to: AppliesTo,
    billing_mode: BillingMode,
    billing_schedules: BillingSchedule,
    current_phase: CurrentPhase,
    default_settings: DefaultSettings,
    last_price_migration_error: LastPriceMigrationError,
    phases: Phase,
    prebilling: Prebilling,
  }
end

.object_nameObject



7
8
9
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 7

def self.object_name
  "quote_preview_subscription_schedule"
end