Class: Stripe::QuotePreviewSubscriptionSchedule
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::QuotePreviewSubscriptionSchedule
- Defined in:
- lib/stripe/resources/quote_preview_subscription_schedule.rb
Defined Under Namespace
Classes: AppliesTo, BillingMode, BillingSchedule, CurrentPhase, DefaultSettings, LastPriceMigrationError, Phase, Prebilling
Constant Summary collapse
- OBJECT_NAME =
"quote_preview_subscription_schedule"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#application ⇒ Object
readonly
ID of the Connect Application that created the schedule.
-
#applies_to ⇒ Object
readonly
Attribute for field applies_to.
-
#billing_behavior ⇒ Object
readonly
Configures when the subscription schedule generates prorations for phase transitions.
-
#billing_mode ⇒ Object
readonly
The billing mode of the subscription.
-
#billing_schedules ⇒ Object
readonly
Billing schedules for this subscription schedule.
-
#canceled_at ⇒ Object
readonly
Time at which the subscription schedule was canceled.
-
#completed_at ⇒ Object
readonly
Time at which the subscription schedule was completed.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#current_phase ⇒ Object
readonly
Object representing the start and end dates for the current phase of the subscription schedule, if it is ‘active`.
-
#customer ⇒ Object
readonly
ID of the customer who owns the subscription schedule.
-
#customer_account ⇒ Object
readonly
ID of the account who owns the subscription schedule.
-
#default_settings ⇒ Object
readonly
Attribute for field default_settings.
-
#end_behavior ⇒ Object
readonly
Behavior of the subscription schedule and underlying subscription when it ends.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#last_price_migration_error ⇒ Object
readonly
Details of the most recent price migration that failed for the subscription schedule.
-
#latest_invoice ⇒ Object
readonly
The most recent invoice this subscription schedule has generated.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#phases ⇒ Object
readonly
Configuration for the subscription schedule’s phases.
-
#prebilling ⇒ Object
readonly
Time period and invoice for a Subscription billed in advance.
-
#released_at ⇒ Object
readonly
Time at which the subscription schedule was released.
-
#released_subscription ⇒ Object
readonly
ID of the subscription once managed by the subscription schedule (if it is released).
-
#status ⇒ Object
readonly
The present status of the subscription schedule.
-
#subscription ⇒ Object
readonly
ID of the subscription managed by the subscription schedule.
-
#test_clock ⇒ Object
readonly
ID of the test clock this subscription schedule belongs to.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#application ⇒ Object (readonly)
ID of the Connect Application that created the schedule.
837 838 839 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 837 def application @application end |
#applies_to ⇒ Object (readonly)
Attribute for field applies_to
839 840 841 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 839 def applies_to @applies_to end |
#billing_behavior ⇒ Object (readonly)
Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.
841 842 843 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 841 def billing_behavior @billing_behavior end |
#billing_mode ⇒ Object (readonly)
The billing mode of the subscription.
843 844 845 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 843 def billing_mode @billing_mode end |
#billing_schedules ⇒ Object (readonly)
Billing schedules for this subscription schedule.
885 886 887 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 885 def billing_schedules @billing_schedules end |
#canceled_at ⇒ Object (readonly)
Time at which the subscription schedule was canceled. Measured in seconds since the Unix epoch.
845 846 847 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 845 def canceled_at @canceled_at end |
#completed_at ⇒ Object (readonly)
Time at which the subscription schedule was completed. Measured in seconds since the Unix epoch.
847 848 849 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 847 def completed_at @completed_at end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
849 850 851 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 849 def created @created end |
#current_phase ⇒ Object (readonly)
Object representing the start and end dates for the current phase of the subscription schedule, if it is ‘active`.
851 852 853 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 851 def current_phase @current_phase end |
#customer ⇒ Object (readonly)
ID of the customer who owns the subscription schedule.
853 854 855 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 853 def customer @customer end |
#customer_account ⇒ Object (readonly)
ID of the account who owns the subscription schedule.
855 856 857 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 855 def customer_account @customer_account end |
#default_settings ⇒ Object (readonly)
Attribute for field default_settings
857 858 859 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 857 def default_settings @default_settings end |
#end_behavior ⇒ Object (readonly)
Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.
859 860 861 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 859 def end_behavior @end_behavior end |
#id ⇒ Object (readonly)
Unique identifier for the object.
861 862 863 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 861 def id @id end |
#last_price_migration_error ⇒ Object (readonly)
Details of the most recent price migration that failed for the subscription schedule.
863 864 865 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 863 def last_price_migration_error @last_price_migration_error end |
#latest_invoice ⇒ Object (readonly)
The most recent invoice this subscription schedule has generated.
887 888 889 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 887 def latest_invoice @latest_invoice end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
865 866 867 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 865 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
867 868 869 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 867 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
869 870 871 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 869 def object @object end |
#phases ⇒ Object (readonly)
Configuration for the subscription schedule’s phases.
871 872 873 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 871 def phases @phases end |
#prebilling ⇒ Object (readonly)
Time period and invoice for a Subscription billed in advance.
873 874 875 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 873 def prebilling @prebilling end |
#released_at ⇒ Object (readonly)
Time at which the subscription schedule was released. Measured in seconds since the Unix epoch.
875 876 877 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 875 def released_at @released_at end |
#released_subscription ⇒ Object (readonly)
ID of the subscription once managed by the subscription schedule (if it is released).
877 878 879 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 877 def released_subscription @released_subscription end |
#status ⇒ Object (readonly)
The present status of the subscription schedule. Possible values are ‘not_started`, `active`, `completed`, `released`, and `canceled`. You can read more about the different states in our [behavior guide](stripe.com/docs/billing/subscriptions/subscription-schedules).
879 880 881 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 879 def status @status end |
#subscription ⇒ Object (readonly)
ID of the subscription managed by the subscription schedule.
881 882 883 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 881 def subscription @subscription end |
#test_clock ⇒ Object (readonly)
ID of the test clock this subscription schedule belongs to.
883 884 885 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 883 def test_clock @test_clock end |
Class Method Details
.field_remappings ⇒ Object
902 903 904 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 902 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
889 890 891 892 893 894 895 896 897 898 899 900 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 889 def self.inner_class_types @inner_class_types = { applies_to: AppliesTo, billing_mode: BillingMode, current_phase: CurrentPhase, default_settings: DefaultSettings, last_price_migration_error: LastPriceMigrationError, phases: Phase, prebilling: Prebilling, billing_schedules: BillingSchedule, } end |
.object_name ⇒ Object
7 8 9 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 7 def self.object_name "quote_preview_subscription_schedule" end |