Class: Stripe::QuotePreviewSubscriptionSchedule
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::QuotePreviewSubscriptionSchedule
- Defined in:
- lib/stripe/resources/quote_preview_subscription_schedule.rb
Defined Under Namespace
Classes: AppliesTo, CurrentPhase, DefaultSettings, LastPriceMigrationError, Phase, Prebilling
Constant Summary collapse
- OBJECT_NAME =
"quote_preview_subscription_schedule"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#application ⇒ Object
readonly
ID of the Connect Application that created the schedule.
-
#applies_to ⇒ Object
readonly
Attribute for field applies_to.
-
#billing_behavior ⇒ Object
readonly
Configures when the subscription schedule generates prorations for phase transitions.
-
#billing_mode ⇒ Object
readonly
The [billing mode](/api/subscriptions/create#create_subscription-billing_mode) that will be used to process all future operations for the subscription schedule.
-
#canceled_at ⇒ Object
readonly
Time at which the subscription schedule was canceled.
-
#completed_at ⇒ Object
readonly
Time at which the subscription schedule was completed.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#current_phase ⇒ Object
readonly
Object representing the start and end dates for the current phase of the subscription schedule, if it is ‘active`.
-
#customer ⇒ Object
readonly
ID of the customer who owns the subscription schedule.
-
#customer_account ⇒ Object
readonly
ID of the account who owns the subscription schedule.
-
#default_settings ⇒ Object
readonly
Attribute for field default_settings.
-
#end_behavior ⇒ Object
readonly
Behavior of the subscription schedule and underlying subscription when it ends.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#last_price_migration_error ⇒ Object
readonly
Details of the most recent price migration that failed for the subscription schedule.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#phases ⇒ Object
readonly
Configuration for the subscription schedule’s phases.
-
#prebilling ⇒ Object
readonly
Time period and invoice for a Subscription billed in advance.
-
#released_at ⇒ Object
readonly
Time at which the subscription schedule was released.
-
#released_subscription ⇒ Object
readonly
ID of the subscription once managed by the subscription schedule (if it is released).
-
#status ⇒ Object
readonly
The present status of the subscription schedule.
-
#subscription ⇒ Object
readonly
ID of the subscription managed by the subscription schedule.
-
#test_clock ⇒ Object
readonly
ID of the test clock this subscription schedule belongs to.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#application ⇒ Object (readonly)
ID of the Connect Application that created the schedule.
316 317 318 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 316 def application @application end |
#applies_to ⇒ Object (readonly)
Attribute for field applies_to
318 319 320 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 318 def applies_to @applies_to end |
#billing_behavior ⇒ Object (readonly)
Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.
320 321 322 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 320 def billing_behavior @billing_behavior end |
#billing_mode ⇒ Object (readonly)
The [billing mode](/api/subscriptions/create#create_subscription-billing_mode) that will be used to process all future operations for the subscription schedule.
322 323 324 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 322 def billing_mode @billing_mode end |
#canceled_at ⇒ Object (readonly)
Time at which the subscription schedule was canceled. Measured in seconds since the Unix epoch.
324 325 326 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 324 def canceled_at @canceled_at end |
#completed_at ⇒ Object (readonly)
Time at which the subscription schedule was completed. Measured in seconds since the Unix epoch.
326 327 328 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 326 def completed_at @completed_at end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
328 329 330 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 328 def created @created end |
#current_phase ⇒ Object (readonly)
Object representing the start and end dates for the current phase of the subscription schedule, if it is ‘active`.
330 331 332 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 330 def current_phase @current_phase end |
#customer ⇒ Object (readonly)
ID of the customer who owns the subscription schedule.
332 333 334 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 332 def customer @customer end |
#customer_account ⇒ Object (readonly)
ID of the account who owns the subscription schedule.
334 335 336 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 334 def customer_account @customer_account end |
#default_settings ⇒ Object (readonly)
Attribute for field default_settings
336 337 338 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 336 def default_settings @default_settings end |
#end_behavior ⇒ Object (readonly)
Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.
338 339 340 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 338 def end_behavior @end_behavior end |
#id ⇒ Object (readonly)
Unique identifier for the object.
340 341 342 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 340 def id @id end |
#last_price_migration_error ⇒ Object (readonly)
Details of the most recent price migration that failed for the subscription schedule.
342 343 344 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 342 def last_price_migration_error @last_price_migration_error end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
344 345 346 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 344 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
346 347 348 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 346 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
348 349 350 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 348 def object @object end |
#phases ⇒ Object (readonly)
Configuration for the subscription schedule’s phases.
350 351 352 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 350 def phases @phases end |
#prebilling ⇒ Object (readonly)
Time period and invoice for a Subscription billed in advance.
352 353 354 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 352 def prebilling @prebilling end |
#released_at ⇒ Object (readonly)
Time at which the subscription schedule was released. Measured in seconds since the Unix epoch.
354 355 356 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 354 def released_at @released_at end |
#released_subscription ⇒ Object (readonly)
ID of the subscription once managed by the subscription schedule (if it is released).
356 357 358 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 356 def released_subscription @released_subscription end |
#status ⇒ Object (readonly)
The present status of the subscription schedule. Possible values are ‘not_started`, `active`, `completed`, `released`, and `canceled`. You can read more about the different states in our [behavior guide](stripe.com/docs/billing/subscriptions/subscription-schedules).
358 359 360 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 358 def status @status end |
#subscription ⇒ Object (readonly)
ID of the subscription managed by the subscription schedule.
360 361 362 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 360 def subscription @subscription end |
#test_clock ⇒ Object (readonly)
ID of the test clock this subscription schedule belongs to.
362 363 364 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 362 def test_clock @test_clock end |
Class Method Details
.object_name ⇒ Object
7 8 9 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 7 def self.object_name "quote_preview_subscription_schedule" end |