Class: Stripe::QuotePreviewSubscriptionSchedule

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Defined Under Namespace

Classes: AppliesTo, CurrentPhase, DefaultSettings, LastPriceMigrationError, Phase, Prebilling

Constant Summary collapse

OBJECT_NAME =
"quote_preview_subscription_schedule"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applicationObject (readonly)

ID of the Connect Application that created the schedule.



291
292
293
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 291

def application
  @application
end

#applies_toObject (readonly)

Attribute for field applies_to



293
294
295
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 293

def applies_to
  @applies_to
end

#billing_behaviorObject (readonly)

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



295
296
297
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 295

def billing_behavior
  @billing_behavior
end

#billing_modeObject (readonly)

The [billing mode](/api/subscriptions/create#create_subscription-billing_mode) that will be used to process all future operations for the subscription schedule.



297
298
299
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 297

def billing_mode
  @billing_mode
end

#canceled_atObject (readonly)

Time at which the subscription schedule was canceled. Measured in seconds since the Unix epoch.



299
300
301
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 299

def canceled_at
  @canceled_at
end

#completed_atObject (readonly)

Time at which the subscription schedule was completed. Measured in seconds since the Unix epoch.



301
302
303
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 301

def completed_at
  @completed_at
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



303
304
305
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 303

def created
  @created
end

#current_phaseObject (readonly)

Object representing the start and end dates for the current phase of the subscription schedule, if it is ‘active`.



305
306
307
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 305

def current_phase
  @current_phase
end

#customerObject (readonly)

ID of the customer who owns the subscription schedule.



307
308
309
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 307

def customer
  @customer
end

#customer_accountObject (readonly)

ID of the account who owns the subscription schedule.



309
310
311
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 309

def 
  @customer_account
end

#default_settingsObject (readonly)

Attribute for field default_settings



311
312
313
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 311

def default_settings
  @default_settings
end

#end_behaviorObject (readonly)

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



313
314
315
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 313

def end_behavior
  @end_behavior
end

#idObject (readonly)

Unique identifier for the object.



315
316
317
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 315

def id
  @id
end

#last_price_migration_errorObject (readonly)

Details of the most recent price migration that failed for the subscription schedule.



317
318
319
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 317

def last_price_migration_error
  @last_price_migration_error
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



319
320
321
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 319

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



321
322
323
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 321

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



323
324
325
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 323

def object
  @object
end

#phasesObject (readonly)

Configuration for the subscription schedule’s phases.



325
326
327
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 325

def phases
  @phases
end

#prebillingObject (readonly)

Time period and invoice for a Subscription billed in advance.



327
328
329
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 327

def prebilling
  @prebilling
end

#released_atObject (readonly)

Time at which the subscription schedule was released. Measured in seconds since the Unix epoch.



329
330
331
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 329

def released_at
  @released_at
end

#released_subscriptionObject (readonly)

ID of the subscription once managed by the subscription schedule (if it is released).



331
332
333
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 331

def released_subscription
  @released_subscription
end

#statusObject (readonly)

The present status of the subscription schedule. Possible values are ‘not_started`, `active`, `completed`, `released`, and `canceled`. You can read more about the different states in our [behavior guide](stripe.com/docs/billing/subscriptions/subscription-schedules).



333
334
335
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 333

def status
  @status
end

#subscriptionObject (readonly)

ID of the subscription managed by the subscription schedule.



335
336
337
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 335

def subscription
  @subscription
end

#test_clockObject (readonly)

ID of the test clock this subscription schedule belongs to.



337
338
339
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 337

def test_clock
  @test_clock
end

Class Method Details

.object_nameObject



7
8
9
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 7

def self.object_name
  "quote_preview_subscription_schedule"
end