Class: Stripe::QuotePreviewSubscriptionSchedule
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::QuotePreviewSubscriptionSchedule
- Defined in:
- lib/stripe/resources/quote_preview_subscription_schedule.rb
Defined Under Namespace
Classes: AppliesTo, CurrentPhase, DefaultSettings, LastPriceMigrationError, Phase, Prebilling
Constant Summary collapse
- OBJECT_NAME =
"quote_preview_subscription_schedule"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#application ⇒ Object
readonly
ID of the Connect Application that created the schedule.
-
#applies_to ⇒ Object
readonly
Attribute for field applies_to.
-
#billing_behavior ⇒ Object
readonly
Configures when the subscription schedule generates prorations for phase transitions.
-
#canceled_at ⇒ Object
readonly
Time at which the subscription schedule was canceled.
-
#completed_at ⇒ Object
readonly
Time at which the subscription schedule was completed.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#current_phase ⇒ Object
readonly
Object representing the start and end dates for the current phase of the subscription schedule, if it is ‘active`.
-
#customer ⇒ Object
readonly
ID of the customer who owns the subscription schedule.
-
#default_settings ⇒ Object
readonly
Attribute for field default_settings.
-
#end_behavior ⇒ Object
readonly
Behavior of the subscription schedule and underlying subscription when it ends.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#last_price_migration_error ⇒ Object
readonly
Details of the most recent price migration that failed for the subscription schedule.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#phases ⇒ Object
readonly
Configuration for the subscription schedule’s phases.
-
#prebilling ⇒ Object
readonly
Time period and invoice for a Subscription billed in advance.
-
#released_at ⇒ Object
readonly
Time at which the subscription schedule was released.
-
#released_subscription ⇒ Object
readonly
ID of the subscription once managed by the subscription schedule (if it is released).
-
#status ⇒ Object
readonly
The present status of the subscription schedule.
-
#subscription ⇒ Object
readonly
ID of the subscription managed by the subscription schedule.
-
#test_clock ⇒ Object
readonly
ID of the test clock this subscription schedule belongs to.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#application ⇒ Object (readonly)
ID of the Connect Application that created the schedule.
126 127 128 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 126 def application @application end |
#applies_to ⇒ Object (readonly)
Attribute for field applies_to
128 129 130 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 128 def applies_to @applies_to end |
#billing_behavior ⇒ Object (readonly)
Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.
130 131 132 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 130 def billing_behavior @billing_behavior end |
#canceled_at ⇒ Object (readonly)
Time at which the subscription schedule was canceled. Measured in seconds since the Unix epoch.
132 133 134 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 132 def canceled_at @canceled_at end |
#completed_at ⇒ Object (readonly)
Time at which the subscription schedule was completed. Measured in seconds since the Unix epoch.
134 135 136 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 134 def completed_at @completed_at end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
136 137 138 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 136 def created @created end |
#current_phase ⇒ Object (readonly)
Object representing the start and end dates for the current phase of the subscription schedule, if it is ‘active`.
138 139 140 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 138 def current_phase @current_phase end |
#customer ⇒ Object (readonly)
ID of the customer who owns the subscription schedule.
140 141 142 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 140 def customer @customer end |
#default_settings ⇒ Object (readonly)
Attribute for field default_settings
142 143 144 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 142 def default_settings @default_settings end |
#end_behavior ⇒ Object (readonly)
Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.
144 145 146 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 144 def end_behavior @end_behavior end |
#id ⇒ Object (readonly)
Unique identifier for the object.
146 147 148 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 146 def id @id end |
#last_price_migration_error ⇒ Object (readonly)
Details of the most recent price migration that failed for the subscription schedule.
148 149 150 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 148 def last_price_migration_error @last_price_migration_error end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
150 151 152 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 150 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
152 153 154 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 152 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
154 155 156 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 154 def object @object end |
#phases ⇒ Object (readonly)
Configuration for the subscription schedule’s phases.
156 157 158 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 156 def phases @phases end |
#prebilling ⇒ Object (readonly)
Time period and invoice for a Subscription billed in advance.
158 159 160 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 158 def prebilling @prebilling end |
#released_at ⇒ Object (readonly)
Time at which the subscription schedule was released. Measured in seconds since the Unix epoch.
160 161 162 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 160 def released_at @released_at end |
#released_subscription ⇒ Object (readonly)
ID of the subscription once managed by the subscription schedule (if it is released).
162 163 164 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 162 def released_subscription @released_subscription end |
#status ⇒ Object (readonly)
The present status of the subscription schedule. Possible values are ‘not_started`, `active`, `completed`, `released`, and `canceled`. You can read more about the different states in our [behavior guide](stripe.com/docs/billing/subscriptions/subscription-schedules).
164 165 166 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 164 def status @status end |
#subscription ⇒ Object (readonly)
ID of the subscription managed by the subscription schedule.
166 167 168 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 166 def subscription @subscription end |
#test_clock ⇒ Object (readonly)
ID of the test clock this subscription schedule belongs to.
168 169 170 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 168 def test_clock @test_clock end |
Class Method Details
.object_name ⇒ Object
7 8 9 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 7 def self.object_name "quote_preview_subscription_schedule" end |