Class: Stripe::QuotePreviewSubscriptionSchedule::BillingSchedule::BillUntil
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewSubscriptionSchedule::BillingSchedule::BillUntil
- Defined in:
- lib/stripe/resources/quote_preview_subscription_schedule.rb
Defined Under Namespace
Classes: Duration
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#computed_timestamp ⇒ Object
readonly
The timestamp the billing schedule will apply until.
-
#duration ⇒ Object
readonly
Specifies the billing period.
-
#timestamp ⇒ Object
readonly
If specified, the billing schedule will apply until the specified timestamp.
-
#type ⇒ Object
readonly
Describes how the billing schedule will determine the end date.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#computed_timestamp ⇒ Object (readonly)
The timestamp the billing schedule will apply until.
106 107 108 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 106 def @computed_timestamp end |
#duration ⇒ Object (readonly)
Specifies the billing period.
108 109 110 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 108 def duration @duration end |
#timestamp ⇒ Object (readonly)
If specified, the billing schedule will apply until the specified timestamp.
110 111 112 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 110 def @timestamp end |
#type ⇒ Object (readonly)
Describes how the billing schedule will determine the end date. Either ‘duration` or `timestamp`.
112 113 114 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 112 def type @type end |
Class Method Details
.field_remappings ⇒ Object
118 119 120 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 118 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
114 115 116 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 114 def self.inner_class_types @inner_class_types = { duration: Duration } end |