Class: Stripe::QuotePreviewSubscriptionSchedule::BillingSchedule::BillUntil

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration, LineEndsAt

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amendment_endObject (readonly)

Use an index to specify the position of an amendment to end prebilling with.



795
796
797
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 795

def amendment_end
  @amendment_end
end

#computed_timestampObject (readonly)

The timestamp the billing schedule will apply until.



797
798
799
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 797

def computed_timestamp
  @computed_timestamp
end

#durationObject (readonly)

Specifies the billing period.



799
800
801
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 799

def duration
  @duration
end

#line_ends_atObject (readonly)

Lets you bill the period ending at a particular Quote line.



801
802
803
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 801

def line_ends_at
  @line_ends_at
end

#timestampObject (readonly)

If specified, the billing schedule will apply until the specified timestamp.



803
804
805
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 803

def timestamp
  @timestamp
end

#typeObject (readonly)

Describes how the billing schedule will determine the end date. Either ‘duration` or `timestamp`.



805
806
807
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 805

def type
  @type
end

Class Method Details

.field_remappingsObject



815
816
817
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 815

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



807
808
809
810
811
812
813
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 807

def self.inner_class_types
  @inner_class_types = {
    amendment_end: AmendmentEnd,
    duration: Duration,
    line_ends_at: LineEndsAt,
  }
end