Class: Stripe::QuotePreviewSubscriptionSchedule::DefaultSettings

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Defined Under Namespace

Classes: AutomaticTax, BillingThresholds, InvoiceSettings, TransferData

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#application_fee_percentObject (readonly)

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account during this phase of the schedule.



165
166
167
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 165

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject (readonly)

Attribute for field automatic_tax



167
168
169
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 167

def automatic_tax
  @automatic_tax
end

#billing_cycle_anchorObject (readonly)

Possible values are ‘phase_start` or `automatic`. If `phase_start` then billing cycle anchor of the subscription is set to the start of the phase when entering the phase. If `automatic` then the billing cycle anchor is automatically modified as needed when entering the phase. For more information, see the billing cycle [documentation](docs.stripe.com/billing/subscriptions/billing-cycle).



169
170
171
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 169

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_thresholdsObject (readonly)

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period



171
172
173
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 171

def billing_thresholds
  @billing_thresholds
end

#collection_methodObject (readonly)

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay the underlying subscription at the end of each billing cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`.



173
174
175
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 173

def collection_method
  @collection_method
end

#default_payment_methodObject (readonly)

ID of the default payment method for the subscription schedule. If not set, invoices will use the default payment method in the customer’s invoice settings.



175
176
177
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 175

def default_payment_method
  @default_payment_method
end

#descriptionObject (readonly)

Subscription description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



177
178
179
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 177

def description
  @description
end

#invoice_settingsObject (readonly)

Attribute for field invoice_settings



179
180
181
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 179

def invoice_settings
  @invoice_settings
end

#on_behalf_ofObject (readonly)

The account (if any) the charge was made on behalf of for charges associated with the schedule’s subscription. See the Connect documentation for details.



181
182
183
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 181

def on_behalf_of
  @on_behalf_of
end

#transfer_dataObject (readonly)

The account (if any) the associated subscription’s payments will be attributed to for tax reporting, and where funds from each payment will be transferred to for each of the subscription’s invoices.



183
184
185
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 183

def transfer_data
  @transfer_data
end

Class Method Details

.field_remappingsObject



194
195
196
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 194

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



185
186
187
188
189
190
191
192
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 185

def self.inner_class_types
  @inner_class_types = {
    automatic_tax: AutomaticTax,
    billing_thresholds: BillingThresholds,
    invoice_settings: InvoiceSettings,
    transfer_data: TransferData,
  }
end