Class: Stripe::QuotePreviewSubscriptionSchedule::DefaultSettings::InvoiceSettings

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Defined Under Namespace

Classes: Issuer

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_tax_idsObject (readonly)

The account tax IDs associated with the subscription schedule. Will be set on invoices generated by the subscription schedule.



135
136
137
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 135

def 
  @account_tax_ids
end

#days_until_dueObject (readonly)

Number of days within which a customer must pay invoices generated by this subscription schedule. This value will be ‘null` for subscription schedules where `billing=charge_automatically`.



137
138
139
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 137

def days_until_due
  @days_until_due
end

#issuerObject (readonly)

Attribute for field issuer



139
140
141
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 139

def issuer
  @issuer
end

Class Method Details

.field_remappingsObject



145
146
147
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 145

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



141
142
143
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 141

def self.inner_class_types
  @inner_class_types = { issuer: Issuer }
end