Class: Stripe::QuotePreviewSubscriptionSchedule::DefaultSettings::InvoiceSettings
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewSubscriptionSchedule::DefaultSettings::InvoiceSettings
- Defined in:
- lib/stripe/resources/quote_preview_subscription_schedule.rb
Defined Under Namespace
Classes: Issuer
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_tax_ids ⇒ Object
readonly
The account tax IDs associated with the subscription schedule.
-
#days_until_due ⇒ Object
readonly
Number of days within which a customer must pay invoices generated by this subscription schedule.
-
#issuer ⇒ Object
readonly
Attribute for field issuer.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_tax_ids ⇒ Object (readonly)
The account tax IDs associated with the subscription schedule. Will be set on invoices generated by the subscription schedule.
218 219 220 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 218 def account_tax_ids @account_tax_ids end |
#days_until_due ⇒ Object (readonly)
Number of days within which a customer must pay invoices generated by this subscription schedule. This value will be ‘null` for subscription schedules where `billing=charge_automatically`.
220 221 222 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 220 def days_until_due @days_until_due end |
#issuer ⇒ Object (readonly)
Attribute for field issuer
222 223 224 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 222 def issuer @issuer end |
Class Method Details
.field_remappings ⇒ Object
228 229 230 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 228 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
224 225 226 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 224 def self.inner_class_types @inner_class_types = { issuer: Issuer } end |