Class: Stripe::QuotePreviewSubscriptionSchedule::LastPriceMigrationError

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Defined Under Namespace

Classes: FailedTransition

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#errored_atObject (readonly)

The time at which the price migration encountered an error.



122
123
124
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 122

def errored_at
  @errored_at
end

#failed_transitionsObject (readonly)

The involved price pairs in each failed transition.



125
126
127
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 125

def failed_transitions
  @failed_transitions
end

#typeObject (readonly)

The type of error encountered by the price migration.



128
129
130
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 128

def type
  @type
end