Class: Stripe::QuotePreviewSubscriptionSchedule::Phase

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Defined Under Namespace

Classes: AddInvoiceItem, AutomaticTax, Discount, InvoiceSettings, Item, PauseCollection, TransferData, TrialSettings

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#add_invoice_itemsObject (readonly)

A list of prices and quantities that will generate invoice items appended to the next invoice for this phase.



235
236
237
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 235

def add_invoice_items
  @add_invoice_items
end

#application_fee_percentObject (readonly)

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account during this phase of the schedule.



237
238
239
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 237

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject (readonly)

Attribute for field automatic_tax



239
240
241
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 239

def automatic_tax
  @automatic_tax
end

#billing_cycle_anchorObject (readonly)

Possible values are ‘phase_start` or `automatic`. If `phase_start` then billing cycle anchor of the subscription is set to the start of the phase when entering the phase. If `automatic` then the billing cycle anchor is automatically modified as needed when entering the phase. For more information, see the billing cycle [documentation](stripe.com/docs/billing/subscriptions/billing-cycle).



241
242
243
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 241

def billing_cycle_anchor
  @billing_cycle_anchor
end

#collection_methodObject (readonly)

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay the underlying subscription at the end of each billing cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`.



243
244
245
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 243

def collection_method
  @collection_method
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



245
246
247
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 245

def currency
  @currency
end

#default_payment_methodObject (readonly)

ID of the default payment method for the subscription schedule. It must belong to the customer associated with the subscription schedule. If not set, invoices will use the default payment method in the customer’s invoice settings.



247
248
249
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 247

def default_payment_method
  @default_payment_method
end

#default_tax_ratesObject (readonly)

The default tax rates to apply to the subscription during this phase of the subscription schedule.



249
250
251
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 249

def default_tax_rates
  @default_tax_rates
end

#descriptionObject (readonly)

Subscription description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



251
252
253
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 251

def description
  @description
end

#discountsObject (readonly)

The stackable discounts that will be applied to the subscription on this phase. Subscription item discounts are applied before subscription discounts.



253
254
255
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 253

def discounts
  @discounts
end

#end_dateObject (readonly)

The end of this phase of the subscription schedule.



255
256
257
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 255

def end_date
  @end_date
end

#invoice_settingsObject (readonly)

The invoice settings applicable during this phase.



257
258
259
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 257

def invoice_settings
  @invoice_settings
end

#itemsObject (readonly)

Subscription items to configure the subscription to during this phase of the subscription schedule.



259
260
261
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 259

def items
  @items
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a phase. Metadata on a schedule’s phase will update the underlying subscription’s ‘metadata` when the phase is entered. Updating the underlying subscription’s ‘metadata` directly will not affect the current phase’s ‘metadata`.



261
262
263
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 261

def 
  @metadata
end

#on_behalf_ofObject (readonly)

The account (if any) the charge was made on behalf of for charges associated with the schedule’s subscription. See the Connect documentation for details.



263
264
265
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 263

def on_behalf_of
  @on_behalf_of
end

#pause_collectionObject (readonly)

If specified, payment collection for this subscription will be paused. Note that the subscription status will be unchanged and will not be updated to ‘paused`. Learn more about [pausing collection](stripe.com/docs/billing/subscriptions/pause-payment).



265
266
267
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 265

def pause_collection
  @pause_collection
end

#proration_behaviorObject (readonly)

If the subscription schedule will prorate when transitioning to this phase. Possible values are ‘create_prorations` and `none`.



267
268
269
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 267

def proration_behavior
  @proration_behavior
end

#start_dateObject (readonly)

The start of this phase of the subscription schedule.



269
270
271
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 269

def start_date
  @start_date
end

#transfer_dataObject (readonly)

The account (if any) the associated subscription’s payments will be attributed to for tax reporting, and where funds from each payment will be transferred to for each of the subscription’s invoices.



271
272
273
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 271

def transfer_data
  @transfer_data
end

#trial_continuationObject (readonly)

Specify behavior of the trial when crossing schedule phase boundaries



273
274
275
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 273

def trial_continuation
  @trial_continuation
end

#trial_endObject (readonly)

When the trial ends within the phase.



275
276
277
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 275

def trial_end
  @trial_end
end

#trial_settingsObject (readonly)

Settings related to any trials on the subscription during this phase.



277
278
279
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 277

def trial_settings
  @trial_settings
end