Class: Stripe::QuotePreviewSubscriptionSchedule::Phase::AddInvoiceItem

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Defined Under Namespace

Classes: Discount, Period

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#discountsObject (readonly)

The stackable discounts that will be applied to the item.



309
310
311
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 309

def discounts
  @discounts
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



311
312
313
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 311

def 
  @metadata
end

#periodObject (readonly)

Attribute for field period



313
314
315
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 313

def period
  @period
end

#priceObject (readonly)

ID of the price used to generate the invoice item.



315
316
317
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 315

def price
  @price
end

#quantityObject (readonly)

The quantity of the invoice item.



317
318
319
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 317

def quantity
  @quantity
end

#tax_ratesObject (readonly)

The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.



319
320
321
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 319

def tax_rates
  @tax_rates
end

Class Method Details

.field_remappingsObject



325
326
327
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 325

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



321
322
323
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 321

def self.inner_class_types
  @inner_class_types = { discounts: Discount, period: Period }
end