Class: Stripe::QuotePreviewSubscriptionSchedule::Phase::AddInvoiceItem
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewSubscriptionSchedule::Phase::AddInvoiceItem
- Defined in:
- lib/stripe/resources/quote_preview_subscription_schedule.rb
Defined Under Namespace
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#discounts ⇒ Object
readonly
The stackable discounts that will be applied to the item.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#period ⇒ Object
readonly
Attribute for field period.
-
#price ⇒ Object
readonly
ID of the price used to generate the invoice item.
-
#quantity ⇒ Object
readonly
The quantity of the invoice item.
-
#tax_rates ⇒ Object
readonly
The tax rates which apply to the item.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#discounts ⇒ Object (readonly)
The stackable discounts that will be applied to the item.
394 395 396 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 394 def discounts @discounts end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
396 397 398 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 396 def @metadata end |
#period ⇒ Object (readonly)
Attribute for field period
398 399 400 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 398 def period @period end |
#price ⇒ Object (readonly)
ID of the price used to generate the invoice item.
400 401 402 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 400 def price @price end |
#quantity ⇒ Object (readonly)
The quantity of the invoice item.
402 403 404 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 402 def quantity @quantity end |
#tax_rates ⇒ Object (readonly)
The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.
404 405 406 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 404 def tax_rates @tax_rates end |
Class Method Details
.field_remappings ⇒ Object
410 411 412 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 410 def self.field_remappings @field_remappings = {} end |