Class: Stripe::QuotePreviewSubscriptionSchedule::Phase::AddInvoiceItem

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Defined Under Namespace

Classes: Discount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#discountsObject (readonly)

The stackable discounts that will be applied to the item.



127
128
129
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 127

def discounts
  @discounts
end

#priceObject (readonly)

ID of the price used to generate the invoice item.



129
130
131
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 129

def price
  @price
end

#quantityObject (readonly)

The quantity of the invoice item.



131
132
133
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 131

def quantity
  @quantity
end

#tax_ratesObject (readonly)

The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.



133
134
135
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 133

def tax_rates
  @tax_rates
end