Class: Stripe::QuotePreviewSubscriptionSchedule::Phase::AutomaticTax

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Defined Under Namespace

Classes: Liability

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#disabled_reasonObject (readonly)

If Stripe disabled automatic tax, this enum describes why.



348
349
350
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 348

def disabled_reason
  @disabled_reason
end

#enabledObject (readonly)

Whether Stripe automatically computes tax on invoices created during this phase.



350
351
352
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 350

def enabled
  @enabled
end

#liabilityObject (readonly)

The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.



352
353
354
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 352

def liability
  @liability
end

Class Method Details

.field_remappingsObject



358
359
360
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 358

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



354
355
356
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 354

def self.inner_class_types
  @inner_class_types = { liability: Liability }
end