Class: Stripe::QuotePreviewSubscriptionSchedule::Phase::AutomaticTax
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewSubscriptionSchedule::Phase::AutomaticTax
- Defined in:
- lib/stripe/resources/quote_preview_subscription_schedule.rb
Defined Under Namespace
Classes: Liability
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#disabled_reason ⇒ Object
readonly
If Stripe disabled automatic tax, this enum describes why.
-
#enabled ⇒ Object
readonly
Whether Stripe automatically computes tax on invoices created during this phase.
-
#liability ⇒ Object
readonly
The account that’s liable for tax.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#disabled_reason ⇒ Object (readonly)
If Stripe disabled automatic tax, this enum describes why.
431 432 433 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 431 def disabled_reason @disabled_reason end |
#enabled ⇒ Object (readonly)
Whether Stripe automatically computes tax on invoices created during this phase.
433 434 435 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 433 def enabled @enabled end |
#liability ⇒ Object (readonly)
The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
435 436 437 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 435 def liability @liability end |
Class Method Details
.field_remappings ⇒ Object
441 442 443 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 441 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
437 438 439 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 437 def self.inner_class_types @inner_class_types = { liability: Liability } end |