Class: Stripe::QuotePreviewSubscriptionSchedule::Phase::AutomaticTax

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Defined Under Namespace

Classes: Liability

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#disabled_reasonObject (readonly)

If Stripe disabled automatic tax, this enum describes why.



151
152
153
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 151

def disabled_reason
  @disabled_reason
end

#enabledObject (readonly)

Whether Stripe automatically computes tax on invoices created during this phase.



153
154
155
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 153

def enabled
  @enabled
end

#liabilityObject (readonly)

The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.



155
156
157
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 155

def liability
  @liability
end