Class: Stripe::QuotePreviewSubscriptionSchedule::Phase::Discount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewSubscriptionSchedule::Phase::Discount
- Defined in:
- lib/stripe/resources/quote_preview_subscription_schedule.rb
Defined Under Namespace
Classes: DiscountEnd, Settings
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#coupon ⇒ Object
readonly
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
readonly
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
readonly
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
readonly
ID of the promotion code to create a new discount for.
-
#settings ⇒ Object
readonly
Attribute for field settings.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#coupon ⇒ Object (readonly)
ID of the coupon to create a new discount for.
507 508 509 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 507 def coupon @coupon end |
#discount ⇒ Object (readonly)
ID of an existing discount on the object (or one of its ancestors) to reuse.
509 510 511 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 509 def discount @discount end |
#discount_end ⇒ Object (readonly)
Details to determine how long the discount should be applied for.
511 512 513 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 511 def discount_end @discount_end end |
#promotion_code ⇒ Object (readonly)
ID of the promotion code to create a new discount for.
513 514 515 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 513 def promotion_code @promotion_code end |
#settings ⇒ Object (readonly)
Attribute for field settings
515 516 517 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 515 def settings @settings end |
Class Method Details
.field_remappings ⇒ Object
521 522 523 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 521 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
517 518 519 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 517 def self.inner_class_types @inner_class_types = { discount_end: DiscountEnd, settings: Settings } end |