Class: Stripe::QuotePreviewSubscriptionSchedule::Phase::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#day_of_monthObject (readonly)

The day of the month the anchor should be. Ranges from 1 to 31.



481
482
483
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 481

def day_of_month
  @day_of_month
end

#hourObject (readonly)

The hour of the day the anchor should be. Ranges from 0 to 23.



483
484
485
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 483

def hour
  @hour
end

#minuteObject (readonly)

The minute of the hour the anchor should be. Ranges from 0 to 59.



485
486
487
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 485

def minute
  @minute
end

#monthObject (readonly)

The month to start full cycle periods. Ranges from 1 to 12.



487
488
489
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 487

def month
  @month
end

#secondObject (readonly)

The second of the minute the anchor should be. Ranges from 0 to 59.



489
490
491
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 489

def second
  @second
end

Class Method Details

.field_remappingsObject



495
496
497
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 495

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



491
492
493
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 491

def self.inner_class_types
  @inner_class_types = {}
end