Class: Stripe::QuotePreviewSubscriptionSchedule::Phase::InvoiceSettings
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewSubscriptionSchedule::Phase::InvoiceSettings
- Defined in:
- lib/stripe/resources/quote_preview_subscription_schedule.rb
Defined Under Namespace
Classes: CustomField, Issuer
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_tax_ids ⇒ Object
readonly
The account tax IDs associated with this phase of the subscription schedule.
-
#custom_fields ⇒ Object
readonly
A list of up to 4 custom fields to be displayed on the invoice.
-
#days_until_due ⇒ Object
readonly
Number of days within which a customer must pay invoices generated by this subscription schedule.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#footer ⇒ Object
readonly
Footer to be displayed on the invoice.
-
#issuer ⇒ Object
readonly
The connected account that issues the invoice.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_tax_ids ⇒ Object (readonly)
The account tax IDs associated with this phase of the subscription schedule. Will be set on invoices generated by this phase of the subscription schedule.
463 464 465 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 463 def account_tax_ids @account_tax_ids end |
#custom_fields ⇒ Object (readonly)
A list of up to 4 custom fields to be displayed on the invoice.
465 466 467 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 465 def custom_fields @custom_fields end |
#days_until_due ⇒ Object (readonly)
Number of days within which a customer must pay invoices generated by this subscription schedule. This value will be null for subscription schedules where billing=charge_automatically.
467 468 469 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 467 def days_until_due @days_until_due end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
469 470 471 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 469 def description @description end |
#footer ⇒ Object (readonly)
Footer to be displayed on the invoice.
471 472 473 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 471 def @footer end |
#issuer ⇒ Object (readonly)
The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
473 474 475 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 473 def issuer @issuer end |
Class Method Details
.field_remappings ⇒ Object
479 480 481 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 479 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
475 476 477 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 475 def self.inner_class_types @inner_class_types = { custom_fields: CustomField, issuer: Issuer } end |