Class: Stripe::QuotePreviewSubscriptionSchedule::Phase::InvoiceSettings
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewSubscriptionSchedule::Phase::InvoiceSettings
- Defined in:
- lib/stripe/resources/quote_preview_subscription_schedule.rb
Defined Under Namespace
Classes: Issuer
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_tax_ids ⇒ Object
readonly
The account tax IDs associated with this phase of the subscription schedule.
-
#days_until_due ⇒ Object
readonly
Number of days within which a customer must pay invoices generated by this subscription schedule.
-
#issuer ⇒ Object
readonly
The connected account that issues the invoice.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_tax_ids ⇒ Object (readonly)
The account tax IDs associated with this phase of the subscription schedule. Will be set on invoices generated by this phase of the subscription schedule.
425 426 427 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 425 def account_tax_ids @account_tax_ids end |
#days_until_due ⇒ Object (readonly)
Number of days within which a customer must pay invoices generated by this subscription schedule. This value will be ‘null` for subscription schedules where `billing=charge_automatically`.
427 428 429 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 427 def days_until_due @days_until_due end |
#issuer ⇒ Object (readonly)
The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
429 430 431 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 429 def issuer @issuer end |
Class Method Details
.field_remappings ⇒ Object
435 436 437 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 435 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
431 432 433 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 431 def self.inner_class_types @inner_class_types = { issuer: Issuer } end |