Class: Stripe::QuotePreviewSubscriptionSchedule::Phase::Item
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewSubscriptionSchedule::Phase::Item
- Defined in:
- lib/stripe/resources/quote_preview_subscription_schedule.rb
Defined Under Namespace
Classes: BillingThresholds, Discount, Trial
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
readonly
Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period.
-
#discounts ⇒ Object
readonly
The discounts applied to the subscription item.
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an item.
-
#plan ⇒ Object
readonly
ID of the plan to which the customer should be subscribed.
-
#price ⇒ Object
readonly
ID of the price to which the customer should be subscribed.
-
#quantity ⇒ Object
readonly
Quantity of the plan to which the customer should be subscribed.
-
#tax_rates ⇒ Object
readonly
The tax rates which apply to this
phase_item. -
#trial ⇒ Object
readonly
Options that configure the trial on the subscription item.
-
#trial_offer ⇒ Object
readonly
The ID of the trial offer to apply to the configuration item.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_thresholds ⇒ Object (readonly)
Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period
546 547 548 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 546 def billing_thresholds @billing_thresholds end |
#discounts ⇒ Object (readonly)
The discounts applied to the subscription item. Subscription item discounts are applied before subscription discounts. Use expand[]=discounts to expand each discount.
548 549 550 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 548 def discounts @discounts end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an item. Metadata on this item will update the underlying subscription item's metadata when the phase is entered.
550 551 552 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 550 def @metadata end |
#plan ⇒ Object (readonly)
ID of the plan to which the customer should be subscribed.
552 553 554 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 552 def plan @plan end |
#price ⇒ Object (readonly)
ID of the price to which the customer should be subscribed.
554 555 556 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 554 def price @price end |
#quantity ⇒ Object (readonly)
Quantity of the plan to which the customer should be subscribed.
556 557 558 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 556 def quantity @quantity end |
#tax_rates ⇒ Object (readonly)
The tax rates which apply to this phase_item. When set, the default_tax_rates on the phase do not apply to this phase_item.
558 559 560 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 558 def tax_rates @tax_rates end |
#trial ⇒ Object (readonly)
Options that configure the trial on the subscription item.
560 561 562 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 560 def trial @trial end |
#trial_offer ⇒ Object (readonly)
The ID of the trial offer to apply to the configuration item.
562 563 564 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 562 def trial_offer @trial_offer end |
Class Method Details
.field_remappings ⇒ Object
572 573 574 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 572 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
564 565 566 567 568 569 570 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 564 def self.inner_class_types @inner_class_types = { billing_thresholds: BillingThresholds, discounts: Discount, trial: Trial, } end |