Class: Stripe::QuotePreviewSubscriptionSchedule::Phase::Item

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, Trial

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_thresholdsObject (readonly)

Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period



689
690
691
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 689

def billing_thresholds
  @billing_thresholds
end

#discountsObject (readonly)

The discounts applied to the subscription item. Subscription item discounts are applied before subscription discounts. Use ‘expand[]=discounts` to expand each discount.



691
692
693
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 691

def discounts
  @discounts
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an item. Metadata on this item will update the underlying subscription item’s ‘metadata` when the phase is entered.



693
694
695
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 693

def 
  @metadata
end

#planObject (readonly)

ID of the plan to which the customer should be subscribed.



695
696
697
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 695

def plan
  @plan
end

#priceObject (readonly)

ID of the price to which the customer should be subscribed.



697
698
699
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 697

def price
  @price
end

#quantityObject (readonly)

Quantity of the plan to which the customer should be subscribed.



699
700
701
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 699

def quantity
  @quantity
end

#tax_ratesObject (readonly)

The tax rates which apply to this ‘phase_item`. When set, the `default_tax_rates` on the phase do not apply to this `phase_item`.



701
702
703
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 701

def tax_rates
  @tax_rates
end

#trialObject (readonly)

Options that configure the trial on the subscription item.



703
704
705
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 703

def trial
  @trial
end

#trial_offerObject (readonly)

The ID of the trial offer to apply to the configuration item.



705
706
707
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 705

def trial_offer
  @trial_offer
end

Class Method Details

.field_remappingsObject



715
716
717
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 715

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



707
708
709
710
711
712
713
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 707

def self.inner_class_types
  @inner_class_types = {
    billing_thresholds: BillingThresholds,
    discounts: Discount,
    trial: Trial,
  }
end