Class: Stripe::QuotePreviewSubscriptionSchedule::Phase::Item

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, Trial

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_thresholdsObject (readonly)

Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period



587
588
589
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 587

def billing_thresholds
  @billing_thresholds
end

#discountsObject (readonly)

The discounts applied to the subscription item. Subscription item discounts are applied before subscription discounts. Use ‘expand[]=discounts` to expand each discount.



589
590
591
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 589

def discounts
  @discounts
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an item. Metadata on this item will update the underlying subscription item’s ‘metadata` when the phase is entered.



591
592
593
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 591

def 
  @metadata
end

#planObject (readonly)

ID of the plan to which the customer should be subscribed.



593
594
595
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 593

def plan
  @plan
end

#priceObject (readonly)

ID of the price to which the customer should be subscribed.



595
596
597
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 595

def price
  @price
end

#quantityObject (readonly)

Quantity of the plan to which the customer should be subscribed.



597
598
599
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 597

def quantity
  @quantity
end

#tax_ratesObject (readonly)

The tax rates which apply to this ‘phase_item`. When set, the `default_tax_rates` on the phase do not apply to this `phase_item`.



599
600
601
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 599

def tax_rates
  @tax_rates
end

#trialObject (readonly)

Options that configure the trial on the subscription item.



601
602
603
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 601

def trial
  @trial
end

#trial_offerObject (readonly)

The ID of the trial offer to apply to the configuration item.



603
604
605
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 603

def trial_offer
  @trial_offer
end

Class Method Details

.field_remappingsObject



613
614
615
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 613

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



605
606
607
608
609
610
611
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 605

def self.inner_class_types
  @inner_class_types = {
    billing_thresholds: BillingThresholds,
    discounts: Discount,
    trial: Trial,
  }
end