Class: Stripe::QuotePreviewSubscriptionSchedule::Phase::Item

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, Trial

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_thresholdsObject (readonly)

Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period



266
267
268
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 266

def billing_thresholds
  @billing_thresholds
end

#discountsObject (readonly)

The discounts applied to the subscription item. Subscription item discounts are applied before subscription discounts. Use ‘expand[]=discounts` to expand each discount.



269
270
271
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 269

def discounts
  @discounts
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an item. Metadata on this item will update the underlying subscription item’s ‘metadata` when the phase is entered.



272
273
274
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 272

def 
  @metadata
end

#planObject (readonly)

ID of the plan to which the customer should be subscribed.



275
276
277
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 275

def plan
  @plan
end

#priceObject (readonly)

ID of the price to which the customer should be subscribed.



278
279
280
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 278

def price
  @price
end

#quantityObject (readonly)

Quantity of the plan to which the customer should be subscribed.



281
282
283
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 281

def quantity
  @quantity
end

#tax_ratesObject (readonly)

The tax rates which apply to this ‘phase_item`. When set, the `default_tax_rates` on the phase do not apply to this `phase_item`.



284
285
286
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 284

def tax_rates
  @tax_rates
end

#trialObject (readonly)

Options that configure the trial on the subscription item.



287
288
289
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 287

def trial
  @trial
end