Class: Stripe::QuotePreviewSubscriptionSchedule::Phase::Item::Discount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd, Settings

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#couponObject (readonly)

ID of the coupon to create a new discount for.



655
656
657
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 655

def coupon
  @coupon
end

#discountObject (readonly)

ID of an existing discount on the object (or one of its ancestors) to reuse.



657
658
659
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 657

def discount
  @discount
end

#discount_endObject (readonly)

Details to determine how long the discount should be applied for.



659
660
661
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 659

def discount_end
  @discount_end
end

#promotion_codeObject (readonly)

ID of the promotion code to create a new discount for.



661
662
663
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 661

def promotion_code
  @promotion_code
end

#settingsObject (readonly)

Attribute for field settings



663
664
665
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 663

def settings
  @settings
end

Class Method Details

.field_remappingsObject



669
670
671
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 669

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



665
666
667
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 665

def self.inner_class_types
  @inner_class_types = { discount_end: DiscountEnd, settings: Settings }
end