Class: Stripe::QuotePreviewSubscriptionSchedule::Phase::TransferData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::QuotePreviewSubscriptionSchedule::Phase::TransferData
- Defined in:
- lib/stripe/resources/quote_preview_subscription_schedule.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_percent ⇒ Object
readonly
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#destination ⇒ Object
readonly
The account where funds from the payment will be transferred to upon payment success.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_percent ⇒ Object (readonly)
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.
546 547 548 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 546 def amount_percent @amount_percent end |
#destination ⇒ Object (readonly)
The account where funds from the payment will be transferred to upon payment success.
548 549 550 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 548 def destination @destination end |
Class Method Details
.field_remappings ⇒ Object
554 555 556 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 554 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
550 551 552 |
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 550 def self.inner_class_types @inner_class_types = {} end |