Class: Stripe::QuotePreviewSubscriptionSchedule::Prebilling

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/quote_preview_subscription_schedule.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#invoiceObject (readonly)

ID of the prebilling invoice.



740
741
742
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 740

def invoice
  @invoice
end

#period_endObject (readonly)

The end of the last period for which the invoice pre-bills.



742
743
744
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 742

def period_end
  @period_end
end

#period_startObject (readonly)

The start of the first period for which the invoice pre-bills.



744
745
746
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 744

def period_start
  @period_start
end

#update_behaviorObject (readonly)

Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period.



746
747
748
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 746

def update_behavior
  @update_behavior
end

Class Method Details

.field_remappingsObject



752
753
754
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 752

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



748
749
750
# File 'lib/stripe/resources/quote_preview_subscription_schedule.rb', line 748

def self.inner_class_types
  @inner_class_types = {}
end