Class: Stripe::QuoteService::AcceptParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::AcceptParams
- Defined in:
- lib/stripe/services/quote_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ AcceptParams
constructor
A new instance of AcceptParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ AcceptParams
Returns a new instance of AcceptParams.
2205 2206 2207 |
# File 'lib/stripe/services/quote_service.rb', line 2205 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2203 2204 2205 |
# File 'lib/stripe/services/quote_service.rb', line 2203 def @expand end |