Class: Stripe::QuoteService::CreateParams::Line

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: Action, AppliesTo, CancelSubscriptionSchedule, EndsAt, SetPauseCollection, StartsAt, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(actions: nil, applies_to: nil, billing_cycle_anchor: nil, cancel_subscription_schedule: nil, ends_at: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, starts_at: nil, trial_settings: nil) ⇒ Line

Returns a new instance of Line.



690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
# File 'lib/stripe/services/quote_service.rb', line 690

def initialize(
  actions: nil,
  applies_to: nil,
  billing_cycle_anchor: nil,
  cancel_subscription_schedule: nil,
  ends_at: nil,
  proration_behavior: nil,
  set_pause_collection: nil,
  set_schedule_end: nil,
  starts_at: nil,
  trial_settings: nil
)
  @actions = actions
  @applies_to = applies_to
  @billing_cycle_anchor = billing_cycle_anchor
  @cancel_subscription_schedule = cancel_subscription_schedule
  @ends_at = ends_at
  @proration_behavior = proration_behavior
  @set_pause_collection = set_pause_collection
  @set_schedule_end = set_schedule_end
  @starts_at = starts_at
  @trial_settings = trial_settings
end

Instance Attribute Details

#actionsObject

An array of operations the quote line performs.



661
662
663
# File 'lib/stripe/services/quote_service.rb', line 661

def actions
  @actions
end

#applies_toObject

Details to identify the subscription schedule the quote line applies to.



664
665
666
# File 'lib/stripe/services/quote_service.rb', line 664

def applies_to
  @applies_to
end

#billing_cycle_anchorObject

For point-in-time quote lines (having no ‘ends_at` timestamp), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the Quote Line ‘starts_at` timestamp.For time-span based quote lines (having both `starts_at` and `ends_at`), the only valid value is `automatic`, which removes any previously configured billing cycle anchor resets during the window of time spanning the quote line.



667
668
669
# File 'lib/stripe/services/quote_service.rb', line 667

def billing_cycle_anchor
  @billing_cycle_anchor
end

#cancel_subscription_scheduleObject

A point-in-time operation that cancels an existing subscription schedule at the line’s starts_at timestamp. Currently only compatible with ‘quote_acceptance_date` for `starts_at`. When using cancel_subscription_schedule, the subscription schedule on the quote remains unalterable, except for modifications to the metadata, collection_method or invoice_settings.



670
671
672
# File 'lib/stripe/services/quote_service.rb', line 670

def cancel_subscription_schedule
  @cancel_subscription_schedule
end

#ends_atObject

Details to identify the end of the time range modified by the proposed change. If not supplied, the quote line is considered a point-in-time operation that only affects the exact timestamp at ‘starts_at`, and a restricted set of attributes is supported on the quote line.



673
674
675
# File 'lib/stripe/services/quote_service.rb', line 673

def ends_at
  @ends_at
end

#proration_behaviorObject

Changes to how Stripe handles prorations during the quote line’s time span. Affects if and how prorations are created when a future phase starts.



676
677
678
# File 'lib/stripe/services/quote_service.rb', line 676

def proration_behavior
  @proration_behavior
end

#set_pause_collectionObject

Defines how to pause collection for the underlying subscription throughout the duration of the amendment.



679
680
681
# File 'lib/stripe/services/quote_service.rb', line 679

def set_pause_collection
  @set_pause_collection
end

#set_schedule_endObject

Timestamp helper to end the underlying schedule early, based on the acompanying line’s start or end date.



682
683
684
# File 'lib/stripe/services/quote_service.rb', line 682

def set_schedule_end
  @set_schedule_end
end

#starts_atObject

Details to identify the earliest timestamp where the proposed change should take effect.



685
686
687
# File 'lib/stripe/services/quote_service.rb', line 685

def starts_at
  @starts_at
end

#trial_settingsObject

Settings related to subscription trials.



688
689
690
# File 'lib/stripe/services/quote_service.rb', line 688

def trial_settings
  @trial_settings
end