Class: Stripe::QuoteService::CreateParams::Line

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: Action, AppliesTo, CancelSubscriptionSchedule, EndsAt, SetPauseCollection, StartsAt, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(actions: nil, applies_to: nil, billing_cycle_anchor: nil, cancel_subscription_schedule: nil, ends_at: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, starts_at: nil, trial_settings: nil) ⇒ Line

Returns a new instance of Line.



610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
# File 'lib/stripe/services/quote_service.rb', line 610

def initialize(
  actions: nil,
  applies_to: nil,
  billing_cycle_anchor: nil,
  cancel_subscription_schedule: nil,
  ends_at: nil,
  proration_behavior: nil,
  set_pause_collection: nil,
  set_schedule_end: nil,
  starts_at: nil,
  trial_settings: nil
)
  @actions = actions
  @applies_to = applies_to
  @billing_cycle_anchor = billing_cycle_anchor
  @cancel_subscription_schedule = cancel_subscription_schedule
  @ends_at = ends_at
  @proration_behavior = proration_behavior
  @set_pause_collection = set_pause_collection
  @set_schedule_end = set_schedule_end
  @starts_at = starts_at
  @trial_settings = trial_settings
end

Instance Attribute Details

#actionsObject

An array of operations the quote line performs.



590
591
592
# File 'lib/stripe/services/quote_service.rb', line 590

def actions
  @actions
end

#applies_toObject

Details to identify the subscription schedule the quote line applies to.



592
593
594
# File 'lib/stripe/services/quote_service.rb', line 592

def applies_to
  @applies_to
end

#billing_cycle_anchorObject

For point-in-time quote lines (having no ‘ends_at` timestamp), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the Quote Line ‘starts_at` timestamp.For time-span based quote lines (having both `starts_at` and `ends_at`), the only valid value is `automatic`, which removes any previously configured billing cycle anchor resets during the window of time spanning the quote line.



594
595
596
# File 'lib/stripe/services/quote_service.rb', line 594

def billing_cycle_anchor
  @billing_cycle_anchor
end

#cancel_subscription_scheduleObject

A point-in-time operation that cancels an existing subscription schedule at the line’s starts_at timestamp. Currently only compatible with ‘quote_acceptance_date` for `starts_at`. When using cancel_subscription_schedule, the subscription schedule on the quote remains unalterable, except for modifications to the metadata, collection_method or invoice_settings.



596
597
598
# File 'lib/stripe/services/quote_service.rb', line 596

def cancel_subscription_schedule
  @cancel_subscription_schedule
end

#ends_atObject

Details to identify the end of the time range modified by the proposed change. If not supplied, the quote line is considered a point-in-time operation that only affects the exact timestamp at ‘starts_at`, and a restricted set of attributes is supported on the quote line.



598
599
600
# File 'lib/stripe/services/quote_service.rb', line 598

def ends_at
  @ends_at
end

#proration_behaviorObject

Changes to how Stripe handles prorations during the quote line’s time span. Affects if and how prorations are created when a future phase starts.



600
601
602
# File 'lib/stripe/services/quote_service.rb', line 600

def proration_behavior
  @proration_behavior
end

#set_pause_collectionObject

Defines how to pause collection for the underlying subscription throughout the duration of the amendment.



602
603
604
# File 'lib/stripe/services/quote_service.rb', line 602

def set_pause_collection
  @set_pause_collection
end

#set_schedule_endObject

Timestamp helper to end the underlying schedule early, based on the acompanying line’s start or end date.



604
605
606
# File 'lib/stripe/services/quote_service.rb', line 604

def set_schedule_end
  @set_schedule_end
end

#starts_atObject

Details to identify the earliest timestamp where the proposed change should take effect.



606
607
608
# File 'lib/stripe/services/quote_service.rb', line 606

def starts_at
  @starts_at
end

#trial_settingsObject

Settings related to subscription trials.



608
609
610
# File 'lib/stripe/services/quote_service.rb', line 608

def trial_settings
  @trial_settings
end