Class: Stripe::QuoteService::CreateParams::Line::Action::AddDiscount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::CreateParams::Line::Action::AddDiscount
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ AddDiscount
constructor
A new instance of AddDiscount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ AddDiscount
Returns a new instance of AddDiscount.
185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/stripe/services/quote_service.rb', line 185 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
175 176 177 |
# File 'lib/stripe/services/quote_service.rb', line 175 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
177 178 179 |
# File 'lib/stripe/services/quote_service.rb', line 177 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
179 180 181 |
# File 'lib/stripe/services/quote_service.rb', line 179 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
181 182 183 |
# File 'lib/stripe/services/quote_service.rb', line 181 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
183 184 185 |
# File 'lib/stripe/services/quote_service.rb', line 183 def promotion_code @promotion_code end |