Class: Stripe::QuoteService::CreateParams::Line::Action::AddDiscount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::CreateParams::Line::Action::AddDiscount
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ AddDiscount
constructor
A new instance of AddDiscount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ AddDiscount
Returns a new instance of AddDiscount.
203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/stripe/services/quote_service.rb', line 203 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
189 190 191 |
# File 'lib/stripe/services/quote_service.rb', line 189 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
192 193 194 |
# File 'lib/stripe/services/quote_service.rb', line 192 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
195 196 197 |
# File 'lib/stripe/services/quote_service.rb', line 195 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
198 199 200 |
# File 'lib/stripe/services/quote_service.rb', line 198 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
201 202 203 |
# File 'lib/stripe/services/quote_service.rb', line 201 def promotion_code @promotion_code end |