Class: Stripe::QuoteService::CreateParams::Line::Action::AddItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ AddItem

Returns a new instance of AddItem.



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/stripe/services/quote_service.rb', line 298

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



281
282
283
# File 'lib/stripe/services/quote_service.rb', line 281

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



284
285
286
# File 'lib/stripe/services/quote_service.rb', line 284

def 
  @metadata
end

#priceObject

The ID of the price object.



287
288
289
# File 'lib/stripe/services/quote_service.rb', line 287

def price
  @price
end

#quantityObject

Quantity for this item.



290
291
292
# File 'lib/stripe/services/quote_service.rb', line 290

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



293
294
295
# File 'lib/stripe/services/quote_service.rb', line 293

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



296
297
298
# File 'lib/stripe/services/quote_service.rb', line 296

def trial
  @trial
end