Class: Stripe::QuoteService::CreateParams::Line::Action::AddItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::CreateParams::Line::Action::AddItem
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to the item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates that apply to this subscription item.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ AddItem
constructor
A new instance of AddItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ AddItem
Returns a new instance of AddItem.
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/stripe/services/quote_service.rb', line 264 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to the item. Subscription item discounts are applied before subscription discounts.
252 253 254 |
# File 'lib/stripe/services/quote_service.rb', line 252 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
254 255 256 |
# File 'lib/stripe/services/quote_service.rb', line 254 def @metadata end |
#price ⇒ Object
The ID of the price object.
256 257 258 |
# File 'lib/stripe/services/quote_service.rb', line 256 def price @price end |
#quantity ⇒ Object
Quantity for this item.
258 259 260 |
# File 'lib/stripe/services/quote_service.rb', line 258 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.
260 261 262 |
# File 'lib/stripe/services/quote_service.rb', line 260 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
262 263 264 |
# File 'lib/stripe/services/quote_service.rb', line 262 def trial @trial end |