Class: Stripe::QuoteService::CreateParams::Line::Action::AddItem::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::CreateParams::Line::Action::AddItem::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
242 243 244 245 246 |
# File 'lib/stripe/services/quote_service.rb', line 242 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
234 235 236 |
# File 'lib/stripe/services/quote_service.rb', line 234 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
237 238 239 |
# File 'lib/stripe/services/quote_service.rb', line 237 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
240 241 242 |
# File 'lib/stripe/services/quote_service.rb', line 240 def type @type end |