Class: Stripe::QuoteService::CreateParams::Line::Action::SetDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount

Returns a new instance of SetDiscount.



351
352
353
354
355
# File 'lib/stripe/services/quote_service.rb', line 351

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



343
344
345
# File 'lib/stripe/services/quote_service.rb', line 343

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



346
347
348
# File 'lib/stripe/services/quote_service.rb', line 346

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



349
350
351
# File 'lib/stripe/services/quote_service.rb', line 349

def promotion_code
  @promotion_code
end