Class: Stripe::QuoteService::CreateParams::Line::Action::SetItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



382
383
384
385
386
# File 'lib/stripe/services/quote_service.rb', line 382

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



374
375
376
# File 'lib/stripe/services/quote_service.rb', line 374

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



377
378
379
# File 'lib/stripe/services/quote_service.rb', line 377

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



380
381
382
# File 'lib/stripe/services/quote_service.rb', line 380

def type
  @type
end