Class: Stripe::QuoteService::CreateParams::Line::Action::SetItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



341
342
343
344
345
# File 'lib/stripe/services/quote_service.rb', line 341

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



335
336
337
# File 'lib/stripe/services/quote_service.rb', line 335

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



337
338
339
# File 'lib/stripe/services/quote_service.rb', line 337

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



339
340
341
# File 'lib/stripe/services/quote_service.rb', line 339

def type
  @type
end