Class: Stripe::QuoteService::CreateParams::Line::CancelSubscriptionSchedule
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::CreateParams::Line::CancelSubscriptionSchedule
- Defined in:
- lib/stripe/services/quote_service.rb
Instance Attribute Summary collapse
-
#cancel_at ⇒ Object
Timestamp helper to cancel the underlying schedule on the accompanying line’s start date.
-
#invoice_now ⇒ Object
If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items.
-
#prorate ⇒ Object
If the subscription schedule is ‘active`, indicates if the cancellation should be prorated.
Instance Method Summary collapse
-
#initialize(cancel_at: nil, invoice_now: nil, prorate: nil) ⇒ CancelSubscriptionSchedule
constructor
A new instance of CancelSubscriptionSchedule.
Methods inherited from RequestParams
Constructor Details
#initialize(cancel_at: nil, invoice_now: nil, prorate: nil) ⇒ CancelSubscriptionSchedule
Returns a new instance of CancelSubscriptionSchedule.
477 478 479 480 481 |
# File 'lib/stripe/services/quote_service.rb', line 477 def initialize(cancel_at: nil, invoice_now: nil, prorate: nil) @cancel_at = cancel_at @invoice_now = invoice_now @prorate = prorate end |
Instance Attribute Details
#cancel_at ⇒ Object
Timestamp helper to cancel the underlying schedule on the accompanying line’s start date. Must be set to ‘line_starts_at`.
471 472 473 |
# File 'lib/stripe/services/quote_service.rb', line 471 def cancel_at @cancel_at end |
#invoice_now ⇒ Object
If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items. Boolean that defaults to `true`.
473 474 475 |
# File 'lib/stripe/services/quote_service.rb', line 473 def invoice_now @invoice_now end |
#prorate ⇒ Object
If the subscription schedule is ‘active`, indicates if the cancellation should be prorated. Boolean that defaults to `true`.
475 476 477 |
# File 'lib/stripe/services/quote_service.rb', line 475 def prorate @prorate end |