Class: Stripe::QuoteService::CreateParams::Line::EndsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::CreateParams::Line::EndsAt
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: DiscountEnd, Duration
Instance Attribute Summary collapse
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
Select a way to pass in ‘ends_at`.
Instance Method Summary collapse
-
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
constructor
A new instance of EndsAt.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
Returns a new instance of EndsAt.
510 511 512 513 514 515 |
# File 'lib/stripe/services/quote_service.rb', line 510 def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) @discount_end = discount_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
502 503 504 |
# File 'lib/stripe/services/quote_service.rb', line 502 def discount_end @discount_end end |
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
504 505 506 |
# File 'lib/stripe/services/quote_service.rb', line 504 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp.
506 507 508 |
# File 'lib/stripe/services/quote_service.rb', line 506 def @timestamp end |
#type ⇒ Object
Select a way to pass in ‘ends_at`.
508 509 510 |
# File 'lib/stripe/services/quote_service.rb', line 508 def type @type end |