Class: Stripe::QuoteService::CreateParams::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



827
828
829
830
831
832
833
# File 'lib/stripe/services/quote_service.rb', line 827

def initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil)
  @discounts = discounts
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The discounts applied to this line item.



813
814
815
# File 'lib/stripe/services/quote_service.rb', line 813

def discounts
  @discounts
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



816
817
818
# File 'lib/stripe/services/quote_service.rb', line 816

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



819
820
821
# File 'lib/stripe/services/quote_service.rb', line 819

def price_data
  @price_data
end

#quantityObject

The quantity of the line item.



822
823
824
# File 'lib/stripe/services/quote_service.rb', line 822

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the quote do not apply to this line item.



825
826
827
# File 'lib/stripe/services/quote_service.rb', line 825

def tax_rates
  @tax_rates
end