Class: Stripe::QuoteService::CreateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::CreateParams::LineItem
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to this line item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
The quantity of the line item.
-
#tax_rates ⇒ Object
The tax rates which apply to the line item.
Instance Method Summary collapse
-
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
Returns a new instance of LineItem.
731 732 733 734 735 736 737 |
# File 'lib/stripe/services/quote_service.rb', line 731 def initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) @discounts = discounts @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to this line item.
721 722 723 |
# File 'lib/stripe/services/quote_service.rb', line 721 def discounts @discounts end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
723 724 725 |
# File 'lib/stripe/services/quote_service.rb', line 723 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
725 726 727 |
# File 'lib/stripe/services/quote_service.rb', line 725 def price_data @price_data end |
#quantity ⇒ Object
The quantity of the line item.
727 728 729 |
# File 'lib/stripe/services/quote_service.rb', line 727 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the quote do not apply to this line item.
729 730 731 |
# File 'lib/stripe/services/quote_service.rb', line 729 def tax_rates @tax_rates end |