Class: Stripe::QuoteService::CreateParams::LineItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



656
657
658
659
660
# File 'lib/stripe/services/quote_service.rb', line 656

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



650
651
652
# File 'lib/stripe/services/quote_service.rb', line 650

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



652
653
654
# File 'lib/stripe/services/quote_service.rb', line 652

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



654
655
656
# File 'lib/stripe/services/quote_service.rb', line 654

def type
  @type
end