Class: Stripe::QuoteService::CreateParams::SubscriptionData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: BillOnAcceptance, Prebilling

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bill_on_acceptance: nil, billing_behavior: nil, billing_cycle_anchor: nil, description: nil, effective_date: nil, end_behavior: nil, from_subscription: nil, metadata: nil, prebilling: nil, proration_behavior: nil, trial_period_days: nil) ⇒ SubscriptionData

Returns a new instance of SubscriptionData.



971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
# File 'lib/stripe/services/quote_service.rb', line 971

def initialize(
  bill_on_acceptance: nil,
  billing_behavior: nil,
  billing_cycle_anchor: nil,
  description: nil,
  effective_date: nil,
  end_behavior: nil,
  from_subscription: nil,
  metadata: nil,
  prebilling: nil,
  proration_behavior: nil,
  trial_period_days: nil
)
  @bill_on_acceptance = bill_on_acceptance
  @billing_behavior = billing_behavior
  @billing_cycle_anchor = billing_cycle_anchor
  @description = description
  @effective_date = effective_date
  @end_behavior = end_behavior
  @from_subscription = from_subscription
  @metadata = 
  @prebilling = prebilling
  @proration_behavior = proration_behavior
  @trial_period_days = trial_period_days
end

Instance Attribute Details

#bill_on_acceptanceObject

Describes the period to bill for upon accepting the quote.



933
934
935
# File 'lib/stripe/services/quote_service.rb', line 933

def bill_on_acceptance
  @bill_on_acceptance
end

#billing_behaviorObject

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



936
937
938
# File 'lib/stripe/services/quote_service.rb', line 936

def billing_behavior
  @billing_behavior
end

#billing_cycle_anchorObject

When specified as ‘reset`, the subscription will always start a new billing period when the quote is accepted.



939
940
941
# File 'lib/stripe/services/quote_service.rb', line 939

def billing_cycle_anchor
  @billing_cycle_anchor
end

#descriptionObject

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



942
943
944
# File 'lib/stripe/services/quote_service.rb', line 942

def description
  @description
end

#effective_dateObject

When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted. When updating a subscription, the date of which the subscription will be updated using a subscription schedule. The special value ‘current_period_end` can be provided to update a subscription at the end of its current period. The `effective_date` is ignored if it is in the past when the quote is accepted.



945
946
947
# File 'lib/stripe/services/quote_service.rb', line 945

def effective_date
  @effective_date
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends.



948
949
950
# File 'lib/stripe/services/quote_service.rb', line 948

def end_behavior
  @end_behavior
end

#from_subscriptionObject

The id of a subscription that the quote will update. By default, the quote will contain the state of the subscription (such as line items, collection method and billing thresholds) unless overridden.



951
952
953
# File 'lib/stripe/services/quote_service.rb', line 951

def from_subscription
  @from_subscription
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that will set metadata on the subscription or subscription schedule when the quote is accepted. If a recurring price is included in ‘line_items`, this field will be passed to the resulting subscription’s ‘metadata` field. If `subscription_data.effective_date` is used, this field will be passed to the resulting subscription schedule’s ‘phases.metadata` field. Unlike object-level metadata, this field is declarative. Updates will clear prior values.



954
955
956
# File 'lib/stripe/services/quote_service.rb', line 954

def 
  @metadata
end

#prebillingObject

If specified, the invoicing for the given billing cycle iterations will be processed when the quote is accepted. Cannot be used with ‘effective_date`.



957
958
959
# File 'lib/stripe/services/quote_service.rb', line 957

def prebilling
  @prebilling
end

#proration_behaviorObject

Determines how to handle [prorations](stripe.com/docs/subscriptions/billing-cycle#prorations). When creating a subscription, valid values are ‘create_prorations` or `none`.

When updating a subscription, valid values are ‘create_prorations`, `none`, or `always_invoice`.

Passing ‘create_prorations` will cause proration invoice items to be created when applicable. These proration items will only be invoiced immediately under [certain conditions](stripe.com/docs/subscriptions/upgrading-downgrading#immediate-payment). In order to always invoice immediately for prorations, pass `always_invoice`.

Prorations can be disabled by passing ‘none`.



966
967
968
# File 'lib/stripe/services/quote_service.rb', line 966

def proration_behavior
  @proration_behavior
end

#trial_period_daysObject

Integer representing the number of trial period days before the customer is charged for the first time.



969
970
971
# File 'lib/stripe/services/quote_service.rb', line 969

def trial_period_days
  @trial_period_days
end