Class: Stripe::QuoteService::CreateParams::SubscriptionDataOverride::AppliesTo
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::CreateParams::SubscriptionDataOverride::AppliesTo
- Defined in:
- lib/stripe/services/quote_service.rb
Instance Attribute Summary collapse
-
#new_reference ⇒ Object
A custom string that identifies a new subscription schedule being created upon quote acceptance.
-
#subscription_schedule ⇒ Object
The ID of the schedule the line applies to.
-
#type ⇒ Object
Describes whether the quote line is affecting a new schedule or an existing schedule.
Instance Method Summary collapse
-
#initialize(new_reference: nil, subscription_schedule: nil, type: nil) ⇒ AppliesTo
constructor
A new instance of AppliesTo.
Methods inherited from RequestParams
Constructor Details
#initialize(new_reference: nil, subscription_schedule: nil, type: nil) ⇒ AppliesTo
Returns a new instance of AppliesTo.
892 893 894 895 896 |
# File 'lib/stripe/services/quote_service.rb', line 892 def initialize(new_reference: nil, subscription_schedule: nil, type: nil) @new_reference = new_reference @subscription_schedule = subscription_schedule @type = type end |
Instance Attribute Details
#new_reference ⇒ Object
A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same ‘new_reference` field will be applied to the creation of a new subscription schedule.
886 887 888 |
# File 'lib/stripe/services/quote_service.rb', line 886 def new_reference @new_reference end |
#subscription_schedule ⇒ Object
The ID of the schedule the line applies to.
888 889 890 |
# File 'lib/stripe/services/quote_service.rb', line 888 def subscription_schedule @subscription_schedule end |
#type ⇒ Object
Describes whether the quote line is affecting a new schedule or an existing schedule.
890 891 892 |
# File 'lib/stripe/services/quote_service.rb', line 890 def type @type end |