Class: Stripe::QuoteService::CreateParams::SubscriptionDataOverride::AppliesTo

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(new_reference: nil, subscription_schedule: nil, type: nil) ⇒ AppliesTo

Returns a new instance of AppliesTo.



1009
1010
1011
1012
1013
# File 'lib/stripe/services/quote_service.rb', line 1009

def initialize(new_reference: nil, subscription_schedule: nil, type: nil)
  @new_reference = new_reference
  @subscription_schedule = subscription_schedule
  @type = type
end

Instance Attribute Details

#new_referenceObject

A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same ‘new_reference` field will be applied to the creation of a new subscription schedule.



1001
1002
1003
# File 'lib/stripe/services/quote_service.rb', line 1001

def new_reference
  @new_reference
end

#subscription_scheduleObject

The ID of the schedule the line applies to.



1004
1005
1006
# File 'lib/stripe/services/quote_service.rb', line 1004

def subscription_schedule
  @subscription_schedule
end

#typeObject

Describes whether the quote line is affecting a new schedule or an existing schedule.



1007
1008
1009
# File 'lib/stripe/services/quote_service.rb', line 1007

def type
  @type
end