Class: Stripe::QuoteService::CreateParams::SubscriptionDataOverride::BillOnAcceptance::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::CreateParams::SubscriptionDataOverride::BillOnAcceptance::BillUntil
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: Duration, LineEndsAt
Instance Attribute Summary collapse
-
#duration ⇒ Object
Details of the duration over which to bill.
-
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
Instance Method Summary collapse
-
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
1084 1085 1086 1087 1088 1089 |
# File 'lib/stripe/services/quote_service.rb', line 1084 def initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) @duration = duration @line_ends_at = line_ends_at @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Details of the duration over which to bill.
1073 1074 1075 |
# File 'lib/stripe/services/quote_service.rb', line 1073 def duration @duration end |
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
1076 1077 1078 |
# File 'lib/stripe/services/quote_service.rb', line 1076 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
1079 1080 1081 |
# File 'lib/stripe/services/quote_service.rb', line 1079 def @timestamp end |
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
1082 1083 1084 |
# File 'lib/stripe/services/quote_service.rb', line 1082 def type @type end |