Class: Stripe::QuoteService::CreateParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::CreateParams::TransferData
- Defined in:
- lib/stripe/services/quote_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when the invoice is paid.
-
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_percent: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_percent: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
1158 1159 1160 1161 1162 |
# File 'lib/stripe/services/quote_service.rb', line 1158 def initialize(amount: nil, amount_percent: nil, destination: nil) @amount = amount @amount_percent = amount_percent @destination = destination end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.
1150 1151 1152 |
# File 'lib/stripe/services/quote_service.rb', line 1150 def amount @amount end |
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination. There must be at least 1 line item with a recurring price to use this field.
1153 1154 1155 |
# File 'lib/stripe/services/quote_service.rb', line 1153 def amount_percent @amount_percent end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
1156 1157 1158 |
# File 'lib/stripe/services/quote_service.rb', line 1156 def destination @destination end |