Class: Stripe::QuoteService::FinalizeQuoteParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::FinalizeQuoteParams
- Defined in:
- lib/stripe/services/quote_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expires_at ⇒ Object
A future timestamp on which the quote will be canceled if in ‘open` or `draft` status.
Instance Method Summary collapse
-
#initialize(expand: nil, expires_at: nil) ⇒ FinalizeQuoteParams
constructor
A new instance of FinalizeQuoteParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, expires_at: nil) ⇒ FinalizeQuoteParams
Returns a new instance of FinalizeQuoteParams.
2530 2531 2532 2533 |
# File 'lib/stripe/services/quote_service.rb', line 2530 def initialize(expand: nil, expires_at: nil) @expand = @expires_at = expires_at end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2525 2526 2527 |
# File 'lib/stripe/services/quote_service.rb', line 2525 def @expand end |
#expires_at ⇒ Object
A future timestamp on which the quote will be canceled if in ‘open` or `draft` status. Measured in seconds since the Unix epoch.
2528 2529 2530 |
# File 'lib/stripe/services/quote_service.rb', line 2528 def expires_at @expires_at end |