Class: Stripe::QuoteService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::ListParams
- Defined in:
- lib/stripe/services/quote_service.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of the customer whose quotes will be retrieved.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
The status of the quote.
-
#test_clock ⇒ Object
Provides a list of quotes that are associated with the specified test clock.
Instance Method Summary collapse
-
#initialize(customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams
Returns a new instance of ListParams.
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/stripe/services/quote_service.rb', line 30 def initialize( customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, test_clock: nil ) @customer = customer @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after @status = status @test_clock = test_clock end |
Instance Attribute Details
#customer ⇒ Object
The ID of the customer whose quotes will be retrieved.
16 17 18 |
# File 'lib/stripe/services/quote_service.rb', line 16 def customer @customer end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
18 19 20 |
# File 'lib/stripe/services/quote_service.rb', line 18 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
20 21 22 |
# File 'lib/stripe/services/quote_service.rb', line 20 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
22 23 24 |
# File 'lib/stripe/services/quote_service.rb', line 22 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
24 25 26 |
# File 'lib/stripe/services/quote_service.rb', line 24 def starting_after @starting_after end |
#status ⇒ Object
The status of the quote.
26 27 28 |
# File 'lib/stripe/services/quote_service.rb', line 26 def status @status end |
#test_clock ⇒ Object
Provides a list of quotes that are associated with the specified test clock. The response will not include quotes with test clocks if this and the customer parameter is not set.
28 29 30 |
# File 'lib/stripe/services/quote_service.rb', line 28 def test_clock @test_clock end |