Class: Stripe::QuoteService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::ListParams
- Defined in:
- lib/stripe/services/quote_service.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of the customer whose quotes will be retrieved.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#from_subscription ⇒ Object
The subscription which the quote updates.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
The status of the quote.
-
#test_clock ⇒ Object
Provides a list of quotes that are associated with the specified test clock.
Instance Method Summary collapse
-
#initialize(customer: nil, ending_before: nil, expand: nil, from_subscription: nil, limit: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, ending_before: nil, expand: nil, from_subscription: nil, limit: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams
Returns a new instance of ListParams.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/stripe/services/quote_service.rb', line 43 def initialize( customer: nil, ending_before: nil, expand: nil, from_subscription: nil, limit: nil, starting_after: nil, status: nil, test_clock: nil ) @customer = customer @ending_before = ending_before @expand = @from_subscription = from_subscription @limit = limit @starting_after = starting_after @status = status @test_clock = test_clock end |
Instance Attribute Details
#customer ⇒ Object
The ID of the customer whose quotes will be retrieved.
20 21 22 |
# File 'lib/stripe/services/quote_service.rb', line 20 def customer @customer end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
23 24 25 |
# File 'lib/stripe/services/quote_service.rb', line 23 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
26 27 28 |
# File 'lib/stripe/services/quote_service.rb', line 26 def @expand end |
#from_subscription ⇒ Object
The subscription which the quote updates.
29 30 31 |
# File 'lib/stripe/services/quote_service.rb', line 29 def from_subscription @from_subscription end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
32 33 34 |
# File 'lib/stripe/services/quote_service.rb', line 32 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
35 36 37 |
# File 'lib/stripe/services/quote_service.rb', line 35 def starting_after @starting_after end |
#status ⇒ Object
The status of the quote.
38 39 40 |
# File 'lib/stripe/services/quote_service.rb', line 38 def status @status end |
#test_clock ⇒ Object
Provides a list of quotes that are associated with the specified test clock. The response will not include quotes with test clocks if this and the customer parameter is not set.
41 42 43 |
# File 'lib/stripe/services/quote_service.rb', line 41 def test_clock @test_clock end |