Class: Stripe::QuoteService::ListPreviewInvoiceLinesParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListPreviewInvoiceLinesParams

Returns a new instance of ListPreviewInvoiceLinesParams.



2280
2281
2282
2283
2284
2285
# File 'lib/stripe/services/quote_service.rb', line 2280

def initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil)
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



2272
2273
2274
# File 'lib/stripe/services/quote_service.rb', line 2272

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



2274
2275
2276
# File 'lib/stripe/services/quote_service.rb', line 2274

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



2276
2277
2278
# File 'lib/stripe/services/quote_service.rb', line 2276

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



2278
2279
2280
# File 'lib/stripe/services/quote_service.rb', line 2278

def starting_after
  @starting_after
end