Class: Stripe::QuoteService::MarkStaleParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::MarkStaleParams
- Defined in:
- lib/stripe/services/quote_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#reason ⇒ Object
Reason the Quote is being marked stale.
Instance Method Summary collapse
-
#initialize(expand: nil, reason: nil) ⇒ MarkStaleParams
constructor
A new instance of MarkStaleParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, reason: nil) ⇒ MarkStaleParams
Returns a new instance of MarkStaleParams.
2246 2247 2248 2249 |
# File 'lib/stripe/services/quote_service.rb', line 2246 def initialize(expand: nil, reason: nil) @expand = @reason = reason end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2242 2243 2244 |
# File 'lib/stripe/services/quote_service.rb', line 2242 def @expand end |
#reason ⇒ Object
Reason the Quote is being marked stale.
2244 2245 2246 |
# File 'lib/stripe/services/quote_service.rb', line 2244 def reason @reason end |