Class: Stripe::QuoteService::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: AutomaticTax, Discount, InvoiceSettings, LineItem, SubscriptionData, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(application_fee_amount: nil, application_fee_percent: nil, automatic_tax: nil, collection_method: nil, customer: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, expires_at: nil, footer: nil, header: nil, invoice_settings: nil, line_items: nil, metadata: nil, on_behalf_of: nil, subscription_data: nil, transfer_data: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
# File 'lib/stripe/services/quote_service.rb', line 562

def initialize(
  application_fee_amount: nil,
  application_fee_percent: nil,
  automatic_tax: nil,
  collection_method: nil,
  customer: nil,
  default_tax_rates: nil,
  description: nil,
  discounts: nil,
  expand: nil,
  expires_at: nil,
  footer: nil,
  header: nil,
  invoice_settings: nil,
  line_items: nil,
  metadata: nil,
  on_behalf_of: nil,
  subscription_data: nil,
  transfer_data: nil
)
  @application_fee_amount = application_fee_amount
  @application_fee_percent = application_fee_percent
  @automatic_tax = automatic_tax
  @collection_method = collection_method
  @customer = customer
  @default_tax_rates = default_tax_rates
  @description = description
  @discounts = discounts
  @expand = expand
  @expires_at = expires_at
  @footer = footer
  @header = header
  @invoice_settings = invoice_settings
  @line_items = line_items
  @metadata = 
  @on_behalf_of = on_behalf_of
  @subscription_data = subscription_data
  @transfer_data = transfer_data
end

Instance Attribute Details

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. There cannot be any line items with recurring prices when using this field.



526
527
528
# File 'lib/stripe/services/quote_service.rb', line 526

def application_fee_amount
  @application_fee_amount
end

#application_fee_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. There must be at least 1 line item with a recurring price to use this field.



528
529
530
# File 'lib/stripe/services/quote_service.rb', line 528

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject

Settings for automatic tax lookup for this quote and resulting invoices and subscriptions.



530
531
532
# File 'lib/stripe/services/quote_service.rb', line 530

def automatic_tax
  @automatic_tax
end

#collection_methodObject

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay invoices at the end of the subscription cycle or at invoice finalization using the default payment method attached to the subscription or customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically`.



532
533
534
# File 'lib/stripe/services/quote_service.rb', line 532

def collection_method
  @collection_method
end

#customerObject

The customer for which this quote belongs to. A customer is required before finalizing the quote. Once specified, it cannot be changed.



534
535
536
# File 'lib/stripe/services/quote_service.rb', line 534

def customer
  @customer
end

#default_tax_ratesObject

The tax rates that will apply to any line item that does not have ‘tax_rates` set.



536
537
538
# File 'lib/stripe/services/quote_service.rb', line 536

def default_tax_rates
  @default_tax_rates
end

#descriptionObject

A description that will be displayed on the quote PDF.



538
539
540
# File 'lib/stripe/services/quote_service.rb', line 538

def description
  @description
end

#discountsObject

The discounts applied to the quote.



540
541
542
# File 'lib/stripe/services/quote_service.rb', line 540

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



542
543
544
# File 'lib/stripe/services/quote_service.rb', line 542

def expand
  @expand
end

#expires_atObject

A future timestamp on which the quote will be canceled if in ‘open` or `draft` status. Measured in seconds since the Unix epoch.



544
545
546
# File 'lib/stripe/services/quote_service.rb', line 544

def expires_at
  @expires_at
end

A footer that will be displayed on the quote PDF.



546
547
548
# File 'lib/stripe/services/quote_service.rb', line 546

def footer
  @footer
end

#headerObject

A header that will be displayed on the quote PDF.



548
549
550
# File 'lib/stripe/services/quote_service.rb', line 548

def header
  @header
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



550
551
552
# File 'lib/stripe/services/quote_service.rb', line 550

def invoice_settings
  @invoice_settings
end

#line_itemsObject

A list of line items the customer is being quoted for. Each line item includes information about the product, the quantity, and the resulting cost.



552
553
554
# File 'lib/stripe/services/quote_service.rb', line 552

def line_items
  @line_items
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



554
555
556
# File 'lib/stripe/services/quote_service.rb', line 554

def 
  @metadata
end

#on_behalf_ofObject

The account on behalf of which to charge.



556
557
558
# File 'lib/stripe/services/quote_service.rb', line 556

def on_behalf_of
  @on_behalf_of
end

#subscription_dataObject

When creating a subscription or subscription schedule, the specified configuration data will be used. There must be at least one line item with a recurring price for a subscription or subscription schedule to be created. A subscription schedule is created if ‘subscription_data` is present and in the future, otherwise a subscription is created.



558
559
560
# File 'lib/stripe/services/quote_service.rb', line 558

def subscription_data
  @subscription_data
end

#transfer_dataObject

The data with which to automatically create a Transfer for each of the invoices.



560
561
562
# File 'lib/stripe/services/quote_service.rb', line 560

def transfer_data
  @transfer_data
end