Class: Stripe::QuoteService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: AutomaticTax, Discount, InvoiceSettings, Line, LineItem, SubscriptionData, SubscriptionDataOverride, TransferData
Instance Attribute Summary collapse
-
#allow_backdated_lines ⇒ Object
Set to true to allow quote lines to have ‘starts_at` in the past if collection is paused between `starts_at` and now.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this quote and resulting invoices and subscriptions.
-
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`.
-
#customer ⇒ Object
The customer for which this quote belongs to.
-
#default_tax_rates ⇒ Object
The tax rates that will apply to any line item that does not have ‘tax_rates` set.
-
#description ⇒ Object
A description that will be displayed on the quote PDF.
-
#discounts ⇒ Object
The discounts applied to the quote.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expires_at ⇒ Object
A future timestamp on which the quote will be canceled if in ‘open` or `draft` status.
-
#footer ⇒ Object
A footer that will be displayed on the quote PDF.
-
#header ⇒ Object
A header that will be displayed on the quote PDF.
-
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
-
#line_items ⇒ Object
A list of line items the customer is being quoted for.
-
#lines ⇒ Object
A list of [quote lines](docs.stripe.com/api/quote_lines) on the quote.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#on_behalf_of ⇒ Object
The account on behalf of which to charge.
-
#subscription_data ⇒ Object
When creating a subscription or subscription schedule, the specified configuration data will be used.
-
#subscription_data_overrides ⇒ Object
List representing overrides for ‘subscription_data` configurations for specific subscription schedules.
-
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the invoices.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(allow_backdated_lines: nil, application_fee_amount: nil, application_fee_percent: nil, automatic_tax: nil, collection_method: nil, customer: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, expires_at: nil, footer: nil, header: nil, invoice_settings: nil, line_items: nil, lines: nil, metadata: nil, on_behalf_of: nil, subscription_data: nil, subscription_data_overrides: nil, transfer_data: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 2479 2480 2481 2482 2483 2484 2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 2496 2497 2498 2499 2500 2501 2502 |
# File 'lib/stripe/services/quote_service.rb', line 2458 def initialize( allow_backdated_lines: nil, application_fee_amount: nil, application_fee_percent: nil, automatic_tax: nil, collection_method: nil, customer: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, expires_at: nil, footer: nil, header: nil, invoice_settings: nil, line_items: nil, lines: nil, metadata: nil, on_behalf_of: nil, subscription_data: nil, subscription_data_overrides: nil, transfer_data: nil ) @allow_backdated_lines = allow_backdated_lines @application_fee_amount = application_fee_amount @application_fee_percent = application_fee_percent @automatic_tax = automatic_tax @collection_method = collection_method @customer = customer @default_tax_rates = default_tax_rates @description = description @discounts = discounts @expand = @expires_at = expires_at @footer = @header = header @invoice_settings = invoice_settings @line_items = line_items @lines = lines @metadata = @on_behalf_of = on_behalf_of @subscription_data = subscription_data @subscription_data_overrides = subscription_data_overrides @transfer_data = transfer_data end |
Instance Attribute Details
#allow_backdated_lines ⇒ Object
Set to true to allow quote lines to have ‘starts_at` in the past if collection is paused between `starts_at` and now.
2396 2397 2398 |
# File 'lib/stripe/services/quote_service.rb', line 2396 def allow_backdated_lines @allow_backdated_lines end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. There cannot be any line items with recurring prices when using this field.
2399 2400 2401 |
# File 'lib/stripe/services/quote_service.rb', line 2399 def application_fee_amount @application_fee_amount end |
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. There must be at least 1 line item with a recurring price to use this field.
2402 2403 2404 |
# File 'lib/stripe/services/quote_service.rb', line 2402 def application_fee_percent @application_fee_percent end |
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this quote and resulting invoices and subscriptions.
2405 2406 2407 |
# File 'lib/stripe/services/quote_service.rb', line 2405 def automatic_tax @automatic_tax end |
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay invoices at the end of the subscription cycle or at invoice finalization using the default payment method attached to the subscription or customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically`.
2408 2409 2410 |
# File 'lib/stripe/services/quote_service.rb', line 2408 def collection_method @collection_method end |
#customer ⇒ Object
The customer for which this quote belongs to. A customer is required before finalizing the quote. Once specified, it cannot be changed.
2411 2412 2413 |
# File 'lib/stripe/services/quote_service.rb', line 2411 def customer @customer end |
#default_tax_rates ⇒ Object
The tax rates that will apply to any line item that does not have ‘tax_rates` set.
2414 2415 2416 |
# File 'lib/stripe/services/quote_service.rb', line 2414 def default_tax_rates @default_tax_rates end |
#description ⇒ Object
A description that will be displayed on the quote PDF.
2417 2418 2419 |
# File 'lib/stripe/services/quote_service.rb', line 2417 def description @description end |
#discounts ⇒ Object
The discounts applied to the quote.
2420 2421 2422 |
# File 'lib/stripe/services/quote_service.rb', line 2420 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2423 2424 2425 |
# File 'lib/stripe/services/quote_service.rb', line 2423 def @expand end |
#expires_at ⇒ Object
A future timestamp on which the quote will be canceled if in ‘open` or `draft` status. Measured in seconds since the Unix epoch.
2426 2427 2428 |
# File 'lib/stripe/services/quote_service.rb', line 2426 def expires_at @expires_at end |
#footer ⇒ Object
A footer that will be displayed on the quote PDF.
2429 2430 2431 |
# File 'lib/stripe/services/quote_service.rb', line 2429 def @footer end |
#header ⇒ Object
A header that will be displayed on the quote PDF.
2432 2433 2434 |
# File 'lib/stripe/services/quote_service.rb', line 2432 def header @header end |
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
2435 2436 2437 |
# File 'lib/stripe/services/quote_service.rb', line 2435 def invoice_settings @invoice_settings end |
#line_items ⇒ Object
A list of line items the customer is being quoted for. Each line item includes information about the product, the quantity, and the resulting cost.
2438 2439 2440 |
# File 'lib/stripe/services/quote_service.rb', line 2438 def line_items @line_items end |
#lines ⇒ Object
A list of [quote lines](docs.stripe.com/api/quote_lines) on the quote. These lines describe changes, in the order provided, that will be used to create new subscription schedules or update existing subscription schedules when the quote is accepted.
2441 2442 2443 |
# File 'lib/stripe/services/quote_service.rb', line 2441 def lines @lines end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2444 2445 2446 |
# File 'lib/stripe/services/quote_service.rb', line 2444 def @metadata end |
#on_behalf_of ⇒ Object
The account on behalf of which to charge.
2447 2448 2449 |
# File 'lib/stripe/services/quote_service.rb', line 2447 def on_behalf_of @on_behalf_of end |
#subscription_data ⇒ Object
When creating a subscription or subscription schedule, the specified configuration data will be used. There must be at least one line item with a recurring price for a subscription or subscription schedule to be created. A subscription schedule is created if ‘subscription_data` is present and in the future, otherwise a subscription is created.
2450 2451 2452 |
# File 'lib/stripe/services/quote_service.rb', line 2450 def subscription_data @subscription_data end |
#subscription_data_overrides ⇒ Object
List representing overrides for ‘subscription_data` configurations for specific subscription schedules.
2453 2454 2455 |
# File 'lib/stripe/services/quote_service.rb', line 2453 def subscription_data_overrides @subscription_data_overrides end |
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the invoices.
2456 2457 2458 |
# File 'lib/stripe/services/quote_service.rb', line 2456 def transfer_data @transfer_data end |