Class: Stripe::QuoteService::UpdateParams::AutomaticTax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: Liability

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax

Returns a new instance of AutomaticTax.



345
346
347
348
# File 'lib/stripe/services/quote_service.rb', line 345

def initialize(enabled: nil, liability: nil)
  @enabled = enabled
  @liability = liability
end

Instance Attribute Details

#enabledObject

Controls whether Stripe will automatically compute tax on the resulting invoices or subscriptions as well as the quote itself.



341
342
343
# File 'lib/stripe/services/quote_service.rb', line 341

def enabled
  @enabled
end

#liabilityObject

The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.



343
344
345
# File 'lib/stripe/services/quote_service.rb', line 343

def liability
  @liability
end