Class: Stripe::QuoteService::UpdateParams::AutomaticTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::AutomaticTax
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: Liability
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Controls whether Stripe will automatically compute tax on the resulting invoices or subscriptions as well as the quote itself.
-
#liability ⇒ Object
The account that’s liable for tax.
Instance Method Summary collapse
-
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
constructor
A new instance of AutomaticTax.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
Returns a new instance of AutomaticTax.
1313 1314 1315 1316 |
# File 'lib/stripe/services/quote_service.rb', line 1313 def initialize(enabled: nil, liability: nil) @enabled = enabled @liability = liability end |
Instance Attribute Details
#enabled ⇒ Object
Controls whether Stripe will automatically compute tax on the resulting invoices or subscriptions as well as the quote itself.
1308 1309 1310 |
# File 'lib/stripe/services/quote_service.rb', line 1308 def enabled @enabled end |
#liability ⇒ Object
The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
1311 1312 1313 |
# File 'lib/stripe/services/quote_service.rb', line 1311 def liability @liability end |