Class: Stripe::QuoteService::UpdateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1360
1361
1362
1363
1364
1365
# File 'lib/stripe/services/quote_service.rb', line 1360

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1349
1350
1351
# File 'lib/stripe/services/quote_service.rb', line 1349

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1352
1353
1354
# File 'lib/stripe/services/quote_service.rb', line 1352

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1355
1356
1357
# File 'lib/stripe/services/quote_service.rb', line 1355

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1358
1359
1360
# File 'lib/stripe/services/quote_service.rb', line 1358

def promotion_code
  @promotion_code
end