Class: Stripe::QuoteService::UpdateParams::Line
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::Line
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: Action, AppliesTo, CancelSubscriptionSchedule, EndsAt, SetPauseCollection, StartsAt, TrialSettings
Instance Attribute Summary collapse
-
#actions ⇒ Object
An array of operations the quote line performs.
-
#applies_to ⇒ Object
Details to identify the subscription schedule the quote line applies to.
-
#billing_cycle_anchor ⇒ Object
For point-in-time quote lines (having no ‘ends_at` timestamp), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the Quote Line ‘starts_at` timestamp.For time-span based quote lines (having both `starts_at` and `ends_at`), the only valid value is `automatic`, which removes any previously configured billing cycle anchor resets during the window of time spanning the quote line.
-
#cancel_subscription_schedule ⇒ Object
A point-in-time operation that cancels an existing subscription schedule at the line’s starts_at timestamp.
-
#ends_at ⇒ Object
Details to identify the end of the time range modified by the proposed change.
-
#id ⇒ Object
The ID of an existing line on the quote.
-
#proration_behavior ⇒ Object
Changes to how Stripe handles prorations during the quote line’s time span.
-
#set_pause_collection ⇒ Object
Defines how to pause collection for the underlying subscription throughout the duration of the amendment.
-
#set_schedule_end ⇒ Object
Timestamp helper to end the underlying schedule early, based on the acompanying line’s start or end date.
-
#starts_at ⇒ Object
Details to identify the earliest timestamp where the proposed change should take effect.
-
#trial_settings ⇒ Object
Settings related to subscription trials.
Instance Method Summary collapse
-
#initialize(actions: nil, applies_to: nil, billing_cycle_anchor: nil, cancel_subscription_schedule: nil, ends_at: nil, id: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, starts_at: nil, trial_settings: nil) ⇒ Line
constructor
A new instance of Line.
Methods inherited from RequestParams
Constructor Details
#initialize(actions: nil, applies_to: nil, billing_cycle_anchor: nil, cancel_subscription_schedule: nil, ends_at: nil, id: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, starts_at: nil, trial_settings: nil) ⇒ Line
Returns a new instance of Line.
1691 1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 |
# File 'lib/stripe/services/quote_service.rb', line 1691 def initialize( actions: nil, applies_to: nil, billing_cycle_anchor: nil, cancel_subscription_schedule: nil, ends_at: nil, id: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, starts_at: nil, trial_settings: nil ) @actions = actions @applies_to = applies_to @billing_cycle_anchor = billing_cycle_anchor @cancel_subscription_schedule = cancel_subscription_schedule @ends_at = ends_at @id = id @proration_behavior = proration_behavior @set_pause_collection = set_pause_collection @set_schedule_end = set_schedule_end @starts_at = starts_at @trial_settings = trial_settings end |
Instance Attribute Details
#actions ⇒ Object
An array of operations the quote line performs.
1669 1670 1671 |
# File 'lib/stripe/services/quote_service.rb', line 1669 def actions @actions end |
#applies_to ⇒ Object
Details to identify the subscription schedule the quote line applies to.
1671 1672 1673 |
# File 'lib/stripe/services/quote_service.rb', line 1671 def applies_to @applies_to end |
#billing_cycle_anchor ⇒ Object
For point-in-time quote lines (having no ‘ends_at` timestamp), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the Quote Line ‘starts_at` timestamp.For time-span based quote lines (having both `starts_at` and `ends_at`), the only valid value is `automatic`, which removes any previously configured billing cycle anchor resets during the window of time spanning the quote line.
1673 1674 1675 |
# File 'lib/stripe/services/quote_service.rb', line 1673 def billing_cycle_anchor @billing_cycle_anchor end |
#cancel_subscription_schedule ⇒ Object
A point-in-time operation that cancels an existing subscription schedule at the line’s starts_at timestamp. Currently only compatible with ‘quote_acceptance_date` for `starts_at`. When using cancel_subscription_schedule, the subscription schedule on the quote remains unalterable, except for modifications to the metadata, collection_method or invoice_settings.
1675 1676 1677 |
# File 'lib/stripe/services/quote_service.rb', line 1675 def cancel_subscription_schedule @cancel_subscription_schedule end |
#ends_at ⇒ Object
Details to identify the end of the time range modified by the proposed change. If not supplied, the quote line is considered a point-in-time operation that only affects the exact timestamp at ‘starts_at`, and a restricted set of attributes is supported on the quote line.
1677 1678 1679 |
# File 'lib/stripe/services/quote_service.rb', line 1677 def ends_at @ends_at end |
#id ⇒ Object
The ID of an existing line on the quote.
1679 1680 1681 |
# File 'lib/stripe/services/quote_service.rb', line 1679 def id @id end |
#proration_behavior ⇒ Object
Changes to how Stripe handles prorations during the quote line’s time span. Affects if and how prorations are created when a future phase starts.
1681 1682 1683 |
# File 'lib/stripe/services/quote_service.rb', line 1681 def proration_behavior @proration_behavior end |
#set_pause_collection ⇒ Object
Defines how to pause collection for the underlying subscription throughout the duration of the amendment.
1683 1684 1685 |
# File 'lib/stripe/services/quote_service.rb', line 1683 def set_pause_collection @set_pause_collection end |
#set_schedule_end ⇒ Object
Timestamp helper to end the underlying schedule early, based on the acompanying line’s start or end date.
1685 1686 1687 |
# File 'lib/stripe/services/quote_service.rb', line 1685 def set_schedule_end @set_schedule_end end |
#starts_at ⇒ Object
Details to identify the earliest timestamp where the proposed change should take effect.
1687 1688 1689 |
# File 'lib/stripe/services/quote_service.rb', line 1687 def starts_at @starts_at end |
#trial_settings ⇒ Object
Settings related to subscription trials.
1689 1690 1691 |
# File 'lib/stripe/services/quote_service.rb', line 1689 def trial_settings @trial_settings end |