Class: Stripe::QuoteService::UpdateParams::Line
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::Line
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: Action, AppliesTo, CancelSubscriptionSchedule, EndsAt, SetPauseCollection, StartsAt, TrialSettings
Instance Attribute Summary collapse
-
#actions ⇒ Object
An array of operations the quote line performs.
-
#applies_to ⇒ Object
Details to identify the subscription schedule the quote line applies to.
-
#billing_cycle_anchor ⇒ Object
For point-in-time quote lines (having no ‘ends_at` timestamp), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the Quote Line ‘starts_at` timestamp.For time-span based quote lines (having both `starts_at` and `ends_at`), the only valid value is `automatic`, which removes any previously configured billing cycle anchor resets during the window of time spanning the quote line.
-
#cancel_subscription_schedule ⇒ Object
A point-in-time operation that cancels an existing subscription schedule at the line’s starts_at timestamp.
-
#ends_at ⇒ Object
Details to identify the end of the time range modified by the proposed change.
-
#id ⇒ Object
The ID of an existing line on the quote.
-
#proration_behavior ⇒ Object
Changes to how Stripe handles prorations during the quote line’s time span.
-
#set_pause_collection ⇒ Object
Defines how to pause collection for the underlying subscription throughout the duration of the amendment.
-
#set_schedule_end ⇒ Object
Timestamp helper to end the underlying schedule early, based on the acompanying line’s start or end date.
-
#starts_at ⇒ Object
Details to identify the earliest timestamp where the proposed change should take effect.
-
#trial_settings ⇒ Object
Settings related to subscription trials.
Instance Method Summary collapse
-
#initialize(actions: nil, applies_to: nil, billing_cycle_anchor: nil, cancel_subscription_schedule: nil, ends_at: nil, id: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, starts_at: nil, trial_settings: nil) ⇒ Line
constructor
A new instance of Line.
Methods inherited from RequestParams
Constructor Details
#initialize(actions: nil, applies_to: nil, billing_cycle_anchor: nil, cancel_subscription_schedule: nil, ends_at: nil, id: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, starts_at: nil, trial_settings: nil) ⇒ Line
Returns a new instance of Line.
1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 |
# File 'lib/stripe/services/quote_service.rb', line 1913 def initialize( actions: nil, applies_to: nil, billing_cycle_anchor: nil, cancel_subscription_schedule: nil, ends_at: nil, id: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, starts_at: nil, trial_settings: nil ) @actions = actions @applies_to = applies_to @billing_cycle_anchor = billing_cycle_anchor @cancel_subscription_schedule = cancel_subscription_schedule @ends_at = ends_at @id = id @proration_behavior = proration_behavior @set_pause_collection = set_pause_collection @set_schedule_end = set_schedule_end @starts_at = starts_at @trial_settings = trial_settings end |
Instance Attribute Details
#actions ⇒ Object
An array of operations the quote line performs.
1881 1882 1883 |
# File 'lib/stripe/services/quote_service.rb', line 1881 def actions @actions end |
#applies_to ⇒ Object
Details to identify the subscription schedule the quote line applies to.
1884 1885 1886 |
# File 'lib/stripe/services/quote_service.rb', line 1884 def applies_to @applies_to end |
#billing_cycle_anchor ⇒ Object
For point-in-time quote lines (having no ‘ends_at` timestamp), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the Quote Line ‘starts_at` timestamp.For time-span based quote lines (having both `starts_at` and `ends_at`), the only valid value is `automatic`, which removes any previously configured billing cycle anchor resets during the window of time spanning the quote line.
1887 1888 1889 |
# File 'lib/stripe/services/quote_service.rb', line 1887 def billing_cycle_anchor @billing_cycle_anchor end |
#cancel_subscription_schedule ⇒ Object
A point-in-time operation that cancels an existing subscription schedule at the line’s starts_at timestamp. Currently only compatible with ‘quote_acceptance_date` for `starts_at`. When using cancel_subscription_schedule, the subscription schedule on the quote remains unalterable, except for modifications to the metadata, collection_method or invoice_settings.
1890 1891 1892 |
# File 'lib/stripe/services/quote_service.rb', line 1890 def cancel_subscription_schedule @cancel_subscription_schedule end |
#ends_at ⇒ Object
Details to identify the end of the time range modified by the proposed change. If not supplied, the quote line is considered a point-in-time operation that only affects the exact timestamp at ‘starts_at`, and a restricted set of attributes is supported on the quote line.
1893 1894 1895 |
# File 'lib/stripe/services/quote_service.rb', line 1893 def ends_at @ends_at end |
#id ⇒ Object
The ID of an existing line on the quote.
1896 1897 1898 |
# File 'lib/stripe/services/quote_service.rb', line 1896 def id @id end |
#proration_behavior ⇒ Object
Changes to how Stripe handles prorations during the quote line’s time span. Affects if and how prorations are created when a future phase starts.
1899 1900 1901 |
# File 'lib/stripe/services/quote_service.rb', line 1899 def proration_behavior @proration_behavior end |
#set_pause_collection ⇒ Object
Defines how to pause collection for the underlying subscription throughout the duration of the amendment.
1902 1903 1904 |
# File 'lib/stripe/services/quote_service.rb', line 1902 def set_pause_collection @set_pause_collection end |
#set_schedule_end ⇒ Object
Timestamp helper to end the underlying schedule early, based on the acompanying line’s start or end date.
1905 1906 1907 |
# File 'lib/stripe/services/quote_service.rb', line 1905 def set_schedule_end @set_schedule_end end |
#starts_at ⇒ Object
Details to identify the earliest timestamp where the proposed change should take effect.
1908 1909 1910 |
# File 'lib/stripe/services/quote_service.rb', line 1908 def starts_at @starts_at end |
#trial_settings ⇒ Object
Settings related to subscription trials.
1911 1912 1913 |
# File 'lib/stripe/services/quote_service.rb', line 1911 def trial_settings @trial_settings end |