Class: Stripe::QuoteService::UpdateParams::Line::Action::AddDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ AddDiscount

Returns a new instance of AddDiscount.



1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
# File 'lib/stripe/services/quote_service.rb', line 1261

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



1251
1252
1253
# File 'lib/stripe/services/quote_service.rb', line 1251

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



1253
1254
1255
# File 'lib/stripe/services/quote_service.rb', line 1253

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1255
1256
1257
# File 'lib/stripe/services/quote_service.rb', line 1255

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



1257
1258
1259
# File 'lib/stripe/services/quote_service.rb', line 1257

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



1259
1260
1261
# File 'lib/stripe/services/quote_service.rb', line 1259

def promotion_code
  @promotion_code
end