Class: Stripe::QuoteService::UpdateParams::Line::Action::AddDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ AddDiscount

Returns a new instance of AddDiscount.



1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
# File 'lib/stripe/services/quote_service.rb', line 1249

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



1239
1240
1241
# File 'lib/stripe/services/quote_service.rb', line 1239

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



1241
1242
1243
# File 'lib/stripe/services/quote_service.rb', line 1241

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1243
1244
1245
# File 'lib/stripe/services/quote_service.rb', line 1243

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



1245
1246
1247
# File 'lib/stripe/services/quote_service.rb', line 1245

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



1247
1248
1249
# File 'lib/stripe/services/quote_service.rb', line 1247

def promotion_code
  @promotion_code
end