Class: Stripe::QuoteService::UpdateParams::Line::Action::AddDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ AddDiscount

Returns a new instance of AddDiscount.



1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
# File 'lib/stripe/services/quote_service.rb', line 1419

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



1405
1406
1407
# File 'lib/stripe/services/quote_service.rb', line 1405

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



1408
1409
1410
# File 'lib/stripe/services/quote_service.rb', line 1408

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1411
1412
1413
# File 'lib/stripe/services/quote_service.rb', line 1411

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



1414
1415
1416
# File 'lib/stripe/services/quote_service.rb', line 1414

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



1417
1418
1419
# File 'lib/stripe/services/quote_service.rb', line 1417

def promotion_code
  @promotion_code
end