Class: Stripe::QuoteService::UpdateParams::Line::Action::AddItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ AddItem

Returns a new instance of AddItem.



1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
# File 'lib/stripe/services/quote_service.rb', line 1344

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



1332
1333
1334
# File 'lib/stripe/services/quote_service.rb', line 1332

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1334
1335
1336
# File 'lib/stripe/services/quote_service.rb', line 1334

def 
  @metadata
end

#priceObject

The ID of the price object.



1336
1337
1338
# File 'lib/stripe/services/quote_service.rb', line 1336

def price
  @price
end

#quantityObject

Quantity for this item.



1338
1339
1340
# File 'lib/stripe/services/quote_service.rb', line 1338

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



1340
1341
1342
# File 'lib/stripe/services/quote_service.rb', line 1340

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



1342
1343
1344
# File 'lib/stripe/services/quote_service.rb', line 1342

def trial
  @trial
end