Class: Stripe::QuoteService::UpdateParams::Line::Action::AddItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ AddItem

Returns a new instance of AddItem.



1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
# File 'lib/stripe/services/quote_service.rb', line 1514

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



1497
1498
1499
# File 'lib/stripe/services/quote_service.rb', line 1497

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1500
1501
1502
# File 'lib/stripe/services/quote_service.rb', line 1500

def 
  @metadata
end

#priceObject

The ID of the price object.



1503
1504
1505
# File 'lib/stripe/services/quote_service.rb', line 1503

def price
  @price
end

#quantityObject

Quantity for this item.



1506
1507
1508
# File 'lib/stripe/services/quote_service.rb', line 1506

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



1509
1510
1511
# File 'lib/stripe/services/quote_service.rb', line 1509

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



1512
1513
1514
# File 'lib/stripe/services/quote_service.rb', line 1512

def trial
  @trial
end