Class: Stripe::QuoteService::UpdateParams::Line::Action::AddItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1458
1459
1460
1461
1462
# File 'lib/stripe/services/quote_service.rb', line 1458

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1450
1451
1452
# File 'lib/stripe/services/quote_service.rb', line 1450

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1453
1454
1455
# File 'lib/stripe/services/quote_service.rb', line 1453

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1456
1457
1458
# File 'lib/stripe/services/quote_service.rb', line 1456

def type
  @type
end