Class: Stripe::QuoteService::UpdateParams::Line::Action::RemoveDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ RemoveDiscount

Returns a new instance of RemoveDiscount.



1541
1542
1543
1544
1545
# File 'lib/stripe/services/quote_service.rb', line 1541

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



1533
1534
1535
# File 'lib/stripe/services/quote_service.rb', line 1533

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



1536
1537
1538
# File 'lib/stripe/services/quote_service.rb', line 1536

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



1539
1540
1541
# File 'lib/stripe/services/quote_service.rb', line 1539

def promotion_code
  @promotion_code
end