Class: Stripe::QuoteService::UpdateParams::Line::Action::RemoveDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ RemoveDiscount

Returns a new instance of RemoveDiscount.



1357
1358
1359
1360
1361
# File 'lib/stripe/services/quote_service.rb', line 1357

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



1351
1352
1353
# File 'lib/stripe/services/quote_service.rb', line 1351

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



1353
1354
1355
# File 'lib/stripe/services/quote_service.rb', line 1353

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



1355
1356
1357
# File 'lib/stripe/services/quote_service.rb', line 1355

def promotion_code
  @promotion_code
end