Class: Stripe::QuoteService::UpdateParams::Line::Action::SetDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount

Returns a new instance of SetDiscount.



1393
1394
1395
1396
1397
# File 'lib/stripe/services/quote_service.rb', line 1393

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



1387
1388
1389
# File 'lib/stripe/services/quote_service.rb', line 1387

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



1389
1390
1391
# File 'lib/stripe/services/quote_service.rb', line 1389

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



1391
1392
1393
# File 'lib/stripe/services/quote_service.rb', line 1391

def promotion_code
  @promotion_code
end