Class: Stripe::QuoteService::UpdateParams::Line::Action::SetDiscount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::Line::Action::SetDiscount
- Defined in:
- lib/stripe/services/quote_service.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
-
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
-
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount
constructor
A new instance of SetDiscount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount
Returns a new instance of SetDiscount.
1389 1390 1391 1392 1393 |
# File 'lib/stripe/services/quote_service.rb', line 1389 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
1383 1384 1385 |
# File 'lib/stripe/services/quote_service.rb', line 1383 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
1385 1386 1387 |
# File 'lib/stripe/services/quote_service.rb', line 1385 def discount @discount end |
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
1387 1388 1389 |
# File 'lib/stripe/services/quote_service.rb', line 1387 def promotion_code @promotion_code end |