Class: Stripe::QuoteService::UpdateParams::Line::Action::SetDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount

Returns a new instance of SetDiscount.



1381
1382
1383
1384
1385
# File 'lib/stripe/services/quote_service.rb', line 1381

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



1375
1376
1377
# File 'lib/stripe/services/quote_service.rb', line 1375

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



1377
1378
1379
# File 'lib/stripe/services/quote_service.rb', line 1377

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



1379
1380
1381
# File 'lib/stripe/services/quote_service.rb', line 1379

def promotion_code
  @promotion_code
end