Class: Stripe::QuoteService::UpdateParams::Line::Action::SetItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1616
1617
1618
1619
1620
1621
# File 'lib/stripe/services/quote_service.rb', line 1616

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1605
1606
1607
# File 'lib/stripe/services/quote_service.rb', line 1605

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1608
1609
1610
# File 'lib/stripe/services/quote_service.rb', line 1608

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1611
1612
1613
# File 'lib/stripe/services/quote_service.rb', line 1611

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1614
1615
1616
# File 'lib/stripe/services/quote_service.rb', line 1614

def promotion_code
  @promotion_code
end