Class: Stripe::QuoteService::UpdateParams::Line::Action::SetItem::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::Line::Action::SetItem::Discount
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1616 1617 1618 1619 1620 1621 |
# File 'lib/stripe/services/quote_service.rb', line 1616 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1605 1606 1607 |
# File 'lib/stripe/services/quote_service.rb', line 1605 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1608 1609 1610 |
# File 'lib/stripe/services/quote_service.rb', line 1608 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1611 1612 1613 |
# File 'lib/stripe/services/quote_service.rb', line 1611 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1614 1615 1616 |
# File 'lib/stripe/services/quote_service.rb', line 1614 def promotion_code @promotion_code end |