Class: Stripe::QuoteService::UpdateParams::Line::Action::SetItem::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::Line::Action::SetItem::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1430 1431 1432 1433 1434 |
# File 'lib/stripe/services/quote_service.rb', line 1430 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1424 1425 1426 |
# File 'lib/stripe/services/quote_service.rb', line 1424 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1426 1427 1428 |
# File 'lib/stripe/services/quote_service.rb', line 1426 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1428 1429 1430 |
# File 'lib/stripe/services/quote_service.rb', line 1428 def type @type end |