Class: Stripe::QuoteService::UpdateParams::Line::Action::SetItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1417
1418
1419
1420
1421
# File 'lib/stripe/services/quote_service.rb', line 1417

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1411
1412
1413
# File 'lib/stripe/services/quote_service.rb', line 1411

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1413
1414
1415
# File 'lib/stripe/services/quote_service.rb', line 1413

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1415
1416
1417
# File 'lib/stripe/services/quote_service.rb', line 1415

def type
  @type
end