Class: Stripe::QuoteService::UpdateParams::Line::Action::SetItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1598
1599
1600
1601
1602
# File 'lib/stripe/services/quote_service.rb', line 1598

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1590
1591
1592
# File 'lib/stripe/services/quote_service.rb', line 1590

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1593
1594
1595
# File 'lib/stripe/services/quote_service.rb', line 1593

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1596
1597
1598
# File 'lib/stripe/services/quote_service.rb', line 1596

def type
  @type
end