Class: Stripe::QuoteService::UpdateParams::Line::Action::SetItem::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::Line::Action::SetItem::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1598 1599 1600 1601 1602 |
# File 'lib/stripe/services/quote_service.rb', line 1598 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1590 1591 1592 |
# File 'lib/stripe/services/quote_service.rb', line 1590 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1593 1594 1595 |
# File 'lib/stripe/services/quote_service.rb', line 1593 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1596 1597 1598 |
# File 'lib/stripe/services/quote_service.rb', line 1596 def type @type end |