Class: Stripe::QuoteService::UpdateParams::Line::CancelSubscriptionSchedule

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(cancel_at: nil, invoice_now: nil, prorate: nil) ⇒ CancelSubscriptionSchedule

Returns a new instance of CancelSubscriptionSchedule.



1549
1550
1551
1552
1553
# File 'lib/stripe/services/quote_service.rb', line 1549

def initialize(cancel_at: nil, invoice_now: nil, prorate: nil)
  @cancel_at = cancel_at
  @invoice_now = invoice_now
  @prorate = prorate
end

Instance Attribute Details

#cancel_atObject

Timestamp helper to cancel the underlying schedule on the accompanying line’s start date. Must be set to ‘line_starts_at`.



1543
1544
1545
# File 'lib/stripe/services/quote_service.rb', line 1543

def cancel_at
  @cancel_at
end

#invoice_nowObject

If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items. Boolean that defaults to `true`.



1545
1546
1547
# File 'lib/stripe/services/quote_service.rb', line 1545

def invoice_now
  @invoice_now
end

#prorateObject

If the subscription schedule is ‘active`, indicates if the cancellation should be prorated. Boolean that defaults to `true`.



1547
1548
1549
# File 'lib/stripe/services/quote_service.rb', line 1547

def prorate
  @prorate
end