Class: Stripe::QuoteService::UpdateParams::Line::EndsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::Line::EndsAt
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: DiscountEnd, Duration
Instance Attribute Summary collapse
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
Select a way to pass in ‘ends_at`.
Instance Method Summary collapse
-
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
constructor
A new instance of EndsAt.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
Returns a new instance of EndsAt.
1586 1587 1588 1589 1590 1591 |
# File 'lib/stripe/services/quote_service.rb', line 1586 def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) @discount_end = discount_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
1578 1579 1580 |
# File 'lib/stripe/services/quote_service.rb', line 1578 def discount_end @discount_end end |
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
1580 1581 1582 |
# File 'lib/stripe/services/quote_service.rb', line 1580 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp.
1582 1583 1584 |
# File 'lib/stripe/services/quote_service.rb', line 1582 def @timestamp end |
#type ⇒ Object
Select a way to pass in ‘ends_at`.
1584 1585 1586 |
# File 'lib/stripe/services/quote_service.rb', line 1584 def type @type end |