Class: Stripe::QuoteService::UpdateParams::Line::EndsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::Line::EndsAt
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: DiscountEnd, Duration
Instance Attribute Summary collapse
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
Select a way to pass in ‘ends_at`.
Instance Method Summary collapse
-
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
constructor
A new instance of EndsAt.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
Returns a new instance of EndsAt.
1793 1794 1795 1796 1797 1798 |
# File 'lib/stripe/services/quote_service.rb', line 1793 def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) @discount_end = discount_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
1782 1783 1784 |
# File 'lib/stripe/services/quote_service.rb', line 1782 def discount_end @discount_end end |
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
1785 1786 1787 |
# File 'lib/stripe/services/quote_service.rb', line 1785 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp.
1788 1789 1790 |
# File 'lib/stripe/services/quote_service.rb', line 1788 def @timestamp end |
#type ⇒ Object
Select a way to pass in ‘ends_at`.
1791 1792 1793 |
# File 'lib/stripe/services/quote_service.rb', line 1791 def type @type end |