Class: Stripe::QuoteService::UpdateParams::Line::StartsAt::LineEndsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::Line::StartsAt::LineEndsAt
- Defined in:
- lib/stripe/services/quote_service.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of a quote line.
-
#index ⇒ Object
The position of the previous quote line in the ‘lines` array after which this line should begin.
Instance Method Summary collapse
-
#initialize(id: nil, index: nil) ⇒ LineEndsAt
constructor
A new instance of LineEndsAt.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, index: nil) ⇒ LineEndsAt
Returns a new instance of LineEndsAt.
1634 1635 1636 1637 |
# File 'lib/stripe/services/quote_service.rb', line 1634 def initialize(id: nil, index: nil) @id = id @index = index end |
Instance Attribute Details
#id ⇒ Object
The ID of a quote line.
1630 1631 1632 |
# File 'lib/stripe/services/quote_service.rb', line 1630 def id @id end |
#index ⇒ Object
The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.
1632 1633 1634 |
# File 'lib/stripe/services/quote_service.rb', line 1632 def index @index end |