Class: Stripe::QuoteService::UpdateParams::Line::StartsAt::LineEndsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineEndsAt

Returns a new instance of LineEndsAt.



1622
1623
1624
1625
# File 'lib/stripe/services/quote_service.rb', line 1622

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



1618
1619
1620
# File 'lib/stripe/services/quote_service.rb', line 1618

def id
  @id
end

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



1620
1621
1622
# File 'lib/stripe/services/quote_service.rb', line 1620

def index
  @index
end