Class: Stripe::QuoteService::UpdateParams::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



1829
1830
1831
1832
1833
1834
1835
1836
1837
1838
1839
1840
1841
1842
1843
# File 'lib/stripe/services/quote_service.rb', line 1829

def initialize(
  discounts: nil,
  id: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discounts = discounts
  @id = id
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The discounts applied to this line item.



1817
1818
1819
# File 'lib/stripe/services/quote_service.rb', line 1817

def discounts
  @discounts
end

#idObject

The ID of an existing line item on the quote.



1819
1820
1821
# File 'lib/stripe/services/quote_service.rb', line 1819

def id
  @id
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



1821
1822
1823
# File 'lib/stripe/services/quote_service.rb', line 1821

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



1823
1824
1825
# File 'lib/stripe/services/quote_service.rb', line 1823

def price_data
  @price_data
end

#quantityObject

The quantity of the line item.



1825
1826
1827
# File 'lib/stripe/services/quote_service.rb', line 1825

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the quote do not apply to this line item.



1827
1828
1829
# File 'lib/stripe/services/quote_service.rb', line 1827

def tax_rates
  @tax_rates
end