Class: Stripe::QuoteService::UpdateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::LineItem
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to this line item.
-
#id ⇒ Object
The ID of an existing line item on the quote.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
The quantity of the line item.
-
#tax_rates ⇒ Object
The tax rates which apply to the line item.
Instance Method Summary collapse
-
#initialize(discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
Returns a new instance of LineItem.
2055 2056 2057 2058 2059 2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 |
# File 'lib/stripe/services/quote_service.rb', line 2055 def initialize( discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @discounts = discounts @id = id @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to this line item.
2038 2039 2040 |
# File 'lib/stripe/services/quote_service.rb', line 2038 def discounts @discounts end |
#id ⇒ Object
The ID of an existing line item on the quote.
2041 2042 2043 |
# File 'lib/stripe/services/quote_service.rb', line 2041 def id @id end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
2044 2045 2046 |
# File 'lib/stripe/services/quote_service.rb', line 2044 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
2047 2048 2049 |
# File 'lib/stripe/services/quote_service.rb', line 2047 def price_data @price_data end |
#quantity ⇒ Object
The quantity of the line item.
2050 2051 2052 |
# File 'lib/stripe/services/quote_service.rb', line 2050 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the quote do not apply to this line item.
2053 2054 2055 |
# File 'lib/stripe/services/quote_service.rb', line 2053 def tax_rates @tax_rates end |