Class: Stripe::QuoteService::UpdateParams::LineItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



415
416
417
418
419
# File 'lib/stripe/services/quote_service.rb', line 415

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



409
410
411
# File 'lib/stripe/services/quote_service.rb', line 409

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



411
412
413
# File 'lib/stripe/services/quote_service.rb', line 411

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



413
414
415
# File 'lib/stripe/services/quote_service.rb', line 413

def promotion_code
  @promotion_code
end