Class: Stripe::QuoteService::UpdateParams::LineItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1982
1983
1984
1985
1986
1987
# File 'lib/stripe/services/quote_service.rb', line 1982

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1971
1972
1973
# File 'lib/stripe/services/quote_service.rb', line 1971

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1974
1975
1976
# File 'lib/stripe/services/quote_service.rb', line 1974

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1977
1978
1979
# File 'lib/stripe/services/quote_service.rb', line 1977

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1980
1981
1982
# File 'lib/stripe/services/quote_service.rb', line 1980

def promotion_code
  @promotion_code
end