Class: Stripe::QuoteService::UpdateParams::LineItem::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::LineItem::Discount
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1746 1747 1748 1749 1750 1751 |
# File 'lib/stripe/services/quote_service.rb', line 1746 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1738 1739 1740 |
# File 'lib/stripe/services/quote_service.rb', line 1738 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1740 1741 1742 |
# File 'lib/stripe/services/quote_service.rb', line 1740 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1742 1743 1744 |
# File 'lib/stripe/services/quote_service.rb', line 1742 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1744 1745 1746 |
# File 'lib/stripe/services/quote_service.rb', line 1744 def promotion_code @promotion_code end |