Class: Stripe::QuoteService::UpdateParams::LineItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1964
1965
1966
1967
1968
# File 'lib/stripe/services/quote_service.rb', line 1964

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1956
1957
1958
# File 'lib/stripe/services/quote_service.rb', line 1956

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1959
1960
1961
# File 'lib/stripe/services/quote_service.rb', line 1959

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1962
1963
1964
# File 'lib/stripe/services/quote_service.rb', line 1962

def type
  @type
end