Class: Stripe::QuoteService::UpdateParams::LineItem::Discount::DiscountEnd::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



1719
1720
1721
1722
# File 'lib/stripe/services/quote_service.rb', line 1719

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1715
1716
1717
# File 'lib/stripe/services/quote_service.rb', line 1715

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1717
1718
1719
# File 'lib/stripe/services/quote_service.rb', line 1717

def interval_count
  @interval_count
end