Class: Stripe::QuoteService::UpdateParams::SubscriptionData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, effective_date: nil, metadata: nil, trial_period_days: nil) ⇒ SubscriptionData

Returns a new instance of SubscriptionData.



503
504
505
506
507
508
# File 'lib/stripe/services/quote_service.rb', line 503

def initialize(description: nil, effective_date: nil, metadata: nil, trial_period_days: nil)
  @description = description
  @effective_date = effective_date
  @metadata = 
  @trial_period_days = trial_period_days
end

Instance Attribute Details

#descriptionObject

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



495
496
497
# File 'lib/stripe/services/quote_service.rb', line 495

def description
  @description
end

#effective_dateObject

When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted. The ‘effective_date` is ignored if it is in the past when the quote is accepted.



497
498
499
# File 'lib/stripe/services/quote_service.rb', line 497

def effective_date
  @effective_date
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that will set metadata on the subscription or subscription schedule when the quote is accepted. If a recurring price is included in ‘line_items`, this field will be passed to the resulting subscription’s ‘metadata` field. If `subscription_data.effective_date` is used, this field will be passed to the resulting subscription schedule’s ‘phases.metadata` field. Unlike object-level metadata, this field is declarative. Updates will clear prior values.



499
500
501
# File 'lib/stripe/services/quote_service.rb', line 499

def 
  @metadata
end

#trial_period_daysObject

Integer representing the number of trial period days before the customer is charged for the first time.



501
502
503
# File 'lib/stripe/services/quote_service.rb', line 501

def trial_period_days
  @trial_period_days
end