Class: Stripe::QuoteService::UpdateParams::SubscriptionData::BillOnAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: BillFrom, BillUntil

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bill_from: nil, bill_until: nil) ⇒ BillOnAcceptance

Returns a new instance of BillOnAcceptance.



1906
1907
1908
1909
# File 'lib/stripe/services/quote_service.rb', line 1906

def initialize(bill_from: nil, bill_until: nil)
  @bill_from = bill_from
  @bill_until = bill_until
end

Instance Attribute Details

#bill_fromObject

The start of the period to bill from when the Quote is accepted.



1902
1903
1904
# File 'lib/stripe/services/quote_service.rb', line 1902

def bill_from
  @bill_from
end

#bill_untilObject

The end of the period to bill until when the Quote is accepted.



1904
1905
1906
# File 'lib/stripe/services/quote_service.rb', line 1904

def bill_until
  @bill_until
end