Class: Stripe::QuoteService::UpdateParams::SubscriptionData::BillOnAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteService::UpdateParams::SubscriptionData::BillOnAcceptance
- Defined in:
- lib/stripe/services/quote_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#bill_from ⇒ Object
The start of the period to bill from when the Quote is accepted.
-
#bill_until ⇒ Object
The end of the period to bill until when the Quote is accepted.
Instance Method Summary collapse
-
#initialize(bill_from: nil, bill_until: nil) ⇒ BillOnAcceptance
constructor
A new instance of BillOnAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(bill_from: nil, bill_until: nil) ⇒ BillOnAcceptance
Returns a new instance of BillOnAcceptance.
2154 2155 2156 2157 |
# File 'lib/stripe/services/quote_service.rb', line 2154 def initialize(bill_from: nil, bill_until: nil) @bill_from = bill_from @bill_until = bill_until end |
Instance Attribute Details
#bill_from ⇒ Object
The start of the period to bill from when the Quote is accepted.
2149 2150 2151 |
# File 'lib/stripe/services/quote_service.rb', line 2149 def bill_from @bill_from end |
#bill_until ⇒ Object
The end of the period to bill until when the Quote is accepted.
2152 2153 2154 |
# File 'lib/stripe/services/quote_service.rb', line 2152 def bill_until @bill_until end |