Class: Stripe::QuoteService::UpdateParams::SubscriptionDataOverride

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: AppliesTo, BillOnAcceptance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(applies_to: nil, bill_on_acceptance: nil, billing_behavior: nil, customer: nil, description: nil, end_behavior: nil, proration_behavior: nil) ⇒ SubscriptionDataOverride

Returns a new instance of SubscriptionDataOverride.



2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
# File 'lib/stripe/services/quote_service.rb', line 2078

def initialize(
  applies_to: nil,
  bill_on_acceptance: nil,
  billing_behavior: nil,
  customer: nil,
  description: nil,
  end_behavior: nil,
  proration_behavior: nil
)
  @applies_to = applies_to
  @bill_on_acceptance = bill_on_acceptance
  @billing_behavior = billing_behavior
  @customer = customer
  @description = description
  @end_behavior = end_behavior
  @proration_behavior = proration_behavior
end

Instance Attribute Details

#applies_toObject

Whether the override applies to an existing Subscription Schedule or a new Subscription Schedule.



2058
2059
2060
# File 'lib/stripe/services/quote_service.rb', line 2058

def applies_to
  @applies_to
end

#bill_on_acceptanceObject

Describes the period to bill for upon accepting the quote.



2060
2061
2062
# File 'lib/stripe/services/quote_service.rb', line 2060

def bill_on_acceptance
  @bill_on_acceptance
end

#billing_behaviorObject

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



2062
2063
2064
# File 'lib/stripe/services/quote_service.rb', line 2062

def billing_behavior
  @billing_behavior
end

#customerObject

The customer the Subscription Data override applies to.



2064
2065
2066
# File 'lib/stripe/services/quote_service.rb', line 2064

def customer
  @customer
end

#descriptionObject

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



2066
2067
2068
# File 'lib/stripe/services/quote_service.rb', line 2066

def description
  @description
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends.



2068
2069
2070
# File 'lib/stripe/services/quote_service.rb', line 2068

def end_behavior
  @end_behavior
end

#proration_behaviorObject

Determines how to handle [prorations](stripe.com/docs/subscriptions/billing-cycle#prorations). When creating a subscription, valid values are ‘create_prorations` or `none`.

When updating a subscription, valid values are ‘create_prorations`, `none`, or `always_invoice`.

Passing ‘create_prorations` will cause proration invoice items to be created when applicable. These proration items will only be invoiced immediately under [certain conditions](stripe.com/docs/subscriptions/upgrading-downgrading#immediate-payment). In order to always invoice immediately for prorations, pass `always_invoice`.

Prorations can be disabled by passing ‘none`.



2076
2077
2078
# File 'lib/stripe/services/quote_service.rb', line 2076

def proration_behavior
  @proration_behavior
end