Class: Stripe::QuoteService::UpdateParams::SubscriptionDataOverride::BillOnAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/quote_service.rb

Defined Under Namespace

Classes: BillFrom, BillUntil

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bill_from: nil, bill_until: nil) ⇒ BillOnAcceptance

Returns a new instance of BillOnAcceptance.



2052
2053
2054
2055
# File 'lib/stripe/services/quote_service.rb', line 2052

def initialize(bill_from: nil, bill_until: nil)
  @bill_from = bill_from
  @bill_until = bill_until
end

Instance Attribute Details

#bill_fromObject

The start of the period to bill from when the Quote is accepted.



2048
2049
2050
# File 'lib/stripe/services/quote_service.rb', line 2048

def bill_from
  @bill_from
end

#bill_untilObject

The end of the period to bill until when the Quote is accepted.



2050
2051
2052
# File 'lib/stripe/services/quote_service.rb', line 2050

def bill_until
  @bill_until
end