Class: Stripe::QuoteUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Classes: AutomaticTax, Discount, InvoiceSettings, Line, LineItem, SubscriptionData, SubscriptionDataOverride, TransferData
Instance Attribute Summary collapse
-
#allow_backdated_lines ⇒ Object
Set to true to allow quote lines to have
starts_atin the past if collection is paused betweenstarts_atand now. -
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account.
-
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this quote and resulting invoices and subscriptions.
-
#collection_method ⇒ Object
Either
charge_automatically, orsend_invoice. -
#customer ⇒ Object
The customer for which this quote belongs to.
-
#customer_account ⇒ Object
The account for which this quote belongs to.
-
#default_tax_rates ⇒ Object
The tax rates that will apply to any line item that does not have
tax_ratesset. -
#description ⇒ Object
A description that will be displayed on the quote PDF.
-
#discounts ⇒ Object
The discounts applied to the quote.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expires_at ⇒ Object
A future timestamp on which the quote will be canceled if in
openordraftstatus. -
#footer ⇒ Object
A footer that will be displayed on the quote PDF.
-
#header ⇒ Object
A header that will be displayed on the quote PDF.
-
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
-
#line_items ⇒ Object
A list of line items the customer is being quoted for.
-
#lines ⇒ Object
A list of quote lines on the quote.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#on_behalf_of ⇒ Object
The account on behalf of which to charge.
-
#subscription_data ⇒ Object
When creating a subscription or subscription schedule, the specified configuration data will be used.
-
#subscription_data_overrides ⇒ Object
List representing overrides for
subscription_dataconfigurations for specific subscription schedules. -
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the invoices.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(allow_backdated_lines: nil, application_fee_amount: nil, application_fee_percent: nil, automatic_tax: nil, collection_method: nil, customer: nil, customer_account: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, expires_at: nil, footer: nil, header: nil, invoice_settings: nil, line_items: nil, lines: nil, metadata: nil, on_behalf_of: nil, subscription_data: nil, subscription_data_overrides: nil, transfer_data: nil) ⇒ QuoteUpdateParams
Returns a new instance of QuoteUpdateParams.
1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 |
# File 'lib/stripe/params/quote_update_params.rb', line 1477 def initialize( allow_backdated_lines: nil, application_fee_amount: nil, application_fee_percent: nil, automatic_tax: nil, collection_method: nil, customer: nil, customer_account: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, expires_at: nil, footer: nil, header: nil, invoice_settings: nil, line_items: nil, lines: nil, metadata: nil, on_behalf_of: nil, subscription_data: nil, subscription_data_overrides: nil, transfer_data: nil ) @allow_backdated_lines = allow_backdated_lines @application_fee_amount = application_fee_amount @application_fee_percent = application_fee_percent @automatic_tax = automatic_tax @collection_method = collection_method @customer = customer @customer_account = customer_account @default_tax_rates = default_tax_rates @description = description @discounts = discounts @expand = @expires_at = expires_at @footer = @header = header @invoice_settings = invoice_settings @line_items = line_items @lines = lines @metadata = @on_behalf_of = on_behalf_of @subscription_data = subscription_data @subscription_data_overrides = subscription_data_overrides @transfer_data = transfer_data end |
Instance Attribute Details
#allow_backdated_lines ⇒ Object
Set to true to allow quote lines to have starts_at in the past if collection is paused between starts_at and now.
1433 1434 1435 |
# File 'lib/stripe/params/quote_update_params.rb', line 1433 def allow_backdated_lines @allow_backdated_lines end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. There cannot be any line items with recurring prices when using this field.
1435 1436 1437 |
# File 'lib/stripe/params/quote_update_params.rb', line 1435 def application_fee_amount @application_fee_amount end |
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner's Stripe account. There must be at least 1 line item with a recurring price to use this field.
1437 1438 1439 |
# File 'lib/stripe/params/quote_update_params.rb', line 1437 def application_fee_percent @application_fee_percent end |
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this quote and resulting invoices and subscriptions.
1439 1440 1441 |
# File 'lib/stripe/params/quote_update_params.rb', line 1439 def automatic_tax @automatic_tax end |
#collection_method ⇒ Object
Either charge_automatically, or send_invoice. When charging automatically, Stripe will attempt to pay invoices at the end of the subscription cycle or at invoice finalization using the default payment method attached to the subscription or customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as active. Defaults to charge_automatically.
1441 1442 1443 |
# File 'lib/stripe/params/quote_update_params.rb', line 1441 def collection_method @collection_method end |
#customer ⇒ Object
The customer for which this quote belongs to. A customer is required before finalizing the quote. Once specified, it cannot be changed.
1443 1444 1445 |
# File 'lib/stripe/params/quote_update_params.rb', line 1443 def customer @customer end |
#customer_account ⇒ Object
The account for which this quote belongs to. A customer or account is required before finalizing the quote. Once specified, it cannot be changed.
1445 1446 1447 |
# File 'lib/stripe/params/quote_update_params.rb', line 1445 def customer_account @customer_account end |
#default_tax_rates ⇒ Object
The tax rates that will apply to any line item that does not have tax_rates set.
1447 1448 1449 |
# File 'lib/stripe/params/quote_update_params.rb', line 1447 def default_tax_rates @default_tax_rates end |
#description ⇒ Object
A description that will be displayed on the quote PDF.
1449 1450 1451 |
# File 'lib/stripe/params/quote_update_params.rb', line 1449 def description @description end |
#discounts ⇒ Object
The discounts applied to the quote.
1451 1452 1453 |
# File 'lib/stripe/params/quote_update_params.rb', line 1451 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1453 1454 1455 |
# File 'lib/stripe/params/quote_update_params.rb', line 1453 def @expand end |
#expires_at ⇒ Object
A future timestamp on which the quote will be canceled if in open or draft status. Measured in seconds since the Unix epoch.
1455 1456 1457 |
# File 'lib/stripe/params/quote_update_params.rb', line 1455 def expires_at @expires_at end |
#footer ⇒ Object
A footer that will be displayed on the quote PDF.
1457 1458 1459 |
# File 'lib/stripe/params/quote_update_params.rb', line 1457 def @footer end |
#header ⇒ Object
A header that will be displayed on the quote PDF.
1459 1460 1461 |
# File 'lib/stripe/params/quote_update_params.rb', line 1459 def header @header end |
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
1461 1462 1463 |
# File 'lib/stripe/params/quote_update_params.rb', line 1461 def invoice_settings @invoice_settings end |
#line_items ⇒ Object
A list of line items the customer is being quoted for. Each line item includes information about the product, the quantity, and the resulting cost.
1463 1464 1465 |
# File 'lib/stripe/params/quote_update_params.rb', line 1463 def line_items @line_items end |
#lines ⇒ Object
A list of quote lines on the quote. These lines describe changes, in the order provided, that will be used to create new subscription schedules or update existing subscription schedules when the quote is accepted.
1465 1466 1467 |
# File 'lib/stripe/params/quote_update_params.rb', line 1465 def lines @lines end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
1467 1468 1469 |
# File 'lib/stripe/params/quote_update_params.rb', line 1467 def @metadata end |
#on_behalf_of ⇒ Object
The account on behalf of which to charge.
1469 1470 1471 |
# File 'lib/stripe/params/quote_update_params.rb', line 1469 def on_behalf_of @on_behalf_of end |
#subscription_data ⇒ Object
When creating a subscription or subscription schedule, the specified configuration data will be used. There must be at least one line item with a recurring price for a subscription or subscription schedule to be created. A subscription schedule is created if subscription_data[effective_date] is present and in the future, otherwise a subscription is created.
1471 1472 1473 |
# File 'lib/stripe/params/quote_update_params.rb', line 1471 def subscription_data @subscription_data end |
#subscription_data_overrides ⇒ Object
List representing overrides for subscription_data configurations for specific subscription schedules.
1473 1474 1475 |
# File 'lib/stripe/params/quote_update_params.rb', line 1473 def subscription_data_overrides @subscription_data_overrides end |
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the invoices.
1475 1476 1477 |
# File 'lib/stripe/params/quote_update_params.rb', line 1475 def transfer_data @transfer_data end |
Class Method Details
.field_encodings ⇒ Object
1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 |
# File 'lib/stripe/params/quote_update_params.rb', line 1525 def self.field_encodings @field_encodings = { line_items: { kind: :array, element: { kind: :object, fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } }, }, }, } end |