Class: Stripe::QuoteUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: AutomaticTax, Discount, InvoiceSettings, LineItem, SubscriptionData, TransferData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(application_fee_amount: nil, application_fee_percent: nil, automatic_tax: nil, collection_method: nil, customer: nil, customer_account: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, expires_at: nil, footer: nil, header: nil, invoice_settings: nil, line_items: nil, metadata: nil, on_behalf_of: nil, subscription_data: nil, transfer_data: nil) ⇒ QuoteUpdateParams

Returns a new instance of QuoteUpdateParams.



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/stripe/params/quote_update_params.rb', line 262

def initialize(
  application_fee_amount: nil,
  application_fee_percent: nil,
  automatic_tax: nil,
  collection_method: nil,
  customer: nil,
  customer_account: nil,
  default_tax_rates: nil,
  description: nil,
  discounts: nil,
  expand: nil,
  expires_at: nil,
  footer: nil,
  header: nil,
  invoice_settings: nil,
  line_items: nil,
  metadata: nil,
  on_behalf_of: nil,
  subscription_data: nil,
  transfer_data: nil
)
  @application_fee_amount = application_fee_amount
  @application_fee_percent = application_fee_percent
  @automatic_tax = automatic_tax
  @collection_method = collection_method
  @customer = customer
  @customer_account = 
  @default_tax_rates = default_tax_rates
  @description = description
  @discounts = discounts
  @expand = expand
  @expires_at = expires_at
  @footer = footer
  @header = header
  @invoice_settings = invoice_settings
  @line_items = line_items
  @metadata = 
  @on_behalf_of = on_behalf_of
  @subscription_data = subscription_data
  @transfer_data = transfer_data
end

Instance Attribute Details

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. There cannot be any line items with recurring prices when using this field.



224
225
226
# File 'lib/stripe/params/quote_update_params.rb', line 224

def application_fee_amount
  @application_fee_amount
end

#application_fee_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner's Stripe account. There must be at least 1 line item with a recurring price to use this field.



226
227
228
# File 'lib/stripe/params/quote_update_params.rb', line 226

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject

Settings for automatic tax lookup for this quote and resulting invoices and subscriptions.



228
229
230
# File 'lib/stripe/params/quote_update_params.rb', line 228

def automatic_tax
  @automatic_tax
end

#collection_methodObject

Either charge_automatically, or send_invoice. When charging automatically, Stripe will attempt to pay invoices at the end of the subscription cycle or at invoice finalization using the default payment method attached to the subscription or customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as active. Defaults to charge_automatically.



230
231
232
# File 'lib/stripe/params/quote_update_params.rb', line 230

def collection_method
  @collection_method
end

#customerObject

The customer for which this quote belongs to. A customer is required before finalizing the quote. Once specified, it cannot be changed.



232
233
234
# File 'lib/stripe/params/quote_update_params.rb', line 232

def customer
  @customer
end

#customer_accountObject

The account for which this quote belongs to. A customer or account is required before finalizing the quote. Once specified, it cannot be changed.



234
235
236
# File 'lib/stripe/params/quote_update_params.rb', line 234

def 
  @customer_account
end

#default_tax_ratesObject

The tax rates that will apply to any line item that does not have tax_rates set.



236
237
238
# File 'lib/stripe/params/quote_update_params.rb', line 236

def default_tax_rates
  @default_tax_rates
end

#descriptionObject

A description that will be displayed on the quote PDF.



238
239
240
# File 'lib/stripe/params/quote_update_params.rb', line 238

def description
  @description
end

#discountsObject

The discounts applied to the quote.



240
241
242
# File 'lib/stripe/params/quote_update_params.rb', line 240

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



242
243
244
# File 'lib/stripe/params/quote_update_params.rb', line 242

def expand
  @expand
end

#expires_atObject

A future timestamp on which the quote will be canceled if in open or draft status. Measured in seconds since the Unix epoch.



244
245
246
# File 'lib/stripe/params/quote_update_params.rb', line 244

def expires_at
  @expires_at
end

A footer that will be displayed on the quote PDF.



246
247
248
# File 'lib/stripe/params/quote_update_params.rb', line 246

def footer
  @footer
end

#headerObject

A header that will be displayed on the quote PDF.



248
249
250
# File 'lib/stripe/params/quote_update_params.rb', line 248

def header
  @header
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



250
251
252
# File 'lib/stripe/params/quote_update_params.rb', line 250

def invoice_settings
  @invoice_settings
end

#line_itemsObject

A list of line items the customer is being quoted for. Each line item includes information about the product, the quantity, and the resulting cost.



252
253
254
# File 'lib/stripe/params/quote_update_params.rb', line 252

def line_items
  @line_items
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



254
255
256
# File 'lib/stripe/params/quote_update_params.rb', line 254

def 
  @metadata
end

#on_behalf_ofObject

The account on behalf of which to charge.



256
257
258
# File 'lib/stripe/params/quote_update_params.rb', line 256

def on_behalf_of
  @on_behalf_of
end

#subscription_dataObject

When creating a subscription or subscription schedule, the specified configuration data will be used. There must be at least one line item with a recurring price for a subscription or subscription schedule to be created. A subscription schedule is created if subscription_data[effective_date] is present and in the future, otherwise a subscription is created.



258
259
260
# File 'lib/stripe/params/quote_update_params.rb', line 258

def subscription_data
  @subscription_data
end

#transfer_dataObject

The data with which to automatically create a Transfer for each of the invoices.



260
261
262
# File 'lib/stripe/params/quote_update_params.rb', line 260

def transfer_data
  @transfer_data
end

Class Method Details

.field_encodingsObject



304
305
306
307
308
309
310
311
312
313
314
# File 'lib/stripe/params/quote_update_params.rb', line 304

def self.field_encodings
  @field_encodings = {
    line_items: {
      kind: :array,
      element: {
        kind: :object,
        fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } },
      },
    },
  }
end