Class: Stripe::QuoteUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: AutomaticTax, Discount, InvoiceSettings, Line, LineItem, SubscriptionData, SubscriptionDataOverride, TransferData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(allow_backdated_lines: nil, application_fee_amount: nil, application_fee_percent: nil, automatic_tax: nil, collection_method: nil, customer: nil, customer_account: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, expires_at: nil, footer: nil, header: nil, invoice_settings: nil, line_items: nil, lines: nil, metadata: nil, on_behalf_of: nil, subscription_data: nil, subscription_data_overrides: nil, transfer_data: nil) ⇒ QuoteUpdateParams

Returns a new instance of QuoteUpdateParams.



1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
# File 'lib/stripe/params/quote_update_params.rb', line 1042

def initialize(
  allow_backdated_lines: nil,
  application_fee_amount: nil,
  application_fee_percent: nil,
  automatic_tax: nil,
  collection_method: nil,
  customer: nil,
  customer_account: nil,
  default_tax_rates: nil,
  description: nil,
  discounts: nil,
  expand: nil,
  expires_at: nil,
  footer: nil,
  header: nil,
  invoice_settings: nil,
  line_items: nil,
  lines: nil,
  metadata: nil,
  on_behalf_of: nil,
  subscription_data: nil,
  subscription_data_overrides: nil,
  transfer_data: nil
)
  @allow_backdated_lines = allow_backdated_lines
  @application_fee_amount = application_fee_amount
  @application_fee_percent = application_fee_percent
  @automatic_tax = automatic_tax
  @collection_method = collection_method
  @customer = customer
  @customer_account = 
  @default_tax_rates = default_tax_rates
  @description = description
  @discounts = discounts
  @expand = expand
  @expires_at = expires_at
  @footer = footer
  @header = header
  @invoice_settings = invoice_settings
  @line_items = line_items
  @lines = lines
  @metadata = 
  @on_behalf_of = on_behalf_of
  @subscription_data = subscription_data
  @subscription_data_overrides = subscription_data_overrides
  @transfer_data = transfer_data
end

Instance Attribute Details

#allow_backdated_linesObject

Set to true to allow quote lines to have ‘starts_at` in the past if collection is paused between `starts_at` and now.



998
999
1000
# File 'lib/stripe/params/quote_update_params.rb', line 998

def allow_backdated_lines
  @allow_backdated_lines
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. There cannot be any line items with recurring prices when using this field.



1000
1001
1002
# File 'lib/stripe/params/quote_update_params.rb', line 1000

def application_fee_amount
  @application_fee_amount
end

#application_fee_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. There must be at least 1 line item with a recurring price to use this field.



1002
1003
1004
# File 'lib/stripe/params/quote_update_params.rb', line 1002

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject

Settings for automatic tax lookup for this quote and resulting invoices and subscriptions.



1004
1005
1006
# File 'lib/stripe/params/quote_update_params.rb', line 1004

def automatic_tax
  @automatic_tax
end

#collection_methodObject

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay invoices at the end of the subscription cycle or at invoice finalization using the default payment method attached to the subscription or customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically`.



1006
1007
1008
# File 'lib/stripe/params/quote_update_params.rb', line 1006

def collection_method
  @collection_method
end

#customerObject

The customer for which this quote belongs to. A customer is required before finalizing the quote. Once specified, it cannot be changed.



1008
1009
1010
# File 'lib/stripe/params/quote_update_params.rb', line 1008

def customer
  @customer
end

#customer_accountObject

The account for which this quote belongs to. A customer or account is required before finalizing the quote. Once specified, it cannot be changed.



1010
1011
1012
# File 'lib/stripe/params/quote_update_params.rb', line 1010

def 
  @customer_account
end

#default_tax_ratesObject

The tax rates that will apply to any line item that does not have ‘tax_rates` set.



1012
1013
1014
# File 'lib/stripe/params/quote_update_params.rb', line 1012

def default_tax_rates
  @default_tax_rates
end

#descriptionObject

A description that will be displayed on the quote PDF.



1014
1015
1016
# File 'lib/stripe/params/quote_update_params.rb', line 1014

def description
  @description
end

#discountsObject

The discounts applied to the quote.



1016
1017
1018
# File 'lib/stripe/params/quote_update_params.rb', line 1016

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



1018
1019
1020
# File 'lib/stripe/params/quote_update_params.rb', line 1018

def expand
  @expand
end

#expires_atObject

A future timestamp on which the quote will be canceled if in ‘open` or `draft` status. Measured in seconds since the Unix epoch.



1020
1021
1022
# File 'lib/stripe/params/quote_update_params.rb', line 1020

def expires_at
  @expires_at
end

A footer that will be displayed on the quote PDF.



1022
1023
1024
# File 'lib/stripe/params/quote_update_params.rb', line 1022

def footer
  @footer
end

#headerObject

A header that will be displayed on the quote PDF.



1024
1025
1026
# File 'lib/stripe/params/quote_update_params.rb', line 1024

def header
  @header
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



1026
1027
1028
# File 'lib/stripe/params/quote_update_params.rb', line 1026

def invoice_settings
  @invoice_settings
end

#line_itemsObject

A list of line items the customer is being quoted for. Each line item includes information about the product, the quantity, and the resulting cost.



1028
1029
1030
# File 'lib/stripe/params/quote_update_params.rb', line 1028

def line_items
  @line_items
end

#linesObject

A list of [quote lines](docs.stripe.com/api/quote_lines) on the quote. These lines describe changes, in the order provided, that will be used to create new subscription schedules or update existing subscription schedules when the quote is accepted.



1030
1031
1032
# File 'lib/stripe/params/quote_update_params.rb', line 1030

def lines
  @lines
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1032
1033
1034
# File 'lib/stripe/params/quote_update_params.rb', line 1032

def 
  @metadata
end

#on_behalf_ofObject

The account on behalf of which to charge.



1034
1035
1036
# File 'lib/stripe/params/quote_update_params.rb', line 1034

def on_behalf_of
  @on_behalf_of
end

#subscription_dataObject

When creating a subscription or subscription schedule, the specified configuration data will be used. There must be at least one line item with a recurring price for a subscription or subscription schedule to be created. A subscription schedule is created if ‘subscription_data` is present and in the future, otherwise a subscription is created.



1036
1037
1038
# File 'lib/stripe/params/quote_update_params.rb', line 1036

def subscription_data
  @subscription_data
end

#subscription_data_overridesObject

List representing overrides for ‘subscription_data` configurations for specific subscription schedules.



1038
1039
1040
# File 'lib/stripe/params/quote_update_params.rb', line 1038

def subscription_data_overrides
  @subscription_data_overrides
end

#transfer_dataObject

The data with which to automatically create a Transfer for each of the invoices.



1040
1041
1042
# File 'lib/stripe/params/quote_update_params.rb', line 1040

def transfer_data
  @transfer_data
end

Class Method Details

.field_encodingsObject



1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
# File 'lib/stripe/params/quote_update_params.rb', line 1090

def self.field_encodings
  @field_encodings = {
    line_items: {
      kind: :array,
      element: {
        kind: :object,
        fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } },
      },
    },
  }
end