Class: Stripe::QuoteUpdateParams::InvoiceSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::InvoiceSettings
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Classes: CustomField, Issuer
Instance Attribute Summary collapse
-
#custom_fields ⇒ Object
A list of up to 4 custom fields to be displayed on the invoice.
-
#days_until_due ⇒ Object
Number of days within which a customer must pay the invoice generated by this quote.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#footer ⇒ Object
Footer to be displayed on the invoice.
-
#issuer ⇒ Object
The connected account that issues the invoice.
Instance Method Summary collapse
-
#initialize(custom_fields: nil, days_until_due: nil, description: nil, footer: nil, issuer: nil) ⇒ InvoiceSettings
constructor
A new instance of InvoiceSettings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(custom_fields: nil, days_until_due: nil, description: nil, footer: nil, issuer: nil) ⇒ InvoiceSettings
Returns a new instance of InvoiceSettings.
79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/stripe/params/quote_update_params.rb', line 79 def initialize( custom_fields: nil, days_until_due: nil, description: nil, footer: nil, issuer: nil ) @custom_fields = custom_fields @days_until_due = days_until_due @description = description @footer = @issuer = issuer end |
Instance Attribute Details
#custom_fields ⇒ Object
A list of up to 4 custom fields to be displayed on the invoice.
69 70 71 |
# File 'lib/stripe/params/quote_update_params.rb', line 69 def custom_fields @custom_fields end |
#days_until_due ⇒ Object
Number of days within which a customer must pay the invoice generated by this quote. This value will be null for quotes where collection_method=charge_automatically.
71 72 73 |
# File 'lib/stripe/params/quote_update_params.rb', line 71 def days_until_due @days_until_due end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
73 74 75 |
# File 'lib/stripe/params/quote_update_params.rb', line 73 def description @description end |
#footer ⇒ Object
Footer to be displayed on the invoice.
75 76 77 |
# File 'lib/stripe/params/quote_update_params.rb', line 75 def @footer end |
#issuer ⇒ Object
The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
77 78 79 |
# File 'lib/stripe/params/quote_update_params.rb', line 77 def issuer @issuer end |