Class: Stripe::QuoteUpdateParams::InvoiceSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: CustomField, Issuer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(custom_fields: nil, days_until_due: nil, description: nil, footer: nil, issuer: nil) ⇒ InvoiceSettings

Returns a new instance of InvoiceSettings.



107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/stripe/params/quote_update_params.rb', line 107

def initialize(
  custom_fields: nil,
  days_until_due: nil,
  description: nil,
  footer: nil,
  issuer: nil
)
  @custom_fields = custom_fields
  @days_until_due = days_until_due
  @description = description
  @footer = footer
  @issuer = issuer
end

Instance Attribute Details

#custom_fieldsObject

A list of up to 4 custom fields to be displayed on the invoice.



97
98
99
# File 'lib/stripe/params/quote_update_params.rb', line 97

def custom_fields
  @custom_fields
end

#days_until_dueObject

Number of days within which a customer must pay the invoice generated by this quote. This value will be null for quotes where collection_method=charge_automatically.



99
100
101
# File 'lib/stripe/params/quote_update_params.rb', line 99

def days_until_due
  @days_until_due
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



101
102
103
# File 'lib/stripe/params/quote_update_params.rb', line 101

def description
  @description
end

Footer to be displayed on the invoice.



103
104
105
# File 'lib/stripe/params/quote_update_params.rb', line 103

def footer
  @footer
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



105
106
107
# File 'lib/stripe/params/quote_update_params.rb', line 105

def issuer
  @issuer
end