Class: Stripe::QuoteUpdateParams::Line
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::Line
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Classes: Action, AppliesTo, CancelSubscriptionSchedule, EndsAt, SetPauseCollection, StartsAt, TrialSettings
Instance Attribute Summary collapse
-
#actions ⇒ Object
An array of operations the quote line performs.
-
#applies_to ⇒ Object
Details to identify the subscription schedule the quote line applies to.
-
#billing_cycle_anchor ⇒ Object
For point-in-time quote lines (having no ‘ends_at` timestamp), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the Quote Line ‘starts_at` timestamp.For time-span based quote lines (having both `starts_at` and `ends_at`), the only valid value is `automatic`, which removes any previously configured billing cycle anchor resets during the window of time spanning the quote line.
-
#cancel_subscription_schedule ⇒ Object
A point-in-time operation that cancels an existing subscription schedule at the line’s starts_at timestamp.
-
#effective_at ⇒ Object
Configures how the quote handles billing for line transitions.
-
#ends_at ⇒ Object
Details to identify the end of the time range modified by the proposed change.
-
#id ⇒ Object
The ID of an existing line on the quote.
-
#proration_behavior ⇒ Object
Changes to how Stripe handles prorations during the quote line’s time span.
-
#set_pause_collection ⇒ Object
Defines how to pause collection for the underlying subscription throughout the duration of the amendment.
-
#set_schedule_end ⇒ Object
Timestamp helper to end the underlying schedule early, based on the acompanying line’s start or end date.
-
#starts_at ⇒ Object
Details to identify the earliest timestamp where the proposed change should take effect.
-
#trial_settings ⇒ Object
Settings related to subscription trials.
Instance Method Summary collapse
-
#initialize(actions: nil, applies_to: nil, billing_cycle_anchor: nil, cancel_subscription_schedule: nil, effective_at: nil, ends_at: nil, id: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, starts_at: nil, trial_settings: nil) ⇒ Line
constructor
A new instance of Line.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(actions: nil, applies_to: nil, billing_cycle_anchor: nil, cancel_subscription_schedule: nil, effective_at: nil, ends_at: nil, id: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, starts_at: nil, trial_settings: nil) ⇒ Line
Returns a new instance of Line.
757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 |
# File 'lib/stripe/params/quote_update_params.rb', line 757 def initialize( actions: nil, applies_to: nil, billing_cycle_anchor: nil, cancel_subscription_schedule: nil, effective_at: nil, ends_at: nil, id: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, starts_at: nil, trial_settings: nil ) @actions = actions @applies_to = applies_to @billing_cycle_anchor = billing_cycle_anchor @cancel_subscription_schedule = cancel_subscription_schedule @effective_at = effective_at @ends_at = ends_at @id = id @proration_behavior = proration_behavior @set_pause_collection = set_pause_collection @set_schedule_end = set_schedule_end @starts_at = starts_at @trial_settings = trial_settings end |
Instance Attribute Details
#actions ⇒ Object
An array of operations the quote line performs.
733 734 735 |
# File 'lib/stripe/params/quote_update_params.rb', line 733 def actions @actions end |
#applies_to ⇒ Object
Details to identify the subscription schedule the quote line applies to.
735 736 737 |
# File 'lib/stripe/params/quote_update_params.rb', line 735 def applies_to @applies_to end |
#billing_cycle_anchor ⇒ Object
For point-in-time quote lines (having no ‘ends_at` timestamp), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the Quote Line ‘starts_at` timestamp.For time-span based quote lines (having both `starts_at` and `ends_at`), the only valid value is `automatic`, which removes any previously configured billing cycle anchor resets during the window of time spanning the quote line.
737 738 739 |
# File 'lib/stripe/params/quote_update_params.rb', line 737 def billing_cycle_anchor @billing_cycle_anchor end |
#cancel_subscription_schedule ⇒ Object
A point-in-time operation that cancels an existing subscription schedule at the line’s starts_at timestamp. Currently only compatible with ‘quote_acceptance_date` for `starts_at`. When using cancel_subscription_schedule, the subscription schedule on the quote remains unalterable, except for modifications to the metadata, collection_method or invoice_settings.
739 740 741 |
# File 'lib/stripe/params/quote_update_params.rb', line 739 def cancel_subscription_schedule @cancel_subscription_schedule end |
#effective_at ⇒ Object
Configures how the quote handles billing for line transitions.
741 742 743 |
# File 'lib/stripe/params/quote_update_params.rb', line 741 def effective_at @effective_at end |
#ends_at ⇒ Object
Details to identify the end of the time range modified by the proposed change. If not supplied, the quote line is considered a point-in-time operation that only affects the exact timestamp at ‘starts_at`, and a restricted set of attributes is supported on the quote line.
743 744 745 |
# File 'lib/stripe/params/quote_update_params.rb', line 743 def ends_at @ends_at end |
#id ⇒ Object
The ID of an existing line on the quote.
745 746 747 |
# File 'lib/stripe/params/quote_update_params.rb', line 745 def id @id end |
#proration_behavior ⇒ Object
Changes to how Stripe handles prorations during the quote line’s time span. Affects if and how prorations are created when a future phase starts.
747 748 749 |
# File 'lib/stripe/params/quote_update_params.rb', line 747 def proration_behavior @proration_behavior end |
#set_pause_collection ⇒ Object
Defines how to pause collection for the underlying subscription throughout the duration of the amendment.
749 750 751 |
# File 'lib/stripe/params/quote_update_params.rb', line 749 def set_pause_collection @set_pause_collection end |
#set_schedule_end ⇒ Object
Timestamp helper to end the underlying schedule early, based on the acompanying line’s start or end date.
751 752 753 |
# File 'lib/stripe/params/quote_update_params.rb', line 751 def set_schedule_end @set_schedule_end end |
#starts_at ⇒ Object
Details to identify the earliest timestamp where the proposed change should take effect.
753 754 755 |
# File 'lib/stripe/params/quote_update_params.rb', line 753 def starts_at @starts_at end |
#trial_settings ⇒ Object
Settings related to subscription trials.
755 756 757 |
# File 'lib/stripe/params/quote_update_params.rb', line 755 def trial_settings @trial_settings end |