Class: Stripe::QuoteUpdateParams::Line

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: Action, AppliesTo, CancelSubscriptionSchedule, EndsAt, SetPauseCollection, StartsAt, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(actions: nil, applies_to: nil, billing_cycle_anchor: nil, cancel_subscription_schedule: nil, effective_at: nil, ends_at: nil, id: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, starts_at: nil, trial_settings: nil) ⇒ Line

Returns a new instance of Line.



561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
# File 'lib/stripe/params/quote_update_params.rb', line 561

def initialize(
  actions: nil,
  applies_to: nil,
  billing_cycle_anchor: nil,
  cancel_subscription_schedule: nil,
  effective_at: nil,
  ends_at: nil,
  id: nil,
  proration_behavior: nil,
  set_pause_collection: nil,
  set_schedule_end: nil,
  starts_at: nil,
  trial_settings: nil
)
  @actions = actions
  @applies_to = applies_to
  @billing_cycle_anchor = billing_cycle_anchor
  @cancel_subscription_schedule = cancel_subscription_schedule
  @effective_at = effective_at
  @ends_at = ends_at
  @id = id
  @proration_behavior = proration_behavior
  @set_pause_collection = set_pause_collection
  @set_schedule_end = set_schedule_end
  @starts_at = starts_at
  @trial_settings = trial_settings
end

Instance Attribute Details

#actionsObject

An array of operations the quote line performs.



537
538
539
# File 'lib/stripe/params/quote_update_params.rb', line 537

def actions
  @actions
end

#applies_toObject

Details to identify the subscription schedule the quote line applies to.



539
540
541
# File 'lib/stripe/params/quote_update_params.rb', line 539

def applies_to
  @applies_to
end

#billing_cycle_anchorObject

For point-in-time quote lines (having no ‘ends_at` timestamp), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the Quote Line ‘starts_at` timestamp.For time-span based quote lines (having both `starts_at` and `ends_at`), the only valid value is `automatic`, which removes any previously configured billing cycle anchor resets during the window of time spanning the quote line.



541
542
543
# File 'lib/stripe/params/quote_update_params.rb', line 541

def billing_cycle_anchor
  @billing_cycle_anchor
end

#cancel_subscription_scheduleObject

A point-in-time operation that cancels an existing subscription schedule at the line’s starts_at timestamp. Currently only compatible with ‘quote_acceptance_date` for `starts_at`. When using cancel_subscription_schedule, the subscription schedule on the quote remains unalterable, except for modifications to the metadata, collection_method or invoice_settings.



543
544
545
# File 'lib/stripe/params/quote_update_params.rb', line 543

def cancel_subscription_schedule
  @cancel_subscription_schedule
end

#effective_atObject

Configures how the quote handles billing for line transitions.



545
546
547
# File 'lib/stripe/params/quote_update_params.rb', line 545

def effective_at
  @effective_at
end

#ends_atObject

Details to identify the end of the time range modified by the proposed change. If not supplied, the quote line is considered a point-in-time operation that only affects the exact timestamp at ‘starts_at`, and a restricted set of attributes is supported on the quote line.



547
548
549
# File 'lib/stripe/params/quote_update_params.rb', line 547

def ends_at
  @ends_at
end

#idObject

The ID of an existing line on the quote.



549
550
551
# File 'lib/stripe/params/quote_update_params.rb', line 549

def id
  @id
end

#proration_behaviorObject

Changes to how Stripe handles prorations during the quote line’s time span. Affects if and how prorations are created when a future phase starts.



551
552
553
# File 'lib/stripe/params/quote_update_params.rb', line 551

def proration_behavior
  @proration_behavior
end

#set_pause_collectionObject

Defines how to pause collection for the underlying subscription throughout the duration of the amendment.



553
554
555
# File 'lib/stripe/params/quote_update_params.rb', line 553

def set_pause_collection
  @set_pause_collection
end

#set_schedule_endObject

Timestamp helper to end the underlying schedule early, based on the acompanying line’s start or end date.



555
556
557
# File 'lib/stripe/params/quote_update_params.rb', line 555

def set_schedule_end
  @set_schedule_end
end

#starts_atObject

Details to identify the earliest timestamp where the proposed change should take effect.



557
558
559
# File 'lib/stripe/params/quote_update_params.rb', line 557

def starts_at
  @starts_at
end

#trial_settingsObject

Settings related to subscription trials.



559
560
561
# File 'lib/stripe/params/quote_update_params.rb', line 559

def trial_settings
  @trial_settings
end