Class: Stripe::QuoteUpdateParams::Line::Action::AddDiscount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::Line::Action::AddDiscount
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Classes: DiscountEnd, Settings
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
-
#settings ⇒ Object
Settings for discount application including service period anchoring.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil, settings: nil) ⇒ AddDiscount
constructor
A new instance of AddDiscount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil, settings: nil) ⇒ AddDiscount
Returns a new instance of AddDiscount.
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/stripe/params/quote_update_params.rb', line 189 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil, settings: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code @settings = settings end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
177 178 179 |
# File 'lib/stripe/params/quote_update_params.rb', line 177 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
179 180 181 |
# File 'lib/stripe/params/quote_update_params.rb', line 179 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
181 182 183 |
# File 'lib/stripe/params/quote_update_params.rb', line 181 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the discounts array.
183 184 185 |
# File 'lib/stripe/params/quote_update_params.rb', line 183 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
185 186 187 |
# File 'lib/stripe/params/quote_update_params.rb', line 185 def promotion_code @promotion_code end |
#settings ⇒ Object
Settings for discount application including service period anchoring.
187 188 189 |
# File 'lib/stripe/params/quote_update_params.rb', line 187 def settings @settings end |