Class: Stripe::QuoteUpdateParams::Line::Action::AddDiscount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::Line::Action::AddDiscount
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ AddDiscount
constructor
A new instance of AddDiscount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ AddDiscount
Returns a new instance of AddDiscount.
117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/stripe/params/quote_update_params.rb', line 117 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
107 108 109 |
# File 'lib/stripe/params/quote_update_params.rb', line 107 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
109 110 111 |
# File 'lib/stripe/params/quote_update_params.rb', line 109 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
111 112 113 |
# File 'lib/stripe/params/quote_update_params.rb', line 111 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
113 114 115 |
# File 'lib/stripe/params/quote_update_params.rb', line 113 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
115 116 117 |
# File 'lib/stripe/params/quote_update_params.rb', line 115 def promotion_code @promotion_code end |