Class: Stripe::QuoteUpdateParams::Line::Action::AddDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: DiscountEnd, Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil, settings: nil) ⇒ AddDiscount

Returns a new instance of AddDiscount.



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/stripe/params/quote_update_params.rb', line 162

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil,
  settings: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
  @settings = settings
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



150
151
152
# File 'lib/stripe/params/quote_update_params.rb', line 150

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



152
153
154
# File 'lib/stripe/params/quote_update_params.rb', line 152

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



154
155
156
# File 'lib/stripe/params/quote_update_params.rb', line 154

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



156
157
158
# File 'lib/stripe/params/quote_update_params.rb', line 156

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



158
159
160
# File 'lib/stripe/params/quote_update_params.rb', line 158

def promotion_code
  @promotion_code
end

#settingsObject

Settings for discount application including service period anchoring.



160
161
162
# File 'lib/stripe/params/quote_update_params.rb', line 160

def settings
  @settings
end