Class: Stripe::QuoteUpdateParams::Line::Action::AddDiscount::Settings::ServicePeriodAnchorConfig::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::Line::Action::AddDiscount::Settings::ServicePeriodAnchorConfig::Custom
- Defined in:
- lib/stripe/params/quote_update_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
Returns a new instance of Custom.
121 122 123 124 125 126 127 |
# File 'lib/stripe/params/quote_update_params.rb', line 121 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
111 112 113 |
# File 'lib/stripe/params/quote_update_params.rb', line 111 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
113 114 115 |
# File 'lib/stripe/params/quote_update_params.rb', line 113 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
115 116 117 |
# File 'lib/stripe/params/quote_update_params.rb', line 115 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
117 118 119 |
# File 'lib/stripe/params/quote_update_params.rb', line 117 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
119 120 121 |
# File 'lib/stripe/params/quote_update_params.rb', line 119 def second @second end |