Class: Stripe::QuoteUpdateParams::Line::Action::AddItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::Line::Action::AddItem
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to the item.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates that apply to this subscription item.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
-
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ AddItem
constructor
A new instance of AddItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ AddItem
Returns a new instance of AddItem.
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/stripe/params/quote_update_params.rb', line 301 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial @trial_offer = trial_offer end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to the item. Subscription item discounts are applied before subscription discounts.
287 288 289 |
# File 'lib/stripe/params/quote_update_params.rb', line 287 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
289 290 291 |
# File 'lib/stripe/params/quote_update_params.rb', line 289 def @metadata end |
#price ⇒ Object
The ID of the price object.
291 292 293 |
# File 'lib/stripe/params/quote_update_params.rb', line 291 def price @price end |
#quantity ⇒ Object
Quantity for this item.
293 294 295 |
# File 'lib/stripe/params/quote_update_params.rb', line 293 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.
295 296 297 |
# File 'lib/stripe/params/quote_update_params.rb', line 295 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
297 298 299 |
# File 'lib/stripe/params/quote_update_params.rb', line 297 def trial @trial end |
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
299 300 301 |
# File 'lib/stripe/params/quote_update_params.rb', line 299 def trial_offer @trial_offer end |