Class: Stripe::QuoteUpdateParams::Line::Action::RemoveDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ RemoveDiscount

Returns a new instance of RemoveDiscount.



229
230
231
232
233
# File 'lib/stripe/params/quote_update_params.rb', line 229

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



223
224
225
# File 'lib/stripe/params/quote_update_params.rb', line 223

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



225
226
227
# File 'lib/stripe/params/quote_update_params.rb', line 225

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



227
228
229
# File 'lib/stripe/params/quote_update_params.rb', line 227

def promotion_code
  @promotion_code
end