Class: Stripe::QuoteUpdateParams::Line::Action::RemoveDiscount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::Line::Action::RemoveDiscount
- Defined in:
- lib/stripe/params/quote_update_params.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to remove from the ‘discounts` array.
-
#discount ⇒ Object
The ID of a discount to remove from the ‘discounts` array.
-
#promotion_code ⇒ Object
The ID of a promotion code to remove from the ‘discounts` array.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ RemoveDiscount
constructor
A new instance of RemoveDiscount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ RemoveDiscount
Returns a new instance of RemoveDiscount.
229 230 231 232 233 |
# File 'lib/stripe/params/quote_update_params.rb', line 229 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to remove from the ‘discounts` array.
223 224 225 |
# File 'lib/stripe/params/quote_update_params.rb', line 223 def coupon @coupon end |
#discount ⇒ Object
The ID of a discount to remove from the ‘discounts` array.
225 226 227 |
# File 'lib/stripe/params/quote_update_params.rb', line 225 def discount @discount end |
#promotion_code ⇒ Object
The ID of a promotion code to remove from the ‘discounts` array.
227 228 229 |
# File 'lib/stripe/params/quote_update_params.rb', line 227 def promotion_code @promotion_code end |