Class: Stripe::QuoteUpdateParams::Line::Action::RemoveDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ RemoveDiscount

Returns a new instance of RemoveDiscount.



328
329
330
331
332
# File 'lib/stripe/params/quote_update_params.rb', line 328

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



322
323
324
# File 'lib/stripe/params/quote_update_params.rb', line 322

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



324
325
326
# File 'lib/stripe/params/quote_update_params.rb', line 324

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



326
327
328
# File 'lib/stripe/params/quote_update_params.rb', line 326

def promotion_code
  @promotion_code
end