Class: Stripe::QuoteUpdateParams::Line::Action::SetDiscount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::Line::Action::SetDiscount
- Defined in:
- lib/stripe/params/quote_update_params.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to replace the
discountsarray with. -
#discount ⇒ Object
An ID of an existing discount to replace the
discountsarray with. -
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the
discountsarray with.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount
constructor
A new instance of SetDiscount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount
Returns a new instance of SetDiscount.
280 281 282 283 284 |
# File 'lib/stripe/params/quote_update_params.rb', line 280 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to replace the discounts array with.
274 275 276 |
# File 'lib/stripe/params/quote_update_params.rb', line 274 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount to replace the discounts array with.
276 277 278 |
# File 'lib/stripe/params/quote_update_params.rb', line 276 def discount @discount end |
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the discounts array with.
278 279 280 |
# File 'lib/stripe/params/quote_update_params.rb', line 278 def promotion_code @promotion_code end |