Class: Stripe::QuoteUpdateParams::Line::Action::SetDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ SetDiscount

Returns a new instance of SetDiscount.



253
254
255
256
257
# File 'lib/stripe/params/quote_update_params.rb', line 253

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



247
248
249
# File 'lib/stripe/params/quote_update_params.rb', line 247

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



249
250
251
# File 'lib/stripe/params/quote_update_params.rb', line 249

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



251
252
253
# File 'lib/stripe/params/quote_update_params.rb', line 251

def promotion_code
  @promotion_code
end