Class: Stripe::QuoteUpdateParams::Line::Action::SetDiscount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil, settings: nil) ⇒ SetDiscount

Returns a new instance of SetDiscount.



396
397
398
399
400
401
# File 'lib/stripe/params/quote_update_params.rb', line 396

def initialize(coupon: nil, discount: nil, promotion_code: nil, settings: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
  @settings = settings
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



388
389
390
# File 'lib/stripe/params/quote_update_params.rb', line 388

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



390
391
392
# File 'lib/stripe/params/quote_update_params.rb', line 390

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



392
393
394
# File 'lib/stripe/params/quote_update_params.rb', line 392

def promotion_code
  @promotion_code
end

#settingsObject

Settings for discount application including service period anchoring.



394
395
396
# File 'lib/stripe/params/quote_update_params.rb', line 394

def settings
  @settings
end