Class: Stripe::QuoteUpdateParams::Line::Action::SetItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::Line::Action::SetItem
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
If an item with the
pricealready exists, passing this will override thediscountsarray on the subscription item that matches that price. -
#metadata ⇒ Object
If an item with the
pricealready exists, passing this will override themetadataon the subscription item that matches that price. -
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
If an item with the
pricealready exists, passing this will override the quantity on the subscription item that matches that price. -
#tax_rates ⇒ Object
If an item with the
pricealready exists, passing this will override thetax_ratesarray on the subscription item that matches that price. -
#trial ⇒ Object
If an item with the
pricealready exists, passing this will override thetrialconfiguration on the subscription item that matches that price. -
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ SetItem
constructor
A new instance of SetItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ SetItem
Returns a new instance of SetItem.
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 |
# File 'lib/stripe/params/quote_update_params.rb', line 553 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial @trial_offer = trial_offer end |
Instance Attribute Details
#discounts ⇒ Object
If an item with the price already exists, passing this will override the discounts array on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied discounts.
539 540 541 |
# File 'lib/stripe/params/quote_update_params.rb', line 539 def discounts @discounts end |
#metadata ⇒ Object
If an item with the price already exists, passing this will override the metadata on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied metadata.
541 542 543 |
# File 'lib/stripe/params/quote_update_params.rb', line 541 def @metadata end |
#price ⇒ Object
The ID of the price object.
543 544 545 |
# File 'lib/stripe/params/quote_update_params.rb', line 543 def price @price end |
#quantity ⇒ Object
If an item with the price already exists, passing this will override the quantity on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied quantity.
545 546 547 |
# File 'lib/stripe/params/quote_update_params.rb', line 545 def quantity @quantity end |
#tax_rates ⇒ Object
If an item with the price already exists, passing this will override the tax_rates array on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied tax_rates.
547 548 549 |
# File 'lib/stripe/params/quote_update_params.rb', line 547 def tax_rates @tax_rates end |
#trial ⇒ Object
If an item with the price already exists, passing this will override the trial configuration on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied trial.
549 550 551 |
# File 'lib/stripe/params/quote_update_params.rb', line 549 def trial @trial end |
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
551 552 553 |
# File 'lib/stripe/params/quote_update_params.rb', line 551 def trial_offer @trial_offer end |