Class: Stripe::QuoteUpdateParams::Line::Action::SetItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::Line::Action::SetItem
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
If an item with the ‘price` already exists, passing this will override the `discounts` array on the subscription item that matches that price.
-
#metadata ⇒ Object
If an item with the ‘price` already exists, passing this will override the `metadata` on the subscription item that matches that price.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
If an item with the ‘price` already exists, passing this will override the quantity on the subscription item that matches that price.
-
#tax_rates ⇒ Object
If an item with the ‘price` already exists, passing this will override the `tax_rates` array on the subscription item that matches that price.
-
#trial ⇒ Object
If an item with the ‘price` already exists, passing this will override the `trial` configuration on the subscription item that matches that price.
-
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ SetItem
constructor
A new instance of SetItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ SetItem
Returns a new instance of SetItem.
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/stripe/params/quote_update_params.rb', line 330 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial @trial_offer = trial_offer end |
Instance Attribute Details
#discounts ⇒ Object
If an item with the ‘price` already exists, passing this will override the `discounts` array on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `discounts`.
316 317 318 |
# File 'lib/stripe/params/quote_update_params.rb', line 316 def discounts @discounts end |
#metadata ⇒ Object
If an item with the ‘price` already exists, passing this will override the `metadata` on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `metadata`.
318 319 320 |
# File 'lib/stripe/params/quote_update_params.rb', line 318 def @metadata end |
#price ⇒ Object
The ID of the price object.
320 321 322 |
# File 'lib/stripe/params/quote_update_params.rb', line 320 def price @price end |
#quantity ⇒ Object
If an item with the ‘price` already exists, passing this will override the quantity on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `quantity`.
322 323 324 |
# File 'lib/stripe/params/quote_update_params.rb', line 322 def quantity @quantity end |
#tax_rates ⇒ Object
If an item with the ‘price` already exists, passing this will override the `tax_rates` array on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `tax_rates`.
324 325 326 |
# File 'lib/stripe/params/quote_update_params.rb', line 324 def tax_rates @tax_rates end |
#trial ⇒ Object
If an item with the ‘price` already exists, passing this will override the `trial` configuration on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `trial`.
326 327 328 |
# File 'lib/stripe/params/quote_update_params.rb', line 326 def trial @trial end |
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
328 329 330 |
# File 'lib/stripe/params/quote_update_params.rb', line 328 def trial_offer @trial_offer end |