Class: Stripe::QuoteUpdateParams::Line::Action::SetItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ SetItem

Returns a new instance of SetItem.



526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
# File 'lib/stripe/params/quote_update_params.rb', line 526

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil,
  trial_offer: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
  @trial_offer = trial_offer
end

Instance Attribute Details

#discountsObject

If an item with the ‘price` already exists, passing this will override the `discounts` array on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `discounts`.



512
513
514
# File 'lib/stripe/params/quote_update_params.rb', line 512

def discounts
  @discounts
end

#metadataObject

If an item with the ‘price` already exists, passing this will override the `metadata` on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `metadata`.



514
515
516
# File 'lib/stripe/params/quote_update_params.rb', line 514

def 
  @metadata
end

#priceObject

The ID of the price object.



516
517
518
# File 'lib/stripe/params/quote_update_params.rb', line 516

def price
  @price
end

#quantityObject

If an item with the ‘price` already exists, passing this will override the quantity on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `quantity`.



518
519
520
# File 'lib/stripe/params/quote_update_params.rb', line 518

def quantity
  @quantity
end

#tax_ratesObject

If an item with the ‘price` already exists, passing this will override the `tax_rates` array on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `tax_rates`.



520
521
522
# File 'lib/stripe/params/quote_update_params.rb', line 520

def tax_rates
  @tax_rates
end

#trialObject

If an item with the ‘price` already exists, passing this will override the `trial` configuration on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `trial`.



522
523
524
# File 'lib/stripe/params/quote_update_params.rb', line 522

def trial
  @trial
end

#trial_offerObject

The ID of the trial offer to apply to the configuration item.



524
525
526
# File 'lib/stripe/params/quote_update_params.rb', line 524

def trial_offer
  @trial_offer
end