Class: Stripe::QuoteUpdateParams::Line::Action::SetItem::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::Line::Action::SetItem::Discount::DiscountEnd
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
281 282 283 284 285 |
# File 'lib/stripe/params/quote_update_params.rb', line 281 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
275 276 277 |
# File 'lib/stripe/params/quote_update_params.rb', line 275 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
277 278 279 |
# File 'lib/stripe/params/quote_update_params.rb', line 277 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
279 280 281 |
# File 'lib/stripe/params/quote_update_params.rb', line 279 def type @type end |