Class: Stripe::QuoteUpdateParams::Line::AppliesTo

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(new_reference: nil, subscription_schedule: nil, type: nil) ⇒ AppliesTo

Returns a new instance of AppliesTo.



598
599
600
601
602
# File 'lib/stripe/params/quote_update_params.rb', line 598

def initialize(new_reference: nil, subscription_schedule: nil, type: nil)
  @new_reference = new_reference
  @subscription_schedule = subscription_schedule
  @type = type
end

Instance Attribute Details

#new_referenceObject

A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same ‘new_reference` field will be applied to the creation of a new subscription schedule.



592
593
594
# File 'lib/stripe/params/quote_update_params.rb', line 592

def new_reference
  @new_reference
end

#subscription_scheduleObject

The ID of the schedule the line applies to.



594
595
596
# File 'lib/stripe/params/quote_update_params.rb', line 594

def subscription_schedule
  @subscription_schedule
end

#typeObject

Describes whether the quote line is affecting a new schedule or an existing schedule.



596
597
598
# File 'lib/stripe/params/quote_update_params.rb', line 596

def type
  @type
end