Class: Stripe::QuoteUpdateParams::Line::AppliesTo
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::Line::AppliesTo
- Defined in:
- lib/stripe/params/quote_update_params.rb
Instance Attribute Summary collapse
-
#new_reference ⇒ Object
A custom string that identifies a new subscription schedule being created upon quote acceptance.
-
#subscription_schedule ⇒ Object
The ID of the schedule the line applies to.
-
#type ⇒ Object
Describes whether the quote line is affecting a new schedule or an existing schedule.
Instance Method Summary collapse
-
#initialize(new_reference: nil, subscription_schedule: nil, type: nil) ⇒ AppliesTo
constructor
A new instance of AppliesTo.
Methods inherited from RequestParams
Constructor Details
#initialize(new_reference: nil, subscription_schedule: nil, type: nil) ⇒ AppliesTo
Returns a new instance of AppliesTo.
598 599 600 601 602 |
# File 'lib/stripe/params/quote_update_params.rb', line 598 def initialize(new_reference: nil, subscription_schedule: nil, type: nil) @new_reference = new_reference @subscription_schedule = subscription_schedule @type = type end |
Instance Attribute Details
#new_reference ⇒ Object
A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same ‘new_reference` field will be applied to the creation of a new subscription schedule.
592 593 594 |
# File 'lib/stripe/params/quote_update_params.rb', line 592 def new_reference @new_reference end |
#subscription_schedule ⇒ Object
The ID of the schedule the line applies to.
594 595 596 |
# File 'lib/stripe/params/quote_update_params.rb', line 594 def subscription_schedule @subscription_schedule end |
#type ⇒ Object
Describes whether the quote line is affecting a new schedule or an existing schedule.
596 597 598 |
# File 'lib/stripe/params/quote_update_params.rb', line 596 def type @type end |