Class: Stripe::QuoteUpdateParams::Line::EndsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::Line::EndsAt
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Classes: DiscountEnd, Duration
Instance Attribute Summary collapse
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
Select a way to pass in ‘ends_at`.
Instance Method Summary collapse
-
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
constructor
A new instance of EndsAt.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
Returns a new instance of EndsAt.
650 651 652 653 654 655 |
# File 'lib/stripe/params/quote_update_params.rb', line 650 def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) @discount_end = discount_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
642 643 644 |
# File 'lib/stripe/params/quote_update_params.rb', line 642 def discount_end @discount_end end |
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
644 645 646 |
# File 'lib/stripe/params/quote_update_params.rb', line 644 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp.
646 647 648 |
# File 'lib/stripe/params/quote_update_params.rb', line 646 def @timestamp end |
#type ⇒ Object
Select a way to pass in ‘ends_at`.
648 649 650 |
# File 'lib/stripe/params/quote_update_params.rb', line 648 def type @type end |