Class: Stripe::QuoteUpdateParams::Line::EndsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::Line::EndsAt
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Classes: DiscountEnd, Duration
Instance Attribute Summary collapse
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
Select a way to pass in ‘ends_at`.
Instance Method Summary collapse
-
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
constructor
A new instance of EndsAt.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ EndsAt
Returns a new instance of EndsAt.
446 447 448 449 450 451 |
# File 'lib/stripe/params/quote_update_params.rb', line 446 def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) @discount_end = discount_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
438 439 440 |
# File 'lib/stripe/params/quote_update_params.rb', line 438 def discount_end @discount_end end |
#duration ⇒ Object
Time span for the quote line starting from the ‘starts_at` date.
440 441 442 |
# File 'lib/stripe/params/quote_update_params.rb', line 440 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp.
442 443 444 |
# File 'lib/stripe/params/quote_update_params.rb', line 442 def @timestamp end |
#type ⇒ Object
Select a way to pass in ‘ends_at`.
444 445 446 |
# File 'lib/stripe/params/quote_update_params.rb', line 444 def type @type end |