Class: Stripe::QuoteUpdateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::LineItem
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to this line item.
-
#id ⇒ Object
The ID of an existing line item on the quote.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new Price object inline.
-
#quantity ⇒ Object
The quantity of the line item.
-
#tax_rates ⇒ Object
The tax rates which apply to the line item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
Returns a new instance of LineItem.
915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 |
# File 'lib/stripe/params/quote_update_params.rb', line 915 def initialize( discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @discounts = discounts @id = id @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to this line item.
903 904 905 |
# File 'lib/stripe/params/quote_update_params.rb', line 903 def discounts @discounts end |
#id ⇒ Object
The ID of an existing line item on the quote.
905 906 907 |
# File 'lib/stripe/params/quote_update_params.rb', line 905 def id @id end |
#price ⇒ Object
The ID of the price object. One of price or price_data is required.
907 908 909 |
# File 'lib/stripe/params/quote_update_params.rb', line 907 def price @price end |
#price_data ⇒ Object
Data used to generate a new Price object inline. One of price or price_data is required.
909 910 911 |
# File 'lib/stripe/params/quote_update_params.rb', line 909 def price_data @price_data end |
#quantity ⇒ Object
The quantity of the line item.
911 912 913 |
# File 'lib/stripe/params/quote_update_params.rb', line 911 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the line item. When set, the default_tax_rates on the quote do not apply to this line item.
913 914 915 |
# File 'lib/stripe/params/quote_update_params.rb', line 913 def tax_rates @tax_rates end |
Class Method Details
.field_encodings ⇒ Object
931 932 933 934 935 |
# File 'lib/stripe/params/quote_update_params.rb', line 931 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |