Class: Stripe::QuoteUpdateParams::LineItem

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: Discount, PriceData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/stripe/params/quote_update_params.rb', line 168

def initialize(
  discounts: nil,
  id: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discounts = discounts
  @id = id
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The discounts applied to this line item.



156
157
158
# File 'lib/stripe/params/quote_update_params.rb', line 156

def discounts
  @discounts
end

#idObject

The ID of an existing line item on the quote.



158
159
160
# File 'lib/stripe/params/quote_update_params.rb', line 158

def id
  @id
end

#priceObject

The ID of the price object. One of price or price_data is required.



160
161
162
# File 'lib/stripe/params/quote_update_params.rb', line 160

def price
  @price
end

#price_dataObject

Data used to generate a new Price object inline. One of price or price_data is required.



162
163
164
# File 'lib/stripe/params/quote_update_params.rb', line 162

def price_data
  @price_data
end

#quantityObject

The quantity of the line item.



164
165
166
# File 'lib/stripe/params/quote_update_params.rb', line 164

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the default_tax_rates on the quote do not apply to this line item.



166
167
168
# File 'lib/stripe/params/quote_update_params.rb', line 166

def tax_rates
  @tax_rates
end

Class Method Details

.field_encodingsObject



184
185
186
187
188
# File 'lib/stripe/params/quote_update_params.rb', line 184

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end