Class: Stripe::QuoteUpdateParams::LineItem

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: Discount, PriceData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
# File 'lib/stripe/params/quote_update_params.rb', line 715

def initialize(
  discounts: nil,
  id: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discounts = discounts
  @id = id
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The discounts applied to this line item.



703
704
705
# File 'lib/stripe/params/quote_update_params.rb', line 703

def discounts
  @discounts
end

#idObject

The ID of an existing line item on the quote.



705
706
707
# File 'lib/stripe/params/quote_update_params.rb', line 705

def id
  @id
end

#priceObject

The ID of the price object. One of price or price_data is required.



707
708
709
# File 'lib/stripe/params/quote_update_params.rb', line 707

def price
  @price
end

#price_dataObject

Data used to generate a new Price object inline. One of price or price_data is required.



709
710
711
# File 'lib/stripe/params/quote_update_params.rb', line 709

def price_data
  @price_data
end

#quantityObject

The quantity of the line item.



711
712
713
# File 'lib/stripe/params/quote_update_params.rb', line 711

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the default_tax_rates on the quote do not apply to this line item.



713
714
715
# File 'lib/stripe/params/quote_update_params.rb', line 713

def tax_rates
  @tax_rates
end

Class Method Details

.field_encodingsObject



731
732
733
734
735
# File 'lib/stripe/params/quote_update_params.rb', line 731

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end