Class: Stripe::QuoteUpdateParams::LineItem

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: Discount, PriceData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
# File 'lib/stripe/params/quote_update_params.rb', line 888

def initialize(
  discounts: nil,
  id: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discounts = discounts
  @id = id
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The discounts applied to this line item.



876
877
878
# File 'lib/stripe/params/quote_update_params.rb', line 876

def discounts
  @discounts
end

#idObject

The ID of an existing line item on the quote.



878
879
880
# File 'lib/stripe/params/quote_update_params.rb', line 878

def id
  @id
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



880
881
882
# File 'lib/stripe/params/quote_update_params.rb', line 880

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.



882
883
884
# File 'lib/stripe/params/quote_update_params.rb', line 882

def price_data
  @price_data
end

#quantityObject

The quantity of the line item.



884
885
886
# File 'lib/stripe/params/quote_update_params.rb', line 884

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the quote do not apply to this line item.



886
887
888
# File 'lib/stripe/params/quote_update_params.rb', line 886

def tax_rates
  @tax_rates
end

Class Method Details

.field_encodingsObject



904
905
906
907
908
# File 'lib/stripe/params/quote_update_params.rb', line 904

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end