Class: Stripe::QuoteUpdateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::LineItem
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to this line item.
-
#id ⇒ Object
The ID of an existing line item on the quote.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
-
#quantity ⇒ Object
The quantity of the line item.
-
#tax_rates ⇒ Object
The tax rates which apply to the line item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
Returns a new instance of LineItem.
688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 |
# File 'lib/stripe/params/quote_update_params.rb', line 688 def initialize( discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @discounts = discounts @id = id @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to this line item.
676 677 678 |
# File 'lib/stripe/params/quote_update_params.rb', line 676 def discounts @discounts end |
#id ⇒ Object
The ID of an existing line item on the quote.
678 679 680 |
# File 'lib/stripe/params/quote_update_params.rb', line 678 def id @id end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
680 681 682 |
# File 'lib/stripe/params/quote_update_params.rb', line 680 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.
682 683 684 |
# File 'lib/stripe/params/quote_update_params.rb', line 682 def price_data @price_data end |
#quantity ⇒ Object
The quantity of the line item.
684 685 686 |
# File 'lib/stripe/params/quote_update_params.rb', line 684 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the quote do not apply to this line item.
686 687 688 |
# File 'lib/stripe/params/quote_update_params.rb', line 686 def tax_rates @tax_rates end |
Class Method Details
.field_encodings ⇒ Object
704 705 706 707 708 |
# File 'lib/stripe/params/quote_update_params.rb', line 704 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |