Class: Stripe::QuoteUpdateParams::LineItem

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, id: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
# File 'lib/stripe/params/quote_update_params.rb', line 676

def initialize(
  discounts: nil,
  id: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discounts = discounts
  @id = id
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The discounts applied to this line item.



664
665
666
# File 'lib/stripe/params/quote_update_params.rb', line 664

def discounts
  @discounts
end

#idObject

The ID of an existing line item on the quote.



666
667
668
# File 'lib/stripe/params/quote_update_params.rb', line 666

def id
  @id
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



668
669
670
# File 'lib/stripe/params/quote_update_params.rb', line 668

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.



670
671
672
# File 'lib/stripe/params/quote_update_params.rb', line 670

def price_data
  @price_data
end

#quantityObject

The quantity of the line item.



672
673
674
# File 'lib/stripe/params/quote_update_params.rb', line 672

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the quote do not apply to this line item.



674
675
676
# File 'lib/stripe/params/quote_update_params.rb', line 674

def tax_rates
  @tax_rates
end