Class: Stripe::QuoteUpdateParams::SubscriptionData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::SubscriptionData
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Classes: BillOnAcceptance, BillingSchedule, Prebilling
Instance Attribute Summary collapse
-
#bill_on_acceptance ⇒ Object
Describes the period to bill for upon accepting the quote.
-
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions.
-
#billing_cycle_anchor ⇒ Object
When specified as
reset, the subscription will always start a new billing period when the quote is accepted. -
#billing_schedules ⇒ Object
Billing schedules that will be applied to the subscription or subscription schedule created when the quote is accepted.
-
#description ⇒ Object
The subscription's description, meant to be displayable to the customer.
-
#effective_date ⇒ Object
When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted.
-
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
-
#metadata ⇒ Object
Set of key-value pairs that will set metadata on the subscription or subscription schedule when the quote is accepted.
-
#phase_effective_at ⇒ Object
Configures how the subscription schedule handles billing for phase transitions when the quote is accepted.
-
#prebilling ⇒ Object
If specified, the invoicing for the given billing cycle iterations will be processed when the quote is accepted.
-
#proration_behavior ⇒ Object
Determines how to handle prorations.
-
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time.
Instance Method Summary collapse
-
#initialize(bill_on_acceptance: nil, billing_behavior: nil, billing_cycle_anchor: nil, billing_schedules: nil, description: nil, effective_date: nil, end_behavior: nil, metadata: nil, phase_effective_at: nil, prebilling: nil, proration_behavior: nil, trial_period_days: nil) ⇒ SubscriptionData
constructor
A new instance of SubscriptionData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bill_on_acceptance: nil, billing_behavior: nil, billing_cycle_anchor: nil, billing_schedules: nil, description: nil, effective_date: nil, end_behavior: nil, metadata: nil, phase_effective_at: nil, prebilling: nil, proration_behavior: nil, trial_period_days: nil) ⇒ SubscriptionData
Returns a new instance of SubscriptionData.
1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 |
# File 'lib/stripe/params/quote_update_params.rb', line 1152 def initialize( bill_on_acceptance: nil, billing_behavior: nil, billing_cycle_anchor: nil, billing_schedules: nil, description: nil, effective_date: nil, end_behavior: nil, metadata: nil, phase_effective_at: nil, prebilling: nil, proration_behavior: nil, trial_period_days: nil ) @bill_on_acceptance = bill_on_acceptance @billing_behavior = billing_behavior @billing_cycle_anchor = billing_cycle_anchor @billing_schedules = billing_schedules @description = description @effective_date = effective_date @end_behavior = end_behavior @metadata = @phase_effective_at = phase_effective_at @prebilling = prebilling @proration_behavior = proration_behavior @trial_period_days = trial_period_days end |
Instance Attribute Details
#bill_on_acceptance ⇒ Object
Describes the period to bill for upon accepting the quote.
1122 1123 1124 |
# File 'lib/stripe/params/quote_update_params.rb', line 1122 def bill_on_acceptance @bill_on_acceptance end |
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions. Possible values are prorate_on_next_phase or prorate_up_front with the default being prorate_on_next_phase. prorate_on_next_phase will apply phase changes and generate prorations at transition time. prorate_up_front will bill for all phases within the current billing cycle up front.
1124 1125 1126 |
# File 'lib/stripe/params/quote_update_params.rb', line 1124 def billing_behavior @billing_behavior end |
#billing_cycle_anchor ⇒ Object
When specified as reset, the subscription will always start a new billing period when the quote is accepted.
1126 1127 1128 |
# File 'lib/stripe/params/quote_update_params.rb', line 1126 def billing_cycle_anchor @billing_cycle_anchor end |
#billing_schedules ⇒ Object
Billing schedules that will be applied to the subscription or subscription schedule created when the quote is accepted.
1128 1129 1130 |
# File 'lib/stripe/params/quote_update_params.rb', line 1128 def billing_schedules @billing_schedules end |
#description ⇒ Object
The subscription's description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
1130 1131 1132 |
# File 'lib/stripe/params/quote_update_params.rb', line 1130 def description @description end |
#effective_date ⇒ Object
When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted. When updating a subscription, the date of which the subscription will be updated using a subscription schedule. The special value current_period_end can be provided to update a subscription at the end of its current period. The effective_date is ignored if it is in the past when the quote is accepted.
1132 1133 1134 |
# File 'lib/stripe/params/quote_update_params.rb', line 1132 def effective_date @effective_date end |
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
1134 1135 1136 |
# File 'lib/stripe/params/quote_update_params.rb', line 1134 def end_behavior @end_behavior end |
#metadata ⇒ Object
Set of key-value pairs that will set metadata on the subscription or subscription schedule when the quote is accepted. If a recurring price is included in line_items, this field will be passed to the resulting subscription's metadata field. If subscription_data.effective_date is used, this field will be passed to the resulting subscription schedule's phases.metadata field. Unlike object-level metadata, this field is declarative. Updates will clear prior values.
1136 1137 1138 |
# File 'lib/stripe/params/quote_update_params.rb', line 1136 def @metadata end |
#phase_effective_at ⇒ Object
Configures how the subscription schedule handles billing for phase transitions when the quote is accepted.
1138 1139 1140 |
# File 'lib/stripe/params/quote_update_params.rb', line 1138 def phase_effective_at @phase_effective_at end |
#prebilling ⇒ Object
If specified, the invoicing for the given billing cycle iterations will be processed when the quote is accepted. Cannot be used with effective_date.
1140 1141 1142 |
# File 'lib/stripe/params/quote_update_params.rb', line 1140 def prebilling @prebilling end |
#proration_behavior ⇒ Object
Determines how to handle prorations. When creating a subscription, valid values are create_prorations or none.
When updating a subscription, valid values are create_prorations, none, or always_invoice.
Passing create_prorations will cause proration invoice items to be created when applicable. These proration items will only be invoiced immediately under certain conditions. In order to always invoice immediately for prorations, pass always_invoice.
Prorations can be disabled by passing none.
1148 1149 1150 |
# File 'lib/stripe/params/quote_update_params.rb', line 1148 def proration_behavior @proration_behavior end |
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time.
1150 1151 1152 |
# File 'lib/stripe/params/quote_update_params.rb', line 1150 def trial_period_days @trial_period_days end |