Class: Stripe::QuoteUpdateParams::SubscriptionData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::SubscriptionData
- Defined in:
- lib/stripe/params/quote_update_params.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
The subscription's description, meant to be displayable to the customer.
-
#effective_date ⇒ Object
When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted.
-
#metadata ⇒ Object
Set of key-value pairs that will set metadata on the subscription or subscription schedule when the quote is accepted.
-
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time.
Instance Method Summary collapse
-
#initialize(description: nil, effective_date: nil, metadata: nil, trial_period_days: nil) ⇒ SubscriptionData
constructor
A new instance of SubscriptionData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(description: nil, effective_date: nil, metadata: nil, trial_period_days: nil) ⇒ SubscriptionData
Returns a new instance of SubscriptionData.
201 202 203 204 205 206 |
# File 'lib/stripe/params/quote_update_params.rb', line 201 def initialize(description: nil, effective_date: nil, metadata: nil, trial_period_days: nil) @description = description @effective_date = effective_date @metadata = @trial_period_days = trial_period_days end |
Instance Attribute Details
#description ⇒ Object
The subscription's description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
193 194 195 |
# File 'lib/stripe/params/quote_update_params.rb', line 193 def description @description end |
#effective_date ⇒ Object
When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted. The effective_date is ignored if it is in the past when the quote is accepted.
195 196 197 |
# File 'lib/stripe/params/quote_update_params.rb', line 195 def effective_date @effective_date end |
#metadata ⇒ Object
Set of key-value pairs that will set metadata on the subscription or subscription schedule when the quote is accepted. If a recurring price is included in line_items, this field will be passed to the resulting subscription's metadata field. If subscription_data.effective_date is used, this field will be passed to the resulting subscription schedule's phases.metadata field. Unlike object-level metadata, this field is declarative. Updates will clear prior values.
197 198 199 |
# File 'lib/stripe/params/quote_update_params.rb', line 197 def @metadata end |
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time.
199 200 201 |
# File 'lib/stripe/params/quote_update_params.rb', line 199 def trial_period_days @trial_period_days end |