Class: Stripe::QuoteUpdateParams::SubscriptionData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: BillOnAcceptance, Prebilling

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bill_on_acceptance: nil, billing_behavior: nil, billing_cycle_anchor: nil, description: nil, effective_date: nil, end_behavior: nil, metadata: nil, prebilling: nil, proration_behavior: nil, trial_period_days: nil) ⇒ SubscriptionData

Returns a new instance of SubscriptionData.



825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
# File 'lib/stripe/params/quote_update_params.rb', line 825

def initialize(
  bill_on_acceptance: nil,
  billing_behavior: nil,
  billing_cycle_anchor: nil,
  description: nil,
  effective_date: nil,
  end_behavior: nil,
  metadata: nil,
  prebilling: nil,
  proration_behavior: nil,
  trial_period_days: nil
)
  @bill_on_acceptance = bill_on_acceptance
  @billing_behavior = billing_behavior
  @billing_cycle_anchor = billing_cycle_anchor
  @description = description
  @effective_date = effective_date
  @end_behavior = end_behavior
  @metadata = 
  @prebilling = prebilling
  @proration_behavior = proration_behavior
  @trial_period_days = trial_period_days
end

Instance Attribute Details

#bill_on_acceptanceObject

Describes the period to bill for upon accepting the quote.



799
800
801
# File 'lib/stripe/params/quote_update_params.rb', line 799

def bill_on_acceptance
  @bill_on_acceptance
end

#billing_behaviorObject

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



801
802
803
# File 'lib/stripe/params/quote_update_params.rb', line 801

def billing_behavior
  @billing_behavior
end

#billing_cycle_anchorObject

When specified as ‘reset`, the subscription will always start a new billing period when the quote is accepted.



803
804
805
# File 'lib/stripe/params/quote_update_params.rb', line 803

def billing_cycle_anchor
  @billing_cycle_anchor
end

#descriptionObject

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



805
806
807
# File 'lib/stripe/params/quote_update_params.rb', line 805

def description
  @description
end

#effective_dateObject

When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted. When updating a subscription, the date of which the subscription will be updated using a subscription schedule. The special value ‘current_period_end` can be provided to update a subscription at the end of its current period. The `effective_date` is ignored if it is in the past when the quote is accepted.



807
808
809
# File 'lib/stripe/params/quote_update_params.rb', line 807

def effective_date
  @effective_date
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends.



809
810
811
# File 'lib/stripe/params/quote_update_params.rb', line 809

def end_behavior
  @end_behavior
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that will set metadata on the subscription or subscription schedule when the quote is accepted. If a recurring price is included in ‘line_items`, this field will be passed to the resulting subscription’s ‘metadata` field. If `subscription_data.effective_date` is used, this field will be passed to the resulting subscription schedule’s ‘phases.metadata` field. Unlike object-level metadata, this field is declarative. Updates will clear prior values.



811
812
813
# File 'lib/stripe/params/quote_update_params.rb', line 811

def 
  @metadata
end

#prebillingObject

If specified, the invoicing for the given billing cycle iterations will be processed when the quote is accepted. Cannot be used with ‘effective_date`.



813
814
815
# File 'lib/stripe/params/quote_update_params.rb', line 813

def prebilling
  @prebilling
end

#proration_behaviorObject

Determines how to handle [prorations](docs.stripe.com/subscriptions/billing-cycle#prorations). When creating a subscription, valid values are ‘create_prorations` or `none`.

When updating a subscription, valid values are ‘create_prorations`, `none`, or `always_invoice`.

Passing ‘create_prorations` will cause proration invoice items to be created when applicable. These proration items will only be invoiced immediately under [certain conditions](docs.stripe.com/subscriptions/upgrading-downgrading#immediate-payment). In order to always invoice immediately for prorations, pass `always_invoice`.

Prorations can be disabled by passing ‘none`.



821
822
823
# File 'lib/stripe/params/quote_update_params.rb', line 821

def proration_behavior
  @proration_behavior
end

#trial_period_daysObject

Integer representing the number of trial period days before the customer is charged for the first time.



823
824
825
# File 'lib/stripe/params/quote_update_params.rb', line 823

def trial_period_days
  @trial_period_days
end