Class: Stripe::QuoteUpdateParams::SubscriptionData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: BillOnAcceptance, BillingSchedule, Prebilling

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bill_on_acceptance: nil, billing_behavior: nil, billing_cycle_anchor: nil, billing_schedules: nil, description: nil, effective_date: nil, end_behavior: nil, metadata: nil, phase_effective_at: nil, prebilling: nil, proration_behavior: nil, trial_period_days: nil) ⇒ SubscriptionData

Returns a new instance of SubscriptionData.



1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
# File 'lib/stripe/params/quote_update_params.rb', line 1115

def initialize(
  bill_on_acceptance: nil,
  billing_behavior: nil,
  billing_cycle_anchor: nil,
  billing_schedules: nil,
  description: nil,
  effective_date: nil,
  end_behavior: nil,
  metadata: nil,
  phase_effective_at: nil,
  prebilling: nil,
  proration_behavior: nil,
  trial_period_days: nil
)
  @bill_on_acceptance = bill_on_acceptance
  @billing_behavior = billing_behavior
  @billing_cycle_anchor = billing_cycle_anchor
  @billing_schedules = billing_schedules
  @description = description
  @effective_date = effective_date
  @end_behavior = end_behavior
  @metadata = 
  @phase_effective_at = phase_effective_at
  @prebilling = prebilling
  @proration_behavior = proration_behavior
  @trial_period_days = trial_period_days
end

Instance Attribute Details

#bill_on_acceptanceObject

Describes the period to bill for upon accepting the quote.



1085
1086
1087
# File 'lib/stripe/params/quote_update_params.rb', line 1085

def bill_on_acceptance
  @bill_on_acceptance
end

#billing_behaviorObject

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



1087
1088
1089
# File 'lib/stripe/params/quote_update_params.rb', line 1087

def billing_behavior
  @billing_behavior
end

#billing_cycle_anchorObject

When specified as ‘reset`, the subscription will always start a new billing period when the quote is accepted.



1089
1090
1091
# File 'lib/stripe/params/quote_update_params.rb', line 1089

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_schedulesObject

Billing schedules that will be applied to the subscription or subscription schedule created when the quote is accepted.



1091
1092
1093
# File 'lib/stripe/params/quote_update_params.rb', line 1091

def billing_schedules
  @billing_schedules
end

#descriptionObject

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



1093
1094
1095
# File 'lib/stripe/params/quote_update_params.rb', line 1093

def description
  @description
end

#effective_dateObject

When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted. When updating a subscription, the date of which the subscription will be updated using a subscription schedule. The special value ‘current_period_end` can be provided to update a subscription at the end of its current period. The `effective_date` is ignored if it is in the past when the quote is accepted.



1095
1096
1097
# File 'lib/stripe/params/quote_update_params.rb', line 1095

def effective_date
  @effective_date
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends.



1097
1098
1099
# File 'lib/stripe/params/quote_update_params.rb', line 1097

def end_behavior
  @end_behavior
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that will set metadata on the subscription or subscription schedule when the quote is accepted. If a recurring price is included in ‘line_items`, this field will be passed to the resulting subscription’s ‘metadata` field. If `subscription_data.effective_date` is used, this field will be passed to the resulting subscription schedule’s ‘phases.metadata` field. Unlike object-level metadata, this field is declarative. Updates will clear prior values.



1099
1100
1101
# File 'lib/stripe/params/quote_update_params.rb', line 1099

def 
  @metadata
end

#phase_effective_atObject

Configures how the subscription schedule handles billing for phase transitions when the quote is accepted.



1101
1102
1103
# File 'lib/stripe/params/quote_update_params.rb', line 1101

def phase_effective_at
  @phase_effective_at
end

#prebillingObject

If specified, the invoicing for the given billing cycle iterations will be processed when the quote is accepted. Cannot be used with ‘effective_date`.



1103
1104
1105
# File 'lib/stripe/params/quote_update_params.rb', line 1103

def prebilling
  @prebilling
end

#proration_behaviorObject

Determines how to handle [prorations](docs.stripe.com/subscriptions/billing-cycle#prorations). When creating a subscription, valid values are ‘create_prorations` or `none`.

When updating a subscription, valid values are ‘create_prorations`, `none`, or `always_invoice`.

Passing ‘create_prorations` will cause proration invoice items to be created when applicable. These proration items will only be invoiced immediately under [certain conditions](docs.stripe.com/subscriptions/upgrading-downgrading#immediate-payment). In order to always invoice immediately for prorations, pass `always_invoice`.

Prorations can be disabled by passing ‘none`.



1111
1112
1113
# File 'lib/stripe/params/quote_update_params.rb', line 1111

def proration_behavior
  @proration_behavior
end

#trial_period_daysObject

Integer representing the number of trial period days before the customer is charged for the first time.



1113
1114
1115
# File 'lib/stripe/params/quote_update_params.rb', line 1113

def trial_period_days
  @trial_period_days
end