Class: Stripe::QuoteUpdateParams::SubscriptionData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::SubscriptionData
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Classes: BillOnAcceptance, BillingSchedule, Prebilling
Instance Attribute Summary collapse
-
#bill_on_acceptance ⇒ Object
Describes the period to bill for upon accepting the quote.
-
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions.
-
#billing_cycle_anchor ⇒ Object
When specified as ‘reset`, the subscription will always start a new billing period when the quote is accepted.
-
#billing_schedules ⇒ Object
Billing schedules that will be applied to the subscription or subscription schedule created when the quote is accepted.
-
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer.
-
#effective_date ⇒ Object
When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted.
-
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that will set metadata on the subscription or subscription schedule when the quote is accepted.
-
#phase_effective_at ⇒ Object
Configures how the subscription schedule handles billing for phase transitions when the quote is accepted.
-
#prebilling ⇒ Object
If specified, the invoicing for the given billing cycle iterations will be processed when the quote is accepted.
-
#proration_behavior ⇒ Object
Determines how to handle [prorations](docs.stripe.com/subscriptions/billing-cycle#prorations).
-
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time.
Instance Method Summary collapse
-
#initialize(bill_on_acceptance: nil, billing_behavior: nil, billing_cycle_anchor: nil, billing_schedules: nil, description: nil, effective_date: nil, end_behavior: nil, metadata: nil, phase_effective_at: nil, prebilling: nil, proration_behavior: nil, trial_period_days: nil) ⇒ SubscriptionData
constructor
A new instance of SubscriptionData.
Methods inherited from RequestParams
Constructor Details
#initialize(bill_on_acceptance: nil, billing_behavior: nil, billing_cycle_anchor: nil, billing_schedules: nil, description: nil, effective_date: nil, end_behavior: nil, metadata: nil, phase_effective_at: nil, prebilling: nil, proration_behavior: nil, trial_period_days: nil) ⇒ SubscriptionData
Returns a new instance of SubscriptionData.
919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 |
# File 'lib/stripe/params/quote_update_params.rb', line 919 def initialize( bill_on_acceptance: nil, billing_behavior: nil, billing_cycle_anchor: nil, billing_schedules: nil, description: nil, effective_date: nil, end_behavior: nil, metadata: nil, phase_effective_at: nil, prebilling: nil, proration_behavior: nil, trial_period_days: nil ) @bill_on_acceptance = bill_on_acceptance @billing_behavior = billing_behavior @billing_cycle_anchor = billing_cycle_anchor @billing_schedules = billing_schedules @description = description @effective_date = effective_date @end_behavior = end_behavior @metadata = @phase_effective_at = phase_effective_at @prebilling = prebilling @proration_behavior = proration_behavior @trial_period_days = trial_period_days end |
Instance Attribute Details
#bill_on_acceptance ⇒ Object
Describes the period to bill for upon accepting the quote.
889 890 891 |
# File 'lib/stripe/params/quote_update_params.rb', line 889 def bill_on_acceptance @bill_on_acceptance end |
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.
891 892 893 |
# File 'lib/stripe/params/quote_update_params.rb', line 891 def billing_behavior @billing_behavior end |
#billing_cycle_anchor ⇒ Object
When specified as ‘reset`, the subscription will always start a new billing period when the quote is accepted.
893 894 895 |
# File 'lib/stripe/params/quote_update_params.rb', line 893 def billing_cycle_anchor @billing_cycle_anchor end |
#billing_schedules ⇒ Object
Billing schedules that will be applied to the subscription or subscription schedule created when the quote is accepted.
895 896 897 |
# File 'lib/stripe/params/quote_update_params.rb', line 895 def billing_schedules @billing_schedules end |
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
897 898 899 |
# File 'lib/stripe/params/quote_update_params.rb', line 897 def description @description end |
#effective_date ⇒ Object
When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted. When updating a subscription, the date of which the subscription will be updated using a subscription schedule. The special value ‘current_period_end` can be provided to update a subscription at the end of its current period. The `effective_date` is ignored if it is in the past when the quote is accepted.
899 900 901 |
# File 'lib/stripe/params/quote_update_params.rb', line 899 def effective_date @effective_date end |
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
901 902 903 |
# File 'lib/stripe/params/quote_update_params.rb', line 901 def end_behavior @end_behavior end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that will set metadata on the subscription or subscription schedule when the quote is accepted. If a recurring price is included in ‘line_items`, this field will be passed to the resulting subscription’s ‘metadata` field. If `subscription_data.effective_date` is used, this field will be passed to the resulting subscription schedule’s ‘phases.metadata` field. Unlike object-level metadata, this field is declarative. Updates will clear prior values.
903 904 905 |
# File 'lib/stripe/params/quote_update_params.rb', line 903 def @metadata end |
#phase_effective_at ⇒ Object
Configures how the subscription schedule handles billing for phase transitions when the quote is accepted.
905 906 907 |
# File 'lib/stripe/params/quote_update_params.rb', line 905 def phase_effective_at @phase_effective_at end |
#prebilling ⇒ Object
If specified, the invoicing for the given billing cycle iterations will be processed when the quote is accepted. Cannot be used with ‘effective_date`.
907 908 909 |
# File 'lib/stripe/params/quote_update_params.rb', line 907 def prebilling @prebilling end |
#proration_behavior ⇒ Object
Determines how to handle [prorations](docs.stripe.com/subscriptions/billing-cycle#prorations). When creating a subscription, valid values are ‘create_prorations` or `none`.
When updating a subscription, valid values are ‘create_prorations`, `none`, or `always_invoice`.
Passing ‘create_prorations` will cause proration invoice items to be created when applicable. These proration items will only be invoiced immediately under [certain conditions](docs.stripe.com/subscriptions/upgrading-downgrading#immediate-payment). In order to always invoice immediately for prorations, pass `always_invoice`.
Prorations can be disabled by passing ‘none`.
915 916 917 |
# File 'lib/stripe/params/quote_update_params.rb', line 915 def proration_behavior @proration_behavior end |
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time.
917 918 919 |
# File 'lib/stripe/params/quote_update_params.rb', line 917 def trial_period_days @trial_period_days end |