Class: Stripe::QuoteUpdateParams::SubscriptionData::BillOnAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: BillFrom, BillUntil

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bill_from: nil, bill_until: nil) ⇒ BillOnAcceptance

Returns a new instance of BillOnAcceptance.



766
767
768
769
# File 'lib/stripe/params/quote_update_params.rb', line 766

def initialize(bill_from: nil, bill_until: nil)
  @bill_from = bill_from
  @bill_until = bill_until
end

Instance Attribute Details

#bill_fromObject

The start of the period to bill from when the Quote is accepted.



762
763
764
# File 'lib/stripe/params/quote_update_params.rb', line 762

def bill_from
  @bill_from
end

#bill_untilObject

The end of the period to bill until when the Quote is accepted.



764
765
766
# File 'lib/stripe/params/quote_update_params.rb', line 764

def bill_until
  @bill_until
end