Class: Stripe::QuoteUpdateParams::SubscriptionData::BillOnAcceptance::BillFrom::LineStartsAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::SubscriptionData::BillOnAcceptance::BillFrom::LineStartsAt
- Defined in:
- lib/stripe/params/quote_update_params.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of a quote line.
-
#index ⇒ Object
The position of the previous quote line in the ‘lines` array after which this line should begin.
Instance Method Summary collapse
-
#initialize(id: nil, index: nil) ⇒ LineStartsAt
constructor
A new instance of LineStartsAt.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, index: nil) ⇒ LineStartsAt
Returns a new instance of LineStartsAt.
910 911 912 913 |
# File 'lib/stripe/params/quote_update_params.rb', line 910 def initialize(id: nil, index: nil) @id = id @index = index end |
Instance Attribute Details
#id ⇒ Object
The ID of a quote line.
906 907 908 |
# File 'lib/stripe/params/quote_update_params.rb', line 906 def id @id end |
#index ⇒ Object
The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.
908 909 910 |
# File 'lib/stripe/params/quote_update_params.rb', line 908 def index @index end |