Class: Stripe::QuoteUpdateParams::SubscriptionData::BillOnAcceptance::BillUntil::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



740
741
742
743
# File 'lib/stripe/params/quote_update_params.rb', line 740

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



736
737
738
# File 'lib/stripe/params/quote_update_params.rb', line 736

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



738
739
740
# File 'lib/stripe/params/quote_update_params.rb', line 738

def interval_count
  @interval_count
end