Class: Stripe::QuoteUpdateParams::SubscriptionData::BillingSchedule
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::SubscriptionData::BillingSchedule
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Classes: AppliesTo, BillFrom, BillUntil
Instance Attribute Summary collapse
-
#applies_to ⇒ Object
Configure billing schedule differently for individual subscription items.
-
#bill_from ⇒ Object
The start of the period to bill from when the Quote is accepted.
-
#bill_until ⇒ Object
The end of the period to bill until when the Quote is accepted.
-
#key ⇒ Object
Specify a key for the billing schedule.
Instance Method Summary collapse
-
#initialize(applies_to: nil, bill_from: nil, bill_until: nil, key: nil) ⇒ BillingSchedule
constructor
A new instance of BillingSchedule.
Methods inherited from RequestParams
Constructor Details
#initialize(applies_to: nil, bill_from: nil, bill_until: nil, key: nil) ⇒ BillingSchedule
Returns a new instance of BillingSchedule.
1068 1069 1070 1071 1072 1073 |
# File 'lib/stripe/params/quote_update_params.rb', line 1068 def initialize(applies_to: nil, bill_from: nil, bill_until: nil, key: nil) @applies_to = applies_to @bill_from = bill_from @bill_until = bill_until @key = key end |
Instance Attribute Details
#applies_to ⇒ Object
Configure billing schedule differently for individual subscription items.
1060 1061 1062 |
# File 'lib/stripe/params/quote_update_params.rb', line 1060 def applies_to @applies_to end |
#bill_from ⇒ Object
The start of the period to bill from when the Quote is accepted.
1062 1063 1064 |
# File 'lib/stripe/params/quote_update_params.rb', line 1062 def bill_from @bill_from end |
#bill_until ⇒ Object
The end of the period to bill until when the Quote is accepted.
1064 1065 1066 |
# File 'lib/stripe/params/quote_update_params.rb', line 1064 def bill_until @bill_until end |
#key ⇒ Object
Specify a key for the billing schedule. Must be unique to this field, alphanumeric, and up to 200 characters. If not provided, a unique key will be generated.
1066 1067 1068 |
# File 'lib/stripe/params/quote_update_params.rb', line 1066 def key @key end |