Class: Stripe::QuoteUpdateParams::SubscriptionData::BillingSchedule::BillFrom::LineStartsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineStartsAt

Returns a new instance of LineStartsAt.



792
793
794
795
# File 'lib/stripe/params/quote_update_params.rb', line 792

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



788
789
790
# File 'lib/stripe/params/quote_update_params.rb', line 788

def id
  @id
end

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



790
791
792
# File 'lib/stripe/params/quote_update_params.rb', line 790

def index
  @index
end