Class: Stripe::QuoteUpdateParams::SubscriptionData::BillingSchedule::BillUntil::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



818
819
820
821
# File 'lib/stripe/params/quote_update_params.rb', line 818

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



814
815
816
# File 'lib/stripe/params/quote_update_params.rb', line 814

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



816
817
818
# File 'lib/stripe/params/quote_update_params.rb', line 816

def interval_count
  @interval_count
end