Class: Stripe::QuoteUpdateParams::SubscriptionDataOverride

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: AppliesTo, BillOnAcceptance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(applies_to: nil, bill_on_acceptance: nil, billing_behavior: nil, customer: nil, description: nil, end_behavior: nil, proration_behavior: nil) ⇒ SubscriptionDataOverride

Returns a new instance of SubscriptionDataOverride.



991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
# File 'lib/stripe/params/quote_update_params.rb', line 991

def initialize(
  applies_to: nil,
  bill_on_acceptance: nil,
  billing_behavior: nil,
  customer: nil,
  description: nil,
  end_behavior: nil,
  proration_behavior: nil
)
  @applies_to = applies_to
  @bill_on_acceptance = bill_on_acceptance
  @billing_behavior = billing_behavior
  @customer = customer
  @description = description
  @end_behavior = end_behavior
  @proration_behavior = proration_behavior
end

Instance Attribute Details

#applies_toObject

Whether the override applies to an existing Subscription Schedule or a new Subscription Schedule.



971
972
973
# File 'lib/stripe/params/quote_update_params.rb', line 971

def applies_to
  @applies_to
end

#bill_on_acceptanceObject

Describes the period to bill for upon accepting the quote.



973
974
975
# File 'lib/stripe/params/quote_update_params.rb', line 973

def bill_on_acceptance
  @bill_on_acceptance
end

#billing_behaviorObject

Configures when the subscription schedule generates prorations for phase transitions. Possible values are prorate_on_next_phase or prorate_up_front with the default being prorate_on_next_phase. prorate_on_next_phase will apply phase changes and generate prorations at transition time. prorate_up_front will bill for all phases within the current billing cycle up front.



975
976
977
# File 'lib/stripe/params/quote_update_params.rb', line 975

def billing_behavior
  @billing_behavior
end

#customerObject

The customer the Subscription Data override applies to.



977
978
979
# File 'lib/stripe/params/quote_update_params.rb', line 977

def customer
  @customer
end

#descriptionObject

The subscription's description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



979
980
981
# File 'lib/stripe/params/quote_update_params.rb', line 979

def description
  @description
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends.



981
982
983
# File 'lib/stripe/params/quote_update_params.rb', line 981

def end_behavior
  @end_behavior
end

#proration_behaviorObject

Determines how to handle prorations. When creating a subscription, valid values are create_prorations or none.

When updating a subscription, valid values are create_prorations, none, or always_invoice.

Passing create_prorations will cause proration invoice items to be created when applicable. These proration items will only be invoiced immediately under certain conditions. In order to always invoice immediately for prorations, pass always_invoice.

Prorations can be disabled by passing none.



989
990
991
# File 'lib/stripe/params/quote_update_params.rb', line 989

def proration_behavior
  @proration_behavior
end