Class: Stripe::QuoteUpdateParams::SubscriptionDataOverride

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: AppliesTo, BillOnAcceptance, BillingSchedule

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(applies_to: nil, bill_on_acceptance: nil, billing_behavior: nil, billing_schedules: nil, customer: nil, description: nil, end_behavior: nil, phase_effective_at: nil, proration_behavior: nil) ⇒ SubscriptionDataOverride

Returns a new instance of SubscriptionDataOverride.



1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
# File 'lib/stripe/params/quote_update_params.rb', line 1358

def initialize(
  applies_to: nil,
  bill_on_acceptance: nil,
  billing_behavior: nil,
  billing_schedules: nil,
  customer: nil,
  description: nil,
  end_behavior: nil,
  phase_effective_at: nil,
  proration_behavior: nil
)
  @applies_to = applies_to
  @bill_on_acceptance = bill_on_acceptance
  @billing_behavior = billing_behavior
  @billing_schedules = billing_schedules
  @customer = customer
  @description = description
  @end_behavior = end_behavior
  @phase_effective_at = phase_effective_at
  @proration_behavior = proration_behavior
end

Instance Attribute Details

#applies_toObject

Whether the override applies to an existing Subscription Schedule or a new Subscription Schedule.



1334
1335
1336
# File 'lib/stripe/params/quote_update_params.rb', line 1334

def applies_to
  @applies_to
end

#bill_on_acceptanceObject

Describes the period to bill for upon accepting the quote.



1336
1337
1338
# File 'lib/stripe/params/quote_update_params.rb', line 1336

def bill_on_acceptance
  @bill_on_acceptance
end

#billing_behaviorObject

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



1338
1339
1340
# File 'lib/stripe/params/quote_update_params.rb', line 1338

def billing_behavior
  @billing_behavior
end

#billing_schedulesObject

Billing schedules that will be applied to the subscription or subscription schedule created when the quote is accepted.



1340
1341
1342
# File 'lib/stripe/params/quote_update_params.rb', line 1340

def billing_schedules
  @billing_schedules
end

#customerObject

The customer the Subscription Data override applies to.



1342
1343
1344
# File 'lib/stripe/params/quote_update_params.rb', line 1342

def customer
  @customer
end

#descriptionObject

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



1344
1345
1346
# File 'lib/stripe/params/quote_update_params.rb', line 1344

def description
  @description
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends.



1346
1347
1348
# File 'lib/stripe/params/quote_update_params.rb', line 1346

def end_behavior
  @end_behavior
end

#phase_effective_atObject

Configures how the subscription schedule handles billing for phase transitions when the quote is accepted.



1348
1349
1350
# File 'lib/stripe/params/quote_update_params.rb', line 1348

def phase_effective_at
  @phase_effective_at
end

#proration_behaviorObject

Determines how to handle [prorations](docs.stripe.com/subscriptions/billing-cycle#prorations). When creating a subscription, valid values are ‘create_prorations` or `none`.

When updating a subscription, valid values are ‘create_prorations`, `none`, or `always_invoice`.

Passing ‘create_prorations` will cause proration invoice items to be created when applicable. These proration items will only be invoiced immediately under [certain conditions](docs.stripe.com/subscriptions/upgrading-downgrading#immediate-payment). In order to always invoice immediately for prorations, pass `always_invoice`.

Prorations can be disabled by passing ‘none`.



1356
1357
1358
# File 'lib/stripe/params/quote_update_params.rb', line 1356

def proration_behavior
  @proration_behavior
end