Class: Stripe::QuoteUpdateParams::SubscriptionDataOverride::AppliesTo

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(new_reference: nil, subscription_schedule: nil, type: nil) ⇒ AppliesTo

Returns a new instance of AppliesTo.



886
887
888
889
890
# File 'lib/stripe/params/quote_update_params.rb', line 886

def initialize(new_reference: nil, subscription_schedule: nil, type: nil)
  @new_reference = new_reference
  @subscription_schedule = subscription_schedule
  @type = type
end

Instance Attribute Details

#new_referenceObject

A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same new_reference field will be applied to the creation of a new subscription schedule.



880
881
882
# File 'lib/stripe/params/quote_update_params.rb', line 880

def new_reference
  @new_reference
end

#subscription_scheduleObject

The ID of the schedule the line applies to.



882
883
884
# File 'lib/stripe/params/quote_update_params.rb', line 882

def subscription_schedule
  @subscription_schedule
end

#typeObject

Describes whether the quote line is affecting a new schedule or an existing schedule.



884
885
886
# File 'lib/stripe/params/quote_update_params.rb', line 884

def type
  @type
end