Class: Stripe::QuoteUpdateParams::SubscriptionDataOverride::AppliesTo
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::SubscriptionDataOverride::AppliesTo
- Defined in:
- lib/stripe/params/quote_update_params.rb
Instance Attribute Summary collapse
-
#new_reference ⇒ Object
A custom string that identifies a new subscription schedule being created upon quote acceptance.
-
#subscription_schedule ⇒ Object
The ID of the schedule the line applies to.
-
#type ⇒ Object
Describes whether the quote line is affecting a new schedule or an existing schedule.
Instance Method Summary collapse
-
#initialize(new_reference: nil, subscription_schedule: nil, type: nil) ⇒ AppliesTo
constructor
A new instance of AppliesTo.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(new_reference: nil, subscription_schedule: nil, type: nil) ⇒ AppliesTo
Returns a new instance of AppliesTo.
1163 1164 1165 1166 1167 |
# File 'lib/stripe/params/quote_update_params.rb', line 1163 def initialize(new_reference: nil, subscription_schedule: nil, type: nil) @new_reference = new_reference @subscription_schedule = subscription_schedule @type = type end |
Instance Attribute Details
#new_reference ⇒ Object
A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same ‘new_reference` field will be applied to the creation of a new subscription schedule.
1157 1158 1159 |
# File 'lib/stripe/params/quote_update_params.rb', line 1157 def new_reference @new_reference end |
#subscription_schedule ⇒ Object
The ID of the schedule the line applies to.
1159 1160 1161 |
# File 'lib/stripe/params/quote_update_params.rb', line 1159 def subscription_schedule @subscription_schedule end |
#type ⇒ Object
Describes whether the quote line is affecting a new schedule or an existing schedule.
1161 1162 1163 |
# File 'lib/stripe/params/quote_update_params.rb', line 1161 def type @type end |