Class: Stripe::QuoteUpdateParams::SubscriptionDataOverride::AppliesTo

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(new_reference: nil, subscription_schedule: nil, type: nil) ⇒ AppliesTo

Returns a new instance of AppliesTo.



1153
1154
1155
1156
1157
# File 'lib/stripe/params/quote_update_params.rb', line 1153

def initialize(new_reference: nil, subscription_schedule: nil, type: nil)
  @new_reference = new_reference
  @subscription_schedule = subscription_schedule
  @type = type
end

Instance Attribute Details

#new_referenceObject

A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same ‘new_reference` field will be applied to the creation of a new subscription schedule.



1147
1148
1149
# File 'lib/stripe/params/quote_update_params.rb', line 1147

def new_reference
  @new_reference
end

#subscription_scheduleObject

The ID of the schedule the line applies to.



1149
1150
1151
# File 'lib/stripe/params/quote_update_params.rb', line 1149

def subscription_schedule
  @subscription_schedule
end

#typeObject

Describes whether the quote line is affecting a new schedule or an existing schedule.



1151
1152
1153
# File 'lib/stripe/params/quote_update_params.rb', line 1151

def type
  @type
end