Class: Stripe::QuoteUpdateParams::SubscriptionDataOverride::AppliesTo

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(new_reference: nil, subscription_schedule: nil, type: nil) ⇒ AppliesTo

Returns a new instance of AppliesTo.



957
958
959
960
961
# File 'lib/stripe/params/quote_update_params.rb', line 957

def initialize(new_reference: nil, subscription_schedule: nil, type: nil)
  @new_reference = new_reference
  @subscription_schedule = subscription_schedule
  @type = type
end

Instance Attribute Details

#new_referenceObject

A custom string that identifies a new subscription schedule being created upon quote acceptance. All quote lines with the same ‘new_reference` field will be applied to the creation of a new subscription schedule.



951
952
953
# File 'lib/stripe/params/quote_update_params.rb', line 951

def new_reference
  @new_reference
end

#subscription_scheduleObject

The ID of the schedule the line applies to.



953
954
955
# File 'lib/stripe/params/quote_update_params.rb', line 953

def subscription_schedule
  @subscription_schedule
end

#typeObject

Describes whether the quote line is affecting a new schedule or an existing schedule.



955
956
957
# File 'lib/stripe/params/quote_update_params.rb', line 955

def type
  @type
end