Class: Stripe::QuoteUpdateParams::SubscriptionDataOverride::BillOnAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: BillFrom, BillUntil

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bill_from: nil, bill_until: nil) ⇒ BillOnAcceptance

Returns a new instance of BillOnAcceptance.



920
921
922
923
# File 'lib/stripe/params/quote_update_params.rb', line 920

def initialize(bill_from: nil, bill_until: nil)
  @bill_from = bill_from
  @bill_until = bill_until
end

Instance Attribute Details

#bill_fromObject

The start of the period to bill from when the Quote is accepted.



916
917
918
# File 'lib/stripe/params/quote_update_params.rb', line 916

def bill_from
  @bill_from
end

#bill_untilObject

The end of the period to bill until when the Quote is accepted.



918
919
920
# File 'lib/stripe/params/quote_update_params.rb', line 918

def bill_until
  @bill_until
end