Class: Stripe::QuoteUpdateParams::SubscriptionDataOverride::BillOnAcceptance::BillFrom::LineStartsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineStartsAt

Returns a new instance of LineStartsAt.



874
875
876
877
# File 'lib/stripe/params/quote_update_params.rb', line 874

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



870
871
872
# File 'lib/stripe/params/quote_update_params.rb', line 870

def id
  @id
end

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



872
873
874
# File 'lib/stripe/params/quote_update_params.rb', line 872

def index
  @index
end