Class: Stripe::QuoteUpdateParams::SubscriptionDataOverride::BillOnAcceptance::BillFrom::LineStartsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineStartsAt

Returns a new instance of LineStartsAt.



1168
1169
1170
1171
# File 'lib/stripe/params/quote_update_params.rb', line 1168

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



1164
1165
1166
# File 'lib/stripe/params/quote_update_params.rb', line 1164

def id
  @id
end

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



1166
1167
1168
# File 'lib/stripe/params/quote_update_params.rb', line 1166

def index
  @index
end