Class: Stripe::QuoteUpdateParams::SubscriptionDataOverride::BillingSchedule

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: AppliesTo, BillFrom, BillUntil

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(applies_to: nil, bill_from: nil, bill_until: nil, key: nil) ⇒ BillingSchedule

Returns a new instance of BillingSchedule.



1326
1327
1328
1329
1330
1331
# File 'lib/stripe/params/quote_update_params.rb', line 1326

def initialize(applies_to: nil, bill_from: nil, bill_until: nil, key: nil)
  @applies_to = applies_to
  @bill_from = bill_from
  @bill_until = bill_until
  @key = key
end

Instance Attribute Details

#applies_toObject

Configure billing schedule differently for individual subscription items.



1318
1319
1320
# File 'lib/stripe/params/quote_update_params.rb', line 1318

def applies_to
  @applies_to
end

#bill_fromObject

The start of the period to bill from when the Quote is accepted.



1320
1321
1322
# File 'lib/stripe/params/quote_update_params.rb', line 1320

def bill_from
  @bill_from
end

#bill_untilObject

The end of the period to bill until when the Quote is accepted.



1322
1323
1324
# File 'lib/stripe/params/quote_update_params.rb', line 1322

def bill_until
  @bill_until
end

#keyObject

Specify a key for the billing schedule. Must be unique to this field, alphanumeric, and up to 200 characters. If not provided, a unique key will be generated.



1324
1325
1326
# File 'lib/stripe/params/quote_update_params.rb', line 1324

def key
  @key
end