Class: Stripe::QuoteUpdateParams::SubscriptionDataOverride::BillingSchedule

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Defined Under Namespace

Classes: AppliesTo, BillFrom, BillUntil

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(applies_to: nil, bill_from: nil, bill_until: nil, key: nil) ⇒ BillingSchedule

Returns a new instance of BillingSchedule.



1130
1131
1132
1133
1134
1135
# File 'lib/stripe/params/quote_update_params.rb', line 1130

def initialize(applies_to: nil, bill_from: nil, bill_until: nil, key: nil)
  @applies_to = applies_to
  @bill_from = bill_from
  @bill_until = bill_until
  @key = key
end

Instance Attribute Details

#applies_toObject

Configure billing schedule differently for individual subscription items.



1122
1123
1124
# File 'lib/stripe/params/quote_update_params.rb', line 1122

def applies_to
  @applies_to
end

#bill_fromObject

The start of the period to bill from when the Quote is accepted.



1124
1125
1126
# File 'lib/stripe/params/quote_update_params.rb', line 1124

def bill_from
  @bill_from
end

#bill_untilObject

The end of the period to bill until when the Quote is accepted.



1126
1127
1128
# File 'lib/stripe/params/quote_update_params.rb', line 1126

def bill_until
  @bill_until
end

#keyObject

Specify a key for the billing schedule. Must be unique to this field, alphanumeric, and up to 200 characters. If not provided, a unique key will be generated.



1128
1129
1130
# File 'lib/stripe/params/quote_update_params.rb', line 1128

def key
  @key
end