Class: Stripe::QuoteUpdateParams::SubscriptionDataOverride::BillingSchedule::BillFrom::LineStartsAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/quote_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, index: nil) ⇒ LineStartsAt

Returns a new instance of LineStartsAt.



1050
1051
1052
1053
# File 'lib/stripe/params/quote_update_params.rb', line 1050

def initialize(id: nil, index: nil)
  @id = id
  @index = index
end

Instance Attribute Details

#idObject

The ID of a quote line.



1046
1047
1048
# File 'lib/stripe/params/quote_update_params.rb', line 1046

def id
  @id
end

#indexObject

The position of the previous quote line in the ‘lines` array after which this line should begin. Indexes start from 0 and must be less than the index of the current line in the array.



1048
1049
1050
# File 'lib/stripe/params/quote_update_params.rb', line 1048

def index
  @index
end