Class: Stripe::QuoteUpdateParams::SubscriptionDataOverride::BillingSchedule::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::SubscriptionDataOverride::BillingSchedule::BillUntil
- Defined in:
- lib/stripe/params/quote_update_params.rb
Defined Under Namespace
Classes: Duration, LineEndsAt
Instance Attribute Summary collapse
-
#duration ⇒ Object
Details of the duration over which to bill.
-
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
-
#timestamp ⇒ Object
A precise Unix timestamp.
-
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
Instance Method Summary collapse
-
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
1102 1103 1104 1105 1106 1107 |
# File 'lib/stripe/params/quote_update_params.rb', line 1102 def initialize(duration: nil, line_ends_at: nil, timestamp: nil, type: nil) @duration = duration @line_ends_at = line_ends_at @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Details of the duration over which to bill.
1094 1095 1096 |
# File 'lib/stripe/params/quote_update_params.rb', line 1094 def duration @duration end |
#line_ends_at ⇒ Object
Details of a Quote line item from which to bill until.
1096 1097 1098 |
# File 'lib/stripe/params/quote_update_params.rb', line 1096 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object
A precise Unix timestamp.
1098 1099 1100 |
# File 'lib/stripe/params/quote_update_params.rb', line 1098 def @timestamp end |
#type ⇒ Object
The type of method to specify the ‘bill_until` time.
1100 1101 1102 |
# File 'lib/stripe/params/quote_update_params.rb', line 1100 def type @type end |