Class: Stripe::QuoteUpdateParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::QuoteUpdateParams::TransferData
- Defined in:
- lib/stripe/params/quote_update_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when the invoice is paid.
-
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_percent: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_percent: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
217 218 219 220 221 |
# File 'lib/stripe/params/quote_update_params.rb', line 217 def initialize(amount: nil, amount_percent: nil, destination: nil) @amount = amount @amount_percent = amount_percent @destination = destination end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.
211 212 213 |
# File 'lib/stripe/params/quote_update_params.rb', line 211 def amount @amount end |
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination. There must be at least 1 line item with a recurring price to use this field.
213 214 215 |
# File 'lib/stripe/params/quote_update_params.rb', line 213 def amount_percent @amount_percent end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
215 216 217 |
# File 'lib/stripe/params/quote_update_params.rb', line 215 def destination @destination end |