Class: Stripe::Radar::AccountEvaluation
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Radar::AccountEvaluation
- Extended by:
- APIOperations::Create
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/radar/account_evaluation.rb
Overview
Account Evaluation resource returned by the Radar Account Evaluations API.
Defined Under Namespace
Constant Summary collapse
- OBJECT_NAME =
"radar.account_evaluation"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created_at ⇒ Object
readonly
Time at which the object was created.
-
#customer ⇒ Object
readonly
The ID of the Stripe customer the account evaluation is associated with.
-
#events ⇒ Object
readonly
The list of events that were reported for this Account Evaluation object via the report API.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#signals ⇒ Object
readonly
A hash of signal objects providing Radar’s evaluation for the lifecycle event.
-
#type ⇒ Object
readonly
The type of evaluation returned, based on the user’s request.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a new AccountEvaluation object.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
- .object_name ⇒ Object
-
.update(account_evaluation, params = {}, opts = {}) ⇒ Object
Reports an event on an AccountEvaluation object.
Methods included from APIOperations::Create
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created_at ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
135 136 137 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 135 def created_at @created_at end |
#customer ⇒ Object (readonly)
The ID of the Stripe customer the account evaluation is associated with.
137 138 139 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 137 def customer @customer end |
#events ⇒ Object (readonly)
The list of events that were reported for this Account Evaluation object via the report API.
139 140 141 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 139 def events @events end |
#id ⇒ Object (readonly)
Unique identifier for the object.
141 142 143 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 141 def id @id end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
143 144 145 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 143 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
145 146 147 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 145 def object @object end |
#signals ⇒ Object (readonly)
A hash of signal objects providing Radar’s evaluation for the lifecycle event.
147 148 149 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 147 def signals @signals end |
#type ⇒ Object (readonly)
The type of evaluation returned, based on the user’s request.
149 150 151 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 149 def type @type end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a new AccountEvaluation object.
152 153 154 155 156 157 158 159 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 152 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/radar/account_evaluations", params: params, opts: opts ) end |
.field_remappings ⇒ Object
175 176 177 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 175 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
171 172 173 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 171 def self.inner_class_types @inner_class_types = { events: Event, signals: Signals } end |
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 12 def self.object_name "radar.account_evaluation" end |
.update(account_evaluation, params = {}, opts = {}) ⇒ Object
Reports an event on an AccountEvaluation object.
162 163 164 165 166 167 168 169 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 162 def self.update(account_evaluation, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/radar/account_evaluations/%<account_evaluation>s/report_event", { account_evaluation: CGI.escape(account_evaluation) }), params: params, opts: opts ) end |