Class: Stripe::Radar::AccountEvaluation
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Radar::AccountEvaluation
- Extended by:
- APIOperations::Create
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/radar/account_evaluation.rb
Overview
Account Evaluation resource returned by the Radar Account Evaluations API.
Defined Under Namespace
Constant Summary collapse
- OBJECT_NAME =
"radar.account_evaluation"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created_at ⇒ Object
readonly
Time at which the object was created.
-
#customer ⇒ Object
readonly
The ID of the Stripe customer the account evaluation is associated with.
-
#events ⇒ Object
readonly
The list of events that were reported for this Account Evaluation object via the report API.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#signals ⇒ Object
readonly
A hash of signal objects providing Radar’s evaluation for the lifecycle event.
-
#type ⇒ Object
readonly
The type of evaluation returned, based on the user’s request.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a new AccountEvaluation object.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
- .object_name ⇒ Object
-
.update(account_evaluation, params = {}, opts = {}) ⇒ Object
Reports an event on an AccountEvaluation object.
Methods included from APIOperations::Create
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created_at ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
100 101 102 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 100 def created_at @created_at end |
#customer ⇒ Object (readonly)
The ID of the Stripe customer the account evaluation is associated with.
102 103 104 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 102 def customer @customer end |
#events ⇒ Object (readonly)
The list of events that were reported for this Account Evaluation object via the report API.
104 105 106 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 104 def events @events end |
#id ⇒ Object (readonly)
Unique identifier for the object.
106 107 108 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 106 def id @id end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
108 109 110 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 108 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
110 111 112 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 110 def object @object end |
#signals ⇒ Object (readonly)
A hash of signal objects providing Radar’s evaluation for the lifecycle event.
112 113 114 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 112 def signals @signals end |
#type ⇒ Object (readonly)
The type of evaluation returned, based on the user’s request.
114 115 116 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 114 def type @type end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a new AccountEvaluation object.
117 118 119 120 121 122 123 124 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 117 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/radar/account_evaluations", params: params, opts: opts ) end |
.field_remappings ⇒ Object
140 141 142 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 140 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
136 137 138 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 136 def self.inner_class_types @inner_class_types = { events: Event, signals: Signals } end |
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 12 def self.object_name "radar.account_evaluation" end |
.update(account_evaluation, params = {}, opts = {}) ⇒ Object
Reports an event on an AccountEvaluation object.
127 128 129 130 131 132 133 134 |
# File 'lib/stripe/resources/radar/account_evaluation.rb', line 127 def self.update(account_evaluation, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/radar/account_evaluations/%<account_evaluation>s/report_event", { account_evaluation: CGI.escape(account_evaluation) }), params: params, opts: opts ) end |