Class: Stripe::Radar::AccountEvaluationUpdateParams
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Radar::AccountEvaluationUpdateParams
- Defined in:
- lib/stripe/params/radar/account_evaluation_update_params.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#type ⇒ Object
The type of event to report.
Instance Method Summary collapse
-
#initialize(expand: nil, type: nil) ⇒ AccountEvaluationUpdateParams
constructor
A new instance of AccountEvaluationUpdateParams.
Methods inherited from Stripe::RequestParams
Constructor Details
#initialize(expand: nil, type: nil) ⇒ AccountEvaluationUpdateParams
Returns a new instance of AccountEvaluationUpdateParams.
12 13 14 15 |
# File 'lib/stripe/params/radar/account_evaluation_update_params.rb', line 12 def initialize(expand: nil, type: nil) @expand = @type = type end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
8 9 10 |
# File 'lib/stripe/params/radar/account_evaluation_update_params.rb', line 8 def @expand end |
#type ⇒ Object
The type of event to report.
10 11 12 |
# File 'lib/stripe/params/radar/account_evaluation_update_params.rb', line 10 def type @type end |