Class: Stripe::Radar::CustomerEvaluationUpdateParams
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Radar::CustomerEvaluationUpdateParams
- Defined in:
- lib/stripe/params/radar/customer_evaluation_update_params.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of a Customer to attach to an entity-less registration evaluation.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#status ⇒ Object
The outcome status of the evaluation: allowed, restricted, or blocked.
Instance Method Summary collapse
-
#initialize(customer: nil, expand: nil, status: nil) ⇒ CustomerEvaluationUpdateParams
constructor
A new instance of CustomerEvaluationUpdateParams.
Methods inherited from Stripe::RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(customer: nil, expand: nil, status: nil) ⇒ CustomerEvaluationUpdateParams
Returns a new instance of CustomerEvaluationUpdateParams.
14 15 16 17 18 |
# File 'lib/stripe/params/radar/customer_evaluation_update_params.rb', line 14 def initialize(customer: nil, expand: nil, status: nil) @customer = customer @expand = @status = status end |
Instance Attribute Details
#customer ⇒ Object
The ID of a Customer to attach to an entity-less registration evaluation.
8 9 10 |
# File 'lib/stripe/params/radar/customer_evaluation_update_params.rb', line 8 def customer @customer end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
10 11 12 |
# File 'lib/stripe/params/radar/customer_evaluation_update_params.rb', line 10 def @expand end |
#status ⇒ Object
The outcome status of the evaluation: allowed, restricted, or blocked.
12 13 14 |
# File 'lib/stripe/params/radar/customer_evaluation_update_params.rb', line 12 def status @status end |