Class: Stripe::Radar::CustomerEvaluationUpdateParams
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Radar::CustomerEvaluationUpdateParams
- Defined in:
- lib/stripe/params/radar/customer_evaluation_update_params.rb
Defined Under Namespace
Classes: LoginFailed, RegistrationFailed, RegistrationSuccess
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of a Customer to attach to an entity-less registration evaluation.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#login_failed ⇒ Object
Data for a failed login event.
-
#registration_failed ⇒ Object
Data for a failed registration event.
-
#registration_success ⇒ Object
Data for a successful registration event.
-
#status ⇒ Object
The outcome status of the evaluation: allowed, restricted, or blocked.
-
#type ⇒ Object
The type of event to report on the customer evaluation.
Instance Method Summary collapse
-
#initialize(customer: nil, expand: nil, login_failed: nil, registration_failed: nil, registration_success: nil, status: nil, type: nil) ⇒ CustomerEvaluationUpdateParams
constructor
A new instance of CustomerEvaluationUpdateParams.
Methods inherited from Stripe::RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(customer: nil, expand: nil, login_failed: nil, registration_failed: nil, registration_success: nil, status: nil, type: nil) ⇒ CustomerEvaluationUpdateParams
Returns a new instance of CustomerEvaluationUpdateParams.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/stripe/params/radar/customer_evaluation_update_params.rb', line 48 def initialize( customer: nil, expand: nil, login_failed: nil, registration_failed: nil, registration_success: nil, status: nil, type: nil ) @customer = customer @expand = @login_failed = login_failed @registration_failed = registration_failed @registration_success = registration_success @status = status @type = type end |
Instance Attribute Details
#customer ⇒ Object
The ID of a Customer to attach to an entity-less registration evaluation.
34 35 36 |
# File 'lib/stripe/params/radar/customer_evaluation_update_params.rb', line 34 def customer @customer end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
36 37 38 |
# File 'lib/stripe/params/radar/customer_evaluation_update_params.rb', line 36 def @expand end |
#login_failed ⇒ Object
Data for a failed login event.
38 39 40 |
# File 'lib/stripe/params/radar/customer_evaluation_update_params.rb', line 38 def login_failed @login_failed end |
#registration_failed ⇒ Object
Data for a failed registration event.
40 41 42 |
# File 'lib/stripe/params/radar/customer_evaluation_update_params.rb', line 40 def registration_failed @registration_failed end |
#registration_success ⇒ Object
Data for a successful registration event.
42 43 44 |
# File 'lib/stripe/params/radar/customer_evaluation_update_params.rb', line 42 def registration_success @registration_success end |
#status ⇒ Object
The outcome status of the evaluation: allowed, restricted, or blocked.
44 45 46 |
# File 'lib/stripe/params/radar/customer_evaluation_update_params.rb', line 44 def status @status end |
#type ⇒ Object
The type of event to report on the customer evaluation.
46 47 48 |
# File 'lib/stripe/params/radar/customer_evaluation_update_params.rb', line 46 def type @type end |