Class: Stripe::Radar::EarlyFraudWarning::ListParams

Inherits:
Stripe::RequestParams show all
Defined in:
lib/stripe/resources/radar/early_fraud_warning.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

#to_h

Constructor Details

#initialize(charge: nil, created: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/stripe/resources/radar/early_fraud_warning.rb', line 60

def initialize(
  charge: nil,
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  payment_intent: nil,
  starting_after: nil
)
  @charge = charge
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @payment_intent = payment_intent
  @starting_after = starting_after
end

Instance Attribute Details

#chargeObject

Only return early fraud warnings for the charge specified by this charge ID.



40
41
42
# File 'lib/stripe/resources/radar/early_fraud_warning.rb', line 40

def charge
  @charge
end

#createdObject

Only return early fraud warnings that were created during the given date interval.



43
44
45
# File 'lib/stripe/resources/radar/early_fraud_warning.rb', line 43

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



46
47
48
# File 'lib/stripe/resources/radar/early_fraud_warning.rb', line 46

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



49
50
51
# File 'lib/stripe/resources/radar/early_fraud_warning.rb', line 49

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



52
53
54
# File 'lib/stripe/resources/radar/early_fraud_warning.rb', line 52

def limit
  @limit
end

#payment_intentObject

Only return early fraud warnings for charges that were created by the PaymentIntent specified by this PaymentIntent ID.



55
56
57
# File 'lib/stripe/resources/radar/early_fraud_warning.rb', line 55

def payment_intent
  @payment_intent
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



58
59
60
# File 'lib/stripe/resources/radar/early_fraud_warning.rb', line 58

def starting_after
  @starting_after
end