Class: Stripe::Radar::PaymentEvaluation
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Radar::PaymentEvaluation
- Extended by:
- APIOperations::Create
- Defined in:
- lib/stripe/resources/radar/payment_evaluation.rb
Overview
Payment Evaluations represent the risk lifecycle of an externally processed payment. It includes the Radar risk score from Stripe, payment outcome taken by the merchant or processor, and any post transaction events, such as refunds or disputes. See the Radar API guide for integration steps.
Defined Under Namespace
Classes: ClientDeviceMetadataDetails, CustomerDetails, Event, Outcome, PaymentDetails, Signals
Constant Summary collapse
- OBJECT_NAME =
"radar.payment_evaluation"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#client_device_metadata_details ⇒ Object
readonly
Client device metadata attached to this payment evaluation.
-
#created_at ⇒ Object
readonly
Time at which the object was created.
-
#customer_details ⇒ Object
readonly
Customer details attached to this payment evaluation.
-
#events ⇒ Object
readonly
Event information associated with the payment evaluation, such as refunds, dispute, early fraud warnings, or user interventions.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is
true. -
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object's type.
-
#outcome ⇒ Object
readonly
Indicates the final outcome for the payment evaluation.
-
#payment_details ⇒ Object
readonly
Payment details attached to this payment evaluation.
-
#recommended_action ⇒ Object
readonly
Recommended action based on the score of the
fraudulent_paymentsignal. -
#signals ⇒ Object
readonly
Collection of signals for this payment evaluation.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Request a Radar API fraud risk score from Stripe for a payment before sending it for external processor authorization.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
- .object_name ⇒ Object
Methods included from APIOperations::Create
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#client_device_metadata_details ⇒ Object (readonly)
Client device metadata attached to this payment evaluation.
490 491 492 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 490 def @client_device_metadata_details end |
#created_at ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
492 493 494 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 492 def created_at @created_at end |
#customer_details ⇒ Object (readonly)
Customer details attached to this payment evaluation.
494 495 496 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 494 def customer_details @customer_details end |
#events ⇒ Object (readonly)
Event information associated with the payment evaluation, such as refunds, dispute, early fraud warnings, or user interventions.
496 497 498 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 496 def events @events end |
#id ⇒ Object (readonly)
Unique identifier for the object.
498 499 500 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 498 def id @id end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.
500 501 502 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 500 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
502 503 504 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 502 def @metadata end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value.
504 505 506 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 504 def object @object end |
#outcome ⇒ Object (readonly)
Indicates the final outcome for the payment evaluation.
506 507 508 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 506 def outcome @outcome end |
#payment_details ⇒ Object (readonly)
Payment details attached to this payment evaluation.
508 509 510 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 508 def payment_details @payment_details end |
#recommended_action ⇒ Object (readonly)
Recommended action based on the score of the fraudulent_payment signal. Possible values are block, continue and request_three_d_secure.
510 511 512 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 510 def recommended_action @recommended_action end |
#signals ⇒ Object (readonly)
Collection of signals for this payment evaluation.
512 513 514 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 512 def signals @signals end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Request a Radar API fraud risk score from Stripe for a payment before sending it for external processor authorization.
515 516 517 518 519 520 521 522 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 515 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/radar/payment_evaluations", params: params, opts: opts ) end |
.field_remappings ⇒ Object
535 536 537 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 535 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
524 525 526 527 528 529 530 531 532 533 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 524 def self.inner_class_types @inner_class_types = { client_device_metadata_details: ClientDeviceMetadataDetails, customer_details: CustomerDetails, events: Event, outcome: Outcome, payment_details: PaymentDetails, signals: Signals, } end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 11 def self.object_name "radar.payment_evaluation" end |