Class: Stripe::Radar::PaymentEvaluation
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Radar::PaymentEvaluation
- Extended by:
- APIOperations::Create
- Defined in:
- lib/stripe/resources/radar/payment_evaluation.rb
Overview
Payment Evaluations represent the risk lifecycle of an externally processed payment. It includes the Radar risk score from Stripe, payment outcome taken by the merchant or processor, and any post transaction events, such as refunds or disputes. See the [Radar API guide](docs.stripe.com/radar/multiprocessor) for integration steps.
Defined Under Namespace
Classes: ClientDeviceMetadataDetails, CustomerDetails, Event, Outcome, PaymentDetails, Signals
Constant Summary collapse
- OBJECT_NAME =
"radar.payment_evaluation"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#client_device_metadata_details ⇒ Object
readonly
Client device metadata attached to this payment evaluation.
-
#created_at ⇒ Object
readonly
Time at which the object was created.
-
#customer_details ⇒ Object
readonly
Customer details attached to this payment evaluation.
-
#events ⇒ Object
readonly
Event information associated with the payment evaluation, such as refunds, dispute, early fraud warnings, or user interventions.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#outcome ⇒ Object
readonly
Indicates the final outcome for the payment evaluation.
-
#payment_details ⇒ Object
readonly
Payment details attached to this payment evaluation.
-
#recommended_action ⇒ Object
readonly
Recommended action based on the score of the ‘fraudulent_payment` signal.
-
#signals ⇒ Object
readonly
Collection of signals for this payment evaluation.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Request a Radar API fraud risk score from Stripe for a payment before sending it for external processor authorization.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
- .object_name ⇒ Object
Methods included from APIOperations::Create
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#client_device_metadata_details ⇒ Object (readonly)
Client device metadata attached to this payment evaluation.
447 448 449 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 447 def @client_device_metadata_details end |
#created_at ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
449 450 451 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 449 def created_at @created_at end |
#customer_details ⇒ Object (readonly)
Customer details attached to this payment evaluation.
451 452 453 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 451 def customer_details @customer_details end |
#events ⇒ Object (readonly)
Event information associated with the payment evaluation, such as refunds, dispute, early fraud warnings, or user interventions.
453 454 455 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 453 def events @events end |
#id ⇒ Object (readonly)
Unique identifier for the object.
455 456 457 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 455 def id @id end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
457 458 459 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 457 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
459 460 461 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 459 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
461 462 463 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 461 def object @object end |
#outcome ⇒ Object (readonly)
Indicates the final outcome for the payment evaluation.
463 464 465 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 463 def outcome @outcome end |
#payment_details ⇒ Object (readonly)
Payment details attached to this payment evaluation.
465 466 467 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 465 def payment_details @payment_details end |
#recommended_action ⇒ Object (readonly)
Recommended action based on the score of the ‘fraudulent_payment` signal. Possible values are `block` and `continue`.
467 468 469 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 467 def recommended_action @recommended_action end |
#signals ⇒ Object (readonly)
Collection of signals for this payment evaluation.
469 470 471 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 469 def signals @signals end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Request a Radar API fraud risk score from Stripe for a payment before sending it for external processor authorization.
472 473 474 475 476 477 478 479 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 472 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/radar/payment_evaluations", params: params, opts: opts ) end |
.field_remappings ⇒ Object
492 493 494 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 492 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
481 482 483 484 485 486 487 488 489 490 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 481 def self.inner_class_types @inner_class_types = { client_device_metadata_details: ClientDeviceMetadataDetails, customer_details: CustomerDetails, events: Event, outcome: Outcome, payment_details: PaymentDetails, signals: Signals, } end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 11 def self.object_name "radar.payment_evaluation" end |