Class: Stripe::Radar::PaymentEvaluation::CustomerDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Radar::PaymentEvaluation::CustomerDetails
- Defined in:
- lib/stripe/resources/radar/payment_evaluation.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#customer ⇒ Object
readonly
The ID of the customer associated with the payment evaluation.
-
#customer_account ⇒ Object
readonly
The ID of the Account representing the customer associated with the payment evaluation.
-
#email ⇒ Object
readonly
The customer’s email address.
-
#name ⇒ Object
readonly
The customer’s full name or business name.
-
#phone ⇒ Object
readonly
The customer’s phone number.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#customer ⇒ Object (readonly)
The ID of the customer associated with the payment evaluation.
30 31 32 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 30 def customer @customer end |
#customer_account ⇒ Object (readonly)
The ID of the Account representing the customer associated with the payment evaluation.
32 33 34 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 32 def customer_account @customer_account end |
#email ⇒ Object (readonly)
The customer’s email address.
34 35 36 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 34 def email @email end |
#name ⇒ Object (readonly)
The customer’s full name or business name.
36 37 38 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 36 def name @name end |
#phone ⇒ Object (readonly)
The customer’s phone number.
38 39 40 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 38 def phone @phone end |
Class Method Details
.field_remappings ⇒ Object
44 45 46 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 44 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
40 41 42 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 40 def self.inner_class_types @inner_class_types = {} end |