Class: Stripe::Radar::PaymentEvaluation::Event
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Radar::PaymentEvaluation::Event
- Defined in:
- lib/stripe/resources/radar/payment_evaluation.rb
Defined Under Namespace
Classes: DisputeOpened, EarlyFraudWarningReceived, Refunded, UserInterventionRaised, UserInterventionResolved
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#dispute_opened ⇒ Object
readonly
Dispute opened event details attached to this payment evaluation.
-
#early_fraud_warning_received ⇒ Object
readonly
Early Fraud Warning Received event details attached to this payment evaluation.
-
#occurred_at ⇒ Object
readonly
Timestamp when the event occurred.
-
#refunded ⇒ Object
readonly
Refunded Event details attached to this payment evaluation.
-
#type ⇒ Object
readonly
Indicates the type of event attached to the payment evaluation.
-
#user_intervention_raised ⇒ Object
readonly
User intervention raised event details attached to this payment evaluation.
-
#user_intervention_resolved ⇒ Object
readonly
User Intervention Resolved Event details attached to this payment evaluation.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#dispute_opened ⇒ Object (readonly)
Dispute opened event details attached to this payment evaluation.
141 142 143 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 141 def dispute_opened @dispute_opened end |
#early_fraud_warning_received ⇒ Object (readonly)
Early Fraud Warning Received event details attached to this payment evaluation.
143 144 145 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 143 def early_fraud_warning_received @early_fraud_warning_received end |
#occurred_at ⇒ Object (readonly)
Timestamp when the event occurred.
145 146 147 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 145 def occurred_at @occurred_at end |
#refunded ⇒ Object (readonly)
Refunded Event details attached to this payment evaluation.
147 148 149 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 147 def refunded @refunded end |
#type ⇒ Object (readonly)
Indicates the type of event attached to the payment evaluation.
149 150 151 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 149 def type @type end |
#user_intervention_raised ⇒ Object (readonly)
User intervention raised event details attached to this payment evaluation
151 152 153 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 151 def user_intervention_raised @user_intervention_raised end |
#user_intervention_resolved ⇒ Object (readonly)
User Intervention Resolved Event details attached to this payment evaluation
153 154 155 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 153 def user_intervention_resolved @user_intervention_resolved end |
Class Method Details
.field_remappings ⇒ Object
165 166 167 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 165 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
155 156 157 158 159 160 161 162 163 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 155 def self.inner_class_types @inner_class_types = { dispute_opened: DisputeOpened, early_fraud_warning_received: EarlyFraudWarningReceived, refunded: Refunded, user_intervention_raised: UserInterventionRaised, user_intervention_resolved: UserInterventionResolved, } end |