Class: Stripe::Radar::PaymentEvaluation::Outcome
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Radar::PaymentEvaluation::Outcome
- Defined in:
- lib/stripe/resources/radar/payment_evaluation.rb
Defined Under Namespace
Classes: MerchantBlocked, Rejected, Succeeded
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#merchant_blocked ⇒ Object
readonly
Details of a merchant_blocked outcome attached to this payment evaluation.
-
#payment_intent_id ⇒ Object
readonly
The PaymentIntent ID associated with the payment evaluation.
-
#rejected ⇒ Object
readonly
Details of an rejected outcome attached to this payment evaluation.
-
#succeeded ⇒ Object
readonly
Details of a succeeded outcome attached to this payment evaluation.
-
#type ⇒ Object
readonly
Indicates the outcome of the payment evaluation.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#merchant_blocked ⇒ Object (readonly)
Details of a merchant_blocked outcome attached to this payment evaluation.
244 245 246 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 244 def merchant_blocked @merchant_blocked end |
#payment_intent_id ⇒ Object (readonly)
The PaymentIntent ID associated with the payment evaluation.
246 247 248 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 246 def payment_intent_id @payment_intent_id end |
#rejected ⇒ Object (readonly)
Details of an rejected outcome attached to this payment evaluation.
248 249 250 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 248 def rejected @rejected end |
#succeeded ⇒ Object (readonly)
Details of a succeeded outcome attached to this payment evaluation.
250 251 252 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 250 def succeeded @succeeded end |
#type ⇒ Object (readonly)
Indicates the outcome of the payment evaluation.
252 253 254 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 252 def type @type end |
Class Method Details
.field_remappings ⇒ Object
262 263 264 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 262 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
254 255 256 257 258 259 260 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 254 def self.inner_class_types @inner_class_types = { merchant_blocked: MerchantBlocked, rejected: Rejected, succeeded: Succeeded, } end |