Class: Stripe::Radar::PaymentEvaluation::Outcome
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Radar::PaymentEvaluation::Outcome
- Defined in:
- lib/stripe/resources/radar/payment_evaluation.rb
Defined Under Namespace
Classes: MerchantBlocked, Rejected, Succeeded
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#merchant_blocked ⇒ Object
readonly
Details of a merchant_blocked outcome attached to this payment evaluation.
-
#payment_intent_id ⇒ Object
readonly
The PaymentIntent ID associated with the payment evaluation.
-
#rejected ⇒ Object
readonly
Details of an rejected outcome attached to this payment evaluation.
-
#succeeded ⇒ Object
readonly
Details of a succeeded outcome attached to this payment evaluation.
-
#type ⇒ Object
readonly
Indicates the outcome of the payment evaluation.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#merchant_blocked ⇒ Object (readonly)
Details of a merchant_blocked outcome attached to this payment evaluation.
293 294 295 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 293 def merchant_blocked @merchant_blocked end |
#payment_intent_id ⇒ Object (readonly)
The PaymentIntent ID associated with the payment evaluation.
295 296 297 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 295 def payment_intent_id @payment_intent_id end |
#rejected ⇒ Object (readonly)
Details of an rejected outcome attached to this payment evaluation.
297 298 299 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 297 def rejected @rejected end |
#succeeded ⇒ Object (readonly)
Details of a succeeded outcome attached to this payment evaluation.
299 300 301 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 299 def succeeded @succeeded end |
#type ⇒ Object (readonly)
Indicates the outcome of the payment evaluation.
301 302 303 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 301 def type @type end |
Class Method Details
.field_remappings ⇒ Object
311 312 313 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 311 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
303 304 305 306 307 308 309 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 303 def self.inner_class_types @inner_class_types = { merchant_blocked: MerchantBlocked, rejected: Rejected, succeeded: Succeeded, } end |