Class: Stripe::Radar::PaymentEvaluation::PaymentDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/radar/payment_evaluation.rb

Defined Under Namespace

Classes: MoneyMovementDetails, PaymentMethodDetails, ShippingDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount intended to be collected by this payment. A positive integer representing how much to charge in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge currency](docs.stripe.com/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).



420
421
422
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 420

def amount
  @amount
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



422
423
424
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 422

def currency
  @currency
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



424
425
426
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 424

def description
  @description
end

#money_movement_detailsObject (readonly)

Details about the payment’s customer presence and type.



426
427
428
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 426

def money_movement_details
  @money_movement_details
end

#payment_method_detailsObject (readonly)

Details about the payment method used for the payment.



428
429
430
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 428

def payment_method_details
  @payment_method_details
end

#shipping_detailsObject (readonly)

Shipping details for the payment evaluation.



430
431
432
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 430

def shipping_details
  @shipping_details
end

#statement_descriptorObject (readonly)

Payment statement descriptor.



432
433
434
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 432

def statement_descriptor
  @statement_descriptor
end

Class Method Details

.field_remappingsObject



442
443
444
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 442

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



434
435
436
437
438
439
440
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 434

def self.inner_class_types
  @inner_class_types = {
    money_movement_details: MoneyMovementDetails,
    payment_method_details: PaymentMethodDetails,
    shipping_details: ShippingDetails,
  }
end