Class: Stripe::Radar::PaymentEvaluation::Signals::FraudulentPayment
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Radar::PaymentEvaluation::Signals::FraudulentPayment
- Defined in:
- lib/stripe/resources/radar/payment_evaluation.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#evaluated_at ⇒ Object
readonly
The time when this signal was evaluated.
-
#risk_level ⇒ Object
readonly
Risk level of this signal, based on the score.
-
#score ⇒ Object
readonly
Score for this signal.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#evaluated_at ⇒ Object (readonly)
The time when this signal was evaluated.
421 422 423 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 421 def evaluated_at @evaluated_at end |
#risk_level ⇒ Object (readonly)
Risk level of this signal, based on the score.
423 424 425 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 423 def risk_level @risk_level end |
#score ⇒ Object (readonly)
Score for this signal. Possible values for evaluated payments are between 0 and 100. The value is returned with two decimal places and higher scores indicate a higher likelihood of the signal being true. A score of -1 is returned when a model evaluation was not performed, such as requests from incomplete integrations.
425 426 427 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 425 def score @score end |
Class Method Details
.field_remappings ⇒ Object
431 432 433 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 431 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
427 428 429 |
# File 'lib/stripe/resources/radar/payment_evaluation.rb', line 427 def self.inner_class_types @inner_class_types = {} end |