Class: Stripe::Radar::PaymentEvaluationCreateParams
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Radar::PaymentEvaluationCreateParams
- Defined in:
- lib/stripe/params/radar/payment_evaluation_create_params.rb
Defined Under Namespace
Classes: ClientDeviceMetadataDetails, CustomerDetails, PaymentDetails
Instance Attribute Summary collapse
-
#client_device_metadata_details ⇒ Object
Details about the Client Device Metadata to associate with the payment evaluation.
-
#customer_details ⇒ Object
Details about the customer associated with the payment evaluation.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#payment_details ⇒ Object
Details about the payment.
Instance Method Summary collapse
-
#initialize(client_device_metadata_details: nil, customer_details: nil, expand: nil, metadata: nil, payment_details: nil) ⇒ PaymentEvaluationCreateParams
constructor
A new instance of PaymentEvaluationCreateParams.
Methods inherited from Stripe::RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(client_device_metadata_details: nil, customer_details: nil, expand: nil, metadata: nil, payment_details: nil) ⇒ PaymentEvaluationCreateParams
Returns a new instance of PaymentEvaluationCreateParams.
208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 208 def initialize( client_device_metadata_details: nil, customer_details: nil, expand: nil, metadata: nil, payment_details: nil ) @client_device_metadata_details = @customer_details = customer_details @expand = @metadata = @payment_details = payment_details end |
Instance Attribute Details
#client_device_metadata_details ⇒ Object
Details about the Client Device Metadata to associate with the payment evaluation.
198 199 200 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 198 def @client_device_metadata_details end |
#customer_details ⇒ Object
Details about the customer associated with the payment evaluation.
200 201 202 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 200 def customer_details @customer_details end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
202 203 204 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 202 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
204 205 206 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 204 def @metadata end |
#payment_details ⇒ Object
Details about the payment.
206 207 208 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 206 def payment_details @payment_details end |