Class: Stripe::Radar::PaymentEvaluationCreateParams::CustomerDetails

Inherits:
Stripe::RequestParams show all
Defined in:
lib/stripe/params/radar/payment_evaluation_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(customer: nil, customer_account: nil, email: nil, name: nil, phone: nil) ⇒ CustomerDetails

Returns a new instance of CustomerDetails.



57
58
59
60
61
62
63
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 57

def initialize(customer: nil, customer_account: nil, email: nil, name: nil, phone: nil)
  @customer = customer
  @customer_account = 
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#customerObject

The ID of the customer associated with the payment evaluation.



47
48
49
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 47

def customer
  @customer
end

#customer_accountObject

The ID of the Account representing the customer associated with the payment evaluation.



49
50
51
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 49

def 
  @customer_account
end

#emailObject

The customer’s email address.



51
52
53
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 51

def email
  @email
end

#nameObject

The customer’s full name or business name.



53
54
55
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 53

def name
  @name
end

#phoneObject

The customer’s phone number.



55
56
57
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 55

def phone
  @phone
end