Class: Stripe::Radar::PaymentEvaluationCreateParams::PaymentDetails
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Radar::PaymentEvaluationCreateParams::PaymentDetails
- Defined in:
- lib/stripe/params/radar/payment_evaluation_create_params.rb
Defined Under Namespace
Classes: MoneyMovementDetails, PaymentMethodDetails, ShippingDetails
Instance Attribute Summary collapse
-
#amount ⇒ Object
The intended amount to collect with this payment.
-
#currency ⇒ Object
Three-letter ISO currency code, in lowercase.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#money_movement_details ⇒ Object
Details about the payment's customer presence and type.
-
#payment_method_details ⇒ Object
Details about the payment method to use for the payment.
-
#shipping_details ⇒ Object
Shipping details for the payment evaluation.
-
#statement_descriptor ⇒ Object
Payment statement descriptor.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, description: nil, money_movement_details: nil, payment_method_details: nil, shipping_details: nil, statement_descriptor: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from Stripe::RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, currency: nil, description: nil, money_movement_details: nil, payment_method_details: nil, shipping_details: nil, statement_descriptor: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 242 def initialize( amount: nil, currency: nil, description: nil, money_movement_details: nil, payment_method_details: nil, shipping_details: nil, statement_descriptor: nil ) @amount = amount @currency = currency @description = description @money_movement_details = money_movement_details @payment_method_details = payment_method_details @shipping_details = shipping_details @statement_descriptor = statement_descriptor end |
Instance Attribute Details
#amount ⇒ Object
The intended amount to collect with this payment. A positive integer representing how much to charge in the smallest currency unit (for example, 100 cents to charge 1.00 USD or 100 to charge 100 Yen, a zero-decimal currency).
228 229 230 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 228 def amount @amount end |
#currency ⇒ Object
Three-letter ISO currency code, in lowercase. Must be a supported currency.
230 231 232 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 230 def currency @currency end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
232 233 234 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 232 def description @description end |
#money_movement_details ⇒ Object
Details about the payment's customer presence and type.
234 235 236 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 234 def money_movement_details @money_movement_details end |
#payment_method_details ⇒ Object
Details about the payment method to use for the payment.
236 237 238 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 236 def payment_method_details @payment_method_details end |
#shipping_details ⇒ Object
Shipping details for the payment evaluation.
238 239 240 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 238 def shipping_details @shipping_details end |
#statement_descriptor ⇒ Object
Payment statement descriptor.
240 241 242 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 240 def statement_descriptor @statement_descriptor end |