Class: Stripe::Radar::PaymentEvaluationCreateParams::PaymentDetails

Inherits:
Stripe::RequestParams show all
Defined in:
lib/stripe/params/radar/payment_evaluation_create_params.rb

Defined Under Namespace

Classes: MoneyMovementDetails, PaymentMethodDetails, ShippingDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, currency: nil, description: nil, money_movement_details: nil, payment_method_details: nil, shipping_details: nil, statement_descriptor: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 208

def initialize(
  amount: nil,
  currency: nil,
  description: nil,
  money_movement_details: nil,
  payment_method_details: nil,
  shipping_details: nil,
  statement_descriptor: nil
)
  @amount = amount
  @currency = currency
  @description = description
  @money_movement_details = money_movement_details
  @payment_method_details = payment_method_details
  @shipping_details = shipping_details
  @statement_descriptor = statement_descriptor
end

Instance Attribute Details

#amountObject

The intended amount to collect with this payment. A positive integer representing how much to charge in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal) (for example, 100 cents to charge 1.00 USD or 100 to charge 100 Yen, a zero-decimal currency).



194
195
196
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 194

def amount
  @amount
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



196
197
198
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 196

def currency
  @currency
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



198
199
200
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 198

def description
  @description
end

#money_movement_detailsObject

Details about the payment’s customer presence and type.



200
201
202
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 200

def money_movement_details
  @money_movement_details
end

#payment_method_detailsObject

Details about the payment method to use for the payment.



202
203
204
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 202

def payment_method_details
  @payment_method_details
end

#shipping_detailsObject

Shipping details for the payment evaluation.



204
205
206
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 204

def shipping_details
  @shipping_details
end

#statement_descriptorObject

Payment statement descriptor.



206
207
208
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 206

def statement_descriptor
  @statement_descriptor
end