Class: Stripe::Radar::PaymentEvaluationCreateParams::PaymentDetails

Inherits:
Stripe::RequestParams show all
Defined in:
lib/stripe/params/radar/payment_evaluation_create_params.rb

Defined Under Namespace

Classes: MoneyMovementDetails, PaymentMethodDetails, ShippingDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, currency: nil, description: nil, money_movement_details: nil, payment_method_details: nil, shipping_details: nil, statement_descriptor: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 179

def initialize(
  amount: nil,
  currency: nil,
  description: nil,
  money_movement_details: nil,
  payment_method_details: nil,
  shipping_details: nil,
  statement_descriptor: nil
)
  @amount = amount
  @currency = currency
  @description = description
  @money_movement_details = money_movement_details
  @payment_method_details = payment_method_details
  @shipping_details = shipping_details
  @statement_descriptor = statement_descriptor
end

Instance Attribute Details

#amountObject

The intended amount to collect with this payment. A positive integer representing how much to charge in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal) (for example, 100 cents to charge 1.00 USD or 100 to charge 100 Yen, a zero-decimal currency).



165
166
167
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 165

def amount
  @amount
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



167
168
169
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 167

def currency
  @currency
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



169
170
171
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 169

def description
  @description
end

#money_movement_detailsObject

Details about the payment’s customer presence and type.



171
172
173
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 171

def money_movement_details
  @money_movement_details
end

#payment_method_detailsObject

Details about the payment method to use for the payment.



173
174
175
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 173

def payment_method_details
  @payment_method_details
end

#shipping_detailsObject

Shipping details for the payment evaluation.



175
176
177
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 175

def shipping_details
  @shipping_details
end

#statement_descriptorObject

Payment statement descriptor.



177
178
179
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 177

def statement_descriptor
  @statement_descriptor
end