Class: Stripe::Radar::PaymentEvaluationCreateParams::PaymentDetails::MoneyMovementDetails
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Radar::PaymentEvaluationCreateParams::PaymentDetails::MoneyMovementDetails
- Defined in:
- lib/stripe/params/radar/payment_evaluation_create_params.rb
Defined Under Namespace
Classes: Card
Instance Attribute Summary collapse
-
#card ⇒ Object
Describes card money movement details for the payment evaluation.
-
#money_movement_type ⇒ Object
Describes the type of money movement.
Instance Method Summary collapse
-
#initialize(card: nil, money_movement_type: nil) ⇒ MoneyMovementDetails
constructor
A new instance of MoneyMovementDetails.
Methods inherited from Stripe::RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(card: nil, money_movement_type: nil) ⇒ MoneyMovementDetails
Returns a new instance of MoneyMovementDetails.
55 56 57 58 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 55 def initialize(card: nil, money_movement_type: nil) @card = card @money_movement_type = money_movement_type end |
Instance Attribute Details
#card ⇒ Object
Describes card money movement details for the payment evaluation.
51 52 53 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 51 def card @card end |
#money_movement_type ⇒ Object
Describes the type of money movement. Currently only ‘card` is supported.
53 54 55 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 53 def money_movement_type @money_movement_type end |