Class: Stripe::Radar::PaymentEvaluationCreateParams::PaymentDetails::PaymentMethodDetails
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Radar::PaymentEvaluationCreateParams::PaymentDetails::PaymentMethodDetails
- Defined in:
- lib/stripe/params/radar/payment_evaluation_create_params.rb
Defined Under Namespace
Classes: BillingDetails
Instance Attribute Summary collapse
-
#billing_details ⇒ Object
Billing information associated with the payment evaluation.
-
#payment_method ⇒ Object
ID of the payment method used in this payment evaluation.
Instance Method Summary collapse
-
#initialize(billing_details: nil, payment_method: nil) ⇒ PaymentMethodDetails
constructor
A new instance of PaymentMethodDetails.
Methods inherited from Stripe::RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(billing_details: nil, payment_method: nil) ⇒ PaymentMethodDetails
Returns a new instance of PaymentMethodDetails.
114 115 116 117 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 114 def initialize(billing_details: nil, payment_method: nil) @billing_details = billing_details @payment_method = payment_method end |
Instance Attribute Details
#billing_details ⇒ Object
Billing information associated with the payment evaluation.
110 111 112 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 110 def billing_details @billing_details end |
#payment_method ⇒ Object
ID of the payment method used in this payment evaluation.
112 113 114 |
# File 'lib/stripe/params/radar/payment_evaluation_create_params.rb', line 112 def payment_method @payment_method end |