Class: Stripe::Radar::ValueList::CreateParams

Inherits:
Stripe::RequestParams show all
Defined in:
lib/stripe/resources/radar/value_list.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

#to_h

Constructor Details

#initialize(alias_: nil, expand: nil, item_type: nil, metadata: nil, name: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



130
131
132
133
134
135
136
# File 'lib/stripe/resources/radar/value_list.rb', line 130

def initialize(alias_: nil, expand: nil, item_type: nil, metadata: nil, name: nil)
  @alias = alias_
  @expand = expand
  @item_type = item_type
  @metadata = 
  @name = name
end

Instance Attribute Details

#aliasObject

The name of the value list for use in rules.



116
117
118
# File 'lib/stripe/resources/radar/value_list.rb', line 116

def alias
  @alias
end

#expandObject

Specifies which fields in the response should be expanded.



119
120
121
# File 'lib/stripe/resources/radar/value_list.rb', line 119

def expand
  @expand
end

#item_typeObject

Type of the items in the value list. One of ‘card_fingerprint`, `us_bank_account_fingerprint`, `sepa_debit_fingerprint`, `card_bin`, `email`, `ip_address`, `country`, `string`, `case_sensitive_string`, or `customer_id`. Use `string` if the item type is unknown or mixed.



122
123
124
# File 'lib/stripe/resources/radar/value_list.rb', line 122

def item_type
  @item_type
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



125
126
127
# File 'lib/stripe/resources/radar/value_list.rb', line 125

def 
  @metadata
end

#nameObject

The human-readable name of the value list.



128
129
130
# File 'lib/stripe/resources/radar/value_list.rb', line 128

def name
  @name
end