Class: Stripe::Radar::ValueListItemService::CreateParams
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Radar::ValueListItemService::CreateParams
- Defined in:
- lib/stripe/services/radar/value_list_item_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#value ⇒ Object
The value of the item (whose type must match the type of the parent value list).
-
#value_list ⇒ Object
The identifier of the value list which the created item will be added to.
Instance Method Summary collapse
-
#initialize(expand: nil, value: nil, value_list: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from Stripe::RequestParams
Constructor Details
#initialize(expand: nil, value: nil, value_list: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
79 80 81 82 83 |
# File 'lib/stripe/services/radar/value_list_item_service.rb', line 79 def initialize(expand: nil, value: nil, value_list: nil) @expand = @value = value @value_list = value_list end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
73 74 75 |
# File 'lib/stripe/services/radar/value_list_item_service.rb', line 73 def @expand end |
#value ⇒ Object
The value of the item (whose type must match the type of the parent value list).
75 76 77 |
# File 'lib/stripe/services/radar/value_list_item_service.rb', line 75 def value @value end |
#value_list ⇒ Object
The identifier of the value list which the created item will be added to.
77 78 79 |
# File 'lib/stripe/services/radar/value_list_item_service.rb', line 77 def value_list @value_list end |