Class: Stripe::Radar::ValueListItemService::CreateParams
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Radar::ValueListItemService::CreateParams
- Defined in:
- lib/stripe/services/radar/value_list_item_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#value ⇒ Object
The value of the item (whose type must match the type of the parent value list).
-
#value_list ⇒ Object
The identifier of the value list which the created item will be added to.
Instance Method Summary collapse
-
#initialize(expand: nil, value: nil, value_list: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from Stripe::RequestParams
Constructor Details
#initialize(expand: nil, value: nil, value_list: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
90 91 92 93 94 |
# File 'lib/stripe/services/radar/value_list_item_service.rb', line 90 def initialize(expand: nil, value: nil, value_list: nil) @expand = @value = value @value_list = value_list end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
82 83 84 |
# File 'lib/stripe/services/radar/value_list_item_service.rb', line 82 def @expand end |
#value ⇒ Object
The value of the item (whose type must match the type of the parent value list).
85 86 87 |
# File 'lib/stripe/services/radar/value_list_item_service.rb', line 85 def value @value end |
#value_list ⇒ Object
The identifier of the value list which the created item will be added to.
88 89 90 |
# File 'lib/stripe/services/radar/value_list_item_service.rb', line 88 def value_list @value_list end |