Class: Stripe::Radar::ValueListService::CreateParams
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Radar::ValueListService::CreateParams
- Defined in:
- lib/stripe/services/radar/value_list_service.rb
Instance Attribute Summary collapse
-
#alias ⇒ Object
The name of the value list for use in rules.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#item_type ⇒ Object
Type of the items in the value list.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The human-readable name of the value list.
Instance Method Summary collapse
-
#initialize(alias_: nil, expand: nil, item_type: nil, metadata: nil, name: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from Stripe::RequestParams
Constructor Details
#initialize(alias_: nil, expand: nil, item_type: nil, metadata: nil, name: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
101 102 103 104 105 106 107 |
# File 'lib/stripe/services/radar/value_list_service.rb', line 101 def initialize(alias_: nil, expand: nil, item_type: nil, metadata: nil, name: nil) @alias = alias_ @expand = @item_type = item_type @metadata = @name = name end |
Instance Attribute Details
#alias ⇒ Object
The name of the value list for use in rules.
91 92 93 |
# File 'lib/stripe/services/radar/value_list_service.rb', line 91 def alias @alias end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
93 94 95 |
# File 'lib/stripe/services/radar/value_list_service.rb', line 93 def @expand end |
#item_type ⇒ Object
Type of the items in the value list. One of ‘card_fingerprint`, `us_bank_account_fingerprint`, `sepa_debit_fingerprint`, `card_bin`, `email`, `ip_address`, `country`, `string`, `case_sensitive_string`, or `customer_id`. Use `string` if the item type is unknown or mixed.
95 96 97 |
# File 'lib/stripe/services/radar/value_list_service.rb', line 95 def item_type @item_type end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
97 98 99 |
# File 'lib/stripe/services/radar/value_list_service.rb', line 97 def @metadata end |
#name ⇒ Object
The human-readable name of the value list.
99 100 101 |
# File 'lib/stripe/services/radar/value_list_service.rb', line 99 def name @name end |