Class: Stripe::Refund

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/refund.rb

Overview

Refund objects allow you to refund a previously created charge that isn’t refunded yet. Funds are refunded to the credit or debit card that’s initially charged.

Related guide: [Refunds](stripe.com/docs/refunds)

Defined Under Namespace

Classes: DestinationDetails, NextAction, PresentmentDetails, TestHelpers

Constant Summary collapse

OBJECT_NAME =
"refund"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount, in cents (or local equivalent).



612
613
614
# File 'lib/stripe/resources/refund.rb', line 612

def amount
  @amount
end

#balance_transactionObject (readonly)

Balance transaction that describes the impact on your account balance.



614
615
616
# File 'lib/stripe/resources/refund.rb', line 614

def balance_transaction
  @balance_transaction
end

#chargeObject (readonly)

ID of the charge that’s refunded.



616
617
618
# File 'lib/stripe/resources/refund.rb', line 616

def charge
  @charge
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



618
619
620
# File 'lib/stripe/resources/refund.rb', line 618

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



620
621
622
# File 'lib/stripe/resources/refund.rb', line 620

def currency
  @currency
end

#descriptionObject (readonly)

An arbitrary string attached to the object. You can use this for displaying to users (available on non-card refunds only).



622
623
624
# File 'lib/stripe/resources/refund.rb', line 622

def description
  @description
end

#destination_detailsObject (readonly)

Attribute for field destination_details



624
625
626
# File 'lib/stripe/resources/refund.rb', line 624

def destination_details
  @destination_details
end

#failure_balance_transactionObject (readonly)

After the refund fails, this balance transaction describes the adjustment made on your account balance that reverses the initial balance transaction.



626
627
628
# File 'lib/stripe/resources/refund.rb', line 626

def failure_balance_transaction
  @failure_balance_transaction
end

#failure_reasonObject (readonly)

Provides the reason for the refund failure. Possible values are: ‘lost_or_stolen_card`, `expired_or_canceled_card`, `charge_for_pending_refund_disputed`, `insufficient_funds`, `declined`, `merchant_request`, or `unknown`.



628
629
630
# File 'lib/stripe/resources/refund.rb', line 628

def failure_reason
  @failure_reason
end

#idObject (readonly)

Unique identifier for the object.



630
631
632
# File 'lib/stripe/resources/refund.rb', line 630

def id
  @id
end

#instructions_emailObject (readonly)

For payment methods without native refund support (for example, Konbini, PromptPay), provide an email address for the customer to receive refund instructions.



632
633
634
# File 'lib/stripe/resources/refund.rb', line 632

def instructions_email
  @instructions_email
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



634
635
636
# File 'lib/stripe/resources/refund.rb', line 634

def 
  @metadata
end

#next_actionObject (readonly)

Attribute for field next_action



636
637
638
# File 'lib/stripe/resources/refund.rb', line 636

def next_action
  @next_action
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



638
639
640
# File 'lib/stripe/resources/refund.rb', line 638

def object
  @object
end

#payment_intentObject (readonly)

ID of the PaymentIntent that’s refunded.



640
641
642
# File 'lib/stripe/resources/refund.rb', line 640

def payment_intent
  @payment_intent
end

#pending_reasonObject (readonly)

Provides the reason for why the refund is pending. Possible values are: ‘processing`, `insufficient_funds`, or `charge_pending`.



642
643
644
# File 'lib/stripe/resources/refund.rb', line 642

def pending_reason
  @pending_reason
end

#presentment_detailsObject (readonly)

Attribute for field presentment_details



644
645
646
# File 'lib/stripe/resources/refund.rb', line 644

def presentment_details
  @presentment_details
end

#reasonObject (readonly)

Reason for the refund, which is either user-provided (‘duplicate`, `fraudulent`, or `requested_by_customer`) or generated by Stripe internally (`expired_uncaptured_charge`).



646
647
648
# File 'lib/stripe/resources/refund.rb', line 646

def reason
  @reason
end

#receipt_numberObject (readonly)

This is the transaction number that appears on email receipts sent for this refund.



648
649
650
# File 'lib/stripe/resources/refund.rb', line 648

def receipt_number
  @receipt_number
end

#source_transfer_reversalObject (readonly)

The transfer reversal that’s associated with the refund. Only present if the charge came from another Stripe account.



650
651
652
# File 'lib/stripe/resources/refund.rb', line 650

def source_transfer_reversal
  @source_transfer_reversal
end

#statusObject (readonly)

Status of the refund. This can be ‘pending`, `requires_action`, `succeeded`, `failed`, or `canceled`. Learn more about [failed refunds](stripe.com/docs/refunds#failed-refunds).



652
653
654
# File 'lib/stripe/resources/refund.rb', line 652

def status
  @status
end

#transfer_reversalObject (readonly)

This refers to the transfer reversal object if the accompanying transfer reverses. This is only applicable if the charge was created using the destination parameter.



654
655
656
# File 'lib/stripe/resources/refund.rb', line 654

def transfer_reversal
  @transfer_reversal
end

Class Method Details

.cancel(refund, params = {}, opts = {}) ⇒ Object

Cancels a refund with a status of requires_action.

You can’t cancel refunds in other states. Only refunds for payment methods that require customer action can enter the requires_action state.



671
672
673
674
675
676
677
678
# File 'lib/stripe/resources/refund.rb', line 671

def self.cancel(refund, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/refunds/%<refund>s/cancel", { refund: CGI.escape(refund) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

When you create a new refund, you must specify a Charge or a PaymentIntent object on which to create it.

Creating a new refund will refund a charge that has previously been created but not yet refunded. Funds will be refunded to the credit or debit card that was originally charged.

You can optionally refund only part of a charge. You can do so multiple times, until the entire charge has been refunded.

Once entirely refunded, a charge can’t be refunded again. This method will raise an error when called on an already-refunded charge, or when trying to refund more money than is left on a charge.



691
692
693
# File 'lib/stripe/resources/refund.rb', line 691

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/refunds", params: params, opts: opts)
end

.field_remappingsObject



751
752
753
# File 'lib/stripe/resources/refund.rb', line 751

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



743
744
745
746
747
748
749
# File 'lib/stripe/resources/refund.rb', line 743

def self.inner_class_types
  @inner_class_types = {
    destination_details: DestinationDetails,
    next_action: NextAction,
    presentment_details: PresentmentDetails,
  }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of all refunds you created. We return the refunds in sorted order, with the most recent refunds appearing first. The 10 most recent refunds are always available by default on the Charge object.



696
697
698
# File 'lib/stripe/resources/refund.rb', line 696

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/refunds", params: params, opts: opts)
end

.object_nameObject



16
17
18
# File 'lib/stripe/resources/refund.rb', line 16

def self.object_name
  "refund"
end

.update(refund, params = {}, opts = {}) ⇒ Object

Updates the refund that you specify by setting the values of the passed parameters. Any parameters that you don’t provide remain unchanged.

This request only accepts metadata as an argument.



703
704
705
706
707
708
709
710
# File 'lib/stripe/resources/refund.rb', line 703

def self.update(refund, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/refunds/%<refund>s", { refund: CGI.escape(refund) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#cancel(params = {}, opts = {}) ⇒ Object

Cancels a refund with a status of requires_action.

You can’t cancel refunds in other states. Only refunds for payment methods that require customer action can enter the requires_action state.



659
660
661
662
663
664
665
666
# File 'lib/stripe/resources/refund.rb', line 659

def cancel(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/refunds/%<refund>s/cancel", { refund: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#test_helpersObject



712
713
714
# File 'lib/stripe/resources/refund.rb', line 712

def test_helpers
  TestHelpers.new(self)
end