Class: Stripe::Refund

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/refund.rb

Overview

Refund objects allow you to refund a previously created charge that isn’t refunded yet. Funds are refunded to the credit or debit card that’s initially charged.

Related guide: [Refunds](stripe.com/docs/refunds)

Defined Under Namespace

Classes: CancelParams, CreateParams, DestinationDetails, ExpireParams, ListParams, NextAction, RetrieveParams, TestHelpers, UpdateParams

Constant Summary collapse

OBJECT_NAME =
"refund"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount, in cents (or local equivalent).



377
378
379
# File 'lib/stripe/resources/refund.rb', line 377

def amount
  @amount
end

#balance_transactionObject (readonly)

Balance transaction that describes the impact on your account balance.



379
380
381
# File 'lib/stripe/resources/refund.rb', line 379

def balance_transaction
  @balance_transaction
end

#chargeObject (readonly)

ID of the charge that’s refunded.



381
382
383
# File 'lib/stripe/resources/refund.rb', line 381

def charge
  @charge
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



383
384
385
# File 'lib/stripe/resources/refund.rb', line 383

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



385
386
387
# File 'lib/stripe/resources/refund.rb', line 385

def currency
  @currency
end

#descriptionObject (readonly)

An arbitrary string attached to the object. You can use this for displaying to users (available on non-card refunds only).



387
388
389
# File 'lib/stripe/resources/refund.rb', line 387

def description
  @description
end

#destination_detailsObject (readonly)

Attribute for field destination_details



389
390
391
# File 'lib/stripe/resources/refund.rb', line 389

def destination_details
  @destination_details
end

#failure_balance_transactionObject (readonly)

After the refund fails, this balance transaction describes the adjustment made on your account balance that reverses the initial balance transaction.



391
392
393
# File 'lib/stripe/resources/refund.rb', line 391

def failure_balance_transaction
  @failure_balance_transaction
end

#failure_reasonObject (readonly)

Provides the reason for the refund failure. Possible values are: ‘lost_or_stolen_card`, `expired_or_canceled_card`, `charge_for_pending_refund_disputed`, `insufficient_funds`, `declined`, `merchant_request`, or `unknown`.



393
394
395
# File 'lib/stripe/resources/refund.rb', line 393

def failure_reason
  @failure_reason
end

#idObject (readonly)

Unique identifier for the object.



395
396
397
# File 'lib/stripe/resources/refund.rb', line 395

def id
  @id
end

#instructions_emailObject (readonly)

For payment methods without native refund support (for example, Konbini, PromptPay), provide an email address for the customer to receive refund instructions.



397
398
399
# File 'lib/stripe/resources/refund.rb', line 397

def instructions_email
  @instructions_email
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



399
400
401
# File 'lib/stripe/resources/refund.rb', line 399

def 
  @metadata
end

#next_actionObject (readonly)

Attribute for field next_action



401
402
403
# File 'lib/stripe/resources/refund.rb', line 401

def next_action
  @next_action
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



403
404
405
# File 'lib/stripe/resources/refund.rb', line 403

def object
  @object
end

#payment_intentObject (readonly)

ID of the PaymentIntent that’s refunded.



405
406
407
# File 'lib/stripe/resources/refund.rb', line 405

def payment_intent
  @payment_intent
end

#reasonObject (readonly)

Reason for the refund, which is either user-provided (‘duplicate`, `fraudulent`, or `requested_by_customer`) or generated by Stripe internally (`expired_uncaptured_charge`).



407
408
409
# File 'lib/stripe/resources/refund.rb', line 407

def reason
  @reason
end

#receipt_numberObject (readonly)

This is the transaction number that appears on email receipts sent for this refund.



409
410
411
# File 'lib/stripe/resources/refund.rb', line 409

def receipt_number
  @receipt_number
end

#source_transfer_reversalObject (readonly)

The transfer reversal that’s associated with the refund. Only present if the charge came from another Stripe account.



411
412
413
# File 'lib/stripe/resources/refund.rb', line 411

def source_transfer_reversal
  @source_transfer_reversal
end

#statusObject (readonly)

Status of the refund. This can be ‘pending`, `requires_action`, `succeeded`, `failed`, or `canceled`. Learn more about [failed refunds](stripe.com/docs/refunds#failed-refunds).



413
414
415
# File 'lib/stripe/resources/refund.rb', line 413

def status
  @status
end

#transfer_reversalObject (readonly)

This refers to the transfer reversal object if the accompanying transfer reverses. This is only applicable if the charge was created using the destination parameter.



415
416
417
# File 'lib/stripe/resources/refund.rb', line 415

def transfer_reversal
  @transfer_reversal
end

Class Method Details

.cancel(refund, params = {}, opts = {}) ⇒ Object

Cancels a refund with a status of requires_action.

You can’t cancel refunds in other states. Only refunds for payment methods that require customer action can enter the requires_action state.



432
433
434
435
436
437
438
439
# File 'lib/stripe/resources/refund.rb', line 432

def self.cancel(refund, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/refunds/%<refund>s/cancel", { refund: CGI.escape(refund) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

When you create a new refund, you must specify a Charge or a PaymentIntent object on which to create it.

Creating a new refund will refund a charge that has previously been created but not yet refunded. Funds will be refunded to the credit or debit card that was originally charged.

You can optionally refund only part of a charge. You can do so multiple times, until the entire charge has been refunded.

Once entirely refunded, a charge can’t be refunded again. This method will raise an error when called on an already-refunded charge, or when trying to refund more money than is left on a charge.



452
453
454
# File 'lib/stripe/resources/refund.rb', line 452

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/refunds", params: params, opts: opts)
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of all refunds you created. We return the refunds in sorted order, with the most recent refunds appearing first. The 10 most recent refunds are always available by default on the Charge object.



457
458
459
# File 'lib/stripe/resources/refund.rb', line 457

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/refunds", params: params, opts: opts)
end

.object_nameObject



16
17
18
# File 'lib/stripe/resources/refund.rb', line 16

def self.object_name
  "refund"
end

.update(refund, params = {}, opts = {}) ⇒ Object

Updates the refund that you specify by setting the values of the passed parameters. Any parameters that you don’t provide remain unchanged.

This request only accepts metadata as an argument.



464
465
466
467
468
469
470
471
# File 'lib/stripe/resources/refund.rb', line 464

def self.update(refund, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/refunds/%<refund>s", { refund: CGI.escape(refund) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#cancel(params = {}, opts = {}) ⇒ Object

Cancels a refund with a status of requires_action.

You can’t cancel refunds in other states. Only refunds for payment methods that require customer action can enter the requires_action state.



420
421
422
423
424
425
426
427
# File 'lib/stripe/resources/refund.rb', line 420

def cancel(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/refunds/%<refund>s/cancel", { refund: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#test_helpersObject



473
474
475
# File 'lib/stripe/resources/refund.rb', line 473

def test_helpers
  TestHelpers.new(self)
end