Class: Stripe::Refund
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Refund
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/refund.rb
Overview
Refund objects allow you to refund a previously created charge that isn’t refunded yet. Funds are refunded to the credit or debit card that’s initially charged.
Related guide: [Refunds](stripe.com/docs/refunds)
Defined Under Namespace
Classes: DestinationDetails, NextAction, TestHelpers
Constant Summary collapse
- OBJECT_NAME =
"refund"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount, in cents (or local equivalent).
-
#balance_transaction ⇒ Object
readonly
Balance transaction that describes the impact on your account balance.
-
#charge ⇒ Object
readonly
ID of the charge that’s refunded.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#destination_details ⇒ Object
readonly
Attribute for field destination_details.
-
#failure_balance_transaction ⇒ Object
readonly
After the refund fails, this balance transaction describes the adjustment made on your account balance that reverses the initial balance transaction.
-
#failure_reason ⇒ Object
readonly
Provides the reason for the refund failure.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#instructions_email ⇒ Object
readonly
For payment methods without native refund support (for example, Konbini, PromptPay), provide an email address for the customer to receive refund instructions.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#next_action ⇒ Object
readonly
Attribute for field next_action.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#payment_intent ⇒ Object
readonly
ID of the PaymentIntent that’s refunded.
-
#reason ⇒ Object
readonly
Reason for the refund, which is either user-provided (‘duplicate`, `fraudulent`, or `requested_by_customer`) or generated by Stripe internally (`expired_uncaptured_charge`).
-
#receipt_number ⇒ Object
readonly
This is the transaction number that appears on email receipts sent for this refund.
-
#source_transfer_reversal ⇒ Object
readonly
The transfer reversal that’s associated with the refund.
-
#status ⇒ Object
readonly
Status of the refund.
-
#transfer_reversal ⇒ Object
readonly
This refers to the transfer reversal object if the accompanying transfer reverses.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.cancel(refund, params = {}, opts = {}) ⇒ Object
Cancels a refund with a status of requires_action.
-
.create(params = {}, opts = {}) ⇒ Object
When you create a new refund, you must specify a Charge or a PaymentIntent object on which to create it.
-
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of all refunds you created.
- .object_name ⇒ Object
-
.update(id, params = {}, opts = {}) ⇒ Object
Updates the refund that you specify by setting the values of the passed parameters.
Instance Method Summary collapse
-
#cancel(params = {}, opts = {}) ⇒ Object
Cancels a refund with a status of requires_action.
- #test_helpers ⇒ Object
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount, in cents (or local equivalent).
110 111 112 |
# File 'lib/stripe/resources/refund.rb', line 110 def amount @amount end |
#balance_transaction ⇒ Object (readonly)
Balance transaction that describes the impact on your account balance.
112 113 114 |
# File 'lib/stripe/resources/refund.rb', line 112 def balance_transaction @balance_transaction end |
#charge ⇒ Object (readonly)
ID of the charge that’s refunded.
114 115 116 |
# File 'lib/stripe/resources/refund.rb', line 114 def charge @charge end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
116 117 118 |
# File 'lib/stripe/resources/refund.rb', line 116 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
118 119 120 |
# File 'lib/stripe/resources/refund.rb', line 118 def currency @currency end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. You can use this for displaying to users (available on non-card refunds only).
120 121 122 |
# File 'lib/stripe/resources/refund.rb', line 120 def description @description end |
#destination_details ⇒ Object (readonly)
Attribute for field destination_details
122 123 124 |
# File 'lib/stripe/resources/refund.rb', line 122 def destination_details @destination_details end |
#failure_balance_transaction ⇒ Object (readonly)
After the refund fails, this balance transaction describes the adjustment made on your account balance that reverses the initial balance transaction.
124 125 126 |
# File 'lib/stripe/resources/refund.rb', line 124 def failure_balance_transaction @failure_balance_transaction end |
#failure_reason ⇒ Object (readonly)
Provides the reason for the refund failure. Possible values are: ‘lost_or_stolen_card`, `expired_or_canceled_card`, `charge_for_pending_refund_disputed`, `insufficient_funds`, `declined`, `merchant_request`, or `unknown`.
126 127 128 |
# File 'lib/stripe/resources/refund.rb', line 126 def failure_reason @failure_reason end |
#id ⇒ Object (readonly)
Unique identifier for the object.
128 129 130 |
# File 'lib/stripe/resources/refund.rb', line 128 def id @id end |
#instructions_email ⇒ Object (readonly)
For payment methods without native refund support (for example, Konbini, PromptPay), provide an email address for the customer to receive refund instructions.
130 131 132 |
# File 'lib/stripe/resources/refund.rb', line 130 def instructions_email @instructions_email end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
132 133 134 |
# File 'lib/stripe/resources/refund.rb', line 132 def @metadata end |
#next_action ⇒ Object (readonly)
Attribute for field next_action
134 135 136 |
# File 'lib/stripe/resources/refund.rb', line 134 def next_action @next_action end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
136 137 138 |
# File 'lib/stripe/resources/refund.rb', line 136 def object @object end |
#payment_intent ⇒ Object (readonly)
ID of the PaymentIntent that’s refunded.
138 139 140 |
# File 'lib/stripe/resources/refund.rb', line 138 def payment_intent @payment_intent end |
#reason ⇒ Object (readonly)
Reason for the refund, which is either user-provided (‘duplicate`, `fraudulent`, or `requested_by_customer`) or generated by Stripe internally (`expired_uncaptured_charge`).
140 141 142 |
# File 'lib/stripe/resources/refund.rb', line 140 def reason @reason end |
#receipt_number ⇒ Object (readonly)
This is the transaction number that appears on email receipts sent for this refund.
142 143 144 |
# File 'lib/stripe/resources/refund.rb', line 142 def receipt_number @receipt_number end |
#source_transfer_reversal ⇒ Object (readonly)
The transfer reversal that’s associated with the refund. Only present if the charge came from another Stripe account.
144 145 146 |
# File 'lib/stripe/resources/refund.rb', line 144 def source_transfer_reversal @source_transfer_reversal end |
#status ⇒ Object (readonly)
Status of the refund. This can be ‘pending`, `requires_action`, `succeeded`, `failed`, or `canceled`. Learn more about [failed refunds](stripe.com/docs/refunds#failed-refunds).
146 147 148 |
# File 'lib/stripe/resources/refund.rb', line 146 def status @status end |
#transfer_reversal ⇒ Object (readonly)
This refers to the transfer reversal object if the accompanying transfer reverses. This is only applicable if the charge was created using the destination parameter.
148 149 150 |
# File 'lib/stripe/resources/refund.rb', line 148 def transfer_reversal @transfer_reversal end |
Class Method Details
.cancel(refund, params = {}, opts = {}) ⇒ Object
Cancels a refund with a status of requires_action.
You can’t cancel refunds in other states. Only refunds for payment methods that require customer action can enter the requires_action state.
165 166 167 168 169 170 171 172 |
# File 'lib/stripe/resources/refund.rb', line 165 def self.cancel(refund, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/refunds/%<refund>s/cancel", { refund: CGI.escape(refund) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
When you create a new refund, you must specify a Charge or a PaymentIntent object on which to create it.
Creating a new refund will refund a charge that has previously been created but not yet refunded. Funds will be refunded to the credit or debit card that was originally charged.
You can optionally refund only part of a charge. You can do so multiple times, until the entire charge has been refunded.
Once entirely refunded, a charge can’t be refunded again. This method will raise an error when called on an already-refunded charge, or when trying to refund more money than is left on a charge.
185 186 187 |
# File 'lib/stripe/resources/refund.rb', line 185 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/refunds", params: params, opts: opts) end |
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of all refunds you created. We return the refunds in sorted order, with the most recent refunds appearing first. The 10 most recent refunds are always available by default on the Charge object.
190 191 192 |
# File 'lib/stripe/resources/refund.rb', line 190 def self.list(filters = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/refunds", params: filters, opts: opts) end |
.object_name ⇒ Object
16 17 18 |
# File 'lib/stripe/resources/refund.rb', line 16 def self.object_name "refund" end |
.update(id, params = {}, opts = {}) ⇒ Object
Updates the refund that you specify by setting the values of the passed parameters. Any parameters that you don’t provide remain unchanged.
This request only accepts metadata as an argument.
197 198 199 200 201 202 203 204 |
# File 'lib/stripe/resources/refund.rb', line 197 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/refunds/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |
Instance Method Details
#cancel(params = {}, opts = {}) ⇒ Object
Cancels a refund with a status of requires_action.
You can’t cancel refunds in other states. Only refunds for payment methods that require customer action can enter the requires_action state.
153 154 155 156 157 158 159 160 |
# File 'lib/stripe/resources/refund.rb', line 153 def cancel(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/refunds/%<refund>s/cancel", { refund: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#test_helpers ⇒ Object
206 207 208 |
# File 'lib/stripe/resources/refund.rb', line 206 def test_helpers TestHelpers.new(self) end |