Class: Stripe::Refund::CreateParams
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Refund::CreateParams
- Defined in:
- lib/stripe/resources/refund.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Attribute for param field amount.
-
#charge ⇒ Object
The identifier of the charge to refund.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
Customer whose customer balance to refund from.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#instructions_email ⇒ Object
For payment methods without native refund support (e.g., Konbini, PromptPay), use this email from the customer to receive refund instructions.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#origin ⇒ Object
Origin of the refund.
-
#payment_intent ⇒ Object
The identifier of the PaymentIntent to refund.
-
#reason ⇒ Object
String indicating the reason for the refund.
-
#refund_application_fee ⇒ Object
Boolean indicating whether the application fee should be refunded when refunding this charge.
-
#reverse_transfer ⇒ Object
Boolean indicating whether the transfer should be reversed when refunding this charge.
Instance Method Summary collapse
-
#initialize(amount: nil, charge: nil, currency: nil, customer: nil, expand: nil, instructions_email: nil, metadata: nil, origin: nil, payment_intent: nil, reason: nil, refund_application_fee: nil, reverse_transfer: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from Stripe::RequestParams
Constructor Details
#initialize(amount: nil, charge: nil, currency: nil, customer: nil, expand: nil, instructions_email: nil, metadata: nil, origin: nil, payment_intent: nil, reason: nil, refund_application_fee: nil, reverse_transfer: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 |
# File 'lib/stripe/resources/refund.rb', line 674 def initialize( amount: nil, charge: nil, currency: nil, customer: nil, expand: nil, instructions_email: nil, metadata: nil, origin: nil, payment_intent: nil, reason: nil, refund_application_fee: nil, reverse_transfer: nil ) @amount = amount @charge = charge @currency = currency @customer = customer @expand = @instructions_email = instructions_email @metadata = @origin = origin @payment_intent = payment_intent @reason = reason @refund_application_fee = refund_application_fee @reverse_transfer = reverse_transfer end |
Instance Attribute Details
#amount ⇒ Object
Attribute for param field amount
650 651 652 |
# File 'lib/stripe/resources/refund.rb', line 650 def amount @amount end |
#charge ⇒ Object
The identifier of the charge to refund.
652 653 654 |
# File 'lib/stripe/resources/refund.rb', line 652 def charge @charge end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
654 655 656 |
# File 'lib/stripe/resources/refund.rb', line 654 def currency @currency end |
#customer ⇒ Object
Customer whose customer balance to refund from.
656 657 658 |
# File 'lib/stripe/resources/refund.rb', line 656 def customer @customer end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
658 659 660 |
# File 'lib/stripe/resources/refund.rb', line 658 def @expand end |
#instructions_email ⇒ Object
For payment methods without native refund support (e.g., Konbini, PromptPay), use this email from the customer to receive refund instructions.
660 661 662 |
# File 'lib/stripe/resources/refund.rb', line 660 def instructions_email @instructions_email end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
662 663 664 |
# File 'lib/stripe/resources/refund.rb', line 662 def @metadata end |
#origin ⇒ Object
Origin of the refund
664 665 666 |
# File 'lib/stripe/resources/refund.rb', line 664 def origin @origin end |
#payment_intent ⇒ Object
The identifier of the PaymentIntent to refund.
666 667 668 |
# File 'lib/stripe/resources/refund.rb', line 666 def payment_intent @payment_intent end |
#reason ⇒ Object
String indicating the reason for the refund. If set, possible values are ‘duplicate`, `fraudulent`, and `requested_by_customer`. If you believe the charge to be fraudulent, specifying `fraudulent` as the reason will add the associated card and email to your [block lists](stripe.com/docs/radar/lists), and will also help us improve our fraud detection algorithms.
668 669 670 |
# File 'lib/stripe/resources/refund.rb', line 668 def reason @reason end |
#refund_application_fee ⇒ Object
Boolean indicating whether the application fee should be refunded when refunding this charge. If a full charge refund is given, the full application fee will be refunded. Otherwise, the application fee will be refunded in an amount proportional to the amount of the charge refunded. An application fee can be refunded only by the application that created the charge.
670 671 672 |
# File 'lib/stripe/resources/refund.rb', line 670 def refund_application_fee @refund_application_fee end |
#reverse_transfer ⇒ Object
Boolean indicating whether the transfer should be reversed when refunding this charge. The transfer will be reversed proportionally to the amount being refunded (either the entire or partial amount).
A transfer can be reversed only by the application that created the charge.
672 673 674 |
# File 'lib/stripe/resources/refund.rb', line 672 def reverse_transfer @reverse_transfer end |