Class: Stripe::Refund::CreateParams

Inherits:
Stripe::RequestParams show all
Defined in:
lib/stripe/resources/refund.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

#to_h

Constructor Details

#initialize(amount: nil, charge: nil, currency: nil, customer: nil, expand: nil, instructions_email: nil, metadata: nil, origin: nil, payment_intent: nil, reason: nil, refund_application_fee: nil, reverse_transfer: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/stripe/resources/refund.rb', line 325

def initialize(
  amount: nil,
  charge: nil,
  currency: nil,
  customer: nil,
  expand: nil,
  instructions_email: nil,
  metadata: nil,
  origin: nil,
  payment_intent: nil,
  reason: nil,
  refund_application_fee: nil,
  reverse_transfer: nil
)
  @amount = amount
  @charge = charge
  @currency = currency
  @customer = customer
  @expand = expand
  @instructions_email = instructions_email
  @metadata = 
  @origin = origin
  @payment_intent = payment_intent
  @reason = reason
  @refund_application_fee = refund_application_fee
  @reverse_transfer = reverse_transfer
end

Instance Attribute Details

#amountObject

Attribute for param field amount



301
302
303
# File 'lib/stripe/resources/refund.rb', line 301

def amount
  @amount
end

#chargeObject

The identifier of the charge to refund.



303
304
305
# File 'lib/stripe/resources/refund.rb', line 303

def charge
  @charge
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



305
306
307
# File 'lib/stripe/resources/refund.rb', line 305

def currency
  @currency
end

#customerObject

Customer whose customer balance to refund from.



307
308
309
# File 'lib/stripe/resources/refund.rb', line 307

def customer
  @customer
end

#expandObject

Specifies which fields in the response should be expanded.



309
310
311
# File 'lib/stripe/resources/refund.rb', line 309

def expand
  @expand
end

#instructions_emailObject

For payment methods without native refund support (e.g., Konbini, PromptPay), use this email from the customer to receive refund instructions.



311
312
313
# File 'lib/stripe/resources/refund.rb', line 311

def instructions_email
  @instructions_email
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



313
314
315
# File 'lib/stripe/resources/refund.rb', line 313

def 
  @metadata
end

#originObject

Origin of the refund



315
316
317
# File 'lib/stripe/resources/refund.rb', line 315

def origin
  @origin
end

#payment_intentObject

The identifier of the PaymentIntent to refund.



317
318
319
# File 'lib/stripe/resources/refund.rb', line 317

def payment_intent
  @payment_intent
end

#reasonObject

String indicating the reason for the refund. If set, possible values are ‘duplicate`, `fraudulent`, and `requested_by_customer`. If you believe the charge to be fraudulent, specifying `fraudulent` as the reason will add the associated card and email to your [block lists](stripe.com/docs/radar/lists), and will also help us improve our fraud detection algorithms.



319
320
321
# File 'lib/stripe/resources/refund.rb', line 319

def reason
  @reason
end

#refund_application_feeObject

Boolean indicating whether the application fee should be refunded when refunding this charge. If a full charge refund is given, the full application fee will be refunded. Otherwise, the application fee will be refunded in an amount proportional to the amount of the charge refunded. An application fee can be refunded only by the application that created the charge.



321
322
323
# File 'lib/stripe/resources/refund.rb', line 321

def refund_application_fee
  @refund_application_fee
end

#reverse_transferObject

Boolean indicating whether the transfer should be reversed when refunding this charge. The transfer will be reversed proportionally to the amount being refunded (either the entire or partial amount).
A transfer can be reversed only by the application that created the charge.



323
324
325
# File 'lib/stripe/resources/refund.rb', line 323

def reverse_transfer
  @reverse_transfer
end