Class: Stripe::Refund::CreateParams

Inherits:
Stripe::RequestParams show all
Defined in:
lib/stripe/resources/refund.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

#to_h

Constructor Details

#initialize(amount: nil, charge: nil, currency: nil, customer: nil, expand: nil, instructions_email: nil, metadata: nil, origin: nil, payment_intent: nil, reason: nil, refund_application_fee: nil, reverse_transfer: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
# File 'lib/stripe/resources/refund.rb', line 381

def initialize(
  amount: nil,
  charge: nil,
  currency: nil,
  customer: nil,
  expand: nil,
  instructions_email: nil,
  metadata: nil,
  origin: nil,
  payment_intent: nil,
  reason: nil,
  refund_application_fee: nil,
  reverse_transfer: nil
)
  @amount = amount
  @charge = charge
  @currency = currency
  @customer = customer
  @expand = expand
  @instructions_email = instructions_email
  @metadata = 
  @origin = origin
  @payment_intent = payment_intent
  @reason = reason
  @refund_application_fee = refund_application_fee
  @reverse_transfer = reverse_transfer
end

Instance Attribute Details

#amountObject

Attribute for param field amount



346
347
348
# File 'lib/stripe/resources/refund.rb', line 346

def amount
  @amount
end

#chargeObject

The identifier of the charge to refund.



349
350
351
# File 'lib/stripe/resources/refund.rb', line 349

def charge
  @charge
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



352
353
354
# File 'lib/stripe/resources/refund.rb', line 352

def currency
  @currency
end

#customerObject

Customer whose customer balance to refund from.



355
356
357
# File 'lib/stripe/resources/refund.rb', line 355

def customer
  @customer
end

#expandObject

Specifies which fields in the response should be expanded.



358
359
360
# File 'lib/stripe/resources/refund.rb', line 358

def expand
  @expand
end

#instructions_emailObject

For payment methods without native refund support (e.g., Konbini, PromptPay), use this email from the customer to receive refund instructions.



361
362
363
# File 'lib/stripe/resources/refund.rb', line 361

def instructions_email
  @instructions_email
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



364
365
366
# File 'lib/stripe/resources/refund.rb', line 364

def 
  @metadata
end

#originObject

Origin of the refund



367
368
369
# File 'lib/stripe/resources/refund.rb', line 367

def origin
  @origin
end

#payment_intentObject

The identifier of the PaymentIntent to refund.



370
371
372
# File 'lib/stripe/resources/refund.rb', line 370

def payment_intent
  @payment_intent
end

#reasonObject

String indicating the reason for the refund. If set, possible values are ‘duplicate`, `fraudulent`, and `requested_by_customer`. If you believe the charge to be fraudulent, specifying `fraudulent` as the reason will add the associated card and email to your [block lists](stripe.com/docs/radar/lists), and will also help us improve our fraud detection algorithms.



373
374
375
# File 'lib/stripe/resources/refund.rb', line 373

def reason
  @reason
end

#refund_application_feeObject

Boolean indicating whether the application fee should be refunded when refunding this charge. If a full charge refund is given, the full application fee will be refunded. Otherwise, the application fee will be refunded in an amount proportional to the amount of the charge refunded. An application fee can be refunded only by the application that created the charge.



376
377
378
# File 'lib/stripe/resources/refund.rb', line 376

def refund_application_fee
  @refund_application_fee
end

#reverse_transferObject

Boolean indicating whether the transfer should be reversed when refunding this charge. The transfer will be reversed proportionally to the amount being refunded (either the entire or partial amount).
A transfer can be reversed only by the application that created the charge.



379
380
381
# File 'lib/stripe/resources/refund.rb', line 379

def reverse_transfer
  @reverse_transfer
end