Class: Stripe::Refund::DestinationDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Refund::DestinationDetails
- Defined in:
- lib/stripe/resources/refund.rb
Defined Under Namespace
Classes: Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBankTransfer, Blik, BrBankTransfer, Card, Cashapp, Crypto, CustomerCashBalance, Eps, EuBankTransfer, GbBankTransfer, Giropay, Grabpay, JpBankTransfer, Klarna, MbWay, Multibanco, MxBankTransfer, NzBankTransfer, P24, Paynow, Paypal, Pix, Revolut, Scalapay, Sofort, Swish, ThBankTransfer, Twint, UsBankTransfer, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_bank_transfer ⇒ Object
readonly
Attribute for field au_bank_transfer.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#br_bank_transfer ⇒ Object
readonly
Attribute for field br_bank_transfer.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#crypto ⇒ Object
readonly
Attribute for field crypto.
-
#customer_cash_balance ⇒ Object
readonly
Attribute for field customer_cash_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#eu_bank_transfer ⇒ Object
readonly
Attribute for field eu_bank_transfer.
-
#gb_bank_transfer ⇒ Object
readonly
Attribute for field gb_bank_transfer.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#jp_bank_transfer ⇒ Object
readonly
Attribute for field jp_bank_transfer.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#mx_bank_transfer ⇒ Object
readonly
Attribute for field mx_bank_transfer.
-
#nz_bank_transfer ⇒ Object
readonly
Attribute for field nz_bank_transfer.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#revolut ⇒ Object
readonly
Attribute for field revolut.
-
#scalapay ⇒ Object
readonly
Attribute for field scalapay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#th_bank_transfer ⇒ Object
readonly
Attribute for field th_bank_transfer.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of transaction-specific details of the payment method used in the refund (e.g., ‘card`).
-
#us_bank_transfer ⇒ Object
readonly
Attribute for field us_bank_transfer.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affirm ⇒ Object (readonly)
Attribute for field affirm
460 461 462 |
# File 'lib/stripe/resources/refund.rb', line 460 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
462 463 464 |
# File 'lib/stripe/resources/refund.rb', line 462 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
464 465 466 |
# File 'lib/stripe/resources/refund.rb', line 464 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
466 467 468 |
# File 'lib/stripe/resources/refund.rb', line 466 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
468 469 470 |
# File 'lib/stripe/resources/refund.rb', line 468 def amazon_pay @amazon_pay end |
#au_bank_transfer ⇒ Object (readonly)
Attribute for field au_bank_transfer
470 471 472 |
# File 'lib/stripe/resources/refund.rb', line 470 def au_bank_transfer @au_bank_transfer end |
#blik ⇒ Object (readonly)
Attribute for field blik
472 473 474 |
# File 'lib/stripe/resources/refund.rb', line 472 def blik @blik end |
#br_bank_transfer ⇒ Object (readonly)
Attribute for field br_bank_transfer
474 475 476 |
# File 'lib/stripe/resources/refund.rb', line 474 def br_bank_transfer @br_bank_transfer end |
#card ⇒ Object (readonly)
Attribute for field card
476 477 478 |
# File 'lib/stripe/resources/refund.rb', line 476 def card @card end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
478 479 480 |
# File 'lib/stripe/resources/refund.rb', line 478 def cashapp @cashapp end |
#crypto ⇒ Object (readonly)
Attribute for field crypto
480 481 482 |
# File 'lib/stripe/resources/refund.rb', line 480 def crypto @crypto end |
#customer_cash_balance ⇒ Object (readonly)
Attribute for field customer_cash_balance
482 483 484 |
# File 'lib/stripe/resources/refund.rb', line 482 def customer_cash_balance @customer_cash_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
484 485 486 |
# File 'lib/stripe/resources/refund.rb', line 484 def eps @eps end |
#eu_bank_transfer ⇒ Object (readonly)
Attribute for field eu_bank_transfer
486 487 488 |
# File 'lib/stripe/resources/refund.rb', line 486 def eu_bank_transfer @eu_bank_transfer end |
#gb_bank_transfer ⇒ Object (readonly)
Attribute for field gb_bank_transfer
488 489 490 |
# File 'lib/stripe/resources/refund.rb', line 488 def gb_bank_transfer @gb_bank_transfer end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
490 491 492 |
# File 'lib/stripe/resources/refund.rb', line 490 def giropay @giropay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
492 493 494 |
# File 'lib/stripe/resources/refund.rb', line 492 def grabpay @grabpay end |
#jp_bank_transfer ⇒ Object (readonly)
Attribute for field jp_bank_transfer
494 495 496 |
# File 'lib/stripe/resources/refund.rb', line 494 def jp_bank_transfer @jp_bank_transfer end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
496 497 498 |
# File 'lib/stripe/resources/refund.rb', line 496 def klarna @klarna end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
498 499 500 |
# File 'lib/stripe/resources/refund.rb', line 498 def mb_way @mb_way end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
500 501 502 |
# File 'lib/stripe/resources/refund.rb', line 500 def multibanco @multibanco end |
#mx_bank_transfer ⇒ Object (readonly)
Attribute for field mx_bank_transfer
502 503 504 |
# File 'lib/stripe/resources/refund.rb', line 502 def mx_bank_transfer @mx_bank_transfer end |
#nz_bank_transfer ⇒ Object (readonly)
Attribute for field nz_bank_transfer
504 505 506 |
# File 'lib/stripe/resources/refund.rb', line 504 def nz_bank_transfer @nz_bank_transfer end |
#p24 ⇒ Object (readonly)
Attribute for field p24
506 507 508 |
# File 'lib/stripe/resources/refund.rb', line 506 def p24 @p24 end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
508 509 510 |
# File 'lib/stripe/resources/refund.rb', line 508 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
510 511 512 |
# File 'lib/stripe/resources/refund.rb', line 510 def paypal @paypal end |
#pix ⇒ Object (readonly)
Attribute for field pix
512 513 514 |
# File 'lib/stripe/resources/refund.rb', line 512 def pix @pix end |
#revolut ⇒ Object (readonly)
Attribute for field revolut
514 515 516 |
# File 'lib/stripe/resources/refund.rb', line 514 def revolut @revolut end |
#scalapay ⇒ Object (readonly)
Attribute for field scalapay
516 517 518 |
# File 'lib/stripe/resources/refund.rb', line 516 def scalapay @scalapay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
518 519 520 |
# File 'lib/stripe/resources/refund.rb', line 518 def sofort @sofort end |
#swish ⇒ Object (readonly)
Attribute for field swish
520 521 522 |
# File 'lib/stripe/resources/refund.rb', line 520 def swish @swish end |
#th_bank_transfer ⇒ Object (readonly)
Attribute for field th_bank_transfer
522 523 524 |
# File 'lib/stripe/resources/refund.rb', line 522 def th_bank_transfer @th_bank_transfer end |
#twint ⇒ Object (readonly)
Attribute for field twint
524 525 526 |
# File 'lib/stripe/resources/refund.rb', line 524 def twint @twint end |
#type ⇒ Object (readonly)
The type of transaction-specific details of the payment method used in the refund (e.g., ‘card`). An additional hash is included on `destination_details` with a name matching this value. It contains information specific to the refund transaction.
526 527 528 |
# File 'lib/stripe/resources/refund.rb', line 526 def type @type end |
#us_bank_transfer ⇒ Object (readonly)
Attribute for field us_bank_transfer
528 529 530 |
# File 'lib/stripe/resources/refund.rb', line 528 def us_bank_transfer @us_bank_transfer end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
530 531 532 |
# File 'lib/stripe/resources/refund.rb', line 530 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
532 533 534 |
# File 'lib/stripe/resources/refund.rb', line 532 def zip @zip end |
Class Method Details
.field_remappings ⇒ Object
575 576 577 |
# File 'lib/stripe/resources/refund.rb', line 575 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 |
# File 'lib/stripe/resources/refund.rb', line 534 def self.inner_class_types @inner_class_types = { affirm: Affirm, afterpay_clearpay: AfterpayClearpay, alipay: Alipay, alma: Alma, amazon_pay: AmazonPay, au_bank_transfer: AuBankTransfer, blik: Blik, br_bank_transfer: BrBankTransfer, card: Card, cashapp: Cashapp, crypto: Crypto, customer_cash_balance: CustomerCashBalance, eps: Eps, eu_bank_transfer: EuBankTransfer, gb_bank_transfer: GbBankTransfer, giropay: Giropay, grabpay: Grabpay, jp_bank_transfer: JpBankTransfer, klarna: Klarna, mb_way: MbWay, multibanco: Multibanco, mx_bank_transfer: MxBankTransfer, nz_bank_transfer: NzBankTransfer, p24: P24, paynow: Paynow, paypal: Paypal, pix: Pix, revolut: Revolut, scalapay: Scalapay, sofort: Sofort, swish: Swish, th_bank_transfer: ThBankTransfer, twint: Twint, us_bank_transfer: UsBankTransfer, wechat_pay: WechatPay, zip: Zip, } end |