Class: Stripe::Refund::DestinationDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Refund::DestinationDetails
- Defined in:
- lib/stripe/resources/refund.rb
Defined Under Namespace
Classes: Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBankTransfer, Blik, BrBankTransfer, Card, Cashapp, Crypto, CustomerCashBalance, Eps, EuBankTransfer, GbBankTransfer, Giropay, Grabpay, IdBankTransfer, JpBankTransfer, Klarna, Multibanco, MxBankTransfer, NzBankTransfer, P24, Paynow, Paypal, Pix, Revolut, Sofort, Swish, ThBankTransfer, UsBankTransfer, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_bank_transfer ⇒ Object
readonly
Attribute for field au_bank_transfer.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#br_bank_transfer ⇒ Object
readonly
Attribute for field br_bank_transfer.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#crypto ⇒ Object
readonly
Attribute for field crypto.
-
#customer_cash_balance ⇒ Object
readonly
Attribute for field customer_cash_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#eu_bank_transfer ⇒ Object
readonly
Attribute for field eu_bank_transfer.
-
#gb_bank_transfer ⇒ Object
readonly
Attribute for field gb_bank_transfer.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#jp_bank_transfer ⇒ Object
readonly
Attribute for field jp_bank_transfer.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#mx_bank_transfer ⇒ Object
readonly
Attribute for field mx_bank_transfer.
-
#nz_bank_transfer ⇒ Object
readonly
Attribute for field nz_bank_transfer.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#revolut ⇒ Object
readonly
Attribute for field revolut.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#th_bank_transfer ⇒ Object
readonly
Attribute for field th_bank_transfer.
-
#type ⇒ Object
readonly
The type of transaction-specific details of the payment method used in the refund (e.g., ‘card`).
-
#us_bank_transfer ⇒ Object
readonly
Attribute for field us_bank_transfer.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affirm ⇒ Object (readonly)
Attribute for field affirm
440 441 442 |
# File 'lib/stripe/resources/refund.rb', line 440 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
442 443 444 |
# File 'lib/stripe/resources/refund.rb', line 442 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
444 445 446 |
# File 'lib/stripe/resources/refund.rb', line 444 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
446 447 448 |
# File 'lib/stripe/resources/refund.rb', line 446 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
448 449 450 |
# File 'lib/stripe/resources/refund.rb', line 448 def amazon_pay @amazon_pay end |
#au_bank_transfer ⇒ Object (readonly)
Attribute for field au_bank_transfer
450 451 452 |
# File 'lib/stripe/resources/refund.rb', line 450 def au_bank_transfer @au_bank_transfer end |
#blik ⇒ Object (readonly)
Attribute for field blik
452 453 454 |
# File 'lib/stripe/resources/refund.rb', line 452 def blik @blik end |
#br_bank_transfer ⇒ Object (readonly)
Attribute for field br_bank_transfer
454 455 456 |
# File 'lib/stripe/resources/refund.rb', line 454 def br_bank_transfer @br_bank_transfer end |
#card ⇒ Object (readonly)
Attribute for field card
456 457 458 |
# File 'lib/stripe/resources/refund.rb', line 456 def card @card end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
458 459 460 |
# File 'lib/stripe/resources/refund.rb', line 458 def cashapp @cashapp end |
#crypto ⇒ Object (readonly)
Attribute for field crypto
460 461 462 |
# File 'lib/stripe/resources/refund.rb', line 460 def crypto @crypto end |
#customer_cash_balance ⇒ Object (readonly)
Attribute for field customer_cash_balance
462 463 464 |
# File 'lib/stripe/resources/refund.rb', line 462 def customer_cash_balance @customer_cash_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
464 465 466 |
# File 'lib/stripe/resources/refund.rb', line 464 def eps @eps end |
#eu_bank_transfer ⇒ Object (readonly)
Attribute for field eu_bank_transfer
466 467 468 |
# File 'lib/stripe/resources/refund.rb', line 466 def eu_bank_transfer @eu_bank_transfer end |
#gb_bank_transfer ⇒ Object (readonly)
Attribute for field gb_bank_transfer
468 469 470 |
# File 'lib/stripe/resources/refund.rb', line 468 def gb_bank_transfer @gb_bank_transfer end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
470 471 472 |
# File 'lib/stripe/resources/refund.rb', line 470 def giropay @giropay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
472 473 474 |
# File 'lib/stripe/resources/refund.rb', line 472 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
474 475 476 |
# File 'lib/stripe/resources/refund.rb', line 474 def id_bank_transfer @id_bank_transfer end |
#jp_bank_transfer ⇒ Object (readonly)
Attribute for field jp_bank_transfer
476 477 478 |
# File 'lib/stripe/resources/refund.rb', line 476 def jp_bank_transfer @jp_bank_transfer end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
478 479 480 |
# File 'lib/stripe/resources/refund.rb', line 478 def klarna @klarna end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
480 481 482 |
# File 'lib/stripe/resources/refund.rb', line 480 def multibanco @multibanco end |
#mx_bank_transfer ⇒ Object (readonly)
Attribute for field mx_bank_transfer
482 483 484 |
# File 'lib/stripe/resources/refund.rb', line 482 def mx_bank_transfer @mx_bank_transfer end |
#nz_bank_transfer ⇒ Object (readonly)
Attribute for field nz_bank_transfer
484 485 486 |
# File 'lib/stripe/resources/refund.rb', line 484 def nz_bank_transfer @nz_bank_transfer end |
#p24 ⇒ Object (readonly)
Attribute for field p24
486 487 488 |
# File 'lib/stripe/resources/refund.rb', line 486 def p24 @p24 end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
488 489 490 |
# File 'lib/stripe/resources/refund.rb', line 488 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
490 491 492 |
# File 'lib/stripe/resources/refund.rb', line 490 def paypal @paypal end |
#pix ⇒ Object (readonly)
Attribute for field pix
492 493 494 |
# File 'lib/stripe/resources/refund.rb', line 492 def pix @pix end |
#revolut ⇒ Object (readonly)
Attribute for field revolut
494 495 496 |
# File 'lib/stripe/resources/refund.rb', line 494 def revolut @revolut end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
496 497 498 |
# File 'lib/stripe/resources/refund.rb', line 496 def sofort @sofort end |
#swish ⇒ Object (readonly)
Attribute for field swish
498 499 500 |
# File 'lib/stripe/resources/refund.rb', line 498 def swish @swish end |
#th_bank_transfer ⇒ Object (readonly)
Attribute for field th_bank_transfer
500 501 502 |
# File 'lib/stripe/resources/refund.rb', line 500 def th_bank_transfer @th_bank_transfer end |
#type ⇒ Object (readonly)
The type of transaction-specific details of the payment method used in the refund (e.g., ‘card`). An additional hash is included on `destination_details` with a name matching this value. It contains information specific to the refund transaction.
502 503 504 |
# File 'lib/stripe/resources/refund.rb', line 502 def type @type end |
#us_bank_transfer ⇒ Object (readonly)
Attribute for field us_bank_transfer
504 505 506 |
# File 'lib/stripe/resources/refund.rb', line 504 def us_bank_transfer @us_bank_transfer end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
506 507 508 |
# File 'lib/stripe/resources/refund.rb', line 506 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
508 509 510 |
# File 'lib/stripe/resources/refund.rb', line 508 def zip @zip end |
Class Method Details
.field_remappings ⇒ Object
549 550 551 |
# File 'lib/stripe/resources/refund.rb', line 549 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/stripe/resources/refund.rb', line 510 def self.inner_class_types @inner_class_types = { affirm: Affirm, afterpay_clearpay: AfterpayClearpay, alipay: Alipay, alma: Alma, amazon_pay: AmazonPay, au_bank_transfer: AuBankTransfer, blik: Blik, br_bank_transfer: BrBankTransfer, card: Card, cashapp: Cashapp, crypto: Crypto, customer_cash_balance: CustomerCashBalance, eps: Eps, eu_bank_transfer: EuBankTransfer, gb_bank_transfer: GbBankTransfer, giropay: Giropay, grabpay: Grabpay, id_bank_transfer: IdBankTransfer, jp_bank_transfer: JpBankTransfer, klarna: Klarna, multibanco: Multibanco, mx_bank_transfer: MxBankTransfer, nz_bank_transfer: NzBankTransfer, p24: P24, paynow: Paynow, paypal: Paypal, pix: Pix, revolut: Revolut, sofort: Sofort, swish: Swish, th_bank_transfer: ThBankTransfer, us_bank_transfer: UsBankTransfer, wechat_pay: WechatPay, zip: Zip, } end |