Class: Stripe::Refund::DestinationDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Refund::DestinationDetails
- Defined in:
- lib/stripe/resources/refund.rb
Defined Under Namespace
Classes: Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBankTransfer, Blik, BrBankTransfer, Card, Cashapp, Crypto, CustomerCashBalance, Eps, EuBankTransfer, GbBankTransfer, Giropay, Grabpay, JpBankTransfer, Klarna, Multibanco, MxBankTransfer, NzBankTransfer, P24, Paynow, Paypal, Pix, Revolut, Sofort, Swish, ThBankTransfer, UsBankTransfer, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_bank_transfer ⇒ Object
readonly
Attribute for field au_bank_transfer.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#br_bank_transfer ⇒ Object
readonly
Attribute for field br_bank_transfer.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#crypto ⇒ Object
readonly
Attribute for field crypto.
-
#customer_cash_balance ⇒ Object
readonly
Attribute for field customer_cash_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#eu_bank_transfer ⇒ Object
readonly
Attribute for field eu_bank_transfer.
-
#gb_bank_transfer ⇒ Object
readonly
Attribute for field gb_bank_transfer.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#jp_bank_transfer ⇒ Object
readonly
Attribute for field jp_bank_transfer.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#mx_bank_transfer ⇒ Object
readonly
Attribute for field mx_bank_transfer.
-
#nz_bank_transfer ⇒ Object
readonly
Attribute for field nz_bank_transfer.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#revolut ⇒ Object
readonly
Attribute for field revolut.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#th_bank_transfer ⇒ Object
readonly
Attribute for field th_bank_transfer.
-
#type ⇒ Object
readonly
The type of transaction-specific details of the payment method used in the refund (e.g., ‘card`).
-
#us_bank_transfer ⇒ Object
readonly
Attribute for field us_bank_transfer.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affirm ⇒ Object (readonly)
Attribute for field affirm
425 426 427 |
# File 'lib/stripe/resources/refund.rb', line 425 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
427 428 429 |
# File 'lib/stripe/resources/refund.rb', line 427 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
429 430 431 |
# File 'lib/stripe/resources/refund.rb', line 429 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
431 432 433 |
# File 'lib/stripe/resources/refund.rb', line 431 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
433 434 435 |
# File 'lib/stripe/resources/refund.rb', line 433 def amazon_pay @amazon_pay end |
#au_bank_transfer ⇒ Object (readonly)
Attribute for field au_bank_transfer
435 436 437 |
# File 'lib/stripe/resources/refund.rb', line 435 def au_bank_transfer @au_bank_transfer end |
#blik ⇒ Object (readonly)
Attribute for field blik
437 438 439 |
# File 'lib/stripe/resources/refund.rb', line 437 def blik @blik end |
#br_bank_transfer ⇒ Object (readonly)
Attribute for field br_bank_transfer
439 440 441 |
# File 'lib/stripe/resources/refund.rb', line 439 def br_bank_transfer @br_bank_transfer end |
#card ⇒ Object (readonly)
Attribute for field card
441 442 443 |
# File 'lib/stripe/resources/refund.rb', line 441 def card @card end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
443 444 445 |
# File 'lib/stripe/resources/refund.rb', line 443 def cashapp @cashapp end |
#crypto ⇒ Object (readonly)
Attribute for field crypto
445 446 447 |
# File 'lib/stripe/resources/refund.rb', line 445 def crypto @crypto end |
#customer_cash_balance ⇒ Object (readonly)
Attribute for field customer_cash_balance
447 448 449 |
# File 'lib/stripe/resources/refund.rb', line 447 def customer_cash_balance @customer_cash_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
449 450 451 |
# File 'lib/stripe/resources/refund.rb', line 449 def eps @eps end |
#eu_bank_transfer ⇒ Object (readonly)
Attribute for field eu_bank_transfer
451 452 453 |
# File 'lib/stripe/resources/refund.rb', line 451 def eu_bank_transfer @eu_bank_transfer end |
#gb_bank_transfer ⇒ Object (readonly)
Attribute for field gb_bank_transfer
453 454 455 |
# File 'lib/stripe/resources/refund.rb', line 453 def gb_bank_transfer @gb_bank_transfer end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
455 456 457 |
# File 'lib/stripe/resources/refund.rb', line 455 def giropay @giropay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
457 458 459 |
# File 'lib/stripe/resources/refund.rb', line 457 def grabpay @grabpay end |
#jp_bank_transfer ⇒ Object (readonly)
Attribute for field jp_bank_transfer
459 460 461 |
# File 'lib/stripe/resources/refund.rb', line 459 def jp_bank_transfer @jp_bank_transfer end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
461 462 463 |
# File 'lib/stripe/resources/refund.rb', line 461 def klarna @klarna end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
463 464 465 |
# File 'lib/stripe/resources/refund.rb', line 463 def multibanco @multibanco end |
#mx_bank_transfer ⇒ Object (readonly)
Attribute for field mx_bank_transfer
465 466 467 |
# File 'lib/stripe/resources/refund.rb', line 465 def mx_bank_transfer @mx_bank_transfer end |
#nz_bank_transfer ⇒ Object (readonly)
Attribute for field nz_bank_transfer
467 468 469 |
# File 'lib/stripe/resources/refund.rb', line 467 def nz_bank_transfer @nz_bank_transfer end |
#p24 ⇒ Object (readonly)
Attribute for field p24
469 470 471 |
# File 'lib/stripe/resources/refund.rb', line 469 def p24 @p24 end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
471 472 473 |
# File 'lib/stripe/resources/refund.rb', line 471 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
473 474 475 |
# File 'lib/stripe/resources/refund.rb', line 473 def paypal @paypal end |
#pix ⇒ Object (readonly)
Attribute for field pix
475 476 477 |
# File 'lib/stripe/resources/refund.rb', line 475 def pix @pix end |
#revolut ⇒ Object (readonly)
Attribute for field revolut
477 478 479 |
# File 'lib/stripe/resources/refund.rb', line 477 def revolut @revolut end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
479 480 481 |
# File 'lib/stripe/resources/refund.rb', line 479 def sofort @sofort end |
#swish ⇒ Object (readonly)
Attribute for field swish
481 482 483 |
# File 'lib/stripe/resources/refund.rb', line 481 def swish @swish end |
#th_bank_transfer ⇒ Object (readonly)
Attribute for field th_bank_transfer
483 484 485 |
# File 'lib/stripe/resources/refund.rb', line 483 def th_bank_transfer @th_bank_transfer end |
#type ⇒ Object (readonly)
The type of transaction-specific details of the payment method used in the refund (e.g., ‘card`). An additional hash is included on `destination_details` with a name matching this value. It contains information specific to the refund transaction.
485 486 487 |
# File 'lib/stripe/resources/refund.rb', line 485 def type @type end |
#us_bank_transfer ⇒ Object (readonly)
Attribute for field us_bank_transfer
487 488 489 |
# File 'lib/stripe/resources/refund.rb', line 487 def us_bank_transfer @us_bank_transfer end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
489 490 491 |
# File 'lib/stripe/resources/refund.rb', line 489 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
491 492 493 |
# File 'lib/stripe/resources/refund.rb', line 491 def zip @zip end |
Class Method Details
.field_remappings ⇒ Object
531 532 533 |
# File 'lib/stripe/resources/refund.rb', line 531 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 |
# File 'lib/stripe/resources/refund.rb', line 493 def self.inner_class_types @inner_class_types = { affirm: Affirm, afterpay_clearpay: AfterpayClearpay, alipay: Alipay, alma: Alma, amazon_pay: AmazonPay, au_bank_transfer: AuBankTransfer, blik: Blik, br_bank_transfer: BrBankTransfer, card: Card, cashapp: Cashapp, crypto: Crypto, customer_cash_balance: CustomerCashBalance, eps: Eps, eu_bank_transfer: EuBankTransfer, gb_bank_transfer: GbBankTransfer, giropay: Giropay, grabpay: Grabpay, jp_bank_transfer: JpBankTransfer, klarna: Klarna, multibanco: Multibanco, mx_bank_transfer: MxBankTransfer, nz_bank_transfer: NzBankTransfer, p24: P24, paynow: Paynow, paypal: Paypal, pix: Pix, revolut: Revolut, sofort: Sofort, swish: Swish, th_bank_transfer: ThBankTransfer, us_bank_transfer: UsBankTransfer, wechat_pay: WechatPay, zip: Zip, } end |