Class: Stripe::Refund::DestinationDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Refund::DestinationDetails
- Defined in:
- lib/stripe/resources/refund.rb
Defined Under Namespace
Classes: Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBankTransfer, Blik, BrBankTransfer, Card, Cashapp, CustomerCashBalance, Eps, EuBankTransfer, GbBankTransfer, Giropay, Grabpay, IdBankTransfer, JpBankTransfer, Klarna, Multibanco, MxBankTransfer, NzBankTransfer, P24, Paynow, Paypal, Pix, Revolut, Sofort, Swish, ThBankTransfer, UsBankTransfer, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_bank_transfer ⇒ Object
readonly
Attribute for field au_bank_transfer.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#br_bank_transfer ⇒ Object
readonly
Attribute for field br_bank_transfer.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#customer_cash_balance ⇒ Object
readonly
Attribute for field customer_cash_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#eu_bank_transfer ⇒ Object
readonly
Attribute for field eu_bank_transfer.
-
#gb_bank_transfer ⇒ Object
readonly
Attribute for field gb_bank_transfer.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#jp_bank_transfer ⇒ Object
readonly
Attribute for field jp_bank_transfer.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#mx_bank_transfer ⇒ Object
readonly
Attribute for field mx_bank_transfer.
-
#nz_bank_transfer ⇒ Object
readonly
Attribute for field nz_bank_transfer.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#revolut ⇒ Object
readonly
Attribute for field revolut.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#th_bank_transfer ⇒ Object
readonly
Attribute for field th_bank_transfer.
-
#type ⇒ Object
readonly
The type of transaction-specific details of the payment method used in the refund (e.g., ‘card`).
-
#us_bank_transfer ⇒ Object
readonly
Attribute for field us_bank_transfer.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affirm ⇒ Object (readonly)
Attribute for field affirm
147 148 149 |
# File 'lib/stripe/resources/refund.rb', line 147 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
149 150 151 |
# File 'lib/stripe/resources/refund.rb', line 149 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
151 152 153 |
# File 'lib/stripe/resources/refund.rb', line 151 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
153 154 155 |
# File 'lib/stripe/resources/refund.rb', line 153 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
155 156 157 |
# File 'lib/stripe/resources/refund.rb', line 155 def amazon_pay @amazon_pay end |
#au_bank_transfer ⇒ Object (readonly)
Attribute for field au_bank_transfer
157 158 159 |
# File 'lib/stripe/resources/refund.rb', line 157 def au_bank_transfer @au_bank_transfer end |
#blik ⇒ Object (readonly)
Attribute for field blik
159 160 161 |
# File 'lib/stripe/resources/refund.rb', line 159 def blik @blik end |
#br_bank_transfer ⇒ Object (readonly)
Attribute for field br_bank_transfer
161 162 163 |
# File 'lib/stripe/resources/refund.rb', line 161 def br_bank_transfer @br_bank_transfer end |
#card ⇒ Object (readonly)
Attribute for field card
163 164 165 |
# File 'lib/stripe/resources/refund.rb', line 163 def card @card end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
165 166 167 |
# File 'lib/stripe/resources/refund.rb', line 165 def cashapp @cashapp end |
#customer_cash_balance ⇒ Object (readonly)
Attribute for field customer_cash_balance
167 168 169 |
# File 'lib/stripe/resources/refund.rb', line 167 def customer_cash_balance @customer_cash_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
169 170 171 |
# File 'lib/stripe/resources/refund.rb', line 169 def eps @eps end |
#eu_bank_transfer ⇒ Object (readonly)
Attribute for field eu_bank_transfer
171 172 173 |
# File 'lib/stripe/resources/refund.rb', line 171 def eu_bank_transfer @eu_bank_transfer end |
#gb_bank_transfer ⇒ Object (readonly)
Attribute for field gb_bank_transfer
173 174 175 |
# File 'lib/stripe/resources/refund.rb', line 173 def gb_bank_transfer @gb_bank_transfer end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
175 176 177 |
# File 'lib/stripe/resources/refund.rb', line 175 def giropay @giropay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
177 178 179 |
# File 'lib/stripe/resources/refund.rb', line 177 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
179 180 181 |
# File 'lib/stripe/resources/refund.rb', line 179 def id_bank_transfer @id_bank_transfer end |
#jp_bank_transfer ⇒ Object (readonly)
Attribute for field jp_bank_transfer
181 182 183 |
# File 'lib/stripe/resources/refund.rb', line 181 def jp_bank_transfer @jp_bank_transfer end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
183 184 185 |
# File 'lib/stripe/resources/refund.rb', line 183 def klarna @klarna end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
185 186 187 |
# File 'lib/stripe/resources/refund.rb', line 185 def multibanco @multibanco end |
#mx_bank_transfer ⇒ Object (readonly)
Attribute for field mx_bank_transfer
187 188 189 |
# File 'lib/stripe/resources/refund.rb', line 187 def mx_bank_transfer @mx_bank_transfer end |
#nz_bank_transfer ⇒ Object (readonly)
Attribute for field nz_bank_transfer
189 190 191 |
# File 'lib/stripe/resources/refund.rb', line 189 def nz_bank_transfer @nz_bank_transfer end |
#p24 ⇒ Object (readonly)
Attribute for field p24
191 192 193 |
# File 'lib/stripe/resources/refund.rb', line 191 def p24 @p24 end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
193 194 195 |
# File 'lib/stripe/resources/refund.rb', line 193 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
195 196 197 |
# File 'lib/stripe/resources/refund.rb', line 195 def paypal @paypal end |
#pix ⇒ Object (readonly)
Attribute for field pix
197 198 199 |
# File 'lib/stripe/resources/refund.rb', line 197 def pix @pix end |
#revolut ⇒ Object (readonly)
Attribute for field revolut
199 200 201 |
# File 'lib/stripe/resources/refund.rb', line 199 def revolut @revolut end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
201 202 203 |
# File 'lib/stripe/resources/refund.rb', line 201 def sofort @sofort end |
#swish ⇒ Object (readonly)
Attribute for field swish
203 204 205 |
# File 'lib/stripe/resources/refund.rb', line 203 def swish @swish end |
#th_bank_transfer ⇒ Object (readonly)
Attribute for field th_bank_transfer
205 206 207 |
# File 'lib/stripe/resources/refund.rb', line 205 def th_bank_transfer @th_bank_transfer end |
#type ⇒ Object (readonly)
The type of transaction-specific details of the payment method used in the refund (e.g., ‘card`). An additional hash is included on `destination_details` with a name matching this value. It contains information specific to the refund transaction.
207 208 209 |
# File 'lib/stripe/resources/refund.rb', line 207 def type @type end |
#us_bank_transfer ⇒ Object (readonly)
Attribute for field us_bank_transfer
209 210 211 |
# File 'lib/stripe/resources/refund.rb', line 209 def us_bank_transfer @us_bank_transfer end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
211 212 213 |
# File 'lib/stripe/resources/refund.rb', line 211 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
213 214 215 |
# File 'lib/stripe/resources/refund.rb', line 213 def zip @zip end |