Class: Stripe::Refund::DestinationDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Refund::DestinationDetails
- Defined in:
- lib/stripe/resources/refund.rb
Defined Under Namespace
Classes: Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBankTransfer, Blik, BrBankTransfer, Card, Cashapp, CustomerCashBalance, Eps, EuBankTransfer, GbBankTransfer, Giropay, Grabpay, IdBankTransfer, JpBankTransfer, Klarna, Multibanco, MxBankTransfer, P24, Paynow, Paypal, Pix, Revolut, Sofort, Swish, ThBankTransfer, UsBankTransfer, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_bank_transfer ⇒ Object
readonly
Attribute for field au_bank_transfer.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#br_bank_transfer ⇒ Object
readonly
Attribute for field br_bank_transfer.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#customer_cash_balance ⇒ Object
readonly
Attribute for field customer_cash_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#eu_bank_transfer ⇒ Object
readonly
Attribute for field eu_bank_transfer.
-
#gb_bank_transfer ⇒ Object
readonly
Attribute for field gb_bank_transfer.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#jp_bank_transfer ⇒ Object
readonly
Attribute for field jp_bank_transfer.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#mx_bank_transfer ⇒ Object
readonly
Attribute for field mx_bank_transfer.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#revolut ⇒ Object
readonly
Attribute for field revolut.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#th_bank_transfer ⇒ Object
readonly
Attribute for field th_bank_transfer.
-
#type ⇒ Object
readonly
The type of transaction-specific details of the payment method used in the refund (e.g., ‘card`).
-
#us_bank_transfer ⇒ Object
readonly
Attribute for field us_bank_transfer.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affirm ⇒ Object (readonly)
Attribute for field affirm
162 163 164 |
# File 'lib/stripe/resources/refund.rb', line 162 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
165 166 167 |
# File 'lib/stripe/resources/refund.rb', line 165 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
168 169 170 |
# File 'lib/stripe/resources/refund.rb', line 168 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
171 172 173 |
# File 'lib/stripe/resources/refund.rb', line 171 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
174 175 176 |
# File 'lib/stripe/resources/refund.rb', line 174 def amazon_pay @amazon_pay end |
#au_bank_transfer ⇒ Object (readonly)
Attribute for field au_bank_transfer
177 178 179 |
# File 'lib/stripe/resources/refund.rb', line 177 def au_bank_transfer @au_bank_transfer end |
#blik ⇒ Object (readonly)
Attribute for field blik
180 181 182 |
# File 'lib/stripe/resources/refund.rb', line 180 def blik @blik end |
#br_bank_transfer ⇒ Object (readonly)
Attribute for field br_bank_transfer
183 184 185 |
# File 'lib/stripe/resources/refund.rb', line 183 def br_bank_transfer @br_bank_transfer end |
#card ⇒ Object (readonly)
Attribute for field card
186 187 188 |
# File 'lib/stripe/resources/refund.rb', line 186 def card @card end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
189 190 191 |
# File 'lib/stripe/resources/refund.rb', line 189 def cashapp @cashapp end |
#customer_cash_balance ⇒ Object (readonly)
Attribute for field customer_cash_balance
192 193 194 |
# File 'lib/stripe/resources/refund.rb', line 192 def customer_cash_balance @customer_cash_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
195 196 197 |
# File 'lib/stripe/resources/refund.rb', line 195 def eps @eps end |
#eu_bank_transfer ⇒ Object (readonly)
Attribute for field eu_bank_transfer
198 199 200 |
# File 'lib/stripe/resources/refund.rb', line 198 def eu_bank_transfer @eu_bank_transfer end |
#gb_bank_transfer ⇒ Object (readonly)
Attribute for field gb_bank_transfer
201 202 203 |
# File 'lib/stripe/resources/refund.rb', line 201 def gb_bank_transfer @gb_bank_transfer end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
204 205 206 |
# File 'lib/stripe/resources/refund.rb', line 204 def giropay @giropay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
207 208 209 |
# File 'lib/stripe/resources/refund.rb', line 207 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
210 211 212 |
# File 'lib/stripe/resources/refund.rb', line 210 def id_bank_transfer @id_bank_transfer end |
#jp_bank_transfer ⇒ Object (readonly)
Attribute for field jp_bank_transfer
213 214 215 |
# File 'lib/stripe/resources/refund.rb', line 213 def jp_bank_transfer @jp_bank_transfer end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
216 217 218 |
# File 'lib/stripe/resources/refund.rb', line 216 def klarna @klarna end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
219 220 221 |
# File 'lib/stripe/resources/refund.rb', line 219 def multibanco @multibanco end |
#mx_bank_transfer ⇒ Object (readonly)
Attribute for field mx_bank_transfer
222 223 224 |
# File 'lib/stripe/resources/refund.rb', line 222 def mx_bank_transfer @mx_bank_transfer end |
#p24 ⇒ Object (readonly)
Attribute for field p24
225 226 227 |
# File 'lib/stripe/resources/refund.rb', line 225 def p24 @p24 end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
228 229 230 |
# File 'lib/stripe/resources/refund.rb', line 228 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
231 232 233 |
# File 'lib/stripe/resources/refund.rb', line 231 def paypal @paypal end |
#pix ⇒ Object (readonly)
Attribute for field pix
234 235 236 |
# File 'lib/stripe/resources/refund.rb', line 234 def pix @pix end |
#revolut ⇒ Object (readonly)
Attribute for field revolut
237 238 239 |
# File 'lib/stripe/resources/refund.rb', line 237 def revolut @revolut end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
240 241 242 |
# File 'lib/stripe/resources/refund.rb', line 240 def sofort @sofort end |
#swish ⇒ Object (readonly)
Attribute for field swish
243 244 245 |
# File 'lib/stripe/resources/refund.rb', line 243 def swish @swish end |
#th_bank_transfer ⇒ Object (readonly)
Attribute for field th_bank_transfer
246 247 248 |
# File 'lib/stripe/resources/refund.rb', line 246 def th_bank_transfer @th_bank_transfer end |
#type ⇒ Object (readonly)
The type of transaction-specific details of the payment method used in the refund (e.g., ‘card`). An additional hash is included on `destination_details` with a name matching this value. It contains information specific to the refund transaction.
249 250 251 |
# File 'lib/stripe/resources/refund.rb', line 249 def type @type end |
#us_bank_transfer ⇒ Object (readonly)
Attribute for field us_bank_transfer
252 253 254 |
# File 'lib/stripe/resources/refund.rb', line 252 def us_bank_transfer @us_bank_transfer end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
255 256 257 |
# File 'lib/stripe/resources/refund.rb', line 255 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
258 259 260 |
# File 'lib/stripe/resources/refund.rb', line 258 def zip @zip end |