Class: Stripe::Refund::ListParams
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Refund::ListParams
- Defined in:
- lib/stripe/resources/refund.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#charge ⇒ Object
Only return refunds for the charge specified by this charge ID.
-
#created ⇒ Object
Only return refunds that were created during the given date interval.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#payment_intent ⇒ Object
Only return refunds for the PaymentIntent specified by this ID.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(charge: nil, created: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from Stripe::RequestParams
Constructor Details
#initialize(charge: nil, created: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 |
# File 'lib/stripe/resources/refund.rb', line 629 def initialize( charge: nil, created: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil ) @charge = charge @created = created @ending_before = ending_before @expand = @limit = limit @payment_intent = payment_intent @starting_after = starting_after end |
Instance Attribute Details
#charge ⇒ Object
Only return refunds for the charge specified by this charge ID.
615 616 617 |
# File 'lib/stripe/resources/refund.rb', line 615 def charge @charge end |
#created ⇒ Object
Only return refunds that were created during the given date interval.
617 618 619 |
# File 'lib/stripe/resources/refund.rb', line 617 def created @created end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
619 620 621 |
# File 'lib/stripe/resources/refund.rb', line 619 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
621 622 623 |
# File 'lib/stripe/resources/refund.rb', line 621 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
623 624 625 |
# File 'lib/stripe/resources/refund.rb', line 623 def limit @limit end |
#payment_intent ⇒ Object
Only return refunds for the PaymentIntent specified by this ID.
625 626 627 |
# File 'lib/stripe/resources/refund.rb', line 625 def payment_intent @payment_intent end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
627 628 629 |
# File 'lib/stripe/resources/refund.rb', line 627 def starting_after @starting_after end |