Class: Stripe::Refund::ListParams

Inherits:
Stripe::RequestParams show all
Defined in:
lib/stripe/resources/refund.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

#to_h

Constructor Details

#initialize(charge: nil, created: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/stripe/resources/refund.rb', line 266

def initialize(
  charge: nil,
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  payment_intent: nil,
  starting_after: nil
)
  @charge = charge
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @payment_intent = payment_intent
  @starting_after = starting_after
end

Instance Attribute Details

#chargeObject

Only return refunds for the charge specified by this charge ID.



252
253
254
# File 'lib/stripe/resources/refund.rb', line 252

def charge
  @charge
end

#createdObject

Only return refunds that were created during the given date interval.



254
255
256
# File 'lib/stripe/resources/refund.rb', line 254

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



256
257
258
# File 'lib/stripe/resources/refund.rb', line 256

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



258
259
260
# File 'lib/stripe/resources/refund.rb', line 258

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



260
261
262
# File 'lib/stripe/resources/refund.rb', line 260

def limit
  @limit
end

#payment_intentObject

Only return refunds for the PaymentIntent specified by this ID.



262
263
264
# File 'lib/stripe/resources/refund.rb', line 262

def payment_intent
  @payment_intent
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



264
265
266
# File 'lib/stripe/resources/refund.rb', line 264

def starting_after
  @starting_after
end