Class: Stripe::Refund::ListParams
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Refund::ListParams
- Defined in:
- lib/stripe/resources/refund.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#charge ⇒ Object
Only return refunds for the charge specified by this charge ID.
-
#created ⇒ Object
Only return refunds that were created during the given date interval.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#payment_intent ⇒ Object
Only return refunds for the PaymentIntent specified by this ID.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(charge: nil, created: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from Stripe::RequestParams
Constructor Details
#initialize(charge: nil, created: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/stripe/resources/refund.rb', line 325 def initialize( charge: nil, created: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil ) @charge = charge @created = created @ending_before = ending_before @expand = @limit = limit @payment_intent = payment_intent @starting_after = starting_after end |
Instance Attribute Details
#charge ⇒ Object
Only return refunds for the charge specified by this charge ID.
305 306 307 |
# File 'lib/stripe/resources/refund.rb', line 305 def charge @charge end |
#created ⇒ Object
Only return refunds that were created during the given date interval.
308 309 310 |
# File 'lib/stripe/resources/refund.rb', line 308 def created @created end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
311 312 313 |
# File 'lib/stripe/resources/refund.rb', line 311 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
314 315 316 |
# File 'lib/stripe/resources/refund.rb', line 314 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
317 318 319 |
# File 'lib/stripe/resources/refund.rb', line 317 def limit @limit end |
#payment_intent ⇒ Object
Only return refunds for the PaymentIntent specified by this ID.
320 321 322 |
# File 'lib/stripe/resources/refund.rb', line 320 def payment_intent @payment_intent end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
323 324 325 |
# File 'lib/stripe/resources/refund.rb', line 323 def starting_after @starting_after end |