Class: Stripe::RefundService::UpdateParams

Inherits:
Stripe::RequestParams show all
Defined in:
lib/stripe/services/refund_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

#to_h

Constructor Details

#initialize(expand: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



128
129
130
131
# File 'lib/stripe/services/refund_service.rb', line 128

def initialize(expand: nil, metadata: nil)
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



124
125
126
# File 'lib/stripe/services/refund_service.rb', line 124

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



126
127
128
# File 'lib/stripe/services/refund_service.rb', line 126

def 
  @metadata
end