Class: Stripe::Reporting::ReportRun::CreateParams

Inherits:
Stripe::RequestParams show all
Defined in:
lib/stripe/resources/reporting/report_run.rb

Defined Under Namespace

Classes: Parameters

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Stripe::RequestParams

#to_h

Constructor Details

#initialize(expand: nil, parameters: nil, report_type: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



132
133
134
135
136
# File 'lib/stripe/resources/reporting/report_run.rb', line 132

def initialize(expand: nil, parameters: nil, report_type: nil)
  @expand = expand
  @parameters = parameters
  @report_type = report_type
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



126
127
128
# File 'lib/stripe/resources/reporting/report_run.rb', line 126

def expand
  @expand
end

#parametersObject

Parameters specifying how the report should be run. Different Report Types have different required and optional parameters, listed in the [API Access to Reports](stripe.com/docs/reporting/statements/api) documentation.



128
129
130
# File 'lib/stripe/resources/reporting/report_run.rb', line 128

def parameters
  @parameters
end

#report_typeObject

The ID of the [report type](stripe.com/docs/reporting/statements/api#report-types) to run, such as ‘“balance.summary.1”`.



130
131
132
# File 'lib/stripe/resources/reporting/report_run.rb', line 130

def report_type
  @report_type
end