Class: Stripe::Reporting::ReportRun::Parameters
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Reporting::ReportRun::Parameters
- Defined in:
- lib/stripe/resources/reporting/report_run.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#columns ⇒ Object
readonly
The set of output columns requested for inclusion in the report run.
-
#connected_account ⇒ Object
readonly
Connected account ID by which to filter the report run.
-
#currency ⇒ Object
readonly
Currency of objects to be included in the report run.
-
#interval_end ⇒ Object
readonly
Ending timestamp of data to be included in the report run.
-
#interval_start ⇒ Object
readonly
Starting timestamp of data to be included in the report run.
-
#payout ⇒ Object
readonly
Payout ID by which to filter the report run.
-
#reporting_category ⇒ Object
readonly
Category of balance transactions to be included in the report run.
-
#timezone ⇒ Object
readonly
Defaults to ‘Etc/UTC`.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#columns ⇒ Object (readonly)
The set of output columns requested for inclusion in the report run.
25 26 27 |
# File 'lib/stripe/resources/reporting/report_run.rb', line 25 def columns @columns end |
#connected_account ⇒ Object (readonly)
Connected account ID by which to filter the report run.
28 29 30 |
# File 'lib/stripe/resources/reporting/report_run.rb', line 28 def connected_account @connected_account end |
#currency ⇒ Object (readonly)
Currency of objects to be included in the report run.
31 32 33 |
# File 'lib/stripe/resources/reporting/report_run.rb', line 31 def currency @currency end |
#interval_end ⇒ Object (readonly)
Ending timestamp of data to be included in the report run. Can be any UTC timestamp between 1 second after the user specified ‘interval_start` and 1 second before this report’s last ‘data_available_end` value.
34 35 36 |
# File 'lib/stripe/resources/reporting/report_run.rb', line 34 def interval_end @interval_end end |
#interval_start ⇒ Object (readonly)
Starting timestamp of data to be included in the report run. Can be any UTC timestamp between 1 second after this report’s ‘data_available_start` and 1 second before the user specified `interval_end` value.
37 38 39 |
# File 'lib/stripe/resources/reporting/report_run.rb', line 37 def interval_start @interval_start end |
#payout ⇒ Object (readonly)
Payout ID by which to filter the report run.
40 41 42 |
# File 'lib/stripe/resources/reporting/report_run.rb', line 40 def payout @payout end |
#reporting_category ⇒ Object (readonly)
Category of balance transactions to be included in the report run.
43 44 45 |
# File 'lib/stripe/resources/reporting/report_run.rb', line 43 def reporting_category @reporting_category end |
#timezone ⇒ Object (readonly)
Defaults to ‘Etc/UTC`. The output timezone for all timestamps in the report. A list of possible time zone values is maintained at the [IANA Time Zone Database](www.iana.org/time-zones). Has no effect on `interval_start` or `interval_end`.
46 47 48 |
# File 'lib/stripe/resources/reporting/report_run.rb', line 46 def timezone @timezone end |