Class: Stripe::Reporting::ReportRunService::CreateParams
- Inherits:
-
Stripe::RequestParams
- Object
- Stripe::RequestParams
- Stripe::Reporting::ReportRunService::CreateParams
- Defined in:
- lib/stripe/services/reporting/report_run_service.rb
Defined Under Namespace
Classes: Parameters
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#parameters ⇒ Object
Parameters specifying how the report should be run.
-
#report_type ⇒ Object
The ID of the [report type](stripe.com/docs/reporting/statements/api#report-types) to run, such as ‘“balance.summary.1”`.
Instance Method Summary collapse
-
#initialize(expand: nil, parameters: nil, report_type: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from Stripe::RequestParams
Constructor Details
#initialize(expand: nil, parameters: nil, report_type: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
113 114 115 116 117 |
# File 'lib/stripe/services/reporting/report_run_service.rb', line 113 def initialize(expand: nil, parameters: nil, report_type: nil) @expand = @parameters = parameters @report_type = report_type end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
105 106 107 |
# File 'lib/stripe/services/reporting/report_run_service.rb', line 105 def @expand end |
#parameters ⇒ Object
Parameters specifying how the report should be run. Different Report Types have different required and optional parameters, listed in the [API Access to Reports](stripe.com/docs/reporting/statements/api) documentation.
108 109 110 |
# File 'lib/stripe/services/reporting/report_run_service.rb', line 108 def parameters @parameters end |
#report_type ⇒ Object
The ID of the [report type](stripe.com/docs/reporting/statements/api#report-types) to run, such as ‘“balance.summary.1”`.
111 112 113 |
# File 'lib/stripe/services/reporting/report_run_service.rb', line 111 def report_type @report_type end |