Class: Stripe::Review
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Review
- Extended by:
- APIOperations::List
- Defined in:
- lib/stripe/resources/review.rb
Overview
Reviews can be used to supplement automated fraud detection with human expertise.
Learn more about [Radar](stripe.com/radar) and reviewing payments [here](stripe.com/docs/radar/reviews).
Defined Under Namespace
Classes: ApproveParams, IpAddressLocation, ListParams, RetrieveParams, Session
Constant Summary collapse
- OBJECT_NAME =
"review"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_zip ⇒ Object
readonly
The ZIP or postal code of the card used, if applicable.
-
#charge ⇒ Object
readonly
The charge associated with this review.
-
#closed_reason ⇒ Object
readonly
The reason the review was closed, or null if it has not yet been closed.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#ip_address ⇒ Object
readonly
The IP address where the payment originated.
-
#ip_address_location ⇒ Object
readonly
Information related to the location of the payment.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#open ⇒ Object
readonly
If ‘true`, the review needs action.
-
#opened_reason ⇒ Object
readonly
The reason the review was opened.
-
#payment_intent ⇒ Object
readonly
The PaymentIntent ID associated with this review, if one exists.
-
#reason ⇒ Object
readonly
The reason the review is currently open or closed.
-
#session ⇒ Object
readonly
Information related to the browsing session of the user who initiated the payment.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.approve(review, params = {}, opts = {}) ⇒ Object
Approves a Review object, closing it and removing it from the list of reviews.
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Review objects that have open set to true.
- .object_name ⇒ Object
Instance Method Summary collapse
-
#approve(params = {}, opts = {}) ⇒ Object
Approves a Review object, closing it and removing it from the list of reviews.
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_zip ⇒ Object (readonly)
The ZIP or postal code of the card used, if applicable.
97 98 99 |
# File 'lib/stripe/resources/review.rb', line 97 def billing_zip @billing_zip end |
#charge ⇒ Object (readonly)
The charge associated with this review.
99 100 101 |
# File 'lib/stripe/resources/review.rb', line 99 def charge @charge end |
#closed_reason ⇒ Object (readonly)
The reason the review was closed, or null if it has not yet been closed. One of ‘approved`, `refunded`, `refunded_as_fraud`, `disputed`, or `redacted`.
101 102 103 |
# File 'lib/stripe/resources/review.rb', line 101 def closed_reason @closed_reason end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
103 104 105 |
# File 'lib/stripe/resources/review.rb', line 103 def created @created end |
#id ⇒ Object (readonly)
Unique identifier for the object.
105 106 107 |
# File 'lib/stripe/resources/review.rb', line 105 def id @id end |
#ip_address ⇒ Object (readonly)
The IP address where the payment originated.
107 108 109 |
# File 'lib/stripe/resources/review.rb', line 107 def ip_address @ip_address end |
#ip_address_location ⇒ Object (readonly)
Information related to the location of the payment. Note that this information is an approximation and attempts to locate the nearest population center - it should not be used to determine a specific address.
109 110 111 |
# File 'lib/stripe/resources/review.rb', line 109 def ip_address_location @ip_address_location end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
111 112 113 |
# File 'lib/stripe/resources/review.rb', line 111 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
113 114 115 |
# File 'lib/stripe/resources/review.rb', line 113 def object @object end |
#open ⇒ Object (readonly)
If ‘true`, the review needs action.
115 116 117 |
# File 'lib/stripe/resources/review.rb', line 115 def open @open end |
#opened_reason ⇒ Object (readonly)
The reason the review was opened. One of ‘rule` or `manual`.
117 118 119 |
# File 'lib/stripe/resources/review.rb', line 117 def opened_reason @opened_reason end |
#payment_intent ⇒ Object (readonly)
The PaymentIntent ID associated with this review, if one exists.
119 120 121 |
# File 'lib/stripe/resources/review.rb', line 119 def payment_intent @payment_intent end |
#reason ⇒ Object (readonly)
The reason the review is currently open or closed. One of ‘rule`, `manual`, `approved`, `refunded`, `refunded_as_fraud`, `disputed`, or `redacted`.
121 122 123 |
# File 'lib/stripe/resources/review.rb', line 121 def reason @reason end |
#session ⇒ Object (readonly)
Information related to the browsing session of the user who initiated the payment.
123 124 125 |
# File 'lib/stripe/resources/review.rb', line 123 def session @session end |
Class Method Details
.approve(review, params = {}, opts = {}) ⇒ Object
Approves a Review object, closing it and removing it from the list of reviews.
136 137 138 139 140 141 142 143 |
# File 'lib/stripe/resources/review.rb', line 136 def self.approve(review, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/reviews/%<review>s/approve", { review: CGI.escape(review) }), params: params, opts: opts ) end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Review objects that have open set to true. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
146 147 148 |
# File 'lib/stripe/resources/review.rb', line 146 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/reviews", params: params, opts: opts) end |
.object_name ⇒ Object
13 14 15 |
# File 'lib/stripe/resources/review.rb', line 13 def self.object_name "review" end |
Instance Method Details
#approve(params = {}, opts = {}) ⇒ Object
Approves a Review object, closing it and removing it from the list of reviews.
126 127 128 129 130 131 132 133 |
# File 'lib/stripe/resources/review.rb', line 126 def approve(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/reviews/%<review>s/approve", { review: CGI.escape(self["id"]) }), params: params, opts: opts ) end |