Method: Stripe::SearchResultObject.empty_search_result
- Defined in:
- lib/stripe/search_result_object.rb
.empty_search_result(opts = {}) ⇒ Object
An empty search result object. This is returned from next when we know that there isn’t a next page in order to replicate the behavior of the API when it attempts to return a page beyond the last.
22 23 24 |
# File 'lib/stripe/search_result_object.rb', line 22 def self.empty_search_result(opts = {}) SearchResultObject.construct_from({ data: [] }, opts, :v1) end |