Class: Stripe::SetupAttempt

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/setup_attempt.rb

Overview

A SetupAttempt describes one attempted confirmation of a SetupIntent, whether that confirmation is successful or unsuccessful. You can use SetupAttempts to inspect details of a specific attempt at setting up a payment method using a SetupIntent.

Defined Under Namespace

Classes: PaymentMethodDetails, SetupError

Constant Summary collapse

OBJECT_NAME =
"setup_attempt"

Constants inherited from StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applicationObject (readonly)

The value of [application](docs.stripe.com/api/setup_intents/object#setup_intent_object-application) on the SetupIntent at the time of this confirmation.



618
619
620
# File 'lib/stripe/resources/setup_attempt.rb', line 618

def application
  @application
end

#attach_to_selfObject (readonly)

If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.

It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.



622
623
624
# File 'lib/stripe/resources/setup_attempt.rb', line 622

def attach_to_self
  @attach_to_self
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



624
625
626
# File 'lib/stripe/resources/setup_attempt.rb', line 624

def created
  @created
end

#customerObject (readonly)

The value of [customer](docs.stripe.com/api/setup_intents/object#setup_intent_object-customer) on the SetupIntent at the time of this confirmation.



626
627
628
# File 'lib/stripe/resources/setup_attempt.rb', line 626

def customer
  @customer
end

#customer_accountObject (readonly)

The value of [customer_account](docs.stripe.com/api/setup_intents/object#setup_intent_object-customer_account) on the SetupIntent at the time of this confirmation.



628
629
630
# File 'lib/stripe/resources/setup_attempt.rb', line 628

def 
  @customer_account
end

#flow_directionsObject (readonly)

Indicates the directions of money movement for which this payment method is intended to be used.

Include ‘inbound` if you intend to use the payment method as the origin to pull funds from. Include `outbound` if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.



632
633
634
# File 'lib/stripe/resources/setup_attempt.rb', line 632

def flow_directions
  @flow_directions
end

#idObject (readonly)

Unique identifier for the object.



634
635
636
# File 'lib/stripe/resources/setup_attempt.rb', line 634

def id
  @id
end

#livemodeObject (readonly)

If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.



636
637
638
# File 'lib/stripe/resources/setup_attempt.rb', line 636

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



638
639
640
# File 'lib/stripe/resources/setup_attempt.rb', line 638

def object
  @object
end

#on_behalf_ofObject (readonly)

The value of [on_behalf_of](docs.stripe.com/api/setup_intents/object#setup_intent_object-on_behalf_of) on the SetupIntent at the time of this confirmation.



640
641
642
# File 'lib/stripe/resources/setup_attempt.rb', line 640

def on_behalf_of
  @on_behalf_of
end

#payment_methodObject (readonly)

ID of the payment method used with this SetupAttempt.



642
643
644
# File 'lib/stripe/resources/setup_attempt.rb', line 642

def payment_method
  @payment_method
end

#payment_method_detailsObject (readonly)

Attribute for field payment_method_details



644
645
646
# File 'lib/stripe/resources/setup_attempt.rb', line 644

def payment_method_details
  @payment_method_details
end

#setup_errorObject (readonly)

The error encountered during this attempt to confirm the SetupIntent, if any.



646
647
648
# File 'lib/stripe/resources/setup_attempt.rb', line 646

def setup_error
  @setup_error
end

#setup_intentObject (readonly)

ID of the SetupIntent that this attempt belongs to.



648
649
650
# File 'lib/stripe/resources/setup_attempt.rb', line 648

def setup_intent
  @setup_intent
end

#statusObject (readonly)

Status of this SetupAttempt, one of ‘requires_confirmation`, `requires_action`, `processing`, `succeeded`, `failed`, or `abandoned`.



650
651
652
# File 'lib/stripe/resources/setup_attempt.rb', line 650

def status
  @status
end

#usageObject (readonly)

The value of [usage](docs.stripe.com/api/setup_intents/object#setup_intent_object-usage) on the SetupIntent at the time of this confirmation, one of ‘off_session` or `on_session`.



652
653
654
# File 'lib/stripe/resources/setup_attempt.rb', line 652

def usage
  @usage
end

Class Method Details

.field_remappingsObject



663
664
665
# File 'lib/stripe/resources/setup_attempt.rb', line 663

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



659
660
661
# File 'lib/stripe/resources/setup_attempt.rb', line 659

def self.inner_class_types
  @inner_class_types = { payment_method_details: PaymentMethodDetails, setup_error: SetupError }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of SetupAttempts that associate with a provided SetupIntent.



655
656
657
# File 'lib/stripe/resources/setup_attempt.rb', line 655

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/setup_attempts", params: params, opts: opts)
end

.object_nameObject



13
14
15
# File 'lib/stripe/resources/setup_attempt.rb', line 13

def self.object_name
  "setup_attempt"
end