Class: Stripe::SetupAttempt
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::SetupAttempt
- Extended by:
- APIOperations::List
- Defined in:
- lib/stripe/resources/setup_attempt.rb
Overview
A SetupAttempt describes one attempted confirmation of a SetupIntent, whether that confirmation is successful or unsuccessful. You can use SetupAttempts to inspect details of a specific attempt at setting up a payment method using a SetupIntent.
Defined Under Namespace
Classes: PaymentMethodDetails, SetupError
Constant Summary collapse
- OBJECT_NAME =
"setup_attempt"
Constants inherited from StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#application ⇒ Object
readonly
The value of [application](stripe.com/docs/api/setup_intents/object#setup_intent_object-application) on the SetupIntent at the time of this confirmation.
-
#attach_to_self ⇒ Object
readonly
If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#customer ⇒ Object
readonly
The value of [customer](stripe.com/docs/api/setup_intents/object#setup_intent_object-customer) on the SetupIntent at the time of this confirmation.
-
#customer_account ⇒ Object
readonly
The value of [customer_account](stripe.com/docs/api/setup_intents/object#setup_intent_object-customer_account) on the SetupIntent at the time of this confirmation.
-
#flow_directions ⇒ Object
readonly
Indicates the directions of money movement for which this payment method is intended to be used.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#on_behalf_of ⇒ Object
readonly
The value of [on_behalf_of](stripe.com/docs/api/setup_intents/object#setup_intent_object-on_behalf_of) on the SetupIntent at the time of this confirmation.
-
#payment_method ⇒ Object
readonly
ID of the payment method used with this SetupAttempt.
-
#payment_method_details ⇒ Object
readonly
Attribute for field payment_method_details.
-
#setup_error ⇒ Object
readonly
The error encountered during this attempt to confirm the SetupIntent, if any.
-
#setup_intent ⇒ Object
readonly
ID of the SetupIntent that this attempt belongs to.
-
#status ⇒ Object
readonly
Status of this SetupAttempt, one of ‘requires_confirmation`, `requires_action`, `processing`, `succeeded`, `failed`, or `abandoned`.
-
#usage ⇒ Object
readonly
The value of [usage](stripe.com/docs/api/setup_intents/object#setup_intent_object-usage) on the SetupIntent at the time of this confirmation, one of ‘off_session` or `on_session`.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of SetupAttempts that associate with a provided SetupIntent.
- .object_name ⇒ Object
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#application ⇒ Object (readonly)
The value of [application](stripe.com/docs/api/setup_intents/object#setup_intent_object-application) on the SetupIntent at the time of this confirmation.
625 626 627 |
# File 'lib/stripe/resources/setup_attempt.rb', line 625 def application @application end |
#attach_to_self ⇒ Object (readonly)
If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.
It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.
629 630 631 |
# File 'lib/stripe/resources/setup_attempt.rb', line 629 def attach_to_self @attach_to_self end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
631 632 633 |
# File 'lib/stripe/resources/setup_attempt.rb', line 631 def created @created end |
#customer ⇒ Object (readonly)
The value of [customer](stripe.com/docs/api/setup_intents/object#setup_intent_object-customer) on the SetupIntent at the time of this confirmation.
633 634 635 |
# File 'lib/stripe/resources/setup_attempt.rb', line 633 def customer @customer end |
#customer_account ⇒ Object (readonly)
The value of [customer_account](stripe.com/docs/api/setup_intents/object#setup_intent_object-customer_account) on the SetupIntent at the time of this confirmation.
635 636 637 |
# File 'lib/stripe/resources/setup_attempt.rb', line 635 def customer_account @customer_account end |
#flow_directions ⇒ Object (readonly)
Indicates the directions of money movement for which this payment method is intended to be used.
Include ‘inbound` if you intend to use the payment method as the origin to pull funds from. Include `outbound` if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.
639 640 641 |
# File 'lib/stripe/resources/setup_attempt.rb', line 639 def flow_directions @flow_directions end |
#id ⇒ Object (readonly)
Unique identifier for the object.
641 642 643 |
# File 'lib/stripe/resources/setup_attempt.rb', line 641 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
643 644 645 |
# File 'lib/stripe/resources/setup_attempt.rb', line 643 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
645 646 647 |
# File 'lib/stripe/resources/setup_attempt.rb', line 645 def object @object end |
#on_behalf_of ⇒ Object (readonly)
The value of [on_behalf_of](stripe.com/docs/api/setup_intents/object#setup_intent_object-on_behalf_of) on the SetupIntent at the time of this confirmation.
647 648 649 |
# File 'lib/stripe/resources/setup_attempt.rb', line 647 def on_behalf_of @on_behalf_of end |
#payment_method ⇒ Object (readonly)
ID of the payment method used with this SetupAttempt.
649 650 651 |
# File 'lib/stripe/resources/setup_attempt.rb', line 649 def payment_method @payment_method end |
#payment_method_details ⇒ Object (readonly)
Attribute for field payment_method_details
651 652 653 |
# File 'lib/stripe/resources/setup_attempt.rb', line 651 def payment_method_details @payment_method_details end |
#setup_error ⇒ Object (readonly)
The error encountered during this attempt to confirm the SetupIntent, if any.
653 654 655 |
# File 'lib/stripe/resources/setup_attempt.rb', line 653 def setup_error @setup_error end |
#setup_intent ⇒ Object (readonly)
ID of the SetupIntent that this attempt belongs to.
655 656 657 |
# File 'lib/stripe/resources/setup_attempt.rb', line 655 def setup_intent @setup_intent end |
#status ⇒ Object (readonly)
Status of this SetupAttempt, one of ‘requires_confirmation`, `requires_action`, `processing`, `succeeded`, `failed`, or `abandoned`.
657 658 659 |
# File 'lib/stripe/resources/setup_attempt.rb', line 657 def status @status end |
#usage ⇒ Object (readonly)
The value of [usage](stripe.com/docs/api/setup_intents/object#setup_intent_object-usage) on the SetupIntent at the time of this confirmation, one of ‘off_session` or `on_session`.
659 660 661 |
# File 'lib/stripe/resources/setup_attempt.rb', line 659 def usage @usage end |
Class Method Details
.field_remappings ⇒ Object
670 671 672 |
# File 'lib/stripe/resources/setup_attempt.rb', line 670 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
666 667 668 |
# File 'lib/stripe/resources/setup_attempt.rb', line 666 def self.inner_class_types @inner_class_types = { payment_method_details: PaymentMethodDetails, setup_error: SetupError } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of SetupAttempts that associate with a provided SetupIntent.
662 663 664 |
# File 'lib/stripe/resources/setup_attempt.rb', line 662 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/setup_attempts", params: params, opts: opts) end |
.object_name ⇒ Object
13 14 15 |
# File 'lib/stripe/resources/setup_attempt.rb', line 13 def self.object_name "setup_attempt" end |