Class: Stripe::SetupAttempt

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/setup_attempt.rb

Overview

A SetupAttempt describes one attempted confirmation of a SetupIntent, whether that confirmation is successful or unsuccessful. You can use SetupAttempts to inspect details of a specific attempt at setting up a payment method using a SetupIntent.

Defined Under Namespace

Classes: ListParams, PaymentMethodDetails, SetupError

Constant Summary collapse

OBJECT_NAME =
"setup_attempt"

Constants inherited from StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applicationObject (readonly)

The value of [application](stripe.com/docs/api/setup_intents/object#setup_intent_object-application) on the SetupIntent at the time of this confirmation.



373
374
375
# File 'lib/stripe/resources/setup_attempt.rb', line 373

def application
  @application
end

#attach_to_selfObject (readonly)

If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.

It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.



377
378
379
# File 'lib/stripe/resources/setup_attempt.rb', line 377

def attach_to_self
  @attach_to_self
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



379
380
381
# File 'lib/stripe/resources/setup_attempt.rb', line 379

def created
  @created
end

#customerObject (readonly)

The value of [customer](stripe.com/docs/api/setup_intents/object#setup_intent_object-customer) on the SetupIntent at the time of this confirmation.



381
382
383
# File 'lib/stripe/resources/setup_attempt.rb', line 381

def customer
  @customer
end

#customer_accountObject (readonly)

The value of [customer_account](stripe.com/docs/api/setup_intents/object#setup_intent_object-customer_account) on the SetupIntent at the time of this confirmation.



383
384
385
# File 'lib/stripe/resources/setup_attempt.rb', line 383

def 
  @customer_account
end

#flow_directionsObject (readonly)

Indicates the directions of money movement for which this payment method is intended to be used.

Include ‘inbound` if you intend to use the payment method as the origin to pull funds from. Include `outbound` if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.



387
388
389
# File 'lib/stripe/resources/setup_attempt.rb', line 387

def flow_directions
  @flow_directions
end

#idObject (readonly)

Unique identifier for the object.



389
390
391
# File 'lib/stripe/resources/setup_attempt.rb', line 389

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



391
392
393
# File 'lib/stripe/resources/setup_attempt.rb', line 391

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



393
394
395
# File 'lib/stripe/resources/setup_attempt.rb', line 393

def object
  @object
end

#on_behalf_ofObject (readonly)

The value of [on_behalf_of](stripe.com/docs/api/setup_intents/object#setup_intent_object-on_behalf_of) on the SetupIntent at the time of this confirmation.



395
396
397
# File 'lib/stripe/resources/setup_attempt.rb', line 395

def on_behalf_of
  @on_behalf_of
end

#payment_methodObject (readonly)

ID of the payment method used with this SetupAttempt.



397
398
399
# File 'lib/stripe/resources/setup_attempt.rb', line 397

def payment_method
  @payment_method
end

#payment_method_detailsObject (readonly)

Attribute for field payment_method_details



399
400
401
# File 'lib/stripe/resources/setup_attempt.rb', line 399

def payment_method_details
  @payment_method_details
end

#setup_errorObject (readonly)

The error encountered during this attempt to confirm the SetupIntent, if any.



401
402
403
# File 'lib/stripe/resources/setup_attempt.rb', line 401

def setup_error
  @setup_error
end

#setup_intentObject (readonly)

ID of the SetupIntent that this attempt belongs to.



403
404
405
# File 'lib/stripe/resources/setup_attempt.rb', line 403

def setup_intent
  @setup_intent
end

#statusObject (readonly)

Status of this SetupAttempt, one of ‘requires_confirmation`, `requires_action`, `processing`, `succeeded`, `failed`, or `abandoned`.



405
406
407
# File 'lib/stripe/resources/setup_attempt.rb', line 405

def status
  @status
end

#usageObject (readonly)

The value of [usage](stripe.com/docs/api/setup_intents/object#setup_intent_object-usage) on the SetupIntent at the time of this confirmation, one of ‘off_session` or `on_session`.



407
408
409
# File 'lib/stripe/resources/setup_attempt.rb', line 407

def usage
  @usage
end

Class Method Details

.list(params = {}, opts = {}) ⇒ Object

Returns a list of SetupAttempts that associate with a provided SetupIntent.



410
411
412
# File 'lib/stripe/resources/setup_attempt.rb', line 410

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/setup_attempts", params: params, opts: opts)
end

.object_nameObject



13
14
15
# File 'lib/stripe/resources/setup_attempt.rb', line 13

def self.object_name
  "setup_attempt"
end