Class: Stripe::SetupAttempt

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/setup_attempt.rb

Overview

A SetupAttempt describes one attempted confirmation of a SetupIntent, whether that confirmation is successful or unsuccessful. You can use SetupAttempts to inspect details of a specific attempt at setting up a payment method using a SetupIntent.

Defined Under Namespace

Classes: ListParams, PaymentMethodDetails, SetupError

Constant Summary collapse

OBJECT_NAME =
"setup_attempt"

Constants inherited from StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applicationObject (readonly)

The value of [application](stripe.com/docs/api/setup_intents/object#setup_intent_object-application) on the SetupIntent at the time of this confirmation.



356
357
358
# File 'lib/stripe/resources/setup_attempt.rb', line 356

def application
  @application
end

#attach_to_selfObject (readonly)

If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.

It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.



360
361
362
# File 'lib/stripe/resources/setup_attempt.rb', line 360

def attach_to_self
  @attach_to_self
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



362
363
364
# File 'lib/stripe/resources/setup_attempt.rb', line 362

def created
  @created
end

#customerObject (readonly)

The value of [customer](stripe.com/docs/api/setup_intents/object#setup_intent_object-customer) on the SetupIntent at the time of this confirmation.



364
365
366
# File 'lib/stripe/resources/setup_attempt.rb', line 364

def customer
  @customer
end

#flow_directionsObject (readonly)

Indicates the directions of money movement for which this payment method is intended to be used.

Include ‘inbound` if you intend to use the payment method as the origin to pull funds from. Include `outbound` if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.



368
369
370
# File 'lib/stripe/resources/setup_attempt.rb', line 368

def flow_directions
  @flow_directions
end

#idObject (readonly)

Unique identifier for the object.



370
371
372
# File 'lib/stripe/resources/setup_attempt.rb', line 370

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



372
373
374
# File 'lib/stripe/resources/setup_attempt.rb', line 372

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



374
375
376
# File 'lib/stripe/resources/setup_attempt.rb', line 374

def object
  @object
end

#on_behalf_ofObject (readonly)

The value of [on_behalf_of](stripe.com/docs/api/setup_intents/object#setup_intent_object-on_behalf_of) on the SetupIntent at the time of this confirmation.



376
377
378
# File 'lib/stripe/resources/setup_attempt.rb', line 376

def on_behalf_of
  @on_behalf_of
end

#payment_methodObject (readonly)

ID of the payment method used with this SetupAttempt.



378
379
380
# File 'lib/stripe/resources/setup_attempt.rb', line 378

def payment_method
  @payment_method
end

#payment_method_detailsObject (readonly)

Attribute for field payment_method_details



380
381
382
# File 'lib/stripe/resources/setup_attempt.rb', line 380

def payment_method_details
  @payment_method_details
end

#setup_errorObject (readonly)

The error encountered during this attempt to confirm the SetupIntent, if any.



382
383
384
# File 'lib/stripe/resources/setup_attempt.rb', line 382

def setup_error
  @setup_error
end

#setup_intentObject (readonly)

ID of the SetupIntent that this attempt belongs to.



384
385
386
# File 'lib/stripe/resources/setup_attempt.rb', line 384

def setup_intent
  @setup_intent
end

#statusObject (readonly)

Status of this SetupAttempt, one of ‘requires_confirmation`, `requires_action`, `processing`, `succeeded`, `failed`, or `abandoned`.



386
387
388
# File 'lib/stripe/resources/setup_attempt.rb', line 386

def status
  @status
end

#usageObject (readonly)

The value of [usage](stripe.com/docs/api/setup_intents/object#setup_intent_object-usage) on the SetupIntent at the time of this confirmation, one of ‘off_session` or `on_session`.



388
389
390
# File 'lib/stripe/resources/setup_attempt.rb', line 388

def usage
  @usage
end

Class Method Details

.list(params = {}, opts = {}) ⇒ Object

Returns a list of SetupAttempts that associate with a provided SetupIntent.



391
392
393
# File 'lib/stripe/resources/setup_attempt.rb', line 391

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/setup_attempts", params: params, opts: opts)
end

.object_nameObject



13
14
15
# File 'lib/stripe/resources/setup_attempt.rb', line 13

def self.object_name
  "setup_attempt"
end