Class: Stripe::SetupAttempt::PaymentMethodDetails
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SetupAttempt::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/setup_attempt.rb
Defined Under Namespace
Classes: AcssDebit, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Boleto, Card, CardPresent, Cashapp, IdBankTransfer, Ideal, KakaoPay, Klarna, KrCard, Link, NaverPay, NzBankAccount, Paypal, Payto, Pix, RevolutPay, Satispay, SepaDebit, Sofort, StripeBalance, Twint, Upi, UsBankAccount
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#stripe_balance ⇒ Object
readonly
Attribute for field stripe_balance.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of the payment method used in the SetupIntent (e.g., ‘card`).
-
#upi ⇒ Object
readonly
Attribute for field upi.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
496 497 498 |
# File 'lib/stripe/resources/setup_attempt.rb', line 496 def acss_debit @acss_debit end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
498 499 500 |
# File 'lib/stripe/resources/setup_attempt.rb', line 498 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
500 501 502 |
# File 'lib/stripe/resources/setup_attempt.rb', line 500 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
502 503 504 |
# File 'lib/stripe/resources/setup_attempt.rb', line 502 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
504 505 506 |
# File 'lib/stripe/resources/setup_attempt.rb', line 504 def bancontact @bancontact end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
506 507 508 |
# File 'lib/stripe/resources/setup_attempt.rb', line 506 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
508 509 510 |
# File 'lib/stripe/resources/setup_attempt.rb', line 508 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
510 511 512 |
# File 'lib/stripe/resources/setup_attempt.rb', line 510 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
512 513 514 |
# File 'lib/stripe/resources/setup_attempt.rb', line 512 def cashapp @cashapp end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
514 515 516 |
# File 'lib/stripe/resources/setup_attempt.rb', line 514 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
516 517 518 |
# File 'lib/stripe/resources/setup_attempt.rb', line 516 def ideal @ideal end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
518 519 520 |
# File 'lib/stripe/resources/setup_attempt.rb', line 518 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
520 521 522 |
# File 'lib/stripe/resources/setup_attempt.rb', line 520 def klarna @klarna end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
522 523 524 |
# File 'lib/stripe/resources/setup_attempt.rb', line 522 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
524 525 526 |
# File 'lib/stripe/resources/setup_attempt.rb', line 524 def link @link end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
526 527 528 |
# File 'lib/stripe/resources/setup_attempt.rb', line 526 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
528 529 530 |
# File 'lib/stripe/resources/setup_attempt.rb', line 528 def nz_bank_account @nz_bank_account end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
530 531 532 |
# File 'lib/stripe/resources/setup_attempt.rb', line 530 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
532 533 534 |
# File 'lib/stripe/resources/setup_attempt.rb', line 532 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
534 535 536 |
# File 'lib/stripe/resources/setup_attempt.rb', line 534 def pix @pix end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
536 537 538 |
# File 'lib/stripe/resources/setup_attempt.rb', line 536 def revolut_pay @revolut_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
538 539 540 |
# File 'lib/stripe/resources/setup_attempt.rb', line 538 def satispay @satispay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
540 541 542 |
# File 'lib/stripe/resources/setup_attempt.rb', line 540 def sepa_debit @sepa_debit end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
542 543 544 |
# File 'lib/stripe/resources/setup_attempt.rb', line 542 def sofort @sofort end |
#stripe_balance ⇒ Object (readonly)
Attribute for field stripe_balance
544 545 546 |
# File 'lib/stripe/resources/setup_attempt.rb', line 544 def stripe_balance @stripe_balance end |
#twint ⇒ Object (readonly)
Attribute for field twint
546 547 548 |
# File 'lib/stripe/resources/setup_attempt.rb', line 546 def twint @twint end |
#type ⇒ Object (readonly)
The type of the payment method used in the SetupIntent (e.g., ‘card`). An additional hash is included on `payment_method_details` with a name matching this value. It contains confirmation-specific information for the payment method.
548 549 550 |
# File 'lib/stripe/resources/setup_attempt.rb', line 548 def type @type end |
#upi ⇒ Object (readonly)
Attribute for field upi
550 551 552 |
# File 'lib/stripe/resources/setup_attempt.rb', line 550 def upi @upi end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
552 553 554 |
# File 'lib/stripe/resources/setup_attempt.rb', line 552 def us_bank_account @us_bank_account end |
Class Method Details
.field_remappings ⇒ Object
587 588 589 |
# File 'lib/stripe/resources/setup_attempt.rb', line 587 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 |
# File 'lib/stripe/resources/setup_attempt.rb', line 554 def self.inner_class_types @inner_class_types = { acss_debit: AcssDebit, amazon_pay: AmazonPay, au_becs_debit: AuBecsDebit, bacs_debit: BacsDebit, bancontact: Bancontact, boleto: Boleto, card: Card, card_present: CardPresent, cashapp: Cashapp, id_bank_transfer: IdBankTransfer, ideal: Ideal, kakao_pay: KakaoPay, klarna: Klarna, kr_card: KrCard, link: Link, naver_pay: NaverPay, nz_bank_account: NzBankAccount, paypal: Paypal, payto: Payto, pix: Pix, revolut_pay: RevolutPay, satispay: Satispay, sepa_debit: SepaDebit, sofort: Sofort, stripe_balance: StripeBalance, twint: Twint, upi: Upi, us_bank_account: UsBankAccount, } end |