Class: Stripe::SetupAttempt::PaymentMethodDetails
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SetupAttempt::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/setup_attempt.rb
Defined Under Namespace
Classes: AcssDebit, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Boleto, Card, CardPresent, Cashapp, IdBankTransfer, Ideal, KakaoPay, Klarna, KrCard, Link, NaverPay, NzBankAccount, Paypal, Payto, Pix, RevolutPay, SepaDebit, Sofort, StripeBalance, UsBankAccount
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#stripe_balance ⇒ Object
readonly
Attribute for field stripe_balance.
-
#type ⇒ Object
readonly
The type of the payment method used in the SetupIntent (e.g., ‘card`).
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
461 462 463 |
# File 'lib/stripe/resources/setup_attempt.rb', line 461 def acss_debit @acss_debit end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
463 464 465 |
# File 'lib/stripe/resources/setup_attempt.rb', line 463 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
465 466 467 |
# File 'lib/stripe/resources/setup_attempt.rb', line 465 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
467 468 469 |
# File 'lib/stripe/resources/setup_attempt.rb', line 467 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
469 470 471 |
# File 'lib/stripe/resources/setup_attempt.rb', line 469 def bancontact @bancontact end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
471 472 473 |
# File 'lib/stripe/resources/setup_attempt.rb', line 471 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
473 474 475 |
# File 'lib/stripe/resources/setup_attempt.rb', line 473 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
475 476 477 |
# File 'lib/stripe/resources/setup_attempt.rb', line 475 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
477 478 479 |
# File 'lib/stripe/resources/setup_attempt.rb', line 477 def cashapp @cashapp end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
479 480 481 |
# File 'lib/stripe/resources/setup_attempt.rb', line 479 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
481 482 483 |
# File 'lib/stripe/resources/setup_attempt.rb', line 481 def ideal @ideal end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
483 484 485 |
# File 'lib/stripe/resources/setup_attempt.rb', line 483 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
485 486 487 |
# File 'lib/stripe/resources/setup_attempt.rb', line 485 def klarna @klarna end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
487 488 489 |
# File 'lib/stripe/resources/setup_attempt.rb', line 487 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
489 490 491 |
# File 'lib/stripe/resources/setup_attempt.rb', line 489 def link @link end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
491 492 493 |
# File 'lib/stripe/resources/setup_attempt.rb', line 491 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
493 494 495 |
# File 'lib/stripe/resources/setup_attempt.rb', line 493 def nz_bank_account @nz_bank_account end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
495 496 497 |
# File 'lib/stripe/resources/setup_attempt.rb', line 495 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
497 498 499 |
# File 'lib/stripe/resources/setup_attempt.rb', line 497 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
499 500 501 |
# File 'lib/stripe/resources/setup_attempt.rb', line 499 def pix @pix end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
501 502 503 |
# File 'lib/stripe/resources/setup_attempt.rb', line 501 def revolut_pay @revolut_pay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
503 504 505 |
# File 'lib/stripe/resources/setup_attempt.rb', line 503 def sepa_debit @sepa_debit end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
505 506 507 |
# File 'lib/stripe/resources/setup_attempt.rb', line 505 def sofort @sofort end |
#stripe_balance ⇒ Object (readonly)
Attribute for field stripe_balance
507 508 509 |
# File 'lib/stripe/resources/setup_attempt.rb', line 507 def stripe_balance @stripe_balance end |
#type ⇒ Object (readonly)
The type of the payment method used in the SetupIntent (e.g., ‘card`). An additional hash is included on `payment_method_details` with a name matching this value. It contains confirmation-specific information for the payment method.
509 510 511 |
# File 'lib/stripe/resources/setup_attempt.rb', line 509 def type @type end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
511 512 513 |
# File 'lib/stripe/resources/setup_attempt.rb', line 511 def us_bank_account @us_bank_account end |
Class Method Details
.field_remappings ⇒ Object
543 544 545 |
# File 'lib/stripe/resources/setup_attempt.rb', line 543 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 |
# File 'lib/stripe/resources/setup_attempt.rb', line 513 def self.inner_class_types @inner_class_types = { acss_debit: AcssDebit, amazon_pay: AmazonPay, au_becs_debit: AuBecsDebit, bacs_debit: BacsDebit, bancontact: Bancontact, boleto: Boleto, card: Card, card_present: CardPresent, cashapp: Cashapp, id_bank_transfer: IdBankTransfer, ideal: Ideal, kakao_pay: KakaoPay, klarna: Klarna, kr_card: KrCard, link: Link, naver_pay: NaverPay, nz_bank_account: NzBankAccount, paypal: Paypal, payto: Payto, pix: Pix, revolut_pay: RevolutPay, sepa_debit: SepaDebit, sofort: Sofort, stripe_balance: StripeBalance, us_bank_account: UsBankAccount, } end |