Class: Stripe::SetupAttempt::PaymentMethodDetails
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SetupAttempt::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/setup_attempt.rb
Defined Under Namespace
Classes: AcssDebit, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Boleto, Card, CardPresent, Cashapp, IdBankTransfer, Ideal, KakaoPay, Klarna, KrCard, Link, NaverPay, NzBankAccount, Paypal, Payto, Pix, RevolutPay, SepaDebit, Sofort, StripeBalance, UsBankAccount
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#stripe_balance ⇒ Object
readonly
Attribute for field stripe_balance.
-
#type ⇒ Object
readonly
The type of the payment method used in the SetupIntent (e.g., ‘card`).
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
Attributes inherited from Stripe::StripeObject
Method Summary
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
200 201 202 |
# File 'lib/stripe/resources/setup_attempt.rb', line 200 def acss_debit @acss_debit end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
202 203 204 |
# File 'lib/stripe/resources/setup_attempt.rb', line 202 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
204 205 206 |
# File 'lib/stripe/resources/setup_attempt.rb', line 204 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
206 207 208 |
# File 'lib/stripe/resources/setup_attempt.rb', line 206 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
208 209 210 |
# File 'lib/stripe/resources/setup_attempt.rb', line 208 def bancontact @bancontact end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
210 211 212 |
# File 'lib/stripe/resources/setup_attempt.rb', line 210 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
212 213 214 |
# File 'lib/stripe/resources/setup_attempt.rb', line 212 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
214 215 216 |
# File 'lib/stripe/resources/setup_attempt.rb', line 214 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
216 217 218 |
# File 'lib/stripe/resources/setup_attempt.rb', line 216 def cashapp @cashapp end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
218 219 220 |
# File 'lib/stripe/resources/setup_attempt.rb', line 218 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
220 221 222 |
# File 'lib/stripe/resources/setup_attempt.rb', line 220 def ideal @ideal end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
222 223 224 |
# File 'lib/stripe/resources/setup_attempt.rb', line 222 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
224 225 226 |
# File 'lib/stripe/resources/setup_attempt.rb', line 224 def klarna @klarna end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
226 227 228 |
# File 'lib/stripe/resources/setup_attempt.rb', line 226 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
228 229 230 |
# File 'lib/stripe/resources/setup_attempt.rb', line 228 def link @link end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
230 231 232 |
# File 'lib/stripe/resources/setup_attempt.rb', line 230 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
232 233 234 |
# File 'lib/stripe/resources/setup_attempt.rb', line 232 def nz_bank_account @nz_bank_account end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
234 235 236 |
# File 'lib/stripe/resources/setup_attempt.rb', line 234 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
236 237 238 |
# File 'lib/stripe/resources/setup_attempt.rb', line 236 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
238 239 240 |
# File 'lib/stripe/resources/setup_attempt.rb', line 238 def pix @pix end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
240 241 242 |
# File 'lib/stripe/resources/setup_attempt.rb', line 240 def revolut_pay @revolut_pay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
242 243 244 |
# File 'lib/stripe/resources/setup_attempt.rb', line 242 def sepa_debit @sepa_debit end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
244 245 246 |
# File 'lib/stripe/resources/setup_attempt.rb', line 244 def sofort @sofort end |
#stripe_balance ⇒ Object (readonly)
Attribute for field stripe_balance
246 247 248 |
# File 'lib/stripe/resources/setup_attempt.rb', line 246 def stripe_balance @stripe_balance end |
#type ⇒ Object (readonly)
The type of the payment method used in the SetupIntent (e.g., ‘card`). An additional hash is included on `payment_method_details` with a name matching this value. It contains confirmation-specific information for the payment method.
248 249 250 |
# File 'lib/stripe/resources/setup_attempt.rb', line 248 def type @type end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
250 251 252 |
# File 'lib/stripe/resources/setup_attempt.rb', line 250 def us_bank_account @us_bank_account end |