Class: Stripe::SetupAttempt::PaymentMethodDetails
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SetupAttempt::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/setup_attempt.rb
Defined Under Namespace
Classes: AcssDebit, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Boleto, Card, CardPresent, Cashapp, IdBankTransfer, Ideal, KakaoPay, Klarna, KrCard, Link, NaverPay, NzBankAccount, Paypal, Payto, RevolutPay, SepaDebit, Sofort, StripeBalance, UsBankAccount
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#stripe_balance ⇒ Object
readonly
Attribute for field stripe_balance.
-
#type ⇒ Object
readonly
The type of the payment method used in the SetupIntent (e.g., ‘card`).
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
Attributes inherited from Stripe::StripeObject
Method Summary
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
199 200 201 |
# File 'lib/stripe/resources/setup_attempt.rb', line 199 def acss_debit @acss_debit end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
201 202 203 |
# File 'lib/stripe/resources/setup_attempt.rb', line 201 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
203 204 205 |
# File 'lib/stripe/resources/setup_attempt.rb', line 203 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
205 206 207 |
# File 'lib/stripe/resources/setup_attempt.rb', line 205 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
207 208 209 |
# File 'lib/stripe/resources/setup_attempt.rb', line 207 def bancontact @bancontact end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
209 210 211 |
# File 'lib/stripe/resources/setup_attempt.rb', line 209 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
211 212 213 |
# File 'lib/stripe/resources/setup_attempt.rb', line 211 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
213 214 215 |
# File 'lib/stripe/resources/setup_attempt.rb', line 213 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
215 216 217 |
# File 'lib/stripe/resources/setup_attempt.rb', line 215 def cashapp @cashapp end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
217 218 219 |
# File 'lib/stripe/resources/setup_attempt.rb', line 217 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
219 220 221 |
# File 'lib/stripe/resources/setup_attempt.rb', line 219 def ideal @ideal end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
221 222 223 |
# File 'lib/stripe/resources/setup_attempt.rb', line 221 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
223 224 225 |
# File 'lib/stripe/resources/setup_attempt.rb', line 223 def klarna @klarna end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
225 226 227 |
# File 'lib/stripe/resources/setup_attempt.rb', line 225 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
227 228 229 |
# File 'lib/stripe/resources/setup_attempt.rb', line 227 def link @link end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
229 230 231 |
# File 'lib/stripe/resources/setup_attempt.rb', line 229 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
231 232 233 |
# File 'lib/stripe/resources/setup_attempt.rb', line 231 def nz_bank_account @nz_bank_account end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
233 234 235 |
# File 'lib/stripe/resources/setup_attempt.rb', line 233 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
235 236 237 |
# File 'lib/stripe/resources/setup_attempt.rb', line 235 def payto @payto end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
237 238 239 |
# File 'lib/stripe/resources/setup_attempt.rb', line 237 def revolut_pay @revolut_pay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
239 240 241 |
# File 'lib/stripe/resources/setup_attempt.rb', line 239 def sepa_debit @sepa_debit end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
241 242 243 |
# File 'lib/stripe/resources/setup_attempt.rb', line 241 def sofort @sofort end |
#stripe_balance ⇒ Object (readonly)
Attribute for field stripe_balance
243 244 245 |
# File 'lib/stripe/resources/setup_attempt.rb', line 243 def stripe_balance @stripe_balance end |
#type ⇒ Object (readonly)
The type of the payment method used in the SetupIntent (e.g., ‘card`). An additional hash is included on `payment_method_details` with a name matching this value. It contains confirmation-specific information for the payment method.
245 246 247 |
# File 'lib/stripe/resources/setup_attempt.rb', line 245 def type @type end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
247 248 249 |
# File 'lib/stripe/resources/setup_attempt.rb', line 247 def us_bank_account @us_bank_account end |