Class: Stripe::SetupAttempt::PaymentMethodDetails
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SetupAttempt::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/setup_attempt.rb
Defined Under Namespace
Classes: AcssDebit, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Boleto, Card, CardPresent, Cashapp, IdBankTransfer, Ideal, KakaoPay, Klarna, KrCard, Link, Paypal, Payto, RevolutPay, SepaDebit, Sofort, UsBankAccount
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#type ⇒ Object
readonly
The type of the payment method used in the SetupIntent (e.g., ‘card`).
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
Attributes inherited from Stripe::StripeObject
Method Summary
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
237 238 239 |
# File 'lib/stripe/resources/setup_attempt.rb', line 237 def acss_debit @acss_debit end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
240 241 242 |
# File 'lib/stripe/resources/setup_attempt.rb', line 240 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
243 244 245 |
# File 'lib/stripe/resources/setup_attempt.rb', line 243 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
246 247 248 |
# File 'lib/stripe/resources/setup_attempt.rb', line 246 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
249 250 251 |
# File 'lib/stripe/resources/setup_attempt.rb', line 249 def bancontact @bancontact end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
252 253 254 |
# File 'lib/stripe/resources/setup_attempt.rb', line 252 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
255 256 257 |
# File 'lib/stripe/resources/setup_attempt.rb', line 255 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
258 259 260 |
# File 'lib/stripe/resources/setup_attempt.rb', line 258 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
261 262 263 |
# File 'lib/stripe/resources/setup_attempt.rb', line 261 def cashapp @cashapp end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
264 265 266 |
# File 'lib/stripe/resources/setup_attempt.rb', line 264 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
267 268 269 |
# File 'lib/stripe/resources/setup_attempt.rb', line 267 def ideal @ideal end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
270 271 272 |
# File 'lib/stripe/resources/setup_attempt.rb', line 270 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
273 274 275 |
# File 'lib/stripe/resources/setup_attempt.rb', line 273 def klarna @klarna end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
276 277 278 |
# File 'lib/stripe/resources/setup_attempt.rb', line 276 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
279 280 281 |
# File 'lib/stripe/resources/setup_attempt.rb', line 279 def link @link end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
282 283 284 |
# File 'lib/stripe/resources/setup_attempt.rb', line 282 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
285 286 287 |
# File 'lib/stripe/resources/setup_attempt.rb', line 285 def payto @payto end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
288 289 290 |
# File 'lib/stripe/resources/setup_attempt.rb', line 288 def revolut_pay @revolut_pay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
291 292 293 |
# File 'lib/stripe/resources/setup_attempt.rb', line 291 def sepa_debit @sepa_debit end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
294 295 296 |
# File 'lib/stripe/resources/setup_attempt.rb', line 294 def sofort @sofort end |
#type ⇒ Object (readonly)
The type of the payment method used in the SetupIntent (e.g., ‘card`). An additional hash is included on `payment_method_details` with a name matching this value. It contains confirmation-specific information for the payment method.
297 298 299 |
# File 'lib/stripe/resources/setup_attempt.rb', line 297 def type @type end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
300 301 302 |
# File 'lib/stripe/resources/setup_attempt.rb', line 300 def us_bank_account @us_bank_account end |