Class: Stripe::SetupAttempt::PaymentMethodDetails::Card
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SetupAttempt::PaymentMethodDetails::Card
- Defined in:
- lib/stripe/resources/setup_attempt.rb
Defined Under Namespace
Classes: Checks, ThreeDSecure, Wallet
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#brand ⇒ Object
readonly
Card brand.
-
#checks ⇒ Object
readonly
Check results by Card networks on Card address and CVC at the time of authorization.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country of the card.
-
#description ⇒ Object
readonly
A high-level description of the type of cards issued in this range.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card’s expiration year.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular card number.
-
#funding ⇒ Object
readonly
Card funding type.
-
#iin ⇒ Object
readonly
Issuer identification number of the card.
-
#issuer ⇒ Object
readonly
The name of the card’s issuing bank.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#network ⇒ Object
readonly
Identifies which network this charge was processed on.
-
#three_d_secure ⇒ Object
readonly
Populated if this authorization used 3D Secure authentication.
-
#wallet ⇒ Object
readonly
If this Card is part of a card wallet, this contains the details of the card wallet.
Attributes inherited from Stripe::StripeObject
Method Summary
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#brand ⇒ Object (readonly)
Card brand. Can be ‘amex`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.
102 103 104 |
# File 'lib/stripe/resources/setup_attempt.rb', line 102 def brand @brand end |
#checks ⇒ Object (readonly)
Check results by Card networks on Card address and CVC at the time of authorization
105 106 107 |
# File 'lib/stripe/resources/setup_attempt.rb', line 105 def checks @checks end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.
108 109 110 |
# File 'lib/stripe/resources/setup_attempt.rb', line 108 def country @country end |
#description ⇒ Object (readonly)
A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)
111 112 113 |
# File 'lib/stripe/resources/setup_attempt.rb', line 111 def description @description end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card’s expiration month.
114 115 116 |
# File 'lib/stripe/resources/setup_attempt.rb', line 114 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card’s expiration year.
117 118 119 |
# File 'lib/stripe/resources/setup_attempt.rb', line 117 def exp_year @exp_year end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.
*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*
122 123 124 |
# File 'lib/stripe/resources/setup_attempt.rb', line 122 def fingerprint @fingerprint end |
#funding ⇒ Object (readonly)
Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.
125 126 127 |
# File 'lib/stripe/resources/setup_attempt.rb', line 125 def funding @funding end |
#iin ⇒ Object (readonly)
Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)
128 129 130 |
# File 'lib/stripe/resources/setup_attempt.rb', line 128 def iin @iin end |
#issuer ⇒ Object (readonly)
The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)
131 132 133 |
# File 'lib/stripe/resources/setup_attempt.rb', line 131 def issuer @issuer end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
134 135 136 |
# File 'lib/stripe/resources/setup_attempt.rb', line 134 def last4 @last4 end |
#network ⇒ Object (readonly)
Identifies which network this charge was processed on. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `interac`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.
137 138 139 |
# File 'lib/stripe/resources/setup_attempt.rb', line 137 def network @network end |
#three_d_secure ⇒ Object (readonly)
Populated if this authorization used 3D Secure authentication.
140 141 142 |
# File 'lib/stripe/resources/setup_attempt.rb', line 140 def three_d_secure @three_d_secure end |
#wallet ⇒ Object (readonly)
If this Card is part of a card wallet, this contains the details of the card wallet.
143 144 145 |
# File 'lib/stripe/resources/setup_attempt.rb', line 143 def wallet @wallet end |