Class: Stripe::SetupAttempt::PaymentMethodDetails::Card::ThreeDSecure
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SetupAttempt::PaymentMethodDetails::Card::ThreeDSecure
- Defined in:
- lib/stripe/resources/setup_attempt.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#authentication_flow ⇒ Object
readonly
For authenticated transactions: how the customer was authenticated by the issuing bank.
-
#electronic_commerce_indicator ⇒ Object
readonly
The Electronic Commerce Indicator (ECI).
-
#result ⇒ Object
readonly
Indicates the outcome of 3D Secure authentication.
-
#result_reason ⇒ Object
readonly
Additional information about why 3D Secure succeeded or failed based on the
result. -
#transaction_id ⇒ Object
readonly
The 3D Secure 1 XID or 3D Secure 2 Directory Server Transaction ID (dsTransId) for this payment.
-
#version ⇒ Object
readonly
The version of 3D Secure that was used.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#authentication_flow ⇒ Object (readonly)
For authenticated transactions: how the customer was authenticated by the issuing bank.
131 132 133 |
# File 'lib/stripe/resources/setup_attempt.rb', line 131 def authentication_flow @authentication_flow end |
#electronic_commerce_indicator ⇒ Object (readonly)
The Electronic Commerce Indicator (ECI). A protocol-level field indicating what degree of authentication was performed.
134 135 136 |
# File 'lib/stripe/resources/setup_attempt.rb', line 134 def electronic_commerce_indicator @electronic_commerce_indicator end |
#result ⇒ Object (readonly)
Indicates the outcome of 3D Secure authentication.
136 137 138 |
# File 'lib/stripe/resources/setup_attempt.rb', line 136 def result @result end |
#result_reason ⇒ Object (readonly)
Additional information about why 3D Secure succeeded or failed based
on the result.
139 140 141 |
# File 'lib/stripe/resources/setup_attempt.rb', line 139 def result_reason @result_reason end |
#transaction_id ⇒ Object (readonly)
The 3D Secure 1 XID or 3D Secure 2 Directory Server Transaction ID (dsTransId) for this payment.
142 143 144 |
# File 'lib/stripe/resources/setup_attempt.rb', line 142 def transaction_id @transaction_id end |
#version ⇒ Object (readonly)
The version of 3D Secure that was used.
144 145 146 |
# File 'lib/stripe/resources/setup_attempt.rb', line 144 def version @version end |
Class Method Details
.field_remappings ⇒ Object
150 151 152 |
# File 'lib/stripe/resources/setup_attempt.rb', line 150 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
146 147 148 |
# File 'lib/stripe/resources/setup_attempt.rb', line 146 def self.inner_class_types @inner_class_types = {} end |