Class: Stripe::SetupAttempt::PaymentMethodDetails::Card::Wallet

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/setup_attempt.rb

Defined Under Namespace

Classes: ApplePay, GooglePay

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Method Summary

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#apple_payObject (readonly)

Attribute for field apple_pay



93
94
95
# File 'lib/stripe/resources/setup_attempt.rb', line 93

def apple_pay
  @apple_pay
end

#google_payObject (readonly)

Attribute for field google_pay



96
97
98
# File 'lib/stripe/resources/setup_attempt.rb', line 96

def google_pay
  @google_pay
end

#typeObject (readonly)

The type of the card wallet, one of ‘apple_pay`, `google_pay`, or `link`. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type.



99
100
101
# File 'lib/stripe/resources/setup_attempt.rb', line 99

def type
  @type
end