Class: Stripe::SetupAttempt::PaymentMethodDetails::IdBankTransfer
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SetupAttempt::PaymentMethodDetails::IdBankTransfer
- Defined in:
- lib/stripe/resources/setup_attempt.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank ⇒ Object
readonly
Bank where the account is located.
-
#bank_code ⇒ Object
readonly
Local bank code of the bank.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#display_name ⇒ Object
readonly
Merchant name and billing details name, for the customer to check for the correct merchant when performing the bank transfer.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank ⇒ Object (readonly)
Bank where the account is located.
260 261 262 |
# File 'lib/stripe/resources/setup_attempt.rb', line 260 def bank @bank end |
#bank_code ⇒ Object (readonly)
Local bank code of the bank.
262 263 264 |
# File 'lib/stripe/resources/setup_attempt.rb', line 262 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
264 265 266 |
# File 'lib/stripe/resources/setup_attempt.rb', line 264 def bank_name @bank_name end |
#display_name ⇒ Object (readonly)
Merchant name and billing details name, for the customer to check for the correct merchant when performing the bank transfer.
266 267 268 |
# File 'lib/stripe/resources/setup_attempt.rb', line 266 def display_name @display_name end |
Class Method Details
.field_remappings ⇒ Object
272 273 274 |
# File 'lib/stripe/resources/setup_attempt.rb', line 272 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
268 269 270 |
# File 'lib/stripe/resources/setup_attempt.rb', line 268 def self.inner_class_types @inner_class_types = {} end |