Class: Stripe::SetupAttempt::PaymentMethodDetails::IdBankTransfer
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SetupAttempt::PaymentMethodDetails::IdBankTransfer
- Defined in:
- lib/stripe/resources/setup_attempt.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank ⇒ Object
readonly
Bank where the account is located.
-
#bank_code ⇒ Object
readonly
Local bank code of the bank.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#display_name ⇒ Object
readonly
Merchant name and billing details name, for the customer to check for the correct merchant when performing the bank transfer.
Attributes inherited from Stripe::StripeObject
Method Summary
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank ⇒ Object (readonly)
Bank where the account is located.
165 166 167 |
# File 'lib/stripe/resources/setup_attempt.rb', line 165 def bank @bank end |
#bank_code ⇒ Object (readonly)
Local bank code of the bank.
168 169 170 |
# File 'lib/stripe/resources/setup_attempt.rb', line 168 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
171 172 173 |
# File 'lib/stripe/resources/setup_attempt.rb', line 171 def bank_name @bank_name end |
#display_name ⇒ Object (readonly)
Merchant name and billing details name, for the customer to check for the correct merchant when performing the bank transfer.
174 175 176 |
# File 'lib/stripe/resources/setup_attempt.rb', line 174 def display_name @display_name end |