Class: Stripe::SetupAttempt::PaymentMethodDetails::Sofort
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SetupAttempt::PaymentMethodDetails::Sofort
- Defined in:
- lib/stripe/resources/setup_attempt.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_code ⇒ Object
readonly
Bank code of bank associated with the bank account.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#bic ⇒ Object
readonly
Bank Identifier Code of the bank associated with the bank account.
-
#generated_sepa_debit ⇒ Object
readonly
The ID of the SEPA Direct Debit PaymentMethod which was generated by this SetupAttempt.
-
#generated_sepa_debit_mandate ⇒ Object
readonly
The mandate for the SEPA Direct Debit PaymentMethod which was generated by this SetupAttempt.
-
#iban_last4 ⇒ Object
readonly
Last four characters of the IBAN.
-
#preferred_language ⇒ Object
readonly
Preferred language of the Sofort authorization page that the customer is redirected to.
-
#verified_name ⇒ Object
readonly
Owner's verified full name.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_code ⇒ Object (readonly)
Bank code of bank associated with the bank account.
439 440 441 |
# File 'lib/stripe/resources/setup_attempt.rb', line 439 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
441 442 443 |
# File 'lib/stripe/resources/setup_attempt.rb', line 441 def bank_name @bank_name end |
#bic ⇒ Object (readonly)
Bank Identifier Code of the bank associated with the bank account.
443 444 445 |
# File 'lib/stripe/resources/setup_attempt.rb', line 443 def bic @bic end |
#generated_sepa_debit ⇒ Object (readonly)
The ID of the SEPA Direct Debit PaymentMethod which was generated by this SetupAttempt.
445 446 447 |
# File 'lib/stripe/resources/setup_attempt.rb', line 445 def generated_sepa_debit @generated_sepa_debit end |
#generated_sepa_debit_mandate ⇒ Object (readonly)
The mandate for the SEPA Direct Debit PaymentMethod which was generated by this SetupAttempt.
447 448 449 |
# File 'lib/stripe/resources/setup_attempt.rb', line 447 def generated_sepa_debit_mandate @generated_sepa_debit_mandate end |
#iban_last4 ⇒ Object (readonly)
Last four characters of the IBAN.
449 450 451 |
# File 'lib/stripe/resources/setup_attempt.rb', line 449 def iban_last4 @iban_last4 end |
#preferred_language ⇒ Object (readonly)
Preferred language of the Sofort authorization page that the customer is redirected to.
Can be one of en, de, fr, or nl
452 453 454 |
# File 'lib/stripe/resources/setup_attempt.rb', line 452 def preferred_language @preferred_language end |
#verified_name ⇒ Object (readonly)
Owner's verified full name. Values are verified or provided by Sofort directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
455 456 457 |
# File 'lib/stripe/resources/setup_attempt.rb', line 455 def verified_name @verified_name end |
Class Method Details
.field_remappings ⇒ Object
461 462 463 |
# File 'lib/stripe/resources/setup_attempt.rb', line 461 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
457 458 459 |
# File 'lib/stripe/resources/setup_attempt.rb', line 457 def self.inner_class_types @inner_class_types = {} end |