Class: Stripe::SetupAttempt::PaymentMethodDetails::Sofort

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/setup_attempt.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



429
430
431
# File 'lib/stripe/resources/setup_attempt.rb', line 429

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



431
432
433
# File 'lib/stripe/resources/setup_attempt.rb', line 431

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



433
434
435
# File 'lib/stripe/resources/setup_attempt.rb', line 433

def bic
  @bic
end

#generated_sepa_debitObject (readonly)

The ID of the SEPA Direct Debit PaymentMethod which was generated by this SetupAttempt.



435
436
437
# File 'lib/stripe/resources/setup_attempt.rb', line 435

def generated_sepa_debit
  @generated_sepa_debit
end

#generated_sepa_debit_mandateObject (readonly)

The mandate for the SEPA Direct Debit PaymentMethod which was generated by this SetupAttempt.



437
438
439
# File 'lib/stripe/resources/setup_attempt.rb', line 437

def generated_sepa_debit_mandate
  @generated_sepa_debit_mandate
end

#iban_last4Object (readonly)

Last four characters of the IBAN.



439
440
441
# File 'lib/stripe/resources/setup_attempt.rb', line 439

def iban_last4
  @iban_last4
end

#preferred_languageObject (readonly)

Preferred language of the Sofort authorization page that the customer is redirected to. Can be one of ‘en`, `de`, `fr`, or `nl`



442
443
444
# File 'lib/stripe/resources/setup_attempt.rb', line 442

def preferred_language
  @preferred_language
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by Sofort directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



445
446
447
# File 'lib/stripe/resources/setup_attempt.rb', line 445

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



451
452
453
# File 'lib/stripe/resources/setup_attempt.rb', line 451

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



447
448
449
# File 'lib/stripe/resources/setup_attempt.rb', line 447

def self.inner_class_types
  @inner_class_types = {}
end