Class: Stripe::SetupAttempt::PaymentMethodDetails::Sofort

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/setup_attempt.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Method Summary

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



177
178
179
# File 'lib/stripe/resources/setup_attempt.rb', line 177

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



179
180
181
# File 'lib/stripe/resources/setup_attempt.rb', line 179

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



181
182
183
# File 'lib/stripe/resources/setup_attempt.rb', line 181

def bic
  @bic
end

#generated_sepa_debitObject (readonly)

The ID of the SEPA Direct Debit PaymentMethod which was generated by this SetupAttempt.



183
184
185
# File 'lib/stripe/resources/setup_attempt.rb', line 183

def generated_sepa_debit
  @generated_sepa_debit
end

#generated_sepa_debit_mandateObject (readonly)

The mandate for the SEPA Direct Debit PaymentMethod which was generated by this SetupAttempt.



185
186
187
# File 'lib/stripe/resources/setup_attempt.rb', line 185

def generated_sepa_debit_mandate
  @generated_sepa_debit_mandate
end

#iban_last4Object (readonly)

Last four characters of the IBAN.



187
188
189
# File 'lib/stripe/resources/setup_attempt.rb', line 187

def iban_last4
  @iban_last4
end

#preferred_languageObject (readonly)

Preferred language of the Sofort authorization page that the customer is redirected to. Can be one of ‘en`, `de`, `fr`, or `nl`



190
191
192
# File 'lib/stripe/resources/setup_attempt.rb', line 190

def preferred_language
  @preferred_language
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by Sofort directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



193
194
195
# File 'lib/stripe/resources/setup_attempt.rb', line 193

def verified_name
  @verified_name
end