Class: Stripe::SetupIntent
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::SetupIntent
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/setup_intent.rb
Overview
A SetupIntent guides you through the process of setting up and saving a customer’s payment credentials for future payments. For example, you can use a SetupIntent to set up and save your customer’s card without immediately collecting a payment. Later, you can use [PaymentIntents](api.stripe.com#payment_intents) to drive the payment flow.
Create a SetupIntent when you’re ready to collect your customer’s payment credentials. Don’t maintain long-lived, unconfirmed SetupIntents because they might not be valid. The SetupIntent transitions through multiple [statuses](docs.stripe.com/payments/intents#intent-statuses) as it guides you through the setup process.
Successful SetupIntents result in payment credentials that are optimized for future payments. For example, cardholders in [certain regions](stripe.com/guides/strong-customer-authentication) might need to be run through [Strong Customer Authentication](docs.stripe.com/strong-customer-authentication) during payment method collection to streamline later [off-session payments](docs.stripe.com/payments/setup-intents). If you use the SetupIntent with a [Customer](api.stripe.com#setup_intent_object-customer), it automatically attaches the resulting payment method to that Customer after successful setup. We recommend using SetupIntents or [setup_future_usage](api.stripe.com#payment_intent_object-setup_future_usage) on PaymentIntents to save payment methods to prevent saving invalid or unoptimized payment methods.
By using SetupIntents, you can reduce friction for your customers, even as regulations change over time.
Related guide: [Setup Intents API](docs.stripe.com/payments/setup-intents)
Defined Under Namespace
Classes: AutomaticPaymentMethods, LastSetupError, ManagedPayments, NextAction, PaymentMethodConfigurationDetails, PaymentMethodOptions
Constant Summary collapse
- OBJECT_NAME =
"setup_intent"
Constants inherited from StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#application ⇒ Object
readonly
ID of the Connect application that created the SetupIntent.
-
#attach_to_self ⇒ Object
readonly
If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.
-
#automatic_payment_methods ⇒ Object
readonly
Settings for dynamic payment methods compatible with this Setup Intent.
-
#cancellation_reason ⇒ Object
readonly
Reason for cancellation of this SetupIntent, one of ‘abandoned`, `requested_by_customer`, or `duplicate`.
-
#client_secret ⇒ Object
readonly
The client secret of this SetupIntent.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#customer ⇒ Object
readonly
ID of the Customer this SetupIntent belongs to, if one exists.
-
#customer_account ⇒ Object
readonly
ID of the Account this SetupIntent belongs to, if one exists.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#excluded_payment_method_types ⇒ Object
readonly
Payment method types that are excluded from this SetupIntent.
-
#flow_directions ⇒ Object
readonly
Indicates the directions of money movement for which this payment method is intended to be used.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#last_setup_error ⇒ Object
readonly
The error encountered in the previous SetupIntent confirmation.
-
#latest_attempt ⇒ Object
readonly
The most recent SetupAttempt for this SetupIntent.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#managed_payments ⇒ Object
readonly
Attribute for field managed_payments.
-
#mandate ⇒ Object
readonly
ID of the multi use Mandate generated by the SetupIntent.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#next_action ⇒ Object
readonly
If present, this property tells you what actions you need to take in order for your customer to continue payment setup.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#on_behalf_of ⇒ Object
readonly
The account (if any) for which the setup is intended.
-
#payment_method ⇒ Object
readonly
ID of the payment method used with this SetupIntent.
-
#payment_method_configuration_details ⇒ Object
readonly
Information about the [payment method configuration](docs.stripe.com/api/payment_method_configurations) used for this Setup Intent.
-
#payment_method_options ⇒ Object
readonly
Payment method-specific configuration for this SetupIntent.
-
#payment_method_types ⇒ Object
readonly
The list of payment method types (e.g. card) that this SetupIntent is allowed to set up.
-
#single_use_mandate ⇒ Object
readonly
ID of the single_use Mandate generated by the SetupIntent.
-
#status ⇒ Object
readonly
[Status](docs.stripe.com/payments/intents#intent-statuses) of this SetupIntent, one of ‘requires_payment_method`, `requires_confirmation`, `requires_action`, `processing`, `canceled`, or `succeeded`.
-
#usage ⇒ Object
readonly
Indicates how the payment method is intended to be used in the future.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.cancel(intent, params = {}, opts = {}) ⇒ Object
You can cancel a SetupIntent object when it’s in one of these statuses: requires_payment_method, requires_confirmation, or requires_action.
-
.confirm(intent, params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to set up the current or provided payment method.
-
.create(params = {}, opts = {}) ⇒ Object
Creates a SetupIntent object.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of SetupIntents.
- .object_name ⇒ Object
-
.update(intent, params = {}, opts = {}) ⇒ Object
Updates a SetupIntent object.
-
.verify_microdeposits(intent, params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a SetupIntent object.
Instance Method Summary collapse
-
#cancel(params = {}, opts = {}) ⇒ Object
You can cancel a SetupIntent object when it’s in one of these statuses: requires_payment_method, requires_confirmation, or requires_action.
-
#confirm(params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to set up the current or provided payment method.
-
#verify_microdeposits(params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a SetupIntent object.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#application ⇒ Object (readonly)
ID of the Connect application that created the SetupIntent.
741 742 743 |
# File 'lib/stripe/resources/setup_intent.rb', line 741 def application @application end |
#attach_to_self ⇒ Object (readonly)
If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.
It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.
745 746 747 |
# File 'lib/stripe/resources/setup_intent.rb', line 745 def attach_to_self @attach_to_self end |
#automatic_payment_methods ⇒ Object (readonly)
Settings for dynamic payment methods compatible with this Setup Intent
747 748 749 |
# File 'lib/stripe/resources/setup_intent.rb', line 747 def automatic_payment_methods @automatic_payment_methods end |
#cancellation_reason ⇒ Object (readonly)
Reason for cancellation of this SetupIntent, one of ‘abandoned`, `requested_by_customer`, or `duplicate`.
749 750 751 |
# File 'lib/stripe/resources/setup_intent.rb', line 749 def cancellation_reason @cancellation_reason end |
#client_secret ⇒ Object (readonly)
The client secret of this SetupIntent. Used for client-side retrieval using a publishable key.
The client secret can be used to complete payment setup from your frontend. It should not be stored, logged, or exposed to anyone other than the customer. Make sure that you have TLS enabled on any page that includes the client secret.
753 754 755 |
# File 'lib/stripe/resources/setup_intent.rb', line 753 def client_secret @client_secret end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
755 756 757 |
# File 'lib/stripe/resources/setup_intent.rb', line 755 def created @created end |
#customer ⇒ Object (readonly)
ID of the Customer this SetupIntent belongs to, if one exists.
If present, the SetupIntent’s payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.
759 760 761 |
# File 'lib/stripe/resources/setup_intent.rb', line 759 def customer @customer end |
#customer_account ⇒ Object (readonly)
ID of the Account this SetupIntent belongs to, if one exists.
If present, the SetupIntent’s payment method will be attached to the Account on successful setup. Payment methods attached to other Accounts cannot be used with this SetupIntent.
763 764 765 |
# File 'lib/stripe/resources/setup_intent.rb', line 763 def customer_account @customer_account end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
765 766 767 |
# File 'lib/stripe/resources/setup_intent.rb', line 765 def description @description end |
#excluded_payment_method_types ⇒ Object (readonly)
Payment method types that are excluded from this SetupIntent.
767 768 769 |
# File 'lib/stripe/resources/setup_intent.rb', line 767 def excluded_payment_method_types @excluded_payment_method_types end |
#flow_directions ⇒ Object (readonly)
Indicates the directions of money movement for which this payment method is intended to be used.
Include ‘inbound` if you intend to use the payment method as the origin to pull funds from. Include `outbound` if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.
771 772 773 |
# File 'lib/stripe/resources/setup_intent.rb', line 771 def flow_directions @flow_directions end |
#id ⇒ Object (readonly)
Unique identifier for the object.
773 774 775 |
# File 'lib/stripe/resources/setup_intent.rb', line 773 def id @id end |
#last_setup_error ⇒ Object (readonly)
The error encountered in the previous SetupIntent confirmation.
775 776 777 |
# File 'lib/stripe/resources/setup_intent.rb', line 775 def last_setup_error @last_setup_error end |
#latest_attempt ⇒ Object (readonly)
The most recent SetupAttempt for this SetupIntent.
777 778 779 |
# File 'lib/stripe/resources/setup_intent.rb', line 777 def latest_attempt @latest_attempt end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
779 780 781 |
# File 'lib/stripe/resources/setup_intent.rb', line 779 def livemode @livemode end |
#managed_payments ⇒ Object (readonly)
Attribute for field managed_payments
781 782 783 |
# File 'lib/stripe/resources/setup_intent.rb', line 781 def managed_payments @managed_payments end |
#mandate ⇒ Object (readonly)
ID of the multi use Mandate generated by the SetupIntent.
783 784 785 |
# File 'lib/stripe/resources/setup_intent.rb', line 783 def mandate @mandate end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
785 786 787 |
# File 'lib/stripe/resources/setup_intent.rb', line 785 def @metadata end |
#next_action ⇒ Object (readonly)
If present, this property tells you what actions you need to take in order for your customer to continue payment setup.
787 788 789 |
# File 'lib/stripe/resources/setup_intent.rb', line 787 def next_action @next_action end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
789 790 791 |
# File 'lib/stripe/resources/setup_intent.rb', line 789 def object @object end |
#on_behalf_of ⇒ Object (readonly)
The account (if any) for which the setup is intended.
791 792 793 |
# File 'lib/stripe/resources/setup_intent.rb', line 791 def on_behalf_of @on_behalf_of end |
#payment_method ⇒ Object (readonly)
ID of the payment method used with this SetupIntent. If the payment method is ‘card_present` and isn’t a digital wallet, then the [generated_card](docs.stripe.com/api/setup_attempts/object#setup_attempt_object-payment_method_details-card_present-generated_card) associated with the ‘latest_attempt` is attached to the Customer instead.
793 794 795 |
# File 'lib/stripe/resources/setup_intent.rb', line 793 def payment_method @payment_method end |
#payment_method_configuration_details ⇒ Object (readonly)
Information about the [payment method configuration](docs.stripe.com/api/payment_method_configurations) used for this Setup Intent.
795 796 797 |
# File 'lib/stripe/resources/setup_intent.rb', line 795 def payment_method_configuration_details @payment_method_configuration_details end |
#payment_method_options ⇒ Object (readonly)
Payment method-specific configuration for this SetupIntent.
797 798 799 |
# File 'lib/stripe/resources/setup_intent.rb', line 797 def @payment_method_options end |
#payment_method_types ⇒ Object (readonly)
The list of payment method types (e.g. card) that this SetupIntent is allowed to set up. A list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).
799 800 801 |
# File 'lib/stripe/resources/setup_intent.rb', line 799 def payment_method_types @payment_method_types end |
#single_use_mandate ⇒ Object (readonly)
ID of the single_use Mandate generated by the SetupIntent.
801 802 803 |
# File 'lib/stripe/resources/setup_intent.rb', line 801 def single_use_mandate @single_use_mandate end |
#status ⇒ Object (readonly)
[Status](docs.stripe.com/payments/intents#intent-statuses) of this SetupIntent, one of ‘requires_payment_method`, `requires_confirmation`, `requires_action`, `processing`, `canceled`, or `succeeded`.
803 804 805 |
# File 'lib/stripe/resources/setup_intent.rb', line 803 def status @status end |
#usage ⇒ Object (readonly)
Indicates how the payment method is intended to be used in the future.
Use ‘on_session` if you intend to only reuse the payment method when the customer is in your checkout flow. Use `off_session` if your customer may or may not be in your checkout flow. If not provided, this value defaults to `off_session`.
807 808 809 |
# File 'lib/stripe/resources/setup_intent.rb', line 807 def usage @usage end |
Class Method Details
.cancel(intent, params = {}, opts = {}) ⇒ Object
You can cancel a SetupIntent object when it’s in one of these statuses: requires_payment_method, requires_confirmation, or requires_action.
After you cancel it, setup is abandoned and any operations on the SetupIntent fail with an error. You can’t cancel the SetupIntent for a Checkout Session. [Expire the Checkout Session](docs.stripe.com/docs/api/checkout/sessions/expire) instead.
824 825 826 827 828 829 830 831 |
# File 'lib/stripe/resources/setup_intent.rb', line 824 def self.cancel(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/setup_intents/%<intent>s/cancel", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
.confirm(intent, params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to set up the current or provided payment method. For example, you would confirm a SetupIntent when a customer hits the “Save” button on a payment method management page on your website.
If the selected payment method does not require any additional steps from the customer, the SetupIntent will transition to the succeeded status.
Otherwise, it will transition to the requires_action status and suggest additional actions via next_action. If setup fails, the SetupIntent will transition to the requires_payment_method status or the canceled status if the confirmation limit is reached.
870 871 872 873 874 875 876 877 |
# File 'lib/stripe/resources/setup_intent.rb', line 870 def self.confirm(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/setup_intents/%<intent>s/confirm", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
Creates a SetupIntent object.
After you create the SetupIntent, attach a payment method and [confirm](docs.stripe.com/docs/api/setup_intents/confirm) it to collect any required permissions to charge the payment method later.
883 884 885 |
# File 'lib/stripe/resources/setup_intent.rb', line 883 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/setup_intents", params: params, opts: opts) end |
.field_remappings ⇒ Object
933 934 935 |
# File 'lib/stripe/resources/setup_intent.rb', line 933 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
922 923 924 925 926 927 928 929 930 931 |
# File 'lib/stripe/resources/setup_intent.rb', line 922 def self.inner_class_types @inner_class_types = { automatic_payment_methods: AutomaticPaymentMethods, last_setup_error: LastSetupError, managed_payments: ManagedPayments, next_action: NextAction, payment_method_configuration_details: PaymentMethodConfigurationDetails, payment_method_options: PaymentMethodOptions, } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of SetupIntents.
888 889 890 |
# File 'lib/stripe/resources/setup_intent.rb', line 888 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/setup_intents", params: params, opts: opts) end |
.object_name ⇒ Object
32 33 34 |
# File 'lib/stripe/resources/setup_intent.rb', line 32 def self.object_name "setup_intent" end |
.update(intent, params = {}, opts = {}) ⇒ Object
Updates a SetupIntent object.
893 894 895 896 897 898 899 900 |
# File 'lib/stripe/resources/setup_intent.rb', line 893 def self.update(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/setup_intents/%<intent>s", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
.verify_microdeposits(intent, params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a SetupIntent object.
913 914 915 916 917 918 919 920 |
# File 'lib/stripe/resources/setup_intent.rb', line 913 def self.verify_microdeposits(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/setup_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
Instance Method Details
#cancel(params = {}, opts = {}) ⇒ Object
You can cancel a SetupIntent object when it’s in one of these statuses: requires_payment_method, requires_confirmation, or requires_action.
After you cancel it, setup is abandoned and any operations on the SetupIntent fail with an error. You can’t cancel the SetupIntent for a Checkout Session. [Expire the Checkout Session](docs.stripe.com/docs/api/checkout/sessions/expire) instead.
812 813 814 815 816 817 818 819 |
# File 'lib/stripe/resources/setup_intent.rb', line 812 def cancel(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/setup_intents/%<intent>s/cancel", { intent: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#confirm(params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to set up the current or provided payment method. For example, you would confirm a SetupIntent when a customer hits the “Save” button on a payment method management page on your website.
If the selected payment method does not require any additional steps from the customer, the SetupIntent will transition to the succeeded status.
Otherwise, it will transition to the requires_action status and suggest additional actions via next_action. If setup fails, the SetupIntent will transition to the requires_payment_method status or the canceled status if the confirmation limit is reached.
847 848 849 850 851 852 853 854 |
# File 'lib/stripe/resources/setup_intent.rb', line 847 def confirm(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/setup_intents/%<intent>s/confirm", { intent: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#verify_microdeposits(params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a SetupIntent object.
903 904 905 906 907 908 909 910 |
# File 'lib/stripe/resources/setup_intent.rb', line 903 def verify_microdeposits(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/setup_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(self["id"]) }), params: params, opts: opts ) end |