Class: Stripe::SetupIntent
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::SetupIntent
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/setup_intent.rb
Overview
A SetupIntent guides you through the process of setting up and saving a customer’s payment credentials for future payments. For example, you can use a SetupIntent to set up and save your customer’s card without immediately collecting a payment. Later, you can use [PaymentIntents](api.stripe.com#payment_intents) to drive the payment flow.
Create a SetupIntent when you’re ready to collect your customer’s payment credentials. Don’t maintain long-lived, unconfirmed SetupIntents because they might not be valid. The SetupIntent transitions through multiple [statuses](docs.stripe.com/payments/intents#intent-statuses) as it guides you through the setup process.
Successful SetupIntents result in payment credentials that are optimized for future payments. For example, cardholders in [certain regions](stripe.com/guides/strong-customer-authentication) might need to be run through [Strong Customer Authentication](docs.stripe.com/strong-customer-authentication) during payment method collection to streamline later [off-session payments](docs.stripe.com/payments/setup-intents). If you use the SetupIntent with a [Customer](api.stripe.com#setup_intent_object-customer), it automatically attaches the resulting payment method to that Customer after successful setup. We recommend using SetupIntents or [setup_future_usage](api.stripe.com#payment_intent_object-setup_future_usage) on PaymentIntents to save payment methods to prevent saving invalid or unoptimized payment methods.
By using SetupIntents, you can reduce friction for your customers, even as regulations change over time.
Related guide: [Setup Intents API](docs.stripe.com/payments/setup-intents)
Defined Under Namespace
Classes: AutomaticPaymentMethods, LastSetupError, NextAction, PaymentMethodConfigurationDetails, PaymentMethodOptions
Constant Summary collapse
- OBJECT_NAME =
"setup_intent"
Constants inherited from StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#application ⇒ Object
readonly
ID of the Connect application that created the SetupIntent.
-
#attach_to_self ⇒ Object
readonly
If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.
-
#automatic_payment_methods ⇒ Object
readonly
Settings for dynamic payment methods compatible with this Setup Intent.
-
#cancellation_reason ⇒ Object
readonly
Reason for cancellation of this SetupIntent, one of ‘abandoned`, `requested_by_customer`, or `duplicate`.
-
#client_secret ⇒ Object
readonly
The client secret of this SetupIntent.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#customer ⇒ Object
readonly
ID of the Customer this SetupIntent belongs to, if one exists.
-
#customer_account ⇒ Object
readonly
ID of the Account this SetupIntent belongs to, if one exists.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#excluded_payment_method_types ⇒ Object
readonly
Payment method types that are excluded from this SetupIntent.
-
#flow_directions ⇒ Object
readonly
Indicates the directions of money movement for which this payment method is intended to be used.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#last_setup_error ⇒ Object
readonly
The error encountered in the previous SetupIntent confirmation.
-
#latest_attempt ⇒ Object
readonly
The most recent SetupAttempt for this SetupIntent.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#mandate ⇒ Object
readonly
ID of the multi use Mandate generated by the SetupIntent.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#next_action ⇒ Object
readonly
If present, this property tells you what actions you need to take in order for your customer to continue payment setup.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#on_behalf_of ⇒ Object
readonly
The account (if any) for which the setup is intended.
-
#payment_method ⇒ Object
readonly
ID of the payment method used with this SetupIntent.
-
#payment_method_configuration_details ⇒ Object
readonly
Information about the [payment method configuration](docs.stripe.com/api/payment_method_configurations) used for this Setup Intent.
-
#payment_method_options ⇒ Object
readonly
Payment method-specific configuration for this SetupIntent.
-
#payment_method_types ⇒ Object
readonly
The list of payment method types (e.g. card) that this SetupIntent is allowed to set up.
-
#single_use_mandate ⇒ Object
readonly
ID of the single_use Mandate generated by the SetupIntent.
-
#status ⇒ Object
readonly
[Status](docs.stripe.com/payments/intents#intent-statuses) of this SetupIntent, one of ‘requires_payment_method`, `requires_confirmation`, `requires_action`, `processing`, `canceled`, or `succeeded`.
-
#usage ⇒ Object
readonly
Indicates how the payment method is intended to be used in the future.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.cancel(intent, params = {}, opts = {}) ⇒ Object
You can cancel a SetupIntent object when it’s in one of these statuses: requires_payment_method, requires_confirmation, or requires_action.
-
.confirm(intent, params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to set up the current or provided payment method.
-
.create(params = {}, opts = {}) ⇒ Object
Creates a SetupIntent object.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of SetupIntents.
- .object_name ⇒ Object
-
.update(intent, params = {}, opts = {}) ⇒ Object
Updates a SetupIntent object.
-
.verify_microdeposits(intent, params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a SetupIntent object.
Instance Method Summary collapse
-
#cancel(params = {}, opts = {}) ⇒ Object
You can cancel a SetupIntent object when it’s in one of these statuses: requires_payment_method, requires_confirmation, or requires_action.
-
#confirm(params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to set up the current or provided payment method.
-
#verify_microdeposits(params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a SetupIntent object.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#application ⇒ Object (readonly)
ID of the Connect application that created the SetupIntent.
641 642 643 |
# File 'lib/stripe/resources/setup_intent.rb', line 641 def application @application end |
#attach_to_self ⇒ Object (readonly)
If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.
It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.
645 646 647 |
# File 'lib/stripe/resources/setup_intent.rb', line 645 def attach_to_self @attach_to_self end |
#automatic_payment_methods ⇒ Object (readonly)
Settings for dynamic payment methods compatible with this Setup Intent
647 648 649 |
# File 'lib/stripe/resources/setup_intent.rb', line 647 def automatic_payment_methods @automatic_payment_methods end |
#cancellation_reason ⇒ Object (readonly)
Reason for cancellation of this SetupIntent, one of ‘abandoned`, `requested_by_customer`, or `duplicate`.
649 650 651 |
# File 'lib/stripe/resources/setup_intent.rb', line 649 def cancellation_reason @cancellation_reason end |
#client_secret ⇒ Object (readonly)
The client secret of this SetupIntent. Used for client-side retrieval using a publishable key.
The client secret can be used to complete payment setup from your frontend. It should not be stored, logged, or exposed to anyone other than the customer. Make sure that you have TLS enabled on any page that includes the client secret.
653 654 655 |
# File 'lib/stripe/resources/setup_intent.rb', line 653 def client_secret @client_secret end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
655 656 657 |
# File 'lib/stripe/resources/setup_intent.rb', line 655 def created @created end |
#customer ⇒ Object (readonly)
ID of the Customer this SetupIntent belongs to, if one exists.
If present, the SetupIntent’s payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.
659 660 661 |
# File 'lib/stripe/resources/setup_intent.rb', line 659 def customer @customer end |
#customer_account ⇒ Object (readonly)
ID of the Account this SetupIntent belongs to, if one exists.
If present, the SetupIntent’s payment method will be attached to the Account on successful setup. Payment methods attached to other Accounts cannot be used with this SetupIntent.
663 664 665 |
# File 'lib/stripe/resources/setup_intent.rb', line 663 def customer_account @customer_account end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
665 666 667 |
# File 'lib/stripe/resources/setup_intent.rb', line 665 def description @description end |
#excluded_payment_method_types ⇒ Object (readonly)
Payment method types that are excluded from this SetupIntent.
667 668 669 |
# File 'lib/stripe/resources/setup_intent.rb', line 667 def excluded_payment_method_types @excluded_payment_method_types end |
#flow_directions ⇒ Object (readonly)
Indicates the directions of money movement for which this payment method is intended to be used.
Include ‘inbound` if you intend to use the payment method as the origin to pull funds from. Include `outbound` if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.
671 672 673 |
# File 'lib/stripe/resources/setup_intent.rb', line 671 def flow_directions @flow_directions end |
#id ⇒ Object (readonly)
Unique identifier for the object.
673 674 675 |
# File 'lib/stripe/resources/setup_intent.rb', line 673 def id @id end |
#last_setup_error ⇒ Object (readonly)
The error encountered in the previous SetupIntent confirmation.
675 676 677 |
# File 'lib/stripe/resources/setup_intent.rb', line 675 def last_setup_error @last_setup_error end |
#latest_attempt ⇒ Object (readonly)
The most recent SetupAttempt for this SetupIntent.
677 678 679 |
# File 'lib/stripe/resources/setup_intent.rb', line 677 def latest_attempt @latest_attempt end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
679 680 681 |
# File 'lib/stripe/resources/setup_intent.rb', line 679 def livemode @livemode end |
#mandate ⇒ Object (readonly)
ID of the multi use Mandate generated by the SetupIntent.
681 682 683 |
# File 'lib/stripe/resources/setup_intent.rb', line 681 def mandate @mandate end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
683 684 685 |
# File 'lib/stripe/resources/setup_intent.rb', line 683 def @metadata end |
#next_action ⇒ Object (readonly)
If present, this property tells you what actions you need to take in order for your customer to continue payment setup.
685 686 687 |
# File 'lib/stripe/resources/setup_intent.rb', line 685 def next_action @next_action end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
687 688 689 |
# File 'lib/stripe/resources/setup_intent.rb', line 687 def object @object end |
#on_behalf_of ⇒ Object (readonly)
The account (if any) for which the setup is intended.
689 690 691 |
# File 'lib/stripe/resources/setup_intent.rb', line 689 def on_behalf_of @on_behalf_of end |
#payment_method ⇒ Object (readonly)
ID of the payment method used with this SetupIntent. If the payment method is ‘card_present` and isn’t a digital wallet, then the [generated_card](docs.stripe.com/api/setup_attempts/object#setup_attempt_object-payment_method_details-card_present-generated_card) associated with the ‘latest_attempt` is attached to the Customer instead.
691 692 693 |
# File 'lib/stripe/resources/setup_intent.rb', line 691 def payment_method @payment_method end |
#payment_method_configuration_details ⇒ Object (readonly)
Information about the [payment method configuration](docs.stripe.com/api/payment_method_configurations) used for this Setup Intent.
693 694 695 |
# File 'lib/stripe/resources/setup_intent.rb', line 693 def payment_method_configuration_details @payment_method_configuration_details end |
#payment_method_options ⇒ Object (readonly)
Payment method-specific configuration for this SetupIntent.
695 696 697 |
# File 'lib/stripe/resources/setup_intent.rb', line 695 def @payment_method_options end |
#payment_method_types ⇒ Object (readonly)
The list of payment method types (e.g. card) that this SetupIntent is allowed to set up. A list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).
697 698 699 |
# File 'lib/stripe/resources/setup_intent.rb', line 697 def payment_method_types @payment_method_types end |
#single_use_mandate ⇒ Object (readonly)
ID of the single_use Mandate generated by the SetupIntent.
699 700 701 |
# File 'lib/stripe/resources/setup_intent.rb', line 699 def single_use_mandate @single_use_mandate end |
#status ⇒ Object (readonly)
[Status](docs.stripe.com/payments/intents#intent-statuses) of this SetupIntent, one of ‘requires_payment_method`, `requires_confirmation`, `requires_action`, `processing`, `canceled`, or `succeeded`.
701 702 703 |
# File 'lib/stripe/resources/setup_intent.rb', line 701 def status @status end |
#usage ⇒ Object (readonly)
Indicates how the payment method is intended to be used in the future.
Use ‘on_session` if you intend to only reuse the payment method when the customer is in your checkout flow. Use `off_session` if your customer may or may not be in your checkout flow. If not provided, this value defaults to `off_session`.
705 706 707 |
# File 'lib/stripe/resources/setup_intent.rb', line 705 def usage @usage end |
Class Method Details
.cancel(intent, params = {}, opts = {}) ⇒ Object
You can cancel a SetupIntent object when it’s in one of these statuses: requires_payment_method, requires_confirmation, or requires_action.
After you cancel it, setup is abandoned and any operations on the SetupIntent fail with an error. You can’t cancel the SetupIntent for a Checkout Session. [Expire the Checkout Session](docs.stripe.com/docs/api/checkout/sessions/expire) instead.
722 723 724 725 726 727 728 729 |
# File 'lib/stripe/resources/setup_intent.rb', line 722 def self.cancel(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/setup_intents/%<intent>s/cancel", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
.confirm(intent, params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to set up the current or provided payment method. For example, you would confirm a SetupIntent when a customer hits the “Save” button on a payment method management page on your website.
If the selected payment method does not require any additional steps from the customer, the SetupIntent will transition to the succeeded status.
Otherwise, it will transition to the requires_action status and suggest additional actions via next_action. If setup fails, the SetupIntent will transition to the requires_payment_method status or the canceled status if the confirmation limit is reached.
768 769 770 771 772 773 774 775 |
# File 'lib/stripe/resources/setup_intent.rb', line 768 def self.confirm(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/setup_intents/%<intent>s/confirm", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
Creates a SetupIntent object.
After you create the SetupIntent, attach a payment method and [confirm](docs.stripe.com/docs/api/setup_intents/confirm) it to collect any required permissions to charge the payment method later.
781 782 783 |
# File 'lib/stripe/resources/setup_intent.rb', line 781 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/setup_intents", params: params, opts: opts) end |
.field_remappings ⇒ Object
830 831 832 |
# File 'lib/stripe/resources/setup_intent.rb', line 830 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
820 821 822 823 824 825 826 827 828 |
# File 'lib/stripe/resources/setup_intent.rb', line 820 def self.inner_class_types @inner_class_types = { automatic_payment_methods: AutomaticPaymentMethods, last_setup_error: LastSetupError, next_action: NextAction, payment_method_configuration_details: PaymentMethodConfigurationDetails, payment_method_options: PaymentMethodOptions, } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of SetupIntents.
786 787 788 |
# File 'lib/stripe/resources/setup_intent.rb', line 786 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/setup_intents", params: params, opts: opts) end |
.object_name ⇒ Object
32 33 34 |
# File 'lib/stripe/resources/setup_intent.rb', line 32 def self.object_name "setup_intent" end |
.update(intent, params = {}, opts = {}) ⇒ Object
Updates a SetupIntent object.
791 792 793 794 795 796 797 798 |
# File 'lib/stripe/resources/setup_intent.rb', line 791 def self.update(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/setup_intents/%<intent>s", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
.verify_microdeposits(intent, params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a SetupIntent object.
811 812 813 814 815 816 817 818 |
# File 'lib/stripe/resources/setup_intent.rb', line 811 def self.verify_microdeposits(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/setup_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
Instance Method Details
#cancel(params = {}, opts = {}) ⇒ Object
You can cancel a SetupIntent object when it’s in one of these statuses: requires_payment_method, requires_confirmation, or requires_action.
After you cancel it, setup is abandoned and any operations on the SetupIntent fail with an error. You can’t cancel the SetupIntent for a Checkout Session. [Expire the Checkout Session](docs.stripe.com/docs/api/checkout/sessions/expire) instead.
710 711 712 713 714 715 716 717 |
# File 'lib/stripe/resources/setup_intent.rb', line 710 def cancel(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/setup_intents/%<intent>s/cancel", { intent: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#confirm(params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to set up the current or provided payment method. For example, you would confirm a SetupIntent when a customer hits the “Save” button on a payment method management page on your website.
If the selected payment method does not require any additional steps from the customer, the SetupIntent will transition to the succeeded status.
Otherwise, it will transition to the requires_action status and suggest additional actions via next_action. If setup fails, the SetupIntent will transition to the requires_payment_method status or the canceled status if the confirmation limit is reached.
745 746 747 748 749 750 751 752 |
# File 'lib/stripe/resources/setup_intent.rb', line 745 def confirm(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/setup_intents/%<intent>s/confirm", { intent: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#verify_microdeposits(params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a SetupIntent object.
801 802 803 804 805 806 807 808 |
# File 'lib/stripe/resources/setup_intent.rb', line 801 def verify_microdeposits(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/setup_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(self["id"]) }), params: params, opts: opts ) end |