Class: Stripe::SetupIntent

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/setup_intent.rb

Overview

A SetupIntent guides you through the process of setting up and saving a customer’s payment credentials for future payments. For example, you can use a SetupIntent to set up and save your customer’s card without immediately collecting a payment. Later, you can use [PaymentIntents](stripe.com/docs/api#payment_intents) to drive the payment flow.

Create a SetupIntent when you’re ready to collect your customer’s payment credentials. Don’t maintain long-lived, unconfirmed SetupIntents because they might not be valid. The SetupIntent transitions through multiple [statuses](docs.stripe.com/payments/intents#intent-statuses) as it guides you through the setup process.

Successful SetupIntents result in payment credentials that are optimized for future payments. For example, cardholders in [certain regions](stripe.com/guides/strong-customer-authentication) might need to be run through [Strong Customer Authentication](docs.stripe.com/strong-customer-authentication) during payment method collection to streamline later [off-session payments](docs.stripe.com/payments/setup-intents). If you use the SetupIntent with a [Customer](stripe.com/docs/api#setup_intent_object-customer), it automatically attaches the resulting payment method to that Customer after successful setup. We recommend using SetupIntents or [setup_future_usage](stripe.com/docs/api#payment_intent_object-setup_future_usage) on PaymentIntents to save payment methods to prevent saving invalid or unoptimized payment methods.

By using SetupIntents, you can reduce friction for your customers, even as regulations change over time.

Related guide: [Setup Intents API](docs.stripe.com/payments/setup-intents)

Defined Under Namespace

Classes: AutomaticPaymentMethods, CancelParams, ConfirmParams, CreateParams, LastSetupError, ListParams, NextAction, PaymentMethodConfigurationDetails, PaymentMethodOptions, UpdateParams, VerifyMicrodepositsParams

Constant Summary collapse

OBJECT_NAME =
"setup_intent"

Constants inherited from StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applicationObject (readonly)

ID of the Connect application that created the SetupIntent.



4135
4136
4137
# File 'lib/stripe/resources/setup_intent.rb', line 4135

def application
  @application
end

#attach_to_selfObject (readonly)

If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.

It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.



4139
4140
4141
# File 'lib/stripe/resources/setup_intent.rb', line 4139

def attach_to_self
  @attach_to_self
end

#automatic_payment_methodsObject (readonly)

Settings for dynamic payment methods compatible with this Setup Intent



4141
4142
4143
# File 'lib/stripe/resources/setup_intent.rb', line 4141

def automatic_payment_methods
  @automatic_payment_methods
end

#cancellation_reasonObject (readonly)

Reason for cancellation of this SetupIntent, one of ‘abandoned`, `requested_by_customer`, or `duplicate`.



4143
4144
4145
# File 'lib/stripe/resources/setup_intent.rb', line 4143

def cancellation_reason
  @cancellation_reason
end

#client_secretObject (readonly)

The client secret of this SetupIntent. Used for client-side retrieval using a publishable key.

The client secret can be used to complete payment setup from your frontend. It should not be stored, logged, or exposed to anyone other than the customer. Make sure that you have TLS enabled on any page that includes the client secret.



4147
4148
4149
# File 'lib/stripe/resources/setup_intent.rb', line 4147

def client_secret
  @client_secret
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



4149
4150
4151
# File 'lib/stripe/resources/setup_intent.rb', line 4149

def created
  @created
end

#customerObject (readonly)

ID of the Customer this SetupIntent belongs to, if one exists.

If present, the SetupIntent’s payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.



4153
4154
4155
# File 'lib/stripe/resources/setup_intent.rb', line 4153

def customer
  @customer
end

#customer_accountObject (readonly)

ID of the Account this SetupIntent belongs to, if one exists.

If present, the SetupIntent’s payment method will be attached to the Account on successful setup. Payment methods attached to other Accounts cannot be used with this SetupIntent.



4157
4158
4159
# File 'lib/stripe/resources/setup_intent.rb', line 4157

def 
  @customer_account
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



4159
4160
4161
# File 'lib/stripe/resources/setup_intent.rb', line 4159

def description
  @description
end

#flow_directionsObject (readonly)

Indicates the directions of money movement for which this payment method is intended to be used.

Include ‘inbound` if you intend to use the payment method as the origin to pull funds from. Include `outbound` if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.



4163
4164
4165
# File 'lib/stripe/resources/setup_intent.rb', line 4163

def flow_directions
  @flow_directions
end

#idObject (readonly)

Unique identifier for the object.



4165
4166
4167
# File 'lib/stripe/resources/setup_intent.rb', line 4165

def id
  @id
end

#last_setup_errorObject (readonly)

The error encountered in the previous SetupIntent confirmation.



4167
4168
4169
# File 'lib/stripe/resources/setup_intent.rb', line 4167

def last_setup_error
  @last_setup_error
end

#latest_attemptObject (readonly)

The most recent SetupAttempt for this SetupIntent.



4169
4170
4171
# File 'lib/stripe/resources/setup_intent.rb', line 4169

def latest_attempt
  @latest_attempt
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



4171
4172
4173
# File 'lib/stripe/resources/setup_intent.rb', line 4171

def livemode
  @livemode
end

#mandateObject (readonly)

ID of the multi use Mandate generated by the SetupIntent.



4173
4174
4175
# File 'lib/stripe/resources/setup_intent.rb', line 4173

def mandate
  @mandate
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



4175
4176
4177
# File 'lib/stripe/resources/setup_intent.rb', line 4175

def 
  @metadata
end

#next_actionObject (readonly)

If present, this property tells you what actions you need to take in order for your customer to continue payment setup.



4177
4178
4179
# File 'lib/stripe/resources/setup_intent.rb', line 4177

def next_action
  @next_action
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



4179
4180
4181
# File 'lib/stripe/resources/setup_intent.rb', line 4179

def object
  @object
end

#on_behalf_ofObject (readonly)

The account (if any) for which the setup is intended.



4181
4182
4183
# File 'lib/stripe/resources/setup_intent.rb', line 4181

def on_behalf_of
  @on_behalf_of
end

#payment_methodObject (readonly)

ID of the payment method used with this SetupIntent. If the payment method is ‘card_present` and isn’t a digital wallet, then the [generated_card](docs.stripe.com/api/setup_attempts/object#setup_attempt_object-payment_method_details-card_present-generated_card) associated with the ‘latest_attempt` is attached to the Customer instead.



4183
4184
4185
# File 'lib/stripe/resources/setup_intent.rb', line 4183

def payment_method
  @payment_method
end

#payment_method_configuration_detailsObject (readonly)

Information about the [payment method configuration](stripe.com/docs/api/payment_method_configurations) used for this Setup Intent.



4185
4186
4187
# File 'lib/stripe/resources/setup_intent.rb', line 4185

def payment_method_configuration_details
  @payment_method_configuration_details
end

#payment_method_optionsObject (readonly)

Payment method-specific configuration for this SetupIntent.



4187
4188
4189
# File 'lib/stripe/resources/setup_intent.rb', line 4187

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject (readonly)

The list of payment method types (e.g. card) that this SetupIntent is allowed to set up. A list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).



4189
4190
4191
# File 'lib/stripe/resources/setup_intent.rb', line 4189

def payment_method_types
  @payment_method_types
end

#single_use_mandateObject (readonly)

ID of the single_use Mandate generated by the SetupIntent.



4191
4192
4193
# File 'lib/stripe/resources/setup_intent.rb', line 4191

def single_use_mandate
  @single_use_mandate
end

#statusObject (readonly)

[Status](stripe.com/docs/payments/intents#intent-statuses) of this SetupIntent, one of ‘requires_payment_method`, `requires_confirmation`, `requires_action`, `processing`, `canceled`, or `succeeded`.



4193
4194
4195
# File 'lib/stripe/resources/setup_intent.rb', line 4193

def status
  @status
end

#usageObject (readonly)

Indicates how the payment method is intended to be used in the future.

Use ‘on_session` if you intend to only reuse the payment method when the customer is in your checkout flow. Use `off_session` if your customer may or may not be in your checkout flow. If not provided, this value defaults to `off_session`.



4197
4198
4199
# File 'lib/stripe/resources/setup_intent.rb', line 4197

def usage
  @usage
end

Class Method Details

.cancel(intent, params = {}, opts = {}) ⇒ Object

You can cancel a SetupIntent object when it’s in one of these statuses: requires_payment_method, requires_confirmation, or requires_action.

After you cancel it, setup is abandoned and any operations on the SetupIntent fail with an error. You can’t cancel the SetupIntent for a Checkout Session. [Expire the Checkout Session](docs.stripe.com/docs/api/checkout/sessions/expire) instead.



4214
4215
4216
4217
4218
4219
4220
4221
# File 'lib/stripe/resources/setup_intent.rb', line 4214

def self.cancel(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/setup_intents/%<intent>s/cancel", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.confirm(intent, params = {}, opts = {}) ⇒ Object

Confirm that your customer intends to set up the current or provided payment method. For example, you would confirm a SetupIntent when a customer hits the “Save” button on a payment method management page on your website.

If the selected payment method does not require any additional steps from the customer, the SetupIntent will transition to the succeeded status.

Otherwise, it will transition to the requires_action status and suggest additional actions via next_action. If setup fails, the SetupIntent will transition to the requires_payment_method status or the canceled status if the confirmation limit is reached.



4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/stripe/resources/setup_intent.rb', line 4260

def self.confirm(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/setup_intents/%<intent>s/confirm", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

Creates a SetupIntent object.

After you create the SetupIntent, attach a payment method and [confirm](docs.stripe.com/docs/api/setup_intents/confirm) it to collect any required permissions to charge the payment method later.



4273
4274
4275
# File 'lib/stripe/resources/setup_intent.rb', line 4273

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/setup_intents", params: params, opts: opts)
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of SetupIntents.



4278
4279
4280
# File 'lib/stripe/resources/setup_intent.rb', line 4278

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/setup_intents", params: params, opts: opts)
end

.object_nameObject



32
33
34
# File 'lib/stripe/resources/setup_intent.rb', line 32

def self.object_name
  "setup_intent"
end

.update(intent, params = {}, opts = {}) ⇒ Object

Updates a SetupIntent object.



4283
4284
4285
4286
4287
4288
4289
4290
# File 'lib/stripe/resources/setup_intent.rb', line 4283

def self.update(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/setup_intents/%<intent>s", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.verify_microdeposits(intent, params = {}, opts = {}) ⇒ Object

Verifies microdeposits on a SetupIntent object.



4303
4304
4305
4306
4307
4308
4309
4310
# File 'lib/stripe/resources/setup_intent.rb', line 4303

def self.verify_microdeposits(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/setup_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#cancel(params = {}, opts = {}) ⇒ Object

You can cancel a SetupIntent object when it’s in one of these statuses: requires_payment_method, requires_confirmation, or requires_action.

After you cancel it, setup is abandoned and any operations on the SetupIntent fail with an error. You can’t cancel the SetupIntent for a Checkout Session. [Expire the Checkout Session](docs.stripe.com/docs/api/checkout/sessions/expire) instead.



4202
4203
4204
4205
4206
4207
4208
4209
# File 'lib/stripe/resources/setup_intent.rb', line 4202

def cancel(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/setup_intents/%<intent>s/cancel", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#confirm(params = {}, opts = {}) ⇒ Object

Confirm that your customer intends to set up the current or provided payment method. For example, you would confirm a SetupIntent when a customer hits the “Save” button on a payment method management page on your website.

If the selected payment method does not require any additional steps from the customer, the SetupIntent will transition to the succeeded status.

Otherwise, it will transition to the requires_action status and suggest additional actions via next_action. If setup fails, the SetupIntent will transition to the requires_payment_method status or the canceled status if the confirmation limit is reached.



4237
4238
4239
4240
4241
4242
4243
4244
# File 'lib/stripe/resources/setup_intent.rb', line 4237

def confirm(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/setup_intents/%<intent>s/confirm", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#verify_microdeposits(params = {}, opts = {}) ⇒ Object

Verifies microdeposits on a SetupIntent object.



4293
4294
4295
4296
4297
4298
4299
4300
# File 'lib/stripe/resources/setup_intent.rb', line 4293

def verify_microdeposits(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/setup_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end