Class: Stripe::SetupIntent

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/setup_intent.rb

Overview

A SetupIntent guides you through the process of setting up and saving a customer’s payment credentials for future payments. For example, you can use a SetupIntent to set up and save your customer’s card without immediately collecting a payment. Later, you can use [PaymentIntents](stripe.com/docs/api#payment_intents) to drive the payment flow.

Create a SetupIntent when you’re ready to collect your customer’s payment credentials. Don’t maintain long-lived, unconfirmed SetupIntents because they might not be valid. The SetupIntent transitions through multiple [statuses](docs.stripe.com/payments/intents#intent-statuses) as it guides you through the setup process.

Successful SetupIntents result in payment credentials that are optimized for future payments. For example, cardholders in [certain regions](stripe.com/guides/strong-customer-authentication) might need to be run through [Strong Customer Authentication](docs.stripe.com/strong-customer-authentication) during payment method collection to streamline later [off-session payments](docs.stripe.com/payments/setup-intents). If you use the SetupIntent with a [Customer](stripe.com/docs/api#setup_intent_object-customer), it automatically attaches the resulting payment method to that Customer after successful setup. We recommend using SetupIntents or [setup_future_usage](stripe.com/docs/api#payment_intent_object-setup_future_usage) on PaymentIntents to save payment methods to prevent saving invalid or unoptimized payment methods.

By using SetupIntents, you can reduce friction for your customers, even as regulations change over time.

Related guide: [Setup Intents API](docs.stripe.com/payments/setup-intents)

Defined Under Namespace

Classes: AutomaticPaymentMethods, CancelParams, ConfirmParams, CreateParams, LastSetupError, ListParams, NextAction, PaymentMethodConfigurationDetails, PaymentMethodOptions, RetrieveParams, UpdateParams, VerifyMicrodepositsParams

Constant Summary collapse

OBJECT_NAME =
"setup_intent"

Constants inherited from StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applicationObject (readonly)

ID of the Connect application that created the SetupIntent.



3831
3832
3833
# File 'lib/stripe/resources/setup_intent.rb', line 3831

def application
  @application
end

#attach_to_selfObject (readonly)

If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.

It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.



3835
3836
3837
# File 'lib/stripe/resources/setup_intent.rb', line 3835

def attach_to_self
  @attach_to_self
end

#automatic_payment_methodsObject (readonly)

Settings for dynamic payment methods compatible with this Setup Intent



3837
3838
3839
# File 'lib/stripe/resources/setup_intent.rb', line 3837

def automatic_payment_methods
  @automatic_payment_methods
end

#cancellation_reasonObject (readonly)

Reason for cancellation of this SetupIntent, one of ‘abandoned`, `requested_by_customer`, or `duplicate`.



3839
3840
3841
# File 'lib/stripe/resources/setup_intent.rb', line 3839

def cancellation_reason
  @cancellation_reason
end

#client_secretObject (readonly)

The client secret of this SetupIntent. Used for client-side retrieval using a publishable key.

The client secret can be used to complete payment setup from your frontend. It should not be stored, logged, or exposed to anyone other than the customer. Make sure that you have TLS enabled on any page that includes the client secret.



3843
3844
3845
# File 'lib/stripe/resources/setup_intent.rb', line 3843

def client_secret
  @client_secret
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



3845
3846
3847
# File 'lib/stripe/resources/setup_intent.rb', line 3845

def created
  @created
end

#customerObject (readonly)

ID of the Customer this SetupIntent belongs to, if one exists.

If present, the SetupIntent’s payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.



3849
3850
3851
# File 'lib/stripe/resources/setup_intent.rb', line 3849

def customer
  @customer
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



3851
3852
3853
# File 'lib/stripe/resources/setup_intent.rb', line 3851

def description
  @description
end

#flow_directionsObject (readonly)

Indicates the directions of money movement for which this payment method is intended to be used.

Include ‘inbound` if you intend to use the payment method as the origin to pull funds from. Include `outbound` if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.



3855
3856
3857
# File 'lib/stripe/resources/setup_intent.rb', line 3855

def flow_directions
  @flow_directions
end

#idObject (readonly)

Unique identifier for the object.



3857
3858
3859
# File 'lib/stripe/resources/setup_intent.rb', line 3857

def id
  @id
end

#last_setup_errorObject (readonly)

The error encountered in the previous SetupIntent confirmation.



3859
3860
3861
# File 'lib/stripe/resources/setup_intent.rb', line 3859

def last_setup_error
  @last_setup_error
end

#latest_attemptObject (readonly)

The most recent SetupAttempt for this SetupIntent.



3861
3862
3863
# File 'lib/stripe/resources/setup_intent.rb', line 3861

def latest_attempt
  @latest_attempt
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



3863
3864
3865
# File 'lib/stripe/resources/setup_intent.rb', line 3863

def livemode
  @livemode
end

#mandateObject (readonly)

ID of the multi use Mandate generated by the SetupIntent.



3865
3866
3867
# File 'lib/stripe/resources/setup_intent.rb', line 3865

def mandate
  @mandate
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



3867
3868
3869
# File 'lib/stripe/resources/setup_intent.rb', line 3867

def 
  @metadata
end

#next_actionObject (readonly)

If present, this property tells you what actions you need to take in order for your customer to continue payment setup.



3869
3870
3871
# File 'lib/stripe/resources/setup_intent.rb', line 3869

def next_action
  @next_action
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



3871
3872
3873
# File 'lib/stripe/resources/setup_intent.rb', line 3871

def object
  @object
end

#on_behalf_ofObject (readonly)

The account (if any) for which the setup is intended.



3873
3874
3875
# File 'lib/stripe/resources/setup_intent.rb', line 3873

def on_behalf_of
  @on_behalf_of
end

#payment_methodObject (readonly)

ID of the payment method used with this SetupIntent. If the payment method is ‘card_present` and isn’t a digital wallet, then the [generated_card](docs.stripe.com/api/setup_attempts/object#setup_attempt_object-payment_method_details-card_present-generated_card) associated with the ‘latest_attempt` is attached to the Customer instead.



3875
3876
3877
# File 'lib/stripe/resources/setup_intent.rb', line 3875

def payment_method
  @payment_method
end

#payment_method_configuration_detailsObject (readonly)

Information about the [payment method configuration](stripe.com/docs/api/payment_method_configurations) used for this Setup Intent.



3877
3878
3879
# File 'lib/stripe/resources/setup_intent.rb', line 3877

def payment_method_configuration_details
  @payment_method_configuration_details
end

#payment_method_optionsObject (readonly)

Payment method-specific configuration for this SetupIntent.



3879
3880
3881
# File 'lib/stripe/resources/setup_intent.rb', line 3879

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject (readonly)

The list of payment method types (e.g. card) that this SetupIntent is allowed to set up.



3881
3882
3883
# File 'lib/stripe/resources/setup_intent.rb', line 3881

def payment_method_types
  @payment_method_types
end

#single_use_mandateObject (readonly)

ID of the single_use Mandate generated by the SetupIntent.



3883
3884
3885
# File 'lib/stripe/resources/setup_intent.rb', line 3883

def single_use_mandate
  @single_use_mandate
end

#statusObject (readonly)

[Status](stripe.com/docs/payments/intents#intent-statuses) of this SetupIntent, one of ‘requires_payment_method`, `requires_confirmation`, `requires_action`, `processing`, `canceled`, or `succeeded`.



3885
3886
3887
# File 'lib/stripe/resources/setup_intent.rb', line 3885

def status
  @status
end

#usageObject (readonly)

Indicates how the payment method is intended to be used in the future.

Use ‘on_session` if you intend to only reuse the payment method when the customer is in your checkout flow. Use `off_session` if your customer may or may not be in your checkout flow. If not provided, this value defaults to `off_session`.



3889
3890
3891
# File 'lib/stripe/resources/setup_intent.rb', line 3889

def usage
  @usage
end

Class Method Details

.cancel(intent, params = {}, opts = {}) ⇒ Object

You can cancel a SetupIntent object when it’s in one of these statuses: requires_payment_method, requires_confirmation, or requires_action.

After you cancel it, setup is abandoned and any operations on the SetupIntent fail with an error. You can’t cancel the SetupIntent for a Checkout Session. [Expire the Checkout Session](stripe.com/docs/api/checkout/sessions/expire) instead.



3906
3907
3908
3909
3910
3911
3912
3913
# File 'lib/stripe/resources/setup_intent.rb', line 3906

def self.cancel(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/setup_intents/%<intent>s/cancel", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.confirm(intent, params = {}, opts = {}) ⇒ Object

Confirm that your customer intends to set up the current or provided payment method. For example, you would confirm a SetupIntent when a customer hits the “Save” button on a payment method management page on your website.

If the selected payment method does not require any additional steps from the customer, the SetupIntent will transition to the succeeded status.

Otherwise, it will transition to the requires_action status and suggest additional actions via next_action. If setup fails, the SetupIntent will transition to the requires_payment_method status or the canceled status if the confirmation limit is reached.



3952
3953
3954
3955
3956
3957
3958
3959
# File 'lib/stripe/resources/setup_intent.rb', line 3952

def self.confirm(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/setup_intents/%<intent>s/confirm", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

Creates a SetupIntent object.

After you create the SetupIntent, attach a payment method and [confirm](stripe.com/docs/api/setup_intents/confirm) it to collect any required permissions to charge the payment method later.



3965
3966
3967
# File 'lib/stripe/resources/setup_intent.rb', line 3965

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/setup_intents", params: params, opts: opts)
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of SetupIntents.



3970
3971
3972
# File 'lib/stripe/resources/setup_intent.rb', line 3970

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/setup_intents", params: params, opts: opts)
end

.object_nameObject



32
33
34
# File 'lib/stripe/resources/setup_intent.rb', line 32

def self.object_name
  "setup_intent"
end

.update(intent, params = {}, opts = {}) ⇒ Object

Updates a SetupIntent object.



3975
3976
3977
3978
3979
3980
3981
3982
# File 'lib/stripe/resources/setup_intent.rb', line 3975

def self.update(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/setup_intents/%<intent>s", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.verify_microdeposits(intent, params = {}, opts = {}) ⇒ Object

Verifies microdeposits on a SetupIntent object.



3995
3996
3997
3998
3999
4000
4001
4002
# File 'lib/stripe/resources/setup_intent.rb', line 3995

def self.verify_microdeposits(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/setup_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#cancel(params = {}, opts = {}) ⇒ Object

You can cancel a SetupIntent object when it’s in one of these statuses: requires_payment_method, requires_confirmation, or requires_action.

After you cancel it, setup is abandoned and any operations on the SetupIntent fail with an error. You can’t cancel the SetupIntent for a Checkout Session. [Expire the Checkout Session](stripe.com/docs/api/checkout/sessions/expire) instead.



3894
3895
3896
3897
3898
3899
3900
3901
# File 'lib/stripe/resources/setup_intent.rb', line 3894

def cancel(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/setup_intents/%<intent>s/cancel", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#confirm(params = {}, opts = {}) ⇒ Object

Confirm that your customer intends to set up the current or provided payment method. For example, you would confirm a SetupIntent when a customer hits the “Save” button on a payment method management page on your website.

If the selected payment method does not require any additional steps from the customer, the SetupIntent will transition to the succeeded status.

Otherwise, it will transition to the requires_action status and suggest additional actions via next_action. If setup fails, the SetupIntent will transition to the requires_payment_method status or the canceled status if the confirmation limit is reached.



3929
3930
3931
3932
3933
3934
3935
3936
# File 'lib/stripe/resources/setup_intent.rb', line 3929

def confirm(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/setup_intents/%<intent>s/confirm", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#verify_microdeposits(params = {}, opts = {}) ⇒ Object

Verifies microdeposits on a SetupIntent object.



3985
3986
3987
3988
3989
3990
3991
3992
# File 'lib/stripe/resources/setup_intent.rb', line 3985

def verify_microdeposits(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/setup_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end