Class: Stripe::SetupIntent::ConfirmParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::ConfirmParams
- Defined in:
- lib/stripe/resources/setup_intent.rb
Defined Under Namespace
Classes: MandateData, PaymentMethodData, PaymentMethodOptions
Instance Attribute Summary collapse
-
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this SetupIntent.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#mandate_data ⇒ Object
Attribute for param field mandate_data.
-
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.
-
#payment_method_data ⇒ Object
When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.
-
#payment_method_options ⇒ Object
Payment method-specific configuration for this SetupIntent.
-
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate on the payment method’s app or site.
-
#use_stripe_sdk ⇒ Object
Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
Instance Method Summary collapse
-
#initialize(confirmation_token: nil, expand: nil, mandate_data: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, use_stripe_sdk: nil) ⇒ ConfirmParams
constructor
A new instance of ConfirmParams.
Methods inherited from RequestParams
Constructor Details
#initialize(confirmation_token: nil, expand: nil, mandate_data: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, use_stripe_sdk: nil) ⇒ ConfirmParams
Returns a new instance of ConfirmParams.
3996 3997 3998 3999 4000 4001 4002 4003 4004 4005 4006 4007 4008 4009 4010 4011 4012 4013 4014 |
# File 'lib/stripe/resources/setup_intent.rb', line 3996 def initialize( confirmation_token: nil, expand: nil, mandate_data: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, use_stripe_sdk: nil ) @confirmation_token = confirmation_token @expand = @mandate_data = mandate_data @payment_method = payment_method @payment_method_data = payment_method_data @payment_method_options = @return_url = return_url @use_stripe_sdk = use_stripe_sdk end |
Instance Attribute Details
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this SetupIntent.
If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.
3977 3978 3979 |
# File 'lib/stripe/resources/setup_intent.rb', line 3977 def confirmation_token @confirmation_token end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
3979 3980 3981 |
# File 'lib/stripe/resources/setup_intent.rb', line 3979 def @expand end |
#mandate_data ⇒ Object
Attribute for param field mandate_data
3981 3982 3983 |
# File 'lib/stripe/resources/setup_intent.rb', line 3981 def mandate_data @mandate_data end |
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.
3983 3984 3985 |
# File 'lib/stripe/resources/setup_intent.rb', line 3983 def payment_method @payment_method end |
#payment_method_data ⇒ Object
When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.
3986 3987 3988 |
# File 'lib/stripe/resources/setup_intent.rb', line 3986 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment method-specific configuration for this SetupIntent.
3988 3989 3990 |
# File 'lib/stripe/resources/setup_intent.rb', line 3988 def @payment_method_options end |
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.
3992 3993 3994 |
# File 'lib/stripe/resources/setup_intent.rb', line 3992 def return_url @return_url end |
#use_stripe_sdk ⇒ Object
Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
3994 3995 3996 |
# File 'lib/stripe/resources/setup_intent.rb', line 3994 def use_stripe_sdk @use_stripe_sdk end |