Class: Stripe::SetupIntent::ConfirmParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: MandateData, PaymentMethodData, PaymentMethodOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(confirmation_token: nil, expand: nil, mandate_data: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, use_stripe_sdk: nil) ⇒ ConfirmParams

Returns a new instance of ConfirmParams.



4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
4297
4298
4299
4300
4301
4302
4303
# File 'lib/stripe/resources/setup_intent.rb', line 4285

def initialize(
  confirmation_token: nil,
  expand: nil,
  mandate_data: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  return_url: nil,
  use_stripe_sdk: nil
)
  @confirmation_token = confirmation_token
  @expand = expand
  @mandate_data = mandate_data
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @return_url = return_url
  @use_stripe_sdk = use_stripe_sdk
end

Instance Attribute Details

#confirmation_tokenObject

ID of the ConfirmationToken used to confirm this SetupIntent.

If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.



4259
4260
4261
# File 'lib/stripe/resources/setup_intent.rb', line 4259

def confirmation_token
  @confirmation_token
end

#expandObject

Specifies which fields in the response should be expanded.



4262
4263
4264
# File 'lib/stripe/resources/setup_intent.rb', line 4262

def expand
  @expand
end

#mandate_dataObject

Attribute for param field mandate_data



4265
4266
4267
# File 'lib/stripe/resources/setup_intent.rb', line 4265

def mandate_data
  @mandate_data
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.



4268
4269
4270
# File 'lib/stripe/resources/setup_intent.rb', line 4268

def payment_method
  @payment_method
end

#payment_method_dataObject

When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.



4272
4273
4274
# File 'lib/stripe/resources/setup_intent.rb', line 4272

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this SetupIntent.



4275
4276
4277
# File 'lib/stripe/resources/setup_intent.rb', line 4275

def payment_method_options
  @payment_method_options
end

#return_urlObject

The URL to redirect your customer back to after they authenticate on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.



4280
4281
4282
# File 'lib/stripe/resources/setup_intent.rb', line 4280

def return_url
  @return_url
end

#use_stripe_sdkObject

Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.



4283
4284
4285
# File 'lib/stripe/resources/setup_intent.rb', line 4283

def use_stripe_sdk
  @use_stripe_sdk
end