Class: Stripe::SetupIntent::ConfirmParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



2933
2934
2935
2936
2937
2938
# File 'lib/stripe/resources/setup_intent.rb', line 2933

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



2925
2926
2927
# File 'lib/stripe/resources/setup_intent.rb', line 2925

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



2927
2928
2929
# File 'lib/stripe/resources/setup_intent.rb', line 2927

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



2929
2930
2931
# File 'lib/stripe/resources/setup_intent.rb', line 2929

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



2931
2932
2933
# File 'lib/stripe/resources/setup_intent.rb', line 2931

def type
  @type
end