Class: Stripe::SetupIntent::ConfirmParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



2742
2743
2744
2745
2746
2747
# File 'lib/stripe/resources/setup_intent.rb', line 2742

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



2734
2735
2736
# File 'lib/stripe/resources/setup_intent.rb', line 2734

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



2736
2737
2738
# File 'lib/stripe/resources/setup_intent.rb', line 2736

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



2738
2739
2740
# File 'lib/stripe/resources/setup_intent.rb', line 2738

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



2740
2741
2742
# File 'lib/stripe/resources/setup_intent.rb', line 2740

def type
  @type
end