Class: Stripe::SetupIntent::ConfirmParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



2462
2463
2464
2465
2466
2467
# File 'lib/stripe/resources/setup_intent.rb', line 2462

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



2454
2455
2456
# File 'lib/stripe/resources/setup_intent.rb', line 2454

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



2456
2457
2458
# File 'lib/stripe/resources/setup_intent.rb', line 2456

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



2458
2459
2460
# File 'lib/stripe/resources/setup_intent.rb', line 2458

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



2460
2461
2462
# File 'lib/stripe/resources/setup_intent.rb', line 2460

def type
  @type
end