Class: Stripe::SetupIntent::ConfirmParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



2712
2713
2714
2715
2716
2717
# File 'lib/stripe/resources/setup_intent.rb', line 2712

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



2704
2705
2706
# File 'lib/stripe/resources/setup_intent.rb', line 2704

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



2706
2707
2708
# File 'lib/stripe/resources/setup_intent.rb', line 2706

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



2708
2709
2710
# File 'lib/stripe/resources/setup_intent.rb', line 2708

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



2710
2711
2712
# File 'lib/stripe/resources/setup_intent.rb', line 2710

def type
  @type
end