Class: Stripe::SetupIntent::ConfirmParams::MandateData::CustomerAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::ConfirmParams::MandateData::CustomerAcceptance
- Defined in:
- lib/stripe/resources/setup_intent.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#accepted_at ⇒ Object
The time at which the customer accepted the Mandate.
-
#offline ⇒ Object
If this is a Mandate accepted offline, this hash contains details about the offline acceptance.
-
#online ⇒ Object
If this is a Mandate accepted online, this hash contains details about the online acceptance.
-
#type ⇒ Object
The type of customer acceptance information included with the Mandate.
Instance Method Summary collapse
-
#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance
constructor
A new instance of CustomerAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance
Returns a new instance of CustomerAcceptance.
3087 3088 3089 3090 3091 3092 |
# File 'lib/stripe/resources/setup_intent.rb', line 3087 def initialize(accepted_at: nil, offline: nil, online: nil, type: nil) @accepted_at = accepted_at @offline = offline @online = online @type = type end |
Instance Attribute Details
#accepted_at ⇒ Object
The time at which the customer accepted the Mandate.
3076 3077 3078 |
# File 'lib/stripe/resources/setup_intent.rb', line 3076 def accepted_at @accepted_at end |
#offline ⇒ Object
If this is a Mandate accepted offline, this hash contains details about the offline acceptance.
3079 3080 3081 |
# File 'lib/stripe/resources/setup_intent.rb', line 3079 def offline @offline end |
#online ⇒ Object
If this is a Mandate accepted online, this hash contains details about the online acceptance.
3082 3083 3084 |
# File 'lib/stripe/resources/setup_intent.rb', line 3082 def online @online end |
#type ⇒ Object
The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.
3085 3086 3087 |
# File 'lib/stripe/resources/setup_intent.rb', line 3085 def type @type end |