Class: Stripe::SetupIntent::ConfirmParams::MandateData::CustomerAcceptance::Online

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ip_address: nil, user_agent: nil) ⇒ Online

Returns a new instance of Online.



2448
2449
2450
2451
# File 'lib/stripe/resources/setup_intent.rb', line 2448

def initialize(ip_address: nil, user_agent: nil)
  @ip_address = ip_address
  @user_agent = user_agent
end

Instance Attribute Details

#ip_addressObject

The IP address from which the Mandate was accepted by the customer.



2444
2445
2446
# File 'lib/stripe/resources/setup_intent.rb', line 2444

def ip_address
  @ip_address
end

#user_agentObject

The user agent of the browser from which the Mandate was accepted by the customer.



2446
2447
2448
# File 'lib/stripe/resources/setup_intent.rb', line 2446

def user_agent
  @user_agent
end