Class: Stripe::SetupIntent::ConfirmParams::MandateData::CustomerAcceptance::Online

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ip_address: nil, user_agent: nil) ⇒ Online

Returns a new instance of Online.



2712
2713
2714
2715
# File 'lib/stripe/resources/setup_intent.rb', line 2712

def initialize(ip_address: nil, user_agent: nil)
  @ip_address = ip_address
  @user_agent = user_agent
end

Instance Attribute Details

#ip_addressObject

The IP address from which the Mandate was accepted by the customer.



2708
2709
2710
# File 'lib/stripe/resources/setup_intent.rb', line 2708

def ip_address
  @ip_address
end

#user_agentObject

The user agent of the browser from which the Mandate was accepted by the customer.



2710
2711
2712
# File 'lib/stripe/resources/setup_intent.rb', line 2710

def user_agent
  @user_agent
end