Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
# File 'lib/stripe/resources/setup_intent.rb', line 3304

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



3292
3293
3294
# File 'lib/stripe/resources/setup_intent.rb', line 3292

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



3294
3295
3296
# File 'lib/stripe/resources/setup_intent.rb', line 3294

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



3296
3297
3298
# File 'lib/stripe/resources/setup_intent.rb', line 3296

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



3298
3299
3300
# File 'lib/stripe/resources/setup_intent.rb', line 3298

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



3300
3301
3302
# File 'lib/stripe/resources/setup_intent.rb', line 3300

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



3302
3303
3304
# File 'lib/stripe/resources/setup_intent.rb', line 3302

def suffix
  @suffix
end