Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 3318 |
# File 'lib/stripe/resources/setup_intent.rb', line 3304 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
3292 3293 3294 |
# File 'lib/stripe/resources/setup_intent.rb', line 3292 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
3294 3295 3296 |
# File 'lib/stripe/resources/setup_intent.rb', line 3294 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
3296 3297 3298 |
# File 'lib/stripe/resources/setup_intent.rb', line 3296 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
3298 3299 3300 |
# File 'lib/stripe/resources/setup_intent.rb', line 3298 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
3300 3301 3302 |
# File 'lib/stripe/resources/setup_intent.rb', line 3300 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
3302 3303 3304 |
# File 'lib/stripe/resources/setup_intent.rb', line 3302 def suffix @suffix end |