Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



3162
3163
3164
3165
3166
3167
3168
3169
3170
3171
3172
3173
3174
3175
3176
# File 'lib/stripe/resources/setup_intent.rb', line 3162

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



3150
3151
3152
# File 'lib/stripe/resources/setup_intent.rb', line 3150

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



3152
3153
3154
# File 'lib/stripe/resources/setup_intent.rb', line 3152

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



3154
3155
3156
# File 'lib/stripe/resources/setup_intent.rb', line 3154

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



3156
3157
3158
# File 'lib/stripe/resources/setup_intent.rb', line 3156

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



3158
3159
3160
# File 'lib/stripe/resources/setup_intent.rb', line 3158

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



3160
3161
3162
# File 'lib/stripe/resources/setup_intent.rb', line 3160

def suffix
  @suffix
end