Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
2757 2758 2759 2760 2761 2762 2763 2764 2765 2766 2767 2768 2769 2770 2771 |
# File 'lib/stripe/resources/setup_intent.rb', line 2757 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
2745 2746 2747 |
# File 'lib/stripe/resources/setup_intent.rb', line 2745 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
2747 2748 2749 |
# File 'lib/stripe/resources/setup_intent.rb', line 2747 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
2749 2750 2751 |
# File 'lib/stripe/resources/setup_intent.rb', line 2749 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
2751 2752 2753 |
# File 'lib/stripe/resources/setup_intent.rb', line 2751 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
2753 2754 2755 |
# File 'lib/stripe/resources/setup_intent.rb', line 2753 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
2755 2756 2757 |
# File 'lib/stripe/resources/setup_intent.rb', line 2755 def suffix @suffix end |