Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 |
# File 'lib/stripe/resources/setup_intent.rb', line 2970 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
2958 2959 2960 |
# File 'lib/stripe/resources/setup_intent.rb', line 2958 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
2960 2961 2962 |
# File 'lib/stripe/resources/setup_intent.rb', line 2960 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
2962 2963 2964 |
# File 'lib/stripe/resources/setup_intent.rb', line 2962 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
2964 2965 2966 |
# File 'lib/stripe/resources/setup_intent.rb', line 2964 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
2966 2967 2968 |
# File 'lib/stripe/resources/setup_intent.rb', line 2966 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
2968 2969 2970 |
# File 'lib/stripe/resources/setup_intent.rb', line 2968 def suffix @suffix end |