Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
2565 2566 2567 2568 2569 2570 2571 2572 2573 2574 2575 2576 2577 2578 2579 |
# File 'lib/stripe/resources/setup_intent.rb', line 2565 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
2553 2554 2555 |
# File 'lib/stripe/resources/setup_intent.rb', line 2553 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
2555 2556 2557 |
# File 'lib/stripe/resources/setup_intent.rb', line 2555 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
2557 2558 2559 |
# File 'lib/stripe/resources/setup_intent.rb', line 2557 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
2559 2560 2561 |
# File 'lib/stripe/resources/setup_intent.rb', line 2559 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
2561 2562 2563 |
# File 'lib/stripe/resources/setup_intent.rb', line 2561 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
2563 2564 2565 |
# File 'lib/stripe/resources/setup_intent.rb', line 2563 def suffix @suffix end |