Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 |
# File 'lib/stripe/resources/setup_intent.rb', line 2710 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
2698 2699 2700 |
# File 'lib/stripe/resources/setup_intent.rb', line 2698 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
2700 2701 2702 |
# File 'lib/stripe/resources/setup_intent.rb', line 2700 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
2702 2703 2704 |
# File 'lib/stripe/resources/setup_intent.rb', line 2702 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
2704 2705 2706 |
# File 'lib/stripe/resources/setup_intent.rb', line 2704 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
2706 2707 2708 |
# File 'lib/stripe/resources/setup_intent.rb', line 2706 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
2708 2709 2710 |
# File 'lib/stripe/resources/setup_intent.rb', line 2708 def suffix @suffix end |