Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



2701
2702
2703
2704
2705
2706
2707
2708
2709
2710
2711
2712
2713
2714
2715
# File 'lib/stripe/resources/setup_intent.rb', line 2701

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



2689
2690
2691
# File 'lib/stripe/resources/setup_intent.rb', line 2689

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



2691
2692
2693
# File 'lib/stripe/resources/setup_intent.rb', line 2691

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



2693
2694
2695
# File 'lib/stripe/resources/setup_intent.rb', line 2693

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



2695
2696
2697
# File 'lib/stripe/resources/setup_intent.rb', line 2695

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



2697
2698
2699
# File 'lib/stripe/resources/setup_intent.rb', line 2697

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



2699
2700
2701
# File 'lib/stripe/resources/setup_intent.rb', line 2699

def suffix
  @suffix
end