Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



3122
3123
3124
3125
3126
3127
3128
3129
3130
3131
3132
3133
3134
3135
3136
# File 'lib/stripe/resources/setup_intent.rb', line 3122

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



3110
3111
3112
# File 'lib/stripe/resources/setup_intent.rb', line 3110

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



3112
3113
3114
# File 'lib/stripe/resources/setup_intent.rb', line 3112

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



3114
3115
3116
# File 'lib/stripe/resources/setup_intent.rb', line 3114

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



3116
3117
3118
# File 'lib/stripe/resources/setup_intent.rb', line 3116

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



3118
3119
3120
# File 'lib/stripe/resources/setup_intent.rb', line 3118

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



3120
3121
3122
# File 'lib/stripe/resources/setup_intent.rb', line 3120

def suffix
  @suffix
end