Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::ConfirmParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 |
# File 'lib/stripe/resources/setup_intent.rb', line 2811 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
2801 2802 2803 |
# File 'lib/stripe/resources/setup_intent.rb', line 2801 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
2803 2804 2805 |
# File 'lib/stripe/resources/setup_intent.rb', line 2803 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
2805 2806 2807 |
# File 'lib/stripe/resources/setup_intent.rb', line 2805 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
2807 2808 2809 |
# File 'lib/stripe/resources/setup_intent.rb', line 2807 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
2809 2810 2811 |
# File 'lib/stripe/resources/setup_intent.rb', line 2809 def routing_number @routing_number end |