Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::ConfirmParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
3094 3095 3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 |
# File 'lib/stripe/resources/setup_intent.rb', line 3094 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
3084 3085 3086 |
# File 'lib/stripe/resources/setup_intent.rb', line 3084 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
3086 3087 3088 |
# File 'lib/stripe/resources/setup_intent.rb', line 3086 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
3088 3089 3090 |
# File 'lib/stripe/resources/setup_intent.rb', line 3088 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
3090 3091 3092 |
# File 'lib/stripe/resources/setup_intent.rb', line 3090 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
3092 3093 3094 |
# File 'lib/stripe/resources/setup_intent.rb', line 3092 def routing_number @routing_number end |