Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step.
-
#default_for ⇒ Object
List of Stripe products where this mandate can be selected automatically.
-
#interval_description ⇒ Object
Description of the mandate interval.
-
#payment_schedule ⇒ Object
Payment schedule for the mandate.
-
#transaction_type ⇒ Object
Transaction type of the mandate.
Instance Method Summary collapse
-
#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
3999 4000 4001 4002 4003 4004 4005 4006 4007 4008 4009 4010 4011 |
# File 'lib/stripe/resources/setup_intent.rb', line 3999 def initialize( custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil ) @custom_mandate_url = custom_mandate_url @default_for = default_for @interval_description = interval_description @payment_schedule = payment_schedule @transaction_type = transaction_type end |
Instance Attribute Details
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.
3989 3990 3991 |
# File 'lib/stripe/resources/setup_intent.rb', line 3989 def custom_mandate_url @custom_mandate_url end |
#default_for ⇒ Object
List of Stripe products where this mandate can be selected automatically.
3991 3992 3993 |
# File 'lib/stripe/resources/setup_intent.rb', line 3991 def default_for @default_for end |
#interval_description ⇒ Object
Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.
3993 3994 3995 |
# File 'lib/stripe/resources/setup_intent.rb', line 3993 def interval_description @interval_description end |
#payment_schedule ⇒ Object
Payment schedule for the mandate.
3995 3996 3997 |
# File 'lib/stripe/resources/setup_intent.rb', line 3995 def payment_schedule @payment_schedule end |
#transaction_type ⇒ Object
Transaction type of the mandate.
3997 3998 3999 |
# File 'lib/stripe/resources/setup_intent.rb', line 3997 def transaction_type @transaction_type end |