Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::AcssDebit::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
# File 'lib/stripe/resources/setup_intent.rb', line 3561

def initialize(
  custom_mandate_url: nil,
  default_for: nil,
  interval_description: nil,
  payment_schedule: nil,
  transaction_type: nil
)
  @custom_mandate_url = custom_mandate_url
  @default_for = default_for
  @interval_description = interval_description
  @payment_schedule = payment_schedule
  @transaction_type = transaction_type
end

Instance Attribute Details

#custom_mandate_urlObject

A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.



3551
3552
3553
# File 'lib/stripe/resources/setup_intent.rb', line 3551

def custom_mandate_url
  @custom_mandate_url
end

#default_forObject

List of Stripe products where this mandate can be selected automatically.



3553
3554
3555
# File 'lib/stripe/resources/setup_intent.rb', line 3553

def default_for
  @default_for
end

#interval_descriptionObject

Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.



3555
3556
3557
# File 'lib/stripe/resources/setup_intent.rb', line 3555

def interval_description
  @interval_description
end

#payment_scheduleObject

Payment schedule for the mandate.



3557
3558
3559
# File 'lib/stripe/resources/setup_intent.rb', line 3557

def payment_schedule
  @payment_schedule
end

#transaction_typeObject

Transaction type of the mandate.



3559
3560
3561
# File 'lib/stripe/resources/setup_intent.rb', line 3559

def transaction_type
  @transaction_type
end