Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::AcssDebit::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
# File 'lib/stripe/resources/setup_intent.rb', line 3052

def initialize(
  custom_mandate_url: nil,
  default_for: nil,
  interval_description: nil,
  payment_schedule: nil,
  transaction_type: nil
)
  @custom_mandate_url = custom_mandate_url
  @default_for = default_for
  @interval_description = interval_description
  @payment_schedule = payment_schedule
  @transaction_type = transaction_type
end

Instance Attribute Details

#custom_mandate_urlObject

A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.



3042
3043
3044
# File 'lib/stripe/resources/setup_intent.rb', line 3042

def custom_mandate_url
  @custom_mandate_url
end

#default_forObject

List of Stripe products where this mandate can be selected automatically.



3044
3045
3046
# File 'lib/stripe/resources/setup_intent.rb', line 3044

def default_for
  @default_for
end

#interval_descriptionObject

Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.



3046
3047
3048
# File 'lib/stripe/resources/setup_intent.rb', line 3046

def interval_description
  @interval_description
end

#payment_scheduleObject

Payment schedule for the mandate.



3048
3049
3050
# File 'lib/stripe/resources/setup_intent.rb', line 3048

def payment_schedule
  @payment_schedule
end

#transaction_typeObject

Transaction type of the mandate.



3050
3051
3052
# File 'lib/stripe/resources/setup_intent.rb', line 3050

def transaction_type
  @transaction_type
end