Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::Card

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: MandateOptions, ThreeDSecure

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(mandate_options: nil, moto: nil, network: nil, request_three_d_secure: nil, three_d_secure: nil) ⇒ Card

Returns a new instance of Card.



3741
3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
# File 'lib/stripe/resources/setup_intent.rb', line 3741

def initialize(
  mandate_options: nil,
  moto: nil,
  network: nil,
  request_three_d_secure: nil,
  three_d_secure: nil
)
  @mandate_options = mandate_options
  @moto = moto
  @network = network
  @request_three_d_secure = request_three_d_secure
  @three_d_secure = three_d_secure
end

Instance Attribute Details

#mandate_optionsObject

Configuration options for setting up an eMandate for cards issued in India.



3728
3729
3730
# File 'lib/stripe/resources/setup_intent.rb', line 3728

def mandate_options
  @mandate_options
end

#motoObject

When specified, this parameter signals that a card has been collected as MOTO (Mail Order Telephone Order) and thus out of scope for SCA. This parameter can only be provided during confirmation.



3732
3733
3734
# File 'lib/stripe/resources/setup_intent.rb', line 3732

def moto
  @moto
end

#networkObject

Selected network to process this SetupIntent on. Depends on the available networks of the card attached to the SetupIntent. Can be only set confirm-time.



3734
3735
3736
# File 'lib/stripe/resources/setup_intent.rb', line 3734

def network
  @network
end

#request_three_d_secureObject

We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](stripe.com/docs/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.



3736
3737
3738
# File 'lib/stripe/resources/setup_intent.rb', line 3736

def request_three_d_secure
  @request_three_d_secure
end

#three_d_secureObject

If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this setup.



3739
3740
3741
# File 'lib/stripe/resources/setup_intent.rb', line 3739

def three_d_secure
  @three_d_secure
end