Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::Card::ThreeDSecure
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::Card::ThreeDSecure
- Defined in:
- lib/stripe/resources/setup_intent.rb
Defined Under Namespace
Classes: NetworkOptions
Instance Attribute Summary collapse
-
#ares_trans_status ⇒ Object
The ‘transStatus` returned from the card Issuer’s ACS in the ARes.
-
#cryptogram ⇒ Object
The cryptogram, also known as the “authentication value” (AAV, CAVV or AEVV).
-
#electronic_commerce_indicator ⇒ Object
The Electronic Commerce Indicator (ECI) is returned by your 3D Secure provider and indicates what degree of authentication was performed.
-
#network_options ⇒ Object
Network specific 3DS fields.
-
#requestor_challenge_indicator ⇒ Object
The challenge indicator (‘threeDSRequestorChallengeInd`) which was requested in the AReq sent to the card Issuer’s ACS.
-
#transaction_id ⇒ Object
For 3D Secure 1, the XID.
-
#version ⇒ Object
The version of 3D Secure that was performed.
Instance Method Summary collapse
-
#initialize(ares_trans_status: nil, cryptogram: nil, electronic_commerce_indicator: nil, network_options: nil, requestor_challenge_indicator: nil, transaction_id: nil, version: nil) ⇒ ThreeDSecure
constructor
A new instance of ThreeDSecure.
Methods inherited from RequestParams
Constructor Details
#initialize(ares_trans_status: nil, cryptogram: nil, electronic_commerce_indicator: nil, network_options: nil, requestor_challenge_indicator: nil, transaction_id: nil, version: nil) ⇒ ThreeDSecure
Returns a new instance of ThreeDSecure.
3040 3041 3042 3043 3044 3045 3046 3047 3048 3049 3050 3051 3052 3053 3054 3055 3056 |
# File 'lib/stripe/resources/setup_intent.rb', line 3040 def initialize( ares_trans_status: nil, cryptogram: nil, electronic_commerce_indicator: nil, network_options: nil, requestor_challenge_indicator: nil, transaction_id: nil, version: nil ) @ares_trans_status = ares_trans_status @cryptogram = cryptogram @electronic_commerce_indicator = electronic_commerce_indicator @network_options = @requestor_challenge_indicator = requestor_challenge_indicator @transaction_id = transaction_id @version = version end |
Instance Attribute Details
#ares_trans_status ⇒ Object
The ‘transStatus` returned from the card Issuer’s ACS in the ARes.
3018 3019 3020 |
# File 'lib/stripe/resources/setup_intent.rb', line 3018 def ares_trans_status @ares_trans_status end |
#cryptogram ⇒ Object
The cryptogram, also known as the “authentication value” (AAV, CAVV or AEVV). This value is 20 bytes, base64-encoded into a 28-character string. (Most 3D Secure providers will return the base64-encoded version, which is what you should specify here.)
3023 3024 3025 |
# File 'lib/stripe/resources/setup_intent.rb', line 3023 def cryptogram @cryptogram end |
#electronic_commerce_indicator ⇒ Object
The Electronic Commerce Indicator (ECI) is returned by your 3D Secure provider and indicates what degree of authentication was performed.
3026 3027 3028 |
# File 'lib/stripe/resources/setup_intent.rb', line 3026 def electronic_commerce_indicator @electronic_commerce_indicator end |
#network_options ⇒ Object
Network specific 3DS fields. Network specific arguments require an explicit card brand choice. The parameter ‘payment_method_options.card.network“ must be populated accordingly
3030 3031 3032 |
# File 'lib/stripe/resources/setup_intent.rb', line 3030 def @network_options end |
#requestor_challenge_indicator ⇒ Object
The challenge indicator (‘threeDSRequestorChallengeInd`) which was requested in the AReq sent to the card Issuer’s ACS. A string containing 2 digits from 01-99.
3033 3034 3035 |
# File 'lib/stripe/resources/setup_intent.rb', line 3033 def requestor_challenge_indicator @requestor_challenge_indicator end |
#transaction_id ⇒ Object
For 3D Secure 1, the XID. For 3D Secure 2, the Directory Server Transaction ID (dsTransID).
3036 3037 3038 |
# File 'lib/stripe/resources/setup_intent.rb', line 3036 def transaction_id @transaction_id end |
#version ⇒ Object
The version of 3D Secure that was performed.
3038 3039 3040 |
# File 'lib/stripe/resources/setup_intent.rb', line 3038 def version @version end |