Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::Card::ThreeDSecure

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: NetworkOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ares_trans_status: nil, cryptogram: nil, electronic_commerce_indicator: nil, network_options: nil, requestor_challenge_indicator: nil, transaction_id: nil, version: nil) ⇒ ThreeDSecure

Returns a new instance of ThreeDSecure.



3962
3963
3964
3965
3966
3967
3968
3969
3970
3971
3972
3973
3974
3975
3976
3977
3978
# File 'lib/stripe/resources/setup_intent.rb', line 3962

def initialize(
  ares_trans_status: nil,
  cryptogram: nil,
  electronic_commerce_indicator: nil,
  network_options: nil,
  requestor_challenge_indicator: nil,
  transaction_id: nil,
  version: nil
)
  @ares_trans_status = ares_trans_status
  @cryptogram = cryptogram
  @electronic_commerce_indicator = electronic_commerce_indicator
  @network_options = network_options
  @requestor_challenge_indicator = requestor_challenge_indicator
  @transaction_id = transaction_id
  @version = version
end

Instance Attribute Details

#ares_trans_statusObject

The ‘transStatus` returned from the card Issuer’s ACS in the ARes.



3934
3935
3936
# File 'lib/stripe/resources/setup_intent.rb', line 3934

def ares_trans_status
  @ares_trans_status
end

#cryptogramObject

The cryptogram, also known as the “authentication value” (AAV, CAVV or AEVV). This value is 20 bytes, base64-encoded into a 28-character string. (Most 3D Secure providers will return the base64-encoded version, which is what you should specify here.)



3940
3941
3942
# File 'lib/stripe/resources/setup_intent.rb', line 3940

def cryptogram
  @cryptogram
end

#electronic_commerce_indicatorObject

The Electronic Commerce Indicator (ECI) is returned by your 3D Secure provider and indicates what degree of authentication was performed.



3944
3945
3946
# File 'lib/stripe/resources/setup_intent.rb', line 3944

def electronic_commerce_indicator
  @electronic_commerce_indicator
end

#network_optionsObject

Network specific 3DS fields. Network specific arguments require an explicit card brand choice. The parameter ‘payment_method_options.card.network“ must be populated accordingly



3949
3950
3951
# File 'lib/stripe/resources/setup_intent.rb', line 3949

def network_options
  @network_options
end

#requestor_challenge_indicatorObject

The challenge indicator (‘threeDSRequestorChallengeInd`) which was requested in the AReq sent to the card Issuer’s ACS. A string containing 2 digits from 01-99.



3953
3954
3955
# File 'lib/stripe/resources/setup_intent.rb', line 3953

def requestor_challenge_indicator
  @requestor_challenge_indicator
end

#transaction_idObject

For 3D Secure 1, the XID. For 3D Secure 2, the Directory Server Transaction ID (dsTransID).



3957
3958
3959
# File 'lib/stripe/resources/setup_intent.rb', line 3957

def transaction_id
  @transaction_id
end

#versionObject

The version of 3D Secure that was performed.



3960
3961
3962
# File 'lib/stripe/resources/setup_intent.rb', line 3960

def version
  @version
end