Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::Klarna
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::Klarna
- Defined in:
- lib/stripe/resources/setup_intent.rb
Defined Under Namespace
Classes: OnDemand, Subscription
Instance Attribute Summary collapse
-
#currency ⇒ Object
The currency of the SetupIntent.
-
#on_demand ⇒ Object
On-demand details if setting up a payment method for on-demand payments.
-
#preferred_locale ⇒ Object
Preferred language of the Klarna authorization page that the customer is redirected to.
-
#subscriptions ⇒ Object
Subscription details if setting up or charging a subscription.
Instance Method Summary collapse
-
#initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil) ⇒ Klarna
constructor
A new instance of Klarna.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil) ⇒ Klarna
Returns a new instance of Klarna.
3992 3993 3994 3995 3996 3997 |
# File 'lib/stripe/resources/setup_intent.rb', line 3992 def initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil) @currency = currency @on_demand = on_demand @preferred_locale = preferred_locale @subscriptions = subscriptions end |
Instance Attribute Details
#currency ⇒ Object
The currency of the SetupIntent. Three letter ISO currency code.
3984 3985 3986 |
# File 'lib/stripe/resources/setup_intent.rb', line 3984 def currency @currency end |
#on_demand ⇒ Object
On-demand details if setting up a payment method for on-demand payments.
3986 3987 3988 |
# File 'lib/stripe/resources/setup_intent.rb', line 3986 def on_demand @on_demand end |
#preferred_locale ⇒ Object
Preferred language of the Klarna authorization page that the customer is redirected to
3988 3989 3990 |
# File 'lib/stripe/resources/setup_intent.rb', line 3988 def preferred_locale @preferred_locale end |
#subscriptions ⇒ Object
Subscription details if setting up or charging a subscription
3990 3991 3992 |
# File 'lib/stripe/resources/setup_intent.rb', line 3990 def subscriptions @subscriptions end |