Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::Klarna

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: OnDemand, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil) ⇒ Klarna

Returns a new instance of Klarna.



3359
3360
3361
3362
3363
3364
# File 'lib/stripe/resources/setup_intent.rb', line 3359

def initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil)
  @currency = currency
  @on_demand = on_demand
  @preferred_locale = preferred_locale
  @subscriptions = subscriptions
end

Instance Attribute Details

#currencyObject

The currency of the SetupIntent. Three letter ISO currency code.



3351
3352
3353
# File 'lib/stripe/resources/setup_intent.rb', line 3351

def currency
  @currency
end

#on_demandObject

On-demand details if setting up a payment method for on-demand payments.



3353
3354
3355
# File 'lib/stripe/resources/setup_intent.rb', line 3353

def on_demand
  @on_demand
end

#preferred_localeObject

Preferred language of the Klarna authorization page that the customer is redirected to



3355
3356
3357
# File 'lib/stripe/resources/setup_intent.rb', line 3355

def preferred_locale
  @preferred_locale
end

#subscriptionsObject

Subscription details if setting up or charging a subscription



3357
3358
3359
# File 'lib/stripe/resources/setup_intent.rb', line 3357

def subscriptions
  @subscriptions
end