Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::Klarna

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: OnDemand, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil) ⇒ Klarna

Returns a new instance of Klarna.



3850
3851
3852
3853
3854
3855
# File 'lib/stripe/resources/setup_intent.rb', line 3850

def initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil)
  @currency = currency
  @on_demand = on_demand
  @preferred_locale = preferred_locale
  @subscriptions = subscriptions
end

Instance Attribute Details

#currencyObject

The currency of the SetupIntent. Three letter ISO currency code.



3842
3843
3844
# File 'lib/stripe/resources/setup_intent.rb', line 3842

def currency
  @currency
end

#on_demandObject

On-demand details if setting up a payment method for on-demand payments.



3844
3845
3846
# File 'lib/stripe/resources/setup_intent.rb', line 3844

def on_demand
  @on_demand
end

#preferred_localeObject

Preferred language of the Klarna authorization page that the customer is redirected to



3846
3847
3848
# File 'lib/stripe/resources/setup_intent.rb', line 3846

def preferred_locale
  @preferred_locale
end

#subscriptionsObject

Subscription details if setting up or charging a subscription



3848
3849
3850
# File 'lib/stripe/resources/setup_intent.rb', line 3848

def subscriptions
  @subscriptions
end