Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::Klarna::OnDemand
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::Klarna::OnDemand
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#average_amount ⇒ Object
Your average amount value.
-
#maximum_amount ⇒ Object
The maximum value you may charge a customer per purchase.
-
#minimum_amount ⇒ Object
The lowest or minimum value you may charge a customer per purchase.
-
#purchase_interval ⇒ Object
Interval at which the customer is making purchases.
-
#purchase_interval_count ⇒ Object
The number of ‘purchase_interval` between charges.
Instance Method Summary collapse
-
#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand
constructor
A new instance of OnDemand.
Methods inherited from RequestParams
Constructor Details
#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand
Returns a new instance of OnDemand.
3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 |
# File 'lib/stripe/resources/setup_intent.rb', line 3789 def initialize( average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil ) @average_amount = average_amount @maximum_amount = maximum_amount @minimum_amount = minimum_amount @purchase_interval = purchase_interval @purchase_interval_count = purchase_interval_count end |
Instance Attribute Details
#average_amount ⇒ Object
Your average amount value. You can use a value across your customer base, or segment based on customer type, country, etc.
3779 3780 3781 |
# File 'lib/stripe/resources/setup_intent.rb', line 3779 def average_amount @average_amount end |
#maximum_amount ⇒ Object
The maximum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.
3781 3782 3783 |
# File 'lib/stripe/resources/setup_intent.rb', line 3781 def maximum_amount @maximum_amount end |
#minimum_amount ⇒ Object
The lowest or minimum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.
3783 3784 3785 |
# File 'lib/stripe/resources/setup_intent.rb', line 3783 def minimum_amount @minimum_amount end |
#purchase_interval ⇒ Object
Interval at which the customer is making purchases
3785 3786 3787 |
# File 'lib/stripe/resources/setup_intent.rb', line 3785 def purchase_interval @purchase_interval end |
#purchase_interval_count ⇒ Object
The number of ‘purchase_interval` between charges
3787 3788 3789 |
# File 'lib/stripe/resources/setup_intent.rb', line 3787 def purchase_interval_count @purchase_interval_count end |