Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::Payto::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::Payto::MandateOptions
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount that will be collected.
-
#amount_type ⇒ Object
The type of amount that will be collected.
-
#end_date ⇒ Object
Date, in YYYY-MM-DD format, after which payments will not be collected.
-
#payment_schedule ⇒ Object
The periodicity at which payments will be collected.
-
#payments_per_period ⇒ Object
The number of payments that will be made during a payment period.
-
#purpose ⇒ Object
The purpose for which payments are made.
-
#start_date ⇒ Object
Date, in YYYY-MM-DD format, from which payments will be collected.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 3812 3813 3814 3815 3816 |
# File 'lib/stripe/resources/setup_intent.rb', line 3800 def initialize( amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil ) @amount = amount @amount_type = amount_type @end_date = end_date @payment_schedule = payment_schedule @payments_per_period = payments_per_period @purpose = purpose @start_date = start_date end |
Instance Attribute Details
#amount ⇒ Object
Amount that will be collected. It is required when ‘amount_type` is `fixed`.
3786 3787 3788 |
# File 'lib/stripe/resources/setup_intent.rb', line 3786 def amount @amount end |
#amount_type ⇒ Object
The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.
3788 3789 3790 |
# File 'lib/stripe/resources/setup_intent.rb', line 3788 def amount_type @amount_type end |
#end_date ⇒ Object
Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.
3790 3791 3792 |
# File 'lib/stripe/resources/setup_intent.rb', line 3790 def end_date @end_date end |
#payment_schedule ⇒ Object
The periodicity at which payments will be collected.
3792 3793 3794 |
# File 'lib/stripe/resources/setup_intent.rb', line 3792 def payment_schedule @payment_schedule end |
#payments_per_period ⇒ Object
The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.
3794 3795 3796 |
# File 'lib/stripe/resources/setup_intent.rb', line 3794 def payments_per_period @payments_per_period end |
#purpose ⇒ Object
The purpose for which payments are made. Defaults to retail.
3796 3797 3798 |
# File 'lib/stripe/resources/setup_intent.rb', line 3796 def purpose @purpose end |
#start_date ⇒ Object
Date, in YYYY-MM-DD format, from which payments will be collected. Defaults to confirmation time.
3798 3799 3800 |
# File 'lib/stripe/resources/setup_intent.rb', line 3798 def start_date @start_date end |