Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
# File 'lib/stripe/resources/setup_intent.rb', line 3975

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



3965
3966
3967
# File 'lib/stripe/resources/setup_intent.rb', line 3965

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



3967
3968
3969
# File 'lib/stripe/resources/setup_intent.rb', line 3967

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



3969
3970
3971
# File 'lib/stripe/resources/setup_intent.rb', line 3969

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



3971
3972
3973
# File 'lib/stripe/resources/setup_intent.rb', line 3971

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



3973
3974
3975
# File 'lib/stripe/resources/setup_intent.rb', line 3973

def return_url
  @return_url
end