Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/resources/setup_intent.rb
Defined Under Namespace
Classes: Filters, ManualEntry
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#manual_entry ⇒ Object
Customize manual entry behavior.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
3975 3976 3977 3978 3979 3980 3981 3982 3983 3984 3985 3986 3987 |
# File 'lib/stripe/resources/setup_intent.rb', line 3975 def initialize( filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil ) @filters = filters @manual_entry = manual_entry @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
3965 3966 3967 |
# File 'lib/stripe/resources/setup_intent.rb', line 3965 def filters @filters end |
#manual_entry ⇒ Object
Customize manual entry behavior
3967 3968 3969 |
# File 'lib/stripe/resources/setup_intent.rb', line 3967 def manual_entry @manual_entry end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
3969 3970 3971 |
# File 'lib/stripe/resources/setup_intent.rb', line 3969 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
3971 3972 3973 |
# File 'lib/stripe/resources/setup_intent.rb', line 3971 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
3973 3974 3975 |
# File 'lib/stripe/resources/setup_intent.rb', line 3973 def return_url @return_url end |