Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



3876
3877
3878
3879
3880
3881
3882
3883
3884
3885
3886
3887
3888
# File 'lib/stripe/resources/setup_intent.rb', line 3876

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



3866
3867
3868
# File 'lib/stripe/resources/setup_intent.rb', line 3866

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



3868
3869
3870
# File 'lib/stripe/resources/setup_intent.rb', line 3868

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



3870
3871
3872
# File 'lib/stripe/resources/setup_intent.rb', line 3870

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



3872
3873
3874
# File 'lib/stripe/resources/setup_intent.rb', line 3872

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



3874
3875
3876
# File 'lib/stripe/resources/setup_intent.rb', line 3874

def return_url
  @return_url
end