Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/resources/setup_intent.rb
Defined Under Namespace
Classes: Filters, ManualEntry
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#manual_entry ⇒ Object
Customize manual entry behavior.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
4146 4147 4148 4149 4150 4151 4152 4153 4154 4155 4156 4157 4158 |
# File 'lib/stripe/resources/setup_intent.rb', line 4146 def initialize( filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil ) @filters = filters @manual_entry = manual_entry @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method
4132 4133 4134 |
# File 'lib/stripe/resources/setup_intent.rb', line 4132 def filters @filters end |
#manual_entry ⇒ Object
Customize manual entry behavior
4135 4136 4137 |
# File 'lib/stripe/resources/setup_intent.rb', line 4135 def manual_entry @manual_entry end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
4138 4139 4140 |
# File 'lib/stripe/resources/setup_intent.rb', line 4138 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
4141 4142 4143 |
# File 'lib/stripe/resources/setup_intent.rb', line 4141 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
4144 4145 4146 |
# File 'lib/stripe/resources/setup_intent.rb', line 4144 def return_url @return_url end |