Class: Stripe::SetupIntent::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



3654
3655
3656
3657
3658
3659
3660
3661
3662
3663
3664
3665
3666
# File 'lib/stripe/resources/setup_intent.rb', line 3654

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method



3644
3645
3646
# File 'lib/stripe/resources/setup_intent.rb', line 3644

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



3646
3647
3648
# File 'lib/stripe/resources/setup_intent.rb', line 3646

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



3648
3649
3650
# File 'lib/stripe/resources/setup_intent.rb', line 3648

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



3650
3651
3652
# File 'lib/stripe/resources/setup_intent.rb', line 3650

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



3652
3653
3654
# File 'lib/stripe/resources/setup_intent.rb', line 3652

def return_url
  @return_url
end