Class: Stripe::SetupIntent::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: AutomaticPaymentMethods, MandateData, PaymentMethodData, PaymentMethodOptions, SingleUse

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(attach_to_self: nil, automatic_payment_methods: nil, confirm: nil, confirmation_token: nil, customer: nil, customer_account: nil, description: nil, expand: nil, flow_directions: nil, mandate_data: nil, metadata: nil, on_behalf_of: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, single_use: nil, usage: nil, use_stripe_sdk: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



2024
2025
2026
2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
2067
2068
# File 'lib/stripe/resources/setup_intent.rb', line 2024

def initialize(
  attach_to_self: nil,
  automatic_payment_methods: nil,
  confirm: nil,
  confirmation_token: nil,
  customer: nil,
  customer_account: nil,
  description: nil,
  expand: nil,
  flow_directions: nil,
  mandate_data: nil,
  metadata: nil,
  on_behalf_of: nil,
  payment_method: nil,
  payment_method_configuration: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  return_url: nil,
  single_use: nil,
  usage: nil,
  use_stripe_sdk: nil
)
  @attach_to_self = attach_to_self
  @automatic_payment_methods = automatic_payment_methods
  @confirm = confirm
  @confirmation_token = confirmation_token
  @customer = customer
  @customer_account = 
  @description = description
  @expand = expand
  @flow_directions = flow_directions
  @mandate_data = mandate_data
  @metadata = 
  @on_behalf_of = on_behalf_of
  @payment_method = payment_method
  @payment_method_configuration = payment_method_configuration
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @return_url = return_url
  @single_use = single_use
  @usage = usage
  @use_stripe_sdk = use_stripe_sdk
end

Instance Attribute Details

#attach_to_selfObject

If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.

It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.



1971
1972
1973
# File 'lib/stripe/resources/setup_intent.rb', line 1971

def attach_to_self
  @attach_to_self
end

#automatic_payment_methodsObject

When you enable this parameter, this SetupIntent accepts payment methods that you enable in the Dashboard and that are compatible with its other parameters.



1973
1974
1975
# File 'lib/stripe/resources/setup_intent.rb', line 1973

def automatic_payment_methods
  @automatic_payment_methods
end

#confirmObject

Set to ‘true` to attempt to confirm this SetupIntent immediately. This parameter defaults to `false`. If a card is the attached payment method, you can provide a `return_url` in case further authentication is necessary.



1975
1976
1977
# File 'lib/stripe/resources/setup_intent.rb', line 1975

def confirm
  @confirm
end

#confirmation_tokenObject

ID of the ConfirmationToken used to confirm this SetupIntent.

If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.



1979
1980
1981
# File 'lib/stripe/resources/setup_intent.rb', line 1979

def confirmation_token
  @confirmation_token
end

#customerObject

ID of the Customer this SetupIntent belongs to, if one exists.

If present, the SetupIntent’s payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.



1983
1984
1985
# File 'lib/stripe/resources/setup_intent.rb', line 1983

def customer
  @customer
end

#customer_accountObject

ID of the Account this SetupIntent belongs to, if one exists.

If present, the SetupIntent’s payment method will be attached to the Account on successful setup. Payment methods attached to other Accounts cannot be used with this SetupIntent.



1987
1988
1989
# File 'lib/stripe/resources/setup_intent.rb', line 1987

def 
  @customer_account
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1989
1990
1991
# File 'lib/stripe/resources/setup_intent.rb', line 1989

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



1991
1992
1993
# File 'lib/stripe/resources/setup_intent.rb', line 1991

def expand
  @expand
end

#flow_directionsObject

Indicates the directions of money movement for which this payment method is intended to be used.

Include ‘inbound` if you intend to use the payment method as the origin to pull funds from. Include `outbound` if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.



1995
1996
1997
# File 'lib/stripe/resources/setup_intent.rb', line 1995

def flow_directions
  @flow_directions
end

#mandate_dataObject

This hash contains details about the mandate to create. This parameter can only be used with [‘confirm=true`](stripe.com/docs/api/setup_intents/create#create_setup_intent-confirm).



1997
1998
1999
# File 'lib/stripe/resources/setup_intent.rb', line 1997

def mandate_data
  @mandate_data
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1999
2000
2001
# File 'lib/stripe/resources/setup_intent.rb', line 1999

def 
  @metadata
end

#on_behalf_ofObject

The Stripe account ID created for this SetupIntent.



2001
2002
2003
# File 'lib/stripe/resources/setup_intent.rb', line 2001

def on_behalf_of
  @on_behalf_of
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.



2003
2004
2005
# File 'lib/stripe/resources/setup_intent.rb', line 2003

def payment_method
  @payment_method
end

#payment_method_configurationObject

The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this SetupIntent.



2005
2006
2007
# File 'lib/stripe/resources/setup_intent.rb', line 2005

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_dataObject

When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.



2008
2009
2010
# File 'lib/stripe/resources/setup_intent.rb', line 2008

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this SetupIntent.



2010
2011
2012
# File 'lib/stripe/resources/setup_intent.rb', line 2010

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, card) that this SetupIntent can use. If you don’t provide this, Stripe will dynamically show relevant payment methods from your [payment method settings](dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).



2012
2013
2014
# File 'lib/stripe/resources/setup_intent.rb', line 2012

def payment_method_types
  @payment_method_types
end

#return_urlObject

The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. To redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter can only be used with [‘confirm=true`](stripe.com/docs/api/setup_intents/create#create_setup_intent-confirm).



2014
2015
2016
# File 'lib/stripe/resources/setup_intent.rb', line 2014

def return_url
  @return_url
end

#single_useObject

If you populate this hash, this SetupIntent generates a ‘single_use` mandate after successful completion.

Single-use mandates are only valid for the following payment methods: ‘acss_debit`, `alipay`, `au_becs_debit`, `bacs_debit`, `bancontact`, `boleto`, `ideal`, `link`, `sepa_debit`, and `us_bank_account`.



2018
2019
2020
# File 'lib/stripe/resources/setup_intent.rb', line 2018

def single_use
  @single_use
end

#usageObject

Indicates how the payment method is intended to be used in the future. If not provided, this value defaults to ‘off_session`.



2020
2021
2022
# File 'lib/stripe/resources/setup_intent.rb', line 2020

def usage
  @usage
end

#use_stripe_sdkObject

Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.



2022
2023
2024
# File 'lib/stripe/resources/setup_intent.rb', line 2022

def use_stripe_sdk
  @use_stripe_sdk
end