Class: Stripe::SetupIntent::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::CreateParams
- Defined in:
- lib/stripe/resources/setup_intent.rb
Defined Under Namespace
Classes: AutomaticPaymentMethods, MandateData, PaymentMethodData, PaymentMethodOptions, SingleUse
Instance Attribute Summary collapse
-
#attach_to_self ⇒ Object
If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.
-
#automatic_payment_methods ⇒ Object
When you enable this parameter, this SetupIntent accepts payment methods that you enable in the Dashboard and that are compatible with its other parameters.
-
#confirm ⇒ Object
Set to ‘true` to attempt to confirm this SetupIntent immediately.
-
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this SetupIntent.
-
#customer ⇒ Object
ID of the Customer this SetupIntent belongs to, if one exists.
-
#customer_account ⇒ Object
ID of the Account this SetupIntent belongs to, if one exists.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#flow_directions ⇒ Object
Indicates the directions of money movement for which this payment method is intended to be used.
-
#mandate_data ⇒ Object
This hash contains details about the mandate to create.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#on_behalf_of ⇒ Object
The Stripe account ID created for this SetupIntent.
-
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.
-
#payment_method_configuration ⇒ Object
The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this SetupIntent.
-
#payment_method_data ⇒ Object
When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.
-
#payment_method_options ⇒ Object
Payment method-specific configuration for this SetupIntent.
-
#payment_method_types ⇒ Object
The list of payment method types (for example, card) that this SetupIntent can use.
-
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site.
-
#single_use ⇒ Object
If you populate this hash, this SetupIntent generates a ‘single_use` mandate after successful completion.
-
#usage ⇒ Object
Indicates how the payment method is intended to be used in the future.
-
#use_stripe_sdk ⇒ Object
Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(attach_to_self: nil, automatic_payment_methods: nil, confirm: nil, confirmation_token: nil, customer: nil, customer_account: nil, description: nil, expand: nil, flow_directions: nil, mandate_data: nil, metadata: nil, on_behalf_of: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, single_use: nil, usage: nil, use_stripe_sdk: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 |
# File 'lib/stripe/resources/setup_intent.rb', line 1747 def initialize( attach_to_self: nil, automatic_payment_methods: nil, confirm: nil, confirmation_token: nil, customer: nil, customer_account: nil, description: nil, expand: nil, flow_directions: nil, mandate_data: nil, metadata: nil, on_behalf_of: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, single_use: nil, usage: nil, use_stripe_sdk: nil ) @attach_to_self = attach_to_self @automatic_payment_methods = automatic_payment_methods @confirm = confirm @confirmation_token = confirmation_token @customer = customer @customer_account = customer_account @description = description @expand = @flow_directions = flow_directions @mandate_data = mandate_data @metadata = @on_behalf_of = on_behalf_of @payment_method = payment_method @payment_method_configuration = payment_method_configuration @payment_method_data = payment_method_data @payment_method_options = @payment_method_types = payment_method_types @return_url = return_url @single_use = single_use @usage = usage @use_stripe_sdk = use_stripe_sdk end |
Instance Attribute Details
#attach_to_self ⇒ Object
If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.
It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.
1694 1695 1696 |
# File 'lib/stripe/resources/setup_intent.rb', line 1694 def attach_to_self @attach_to_self end |
#automatic_payment_methods ⇒ Object
When you enable this parameter, this SetupIntent accepts payment methods that you enable in the Dashboard and that are compatible with its other parameters.
1696 1697 1698 |
# File 'lib/stripe/resources/setup_intent.rb', line 1696 def automatic_payment_methods @automatic_payment_methods end |
#confirm ⇒ Object
Set to ‘true` to attempt to confirm this SetupIntent immediately. This parameter defaults to `false`. If a card is the attached payment method, you can provide a `return_url` in case further authentication is necessary.
1698 1699 1700 |
# File 'lib/stripe/resources/setup_intent.rb', line 1698 def confirm @confirm end |
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this SetupIntent.
If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.
1702 1703 1704 |
# File 'lib/stripe/resources/setup_intent.rb', line 1702 def confirmation_token @confirmation_token end |
#customer ⇒ Object
ID of the Customer this SetupIntent belongs to, if one exists.
If present, the SetupIntent’s payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.
1706 1707 1708 |
# File 'lib/stripe/resources/setup_intent.rb', line 1706 def customer @customer end |
#customer_account ⇒ Object
ID of the Account this SetupIntent belongs to, if one exists.
If present, the SetupIntent’s payment method will be attached to the Account on successful setup. Payment methods attached to other Accounts cannot be used with this SetupIntent.
1710 1711 1712 |
# File 'lib/stripe/resources/setup_intent.rb', line 1710 def customer_account @customer_account end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
1712 1713 1714 |
# File 'lib/stripe/resources/setup_intent.rb', line 1712 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1714 1715 1716 |
# File 'lib/stripe/resources/setup_intent.rb', line 1714 def @expand end |
#flow_directions ⇒ Object
Indicates the directions of money movement for which this payment method is intended to be used.
Include ‘inbound` if you intend to use the payment method as the origin to pull funds from. Include `outbound` if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.
1718 1719 1720 |
# File 'lib/stripe/resources/setup_intent.rb', line 1718 def flow_directions @flow_directions end |
#mandate_data ⇒ Object
This hash contains details about the mandate to create. This parameter can only be used with [‘confirm=true`](stripe.com/docs/api/setup_intents/create#create_setup_intent-confirm).
1720 1721 1722 |
# File 'lib/stripe/resources/setup_intent.rb', line 1720 def mandate_data @mandate_data end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1722 1723 1724 |
# File 'lib/stripe/resources/setup_intent.rb', line 1722 def @metadata end |
#on_behalf_of ⇒ Object
The Stripe account ID created for this SetupIntent.
1724 1725 1726 |
# File 'lib/stripe/resources/setup_intent.rb', line 1724 def on_behalf_of @on_behalf_of end |
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.
1726 1727 1728 |
# File 'lib/stripe/resources/setup_intent.rb', line 1726 def payment_method @payment_method end |
#payment_method_configuration ⇒ Object
The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this SetupIntent.
1728 1729 1730 |
# File 'lib/stripe/resources/setup_intent.rb', line 1728 def payment_method_configuration @payment_method_configuration end |
#payment_method_data ⇒ Object
When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.
1731 1732 1733 |
# File 'lib/stripe/resources/setup_intent.rb', line 1731 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment method-specific configuration for this SetupIntent.
1733 1734 1735 |
# File 'lib/stripe/resources/setup_intent.rb', line 1733 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types (for example, card) that this SetupIntent can use. If you don’t provide this, Stripe will dynamically show relevant payment methods from your [payment method settings](dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).
1735 1736 1737 |
# File 'lib/stripe/resources/setup_intent.rb', line 1735 def payment_method_types @payment_method_types end |
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. To redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter can only be used with [‘confirm=true`](stripe.com/docs/api/setup_intents/create#create_setup_intent-confirm).
1737 1738 1739 |
# File 'lib/stripe/resources/setup_intent.rb', line 1737 def return_url @return_url end |
#single_use ⇒ Object
If you populate this hash, this SetupIntent generates a ‘single_use` mandate after successful completion.
Single-use mandates are only valid for the following payment methods: ‘acss_debit`, `alipay`, `au_becs_debit`, `bacs_debit`, `bancontact`, `boleto`, `ideal`, `link`, `sepa_debit`, and `us_bank_account`.
1741 1742 1743 |
# File 'lib/stripe/resources/setup_intent.rb', line 1741 def single_use @single_use end |
#usage ⇒ Object
Indicates how the payment method is intended to be used in the future. If not provided, this value defaults to ‘off_session`.
1743 1744 1745 |
# File 'lib/stripe/resources/setup_intent.rb', line 1743 def usage @usage end |
#use_stripe_sdk ⇒ Object
Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
1745 1746 1747 |
# File 'lib/stripe/resources/setup_intent.rb', line 1745 def use_stripe_sdk @use_stripe_sdk end |