Class: Stripe::SetupIntent::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::CreateParams
- Defined in:
- lib/stripe/resources/setup_intent.rb
Defined Under Namespace
Classes: AutomaticPaymentMethods, MandateData, PaymentMethodData, PaymentMethodOptions, SingleUse
Instance Attribute Summary collapse
-
#attach_to_self ⇒ Object
If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.
-
#automatic_payment_methods ⇒ Object
When you enable this parameter, this SetupIntent accepts payment methods that you enable in the Dashboard and that are compatible with its other parameters.
-
#confirm ⇒ Object
Set to ‘true` to attempt to confirm this SetupIntent immediately.
-
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this SetupIntent.
-
#customer ⇒ Object
ID of the Customer this SetupIntent belongs to, if one exists.
-
#customer_account ⇒ Object
ID of the Account this SetupIntent belongs to, if one exists.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#flow_directions ⇒ Object
Indicates the directions of money movement for which this payment method is intended to be used.
-
#mandate_data ⇒ Object
This hash contains details about the mandate to create.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#on_behalf_of ⇒ Object
The Stripe account ID created for this SetupIntent.
-
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.
-
#payment_method_configuration ⇒ Object
The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this SetupIntent.
-
#payment_method_data ⇒ Object
When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.
-
#payment_method_options ⇒ Object
Payment method-specific configuration for this SetupIntent.
-
#payment_method_types ⇒ Object
The list of payment method types (for example, card) that this SetupIntent can use.
-
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site.
-
#single_use ⇒ Object
If you populate this hash, this SetupIntent generates a ‘single_use` mandate after successful completion.
-
#usage ⇒ Object
Indicates how the payment method is intended to be used in the future.
-
#use_stripe_sdk ⇒ Object
Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(attach_to_self: nil, automatic_payment_methods: nil, confirm: nil, confirmation_token: nil, customer: nil, customer_account: nil, description: nil, expand: nil, flow_directions: nil, mandate_data: nil, metadata: nil, on_behalf_of: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, single_use: nil, usage: nil, use_stripe_sdk: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 |
# File 'lib/stripe/resources/setup_intent.rb', line 1616 def initialize( attach_to_self: nil, automatic_payment_methods: nil, confirm: nil, confirmation_token: nil, customer: nil, customer_account: nil, description: nil, expand: nil, flow_directions: nil, mandate_data: nil, metadata: nil, on_behalf_of: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, single_use: nil, usage: nil, use_stripe_sdk: nil ) @attach_to_self = attach_to_self @automatic_payment_methods = automatic_payment_methods @confirm = confirm @confirmation_token = confirmation_token @customer = customer @customer_account = customer_account @description = description @expand = @flow_directions = flow_directions @mandate_data = mandate_data @metadata = @on_behalf_of = on_behalf_of @payment_method = payment_method @payment_method_configuration = payment_method_configuration @payment_method_data = payment_method_data @payment_method_options = @payment_method_types = payment_method_types @return_url = return_url @single_use = single_use @usage = usage @use_stripe_sdk = use_stripe_sdk end |
Instance Attribute Details
#attach_to_self ⇒ Object
If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.
It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.
1563 1564 1565 |
# File 'lib/stripe/resources/setup_intent.rb', line 1563 def attach_to_self @attach_to_self end |
#automatic_payment_methods ⇒ Object
When you enable this parameter, this SetupIntent accepts payment methods that you enable in the Dashboard and that are compatible with its other parameters.
1565 1566 1567 |
# File 'lib/stripe/resources/setup_intent.rb', line 1565 def automatic_payment_methods @automatic_payment_methods end |
#confirm ⇒ Object
Set to ‘true` to attempt to confirm this SetupIntent immediately. This parameter defaults to `false`. If a card is the attached payment method, you can provide a `return_url` in case further authentication is necessary.
1567 1568 1569 |
# File 'lib/stripe/resources/setup_intent.rb', line 1567 def confirm @confirm end |
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this SetupIntent.
If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.
1571 1572 1573 |
# File 'lib/stripe/resources/setup_intent.rb', line 1571 def confirmation_token @confirmation_token end |
#customer ⇒ Object
ID of the Customer this SetupIntent belongs to, if one exists.
If present, the SetupIntent’s payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.
1575 1576 1577 |
# File 'lib/stripe/resources/setup_intent.rb', line 1575 def customer @customer end |
#customer_account ⇒ Object
ID of the Account this SetupIntent belongs to, if one exists.
If present, the SetupIntent’s payment method will be attached to the Account on successful setup. Payment methods attached to other Accounts cannot be used with this SetupIntent.
1579 1580 1581 |
# File 'lib/stripe/resources/setup_intent.rb', line 1579 def customer_account @customer_account end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
1581 1582 1583 |
# File 'lib/stripe/resources/setup_intent.rb', line 1581 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1583 1584 1585 |
# File 'lib/stripe/resources/setup_intent.rb', line 1583 def @expand end |
#flow_directions ⇒ Object
Indicates the directions of money movement for which this payment method is intended to be used.
Include ‘inbound` if you intend to use the payment method as the origin to pull funds from. Include `outbound` if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.
1587 1588 1589 |
# File 'lib/stripe/resources/setup_intent.rb', line 1587 def flow_directions @flow_directions end |
#mandate_data ⇒ Object
This hash contains details about the mandate to create. This parameter can only be used with [‘confirm=true`](stripe.com/docs/api/setup_intents/create#create_setup_intent-confirm).
1589 1590 1591 |
# File 'lib/stripe/resources/setup_intent.rb', line 1589 def mandate_data @mandate_data end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1591 1592 1593 |
# File 'lib/stripe/resources/setup_intent.rb', line 1591 def @metadata end |
#on_behalf_of ⇒ Object
The Stripe account ID created for this SetupIntent.
1593 1594 1595 |
# File 'lib/stripe/resources/setup_intent.rb', line 1593 def on_behalf_of @on_behalf_of end |
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.
1595 1596 1597 |
# File 'lib/stripe/resources/setup_intent.rb', line 1595 def payment_method @payment_method end |
#payment_method_configuration ⇒ Object
The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this SetupIntent.
1597 1598 1599 |
# File 'lib/stripe/resources/setup_intent.rb', line 1597 def payment_method_configuration @payment_method_configuration end |
#payment_method_data ⇒ Object
When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.
1600 1601 1602 |
# File 'lib/stripe/resources/setup_intent.rb', line 1600 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment method-specific configuration for this SetupIntent.
1602 1603 1604 |
# File 'lib/stripe/resources/setup_intent.rb', line 1602 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types (for example, card) that this SetupIntent can use. If you don’t provide this, Stripe will dynamically show relevant payment methods from your [payment method settings](dashboard.stripe.com/settings/payment_methods).
1604 1605 1606 |
# File 'lib/stripe/resources/setup_intent.rb', line 1604 def payment_method_types @payment_method_types end |
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. To redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter can only be used with [‘confirm=true`](stripe.com/docs/api/setup_intents/create#create_setup_intent-confirm).
1606 1607 1608 |
# File 'lib/stripe/resources/setup_intent.rb', line 1606 def return_url @return_url end |
#single_use ⇒ Object
If you populate this hash, this SetupIntent generates a ‘single_use` mandate after successful completion.
Single-use mandates are only valid for the following payment methods: ‘acss_debit`, `alipay`, `au_becs_debit`, `bacs_debit`, `bancontact`, `boleto`, `ideal`, `link`, `sepa_debit`, and `us_bank_account`.
1610 1611 1612 |
# File 'lib/stripe/resources/setup_intent.rb', line 1610 def single_use @single_use end |
#usage ⇒ Object
Indicates how the payment method is intended to be used in the future. If not provided, this value defaults to ‘off_session`.
1612 1613 1614 |
# File 'lib/stripe/resources/setup_intent.rb', line 1612 def usage @usage end |
#use_stripe_sdk ⇒ Object
Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
1614 1615 1616 |
# File 'lib/stripe/resources/setup_intent.rb', line 1614 def use_stripe_sdk @use_stripe_sdk end |