Class: Stripe::SetupIntent::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::CreateParams
- Defined in:
- lib/stripe/resources/setup_intent.rb
Defined Under Namespace
Classes: AutomaticPaymentMethods, MandateData, PaymentMethodData, PaymentMethodOptions, SingleUse
Instance Attribute Summary collapse
-
#attach_to_self ⇒ Object
If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.
-
#automatic_payment_methods ⇒ Object
When you enable this parameter, this SetupIntent accepts payment methods that you enable in the Dashboard and that are compatible with its other parameters.
-
#confirm ⇒ Object
Set to ‘true` to attempt to confirm this SetupIntent immediately.
-
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this SetupIntent.
-
#customer ⇒ Object
ID of the Customer this SetupIntent belongs to, if one exists.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#flow_directions ⇒ Object
Indicates the directions of money movement for which this payment method is intended to be used.
-
#mandate_data ⇒ Object
This hash contains details about the mandate to create.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#on_behalf_of ⇒ Object
The Stripe account ID created for this SetupIntent.
-
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.
-
#payment_method_configuration ⇒ Object
The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this SetupIntent.
-
#payment_method_data ⇒ Object
When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.
-
#payment_method_options ⇒ Object
Payment method-specific configuration for this SetupIntent.
-
#payment_method_types ⇒ Object
The list of payment method types (for example, card) that this SetupIntent can use.
-
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site.
-
#single_use ⇒ Object
If you populate this hash, this SetupIntent generates a ‘single_use` mandate after successful completion.
-
#usage ⇒ Object
Indicates how the payment method is intended to be used in the future.
-
#use_stripe_sdk ⇒ Object
Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(attach_to_self: nil, automatic_payment_methods: nil, confirm: nil, confirmation_token: nil, customer: nil, description: nil, expand: nil, flow_directions: nil, mandate_data: nil, metadata: nil, on_behalf_of: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, single_use: nil, usage: nil, use_stripe_sdk: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 |
# File 'lib/stripe/resources/setup_intent.rb', line 1534 def initialize( attach_to_self: nil, automatic_payment_methods: nil, confirm: nil, confirmation_token: nil, customer: nil, description: nil, expand: nil, flow_directions: nil, mandate_data: nil, metadata: nil, on_behalf_of: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, single_use: nil, usage: nil, use_stripe_sdk: nil ) @attach_to_self = attach_to_self @automatic_payment_methods = automatic_payment_methods @confirm = confirm @confirmation_token = confirmation_token @customer = customer @description = description @expand = @flow_directions = flow_directions @mandate_data = mandate_data @metadata = @on_behalf_of = on_behalf_of @payment_method = payment_method @payment_method_configuration = payment_method_configuration @payment_method_data = payment_method_data @payment_method_options = @payment_method_types = payment_method_types @return_url = return_url @single_use = single_use @usage = usage @use_stripe_sdk = use_stripe_sdk end |
Instance Attribute Details
#attach_to_self ⇒ Object
If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.
It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.
1487 1488 1489 |
# File 'lib/stripe/resources/setup_intent.rb', line 1487 def attach_to_self @attach_to_self end |
#automatic_payment_methods ⇒ Object
When you enable this parameter, this SetupIntent accepts payment methods that you enable in the Dashboard and that are compatible with its other parameters.
1489 1490 1491 |
# File 'lib/stripe/resources/setup_intent.rb', line 1489 def automatic_payment_methods @automatic_payment_methods end |
#confirm ⇒ Object
Set to ‘true` to attempt to confirm this SetupIntent immediately. This parameter defaults to `false`. If a card is the attached payment method, you can provide a `return_url` in case further authentication is necessary.
1491 1492 1493 |
# File 'lib/stripe/resources/setup_intent.rb', line 1491 def confirm @confirm end |
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this SetupIntent.
If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.
1495 1496 1497 |
# File 'lib/stripe/resources/setup_intent.rb', line 1495 def confirmation_token @confirmation_token end |
#customer ⇒ Object
ID of the Customer this SetupIntent belongs to, if one exists.
If present, the SetupIntent’s payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.
1499 1500 1501 |
# File 'lib/stripe/resources/setup_intent.rb', line 1499 def customer @customer end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
1501 1502 1503 |
# File 'lib/stripe/resources/setup_intent.rb', line 1501 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1503 1504 1505 |
# File 'lib/stripe/resources/setup_intent.rb', line 1503 def @expand end |
#flow_directions ⇒ Object
Indicates the directions of money movement for which this payment method is intended to be used.
Include ‘inbound` if you intend to use the payment method as the origin to pull funds from. Include `outbound` if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.
1507 1508 1509 |
# File 'lib/stripe/resources/setup_intent.rb', line 1507 def flow_directions @flow_directions end |
#mandate_data ⇒ Object
This hash contains details about the mandate to create. This parameter can only be used with [‘confirm=true`](stripe.com/docs/api/setup_intents/create#create_setup_intent-confirm).
1509 1510 1511 |
# File 'lib/stripe/resources/setup_intent.rb', line 1509 def mandate_data @mandate_data end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1511 1512 1513 |
# File 'lib/stripe/resources/setup_intent.rb', line 1511 def @metadata end |
#on_behalf_of ⇒ Object
The Stripe account ID created for this SetupIntent.
1513 1514 1515 |
# File 'lib/stripe/resources/setup_intent.rb', line 1513 def on_behalf_of @on_behalf_of end |
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.
1515 1516 1517 |
# File 'lib/stripe/resources/setup_intent.rb', line 1515 def payment_method @payment_method end |
#payment_method_configuration ⇒ Object
The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this SetupIntent.
1517 1518 1519 |
# File 'lib/stripe/resources/setup_intent.rb', line 1517 def payment_method_configuration @payment_method_configuration end |
#payment_method_data ⇒ Object
When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.
1520 1521 1522 |
# File 'lib/stripe/resources/setup_intent.rb', line 1520 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment method-specific configuration for this SetupIntent.
1522 1523 1524 |
# File 'lib/stripe/resources/setup_intent.rb', line 1522 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types (for example, card) that this SetupIntent can use. If you don’t provide this, Stripe will dynamically show relevant payment methods from your [payment method settings](dashboard.stripe.com/settings/payment_methods).
1524 1525 1526 |
# File 'lib/stripe/resources/setup_intent.rb', line 1524 def payment_method_types @payment_method_types end |
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. To redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter can only be used with [‘confirm=true`](stripe.com/docs/api/setup_intents/create#create_setup_intent-confirm).
1526 1527 1528 |
# File 'lib/stripe/resources/setup_intent.rb', line 1526 def return_url @return_url end |
#single_use ⇒ Object
If you populate this hash, this SetupIntent generates a ‘single_use` mandate after successful completion.
1528 1529 1530 |
# File 'lib/stripe/resources/setup_intent.rb', line 1528 def single_use @single_use end |
#usage ⇒ Object
Indicates how the payment method is intended to be used in the future. If not provided, this value defaults to ‘off_session`.
1530 1531 1532 |
# File 'lib/stripe/resources/setup_intent.rb', line 1530 def usage @usage end |
#use_stripe_sdk ⇒ Object
Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
1532 1533 1534 |
# File 'lib/stripe/resources/setup_intent.rb', line 1532 def use_stripe_sdk @use_stripe_sdk end |