Class: Stripe::SetupIntent::CreateParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



432
433
434
435
436
437
# File 'lib/stripe/resources/setup_intent.rb', line 432

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



424
425
426
# File 'lib/stripe/resources/setup_intent.rb', line 424

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



426
427
428
# File 'lib/stripe/resources/setup_intent.rb', line 426

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



428
429
430
# File 'lib/stripe/resources/setup_intent.rb', line 428

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



430
431
432
# File 'lib/stripe/resources/setup_intent.rb', line 430

def type
  @type
end