Class: Stripe::SetupIntent::CreateParams::MandateData::CustomerAcceptance::Online

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ip_address: nil, user_agent: nil) ⇒ Online

Returns a new instance of Online.



382
383
384
385
# File 'lib/stripe/resources/setup_intent.rb', line 382

def initialize(ip_address: nil, user_agent: nil)
  @ip_address = ip_address
  @user_agent = user_agent
end

Instance Attribute Details

#ip_addressObject

The IP address from which the Mandate was accepted by the customer.



378
379
380
# File 'lib/stripe/resources/setup_intent.rb', line 378

def ip_address
  @ip_address
end

#user_agentObject

The user agent of the browser from which the Mandate was accepted by the customer.



380
381
382
# File 'lib/stripe/resources/setup_intent.rb', line 380

def user_agent
  @user_agent
end