Class: Stripe::SetupIntent::CreateParams::PaymentMethodData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, RadarOptions, Rechnung, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, StripeBalance, Swish, Twint, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, billing_details: nil, blik: nil, boleto: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, radar_options: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, stripe_balance: nil, swish: nil, twint: nil, type: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodData

Returns a new instance of PaymentMethodData.



936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
# File 'lib/stripe/resources/setup_intent.rb', line 936

def initialize(
  acss_debit: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  allow_redisplay: nil,
  alma: nil,
  amazon_pay: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  billie: nil,
  billing_details: nil,
  blik: nil,
  boleto: nil,
  cashapp: nil,
  customer_balance: nil,
  eps: nil,
  fpx: nil,
  giropay: nil,
  gopay: nil,
  grabpay: nil,
  id_bank_transfer: nil,
  ideal: nil,
  interac_present: nil,
  kakao_pay: nil,
  klarna: nil,
  konbini: nil,
  kr_card: nil,
  link: nil,
  mb_way: nil,
  metadata: nil,
  mobilepay: nil,
  multibanco: nil,
  naver_pay: nil,
  nz_bank_account: nil,
  oxxo: nil,
  p24: nil,
  pay_by_bank: nil,
  payco: nil,
  paynow: nil,
  paypal: nil,
  payto: nil,
  pix: nil,
  promptpay: nil,
  qris: nil,
  radar_options: nil,
  rechnung: nil,
  revolut_pay: nil,
  samsung_pay: nil,
  satispay: nil,
  sepa_debit: nil,
  shopeepay: nil,
  sofort: nil,
  stripe_balance: nil,
  swish: nil,
  twint: nil,
  type: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @allow_redisplay = allow_redisplay
  @alma = alma
  @amazon_pay = amazon_pay
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @billie = billie
  @billing_details = billing_details
  @blik = blik
  @boleto = boleto
  @cashapp = cashapp
  @customer_balance = customer_balance
  @eps = eps
  @fpx = fpx
  @giropay = giropay
  @gopay = gopay
  @grabpay = grabpay
  @id_bank_transfer = id_bank_transfer
  @ideal = ideal
  @interac_present = interac_present
  @kakao_pay = kakao_pay
  @klarna = klarna
  @konbini = konbini
  @kr_card = kr_card
  @link = link
  @mb_way = mb_way
  @metadata = 
  @mobilepay = mobilepay
  @multibanco = multibanco
  @naver_pay = naver_pay
  @nz_bank_account = 
  @oxxo = oxxo
  @p24 = p24
  @pay_by_bank = pay_by_bank
  @payco = payco
  @paynow = paynow
  @paypal = paypal
  @payto = payto
  @pix = pix
  @promptpay = promptpay
  @qris = qris
  @radar_options = radar_options
  @rechnung = rechnung
  @revolut_pay = revolut_pay
  @samsung_pay = samsung_pay
  @satispay = satispay
  @sepa_debit = sepa_debit
  @shopeepay = shopeepay
  @sofort = sofort
  @stripe_balance = stripe_balance
  @swish = swish
  @twint = twint
  @type = type
  @us_bank_account = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

If this is an ‘acss_debit` PaymentMethod, this hash contains details about the ACSS Debit payment method.



816
817
818
# File 'lib/stripe/resources/setup_intent.rb', line 816

def acss_debit
  @acss_debit
end

#affirmObject

If this is an ‘affirm` PaymentMethod, this hash contains details about the Affirm payment method.



818
819
820
# File 'lib/stripe/resources/setup_intent.rb', line 818

def affirm
  @affirm
end

#afterpay_clearpayObject

If this is an ‘AfterpayClearpay` PaymentMethod, this hash contains details about the AfterpayClearpay payment method.



820
821
822
# File 'lib/stripe/resources/setup_intent.rb', line 820

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If this is an ‘Alipay` PaymentMethod, this hash contains details about the Alipay payment method.



822
823
824
# File 'lib/stripe/resources/setup_intent.rb', line 822

def alipay
  @alipay
end

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.



824
825
826
# File 'lib/stripe/resources/setup_intent.rb', line 824

def allow_redisplay
  @allow_redisplay
end

#almaObject

If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.



826
827
828
# File 'lib/stripe/resources/setup_intent.rb', line 826

def alma
  @alma
end

#amazon_payObject

If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.



828
829
830
# File 'lib/stripe/resources/setup_intent.rb', line 828

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject

If this is an ‘au_becs_debit` PaymentMethod, this hash contains details about the bank account.



830
831
832
# File 'lib/stripe/resources/setup_intent.rb', line 830

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

If this is a ‘bacs_debit` PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.



832
833
834
# File 'lib/stripe/resources/setup_intent.rb', line 832

def bacs_debit
  @bacs_debit
end

#bancontactObject

If this is a ‘bancontact` PaymentMethod, this hash contains details about the Bancontact payment method.



834
835
836
# File 'lib/stripe/resources/setup_intent.rb', line 834

def bancontact
  @bancontact
end

#billieObject

If this is a ‘billie` PaymentMethod, this hash contains details about the Billie payment method.



836
837
838
# File 'lib/stripe/resources/setup_intent.rb', line 836

def billie
  @billie
end

#billing_detailsObject

Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.



838
839
840
# File 'lib/stripe/resources/setup_intent.rb', line 838

def billing_details
  @billing_details
end

#blikObject

If this is a ‘blik` PaymentMethod, this hash contains details about the BLIK payment method.



840
841
842
# File 'lib/stripe/resources/setup_intent.rb', line 840

def blik
  @blik
end

#boletoObject

If this is a ‘boleto` PaymentMethod, this hash contains details about the Boleto payment method.



842
843
844
# File 'lib/stripe/resources/setup_intent.rb', line 842

def boleto
  @boleto
end

#cashappObject

If this is a ‘cashapp` PaymentMethod, this hash contains details about the Cash App Pay payment method.



844
845
846
# File 'lib/stripe/resources/setup_intent.rb', line 844

def cashapp
  @cashapp
end

#customer_balanceObject

If this is a ‘customer_balance` PaymentMethod, this hash contains details about the CustomerBalance payment method.



846
847
848
# File 'lib/stripe/resources/setup_intent.rb', line 846

def customer_balance
  @customer_balance
end

#epsObject

If this is an ‘eps` PaymentMethod, this hash contains details about the EPS payment method.



848
849
850
# File 'lib/stripe/resources/setup_intent.rb', line 848

def eps
  @eps
end

#fpxObject

If this is an ‘fpx` PaymentMethod, this hash contains details about the FPX payment method.



850
851
852
# File 'lib/stripe/resources/setup_intent.rb', line 850

def fpx
  @fpx
end

#giropayObject

If this is a ‘giropay` PaymentMethod, this hash contains details about the Giropay payment method.



852
853
854
# File 'lib/stripe/resources/setup_intent.rb', line 852

def giropay
  @giropay
end

#gopayObject

If this is a Gopay PaymentMethod, this hash contains details about the Gopay payment method.



854
855
856
# File 'lib/stripe/resources/setup_intent.rb', line 854

def gopay
  @gopay
end

#grabpayObject

If this is a ‘grabpay` PaymentMethod, this hash contains details about the GrabPay payment method.



856
857
858
# File 'lib/stripe/resources/setup_intent.rb', line 856

def grabpay
  @grabpay
end

#id_bank_transferObject

If this is an ‘IdBankTransfer` PaymentMethod, this hash contains details about the IdBankTransfer payment method.



858
859
860
# File 'lib/stripe/resources/setup_intent.rb', line 858

def id_bank_transfer
  @id_bank_transfer
end

#idealObject

If this is an ‘ideal` PaymentMethod, this hash contains details about the iDEAL payment method.



860
861
862
# File 'lib/stripe/resources/setup_intent.rb', line 860

def ideal
  @ideal
end

#interac_presentObject

If this is an ‘interac_present` PaymentMethod, this hash contains details about the Interac Present payment method.



862
863
864
# File 'lib/stripe/resources/setup_intent.rb', line 862

def interac_present
  @interac_present
end

#kakao_payObject

If this is a ‘kakao_pay` PaymentMethod, this hash contains details about the Kakao Pay payment method.



864
865
866
# File 'lib/stripe/resources/setup_intent.rb', line 864

def kakao_pay
  @kakao_pay
end

#klarnaObject

If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method.



866
867
868
# File 'lib/stripe/resources/setup_intent.rb', line 866

def klarna
  @klarna
end

#konbiniObject

If this is a ‘konbini` PaymentMethod, this hash contains details about the Konbini payment method.



868
869
870
# File 'lib/stripe/resources/setup_intent.rb', line 868

def konbini
  @konbini
end

#kr_cardObject

If this is a ‘kr_card` PaymentMethod, this hash contains details about the Korean Card payment method.



870
871
872
# File 'lib/stripe/resources/setup_intent.rb', line 870

def kr_card
  @kr_card
end

If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.



872
873
874
# File 'lib/stripe/resources/setup_intent.rb', line 872

def link
  @link
end

#mb_wayObject

If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.



874
875
876
# File 'lib/stripe/resources/setup_intent.rb', line 874

def mb_way
  @mb_way
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



876
877
878
# File 'lib/stripe/resources/setup_intent.rb', line 876

def 
  @metadata
end

#mobilepayObject

If this is a ‘mobilepay` PaymentMethod, this hash contains details about the MobilePay payment method.



878
879
880
# File 'lib/stripe/resources/setup_intent.rb', line 878

def mobilepay
  @mobilepay
end

#multibancoObject

If this is a ‘multibanco` PaymentMethod, this hash contains details about the Multibanco payment method.



880
881
882
# File 'lib/stripe/resources/setup_intent.rb', line 880

def multibanco
  @multibanco
end

If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.



882
883
884
# File 'lib/stripe/resources/setup_intent.rb', line 882

def naver_pay
  @naver_pay
end

#nz_bank_accountObject

If this is an nz_bank_account PaymentMethod, this hash contains details about the nz_bank_account payment method.



884
885
886
# File 'lib/stripe/resources/setup_intent.rb', line 884

def 
  @nz_bank_account
end

#oxxoObject

If this is an ‘oxxo` PaymentMethod, this hash contains details about the OXXO payment method.



886
887
888
# File 'lib/stripe/resources/setup_intent.rb', line 886

def oxxo
  @oxxo
end

#p24Object

If this is a ‘p24` PaymentMethod, this hash contains details about the P24 payment method.



888
889
890
# File 'lib/stripe/resources/setup_intent.rb', line 888

def p24
  @p24
end

#pay_by_bankObject

If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.



890
891
892
# File 'lib/stripe/resources/setup_intent.rb', line 890

def pay_by_bank
  @pay_by_bank
end

#paycoObject

If this is a ‘payco` PaymentMethod, this hash contains details about the PAYCO payment method.



892
893
894
# File 'lib/stripe/resources/setup_intent.rb', line 892

def payco
  @payco
end

#paynowObject

If this is a ‘paynow` PaymentMethod, this hash contains details about the PayNow payment method.



894
895
896
# File 'lib/stripe/resources/setup_intent.rb', line 894

def paynow
  @paynow
end

#paypalObject

If this is a ‘paypal` PaymentMethod, this hash contains details about the PayPal payment method.



896
897
898
# File 'lib/stripe/resources/setup_intent.rb', line 896

def paypal
  @paypal
end

#paytoObject

If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.



898
899
900
# File 'lib/stripe/resources/setup_intent.rb', line 898

def payto
  @payto
end

#pixObject

If this is a ‘pix` PaymentMethod, this hash contains details about the Pix payment method.



900
901
902
# File 'lib/stripe/resources/setup_intent.rb', line 900

def pix
  @pix
end

#promptpayObject

If this is a ‘promptpay` PaymentMethod, this hash contains details about the PromptPay payment method.



902
903
904
# File 'lib/stripe/resources/setup_intent.rb', line 902

def promptpay
  @promptpay
end

#qrisObject

If this is a ‘qris` PaymentMethod, this hash contains details about the QRIS payment method.



904
905
906
# File 'lib/stripe/resources/setup_intent.rb', line 904

def qris
  @qris
end

#radar_optionsObject

Options to configure Radar. See [Radar Session](stripe.com/docs/radar/radar-session) for more information.



906
907
908
# File 'lib/stripe/resources/setup_intent.rb', line 906

def radar_options
  @radar_options
end

#rechnungObject

If this is a ‘rechnung` PaymentMethod, this hash contains details about the Rechnung payment method.



908
909
910
# File 'lib/stripe/resources/setup_intent.rb', line 908

def rechnung
  @rechnung
end

#revolut_payObject

If this is a ‘revolut_pay` PaymentMethod, this hash contains details about the Revolut Pay payment method.



910
911
912
# File 'lib/stripe/resources/setup_intent.rb', line 910

def revolut_pay
  @revolut_pay
end

#samsung_payObject

If this is a ‘samsung_pay` PaymentMethod, this hash contains details about the SamsungPay payment method.



912
913
914
# File 'lib/stripe/resources/setup_intent.rb', line 912

def samsung_pay
  @samsung_pay
end

#satispayObject

If this is a ‘satispay` PaymentMethod, this hash contains details about the Satispay payment method.



914
915
916
# File 'lib/stripe/resources/setup_intent.rb', line 914

def satispay
  @satispay
end

#sepa_debitObject

If this is a ‘sepa_debit` PaymentMethod, this hash contains details about the SEPA debit bank account.



916
917
918
# File 'lib/stripe/resources/setup_intent.rb', line 916

def sepa_debit
  @sepa_debit
end

#shopeepayObject

If this is a Shopeepay PaymentMethod, this hash contains details about the Shopeepay payment method.



918
919
920
# File 'lib/stripe/resources/setup_intent.rb', line 918

def shopeepay
  @shopeepay
end

#sofortObject

If this is a ‘sofort` PaymentMethod, this hash contains details about the SOFORT payment method.



920
921
922
# File 'lib/stripe/resources/setup_intent.rb', line 920

def sofort
  @sofort
end

#stripe_balanceObject

This hash contains details about the Stripe balance payment method.



922
923
924
# File 'lib/stripe/resources/setup_intent.rb', line 922

def stripe_balance
  @stripe_balance
end

#swishObject

If this is a ‘swish` PaymentMethod, this hash contains details about the Swish payment method.



924
925
926
# File 'lib/stripe/resources/setup_intent.rb', line 924

def swish
  @swish
end

#twintObject

If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.



926
927
928
# File 'lib/stripe/resources/setup_intent.rb', line 926

def twint
  @twint
end

#typeObject

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



928
929
930
# File 'lib/stripe/resources/setup_intent.rb', line 928

def type
  @type
end

#us_bank_accountObject

If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.



930
931
932
# File 'lib/stripe/resources/setup_intent.rb', line 930

def 
  @us_bank_account
end

#wechat_payObject

If this is an ‘wechat_pay` PaymentMethod, this hash contains details about the wechat_pay payment method.



932
933
934
# File 'lib/stripe/resources/setup_intent.rb', line 932

def wechat_pay
  @wechat_pay
end

#zipObject

If this is a ‘zip` PaymentMethod, this hash contains details about the Zip payment method.



934
935
936
# File 'lib/stripe/resources/setup_intent.rb', line 934

def zip
  @zip
end