Class: Stripe::SetupIntent::CreateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::CreateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 |
# File 'lib/stripe/resources/setup_intent.rb', line 990 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
978 979 980 |
# File 'lib/stripe/resources/setup_intent.rb', line 978 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
980 981 982 |
# File 'lib/stripe/resources/setup_intent.rb', line 980 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
982 983 984 |
# File 'lib/stripe/resources/setup_intent.rb', line 982 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
984 985 986 |
# File 'lib/stripe/resources/setup_intent.rb', line 984 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
986 987 988 |
# File 'lib/stripe/resources/setup_intent.rb', line 986 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
988 989 990 |
# File 'lib/stripe/resources/setup_intent.rb', line 988 def suffix @suffix end |