Class: Stripe::SetupIntent::CreateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::CreateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 |
# File 'lib/stripe/resources/setup_intent.rb', line 713 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
701 702 703 |
# File 'lib/stripe/resources/setup_intent.rb', line 701 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
703 704 705 |
# File 'lib/stripe/resources/setup_intent.rb', line 703 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
705 706 707 |
# File 'lib/stripe/resources/setup_intent.rb', line 705 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
707 708 709 |
# File 'lib/stripe/resources/setup_intent.rb', line 707 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
709 710 711 |
# File 'lib/stripe/resources/setup_intent.rb', line 709 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
711 712 713 |
# File 'lib/stripe/resources/setup_intent.rb', line 711 def suffix @suffix end |