Class: Stripe::SetupIntent::CreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
# File 'lib/stripe/resources/setup_intent.rb', line 673

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



661
662
663
# File 'lib/stripe/resources/setup_intent.rb', line 661

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



663
664
665
# File 'lib/stripe/resources/setup_intent.rb', line 663

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



665
666
667
# File 'lib/stripe/resources/setup_intent.rb', line 665

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



667
668
669
# File 'lib/stripe/resources/setup_intent.rb', line 667

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



669
670
671
# File 'lib/stripe/resources/setup_intent.rb', line 669

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



671
672
673
# File 'lib/stripe/resources/setup_intent.rb', line 671

def suffix
  @suffix
end