Class: Stripe::SetupIntent::CreateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::CreateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 |
# File 'lib/stripe/resources/setup_intent.rb', line 663 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
651 652 653 |
# File 'lib/stripe/resources/setup_intent.rb', line 651 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
653 654 655 |
# File 'lib/stripe/resources/setup_intent.rb', line 653 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
655 656 657 |
# File 'lib/stripe/resources/setup_intent.rb', line 655 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
657 658 659 |
# File 'lib/stripe/resources/setup_intent.rb', line 657 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
659 660 661 |
# File 'lib/stripe/resources/setup_intent.rb', line 659 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
661 662 663 |
# File 'lib/stripe/resources/setup_intent.rb', line 661 def suffix @suffix end |