Class: Stripe::SetupIntent::CreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'lib/stripe/resources/setup_intent.rb', line 612

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



600
601
602
# File 'lib/stripe/resources/setup_intent.rb', line 600

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



602
603
604
# File 'lib/stripe/resources/setup_intent.rb', line 602

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



604
605
606
# File 'lib/stripe/resources/setup_intent.rb', line 604

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



606
607
608
# File 'lib/stripe/resources/setup_intent.rb', line 606

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



608
609
610
# File 'lib/stripe/resources/setup_intent.rb', line 608

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



610
611
612
# File 'lib/stripe/resources/setup_intent.rb', line 610

def suffix
  @suffix
end