Class: Stripe::SetupIntent::CreateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::CreateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/stripe/resources/setup_intent.rb', line 644 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
632 633 634 |
# File 'lib/stripe/resources/setup_intent.rb', line 632 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
634 635 636 |
# File 'lib/stripe/resources/setup_intent.rb', line 634 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
636 637 638 |
# File 'lib/stripe/resources/setup_intent.rb', line 636 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
638 639 640 |
# File 'lib/stripe/resources/setup_intent.rb', line 638 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
640 641 642 |
# File 'lib/stripe/resources/setup_intent.rb', line 640 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
642 643 644 |
# File 'lib/stripe/resources/setup_intent.rb', line 642 def suffix @suffix end |