Class: Stripe::SetupIntent::CreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
# File 'lib/stripe/resources/setup_intent.rb', line 696

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



684
685
686
# File 'lib/stripe/resources/setup_intent.rb', line 684

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



686
687
688
# File 'lib/stripe/resources/setup_intent.rb', line 686

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



688
689
690
# File 'lib/stripe/resources/setup_intent.rb', line 688

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



690
691
692
# File 'lib/stripe/resources/setup_intent.rb', line 690

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



692
693
694
# File 'lib/stripe/resources/setup_intent.rb', line 692

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



694
695
696
# File 'lib/stripe/resources/setup_intent.rb', line 694

def suffix
  @suffix
end