Class: Stripe::SetupIntent::CreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
# File 'lib/stripe/resources/setup_intent.rb', line 699

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



687
688
689
# File 'lib/stripe/resources/setup_intent.rb', line 687

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



689
690
691
# File 'lib/stripe/resources/setup_intent.rb', line 689

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



691
692
693
# File 'lib/stripe/resources/setup_intent.rb', line 691

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



693
694
695
# File 'lib/stripe/resources/setup_intent.rb', line 693

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



695
696
697
# File 'lib/stripe/resources/setup_intent.rb', line 695

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



697
698
699
# File 'lib/stripe/resources/setup_intent.rb', line 697

def suffix
  @suffix
end