Class: Stripe::SetupIntent::CreateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::CreateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/stripe/resources/setup_intent.rb', line 808 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
798 799 800 |
# File 'lib/stripe/resources/setup_intent.rb', line 798 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
800 801 802 |
# File 'lib/stripe/resources/setup_intent.rb', line 800 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
802 803 804 |
# File 'lib/stripe/resources/setup_intent.rb', line 802 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
804 805 806 |
# File 'lib/stripe/resources/setup_intent.rb', line 804 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
806 807 808 |
# File 'lib/stripe/resources/setup_intent.rb', line 806 def routing_number @routing_number end |