Class: Stripe::SetupIntent::CreateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::CreateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
745 746 747 748 749 750 751 752 753 754 755 756 757 |
# File 'lib/stripe/resources/setup_intent.rb', line 745 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
735 736 737 |
# File 'lib/stripe/resources/setup_intent.rb', line 735 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
737 738 739 |
# File 'lib/stripe/resources/setup_intent.rb', line 737 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
739 740 741 |
# File 'lib/stripe/resources/setup_intent.rb', line 739 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
741 742 743 |
# File 'lib/stripe/resources/setup_intent.rb', line 741 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
743 744 745 |
# File 'lib/stripe/resources/setup_intent.rb', line 743 def routing_number @routing_number end |