Class: Stripe::SetupIntent::CreateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::CreateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
853 854 855 856 857 858 859 860 861 862 863 864 865 |
# File 'lib/stripe/resources/setup_intent.rb', line 853 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
843 844 845 |
# File 'lib/stripe/resources/setup_intent.rb', line 843 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
845 846 847 |
# File 'lib/stripe/resources/setup_intent.rb', line 845 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
847 848 849 |
# File 'lib/stripe/resources/setup_intent.rb', line 847 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
849 850 851 |
# File 'lib/stripe/resources/setup_intent.rb', line 849 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
851 852 853 |
# File 'lib/stripe/resources/setup_intent.rb', line 851 def routing_number @routing_number end |