Class: Stripe::SetupIntent::CreateParams::PaymentMethodOptions::AcssDebit::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
# File 'lib/stripe/resources/setup_intent.rb', line 1221

def initialize(
  custom_mandate_url: nil,
  default_for: nil,
  interval_description: nil,
  payment_schedule: nil,
  transaction_type: nil
)
  @custom_mandate_url = custom_mandate_url
  @default_for = default_for
  @interval_description = interval_description
  @payment_schedule = payment_schedule
  @transaction_type = transaction_type
end

Instance Attribute Details

#custom_mandate_urlObject

A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.



1207
1208
1209
# File 'lib/stripe/resources/setup_intent.rb', line 1207

def custom_mandate_url
  @custom_mandate_url
end

#default_forObject

List of Stripe products where this mandate can be selected automatically.



1210
1211
1212
# File 'lib/stripe/resources/setup_intent.rb', line 1210

def default_for
  @default_for
end

#interval_descriptionObject

Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.



1213
1214
1215
# File 'lib/stripe/resources/setup_intent.rb', line 1213

def interval_description
  @interval_description
end

#payment_scheduleObject

Payment schedule for the mandate.



1216
1217
1218
# File 'lib/stripe/resources/setup_intent.rb', line 1216

def payment_schedule
  @payment_schedule
end

#transaction_typeObject

Transaction type of the mandate.



1219
1220
1221
# File 'lib/stripe/resources/setup_intent.rb', line 1219

def transaction_type
  @transaction_type
end