Class: Stripe::SetupIntent::CreateParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, currency: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/stripe/resources/setup_intent.rb', line 1130

def initialize(
  amount: nil,
  amount_type: nil,
  currency: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @currency = currency
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



1110
1111
1112
# File 'lib/stripe/resources/setup_intent.rb', line 1110

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



1112
1113
1114
# File 'lib/stripe/resources/setup_intent.rb', line 1112

def amount_type
  @amount_type
end

#currencyObject

Currency in which future payments will be charged. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



1114
1115
1116
# File 'lib/stripe/resources/setup_intent.rb', line 1114

def currency
  @currency
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



1116
1117
1118
# File 'lib/stripe/resources/setup_intent.rb', line 1116

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



1118
1119
1120
# File 'lib/stripe/resources/setup_intent.rb', line 1118

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



1120
1121
1122
# File 'lib/stripe/resources/setup_intent.rb', line 1120

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



1122
1123
1124
# File 'lib/stripe/resources/setup_intent.rb', line 1122

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



1124
1125
1126
# File 'lib/stripe/resources/setup_intent.rb', line 1124

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



1126
1127
1128
# File 'lib/stripe/resources/setup_intent.rb', line 1126

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are ‘india`.



1128
1129
1130
# File 'lib/stripe/resources/setup_intent.rb', line 1128

def supported_types
  @supported_types
end