Class: Stripe::SetupIntent::CreateParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, currency: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
# File 'lib/stripe/resources/setup_intent.rb', line 1303

def initialize(
  amount: nil,
  amount_type: nil,
  currency: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @currency = currency
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



1274
1275
1276
# File 'lib/stripe/resources/setup_intent.rb', line 1274

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



1277
1278
1279
# File 'lib/stripe/resources/setup_intent.rb', line 1277

def amount_type
  @amount_type
end

#currencyObject

Currency in which future payments will be charged. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



1280
1281
1282
# File 'lib/stripe/resources/setup_intent.rb', line 1280

def currency
  @currency
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



1283
1284
1285
# File 'lib/stripe/resources/setup_intent.rb', line 1283

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



1286
1287
1288
# File 'lib/stripe/resources/setup_intent.rb', line 1286

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



1289
1290
1291
# File 'lib/stripe/resources/setup_intent.rb', line 1289

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



1292
1293
1294
# File 'lib/stripe/resources/setup_intent.rb', line 1292

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



1295
1296
1297
# File 'lib/stripe/resources/setup_intent.rb', line 1295

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



1298
1299
1300
# File 'lib/stripe/resources/setup_intent.rb', line 1298

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are ‘india`.



1301
1302
1303
# File 'lib/stripe/resources/setup_intent.rb', line 1301

def supported_types
  @supported_types
end