Class: Stripe::SetupIntent::CreateParams::PaymentMethodOptions::Card::ThreeDSecure::NetworkOptions::CartesBancaires
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::CreateParams::PaymentMethodOptions::Card::ThreeDSecure::NetworkOptions::CartesBancaires
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#cb_avalgo ⇒ Object
The cryptogram calculation algorithm used by the card Issuer’s ACS to calculate the Authentication cryptogram.
-
#cb_exemption ⇒ Object
The exemption indicator returned from Cartes Bancaires in the ARes.
-
#cb_score ⇒ Object
The risk score returned from Cartes Bancaires in the ARes.
Instance Method Summary collapse
-
#initialize(cb_avalgo: nil, cb_exemption: nil, cb_score: nil) ⇒ CartesBancaires
constructor
A new instance of CartesBancaires.
Methods inherited from RequestParams
Constructor Details
#initialize(cb_avalgo: nil, cb_exemption: nil, cb_score: nil) ⇒ CartesBancaires
Returns a new instance of CartesBancaires.
1346 1347 1348 1349 1350 |
# File 'lib/stripe/resources/setup_intent.rb', line 1346 def initialize(cb_avalgo: nil, cb_exemption: nil, cb_score: nil) @cb_avalgo = cb_avalgo @cb_exemption = cb_exemption @cb_score = cb_score end |
Instance Attribute Details
#cb_avalgo ⇒ Object
The cryptogram calculation algorithm used by the card Issuer’s ACS to calculate the Authentication cryptogram. Also known as ‘cavvAlgorithm`. messageExtension: CB-AVALGO
1334 1335 1336 |
# File 'lib/stripe/resources/setup_intent.rb', line 1334 def cb_avalgo @cb_avalgo end |
#cb_exemption ⇒ Object
The exemption indicator returned from Cartes Bancaires in the ARes. message extension: CB-EXEMPTION; string (4 characters) This is a 3 byte bitmap (low significant byte first and most significant bit first) that has been Base64 encoded
1340 1341 1342 |
# File 'lib/stripe/resources/setup_intent.rb', line 1340 def cb_exemption @cb_exemption end |
#cb_score ⇒ Object
The risk score returned from Cartes Bancaires in the ARes. message extension: CB-SCORE; numeric value 0-99
1344 1345 1346 |
# File 'lib/stripe/resources/setup_intent.rb', line 1344 def cb_score @cb_score end |