Class: Stripe::SetupIntent::CreateParams::PaymentMethodOptions::Klarna

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: OnDemand, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil) ⇒ Klarna

Returns a new instance of Klarna.



1678
1679
1680
1681
1682
1683
# File 'lib/stripe/resources/setup_intent.rb', line 1678

def initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil)
  @currency = currency
  @on_demand = on_demand
  @preferred_locale = preferred_locale
  @subscriptions = subscriptions
end

Instance Attribute Details

#currencyObject

The currency of the SetupIntent. Three letter ISO currency code.



1670
1671
1672
# File 'lib/stripe/resources/setup_intent.rb', line 1670

def currency
  @currency
end

#on_demandObject

On-demand details if setting up a payment method for on-demand payments.



1672
1673
1674
# File 'lib/stripe/resources/setup_intent.rb', line 1672

def on_demand
  @on_demand
end

#preferred_localeObject

Preferred language of the Klarna authorization page that the customer is redirected to



1674
1675
1676
# File 'lib/stripe/resources/setup_intent.rb', line 1674

def preferred_locale
  @preferred_locale
end

#subscriptionsObject

Subscription details if setting up or charging a subscription



1676
1677
1678
# File 'lib/stripe/resources/setup_intent.rb', line 1676

def subscriptions
  @subscriptions
end