Class: Stripe::SetupIntent::CreateParams::PaymentMethodOptions::Klarna

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: OnDemand, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil) ⇒ Klarna

Returns a new instance of Klarna.



1224
1225
1226
1227
1228
1229
# File 'lib/stripe/resources/setup_intent.rb', line 1224

def initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil)
  @currency = currency
  @on_demand = on_demand
  @preferred_locale = preferred_locale
  @subscriptions = subscriptions
end

Instance Attribute Details

#currencyObject

The currency of the SetupIntent. Three letter ISO currency code.



1216
1217
1218
# File 'lib/stripe/resources/setup_intent.rb', line 1216

def currency
  @currency
end

#on_demandObject

On-demand details if setting up a payment method for on-demand payments.



1218
1219
1220
# File 'lib/stripe/resources/setup_intent.rb', line 1218

def on_demand
  @on_demand
end

#preferred_localeObject

Preferred language of the Klarna authorization page that the customer is redirected to



1220
1221
1222
# File 'lib/stripe/resources/setup_intent.rb', line 1220

def preferred_locale
  @preferred_locale
end

#subscriptionsObject

Subscription details if setting up or charging a subscription



1222
1223
1224
# File 'lib/stripe/resources/setup_intent.rb', line 1222

def subscriptions
  @subscriptions
end