Class: Stripe::SetupIntent::CreateParams::PaymentMethodOptions::Klarna

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: OnDemand, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil) ⇒ Klarna

Returns a new instance of Klarna.



1361
1362
1363
1364
1365
1366
# File 'lib/stripe/resources/setup_intent.rb', line 1361

def initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil)
  @currency = currency
  @on_demand = on_demand
  @preferred_locale = preferred_locale
  @subscriptions = subscriptions
end

Instance Attribute Details

#currencyObject

The currency of the SetupIntent. Three letter ISO currency code.



1353
1354
1355
# File 'lib/stripe/resources/setup_intent.rb', line 1353

def currency
  @currency
end

#on_demandObject

On-demand details if setting up a payment method for on-demand payments.



1355
1356
1357
# File 'lib/stripe/resources/setup_intent.rb', line 1355

def on_demand
  @on_demand
end

#preferred_localeObject

Preferred language of the Klarna authorization page that the customer is redirected to



1357
1358
1359
# File 'lib/stripe/resources/setup_intent.rb', line 1357

def preferred_locale
  @preferred_locale
end

#subscriptionsObject

Subscription details if setting up or charging a subscription



1359
1360
1361
# File 'lib/stripe/resources/setup_intent.rb', line 1359

def subscriptions
  @subscriptions
end