Class: Stripe::SetupIntent::CreateParams::PaymentMethodOptions::Paypal

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_agreement_id: nil, currency: nil, subsellers: nil) ⇒ Paypal

Returns a new instance of Paypal.



1386
1387
1388
1389
1390
# File 'lib/stripe/resources/setup_intent.rb', line 1386

def initialize(billing_agreement_id: nil, currency: nil, subsellers: nil)
  @billing_agreement_id = billing_agreement_id
  @currency = currency
  @subsellers = subsellers
end

Instance Attribute Details

#billing_agreement_idObject

The PayPal Billing Agreement ID (BAID). This is an ID generated by PayPal which represents the mandate between the merchant and the customer.



1380
1381
1382
# File 'lib/stripe/resources/setup_intent.rb', line 1380

def billing_agreement_id
  @billing_agreement_id
end

#currencyObject

Attribute for param field currency



1382
1383
1384
# File 'lib/stripe/resources/setup_intent.rb', line 1382

def currency
  @currency
end

#subsellersObject

The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when [separate charges and transfers](stripe.com/docs/connect/separate-charges-and-transfers) are used.



1384
1385
1386
# File 'lib/stripe/resources/setup_intent.rb', line 1384

def subsellers
  @subsellers
end