Class: Stripe::SetupIntent::CreateParams::PaymentMethodOptions::Paypal

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_agreement_id: nil, currency: nil, subsellers: nil) ⇒ Paypal

Returns a new instance of Paypal.



1353
1354
1355
1356
1357
# File 'lib/stripe/resources/setup_intent.rb', line 1353

def initialize(billing_agreement_id: nil, currency: nil, subsellers: nil)
  @billing_agreement_id = billing_agreement_id
  @currency = currency
  @subsellers = subsellers
end

Instance Attribute Details

#billing_agreement_idObject

The PayPal Billing Agreement ID (BAID). This is an ID generated by PayPal which represents the mandate between the merchant and the customer.



1347
1348
1349
# File 'lib/stripe/resources/setup_intent.rb', line 1347

def billing_agreement_id
  @billing_agreement_id
end

#currencyObject

Attribute for param field currency



1349
1350
1351
# File 'lib/stripe/resources/setup_intent.rb', line 1349

def currency
  @currency
end

#subsellersObject

The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when [separate charges and transfers](stripe.com/docs/connect/separate-charges-and-transfers) are used.



1351
1352
1353
# File 'lib/stripe/resources/setup_intent.rb', line 1351

def subsellers
  @subsellers
end