Class: Stripe::SetupIntent::CreateParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
# File 'lib/stripe/resources/setup_intent.rb', line 1298

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil,
  start_date: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
  @start_date = start_date
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when ‘amount_type` is `fixed`.



1284
1285
1286
# File 'lib/stripe/resources/setup_intent.rb', line 1284

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.



1286
1287
1288
# File 'lib/stripe/resources/setup_intent.rb', line 1286

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



1288
1289
1290
# File 'lib/stripe/resources/setup_intent.rb', line 1288

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected.



1290
1291
1292
# File 'lib/stripe/resources/setup_intent.rb', line 1290

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.



1292
1293
1294
# File 'lib/stripe/resources/setup_intent.rb', line 1292

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Defaults to retail.



1294
1295
1296
# File 'lib/stripe/resources/setup_intent.rb', line 1294

def purpose
  @purpose
end

#start_dateObject

Date, in YYYY-MM-DD format, from which payments will be collected. Defaults to confirmation time.



1296
1297
1298
# File 'lib/stripe/resources/setup_intent.rb', line 1296

def start_date
  @start_date
end