Class: Stripe::SetupIntent::CreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
# File 'lib/stripe/resources/setup_intent.rb', line 1453

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



1443
1444
1445
# File 'lib/stripe/resources/setup_intent.rb', line 1443

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



1445
1446
1447
# File 'lib/stripe/resources/setup_intent.rb', line 1445

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



1447
1448
1449
# File 'lib/stripe/resources/setup_intent.rb', line 1447

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



1449
1450
1451
# File 'lib/stripe/resources/setup_intent.rb', line 1449

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



1451
1452
1453
# File 'lib/stripe/resources/setup_intent.rb', line 1451

def return_url
  @return_url
end