Class: Stripe::SetupIntent::CreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
# File 'lib/stripe/resources/setup_intent.rb', line 1381

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



1371
1372
1373
# File 'lib/stripe/resources/setup_intent.rb', line 1371

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



1373
1374
1375
# File 'lib/stripe/resources/setup_intent.rb', line 1373

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



1375
1376
1377
# File 'lib/stripe/resources/setup_intent.rb', line 1375

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



1377
1378
1379
# File 'lib/stripe/resources/setup_intent.rb', line 1377

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



1379
1380
1381
# File 'lib/stripe/resources/setup_intent.rb', line 1379

def return_url
  @return_url
end