Class: Stripe::SetupIntent::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(attach_to_self: nil, created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, payment_method: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/stripe/resources/setup_intent.rb', line 371

def initialize(
  attach_to_self: nil,
  created: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  payment_method: nil,
  starting_after: nil
)
  @attach_to_self = attach_to_self
  @created = created
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @payment_method = payment_method
  @starting_after = starting_after
end

Instance Attribute Details

#attach_to_selfObject

If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.

It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.



355
356
357
# File 'lib/stripe/resources/setup_intent.rb', line 355

def attach_to_self
  @attach_to_self
end

#createdObject

A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.



357
358
359
# File 'lib/stripe/resources/setup_intent.rb', line 357

def created
  @created
end

#customerObject

Only return SetupIntents for the customer specified by this customer ID.



359
360
361
# File 'lib/stripe/resources/setup_intent.rb', line 359

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



361
362
363
# File 'lib/stripe/resources/setup_intent.rb', line 361

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



363
364
365
# File 'lib/stripe/resources/setup_intent.rb', line 363

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



365
366
367
# File 'lib/stripe/resources/setup_intent.rb', line 365

def limit
  @limit
end

#payment_methodObject

Only return SetupIntents that associate with the specified payment method.



367
368
369
# File 'lib/stripe/resources/setup_intent.rb', line 367

def payment_method
  @payment_method
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



369
370
371
# File 'lib/stripe/resources/setup_intent.rb', line 369

def starting_after
  @starting_after
end