Class: Stripe::SetupIntent::NextAction

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: CashappHandleRedirectOrDisplayQrCode, PixDisplayQrCode, RedirectToUrl, UpiHandleRedirectOrDisplayQrCode, VerifyWithMicrodeposits

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#cashapp_handle_redirect_or_display_qr_codeObject (readonly)

Attribute for field cashapp_handle_redirect_or_display_qr_code



261
262
263
# File 'lib/stripe/resources/setup_intent.rb', line 261

def cashapp_handle_redirect_or_display_qr_code
  @cashapp_handle_redirect_or_display_qr_code
end

#pix_display_qr_codeObject (readonly)

Attribute for field pix_display_qr_code



263
264
265
# File 'lib/stripe/resources/setup_intent.rb', line 263

def pix_display_qr_code
  @pix_display_qr_code
end

#redirect_to_urlObject (readonly)

Attribute for field redirect_to_url



265
266
267
# File 'lib/stripe/resources/setup_intent.rb', line 265

def redirect_to_url
  @redirect_to_url
end

#typeObject (readonly)

Type of the next action to perform. Refer to the other child attributes under ‘next_action` for available values. Examples include: `redirect_to_url`, `use_stripe_sdk`, `alipay_handle_redirect`, `oxxo_display_details`, or `verify_with_microdeposits`.



267
268
269
# File 'lib/stripe/resources/setup_intent.rb', line 267

def type
  @type
end

#upi_handle_redirect_or_display_qr_codeObject (readonly)

Attribute for field upi_handle_redirect_or_display_qr_code



269
270
271
# File 'lib/stripe/resources/setup_intent.rb', line 269

def upi_handle_redirect_or_display_qr_code
  @upi_handle_redirect_or_display_qr_code
end

#use_stripe_sdkObject (readonly)

When confirming a SetupIntent with Stripe.js, Stripe.js depends on the contents of this dictionary to invoke authentication flows. The shape of the contents is subject to change and is only intended to be used by Stripe.js.



271
272
273
# File 'lib/stripe/resources/setup_intent.rb', line 271

def use_stripe_sdk
  @use_stripe_sdk
end

#verify_with_microdepositsObject (readonly)

Attribute for field verify_with_microdeposits



273
274
275
# File 'lib/stripe/resources/setup_intent.rb', line 273

def verify_with_microdeposits
  @verify_with_microdeposits
end

Class Method Details

.field_remappingsObject



285
286
287
# File 'lib/stripe/resources/setup_intent.rb', line 285

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



275
276
277
278
279
280
281
282
283
# File 'lib/stripe/resources/setup_intent.rb', line 275

def self.inner_class_types
  @inner_class_types = {
    cashapp_handle_redirect_or_display_qr_code: CashappHandleRedirectOrDisplayQrCode,
    pix_display_qr_code: PixDisplayQrCode,
    redirect_to_url: RedirectToUrl,
    upi_handle_redirect_or_display_qr_code: UpiHandleRedirectOrDisplayQrCode,
    verify_with_microdeposits: VerifyWithMicrodeposits,
  }
end