Class: Stripe::SetupIntent::NextAction

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: CashappHandleRedirectOrDisplayQrCode, PixDisplayQrCode, RedirectToUrl, VerifyWithMicrodeposits

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#cashapp_handle_redirect_or_display_qr_codeObject (readonly)

Attribute for field cashapp_handle_redirect_or_display_qr_code



217
218
219
# File 'lib/stripe/resources/setup_intent.rb', line 217

def cashapp_handle_redirect_or_display_qr_code
  @cashapp_handle_redirect_or_display_qr_code
end

#pix_display_qr_codeObject (readonly)

Attribute for field pix_display_qr_code



219
220
221
# File 'lib/stripe/resources/setup_intent.rb', line 219

def pix_display_qr_code
  @pix_display_qr_code
end

#redirect_to_urlObject (readonly)

Attribute for field redirect_to_url



221
222
223
# File 'lib/stripe/resources/setup_intent.rb', line 221

def redirect_to_url
  @redirect_to_url
end

#typeObject (readonly)

Type of the next action to perform. Refer to the other child attributes under ‘next_action` for available values. Examples include: `redirect_to_url`, `use_stripe_sdk`, `alipay_handle_redirect`, `oxxo_display_details`, or `verify_with_microdeposits`.



223
224
225
# File 'lib/stripe/resources/setup_intent.rb', line 223

def type
  @type
end

#use_stripe_sdkObject (readonly)

When confirming a SetupIntent with Stripe.js, Stripe.js depends on the contents of this dictionary to invoke authentication flows. The shape of the contents is subject to change and is only intended to be used by Stripe.js.



225
226
227
# File 'lib/stripe/resources/setup_intent.rb', line 225

def use_stripe_sdk
  @use_stripe_sdk
end

#verify_with_microdepositsObject (readonly)

Attribute for field verify_with_microdeposits



227
228
229
# File 'lib/stripe/resources/setup_intent.rb', line 227

def verify_with_microdeposits
  @verify_with_microdeposits
end

Class Method Details

.field_remappingsObject



238
239
240
# File 'lib/stripe/resources/setup_intent.rb', line 238

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



229
230
231
232
233
234
235
236
# File 'lib/stripe/resources/setup_intent.rb', line 229

def self.inner_class_types
  @inner_class_types = {
    cashapp_handle_redirect_or_display_qr_code: CashappHandleRedirectOrDisplayQrCode,
    pix_display_qr_code: PixDisplayQrCode,
    redirect_to_url: RedirectToUrl,
    verify_with_microdeposits: VerifyWithMicrodeposits,
  }
end