Class: Stripe::SetupIntent::NextAction

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: CashappHandleRedirectOrDisplayQrCode, RedirectToUrl, VerifyWithMicrodeposits

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Method Summary

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#cashapp_handle_redirect_or_display_qr_codeObject (readonly)

Attribute for field cashapp_handle_redirect_or_display_qr_code



168
169
170
# File 'lib/stripe/resources/setup_intent.rb', line 168

def cashapp_handle_redirect_or_display_qr_code
  @cashapp_handle_redirect_or_display_qr_code
end

#redirect_to_urlObject (readonly)

Attribute for field redirect_to_url



171
172
173
# File 'lib/stripe/resources/setup_intent.rb', line 171

def redirect_to_url
  @redirect_to_url
end

#typeObject (readonly)

Type of the next action to perform, one of ‘redirect_to_url`, `use_stripe_sdk`, `alipay_handle_redirect`, `oxxo_display_details`, or `verify_with_microdeposits`.



174
175
176
# File 'lib/stripe/resources/setup_intent.rb', line 174

def type
  @type
end

#use_stripe_sdkObject (readonly)

When confirming a SetupIntent with Stripe.js, Stripe.js depends on the contents of this dictionary to invoke authentication flows. The shape of the contents is subject to change and is only intended to be used by Stripe.js.



177
178
179
# File 'lib/stripe/resources/setup_intent.rb', line 177

def use_stripe_sdk
  @use_stripe_sdk
end

#verify_with_microdepositsObject (readonly)

Attribute for field verify_with_microdeposits



180
181
182
# File 'lib/stripe/resources/setup_intent.rb', line 180

def verify_with_microdeposits
  @verify_with_microdeposits
end