Class: Stripe::SetupIntent::NextAction::RedirectToUrl

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/setup_intent.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Method Summary

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#return_urlObject (readonly)

If the customer does not exit their browser while authenticating, they will be redirected to this specified URL after completion.



151
152
153
# File 'lib/stripe/resources/setup_intent.rb', line 151

def return_url
  @return_url
end

#urlObject (readonly)

The URL you must redirect your customer to in order to authenticate.



154
155
156
# File 'lib/stripe/resources/setup_intent.rb', line 154

def url
  @url
end