Class: Stripe::SetupIntent::PaymentMethodOptions::Card
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SetupIntent::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/resources/setup_intent.rb
Defined Under Namespace
Classes: MandateOptions
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#mandate_options ⇒ Object
readonly
Configuration options for setting up an eMandate for cards issued in India.
-
#network ⇒ Object
readonly
Selected network to process this SetupIntent on.
-
#request_three_d_secure ⇒ Object
readonly
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#mandate_options ⇒ Object (readonly)
Configuration options for setting up an eMandate for cards issued in India.
433 434 435 |
# File 'lib/stripe/resources/setup_intent.rb', line 433 def @mandate_options end |
#network ⇒ Object (readonly)
Selected network to process this SetupIntent on. Depends on the available networks of the card attached to the setup intent. Can be only set confirm-time.
435 436 437 |
# File 'lib/stripe/resources/setup_intent.rb', line 435 def network @network end |
#request_three_d_secure ⇒ Object (readonly)
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements. However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to automatic. Read our guide on manually requesting 3D Secure for more information on how this configuration interacts with Radar and our SCA Engine.
437 438 439 |
# File 'lib/stripe/resources/setup_intent.rb', line 437 def request_three_d_secure @request_three_d_secure end |
Class Method Details
.field_remappings ⇒ Object
443 444 445 |
# File 'lib/stripe/resources/setup_intent.rb', line 443 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
439 440 441 |
# File 'lib/stripe/resources/setup_intent.rb', line 439 def self.inner_class_types @inner_class_types = { mandate_options: MandateOptions } end |