Class: Stripe::SetupIntent::PaymentMethodOptions::Card::MandateOptions
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SetupIntent::PaymentMethodOptions::Card::MandateOptions
- Defined in:
- lib/stripe/resources/setup_intent.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount to be charged for future payments, specified in the presentment currency.
-
#amount_type ⇒ Object
readonly
One of
fixedormaximum. -
#currency ⇒ Object
readonly
Three-letter ISO currency code, in lowercase.
-
#description ⇒ Object
readonly
A description of the mandate or subscription that is meant to be displayed to the customer.
-
#end_date ⇒ Object
readonly
End date of the mandate or subscription.
-
#interval ⇒ Object
readonly
Specifies payment frequency.
-
#interval_count ⇒ Object
readonly
The number of intervals between payments.
-
#reference ⇒ Object
readonly
Unique identifier for the mandate or subscription.
-
#start_date ⇒ Object
readonly
Start date of the mandate or subscription.
-
#supported_types ⇒ Object
readonly
Specifies the type of mandates supported.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount to be charged for future payments, specified in the presentment currency.
423 424 425 |
# File 'lib/stripe/resources/setup_intent.rb', line 423 def amount @amount end |
#amount_type ⇒ Object (readonly)
One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.
425 426 427 |
# File 'lib/stripe/resources/setup_intent.rb', line 425 def amount_type @amount_type end |
#currency ⇒ Object (readonly)
Three-letter ISO currency code, in lowercase. Must be a supported currency.
427 428 429 |
# File 'lib/stripe/resources/setup_intent.rb', line 427 def currency @currency end |
#description ⇒ Object (readonly)
A description of the mandate or subscription that is meant to be displayed to the customer.
429 430 431 |
# File 'lib/stripe/resources/setup_intent.rb', line 429 def description @description end |
#end_date ⇒ Object (readonly)
End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.
431 432 433 |
# File 'lib/stripe/resources/setup_intent.rb', line 431 def end_date @end_date end |
#interval ⇒ Object (readonly)
Specifies payment frequency. One of day, week, month, year, or sporadic.
433 434 435 |
# File 'lib/stripe/resources/setup_intent.rb', line 433 def interval @interval end |
#interval_count ⇒ Object (readonly)
The number of intervals between payments. For example, interval=month and interval_count=3 indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when interval=sporadic.
435 436 437 |
# File 'lib/stripe/resources/setup_intent.rb', line 435 def interval_count @interval_count end |
#reference ⇒ Object (readonly)
Unique identifier for the mandate or subscription.
437 438 439 |
# File 'lib/stripe/resources/setup_intent.rb', line 437 def reference @reference end |
#start_date ⇒ Object (readonly)
Start date of the mandate or subscription. Start date should not be lesser than yesterday.
439 440 441 |
# File 'lib/stripe/resources/setup_intent.rb', line 439 def start_date @start_date end |
#supported_types ⇒ Object (readonly)
Specifies the type of mandates supported. Possible values are india.
441 442 443 |
# File 'lib/stripe/resources/setup_intent.rb', line 441 def supported_types @supported_types end |
Class Method Details
.field_remappings ⇒ Object
447 448 449 |
# File 'lib/stripe/resources/setup_intent.rb', line 447 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
443 444 445 |
# File 'lib/stripe/resources/setup_intent.rb', line 443 def self.inner_class_types @inner_class_types = {} end |