Class: Stripe::SetupIntent::PaymentMethodOptions::Card::MandateOptions

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/setup_intent.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments, specified in the presentment currency.



344
345
346
# File 'lib/stripe/resources/setup_intent.rb', line 344

def amount
  @amount
end

#amount_typeObject (readonly)

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



346
347
348
# File 'lib/stripe/resources/setup_intent.rb', line 346

def amount_type
  @amount_type
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



348
349
350
# File 'lib/stripe/resources/setup_intent.rb', line 348

def currency
  @currency
end

#descriptionObject (readonly)

A description of the mandate or subscription that is meant to be displayed to the customer.



350
351
352
# File 'lib/stripe/resources/setup_intent.rb', line 350

def description
  @description
end

#end_dateObject (readonly)

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



352
353
354
# File 'lib/stripe/resources/setup_intent.rb', line 352

def end_date
  @end_date
end

#intervalObject (readonly)

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



354
355
356
# File 'lib/stripe/resources/setup_intent.rb', line 354

def interval
  @interval
end

#interval_countObject (readonly)

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



356
357
358
# File 'lib/stripe/resources/setup_intent.rb', line 356

def interval_count
  @interval_count
end

#referenceObject (readonly)

Unique identifier for the mandate or subscription.



358
359
360
# File 'lib/stripe/resources/setup_intent.rb', line 358

def reference
  @reference
end

#start_dateObject (readonly)

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



360
361
362
# File 'lib/stripe/resources/setup_intent.rb', line 360

def start_date
  @start_date
end

#supported_typesObject (readonly)

Specifies the type of mandates supported. Possible values are ‘india`.



362
363
364
# File 'lib/stripe/resources/setup_intent.rb', line 362

def supported_types
  @supported_types
end

Class Method Details

.field_remappingsObject



368
369
370
# File 'lib/stripe/resources/setup_intent.rb', line 368

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



364
365
366
# File 'lib/stripe/resources/setup_intent.rb', line 364

def self.inner_class_types
  @inner_class_types = {}
end