Class: Stripe::SetupIntent::PaymentMethodOptions::Card::MandateOptions
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SetupIntent::PaymentMethodOptions::Card::MandateOptions
- Defined in:
- lib/stripe/resources/setup_intent.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount to be charged for future payments, specified in the presentment currency.
-
#amount_type ⇒ Object
readonly
One of ‘fixed` or `maximum`.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#description ⇒ Object
readonly
A description of the mandate or subscription that is meant to be displayed to the customer.
-
#end_date ⇒ Object
readonly
End date of the mandate or subscription.
-
#interval ⇒ Object
readonly
Specifies payment frequency.
-
#interval_count ⇒ Object
readonly
The number of intervals between payments.
-
#reference ⇒ Object
readonly
Unique identifier for the mandate or subscription.
-
#start_date ⇒ Object
readonly
Start date of the mandate or subscription.
-
#supported_types ⇒ Object
readonly
Specifies the type of mandates supported.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount to be charged for future payments, specified in the presentment currency.
344 345 346 |
# File 'lib/stripe/resources/setup_intent.rb', line 344 def amount @amount end |
#amount_type ⇒ Object (readonly)
One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.
346 347 348 |
# File 'lib/stripe/resources/setup_intent.rb', line 346 def amount_type @amount_type end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
348 349 350 |
# File 'lib/stripe/resources/setup_intent.rb', line 348 def currency @currency end |
#description ⇒ Object (readonly)
A description of the mandate or subscription that is meant to be displayed to the customer.
350 351 352 |
# File 'lib/stripe/resources/setup_intent.rb', line 350 def description @description end |
#end_date ⇒ Object (readonly)
End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.
352 353 354 |
# File 'lib/stripe/resources/setup_intent.rb', line 352 def end_date @end_date end |
#interval ⇒ Object (readonly)
Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.
354 355 356 |
# File 'lib/stripe/resources/setup_intent.rb', line 354 def interval @interval end |
#interval_count ⇒ Object (readonly)
The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.
356 357 358 |
# File 'lib/stripe/resources/setup_intent.rb', line 356 def interval_count @interval_count end |
#reference ⇒ Object (readonly)
Unique identifier for the mandate or subscription.
358 359 360 |
# File 'lib/stripe/resources/setup_intent.rb', line 358 def reference @reference end |
#start_date ⇒ Object (readonly)
Start date of the mandate or subscription. Start date should not be lesser than yesterday.
360 361 362 |
# File 'lib/stripe/resources/setup_intent.rb', line 360 def start_date @start_date end |
#supported_types ⇒ Object (readonly)
Specifies the type of mandates supported. Possible values are ‘india`.
362 363 364 |
# File 'lib/stripe/resources/setup_intent.rb', line 362 def supported_types @supported_types end |
Class Method Details
.field_remappings ⇒ Object
368 369 370 |
# File 'lib/stripe/resources/setup_intent.rb', line 368 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
364 365 366 |
# File 'lib/stripe/resources/setup_intent.rb', line 364 def self.inner_class_types @inner_class_types = {} end |