Class: Stripe::SetupIntent::PaymentMethodOptions::Card::MandateOptions

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/setup_intent.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Method Summary

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments.



233
234
235
# File 'lib/stripe/resources/setup_intent.rb', line 233

def amount
  @amount
end

#amount_typeObject (readonly)

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



236
237
238
# File 'lib/stripe/resources/setup_intent.rb', line 236

def amount_type
  @amount_type
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



239
240
241
# File 'lib/stripe/resources/setup_intent.rb', line 239

def currency
  @currency
end

#descriptionObject (readonly)

A description of the mandate or subscription that is meant to be displayed to the customer.



242
243
244
# File 'lib/stripe/resources/setup_intent.rb', line 242

def description
  @description
end

#end_dateObject (readonly)

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



245
246
247
# File 'lib/stripe/resources/setup_intent.rb', line 245

def end_date
  @end_date
end

#intervalObject (readonly)

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



248
249
250
# File 'lib/stripe/resources/setup_intent.rb', line 248

def interval
  @interval
end

#interval_countObject (readonly)

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



251
252
253
# File 'lib/stripe/resources/setup_intent.rb', line 251

def interval_count
  @interval_count
end

#referenceObject (readonly)

Unique identifier for the mandate or subscription.



254
255
256
# File 'lib/stripe/resources/setup_intent.rb', line 254

def reference
  @reference
end

#start_dateObject (readonly)

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



257
258
259
# File 'lib/stripe/resources/setup_intent.rb', line 257

def start_date
  @start_date
end

#supported_typesObject (readonly)

Specifies the type of mandates supported. Possible values are ‘india`.



260
261
262
# File 'lib/stripe/resources/setup_intent.rb', line 260

def supported_types
  @supported_types
end