Class: Stripe::SetupIntent::PaymentMethodOptions::Pix::MandateOptions

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/setup_intent.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments.



486
487
488
# File 'lib/stripe/resources/setup_intent.rb', line 486

def amount
  @amount
end

#amount_includes_iofObject (readonly)

Determines if the amount includes the IOF tax.



488
489
490
# File 'lib/stripe/resources/setup_intent.rb', line 488

def amount_includes_iof
  @amount_includes_iof
end

#amount_typeObject (readonly)

Type of amount.



490
491
492
# File 'lib/stripe/resources/setup_intent.rb', line 490

def amount_type
  @amount_type
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.



492
493
494
# File 'lib/stripe/resources/setup_intent.rb', line 492

def currency
  @currency
end

#end_dateObject (readonly)

Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.



494
495
496
# File 'lib/stripe/resources/setup_intent.rb', line 494

def end_date
  @end_date
end

#payment_scheduleObject (readonly)

Schedule at which the future payments will be charged.



496
497
498
# File 'lib/stripe/resources/setup_intent.rb', line 496

def payment_schedule
  @payment_schedule
end

#referenceObject (readonly)

Subscription name displayed to buyers in their bank app.



498
499
500
# File 'lib/stripe/resources/setup_intent.rb', line 498

def reference
  @reference
end

#start_dateObject (readonly)

Start date of the mandate, in ‘YYYY-MM-DD`.



500
501
502
# File 'lib/stripe/resources/setup_intent.rb', line 500

def start_date
  @start_date
end

Class Method Details

.field_remappingsObject



506
507
508
# File 'lib/stripe/resources/setup_intent.rb', line 506

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



502
503
504
# File 'lib/stripe/resources/setup_intent.rb', line 502

def self.inner_class_types
  @inner_class_types = {}
end