Class: Stripe::SetupIntent::PaymentMethodOptions::Pix::MandateOptions

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/setup_intent.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments.



473
474
475
# File 'lib/stripe/resources/setup_intent.rb', line 473

def amount
  @amount
end

#amount_includes_iofObject (readonly)

Determines if the amount includes the IOF tax.



475
476
477
# File 'lib/stripe/resources/setup_intent.rb', line 475

def amount_includes_iof
  @amount_includes_iof
end

#amount_typeObject (readonly)

Type of amount.



477
478
479
# File 'lib/stripe/resources/setup_intent.rb', line 477

def amount_type
  @amount_type
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.



479
480
481
# File 'lib/stripe/resources/setup_intent.rb', line 479

def currency
  @currency
end

#end_dateObject (readonly)

Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.



481
482
483
# File 'lib/stripe/resources/setup_intent.rb', line 481

def end_date
  @end_date
end

#payment_scheduleObject (readonly)

Schedule at which the future payments will be charged.



483
484
485
# File 'lib/stripe/resources/setup_intent.rb', line 483

def payment_schedule
  @payment_schedule
end

#referenceObject (readonly)

Subscription name displayed to buyers in their bank app.



485
486
487
# File 'lib/stripe/resources/setup_intent.rb', line 485

def reference
  @reference
end

#start_dateObject (readonly)

Start date of the mandate, in ‘YYYY-MM-DD`.



487
488
489
# File 'lib/stripe/resources/setup_intent.rb', line 487

def start_date
  @start_date
end

Class Method Details

.field_remappingsObject



493
494
495
# File 'lib/stripe/resources/setup_intent.rb', line 493

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



489
490
491
# File 'lib/stripe/resources/setup_intent.rb', line 489

def self.inner_class_types
  @inner_class_types = {}
end