Class: Stripe::SetupIntent::RetrieveParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams

Returns a new instance of RetrieveParams.



1585
1586
1587
1588
# File 'lib/stripe/resources/setup_intent.rb', line 1585

def initialize(client_secret: nil, expand: nil)
  @client_secret = client_secret
  @expand = expand
end

Instance Attribute Details

#client_secretObject

The client secret of the SetupIntent. We require this string if you use a publishable key to retrieve the SetupIntent.



1581
1582
1583
# File 'lib/stripe/resources/setup_intent.rb', line 1581

def client_secret
  @client_secret
end

#expandObject

Specifies which fields in the response should be expanded.



1583
1584
1585
# File 'lib/stripe/resources/setup_intent.rb', line 1583

def expand
  @expand
end