Class: Stripe::SetupIntent::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::RetrieveParams
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#client_secret ⇒ Object
The client secret of the SetupIntent.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
1585 1586 1587 1588 |
# File 'lib/stripe/resources/setup_intent.rb', line 1585 def initialize(client_secret: nil, expand: nil) @client_secret = client_secret @expand = end |
Instance Attribute Details
#client_secret ⇒ Object
The client secret of the SetupIntent. We require this string if you use a publishable key to retrieve the SetupIntent.
1581 1582 1583 |
# File 'lib/stripe/resources/setup_intent.rb', line 1581 def client_secret @client_secret end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1583 1584 1585 |
# File 'lib/stripe/resources/setup_intent.rb', line 1583 def @expand end |