Class: Stripe::SetupIntent::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: PaymentMethodData, PaymentMethodOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(attach_to_self: nil, customer: nil, customer_account: nil, description: nil, expand: nil, flow_directions: nil, metadata: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



2867
2868
2869
2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
# File 'lib/stripe/resources/setup_intent.rb', line 2867

def initialize(
  attach_to_self: nil,
  customer: nil,
  customer_account: nil,
  description: nil,
  expand: nil,
  flow_directions: nil,
  metadata: nil,
  payment_method: nil,
  payment_method_configuration: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil
)
  @attach_to_self = attach_to_self
  @customer = customer
  @customer_account = 
  @description = description
  @expand = expand
  @flow_directions = flow_directions
  @metadata = 
  @payment_method = payment_method
  @payment_method_configuration = payment_method_configuration
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
end

Instance Attribute Details

#attach_to_selfObject

If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.

It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.



2836
2837
2838
# File 'lib/stripe/resources/setup_intent.rb', line 2836

def attach_to_self
  @attach_to_self
end

#customerObject

ID of the Customer this SetupIntent belongs to, if one exists.

If present, the SetupIntent’s payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.



2840
2841
2842
# File 'lib/stripe/resources/setup_intent.rb', line 2840

def customer
  @customer
end

#customer_accountObject

ID of the Account this SetupIntent belongs to, if one exists.

If present, the SetupIntent’s payment method will be attached to the Account on successful setup. Payment methods attached to other Accounts cannot be used with this SetupIntent.



2844
2845
2846
# File 'lib/stripe/resources/setup_intent.rb', line 2844

def 
  @customer_account
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



2846
2847
2848
# File 'lib/stripe/resources/setup_intent.rb', line 2846

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



2848
2849
2850
# File 'lib/stripe/resources/setup_intent.rb', line 2848

def expand
  @expand
end

#flow_directionsObject

Indicates the directions of money movement for which this payment method is intended to be used.

Include ‘inbound` if you intend to use the payment method as the origin to pull funds from. Include `outbound` if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.



2852
2853
2854
# File 'lib/stripe/resources/setup_intent.rb', line 2852

def flow_directions
  @flow_directions
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2854
2855
2856
# File 'lib/stripe/resources/setup_intent.rb', line 2854

def 
  @metadata
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent. To unset this field to null, pass in an empty string.



2856
2857
2858
# File 'lib/stripe/resources/setup_intent.rb', line 2856

def payment_method
  @payment_method
end

#payment_method_configurationObject

The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this SetupIntent.



2858
2859
2860
# File 'lib/stripe/resources/setup_intent.rb', line 2858

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_dataObject

When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.



2861
2862
2863
# File 'lib/stripe/resources/setup_intent.rb', line 2861

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this SetupIntent.



2863
2864
2865
# File 'lib/stripe/resources/setup_intent.rb', line 2863

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, card) that this SetupIntent can set up. If you don’t provide this, Stripe will dynamically show relevant payment methods from your [payment method settings](dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).



2865
2866
2867
# File 'lib/stripe/resources/setup_intent.rb', line 2865

def payment_method_types
  @payment_method_types
end