Class: Stripe::SetupIntent::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::UpdateParams
- Defined in:
- lib/stripe/resources/setup_intent.rb
Defined Under Namespace
Classes: PaymentMethodData, PaymentMethodOptions
Instance Attribute Summary collapse
-
#attach_to_self ⇒ Object
If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.
-
#customer ⇒ Object
ID of the Customer this SetupIntent belongs to, if one exists.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#flow_directions ⇒ Object
Indicates the directions of money movement for which this payment method is intended to be used.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.
-
#payment_method_configuration ⇒ Object
The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this SetupIntent.
-
#payment_method_data ⇒ Object
When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.
-
#payment_method_options ⇒ Object
Payment method-specific configuration for this SetupIntent.
-
#payment_method_types ⇒ Object
The list of payment method types (for example, card) that this SetupIntent can set up.
Instance Method Summary collapse
-
#initialize(attach_to_self: nil, customer: nil, description: nil, expand: nil, flow_directions: nil, metadata: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(attach_to_self: nil, customer: nil, description: nil, expand: nil, flow_directions: nil, metadata: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
2647 2648 2649 2650 2651 2652 2653 2654 2655 2656 2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 |
# File 'lib/stripe/resources/setup_intent.rb', line 2647 def initialize( attach_to_self: nil, customer: nil, description: nil, expand: nil, flow_directions: nil, metadata: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil ) @attach_to_self = attach_to_self @customer = customer @description = description @expand = @flow_directions = flow_directions @metadata = @payment_method = payment_method @payment_method_configuration = payment_method_configuration @payment_method_data = payment_method_data @payment_method_options = @payment_method_types = payment_method_types end |
Instance Attribute Details
#attach_to_self ⇒ Object
If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.
It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.
2620 2621 2622 |
# File 'lib/stripe/resources/setup_intent.rb', line 2620 def attach_to_self @attach_to_self end |
#customer ⇒ Object
ID of the Customer this SetupIntent belongs to, if one exists.
If present, the SetupIntent’s payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.
2624 2625 2626 |
# File 'lib/stripe/resources/setup_intent.rb', line 2624 def customer @customer end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
2626 2627 2628 |
# File 'lib/stripe/resources/setup_intent.rb', line 2626 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2628 2629 2630 |
# File 'lib/stripe/resources/setup_intent.rb', line 2628 def @expand end |
#flow_directions ⇒ Object
Indicates the directions of money movement for which this payment method is intended to be used.
Include ‘inbound` if you intend to use the payment method as the origin to pull funds from. Include `outbound` if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.
2632 2633 2634 |
# File 'lib/stripe/resources/setup_intent.rb', line 2632 def flow_directions @flow_directions end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2634 2635 2636 |
# File 'lib/stripe/resources/setup_intent.rb', line 2634 def @metadata end |
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent. To unset this field to null, pass in an empty string.
2636 2637 2638 |
# File 'lib/stripe/resources/setup_intent.rb', line 2636 def payment_method @payment_method end |
#payment_method_configuration ⇒ Object
The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this SetupIntent.
2638 2639 2640 |
# File 'lib/stripe/resources/setup_intent.rb', line 2638 def payment_method_configuration @payment_method_configuration end |
#payment_method_data ⇒ Object
When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.
2641 2642 2643 |
# File 'lib/stripe/resources/setup_intent.rb', line 2641 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment method-specific configuration for this SetupIntent.
2643 2644 2645 |
# File 'lib/stripe/resources/setup_intent.rb', line 2643 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types (for example, card) that this SetupIntent can set up. If you don’t provide this, Stripe will dynamically show relevant payment methods from your [payment method settings](dashboard.stripe.com/settings/payment_methods).
2645 2646 2647 |
# File 'lib/stripe/resources/setup_intent.rb', line 2645 def payment_method_types @payment_method_types end |