Class: Stripe::SetupIntent::UpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::UpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 |
# File 'lib/stripe/resources/setup_intent.rb', line 2286 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
2274 2275 2276 |
# File 'lib/stripe/resources/setup_intent.rb', line 2274 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
2276 2277 2278 |
# File 'lib/stripe/resources/setup_intent.rb', line 2276 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
2278 2279 2280 |
# File 'lib/stripe/resources/setup_intent.rb', line 2278 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
2280 2281 2282 |
# File 'lib/stripe/resources/setup_intent.rb', line 2280 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
2282 2283 2284 |
# File 'lib/stripe/resources/setup_intent.rb', line 2282 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
2284 2285 2286 |
# File 'lib/stripe/resources/setup_intent.rb', line 2284 def suffix @suffix end |