Class: Stripe::SetupIntent::UpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
# File 'lib/stripe/resources/setup_intent.rb', line 1918

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1906
1907
1908
# File 'lib/stripe/resources/setup_intent.rb', line 1906

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



1908
1909
1910
# File 'lib/stripe/resources/setup_intent.rb', line 1908

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



1910
1911
1912
# File 'lib/stripe/resources/setup_intent.rb', line 1910

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



1912
1913
1914
# File 'lib/stripe/resources/setup_intent.rb', line 1912

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



1914
1915
1916
# File 'lib/stripe/resources/setup_intent.rb', line 1914

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



1916
1917
1918
# File 'lib/stripe/resources/setup_intent.rb', line 1916

def suffix
  @suffix
end