Class: Stripe::SetupIntent::UpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
# File 'lib/stripe/resources/setup_intent.rb', line 1690

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1678
1679
1680
# File 'lib/stripe/resources/setup_intent.rb', line 1678

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



1680
1681
1682
# File 'lib/stripe/resources/setup_intent.rb', line 1680

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



1682
1683
1684
# File 'lib/stripe/resources/setup_intent.rb', line 1682

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



1684
1685
1686
# File 'lib/stripe/resources/setup_intent.rb', line 1684

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



1686
1687
1688
# File 'lib/stripe/resources/setup_intent.rb', line 1686

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



1688
1689
1690
# File 'lib/stripe/resources/setup_intent.rb', line 1688

def suffix
  @suffix
end