Class: Stripe::SetupIntent::UpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
# File 'lib/stripe/resources/setup_intent.rb', line 1817

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1805
1806
1807
# File 'lib/stripe/resources/setup_intent.rb', line 1805

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



1807
1808
1809
# File 'lib/stripe/resources/setup_intent.rb', line 1807

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



1809
1810
1811
# File 'lib/stripe/resources/setup_intent.rb', line 1809

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



1811
1812
1813
# File 'lib/stripe/resources/setup_intent.rb', line 1811

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



1813
1814
1815
# File 'lib/stripe/resources/setup_intent.rb', line 1813

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



1815
1816
1817
# File 'lib/stripe/resources/setup_intent.rb', line 1815

def suffix
  @suffix
end