Class: Stripe::SetupIntent::UpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::UpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 |
# File 'lib/stripe/resources/setup_intent.rb', line 1589 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1577 1578 1579 |
# File 'lib/stripe/resources/setup_intent.rb', line 1577 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
1579 1580 1581 |
# File 'lib/stripe/resources/setup_intent.rb', line 1579 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
1581 1582 1583 |
# File 'lib/stripe/resources/setup_intent.rb', line 1581 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
1583 1584 1585 |
# File 'lib/stripe/resources/setup_intent.rb', line 1583 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
1585 1586 1587 |
# File 'lib/stripe/resources/setup_intent.rb', line 1585 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
1587 1588 1589 |
# File 'lib/stripe/resources/setup_intent.rb', line 1587 def suffix @suffix end |