Class: Stripe::SetupIntent::UpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
# File 'lib/stripe/resources/setup_intent.rb', line 1909

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1897
1898
1899
# File 'lib/stripe/resources/setup_intent.rb', line 1897

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



1899
1900
1901
# File 'lib/stripe/resources/setup_intent.rb', line 1899

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



1901
1902
1903
# File 'lib/stripe/resources/setup_intent.rb', line 1901

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



1903
1904
1905
# File 'lib/stripe/resources/setup_intent.rb', line 1903

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



1905
1906
1907
# File 'lib/stripe/resources/setup_intent.rb', line 1905

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



1907
1908
1909
# File 'lib/stripe/resources/setup_intent.rb', line 1907

def suffix
  @suffix
end