Class: Stripe::SetupIntent::UpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::UpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
1909 1910 1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 |
# File 'lib/stripe/resources/setup_intent.rb', line 1909 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1897 1898 1899 |
# File 'lib/stripe/resources/setup_intent.rb', line 1897 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
1899 1900 1901 |
# File 'lib/stripe/resources/setup_intent.rb', line 1899 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
1901 1902 1903 |
# File 'lib/stripe/resources/setup_intent.rb', line 1901 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
1903 1904 1905 |
# File 'lib/stripe/resources/setup_intent.rb', line 1903 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
1905 1906 1907 |
# File 'lib/stripe/resources/setup_intent.rb', line 1905 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
1907 1908 1909 |
# File 'lib/stripe/resources/setup_intent.rb', line 1907 def suffix @suffix end |