Class: Stripe::SetupIntent::UpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
# File 'lib/stripe/resources/setup_intent.rb', line 1671

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1659
1660
1661
# File 'lib/stripe/resources/setup_intent.rb', line 1659

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



1661
1662
1663
# File 'lib/stripe/resources/setup_intent.rb', line 1661

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



1663
1664
1665
# File 'lib/stripe/resources/setup_intent.rb', line 1663

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



1665
1666
1667
# File 'lib/stripe/resources/setup_intent.rb', line 1665

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



1667
1668
1669
# File 'lib/stripe/resources/setup_intent.rb', line 1667

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



1669
1670
1671
# File 'lib/stripe/resources/setup_intent.rb', line 1669

def suffix
  @suffix
end