Class: Stripe::SetupIntent::UpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::UpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 |
# File 'lib/stripe/resources/setup_intent.rb', line 1671 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1659 1660 1661 |
# File 'lib/stripe/resources/setup_intent.rb', line 1659 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
1661 1662 1663 |
# File 'lib/stripe/resources/setup_intent.rb', line 1661 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
1663 1664 1665 |
# File 'lib/stripe/resources/setup_intent.rb', line 1663 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
1665 1666 1667 |
# File 'lib/stripe/resources/setup_intent.rb', line 1665 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
1667 1668 1669 |
# File 'lib/stripe/resources/setup_intent.rb', line 1667 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
1669 1670 1671 |
# File 'lib/stripe/resources/setup_intent.rb', line 1669 def suffix @suffix end |