Class: Stripe::SetupIntent::UpdateParams::PaymentMethodOptions::Card::ThreeDSecure::NetworkOptions::CartesBancaires

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(cb_avalgo: nil, cb_exemption: nil, cb_score: nil) ⇒ CartesBancaires

Returns a new instance of CartesBancaires.



2460
2461
2462
2463
2464
# File 'lib/stripe/resources/setup_intent.rb', line 2460

def initialize(cb_avalgo: nil, cb_exemption: nil, cb_score: nil)
  @cb_avalgo = cb_avalgo
  @cb_exemption = cb_exemption
  @cb_score = cb_score
end

Instance Attribute Details

#cb_avalgoObject

The cryptogram calculation algorithm used by the card Issuer’s ACS to calculate the Authentication cryptogram. Also known as ‘cavvAlgorithm`. messageExtension: CB-AVALGO



2450
2451
2452
# File 'lib/stripe/resources/setup_intent.rb', line 2450

def cb_avalgo
  @cb_avalgo
end

#cb_exemptionObject

The exemption indicator returned from Cartes Bancaires in the ARes. message extension: CB-EXEMPTION; string (4 characters) This is a 3 byte bitmap (low significant byte first and most significant bit first) that has been Base64 encoded



2455
2456
2457
# File 'lib/stripe/resources/setup_intent.rb', line 2455

def cb_exemption
  @cb_exemption
end

#cb_scoreObject

The risk score returned from Cartes Bancaires in the ARes. message extension: CB-SCORE; numeric value 0-99



2458
2459
2460
# File 'lib/stripe/resources/setup_intent.rb', line 2458

def cb_score
  @cb_score
end