Class: Stripe::SetupIntent::UpdateParams::PaymentMethodOptions::Klarna

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: OnDemand, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil) ⇒ Klarna

Returns a new instance of Klarna.



2292
2293
2294
2295
2296
2297
# File 'lib/stripe/resources/setup_intent.rb', line 2292

def initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil)
  @currency = currency
  @on_demand = on_demand
  @preferred_locale = preferred_locale
  @subscriptions = subscriptions
end

Instance Attribute Details

#currencyObject

The currency of the SetupIntent. Three letter ISO currency code.



2284
2285
2286
# File 'lib/stripe/resources/setup_intent.rb', line 2284

def currency
  @currency
end

#on_demandObject

On-demand details if setting up a payment method for on-demand payments.



2286
2287
2288
# File 'lib/stripe/resources/setup_intent.rb', line 2286

def on_demand
  @on_demand
end

#preferred_localeObject

Preferred language of the Klarna authorization page that the customer is redirected to



2288
2289
2290
# File 'lib/stripe/resources/setup_intent.rb', line 2288

def preferred_locale
  @preferred_locale
end

#subscriptionsObject

Subscription details if setting up or charging a subscription



2290
2291
2292
# File 'lib/stripe/resources/setup_intent.rb', line 2290

def subscriptions
  @subscriptions
end