Class: Stripe::SetupIntent::UpdateParams::PaymentMethodOptions::Klarna

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: OnDemand, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil) ⇒ Klarna

Returns a new instance of Klarna.



2606
2607
2608
2609
2610
2611
# File 'lib/stripe/resources/setup_intent.rb', line 2606

def initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil)
  @currency = currency
  @on_demand = on_demand
  @preferred_locale = preferred_locale
  @subscriptions = subscriptions
end

Instance Attribute Details

#currencyObject

The currency of the SetupIntent. Three letter ISO currency code.



2598
2599
2600
# File 'lib/stripe/resources/setup_intent.rb', line 2598

def currency
  @currency
end

#on_demandObject

On-demand details if setting up a payment method for on-demand payments.



2600
2601
2602
# File 'lib/stripe/resources/setup_intent.rb', line 2600

def on_demand
  @on_demand
end

#preferred_localeObject

Preferred language of the Klarna authorization page that the customer is redirected to



2602
2603
2604
# File 'lib/stripe/resources/setup_intent.rb', line 2602

def preferred_locale
  @preferred_locale
end

#subscriptionsObject

Subscription details if setting up or charging a subscription



2604
2605
2606
# File 'lib/stripe/resources/setup_intent.rb', line 2604

def subscriptions
  @subscriptions
end