Class: Stripe::SetupIntent::UpdateParams::PaymentMethodOptions::Klarna::OnDemand
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::UpdateParams::PaymentMethodOptions::Klarna::OnDemand
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#average_amount ⇒ Object
Your average amount value.
-
#maximum_amount ⇒ Object
The maximum value you may charge a customer per purchase.
-
#minimum_amount ⇒ Object
The lowest or minimum value you may charge a customer per purchase.
-
#purchase_interval ⇒ Object
Interval at which the customer is making purchases.
-
#purchase_interval_count ⇒ Object
The number of ‘purchase_interval` between charges.
Instance Method Summary collapse
-
#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand
constructor
A new instance of OnDemand.
Methods inherited from RequestParams
Constructor Details
#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand
Returns a new instance of OnDemand.
2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 |
# File 'lib/stripe/resources/setup_intent.rb', line 2231 def initialize( average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil ) @average_amount = average_amount @maximum_amount = maximum_amount @minimum_amount = minimum_amount @purchase_interval = purchase_interval @purchase_interval_count = purchase_interval_count end |
Instance Attribute Details
#average_amount ⇒ Object
Your average amount value. You can use a value across your customer base, or segment based on customer type, country, etc.
2221 2222 2223 |
# File 'lib/stripe/resources/setup_intent.rb', line 2221 def average_amount @average_amount end |
#maximum_amount ⇒ Object
The maximum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.
2223 2224 2225 |
# File 'lib/stripe/resources/setup_intent.rb', line 2223 def maximum_amount @maximum_amount end |
#minimum_amount ⇒ Object
The lowest or minimum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.
2225 2226 2227 |
# File 'lib/stripe/resources/setup_intent.rb', line 2225 def minimum_amount @minimum_amount end |
#purchase_interval ⇒ Object
Interval at which the customer is making purchases
2227 2228 2229 |
# File 'lib/stripe/resources/setup_intent.rb', line 2227 def purchase_interval @purchase_interval end |
#purchase_interval_count ⇒ Object
The number of ‘purchase_interval` between charges
2229 2230 2231 |
# File 'lib/stripe/resources/setup_intent.rb', line 2229 def purchase_interval_count @purchase_interval_count end |