Class: Stripe::SetupIntent::UpdateParams::PaymentMethodOptions::Paypal

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_agreement_id: nil, currency: nil, subsellers: nil) ⇒ Paypal

Returns a new instance of Paypal.



2419
2420
2421
2422
2423
# File 'lib/stripe/resources/setup_intent.rb', line 2419

def initialize(billing_agreement_id: nil, currency: nil, subsellers: nil)
  @billing_agreement_id = billing_agreement_id
  @currency = currency
  @subsellers = subsellers
end

Instance Attribute Details

#billing_agreement_idObject

The PayPal Billing Agreement ID (BAID). This is an ID generated by PayPal which represents the mandate between the merchant and the customer.



2413
2414
2415
# File 'lib/stripe/resources/setup_intent.rb', line 2413

def billing_agreement_id
  @billing_agreement_id
end

#currencyObject

Attribute for param field currency



2415
2416
2417
# File 'lib/stripe/resources/setup_intent.rb', line 2415

def currency
  @currency
end

#subsellersObject

The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when [separate charges and transfers](stripe.com/docs/connect/separate-charges-and-transfers) are used.



2417
2418
2419
# File 'lib/stripe/resources/setup_intent.rb', line 2417

def subsellers
  @subsellers
end