Class: Stripe::SetupIntent::UpdateParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
# File 'lib/stripe/resources/setup_intent.rb', line 2786

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil,
  start_date: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
  @start_date = start_date
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when ‘amount_type` is `fixed`.



2766
2767
2768
# File 'lib/stripe/resources/setup_intent.rb', line 2766

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.



2769
2770
2771
# File 'lib/stripe/resources/setup_intent.rb', line 2769

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



2772
2773
2774
# File 'lib/stripe/resources/setup_intent.rb', line 2772

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected.



2775
2776
2777
# File 'lib/stripe/resources/setup_intent.rb', line 2775

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.



2778
2779
2780
# File 'lib/stripe/resources/setup_intent.rb', line 2778

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Defaults to retail.



2781
2782
2783
# File 'lib/stripe/resources/setup_intent.rb', line 2781

def purpose
  @purpose
end

#start_dateObject

Date, in YYYY-MM-DD format, from which payments will be collected. Defaults to confirmation time.



2784
2785
2786
# File 'lib/stripe/resources/setup_intent.rb', line 2784

def start_date
  @start_date
end