Class: Stripe::SetupIntent::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/resources/setup_intent.rb
Defined Under Namespace
Classes: Filters, ManualEntry
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#manual_entry ⇒ Object
Customize manual entry behavior.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 |
# File 'lib/stripe/resources/setup_intent.rb', line 2544 def initialize( filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil ) @filters = filters @manual_entry = manual_entry @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
2534 2535 2536 |
# File 'lib/stripe/resources/setup_intent.rb', line 2534 def filters @filters end |
#manual_entry ⇒ Object
Customize manual entry behavior
2536 2537 2538 |
# File 'lib/stripe/resources/setup_intent.rb', line 2536 def manual_entry @manual_entry end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
2538 2539 2540 |
# File 'lib/stripe/resources/setup_intent.rb', line 2538 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
2540 2541 2542 |
# File 'lib/stripe/resources/setup_intent.rb', line 2540 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
2542 2543 2544 |
# File 'lib/stripe/resources/setup_intent.rb', line 2542 def return_url @return_url end |