Class: Stripe::SetupIntent::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



2867
2868
2869
2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
# File 'lib/stripe/resources/setup_intent.rb', line 2867

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method



2853
2854
2855
# File 'lib/stripe/resources/setup_intent.rb', line 2853

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



2856
2857
2858
# File 'lib/stripe/resources/setup_intent.rb', line 2856

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



2859
2860
2861
# File 'lib/stripe/resources/setup_intent.rb', line 2859

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



2862
2863
2864
# File 'lib/stripe/resources/setup_intent.rb', line 2862

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



2865
2866
2867
# File 'lib/stripe/resources/setup_intent.rb', line 2865

def return_url
  @return_url
end