Class: Stripe::SetupIntent::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



2533
2534
2535
2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
# File 'lib/stripe/resources/setup_intent.rb', line 2533

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method



2523
2524
2525
# File 'lib/stripe/resources/setup_intent.rb', line 2523

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



2525
2526
2527
# File 'lib/stripe/resources/setup_intent.rb', line 2525

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



2527
2528
2529
# File 'lib/stripe/resources/setup_intent.rb', line 2527

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



2529
2530
2531
# File 'lib/stripe/resources/setup_intent.rb', line 2529

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



2531
2532
2533
# File 'lib/stripe/resources/setup_intent.rb', line 2531

def return_url
  @return_url
end