Class: Stripe::SetupIntent::VerifyMicrodepositsParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntent::VerifyMicrodepositsParams
- Defined in:
- lib/stripe/resources/setup_intent.rb
Instance Attribute Summary collapse
-
#amounts ⇒ Object
Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.
-
#descriptor_code ⇒ Object
A six-character code starting with SM present in the microdeposit sent to the bank account.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams
constructor
A new instance of VerifyMicrodepositsParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams
Returns a new instance of VerifyMicrodepositsParams.
4598 4599 4600 4601 4602 |
# File 'lib/stripe/resources/setup_intent.rb', line 4598 def initialize(amounts: nil, descriptor_code: nil, expand: nil) @amounts = amounts @descriptor_code = descriptor_code @expand = end |
Instance Attribute Details
#amounts ⇒ Object
Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.
4592 4593 4594 |
# File 'lib/stripe/resources/setup_intent.rb', line 4592 def amounts @amounts end |
#descriptor_code ⇒ Object
A six-character code starting with SM present in the microdeposit sent to the bank account.
4594 4595 4596 |
# File 'lib/stripe/resources/setup_intent.rb', line 4594 def descriptor_code @descriptor_code end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
4596 4597 4598 |
# File 'lib/stripe/resources/setup_intent.rb', line 4596 def @expand end |