Class: Stripe::SetupIntent::VerifyMicrodepositsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams

Returns a new instance of VerifyMicrodepositsParams.



3563
3564
3565
3566
3567
# File 'lib/stripe/resources/setup_intent.rb', line 3563

def initialize(amounts: nil, descriptor_code: nil, expand: nil)
  @amounts = amounts
  @descriptor_code = descriptor_code
  @expand = expand
end

Instance Attribute Details

#amountsObject

Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.



3557
3558
3559
# File 'lib/stripe/resources/setup_intent.rb', line 3557

def amounts
  @amounts
end

#descriptor_codeObject

A six-character code starting with SM present in the microdeposit sent to the bank account.



3559
3560
3561
# File 'lib/stripe/resources/setup_intent.rb', line 3559

def descriptor_code
  @descriptor_code
end

#expandObject

Specifies which fields in the response should be expanded.



3561
3562
3563
# File 'lib/stripe/resources/setup_intent.rb', line 3561

def expand
  @expand
end