Class: Stripe::SetupIntent::VerifyMicrodepositsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams

Returns a new instance of VerifyMicrodepositsParams.



3846
3847
3848
3849
3850
# File 'lib/stripe/resources/setup_intent.rb', line 3846

def initialize(amounts: nil, descriptor_code: nil, expand: nil)
  @amounts = amounts
  @descriptor_code = descriptor_code
  @expand = expand
end

Instance Attribute Details

#amountsObject

Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.



3840
3841
3842
# File 'lib/stripe/resources/setup_intent.rb', line 3840

def amounts
  @amounts
end

#descriptor_codeObject

A six-character code starting with SM present in the microdeposit sent to the bank account.



3842
3843
3844
# File 'lib/stripe/resources/setup_intent.rb', line 3842

def descriptor_code
  @descriptor_code
end

#expandObject

Specifies which fields in the response should be expanded.



3844
3845
3846
# File 'lib/stripe/resources/setup_intent.rb', line 3844

def expand
  @expand
end