Class: Stripe::SetupIntent::VerifyMicrodepositsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams

Returns a new instance of VerifyMicrodepositsParams.



4034
4035
4036
4037
4038
# File 'lib/stripe/resources/setup_intent.rb', line 4034

def initialize(amounts: nil, descriptor_code: nil, expand: nil)
  @amounts = amounts
  @descriptor_code = descriptor_code
  @expand = expand
end

Instance Attribute Details

#amountsObject

Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.



4028
4029
4030
# File 'lib/stripe/resources/setup_intent.rb', line 4028

def amounts
  @amounts
end

#descriptor_codeObject

A six-character code starting with SM present in the microdeposit sent to the bank account.



4030
4031
4032
# File 'lib/stripe/resources/setup_intent.rb', line 4030

def descriptor_code
  @descriptor_code
end

#expandObject

Specifies which fields in the response should be expanded.



4032
4033
4034
# File 'lib/stripe/resources/setup_intent.rb', line 4032

def expand
  @expand
end