Class: Stripe::SetupIntent::VerifyMicrodepositsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/setup_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams

Returns a new instance of VerifyMicrodepositsParams.



4316
4317
4318
4319
4320
# File 'lib/stripe/resources/setup_intent.rb', line 4316

def initialize(amounts: nil, descriptor_code: nil, expand: nil)
  @amounts = amounts
  @descriptor_code = descriptor_code
  @expand = expand
end

Instance Attribute Details

#amountsObject

Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.



4308
4309
4310
# File 'lib/stripe/resources/setup_intent.rb', line 4308

def amounts
  @amounts
end

#descriptor_codeObject

A six-character code starting with SM present in the microdeposit sent to the bank account.



4311
4312
4313
# File 'lib/stripe/resources/setup_intent.rb', line 4311

def descriptor_code
  @descriptor_code
end

#expandObject

Specifies which fields in the response should be expanded.



4314
4315
4316
# File 'lib/stripe/resources/setup_intent.rb', line 4314

def expand
  @expand
end