Class: Stripe::SetupIntentConfirmParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/setup_intent_confirm_params.rb

Defined Under Namespace

Classes: MandateData, PaymentMethodData, PaymentMethodOptions, SetupDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(confirmation_token: nil, expand: nil, mandate_data: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_details: nil, use_stripe_sdk: nil) ⇒ SetupIntentConfirmParams

Returns a new instance of SetupIntentConfirmParams.



1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1369

def initialize(
  confirmation_token: nil,
  expand: nil,
  mandate_data: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  return_url: nil,
  setup_details: nil,
  use_stripe_sdk: nil
)
  @confirmation_token = confirmation_token
  @expand = expand
  @mandate_data = mandate_data
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @return_url = return_url
  @setup_details = setup_details
  @use_stripe_sdk = use_stripe_sdk
end

Instance Attribute Details

#confirmation_tokenObject

ID of the ConfirmationToken used to confirm this SetupIntent.

If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.



1348
1349
1350
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1348

def confirmation_token
  @confirmation_token
end

#expandObject

Specifies which fields in the response should be expanded.



1350
1351
1352
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1350

def expand
  @expand
end

#mandate_dataObject

Attribute for param field mandate_data



1352
1353
1354
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1352

def mandate_data
  @mandate_data
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.



1354
1355
1356
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1354

def payment_method
  @payment_method
end

#payment_method_dataObject

When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](docs.stripe.com/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.



1357
1358
1359
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1357

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this SetupIntent.



1359
1360
1361
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1359

def payment_method_options
  @payment_method_options
end

#return_urlObject

The URL to redirect your customer back to after they authenticate on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.



1363
1364
1365
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1363

def return_url
  @return_url
end

#setup_detailsObject

Provides industry-specific information about the SetupIntent.



1365
1366
1367
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1365

def setup_details
  @setup_details
end

#use_stripe_sdkObject

Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.



1367
1368
1369
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1367

def use_stripe_sdk
  @use_stripe_sdk
end