Class: Stripe::SetupIntentConfirmParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentConfirmParams
- Defined in:
- lib/stripe/params/setup_intent_confirm_params.rb
Defined Under Namespace
Classes: MandateData, PaymentMethodData, PaymentMethodOptions
Instance Attribute Summary collapse
-
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this SetupIntent.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#mandate_data ⇒ Object
Attribute for param field mandate_data.
-
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.
-
#payment_method_data ⇒ Object
When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](docs.stripe.com/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.
-
#payment_method_options ⇒ Object
Payment method-specific configuration for this SetupIntent.
-
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate on the payment method’s app or site.
-
#use_stripe_sdk ⇒ Object
Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
Instance Method Summary collapse
-
#initialize(confirmation_token: nil, expand: nil, mandate_data: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, use_stripe_sdk: nil) ⇒ SetupIntentConfirmParams
constructor
A new instance of SetupIntentConfirmParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(confirmation_token: nil, expand: nil, mandate_data: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, use_stripe_sdk: nil) ⇒ SetupIntentConfirmParams
Returns a new instance of SetupIntentConfirmParams.
1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1321 def initialize( confirmation_token: nil, expand: nil, mandate_data: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, use_stripe_sdk: nil ) @confirmation_token = confirmation_token @expand = @mandate_data = mandate_data @payment_method = payment_method @payment_method_data = payment_method_data @payment_method_options = @return_url = return_url @use_stripe_sdk = use_stripe_sdk end |
Instance Attribute Details
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this SetupIntent.
If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.
1302 1303 1304 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1302 def confirmation_token @confirmation_token end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1304 1305 1306 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1304 def @expand end |
#mandate_data ⇒ Object
Attribute for param field mandate_data
1306 1307 1308 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1306 def mandate_data @mandate_data end |
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.
1308 1309 1310 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1308 def payment_method @payment_method end |
#payment_method_data ⇒ Object
When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](docs.stripe.com/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.
1311 1312 1313 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1311 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment method-specific configuration for this SetupIntent.
1313 1314 1315 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1313 def @payment_method_options end |
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.
1317 1318 1319 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1317 def return_url @return_url end |
#use_stripe_sdk ⇒ Object
Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
1319 1320 1321 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1319 def use_stripe_sdk @use_stripe_sdk end |