Class: Stripe::SetupIntentConfirmParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/setup_intent_confirm_params.rb

Defined Under Namespace

Classes: MandateData, PaymentMethodData, PaymentMethodOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(confirmation_token: nil, expand: nil, mandate_data: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, use_stripe_sdk: nil) ⇒ SetupIntentConfirmParams

Returns a new instance of SetupIntentConfirmParams.



1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1160

def initialize(
  confirmation_token: nil,
  expand: nil,
  mandate_data: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  return_url: nil,
  use_stripe_sdk: nil
)
  @confirmation_token = confirmation_token
  @expand = expand
  @mandate_data = mandate_data
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @return_url = return_url
  @use_stripe_sdk = use_stripe_sdk
end

Instance Attribute Details

#confirmation_tokenObject

ID of the ConfirmationToken used to confirm this SetupIntent.

If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.



1141
1142
1143
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1141

def confirmation_token
  @confirmation_token
end

#expandObject

Specifies which fields in the response should be expanded.



1143
1144
1145
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1143

def expand
  @expand
end

#mandate_dataObject

Attribute for param field mandate_data



1145
1146
1147
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1145

def mandate_data
  @mandate_data
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.



1147
1148
1149
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1147

def payment_method
  @payment_method
end

#payment_method_dataObject

When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](docs.stripe.com/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.



1150
1151
1152
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1150

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this SetupIntent.



1152
1153
1154
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1152

def payment_method_options
  @payment_method_options
end

#return_urlObject

The URL to redirect your customer back to after they authenticate on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.



1156
1157
1158
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1156

def return_url
  @return_url
end

#use_stripe_sdkObject

Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.



1158
1159
1160
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1158

def use_stripe_sdk
  @use_stripe_sdk
end