Class: Stripe::SetupIntentConfirmParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentConfirmParams
- Defined in:
- lib/stripe/params/setup_intent_confirm_params.rb
Defined Under Namespace
Classes: MandateData, PaymentMethodData, PaymentMethodOptions, SetupDetails
Instance Attribute Summary collapse
-
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this SetupIntent.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#mandate_data ⇒ Object
Attribute for param field mandate_data.
-
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.
-
#payment_method_data ⇒ Object
When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.
-
#payment_method_options ⇒ Object
Payment method-specific configuration for this SetupIntent.
-
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate on the payment method’s app or site.
-
#setup_details ⇒ Object
Provides industry-specific information about the SetupIntent.
-
#use_stripe_sdk ⇒ Object
Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
Instance Method Summary collapse
-
#initialize(confirmation_token: nil, expand: nil, mandate_data: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_details: nil, use_stripe_sdk: nil) ⇒ SetupIntentConfirmParams
constructor
A new instance of SetupIntentConfirmParams.
Methods inherited from RequestParams
Constructor Details
#initialize(confirmation_token: nil, expand: nil, mandate_data: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_details: nil, use_stripe_sdk: nil) ⇒ SetupIntentConfirmParams
Returns a new instance of SetupIntentConfirmParams.
1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1279 def initialize( confirmation_token: nil, expand: nil, mandate_data: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_details: nil, use_stripe_sdk: nil ) @confirmation_token = confirmation_token @expand = @mandate_data = mandate_data @payment_method = payment_method @payment_method_data = payment_method_data @payment_method_options = @return_url = return_url @setup_details = setup_details @use_stripe_sdk = use_stripe_sdk end |
Instance Attribute Details
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this SetupIntent.
If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.
1258 1259 1260 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1258 def confirmation_token @confirmation_token end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1260 1261 1262 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1260 def @expand end |
#mandate_data ⇒ Object
Attribute for param field mandate_data
1262 1263 1264 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1262 def mandate_data @mandate_data end |
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.
1264 1265 1266 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1264 def payment_method @payment_method end |
#payment_method_data ⇒ Object
When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.
1267 1268 1269 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1267 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment method-specific configuration for this SetupIntent.
1269 1270 1271 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1269 def @payment_method_options end |
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.
1273 1274 1275 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1273 def return_url @return_url end |
#setup_details ⇒ Object
Provides industry-specific information about the SetupIntent.
1275 1276 1277 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1275 def setup_details @setup_details end |
#use_stripe_sdk ⇒ Object
Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
1277 1278 1279 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1277 def use_stripe_sdk @use_stripe_sdk end |