Class: Stripe::SetupIntentConfirmParams::PaymentMethodData::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



348
349
350
351
352
353
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 348

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



340
341
342
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 340

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



342
343
344
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 342

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



344
345
346
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 344

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



346
347
348
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 346

def end_date
  @end_date
end