Class: Stripe::SetupIntentConfirmParams::PaymentMethodOptions::Card::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentConfirmParams::PaymentMethodOptions::Card::MandateOptions
- Defined in:
- lib/stripe/params/setup_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments, specified in the presentment currency.
-
#amount_type ⇒ Object
One of
fixedormaximum. -
#currency ⇒ Object
Currency in which future payments will be charged.
-
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
-
#end_date ⇒ Object
End date of the mandate or subscription.
-
#interval ⇒ Object
Specifies payment frequency.
-
#interval_count ⇒ Object
The number of intervals between payments.
-
#reference ⇒ Object
Unique identifier for the mandate or subscription.
-
#start_date ⇒ Object
Start date of the mandate or subscription.
-
#supported_types ⇒ Object
Specifies the type of mandates supported.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, currency: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_type: nil, currency: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 823 def initialize( amount: nil, amount_type: nil, currency: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil ) @amount = amount @amount_type = amount_type @currency = currency @description = description @end_date = end_date @interval = interval @interval_count = interval_count @reference = reference @start_date = start_date @supported_types = supported_types end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments, specified in the presentment currency.
803 804 805 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 803 def amount @amount end |
#amount_type ⇒ Object
One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.
805 806 807 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 805 def amount_type @amount_type end |
#currency ⇒ Object
Currency in which future payments will be charged. Three-letter ISO currency code, in lowercase. Must be a supported currency.
807 808 809 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 807 def currency @currency end |
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
809 810 811 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 809 def description @description end |
#end_date ⇒ Object
End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.
811 812 813 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 811 def end_date @end_date end |
#interval ⇒ Object
Specifies payment frequency. One of day, week, month, year, or sporadic.
813 814 815 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 813 def interval @interval end |
#interval_count ⇒ Object
The number of intervals between payments. For example, interval=month and interval_count=3 indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when interval=sporadic.
815 816 817 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 815 def interval_count @interval_count end |
#reference ⇒ Object
Unique identifier for the mandate or subscription.
817 818 819 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 817 def reference @reference end |
#start_date ⇒ Object
Start date of the mandate or subscription. Start date should not be lesser than yesterday.
819 820 821 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 819 def start_date @start_date end |
#supported_types ⇒ Object
Specifies the type of mandates supported. Possible values are india.
821 822 823 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 821 def supported_types @supported_types end |