Class: Stripe::SetupIntentConfirmParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, currency: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 800

def initialize(
  amount: nil,
  amount_type: nil,
  currency: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @currency = currency
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments, specified in the presentment currency.



780
781
782
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 780

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



782
783
784
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 782

def amount_type
  @amount_type
end

#currencyObject

Currency in which future payments will be charged. Three-letter ISO currency code, in lowercase. Must be a supported currency.



784
785
786
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 784

def currency
  @currency
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



786
787
788
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 786

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



788
789
790
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 788

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of day, week, month, year, or sporadic.



790
791
792
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 790

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, interval=month and interval_count=3 indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when interval=sporadic.



792
793
794
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 792

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



794
795
796
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 794

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



796
797
798
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 796

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are india.



798
799
800
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 798

def supported_types
  @supported_types
end