Class: Stripe::SetupIntentConfirmParams::PaymentMethodOptions::Paypal
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentConfirmParams::PaymentMethodOptions::Paypal
- Defined in:
- lib/stripe/params/setup_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#billing_agreement_id ⇒ Object
The PayPal Billing Agreement ID (BAID).
-
#currency ⇒ Object
Attribute for param field currency.
-
#subsellers ⇒ Object
The Stripe connected account IDs of the sellers on the platform for this transaction (optional).
Instance Method Summary collapse
-
#initialize(billing_agreement_id: nil, currency: nil, subsellers: nil) ⇒ Paypal
constructor
A new instance of Paypal.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(billing_agreement_id: nil, currency: nil, subsellers: nil) ⇒ Paypal
Returns a new instance of Paypal.
1013 1014 1015 1016 1017 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1013 def initialize(billing_agreement_id: nil, currency: nil, subsellers: nil) @billing_agreement_id = billing_agreement_id @currency = currency @subsellers = subsellers end |
Instance Attribute Details
#billing_agreement_id ⇒ Object
The PayPal Billing Agreement ID (BAID). This is an ID generated by PayPal which represents the mandate between the merchant and the customer.
1007 1008 1009 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1007 def billing_agreement_id @billing_agreement_id end |
#currency ⇒ Object
Attribute for param field currency
1009 1010 1011 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1009 def currency @currency end |
#subsellers ⇒ Object
The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when [separate charges and transfers](stripe.com/docs/connect/separate-charges-and-transfers) are used.
1011 1012 1013 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1011 def subsellers @subsellers end |