Class: Stripe::SetupIntentConfirmParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 965

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil,
  start_date: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
  @start_date = start_date
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when ‘amount_type` is `fixed`.



951
952
953
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 951

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively. Defaults to `maximum`.



953
954
955
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 953

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



955
956
957
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 955

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected. Defaults to ‘adhoc`.



957
958
959
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 957

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.



959
960
961
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 959

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Has a default value based on your merchant category code.



961
962
963
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 961

def purpose
  @purpose
end

#start_dateObject

Date, in YYYY-MM-DD format, from which payments will be collected. Defaults to confirmation time.



963
964
965
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 963

def start_date
  @start_date
end