Class: Stripe::SetupIntentConfirmParams::PaymentMethodOptions::Pix::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentConfirmParams::PaymentMethodOptions::Pix::MandateOptions
- Defined in:
- lib/stripe/params/setup_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments.
-
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax.
-
#amount_type ⇒ Object
Type of amount.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#end_date ⇒ Object
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.
-
#payment_schedule ⇒ Object
Schedule at which the future payments will be charged.
-
#reference ⇒ Object
Subscription name displayed to buyers in their bank app.
-
#start_date ⇒ Object
Start date of the mandate, in ‘YYYY-MM-DD`.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1046 def initialize( amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil ) @amount = amount @amount_includes_iof = amount_includes_iof @amount_type = amount_type @currency = currency @end_date = end_date @payment_schedule = payment_schedule @reference = reference @start_date = start_date end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments. Required when ‘amount_type=fixed`. If not provided for `amount_type=maximum`, defaults to 40000.
1030 1031 1032 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1030 def amount @amount end |
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax. Defaults to ‘never`.
1032 1033 1034 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1032 def amount_includes_iof @amount_includes_iof end |
#amount_type ⇒ Object
Type of amount. Defaults to ‘maximum`.
1034 1035 1036 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1034 def amount_type @amount_type end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Only ‘brl` is supported currently.
1036 1037 1038 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1036 def currency @currency end |
#end_date ⇒ Object
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.
1038 1039 1040 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1038 def end_date @end_date end |
#payment_schedule ⇒ Object
Schedule at which the future payments will be charged. Defaults to ‘weekly`.
1040 1041 1042 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1040 def payment_schedule @payment_schedule end |
#reference ⇒ Object
Subscription name displayed to buyers in their bank app. Defaults to the displayable business name.
1042 1043 1044 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1042 def reference @reference end |
#start_date ⇒ Object
Start date of the mandate, in ‘YYYY-MM-DD`. Start date should be at least 3 days in the future. Defaults to 3 days after the current date.
1044 1045 1046 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1044 def start_date @start_date end |