Class: Stripe::SetupIntentConfirmParams::PaymentMethodOptions::Upi::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentConfirmParams::PaymentMethodOptions::Upi::MandateOptions
- Defined in:
- lib/stripe/params/setup_intent_confirm_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments.
-
#amount_type ⇒ Object
One of
fixedormaximum. -
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
-
#end_date ⇒ Object
End date of the mandate or subscription.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
1190 1191 1192 1193 1194 1195 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1190 def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) @amount = amount @amount_type = amount_type @description = description @end_date = end_date end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments.
1182 1183 1184 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1182 def amount @amount end |
#amount_type ⇒ Object
One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.
1184 1185 1186 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1184 def amount_type @amount_type end |
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
1186 1187 1188 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1186 def description @description end |
#end_date ⇒ Object
End date of the mandate or subscription.
1188 1189 1190 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1188 def end_date @end_date end |