Class: Stripe::SetupIntentConfirmParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1150
1151
1152
1153
1154
1155
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1150

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



1142
1143
1144
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1142

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



1144
1145
1146
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1144

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



1146
1147
1148
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1146

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



1148
1149
1150
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1148

def end_date
  @end_date
end