Class: Stripe::SetupIntentConfirmParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_confirm_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1138
1139
1140
1141
1142
1143
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1138

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



1130
1131
1132
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1130

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



1132
1133
1134
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1132

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



1134
1135
1136
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1134

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



1136
1137
1138
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1136

def end_date
  @end_date
end