Class: Stripe::SetupIntentConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/params/setup_intent_confirm_params.rb
Defined Under Namespace
Classes: Filters, ManualEntry
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#manual_entry ⇒ Object
Customize manual entry behavior.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1189 def initialize( filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil ) @filters = filters @manual_entry = manual_entry @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
1179 1180 1181 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1179 def filters @filters end |
#manual_entry ⇒ Object
Customize manual entry behavior
1181 1182 1183 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1181 def manual_entry @manual_entry end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
1183 1184 1185 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1183 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
1185 1186 1187 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1185 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
1187 1188 1189 |
# File 'lib/stripe/params/setup_intent_confirm_params.rb', line 1187 def return_url @return_url end |