Class: Stripe::SetupIntentCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/setup_intent_create_params.rb

Defined Under Namespace

Classes: AutomaticPaymentMethods, MandateData, PaymentMethodData, PaymentMethodOptions, SingleUse

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(allowed_payment_method_types: nil, attach_to_self: nil, automatic_payment_methods: nil, confirm: nil, confirmation_token: nil, customer: nil, customer_account: nil, description: nil, excluded_payment_method_types: nil, expand: nil, flow_directions: nil, mandate_data: nil, metadata: nil, on_behalf_of: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, single_use: nil, usage: nil, use_stripe_sdk: nil) ⇒ SetupIntentCreateParams

Returns a new instance of SetupIntentCreateParams.



1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1401

def initialize(
  allowed_payment_method_types: nil,
  attach_to_self: nil,
  automatic_payment_methods: nil,
  confirm: nil,
  confirmation_token: nil,
  customer: nil,
  customer_account: nil,
  description: nil,
  excluded_payment_method_types: nil,
  expand: nil,
  flow_directions: nil,
  mandate_data: nil,
  metadata: nil,
  on_behalf_of: nil,
  payment_method: nil,
  payment_method_configuration: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  return_url: nil,
  single_use: nil,
  usage: nil,
  use_stripe_sdk: nil
)
  @allowed_payment_method_types = allowed_payment_method_types
  @attach_to_self = attach_to_self
  @automatic_payment_methods = automatic_payment_methods
  @confirm = confirm
  @confirmation_token = confirmation_token
  @customer = customer
  @customer_account = 
  @description = description
  @excluded_payment_method_types = excluded_payment_method_types
  @expand = expand
  @flow_directions = flow_directions
  @mandate_data = mandate_data
  @metadata = 
  @on_behalf_of = on_behalf_of
  @payment_method = payment_method
  @payment_method_configuration = payment_method_configuration
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @return_url = return_url
  @single_use = single_use
  @usage = usage
  @use_stripe_sdk = use_stripe_sdk
end

Instance Attribute Details

#allowed_payment_method_typesObject

The list of payment method types to allow for this SetupIntent. Stripe will only use methods in this list when determining the payment methods to offer. A list of valid payment method types can be found here.



1342
1343
1344
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1342

def allowed_payment_method_types
  @allowed_payment_method_types
end

#attach_to_selfObject

If present, the SetupIntent's payment method will be attached to the in-context Stripe Account.

It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.



1346
1347
1348
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1346

def attach_to_self
  @attach_to_self
end

#automatic_payment_methodsObject

When you enable this parameter, this SetupIntent accepts payment methods that you enable in the Dashboard and that are compatible with its other parameters.



1348
1349
1350
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1348

def automatic_payment_methods
  @automatic_payment_methods
end

#confirmObject

Set to true to attempt to confirm this SetupIntent immediately. This parameter defaults to false. If a card is the attached payment method, you can provide a return_url in case further authentication is necessary.



1350
1351
1352
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1350

def confirm
  @confirm
end

#confirmation_tokenObject

ID of the ConfirmationToken used to confirm this SetupIntent.

If the provided ConfirmationToken contains properties that are also being provided in this request, such as payment_method, then the values in this request will take precedence.



1354
1355
1356
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1354

def confirmation_token
  @confirmation_token
end

#customerObject

ID of the Customer this SetupIntent belongs to, if one exists.

If present, the SetupIntent's payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.



1358
1359
1360
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1358

def customer
  @customer
end

#customer_accountObject

ID of the Account this SetupIntent belongs to, if one exists.

If present, the SetupIntent's payment method will be attached to the Account on successful setup. Payment methods attached to other Accounts cannot be used with this SetupIntent.



1362
1363
1364
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1362

def 
  @customer_account
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1364
1365
1366
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1364

def description
  @description
end

#excluded_payment_method_typesObject

The list of payment method types to exclude from use with this SetupIntent.



1366
1367
1368
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1366

def excluded_payment_method_types
  @excluded_payment_method_types
end

#expandObject

Specifies which fields in the response should be expanded.



1368
1369
1370
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1368

def expand
  @expand
end

#flow_directionsObject

Indicates the directions of money movement for which this payment method is intended to be used.

Include inbound if you intend to use the payment method as the origin to pull funds from. Include outbound if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.



1372
1373
1374
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1372

def flow_directions
  @flow_directions
end

#mandate_dataObject

This hash contains details about the mandate to create. This parameter can only be used with confirm=true.



1374
1375
1376
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1374

def mandate_data
  @mandate_data
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



1376
1377
1378
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1376

def 
  @metadata
end

#on_behalf_ofObject

The Stripe account ID created for this SetupIntent.



1378
1379
1380
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1378

def on_behalf_of
  @on_behalf_of
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.



1380
1381
1382
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1380

def payment_method
  @payment_method
end

#payment_method_configurationObject

The ID of the payment method configuration to use with this SetupIntent.



1382
1383
1384
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1382

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_dataObject

When included, this hash creates a PaymentMethod that is set as the payment_method value in the SetupIntent.



1385
1386
1387
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1385

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this SetupIntent.



1387
1388
1389
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1387

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, card) that this SetupIntent can use. If you don't provide this, Stripe will dynamically show relevant payment methods from your payment method settings. A list of valid payment method types can be found here.



1389
1390
1391
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1389

def payment_method_types
  @payment_method_types
end

#return_urlObject

The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method's app or site. To redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter can only be used with confirm=true.



1391
1392
1393
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1391

def return_url
  @return_url
end

#single_useObject

If you populate this hash, this SetupIntent generates a single_use mandate after successful completion.

Single-use mandates are only valid for the following payment methods: acss_debit, alipay, au_becs_debit, bacs_debit, bancontact, boleto, ideal, link, sepa_debit, and us_bank_account.



1395
1396
1397
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1395

def single_use
  @single_use
end

#usageObject

Indicates how the payment method is intended to be used in the future. If not provided, this value defaults to off_session.



1397
1398
1399
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1397

def usage
  @usage
end

#use_stripe_sdkObject

Set to true when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.



1399
1400
1401
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1399

def use_stripe_sdk
  @use_stripe_sdk
end