Class: Stripe::SetupIntentCreateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentCreateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/params/setup_intent_create_params.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 273 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
261 262 263 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 261 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
263 264 265 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 263 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
265 266 267 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 265 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
267 268 269 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 267 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
269 270 271 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 269 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
271 272 273 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 271 def suffix @suffix end |