Class: Stripe::SetupIntentCreateParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentCreateParams::PaymentMethodOptions
- Defined in:
- lib/stripe/params/setup_intent_create_params.rb
Defined Under Namespace
Classes: AcssDebit, AmazonPay, BacsDebit, Bizum, Card, CardPresent, Klarna, Link, Paypal, Payto, Pix, SepaDebit, StripeBalance, Upi, UsBankAccount
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If this is a
acss_debitSetupIntent, this sub-hash contains details about the ACSS Debit payment method options. -
#amazon_pay ⇒ Object
If this is a
amazon_paySetupIntent, this sub-hash contains details about the AmazonPay payment method options. -
#bacs_debit ⇒ Object
If this is a
bacs_debitSetupIntent, this sub-hash contains details about the Bacs Debit payment method options. -
#bizum ⇒ Object
If this is a
bizumSetupIntent, this sub-hash contains details about the Bizum payment method options. -
#card ⇒ Object
Configuration for any card setup attempted on this SetupIntent.
-
#card_present ⇒ Object
If this is a
card_presentPaymentMethod, this sub-hash contains details about the card-present payment method options. -
#klarna ⇒ Object
If this is a
klarnaPaymentMethod, this hash contains details about the Klarna payment method options. -
#link ⇒ Object
If this is a
linkPaymentMethod, this sub-hash contains details about the Link payment method options (Link is also known as Onelink in the UK). -
#paypal ⇒ Object
If this is a
paypalPaymentMethod, this sub-hash contains details about the PayPal payment method options. -
#payto ⇒ Object
If this is a
paytoSetupIntent, this sub-hash contains details about the PayTo payment method options. -
#pix ⇒ Object
If this is a
pixSetupIntent, this sub-hash contains details about the Pix payment method options. -
#sepa_debit ⇒ Object
If this is a
sepa_debitSetupIntent, this sub-hash contains details about the SEPA Debit payment method options. -
#stripe_balance ⇒ Object
If this is a
stripe_balancePaymentMethod, this sub-hash contains details about the Stripe Balance payment method options. -
#upi ⇒ Object
If this is a
upiSetupIntent, this sub-hash contains details about the UPI payment method options. -
#us_bank_account ⇒ Object
If this is a
us_bank_accountSetupIntent, this sub-hash contains details about the US bank account payment method options.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, amazon_pay: nil, bacs_debit: nil, bizum: nil, card: nil, card_present: nil, klarna: nil, link: nil, paypal: nil, payto: nil, pix: nil, sepa_debit: nil, stripe_balance: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(acss_debit: nil, amazon_pay: nil, bacs_debit: nil, bizum: nil, card: nil, card_present: nil, klarna: nil, link: nil, paypal: nil, payto: nil, pix: nil, sepa_debit: nil, stripe_balance: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1339 def initialize( acss_debit: nil, amazon_pay: nil, bacs_debit: nil, bizum: nil, card: nil, card_present: nil, klarna: nil, link: nil, paypal: nil, payto: nil, pix: nil, sepa_debit: nil, stripe_balance: nil, upi: nil, us_bank_account: nil ) @acss_debit = acss_debit @amazon_pay = amazon_pay @bacs_debit = bacs_debit @bizum = bizum @card = card @card_present = card_present @klarna = klarna @link = link @paypal = paypal @payto = payto @pix = pix @sepa_debit = sepa_debit @stripe_balance = stripe_balance @upi = upi @us_bank_account = us_bank_account end |
Instance Attribute Details
#acss_debit ⇒ Object
If this is a acss_debit SetupIntent, this sub-hash contains details about the ACSS Debit payment method options.
1309 1310 1311 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1309 def acss_debit @acss_debit end |
#amazon_pay ⇒ Object
If this is a amazon_pay SetupIntent, this sub-hash contains details about the AmazonPay payment method options.
1311 1312 1313 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1311 def amazon_pay @amazon_pay end |
#bacs_debit ⇒ Object
If this is a bacs_debit SetupIntent, this sub-hash contains details about the Bacs Debit payment method options.
1313 1314 1315 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1313 def bacs_debit @bacs_debit end |
#bizum ⇒ Object
If this is a bizum SetupIntent, this sub-hash contains details about the Bizum payment method options.
1315 1316 1317 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1315 def bizum @bizum end |
#card ⇒ Object
Configuration for any card setup attempted on this SetupIntent.
1317 1318 1319 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1317 def card @card end |
#card_present ⇒ Object
If this is a card_present PaymentMethod, this sub-hash contains details about the card-present payment method options.
1319 1320 1321 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1319 def card_present @card_present end |
#klarna ⇒ Object
If this is a klarna PaymentMethod, this hash contains details about the Klarna payment method options.
1321 1322 1323 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1321 def klarna @klarna end |
#link ⇒ Object
If this is a link PaymentMethod, this sub-hash contains details about the Link payment method options (Link is also known as Onelink in the UK).
1323 1324 1325 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1323 def link @link end |
#paypal ⇒ Object
If this is a paypal PaymentMethod, this sub-hash contains details about the PayPal payment method options.
1325 1326 1327 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1325 def paypal @paypal end |
#payto ⇒ Object
If this is a payto SetupIntent, this sub-hash contains details about the PayTo payment method options.
1327 1328 1329 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1327 def payto @payto end |
#pix ⇒ Object
If this is a pix SetupIntent, this sub-hash contains details about the Pix payment method options.
1329 1330 1331 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1329 def pix @pix end |
#sepa_debit ⇒ Object
If this is a sepa_debit SetupIntent, this sub-hash contains details about the SEPA Debit payment method options.
1331 1332 1333 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1331 def sepa_debit @sepa_debit end |
#stripe_balance ⇒ Object
If this is a stripe_balance PaymentMethod, this sub-hash contains details about the Stripe Balance payment method options.
1333 1334 1335 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1333 def stripe_balance @stripe_balance end |
#upi ⇒ Object
If this is a upi SetupIntent, this sub-hash contains details about the UPI payment method options.
1335 1336 1337 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1335 def upi @upi end |
#us_bank_account ⇒ Object
If this is a us_bank_account SetupIntent, this sub-hash contains details about the US bank account payment method options.
1337 1338 1339 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1337 def us_bank_account @us_bank_account end |