Class: Stripe::SetupIntentCreateParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentCreateParams::PaymentMethodOptions
- Defined in:
- lib/stripe/params/setup_intent_create_params.rb
Defined Under Namespace
Classes: AcssDebit, AmazonPay, BacsDebit, Bizum, Card, CardPresent, Klarna, Link, Paypal, Payto, Pix, SepaDebit, Upi, UsBankAccount
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If this is a ‘acss_debit` SetupIntent, this sub-hash contains details about the ACSS Debit payment method options.
-
#amazon_pay ⇒ Object
If this is a ‘amazon_pay` SetupIntent, this sub-hash contains details about the AmazonPay payment method options.
-
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` SetupIntent, this sub-hash contains details about the Bacs Debit payment method options.
-
#bizum ⇒ Object
If this is a ‘bizum` SetupIntent, this sub-hash contains details about the Bizum payment method options.
-
#card ⇒ Object
Configuration for any card setup attempted on this SetupIntent.
-
#card_present ⇒ Object
If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the card-present payment method options.
-
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method options.
-
#link ⇒ Object
If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options (Link is also known as Onelink in the UK).
-
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.
-
#payto ⇒ Object
If this is a ‘payto` SetupIntent, this sub-hash contains details about the PayTo payment method options.
-
#pix ⇒ Object
If this is a ‘pix` SetupIntent, this sub-hash contains details about the Pix payment method options.
-
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` SetupIntent, this sub-hash contains details about the SEPA Debit payment method options.
-
#upi ⇒ Object
If this is a ‘upi` SetupIntent, this sub-hash contains details about the UPI payment method options.
-
#us_bank_account ⇒ Object
If this is a ‘us_bank_account` SetupIntent, this sub-hash contains details about the US bank account payment method options.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, amazon_pay: nil, bacs_debit: nil, bizum: nil, card: nil, card_present: nil, klarna: nil, link: nil, paypal: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(acss_debit: nil, amazon_pay: nil, bacs_debit: nil, bizum: nil, card: nil, card_present: nil, klarna: nil, link: nil, paypal: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1297 def initialize( acss_debit: nil, amazon_pay: nil, bacs_debit: nil, bizum: nil, card: nil, card_present: nil, klarna: nil, link: nil, paypal: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil ) @acss_debit = acss_debit @amazon_pay = amazon_pay @bacs_debit = bacs_debit @bizum = bizum @card = card @card_present = card_present @klarna = klarna @link = link @paypal = paypal @payto = payto @pix = pix @sepa_debit = sepa_debit @upi = upi @us_bank_account = us_bank_account end |
Instance Attribute Details
#acss_debit ⇒ Object
If this is a ‘acss_debit` SetupIntent, this sub-hash contains details about the ACSS Debit payment method options.
1269 1270 1271 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1269 def acss_debit @acss_debit end |
#amazon_pay ⇒ Object
If this is a ‘amazon_pay` SetupIntent, this sub-hash contains details about the AmazonPay payment method options.
1271 1272 1273 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1271 def amazon_pay @amazon_pay end |
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` SetupIntent, this sub-hash contains details about the Bacs Debit payment method options.
1273 1274 1275 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1273 def bacs_debit @bacs_debit end |
#bizum ⇒ Object
If this is a ‘bizum` SetupIntent, this sub-hash contains details about the Bizum payment method options.
1275 1276 1277 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1275 def bizum @bizum end |
#card ⇒ Object
Configuration for any card setup attempted on this SetupIntent.
1277 1278 1279 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1277 def card @card end |
#card_present ⇒ Object
If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the card-present payment method options.
1279 1280 1281 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1279 def card_present @card_present end |
#klarna ⇒ Object
If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method options.
1281 1282 1283 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1281 def klarna @klarna end |
#link ⇒ Object
If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options (Link is also known as Onelink in the UK).
1283 1284 1285 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1283 def link @link end |
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.
1285 1286 1287 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1285 def paypal @paypal end |
#payto ⇒ Object
If this is a ‘payto` SetupIntent, this sub-hash contains details about the PayTo payment method options.
1287 1288 1289 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1287 def payto @payto end |
#pix ⇒ Object
If this is a ‘pix` SetupIntent, this sub-hash contains details about the Pix payment method options.
1289 1290 1291 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1289 def pix @pix end |
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` SetupIntent, this sub-hash contains details about the SEPA Debit payment method options.
1291 1292 1293 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1291 def sepa_debit @sepa_debit end |
#upi ⇒ Object
If this is a ‘upi` SetupIntent, this sub-hash contains details about the UPI payment method options.
1293 1294 1295 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1293 def upi @upi end |
#us_bank_account ⇒ Object
If this is a ‘us_bank_account` SetupIntent, this sub-hash contains details about the US bank account payment method options.
1295 1296 1297 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1295 def us_bank_account @us_bank_account end |