Class: Stripe::SetupIntentCreateParams::PaymentMethodOptions::AcssDebit::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



765
766
767
768
769
770
771
772
773
774
775
776
777
# File 'lib/stripe/params/setup_intent_create_params.rb', line 765

def initialize(
  custom_mandate_url: nil,
  default_for: nil,
  interval_description: nil,
  payment_schedule: nil,
  transaction_type: nil
)
  @custom_mandate_url = custom_mandate_url
  @default_for = default_for
  @interval_description = interval_description
  @payment_schedule = payment_schedule
  @transaction_type = transaction_type
end

Instance Attribute Details

#custom_mandate_urlObject

A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters payment_intent and payment_intent_client_secret when confirming a Payment Intent, or setup_intent and setup_intent_client_secret when confirming a Setup Intent.



755
756
757
# File 'lib/stripe/params/setup_intent_create_params.rb', line 755

def custom_mandate_url
  @custom_mandate_url
end

#default_forObject

List of Stripe products where this mandate can be selected automatically.



757
758
759
# File 'lib/stripe/params/setup_intent_create_params.rb', line 757

def default_for
  @default_for
end

#interval_descriptionObject

Description of the mandate interval. Only required if 'payment_schedule' parameter is 'interval' or 'combined'.



759
760
761
# File 'lib/stripe/params/setup_intent_create_params.rb', line 759

def interval_description
  @interval_description
end

#payment_scheduleObject

Payment schedule for the mandate.



761
762
763
# File 'lib/stripe/params/setup_intent_create_params.rb', line 761

def payment_schedule
  @payment_schedule
end

#transaction_typeObject

Transaction type of the mandate.



763
764
765
# File 'lib/stripe/params/setup_intent_create_params.rb', line 763

def transaction_type
  @transaction_type
end