Class: Stripe::SetupIntentCreateParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, currency: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
# File 'lib/stripe/params/setup_intent_create_params.rb', line 736

def initialize(
  amount: nil,
  amount_type: nil,
  currency: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @currency = currency
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments, specified in the presentment currency.



716
717
718
# File 'lib/stripe/params/setup_intent_create_params.rb', line 716

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



718
719
720
# File 'lib/stripe/params/setup_intent_create_params.rb', line 718

def amount_type
  @amount_type
end

#currencyObject

Currency in which future payments will be charged. Three-letter ISO currency code, in lowercase. Must be a supported currency.



720
721
722
# File 'lib/stripe/params/setup_intent_create_params.rb', line 720

def currency
  @currency
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



722
723
724
# File 'lib/stripe/params/setup_intent_create_params.rb', line 722

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



724
725
726
# File 'lib/stripe/params/setup_intent_create_params.rb', line 724

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of day, week, month, year, or sporadic.



726
727
728
# File 'lib/stripe/params/setup_intent_create_params.rb', line 726

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, interval=month and interval_count=3 indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when interval=sporadic.



728
729
730
# File 'lib/stripe/params/setup_intent_create_params.rb', line 728

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



730
731
732
# File 'lib/stripe/params/setup_intent_create_params.rb', line 730

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



732
733
734
# File 'lib/stripe/params/setup_intent_create_params.rb', line 732

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are india.



734
735
736
# File 'lib/stripe/params/setup_intent_create_params.rb', line 734

def supported_types
  @supported_types
end