Class: Stripe::SetupIntentCreateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentCreateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling
- Defined in:
- lib/stripe/params/setup_intent_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount of the next charge for the subscription.
-
#date ⇒ Object
The date of the next charge for the subscription in YYYY-MM-DD format.
Instance Method Summary collapse
-
#initialize(amount: nil, date: nil) ⇒ NextBilling
constructor
A new instance of NextBilling.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, date: nil) ⇒ NextBilling
Returns a new instance of NextBilling.
963 964 965 966 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 963 def initialize(amount: nil, date: nil) @amount = amount @date = date end |
Instance Attribute Details
#amount ⇒ Object
The amount of the next charge for the subscription.
959 960 961 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 959 def amount @amount end |
#date ⇒ Object
The date of the next charge for the subscription in YYYY-MM-DD format.
961 962 963 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 961 def date @date end |