Class: Stripe::SetupIntentCreateParams::PaymentMethodOptions::Paypal

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(billing_agreement_id: nil, currency: nil, subsellers: nil) ⇒ Paypal

Returns a new instance of Paypal.



1027
1028
1029
1030
1031
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1027

def initialize(billing_agreement_id: nil, currency: nil, subsellers: nil)
  @billing_agreement_id = billing_agreement_id
  @currency = currency
  @subsellers = subsellers
end

Instance Attribute Details

#billing_agreement_idObject

The PayPal Billing Agreement ID (BAID). This is an ID generated by PayPal which represents the mandate between the merchant and the customer.



1021
1022
1023
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1021

def billing_agreement_id
  @billing_agreement_id
end

#currencyObject

Attribute for param field currency



1023
1024
1025
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1023

def currency
  @currency
end

#subsellersObject

The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when [separate charges and transfers](stripe.com/docs/connect/separate-charges-and-transfers) are used.



1025
1026
1027
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1025

def subsellers
  @subsellers
end