Class: Stripe::SetupIntentCreateParams::PaymentMethodOptions::Payto::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentCreateParams::PaymentMethodOptions::Payto::MandateOptions
- Defined in:
- lib/stripe/params/setup_intent_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount that will be collected.
-
#amount_type ⇒ Object
The type of amount that will be collected.
-
#end_date ⇒ Object
Date, in YYYY-MM-DD format, after which payments will not be collected.
-
#payment_schedule ⇒ Object
The periodicity at which payments will be collected.
-
#payments_per_period ⇒ Object
The number of payments that will be made during a payment period.
-
#purpose ⇒ Object
The purpose for which payments are made.
-
#start_date ⇒ Object
Date, in YYYY-MM-DD format, from which payments will be collected.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1086 def initialize( amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil ) @amount = amount @amount_type = amount_type @end_date = end_date @payment_schedule = payment_schedule @payments_per_period = payments_per_period @purpose = purpose @start_date = start_date end |
Instance Attribute Details
#amount ⇒ Object
Amount that will be collected. It is required when amount_type is fixed.
1072 1073 1074 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1072 def amount @amount end |
#amount_type ⇒ Object
The type of amount that will be collected. The amount charged must be exact or up to the value of amount param for fixed or maximum type respectively. Defaults to maximum.
1074 1075 1076 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1074 def amount_type @amount_type end |
#end_date ⇒ Object
Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.
1076 1077 1078 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1076 def end_date @end_date end |
#payment_schedule ⇒ Object
The periodicity at which payments will be collected. Defaults to adhoc.
1078 1079 1080 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1078 def payment_schedule @payment_schedule end |
#payments_per_period ⇒ Object
The number of payments that will be made during a payment period. Defaults to 1 except for when payment_schedule is adhoc. In that case, it defaults to no limit.
1080 1081 1082 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1080 def payments_per_period @payments_per_period end |
#purpose ⇒ Object
The purpose for which payments are made. Has a default value based on your merchant category code.
1082 1083 1084 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1082 def purpose @purpose end |
#start_date ⇒ Object
Date, in YYYY-MM-DD format, from which payments will be collected. Defaults to confirmation time.
1084 1085 1086 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1084 def start_date @start_date end |