Class: Stripe::SetupIntentCreateParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1063

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil,
  start_date: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
  @start_date = start_date
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when amount_type is fixed.



1049
1050
1051
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1049

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of amount param for fixed or maximum type respectively. Defaults to maximum.



1051
1052
1053
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1051

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



1053
1054
1055
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1053

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected. Defaults to adhoc.



1055
1056
1057
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1055

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when payment_schedule is adhoc. In that case, it defaults to no limit.



1057
1058
1059
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1057

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Has a default value based on your merchant category code.



1059
1060
1061
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1059

def purpose
  @purpose
end

#start_dateObject

Date, in YYYY-MM-DD format, from which payments will be collected. Defaults to confirmation time.



1061
1062
1063
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1061

def start_date
  @start_date
end