Class: Stripe::SetupIntentCreateParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1204
1205
1206
1207
1208
1209
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1204

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



1196
1197
1198
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1196

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



1198
1199
1200
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1198

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



1200
1201
1202
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1200

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



1202
1203
1204
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1202

def end_date
  @end_date
end