Class: Stripe::SetupIntentCreateParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1080
1081
1082
1083
1084
1085
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1080

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



1072
1073
1074
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1072

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



1074
1075
1076
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1074

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



1076
1077
1078
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1076

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



1078
1079
1080
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1078

def end_date
  @end_date
end