Class: Stripe::SetupIntentCreateParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1164
1165
1166
1167
1168
1169
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1164

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



1156
1157
1158
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1156

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



1158
1159
1160
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1158

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



1160
1161
1162
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1160

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



1162
1163
1164
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1162

def end_date
  @end_date
end