Class: Stripe::SetupIntentCreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_create_params.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1215

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



1205
1206
1207
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1205

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



1207
1208
1209
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1207

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



1209
1210
1211
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1209

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



1211
1212
1213
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1211

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



1213
1214
1215
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1213

def return_url
  @return_url
end