Class: Stripe::SetupIntentCreateParams::PaymentMethodOptions::UsBankAccount::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentCreateParams::PaymentMethodOptions::UsBankAccount::MandateOptions
- Defined in:
- lib/stripe/params/setup_intent_create_params.rb
Instance Attribute Summary collapse
-
#collection_method ⇒ Object
The method used to collect offline mandate customer acceptance.
Instance Method Summary collapse
-
#initialize(collection_method: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(collection_method: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
1157 1158 1159 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1157 def initialize(collection_method: nil) @collection_method = collection_method end |
Instance Attribute Details
#collection_method ⇒ Object
The method used to collect offline mandate customer acceptance.
1155 1156 1157 |
# File 'lib/stripe/params/setup_intent_create_params.rb', line 1155 def collection_method @collection_method end |