Class: Stripe::SetupIntentService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::SetupIntentService
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Defined Under Namespace
Classes: CancelParams, ConfirmParams, CreateParams, ListParams, RetrieveParams, UpdateParams, VerifyMicrodepositsParams
Instance Method Summary collapse
-
#cancel(intent, params = {}, opts = {}) ⇒ Object
You can cancel a SetupIntent object when it’s in one of these statuses: requires_payment_method, requires_confirmation, or requires_action.
-
#confirm(intent, params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to set up the current or provided payment method.
-
#create(params = {}, opts = {}) ⇒ Object
Creates a SetupIntent object.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of SetupIntents.
-
#retrieve(intent, params = {}, opts = {}) ⇒ Object
Retrieves the details of a SetupIntent that has previously been created.
-
#update(intent, params = {}, opts = {}) ⇒ Object
Updates a SetupIntent object.
-
#verify_microdeposits(intent, params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a SetupIntent object.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#cancel(intent, params = {}, opts = {}) ⇒ Object
You can cancel a SetupIntent object when it’s in one of these statuses: requires_payment_method, requires_confirmation, or requires_action.
After you cancel it, setup is abandoned and any operations on the SetupIntent fail with an error. You can’t cancel the SetupIntent for a Checkout Session. [Expire the Checkout Session](docs.stripe.com/docs/api/checkout/sessions/expire) instead.
3966 3967 3968 3969 3970 3971 3972 3973 3974 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3966 def cancel(intent, params = {}, opts = {}) request( method: :post, path: format("/v1/setup_intents/%<intent>s/cancel", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#confirm(intent, params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to set up the current or provided payment method. For example, you would confirm a SetupIntent when a customer hits the “Save” button on a payment method management page on your website.
If the selected payment method does not require any additional steps from the customer, the SetupIntent will transition to the succeeded status.
Otherwise, it will transition to the requires_action status and suggest additional actions via next_action. If setup fails, the SetupIntent will transition to the requires_payment_method status or the canceled status if the confirmation limit is reached.
3990 3991 3992 3993 3994 3995 3996 3997 3998 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3990 def confirm(intent, params = {}, opts = {}) request( method: :post, path: format("/v1/setup_intents/%<intent>s/confirm", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#create(params = {}, opts = {}) ⇒ Object
Creates a SetupIntent object.
After you create the SetupIntent, attach a payment method and [confirm](docs.stripe.com/docs/api/setup_intents/confirm) it to collect any required permissions to charge the payment method later.
4004 4005 4006 4007 4008 4009 4010 4011 4012 |
# File 'lib/stripe/services/setup_intent_service.rb', line 4004 def create(params = {}, opts = {}) request( method: :post, path: "/v1/setup_intents", params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of SetupIntents.
4015 4016 4017 4018 4019 4020 4021 4022 4023 |
# File 'lib/stripe/services/setup_intent_service.rb', line 4015 def list(params = {}, opts = {}) request( method: :get, path: "/v1/setup_intents", params: params, opts: opts, base_address: :api ) end |
#retrieve(intent, params = {}, opts = {}) ⇒ Object
Retrieves the details of a SetupIntent that has previously been created.
Client-side retrieval using a publishable key is allowed when the client_secret is provided in the query string.
When retrieved with a publishable key, only a subset of properties will be returned. Please refer to the [SetupIntent](docs.stripe.com/api#setup_intent_object) object reference for more details.
4030 4031 4032 4033 4034 4035 4036 4037 4038 |
# File 'lib/stripe/services/setup_intent_service.rb', line 4030 def retrieve(intent, params = {}, opts = {}) request( method: :get, path: format("/v1/setup_intents/%<intent>s", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#update(intent, params = {}, opts = {}) ⇒ Object
Updates a SetupIntent object.
4041 4042 4043 4044 4045 4046 4047 4048 4049 |
# File 'lib/stripe/services/setup_intent_service.rb', line 4041 def update(intent, params = {}, opts = {}) request( method: :post, path: format("/v1/setup_intents/%<intent>s", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#verify_microdeposits(intent, params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a SetupIntent object.
4052 4053 4054 4055 4056 4057 4058 4059 4060 |
# File 'lib/stripe/services/setup_intent_service.rb', line 4052 def verify_microdeposits(intent, params = {}, opts = {}) request( method: :post, path: format("/v1/setup_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |