Class: Stripe::SetupIntentService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::SetupIntentService
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Defined Under Namespace
Classes: CancelParams, ConfirmParams, CreateParams, ListParams, RetrieveParams, UpdateParams, VerifyMicrodepositsParams
Instance Method Summary collapse
-
#cancel(intent, params = {}, opts = {}) ⇒ Object
You can cancel a SetupIntent object when it’s in one of these statuses: requires_payment_method, requires_confirmation, or requires_action.
-
#confirm(intent, params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to set up the current or provided payment method.
-
#create(params = {}, opts = {}) ⇒ Object
Creates a SetupIntent object.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of SetupIntents.
-
#retrieve(intent, params = {}, opts = {}) ⇒ Object
Retrieves the details of a SetupIntent that has previously been created.
-
#update(intent, params = {}, opts = {}) ⇒ Object
Updates a SetupIntent object.
-
#verify_microdeposits(intent, params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a SetupIntent object.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#cancel(intent, params = {}, opts = {}) ⇒ Object
You can cancel a SetupIntent object when it’s in one of these statuses: requires_payment_method, requires_confirmation, or requires_action.
After you cancel it, setup is abandoned and any operations on the SetupIntent fail with an error. You can’t cancel the SetupIntent for a Checkout Session. [Expire the Checkout Session](docs.stripe.com/docs/api/checkout/sessions/expire) instead.
3011 3012 3013 3014 3015 3016 3017 3018 3019 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3011 def cancel(intent, params = {}, opts = {}) request( method: :post, path: format("/v1/setup_intents/%<intent>s/cancel", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#confirm(intent, params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to set up the current or provided payment method. For example, you would confirm a SetupIntent when a customer hits the “Save” button on a payment method management page on your website.
If the selected payment method does not require any additional steps from the customer, the SetupIntent will transition to the succeeded status.
Otherwise, it will transition to the requires_action status and suggest additional actions via next_action. If setup fails, the SetupIntent will transition to the requires_payment_method status or the canceled status if the confirmation limit is reached.
3035 3036 3037 3038 3039 3040 3041 3042 3043 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3035 def confirm(intent, params = {}, opts = {}) request( method: :post, path: format("/v1/setup_intents/%<intent>s/confirm", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#create(params = {}, opts = {}) ⇒ Object
Creates a SetupIntent object.
After you create the SetupIntent, attach a payment method and [confirm](docs.stripe.com/docs/api/setup_intents/confirm) it to collect any required permissions to charge the payment method later.
3049 3050 3051 3052 3053 3054 3055 3056 3057 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3049 def create(params = {}, opts = {}) request( method: :post, path: "/v1/setup_intents", params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of SetupIntents.
3060 3061 3062 3063 3064 3065 3066 3067 3068 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3060 def list(params = {}, opts = {}) request( method: :get, path: "/v1/setup_intents", params: params, opts: opts, base_address: :api ) end |
#retrieve(intent, params = {}, opts = {}) ⇒ Object
Retrieves the details of a SetupIntent that has previously been created.
Client-side retrieval using a publishable key is allowed when the client_secret is provided in the query string.
When retrieved with a publishable key, only a subset of properties will be returned. Please refer to the [SetupIntent](docs.stripe.com/api#setup_intent_object) object reference for more details.
3075 3076 3077 3078 3079 3080 3081 3082 3083 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3075 def retrieve(intent, params = {}, opts = {}) request( method: :get, path: format("/v1/setup_intents/%<intent>s", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#update(intent, params = {}, opts = {}) ⇒ Object
Updates a SetupIntent object.
3086 3087 3088 3089 3090 3091 3092 3093 3094 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3086 def update(intent, params = {}, opts = {}) request( method: :post, path: format("/v1/setup_intents/%<intent>s", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |
#verify_microdeposits(intent, params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a SetupIntent object.
3097 3098 3099 3100 3101 3102 3103 3104 3105 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3097 def verify_microdeposits(intent, params = {}, opts = {}) request( method: :post, path: format("/v1/setup_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(intent) }), params: params, opts: opts, base_address: :api ) end |