Class: Stripe::SetupIntentService::ConfirmParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Defined Under Namespace

Classes: MandateData, PaymentMethodData, PaymentMethodOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(confirmation_token: nil, expand: nil, mandate_data: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, use_stripe_sdk: nil) ⇒ ConfirmParams

Returns a new instance of ConfirmParams.



3245
3246
3247
3248
3249
3250
3251
3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
# File 'lib/stripe/services/setup_intent_service.rb', line 3245

def initialize(
  confirmation_token: nil,
  expand: nil,
  mandate_data: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  return_url: nil,
  use_stripe_sdk: nil
)
  @confirmation_token = confirmation_token
  @expand = expand
  @mandate_data = mandate_data
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @return_url = return_url
  @use_stripe_sdk = use_stripe_sdk
end

Instance Attribute Details

#confirmation_tokenObject

ID of the ConfirmationToken used to confirm this SetupIntent.

If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.



3226
3227
3228
# File 'lib/stripe/services/setup_intent_service.rb', line 3226

def confirmation_token
  @confirmation_token
end

#expandObject

Specifies which fields in the response should be expanded.



3228
3229
3230
# File 'lib/stripe/services/setup_intent_service.rb', line 3228

def expand
  @expand
end

#mandate_dataObject

Attribute for param field mandate_data



3230
3231
3232
# File 'lib/stripe/services/setup_intent_service.rb', line 3230

def mandate_data
  @mandate_data
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.



3232
3233
3234
# File 'lib/stripe/services/setup_intent_service.rb', line 3232

def payment_method
  @payment_method
end

#payment_method_dataObject

When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.



3235
3236
3237
# File 'lib/stripe/services/setup_intent_service.rb', line 3235

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this SetupIntent.



3237
3238
3239
# File 'lib/stripe/services/setup_intent_service.rb', line 3237

def payment_method_options
  @payment_method_options
end

#return_urlObject

The URL to redirect your customer back to after they authenticate on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.



3241
3242
3243
# File 'lib/stripe/services/setup_intent_service.rb', line 3241

def return_url
  @return_url
end

#use_stripe_sdkObject

Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.



3243
3244
3245
# File 'lib/stripe/services/setup_intent_service.rb', line 3243

def use_stripe_sdk
  @use_stripe_sdk
end