Class: Stripe::SetupIntentService::ConfirmParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Defined Under Namespace

Classes: MandateData, PaymentMethodData, PaymentMethodOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(confirmation_token: nil, expand: nil, mandate_data: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, use_stripe_sdk: nil) ⇒ ConfirmParams

Returns a new instance of ConfirmParams.



2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
2990
# File 'lib/stripe/services/setup_intent_service.rb', line 2972

def initialize(
  confirmation_token: nil,
  expand: nil,
  mandate_data: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  return_url: nil,
  use_stripe_sdk: nil
)
  @confirmation_token = confirmation_token
  @expand = expand
  @mandate_data = mandate_data
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @return_url = return_url
  @use_stripe_sdk = use_stripe_sdk
end

Instance Attribute Details

#confirmation_tokenObject

ID of the ConfirmationToken used to confirm this SetupIntent.

If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.



2953
2954
2955
# File 'lib/stripe/services/setup_intent_service.rb', line 2953

def confirmation_token
  @confirmation_token
end

#expandObject

Specifies which fields in the response should be expanded.



2955
2956
2957
# File 'lib/stripe/services/setup_intent_service.rb', line 2955

def expand
  @expand
end

#mandate_dataObject

Attribute for param field mandate_data



2957
2958
2959
# File 'lib/stripe/services/setup_intent_service.rb', line 2957

def mandate_data
  @mandate_data
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.



2959
2960
2961
# File 'lib/stripe/services/setup_intent_service.rb', line 2959

def payment_method
  @payment_method
end

#payment_method_dataObject

When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.



2962
2963
2964
# File 'lib/stripe/services/setup_intent_service.rb', line 2962

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this SetupIntent.



2964
2965
2966
# File 'lib/stripe/services/setup_intent_service.rb', line 2964

def payment_method_options
  @payment_method_options
end

#return_urlObject

The URL to redirect your customer back to after they authenticate on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.



2968
2969
2970
# File 'lib/stripe/services/setup_intent_service.rb', line 2968

def return_url
  @return_url
end

#use_stripe_sdkObject

Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.



2970
2971
2972
# File 'lib/stripe/services/setup_intent_service.rb', line 2970

def use_stripe_sdk
  @use_stripe_sdk
end