Class: Stripe::SetupIntentService::ConfirmParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Defined Under Namespace

Classes: MandateData, PaymentMethodData, PaymentMethodOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(confirmation_token: nil, expand: nil, mandate_data: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, use_stripe_sdk: nil) ⇒ ConfirmParams

Returns a new instance of ConfirmParams.



3689
3690
3691
3692
3693
3694
3695
3696
3697
3698
3699
3700
3701
3702
3703
3704
3705
3706
3707
# File 'lib/stripe/services/setup_intent_service.rb', line 3689

def initialize(
  confirmation_token: nil,
  expand: nil,
  mandate_data: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  return_url: nil,
  use_stripe_sdk: nil
)
  @confirmation_token = confirmation_token
  @expand = expand
  @mandate_data = mandate_data
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @return_url = return_url
  @use_stripe_sdk = use_stripe_sdk
end

Instance Attribute Details

#confirmation_tokenObject

ID of the ConfirmationToken used to confirm this SetupIntent.

If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.



3670
3671
3672
# File 'lib/stripe/services/setup_intent_service.rb', line 3670

def confirmation_token
  @confirmation_token
end

#expandObject

Specifies which fields in the response should be expanded.



3672
3673
3674
# File 'lib/stripe/services/setup_intent_service.rb', line 3672

def expand
  @expand
end

#mandate_dataObject

Attribute for param field mandate_data



3674
3675
3676
# File 'lib/stripe/services/setup_intent_service.rb', line 3674

def mandate_data
  @mandate_data
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.



3676
3677
3678
# File 'lib/stripe/services/setup_intent_service.rb', line 3676

def payment_method
  @payment_method
end

#payment_method_dataObject

When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.



3679
3680
3681
# File 'lib/stripe/services/setup_intent_service.rb', line 3679

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this SetupIntent.



3681
3682
3683
# File 'lib/stripe/services/setup_intent_service.rb', line 3681

def payment_method_options
  @payment_method_options
end

#return_urlObject

The URL to redirect your customer back to after they authenticate on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.



3685
3686
3687
# File 'lib/stripe/services/setup_intent_service.rb', line 3685

def return_url
  @return_url
end

#use_stripe_sdkObject

Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.



3687
3688
3689
# File 'lib/stripe/services/setup_intent_service.rb', line 3687

def use_stripe_sdk
  @use_stripe_sdk
end