Class: Stripe::SetupIntentService::ConfirmParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Defined Under Namespace

Classes: MandateData, PaymentMethodData, PaymentMethodOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(confirmation_token: nil, expand: nil, mandate_data: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, use_stripe_sdk: nil) ⇒ ConfirmParams

Returns a new instance of ConfirmParams.



3891
3892
3893
3894
3895
3896
3897
3898
3899
3900
3901
3902
3903
3904
3905
3906
3907
3908
3909
# File 'lib/stripe/services/setup_intent_service.rb', line 3891

def initialize(
  confirmation_token: nil,
  expand: nil,
  mandate_data: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  return_url: nil,
  use_stripe_sdk: nil
)
  @confirmation_token = confirmation_token
  @expand = expand
  @mandate_data = mandate_data
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @return_url = return_url
  @use_stripe_sdk = use_stripe_sdk
end

Instance Attribute Details

#confirmation_tokenObject

ID of the ConfirmationToken used to confirm this SetupIntent.

If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.



3865
3866
3867
# File 'lib/stripe/services/setup_intent_service.rb', line 3865

def confirmation_token
  @confirmation_token
end

#expandObject

Specifies which fields in the response should be expanded.



3868
3869
3870
# File 'lib/stripe/services/setup_intent_service.rb', line 3868

def expand
  @expand
end

#mandate_dataObject

Attribute for param field mandate_data



3871
3872
3873
# File 'lib/stripe/services/setup_intent_service.rb', line 3871

def mandate_data
  @mandate_data
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.



3874
3875
3876
# File 'lib/stripe/services/setup_intent_service.rb', line 3874

def payment_method
  @payment_method
end

#payment_method_dataObject

When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.



3878
3879
3880
# File 'lib/stripe/services/setup_intent_service.rb', line 3878

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this SetupIntent.



3881
3882
3883
# File 'lib/stripe/services/setup_intent_service.rb', line 3881

def payment_method_options
  @payment_method_options
end

#return_urlObject

The URL to redirect your customer back to after they authenticate on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.



3886
3887
3888
# File 'lib/stripe/services/setup_intent_service.rb', line 3886

def return_url
  @return_url
end

#use_stripe_sdkObject

Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.



3889
3890
3891
# File 'lib/stripe/services/setup_intent_service.rb', line 3889

def use_stripe_sdk
  @use_stripe_sdk
end