Class: Stripe::SetupIntentService::ConfirmParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



2182
2183
2184
2185
2186
2187
# File 'lib/stripe/services/setup_intent_service.rb', line 2182

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



2174
2175
2176
# File 'lib/stripe/services/setup_intent_service.rb', line 2174

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



2176
2177
2178
# File 'lib/stripe/services/setup_intent_service.rb', line 2176

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



2178
2179
2180
# File 'lib/stripe/services/setup_intent_service.rb', line 2178

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



2180
2181
2182
# File 'lib/stripe/services/setup_intent_service.rb', line 2180

def type
  @type
end