Class: Stripe::SetupIntentService::ConfirmParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



2398
2399
2400
2401
2402
2403
# File 'lib/stripe/services/setup_intent_service.rb', line 2398

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



2390
2391
2392
# File 'lib/stripe/services/setup_intent_service.rb', line 2390

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



2392
2393
2394
# File 'lib/stripe/services/setup_intent_service.rb', line 2392

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



2394
2395
2396
# File 'lib/stripe/services/setup_intent_service.rb', line 2394

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



2396
2397
2398
# File 'lib/stripe/services/setup_intent_service.rb', line 2396

def type
  @type
end