Class: Stripe::SetupIntentService::ConfirmParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



2384
2385
2386
2387
2388
2389
# File 'lib/stripe/services/setup_intent_service.rb', line 2384

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



2376
2377
2378
# File 'lib/stripe/services/setup_intent_service.rb', line 2376

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



2378
2379
2380
# File 'lib/stripe/services/setup_intent_service.rb', line 2378

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



2380
2381
2382
# File 'lib/stripe/services/setup_intent_service.rb', line 2380

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



2382
2383
2384
# File 'lib/stripe/services/setup_intent_service.rb', line 2382

def type
  @type
end