Class: Stripe::SetupIntentService::ConfirmParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



2693
2694
2695
2696
2697
2698
# File 'lib/stripe/services/setup_intent_service.rb', line 2693

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



2682
2683
2684
# File 'lib/stripe/services/setup_intent_service.rb', line 2682

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



2685
2686
2687
# File 'lib/stripe/services/setup_intent_service.rb', line 2685

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



2688
2689
2690
# File 'lib/stripe/services/setup_intent_service.rb', line 2688

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



2691
2692
2693
# File 'lib/stripe/services/setup_intent_service.rb', line 2691

def type
  @type
end