Class: Stripe::SetupIntentService::ConfirmParams::MandateData::CustomerAcceptance::Online

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ip_address: nil, user_agent: nil) ⇒ Online

Returns a new instance of Online.



2370
2371
2372
2373
# File 'lib/stripe/services/setup_intent_service.rb', line 2370

def initialize(ip_address: nil, user_agent: nil)
  @ip_address = ip_address
  @user_agent = user_agent
end

Instance Attribute Details

#ip_addressObject

The IP address from which the Mandate was accepted by the customer.



2366
2367
2368
# File 'lib/stripe/services/setup_intent_service.rb', line 2366

def ip_address
  @ip_address
end

#user_agentObject

The user agent of the browser from which the Mandate was accepted by the customer.



2368
2369
2370
# File 'lib/stripe/services/setup_intent_service.rb', line 2368

def user_agent
  @user_agent
end