Class: Stripe::SetupIntentService::ConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::ConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
2837 2838 2839 2840 2841 2842 2843 2844 2845 2846 2847 2848 2849 2850 2851 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2837 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
2825 2826 2827 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2825 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
2827 2828 2829 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2827 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
2829 2830 2831 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2829 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
2831 2832 2833 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2831 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
2833 2834 2835 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2833 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
2835 2836 2837 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2835 def suffix @suffix end |