Class: Stripe::SetupIntentService::ConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::ConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2430 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
2418 2419 2420 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2418 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
2420 2421 2422 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2420 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
2422 2423 2424 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2422 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
2424 2425 2426 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2424 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
2426 2427 2428 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2426 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
2428 2429 2430 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2428 def suffix @suffix end |