Class: Stripe::SetupIntentService::ConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::ConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2815 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
2803 2804 2805 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2803 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
2805 2806 2807 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2805 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
2807 2808 2809 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2807 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
2809 2810 2811 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2809 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
2811 2812 2813 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2811 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
2813 2814 2815 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2813 def suffix @suffix end |