Class: Stripe::SetupIntentService::ConfirmParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::ConfirmParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step.
-
#default_for ⇒ Object
List of Stripe products where this mandate can be selected automatically.
-
#interval_description ⇒ Object
Description of the mandate interval.
-
#payment_schedule ⇒ Object
Payment schedule for the mandate.
-
#transaction_type ⇒ Object
Transaction type of the mandate.
Instance Method Summary collapse
-
#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
3255 3256 3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3255 def initialize( custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil ) @custom_mandate_url = custom_mandate_url @default_for = default_for @interval_description = interval_description @payment_schedule = payment_schedule @transaction_type = transaction_type end |
Instance Attribute Details
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.
3245 3246 3247 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3245 def custom_mandate_url @custom_mandate_url end |
#default_for ⇒ Object
List of Stripe products where this mandate can be selected automatically.
3247 3248 3249 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3247 def default_for @default_for end |
#interval_description ⇒ Object
Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.
3249 3250 3251 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3249 def interval_description @interval_description end |
#payment_schedule ⇒ Object
Payment schedule for the mandate.
3251 3252 3253 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3251 def payment_schedule @payment_schedule end |
#transaction_type ⇒ Object
Transaction type of the mandate.
3253 3254 3255 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3253 def transaction_type @transaction_type end |