Class: Stripe::SetupIntentService::ConfirmParams::PaymentMethodOptions::AcssDebit::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
3264
3265
3266
# File 'lib/stripe/services/setup_intent_service.rb', line 3254

def initialize(
  custom_mandate_url: nil,
  default_for: nil,
  interval_description: nil,
  payment_schedule: nil,
  transaction_type: nil
)
  @custom_mandate_url = custom_mandate_url
  @default_for = default_for
  @interval_description = interval_description
  @payment_schedule = payment_schedule
  @transaction_type = transaction_type
end

Instance Attribute Details

#custom_mandate_urlObject

A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.



3244
3245
3246
# File 'lib/stripe/services/setup_intent_service.rb', line 3244

def custom_mandate_url
  @custom_mandate_url
end

#default_forObject

List of Stripe products where this mandate can be selected automatically.



3246
3247
3248
# File 'lib/stripe/services/setup_intent_service.rb', line 3246

def default_for
  @default_for
end

#interval_descriptionObject

Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.



3248
3249
3250
# File 'lib/stripe/services/setup_intent_service.rb', line 3248

def interval_description
  @interval_description
end

#payment_scheduleObject

Payment schedule for the mandate.



3250
3251
3252
# File 'lib/stripe/services/setup_intent_service.rb', line 3250

def payment_schedule
  @payment_schedule
end

#transaction_typeObject

Transaction type of the mandate.



3252
3253
3254
# File 'lib/stripe/services/setup_intent_service.rb', line 3252

def transaction_type
  @transaction_type
end