Class: Stripe::SetupIntentService::ConfirmParams::PaymentMethodOptions::AcssDebit::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
3021
3022
3023
# File 'lib/stripe/services/setup_intent_service.rb', line 3011

def initialize(
  custom_mandate_url: nil,
  default_for: nil,
  interval_description: nil,
  payment_schedule: nil,
  transaction_type: nil
)
  @custom_mandate_url = custom_mandate_url
  @default_for = default_for
  @interval_description = interval_description
  @payment_schedule = payment_schedule
  @transaction_type = transaction_type
end

Instance Attribute Details

#custom_mandate_urlObject

A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.



3001
3002
3003
# File 'lib/stripe/services/setup_intent_service.rb', line 3001

def custom_mandate_url
  @custom_mandate_url
end

#default_forObject

List of Stripe products where this mandate can be selected automatically.



3003
3004
3005
# File 'lib/stripe/services/setup_intent_service.rb', line 3003

def default_for
  @default_for
end

#interval_descriptionObject

Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.



3005
3006
3007
# File 'lib/stripe/services/setup_intent_service.rb', line 3005

def interval_description
  @interval_description
end

#payment_scheduleObject

Payment schedule for the mandate.



3007
3008
3009
# File 'lib/stripe/services/setup_intent_service.rb', line 3007

def payment_schedule
  @payment_schedule
end

#transaction_typeObject

Transaction type of the mandate.



3009
3010
3011
# File 'lib/stripe/services/setup_intent_service.rb', line 3009

def transaction_type
  @transaction_type
end