Class: Stripe::SetupIntentService::ConfirmParams::PaymentMethodOptions::AcssDebit::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



3032
3033
3034
3035
3036
3037
3038
3039
3040
3041
3042
3043
3044
# File 'lib/stripe/services/setup_intent_service.rb', line 3032

def initialize(
  custom_mandate_url: nil,
  default_for: nil,
  interval_description: nil,
  payment_schedule: nil,
  transaction_type: nil
)
  @custom_mandate_url = custom_mandate_url
  @default_for = default_for
  @interval_description = interval_description
  @payment_schedule = payment_schedule
  @transaction_type = transaction_type
end

Instance Attribute Details

#custom_mandate_urlObject

A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.



3022
3023
3024
# File 'lib/stripe/services/setup_intent_service.rb', line 3022

def custom_mandate_url
  @custom_mandate_url
end

#default_forObject

List of Stripe products where this mandate can be selected automatically.



3024
3025
3026
# File 'lib/stripe/services/setup_intent_service.rb', line 3024

def default_for
  @default_for
end

#interval_descriptionObject

Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.



3026
3027
3028
# File 'lib/stripe/services/setup_intent_service.rb', line 3026

def interval_description
  @interval_description
end

#payment_scheduleObject

Payment schedule for the mandate.



3028
3029
3030
# File 'lib/stripe/services/setup_intent_service.rb', line 3028

def payment_schedule
  @payment_schedule
end

#transaction_typeObject

Transaction type of the mandate.



3030
3031
3032
# File 'lib/stripe/services/setup_intent_service.rb', line 3030

def transaction_type
  @transaction_type
end