Class: Stripe::SetupIntentService::ConfirmParams::PaymentMethodOptions::Card::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::ConfirmParams::PaymentMethodOptions::Card::MandateOptions
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments.
-
#amount_type ⇒ Object
One of ‘fixed` or `maximum`.
-
#currency ⇒ Object
Currency in which future payments will be charged.
-
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
-
#end_date ⇒ Object
End date of the mandate or subscription.
-
#interval ⇒ Object
Specifies payment frequency.
-
#interval_count ⇒ Object
The number of intervals between payments.
-
#reference ⇒ Object
Unique identifier for the mandate or subscription.
-
#start_date ⇒ Object
Start date of the mandate or subscription.
-
#supported_types ⇒ Object
Specifies the type of mandates supported.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, currency: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_type: nil, currency: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 3125 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3103 def initialize( amount: nil, amount_type: nil, currency: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil ) @amount = amount @amount_type = amount_type @currency = currency @description = description @end_date = end_date @interval = interval @interval_count = interval_count @reference = reference @start_date = start_date @supported_types = supported_types end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments.
3083 3084 3085 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3083 def amount @amount end |
#amount_type ⇒ Object
One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.
3085 3086 3087 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3085 def amount_type @amount_type end |
#currency ⇒ Object
Currency in which future payments will be charged. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
3087 3088 3089 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3087 def currency @currency end |
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
3089 3090 3091 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3089 def description @description end |
#end_date ⇒ Object
End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.
3091 3092 3093 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3091 def end_date @end_date end |
#interval ⇒ Object
Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.
3093 3094 3095 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3093 def interval @interval end |
#interval_count ⇒ Object
The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.
3095 3096 3097 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3095 def interval_count @interval_count end |
#reference ⇒ Object
Unique identifier for the mandate or subscription.
3097 3098 3099 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3097 def reference @reference end |
#start_date ⇒ Object
Start date of the mandate or subscription. Start date should not be lesser than yesterday.
3099 3100 3101 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3099 def start_date @start_date end |
#supported_types ⇒ Object
Specifies the type of mandates supported. Possible values are ‘india`.
3101 3102 3103 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3101 def supported_types @supported_types end |