Class: Stripe::SetupIntentService::ConfirmParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::ConfirmParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
3502 3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3502 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
3492 3493 3494 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3492 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
3494 3495 3496 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3494 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
3496 3497 3498 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3496 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
3498 3499 3500 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3498 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
3500 3501 3502 |
# File 'lib/stripe/services/setup_intent_service.rb', line 3500 def reference @reference end |