Class: Stripe::SetupIntentService::ConfirmParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



3484
3485
3486
3487
3488
3489
3490
3491
3492
3493
3494
3495
3496
3497
3498
3499
3500
# File 'lib/stripe/services/setup_intent_service.rb', line 3484

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil,
  start_date: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
  @start_date = start_date
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when ‘amount_type` is `fixed`.



3470
3471
3472
# File 'lib/stripe/services/setup_intent_service.rb', line 3470

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.



3472
3473
3474
# File 'lib/stripe/services/setup_intent_service.rb', line 3472

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



3474
3475
3476
# File 'lib/stripe/services/setup_intent_service.rb', line 3474

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected.



3476
3477
3478
# File 'lib/stripe/services/setup_intent_service.rb', line 3476

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.



3478
3479
3480
# File 'lib/stripe/services/setup_intent_service.rb', line 3478

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Defaults to retail.



3480
3481
3482
# File 'lib/stripe/services/setup_intent_service.rb', line 3480

def purpose
  @purpose
end

#start_dateObject

Date, in YYYY-MM-DD format, from which payments will be collected. Defaults to confirmation time.



3482
3483
3484
# File 'lib/stripe/services/setup_intent_service.rb', line 3482

def start_date
  @start_date
end