Class: Stripe::SetupIntentService::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
# File 'lib/stripe/services/setup_intent_service.rb', line 3560

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



3550
3551
3552
# File 'lib/stripe/services/setup_intent_service.rb', line 3550

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



3552
3553
3554
# File 'lib/stripe/services/setup_intent_service.rb', line 3552

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



3554
3555
3556
# File 'lib/stripe/services/setup_intent_service.rb', line 3554

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



3556
3557
3558
# File 'lib/stripe/services/setup_intent_service.rb', line 3556

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



3558
3559
3560
# File 'lib/stripe/services/setup_intent_service.rb', line 3558

def return_url
  @return_url
end