Class: Stripe::SetupIntentService::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Defined Under Namespace

Classes: AutomaticPaymentMethods, MandateData, PaymentMethodData, PaymentMethodOptions, SingleUse

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(attach_to_self: nil, automatic_payment_methods: nil, confirm: nil, confirmation_token: nil, customer: nil, description: nil, expand: nil, flow_directions: nil, mandate_data: nil, metadata: nil, on_behalf_of: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, single_use: nil, usage: nil, use_stripe_sdk: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
# File 'lib/stripe/services/setup_intent_service.rb', line 1140

def initialize(
  attach_to_self: nil,
  automatic_payment_methods: nil,
  confirm: nil,
  confirmation_token: nil,
  customer: nil,
  description: nil,
  expand: nil,
  flow_directions: nil,
  mandate_data: nil,
  metadata: nil,
  on_behalf_of: nil,
  payment_method: nil,
  payment_method_configuration: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  return_url: nil,
  single_use: nil,
  usage: nil,
  use_stripe_sdk: nil
)
  @attach_to_self = attach_to_self
  @automatic_payment_methods = automatic_payment_methods
  @confirm = confirm
  @confirmation_token = confirmation_token
  @customer = customer
  @description = description
  @expand = expand
  @flow_directions = flow_directions
  @mandate_data = mandate_data
  @metadata = 
  @on_behalf_of = on_behalf_of
  @payment_method = payment_method
  @payment_method_configuration = payment_method_configuration
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @return_url = return_url
  @single_use = single_use
  @usage = usage
  @use_stripe_sdk = use_stripe_sdk
end

Instance Attribute Details

#attach_to_selfObject

If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.

It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.



1091
1092
1093
# File 'lib/stripe/services/setup_intent_service.rb', line 1091

def attach_to_self
  @attach_to_self
end

#automatic_payment_methodsObject

When you enable this parameter, this SetupIntent accepts payment methods that you enable in the Dashboard and that are compatible with its other parameters.



1093
1094
1095
# File 'lib/stripe/services/setup_intent_service.rb', line 1093

def automatic_payment_methods
  @automatic_payment_methods
end

#confirmObject

Set to ‘true` to attempt to confirm this SetupIntent immediately. This parameter defaults to `false`. If a card is the attached payment method, you can provide a `return_url` in case further authentication is necessary.



1095
1096
1097
# File 'lib/stripe/services/setup_intent_service.rb', line 1095

def confirm
  @confirm
end

#confirmation_tokenObject

ID of the ConfirmationToken used to confirm this SetupIntent.

If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.



1099
1100
1101
# File 'lib/stripe/services/setup_intent_service.rb', line 1099

def confirmation_token
  @confirmation_token
end

#customerObject

ID of the Customer this SetupIntent belongs to, if one exists.

If present, the SetupIntent’s payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.



1103
1104
1105
# File 'lib/stripe/services/setup_intent_service.rb', line 1103

def customer
  @customer
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1105
1106
1107
# File 'lib/stripe/services/setup_intent_service.rb', line 1105

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



1107
1108
1109
# File 'lib/stripe/services/setup_intent_service.rb', line 1107

def expand
  @expand
end

#flow_directionsObject

Indicates the directions of money movement for which this payment method is intended to be used.

Include ‘inbound` if you intend to use the payment method as the origin to pull funds from. Include `outbound` if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.



1111
1112
1113
# File 'lib/stripe/services/setup_intent_service.rb', line 1111

def flow_directions
  @flow_directions
end

#mandate_dataObject

This hash contains details about the mandate to create. This parameter can only be used with [‘confirm=true`](stripe.com/docs/api/setup_intents/create#create_setup_intent-confirm).



1113
1114
1115
# File 'lib/stripe/services/setup_intent_service.rb', line 1113

def mandate_data
  @mandate_data
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1115
1116
1117
# File 'lib/stripe/services/setup_intent_service.rb', line 1115

def 
  @metadata
end

#on_behalf_ofObject

The Stripe account ID created for this SetupIntent.



1117
1118
1119
# File 'lib/stripe/services/setup_intent_service.rb', line 1117

def on_behalf_of
  @on_behalf_of
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.



1119
1120
1121
# File 'lib/stripe/services/setup_intent_service.rb', line 1119

def payment_method
  @payment_method
end

#payment_method_configurationObject

The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this SetupIntent.



1121
1122
1123
# File 'lib/stripe/services/setup_intent_service.rb', line 1121

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_dataObject

When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.



1124
1125
1126
# File 'lib/stripe/services/setup_intent_service.rb', line 1124

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this SetupIntent.



1126
1127
1128
# File 'lib/stripe/services/setup_intent_service.rb', line 1126

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, card) that this SetupIntent can use. If you don’t provide this, Stripe will dynamically show relevant payment methods from your [payment method settings](dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).



1128
1129
1130
# File 'lib/stripe/services/setup_intent_service.rb', line 1128

def payment_method_types
  @payment_method_types
end

#return_urlObject

The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. To redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter can only be used with [‘confirm=true`](stripe.com/docs/api/setup_intents/create#create_setup_intent-confirm).



1130
1131
1132
# File 'lib/stripe/services/setup_intent_service.rb', line 1130

def return_url
  @return_url
end

#single_useObject

If you populate this hash, this SetupIntent generates a ‘single_use` mandate after successful completion.

Single-use mandates are only valid for the following payment methods: ‘acss_debit`, `alipay`, `au_becs_debit`, `bacs_debit`, `bancontact`, `boleto`, `ideal`, `link`, `sepa_debit`, and `us_bank_account`.



1134
1135
1136
# File 'lib/stripe/services/setup_intent_service.rb', line 1134

def single_use
  @single_use
end

#usageObject

Indicates how the payment method is intended to be used in the future. If not provided, this value defaults to ‘off_session`.



1136
1137
1138
# File 'lib/stripe/services/setup_intent_service.rb', line 1136

def usage
  @usage
end

#use_stripe_sdkObject

Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.



1138
1139
1140
# File 'lib/stripe/services/setup_intent_service.rb', line 1138

def use_stripe_sdk
  @use_stripe_sdk
end