Class: Stripe::SetupIntentService::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Defined Under Namespace

Classes: AutomaticPaymentMethods, MandateData, PaymentMethodData, PaymentMethodOptions, SingleUse

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(attach_to_self: nil, automatic_payment_methods: nil, confirm: nil, confirmation_token: nil, customer: nil, description: nil, expand: nil, flow_directions: nil, mandate_data: nil, metadata: nil, on_behalf_of: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, single_use: nil, usage: nil, use_stripe_sdk: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
# File 'lib/stripe/services/setup_intent_service.rb', line 1049

def initialize(
  attach_to_self: nil,
  automatic_payment_methods: nil,
  confirm: nil,
  confirmation_token: nil,
  customer: nil,
  description: nil,
  expand: nil,
  flow_directions: nil,
  mandate_data: nil,
  metadata: nil,
  on_behalf_of: nil,
  payment_method: nil,
  payment_method_configuration: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  return_url: nil,
  single_use: nil,
  usage: nil,
  use_stripe_sdk: nil
)
  @attach_to_self = attach_to_self
  @automatic_payment_methods = automatic_payment_methods
  @confirm = confirm
  @confirmation_token = confirmation_token
  @customer = customer
  @description = description
  @expand = expand
  @flow_directions = flow_directions
  @mandate_data = mandate_data
  @metadata = 
  @on_behalf_of = on_behalf_of
  @payment_method = payment_method
  @payment_method_configuration = payment_method_configuration
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @return_url = return_url
  @single_use = single_use
  @usage = usage
  @use_stripe_sdk = use_stripe_sdk
end

Instance Attribute Details

#attach_to_selfObject

If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.

It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.



1000
1001
1002
# File 'lib/stripe/services/setup_intent_service.rb', line 1000

def attach_to_self
  @attach_to_self
end

#automatic_payment_methodsObject

When you enable this parameter, this SetupIntent accepts payment methods that you enable in the Dashboard and that are compatible with its other parameters.



1002
1003
1004
# File 'lib/stripe/services/setup_intent_service.rb', line 1002

def automatic_payment_methods
  @automatic_payment_methods
end

#confirmObject

Set to ‘true` to attempt to confirm this SetupIntent immediately. This parameter defaults to `false`. If a card is the attached payment method, you can provide a `return_url` in case further authentication is necessary.



1004
1005
1006
# File 'lib/stripe/services/setup_intent_service.rb', line 1004

def confirm
  @confirm
end

#confirmation_tokenObject

ID of the ConfirmationToken used to confirm this SetupIntent.

If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.



1008
1009
1010
# File 'lib/stripe/services/setup_intent_service.rb', line 1008

def confirmation_token
  @confirmation_token
end

#customerObject

ID of the Customer this SetupIntent belongs to, if one exists.

If present, the SetupIntent’s payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.



1012
1013
1014
# File 'lib/stripe/services/setup_intent_service.rb', line 1012

def customer
  @customer
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1014
1015
1016
# File 'lib/stripe/services/setup_intent_service.rb', line 1014

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



1016
1017
1018
# File 'lib/stripe/services/setup_intent_service.rb', line 1016

def expand
  @expand
end

#flow_directionsObject

Indicates the directions of money movement for which this payment method is intended to be used.

Include ‘inbound` if you intend to use the payment method as the origin to pull funds from. Include `outbound` if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.



1020
1021
1022
# File 'lib/stripe/services/setup_intent_service.rb', line 1020

def flow_directions
  @flow_directions
end

#mandate_dataObject

This hash contains details about the mandate to create. This parameter can only be used with [‘confirm=true`](stripe.com/docs/api/setup_intents/create#create_setup_intent-confirm).



1022
1023
1024
# File 'lib/stripe/services/setup_intent_service.rb', line 1022

def mandate_data
  @mandate_data
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1024
1025
1026
# File 'lib/stripe/services/setup_intent_service.rb', line 1024

def 
  @metadata
end

#on_behalf_ofObject

The Stripe account ID created for this SetupIntent.



1026
1027
1028
# File 'lib/stripe/services/setup_intent_service.rb', line 1026

def on_behalf_of
  @on_behalf_of
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.



1028
1029
1030
# File 'lib/stripe/services/setup_intent_service.rb', line 1028

def payment_method
  @payment_method
end

#payment_method_configurationObject

The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this SetupIntent.



1030
1031
1032
# File 'lib/stripe/services/setup_intent_service.rb', line 1030

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_dataObject

When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.



1033
1034
1035
# File 'lib/stripe/services/setup_intent_service.rb', line 1033

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this SetupIntent.



1035
1036
1037
# File 'lib/stripe/services/setup_intent_service.rb', line 1035

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, card) that this SetupIntent can use. If you don’t provide this, Stripe will dynamically show relevant payment methods from your [payment method settings](dashboard.stripe.com/settings/payment_methods).



1037
1038
1039
# File 'lib/stripe/services/setup_intent_service.rb', line 1037

def payment_method_types
  @payment_method_types
end

#return_urlObject

The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. To redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter can only be used with [‘confirm=true`](stripe.com/docs/api/setup_intents/create#create_setup_intent-confirm).



1039
1040
1041
# File 'lib/stripe/services/setup_intent_service.rb', line 1039

def return_url
  @return_url
end

#single_useObject

If you populate this hash, this SetupIntent generates a ‘single_use` mandate after successful completion.

Single-use mandates are only valid for the following payment methods: ‘acss_debit`, `alipay`, `au_becs_debit`, `bacs_debit`, `bancontact`, `boleto`, `ideal`, `link`, `sepa_debit`, and `us_bank_account`.



1043
1044
1045
# File 'lib/stripe/services/setup_intent_service.rb', line 1043

def single_use
  @single_use
end

#usageObject

Indicates how the payment method is intended to be used in the future. If not provided, this value defaults to ‘off_session`.



1045
1046
1047
# File 'lib/stripe/services/setup_intent_service.rb', line 1045

def usage
  @usage
end

#use_stripe_sdkObject

Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.



1047
1048
1049
# File 'lib/stripe/services/setup_intent_service.rb', line 1047

def use_stripe_sdk
  @use_stripe_sdk
end