Class: Stripe::SetupIntentService::CreateParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



107
108
109
110
111
112
# File 'lib/stripe/services/setup_intent_service.rb', line 107

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



99
100
101
# File 'lib/stripe/services/setup_intent_service.rb', line 99

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



101
102
103
# File 'lib/stripe/services/setup_intent_service.rb', line 101

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



103
104
105
# File 'lib/stripe/services/setup_intent_service.rb', line 103

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



105
106
107
# File 'lib/stripe/services/setup_intent_service.rb', line 105

def type
  @type
end