Class: Stripe::SetupIntentService::CreateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::CreateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/stripe/services/setup_intent_service.rb', line 371 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
359 360 361 |
# File 'lib/stripe/services/setup_intent_service.rb', line 359 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
361 362 363 |
# File 'lib/stripe/services/setup_intent_service.rb', line 361 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
363 364 365 |
# File 'lib/stripe/services/setup_intent_service.rb', line 363 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
365 366 367 |
# File 'lib/stripe/services/setup_intent_service.rb', line 365 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
367 368 369 |
# File 'lib/stripe/services/setup_intent_service.rb', line 367 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
369 370 371 |
# File 'lib/stripe/services/setup_intent_service.rb', line 369 def suffix @suffix end |