Class: Stripe::SetupIntentService::CreateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::CreateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/stripe/services/setup_intent_service.rb', line 349 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
337 338 339 |
# File 'lib/stripe/services/setup_intent_service.rb', line 337 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
339 340 341 |
# File 'lib/stripe/services/setup_intent_service.rb', line 339 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
341 342 343 |
# File 'lib/stripe/services/setup_intent_service.rb', line 341 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
343 344 345 |
# File 'lib/stripe/services/setup_intent_service.rb', line 343 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
345 346 347 |
# File 'lib/stripe/services/setup_intent_service.rb', line 345 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
347 348 349 |
# File 'lib/stripe/services/setup_intent_service.rb', line 347 def suffix @suffix end |