Class: Stripe::SetupIntentService::CreateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::CreateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/stripe/services/setup_intent_service.rb', line 453 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
443 444 445 |
# File 'lib/stripe/services/setup_intent_service.rb', line 443 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
445 446 447 |
# File 'lib/stripe/services/setup_intent_service.rb', line 445 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
447 448 449 |
# File 'lib/stripe/services/setup_intent_service.rb', line 447 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
449 450 451 |
# File 'lib/stripe/services/setup_intent_service.rb', line 449 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
451 452 453 |
# File 'lib/stripe/services/setup_intent_service.rb', line 451 def routing_number @routing_number end |