Class: Stripe::SetupIntentService::CreateParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::CreateParams::PaymentMethodOptions
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Defined Under Namespace
Classes: AcssDebit, AmazonPay, BacsDebit, Card, CardPresent, Link, Paypal, Payto, SepaDebit, UsBankAccount
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If this is a ‘acss_debit` SetupIntent, this sub-hash contains details about the ACSS Debit payment method options.
-
#amazon_pay ⇒ Object
If this is a ‘amazon_pay` SetupIntent, this sub-hash contains details about the AmazonPay payment method options.
-
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` SetupIntent, this sub-hash contains details about the Bacs Debit payment method options.
-
#card ⇒ Object
Configuration for any card setup attempted on this SetupIntent.
-
#card_present ⇒ Object
If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the card-present payment method options.
-
#link ⇒ Object
If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options.
-
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.
-
#payto ⇒ Object
If this is a ‘payto` SetupIntent, this sub-hash contains details about the PayTo payment method options.
-
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` SetupIntent, this sub-hash contains details about the SEPA Debit payment method options.
-
#us_bank_account ⇒ Object
If this is a ‘us_bank_account` SetupIntent, this sub-hash contains details about the US bank account payment method options.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, amazon_pay: nil, bacs_debit: nil, card: nil, card_present: nil, link: nil, paypal: nil, payto: nil, sepa_debit: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, amazon_pay: nil, bacs_debit: nil, card: nil, card_present: nil, link: nil, paypal: nil, payto: nil, sepa_debit: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1120 def initialize( acss_debit: nil, amazon_pay: nil, bacs_debit: nil, card: nil, card_present: nil, link: nil, paypal: nil, payto: nil, sepa_debit: nil, us_bank_account: nil ) @acss_debit = acss_debit @amazon_pay = amazon_pay @bacs_debit = bacs_debit @card = card @card_present = card_present @link = link @paypal = paypal @payto = payto @sepa_debit = sepa_debit @us_bank_account = us_bank_account end |
Instance Attribute Details
#acss_debit ⇒ Object
If this is a ‘acss_debit` SetupIntent, this sub-hash contains details about the ACSS Debit payment method options.
1100 1101 1102 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1100 def acss_debit @acss_debit end |
#amazon_pay ⇒ Object
If this is a ‘amazon_pay` SetupIntent, this sub-hash contains details about the AmazonPay payment method options.
1102 1103 1104 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1102 def amazon_pay @amazon_pay end |
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` SetupIntent, this sub-hash contains details about the Bacs Debit payment method options.
1104 1105 1106 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1104 def bacs_debit @bacs_debit end |
#card ⇒ Object
Configuration for any card setup attempted on this SetupIntent.
1106 1107 1108 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1106 def card @card end |
#card_present ⇒ Object
If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the card-present payment method options.
1108 1109 1110 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1108 def card_present @card_present end |
#link ⇒ Object
If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options.
1110 1111 1112 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1110 def link @link end |
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.
1112 1113 1114 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1112 def paypal @paypal end |
#payto ⇒ Object
If this is a ‘payto` SetupIntent, this sub-hash contains details about the PayTo payment method options.
1114 1115 1116 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1114 def payto @payto end |
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` SetupIntent, this sub-hash contains details about the SEPA Debit payment method options.
1116 1117 1118 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1116 def sepa_debit @sepa_debit end |
#us_bank_account ⇒ Object
If this is a ‘us_bank_account` SetupIntent, this sub-hash contains details about the US bank account payment method options.
1118 1119 1120 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1118 def us_bank_account @us_bank_account end |