Class: Stripe::SetupIntentService::CreateParams::PaymentMethodOptions::Paypal

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_agreement_id: nil, currency: nil, subsellers: nil) ⇒ Paypal

Returns a new instance of Paypal.



1022
1023
1024
1025
1026
# File 'lib/stripe/services/setup_intent_service.rb', line 1022

def initialize(billing_agreement_id: nil, currency: nil, subsellers: nil)
  @billing_agreement_id = billing_agreement_id
  @currency = currency
  @subsellers = subsellers
end

Instance Attribute Details

#billing_agreement_idObject

The PayPal Billing Agreement ID (BAID). This is an ID generated by PayPal which represents the mandate between the merchant and the customer.



1016
1017
1018
# File 'lib/stripe/services/setup_intent_service.rb', line 1016

def billing_agreement_id
  @billing_agreement_id
end

#currencyObject

Attribute for param field currency



1018
1019
1020
# File 'lib/stripe/services/setup_intent_service.rb', line 1018

def currency
  @currency
end

#subsellersObject

The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when [separate charges and transfers](stripe.com/docs/connect/separate-charges-and-transfers) are used.



1020
1021
1022
# File 'lib/stripe/services/setup_intent_service.rb', line 1020

def subsellers
  @subsellers
end