Class: Stripe::SetupIntentService::CreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
# File 'lib/stripe/services/setup_intent_service.rb', line 1062

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



1052
1053
1054
# File 'lib/stripe/services/setup_intent_service.rb', line 1052

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



1054
1055
1056
# File 'lib/stripe/services/setup_intent_service.rb', line 1054

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



1056
1057
1058
# File 'lib/stripe/services/setup_intent_service.rb', line 1056

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



1058
1059
1060
# File 'lib/stripe/services/setup_intent_service.rb', line 1058

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



1060
1061
1062
# File 'lib/stripe/services/setup_intent_service.rb', line 1060

def return_url
  @return_url
end