Class: Stripe::SetupIntentService::CreateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
# File 'lib/stripe/services/setup_intent_service.rb', line 1125

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



1115
1116
1117
# File 'lib/stripe/services/setup_intent_service.rb', line 1115

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



1117
1118
1119
# File 'lib/stripe/services/setup_intent_service.rb', line 1117

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



1119
1120
1121
# File 'lib/stripe/services/setup_intent_service.rb', line 1119

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



1121
1122
1123
# File 'lib/stripe/services/setup_intent_service.rb', line 1121

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



1123
1124
1125
# File 'lib/stripe/services/setup_intent_service.rb', line 1123

def return_url
  @return_url
end