Class: Stripe::SetupIntentService::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::RetrieveParams
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#client_secret ⇒ Object
The client secret of the SetupIntent.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
1100 1101 1102 1103 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1100 def initialize(client_secret: nil, expand: nil) @client_secret = client_secret @expand = end |
Instance Attribute Details
#client_secret ⇒ Object
The client secret of the SetupIntent. We require this string if you use a publishable key to retrieve the SetupIntent.
1096 1097 1098 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1096 def client_secret @client_secret end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1098 1099 1100 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1098 def @expand end |