Class: Stripe::SetupIntentService::RetrieveParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams

Returns a new instance of RetrieveParams.



1344
1345
1346
1347
# File 'lib/stripe/services/setup_intent_service.rb', line 1344

def initialize(client_secret: nil, expand: nil)
  @client_secret = client_secret
  @expand = expand
end

Instance Attribute Details

#client_secretObject

The client secret of the SetupIntent. We require this string if you use a publishable key to retrieve the SetupIntent.



1340
1341
1342
# File 'lib/stripe/services/setup_intent_service.rb', line 1340

def client_secret
  @client_secret
end

#expandObject

Specifies which fields in the response should be expanded.



1342
1343
1344
# File 'lib/stripe/services/setup_intent_service.rb', line 1342

def expand
  @expand
end