Class: Stripe::SetupIntentService::RetrieveParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams

Returns a new instance of RetrieveParams.



1257
1258
1259
1260
# File 'lib/stripe/services/setup_intent_service.rb', line 1257

def initialize(client_secret: nil, expand: nil)
  @client_secret = client_secret
  @expand = expand
end

Instance Attribute Details

#client_secretObject

The client secret of the SetupIntent. We require this string if you use a publishable key to retrieve the SetupIntent.



1253
1254
1255
# File 'lib/stripe/services/setup_intent_service.rb', line 1253

def client_secret
  @client_secret
end

#expandObject

Specifies which fields in the response should be expanded.



1255
1256
1257
# File 'lib/stripe/services/setup_intent_service.rb', line 1255

def expand
  @expand
end