Class: Stripe::SetupIntentService::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::RetrieveParams
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#client_secret ⇒ Object
The client secret of the SetupIntent.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
1257 1258 1259 1260 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1257 def initialize(client_secret: nil, expand: nil) @client_secret = client_secret @expand = end |
Instance Attribute Details
#client_secret ⇒ Object
The client secret of the SetupIntent. We require this string if you use a publishable key to retrieve the SetupIntent.
1253 1254 1255 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1253 def client_secret @client_secret end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1255 1256 1257 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1255 def @expand end |