Class: Stripe::SetupIntentService::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Defined Under Namespace

Classes: PaymentMethodData, PaymentMethodOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(attach_to_self: nil, customer: nil, customer_account: nil, description: nil, expand: nil, flow_directions: nil, metadata: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
# File 'lib/stripe/services/setup_intent_service.rb', line 2485

def initialize(
  attach_to_self: nil,
  customer: nil,
  customer_account: nil,
  description: nil,
  expand: nil,
  flow_directions: nil,
  metadata: nil,
  payment_method: nil,
  payment_method_configuration: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil
)
  @attach_to_self = attach_to_self
  @customer = customer
  @customer_account = 
  @description = description
  @expand = expand
  @flow_directions = flow_directions
  @metadata = 
  @payment_method = payment_method
  @payment_method_configuration = payment_method_configuration
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
end

Instance Attribute Details

#attach_to_selfObject

If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.

It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.



2454
2455
2456
# File 'lib/stripe/services/setup_intent_service.rb', line 2454

def attach_to_self
  @attach_to_self
end

#customerObject

ID of the Customer this SetupIntent belongs to, if one exists.

If present, the SetupIntent’s payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.



2458
2459
2460
# File 'lib/stripe/services/setup_intent_service.rb', line 2458

def customer
  @customer
end

#customer_accountObject

ID of the Account this SetupIntent belongs to, if one exists.

If present, the SetupIntent’s payment method will be attached to the Account on successful setup. Payment methods attached to other Accounts cannot be used with this SetupIntent.



2462
2463
2464
# File 'lib/stripe/services/setup_intent_service.rb', line 2462

def 
  @customer_account
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



2464
2465
2466
# File 'lib/stripe/services/setup_intent_service.rb', line 2464

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



2466
2467
2468
# File 'lib/stripe/services/setup_intent_service.rb', line 2466

def expand
  @expand
end

#flow_directionsObject

Indicates the directions of money movement for which this payment method is intended to be used.

Include ‘inbound` if you intend to use the payment method as the origin to pull funds from. Include `outbound` if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.



2470
2471
2472
# File 'lib/stripe/services/setup_intent_service.rb', line 2470

def flow_directions
  @flow_directions
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2472
2473
2474
# File 'lib/stripe/services/setup_intent_service.rb', line 2472

def 
  @metadata
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent. To unset this field to null, pass in an empty string.



2474
2475
2476
# File 'lib/stripe/services/setup_intent_service.rb', line 2474

def payment_method
  @payment_method
end

#payment_method_configurationObject

The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this SetupIntent.



2476
2477
2478
# File 'lib/stripe/services/setup_intent_service.rb', line 2476

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_dataObject

When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.



2479
2480
2481
# File 'lib/stripe/services/setup_intent_service.rb', line 2479

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this SetupIntent.



2481
2482
2483
# File 'lib/stripe/services/setup_intent_service.rb', line 2481

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, card) that this SetupIntent can set up. If you don’t provide this, Stripe will dynamically show relevant payment methods from your [payment method settings](dashboard.stripe.com/settings/payment_methods).



2483
2484
2485
# File 'lib/stripe/services/setup_intent_service.rb', line 2483

def payment_method_types
  @payment_method_types
end