Class: Stripe::SetupIntentService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::UpdateParams
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Defined Under Namespace
Classes: PaymentMethodData, PaymentMethodOptions
Instance Attribute Summary collapse
-
#attach_to_self ⇒ Object
If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.
-
#customer ⇒ Object
ID of the Customer this SetupIntent belongs to, if one exists.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#flow_directions ⇒ Object
Indicates the directions of money movement for which this payment method is intended to be used.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.
-
#payment_method_configuration ⇒ Object
The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this SetupIntent.
-
#payment_method_data ⇒ Object
When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.
-
#payment_method_options ⇒ Object
Payment method-specific configuration for this SetupIntent.
-
#payment_method_types ⇒ Object
The list of payment method types (for example, card) that this SetupIntent can set up.
Instance Method Summary collapse
-
#initialize(attach_to_self: nil, customer: nil, description: nil, expand: nil, flow_directions: nil, metadata: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(attach_to_self: nil, customer: nil, description: nil, expand: nil, flow_directions: nil, metadata: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2623 def initialize( attach_to_self: nil, customer: nil, description: nil, expand: nil, flow_directions: nil, metadata: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil ) @attach_to_self = attach_to_self @customer = customer @description = description @expand = @flow_directions = flow_directions @metadata = @payment_method = payment_method @payment_method_configuration = payment_method_configuration @payment_method_data = payment_method_data @payment_method_options = @payment_method_types = payment_method_types end |
Instance Attribute Details
#attach_to_self ⇒ Object
If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.
It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.
2586 2587 2588 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2586 def attach_to_self @attach_to_self end |
#customer ⇒ Object
ID of the Customer this SetupIntent belongs to, if one exists.
If present, the SetupIntent’s payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.
2591 2592 2593 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2591 def customer @customer end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
2594 2595 2596 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2594 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2597 2598 2599 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2597 def @expand end |
#flow_directions ⇒ Object
Indicates the directions of money movement for which this payment method is intended to be used.
Include ‘inbound` if you intend to use the payment method as the origin to pull funds from. Include `outbound` if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.
2602 2603 2604 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2602 def flow_directions @flow_directions end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2605 2606 2607 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2605 def @metadata end |
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent. To unset this field to null, pass in an empty string.
2608 2609 2610 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2608 def payment_method @payment_method end |
#payment_method_configuration ⇒ Object
The ID of the [payment method configuration](stripe.com/docs/api/payment_method_configurations) to use with this SetupIntent.
2611 2612 2613 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2611 def payment_method_configuration @payment_method_configuration end |
#payment_method_data ⇒ Object
When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](stripe.com/docs/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.
2615 2616 2617 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2615 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment method-specific configuration for this SetupIntent.
2618 2619 2620 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2618 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types (for example, card) that this SetupIntent can set up. If you don’t provide this, Stripe will dynamically show relevant payment methods from your [payment method settings](dashboard.stripe.com/settings/payment_methods).
2621 2622 2623 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2621 def payment_method_types @payment_method_types end |