Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::UpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1644 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1632 1633 1634 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1632 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
1634 1635 1636 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1634 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
1636 1637 1638 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1636 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
1638 1639 1640 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1638 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
1640 1641 1642 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1640 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
1642 1643 1644 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1642 def suffix @suffix end |