Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
# File 'lib/stripe/services/setup_intent_service.rb', line 1401

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1389
1390
1391
# File 'lib/stripe/services/setup_intent_service.rb', line 1389

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



1391
1392
1393
# File 'lib/stripe/services/setup_intent_service.rb', line 1391

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



1393
1394
1395
# File 'lib/stripe/services/setup_intent_service.rb', line 1393

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



1395
1396
1397
# File 'lib/stripe/services/setup_intent_service.rb', line 1395

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



1397
1398
1399
# File 'lib/stripe/services/setup_intent_service.rb', line 1397

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



1399
1400
1401
# File 'lib/stripe/services/setup_intent_service.rb', line 1399

def suffix
  @suffix
end