Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
# File 'lib/stripe/services/setup_intent_service.rb', line 1593

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1581
1582
1583
# File 'lib/stripe/services/setup_intent_service.rb', line 1581

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



1583
1584
1585
# File 'lib/stripe/services/setup_intent_service.rb', line 1583

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



1585
1586
1587
# File 'lib/stripe/services/setup_intent_service.rb', line 1585

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



1587
1588
1589
# File 'lib/stripe/services/setup_intent_service.rb', line 1587

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



1589
1590
1591
# File 'lib/stripe/services/setup_intent_service.rb', line 1589

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



1591
1592
1593
# File 'lib/stripe/services/setup_intent_service.rb', line 1591

def suffix
  @suffix
end