Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
# File 'lib/stripe/services/setup_intent_service.rb', line 1501

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1489
1490
1491
# File 'lib/stripe/services/setup_intent_service.rb', line 1489

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



1491
1492
1493
# File 'lib/stripe/services/setup_intent_service.rb', line 1491

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



1493
1494
1495
# File 'lib/stripe/services/setup_intent_service.rb', line 1493

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



1495
1496
1497
# File 'lib/stripe/services/setup_intent_service.rb', line 1495

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



1497
1498
1499
# File 'lib/stripe/services/setup_intent_service.rb', line 1497

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



1499
1500
1501
# File 'lib/stripe/services/setup_intent_service.rb', line 1499

def suffix
  @suffix
end