Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::UpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1501 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1489 1490 1491 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1489 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
1491 1492 1493 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1491 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
1493 1494 1495 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1493 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
1495 1496 1497 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1495 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
1497 1498 1499 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1497 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
1499 1500 1501 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1499 def suffix @suffix end |