Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
# File 'lib/stripe/services/setup_intent_service.rb', line 1309

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1297
1298
1299
# File 'lib/stripe/services/setup_intent_service.rb', line 1297

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



1299
1300
1301
# File 'lib/stripe/services/setup_intent_service.rb', line 1299

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



1301
1302
1303
# File 'lib/stripe/services/setup_intent_service.rb', line 1301

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



1303
1304
1305
# File 'lib/stripe/services/setup_intent_service.rb', line 1303

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



1305
1306
1307
# File 'lib/stripe/services/setup_intent_service.rb', line 1305

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



1307
1308
1309
# File 'lib/stripe/services/setup_intent_service.rb', line 1307

def suffix
  @suffix
end