Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::UpdateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1309 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1297 1298 1299 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1297 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
1299 1300 1301 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1299 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
1301 1302 1303 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1301 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
1303 1304 1305 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1303 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
1305 1306 1307 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1305 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
1307 1308 1309 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1307 def suffix @suffix end |