Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
# File 'lib/stripe/services/setup_intent_service.rb', line 1599

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1587
1588
1589
# File 'lib/stripe/services/setup_intent_service.rb', line 1587

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



1589
1590
1591
# File 'lib/stripe/services/setup_intent_service.rb', line 1589

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



1591
1592
1593
# File 'lib/stripe/services/setup_intent_service.rb', line 1591

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



1593
1594
1595
# File 'lib/stripe/services/setup_intent_service.rb', line 1593

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



1595
1596
1597
# File 'lib/stripe/services/setup_intent_service.rb', line 1595

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



1597
1598
1599
# File 'lib/stripe/services/setup_intent_service.rb', line 1597

def suffix
  @suffix
end