Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Defined Under Namespace
Classes: AcssDebit, AmazonPay, BacsDebit, Card, CardPresent, Link, Paypal, Payto, SepaDebit, UsBankAccount
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If this is a ‘acss_debit` SetupIntent, this sub-hash contains details about the ACSS Debit payment method options.
-
#amazon_pay ⇒ Object
If this is a ‘amazon_pay` SetupIntent, this sub-hash contains details about the AmazonPay payment method options.
-
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` SetupIntent, this sub-hash contains details about the Bacs Debit payment method options.
-
#card ⇒ Object
Configuration for any card setup attempted on this SetupIntent.
-
#card_present ⇒ Object
If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the card-present payment method options.
-
#link ⇒ Object
If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options.
-
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.
-
#payto ⇒ Object
If this is a ‘payto` SetupIntent, this sub-hash contains details about the PayTo payment method options.
-
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` SetupIntent, this sub-hash contains details about the SEPA Debit payment method options.
-
#us_bank_account ⇒ Object
If this is a ‘us_bank_account` SetupIntent, this sub-hash contains details about the US bank account payment method options.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, amazon_pay: nil, bacs_debit: nil, card: nil, card_present: nil, link: nil, paypal: nil, payto: nil, sepa_debit: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, amazon_pay: nil, bacs_debit: nil, card: nil, card_present: nil, link: nil, paypal: nil, payto: nil, sepa_debit: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
2427 2428 2429 2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2427 def initialize( acss_debit: nil, amazon_pay: nil, bacs_debit: nil, card: nil, card_present: nil, link: nil, paypal: nil, payto: nil, sepa_debit: nil, us_bank_account: nil ) @acss_debit = acss_debit @amazon_pay = amazon_pay @bacs_debit = bacs_debit @card = card @card_present = card_present @link = link @paypal = paypal @payto = payto @sepa_debit = sepa_debit @us_bank_account = us_bank_account end |
Instance Attribute Details
#acss_debit ⇒ Object
If this is a ‘acss_debit` SetupIntent, this sub-hash contains details about the ACSS Debit payment method options.
2407 2408 2409 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2407 def acss_debit @acss_debit end |
#amazon_pay ⇒ Object
If this is a ‘amazon_pay` SetupIntent, this sub-hash contains details about the AmazonPay payment method options.
2409 2410 2411 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2409 def amazon_pay @amazon_pay end |
#bacs_debit ⇒ Object
If this is a ‘bacs_debit` SetupIntent, this sub-hash contains details about the Bacs Debit payment method options.
2411 2412 2413 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2411 def bacs_debit @bacs_debit end |
#card ⇒ Object
Configuration for any card setup attempted on this SetupIntent.
2413 2414 2415 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2413 def card @card end |
#card_present ⇒ Object
If this is a ‘card_present` PaymentMethod, this sub-hash contains details about the card-present payment method options.
2415 2416 2417 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2415 def card_present @card_present end |
#link ⇒ Object
If this is a ‘link` PaymentMethod, this sub-hash contains details about the Link payment method options.
2417 2418 2419 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2417 def link @link end |
#paypal ⇒ Object
If this is a ‘paypal` PaymentMethod, this sub-hash contains details about the PayPal payment method options.
2419 2420 2421 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2419 def paypal @paypal end |
#payto ⇒ Object
If this is a ‘payto` SetupIntent, this sub-hash contains details about the PayTo payment method options.
2421 2422 2423 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2421 def payto @payto end |
#sepa_debit ⇒ Object
If this is a ‘sepa_debit` SetupIntent, this sub-hash contains details about the SEPA Debit payment method options.
2423 2424 2425 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2423 def sepa_debit @sepa_debit end |
#us_bank_account ⇒ Object
If this is a ‘us_bank_account` SetupIntent, this sub-hash contains details about the US bank account payment method options.
2425 2426 2427 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2425 def us_bank_account @us_bank_account end |