Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step.
-
#default_for ⇒ Object
List of Stripe products where this mandate can be selected automatically.
-
#interval_description ⇒ Object
Description of the mandate interval.
-
#payment_schedule ⇒ Object
Payment schedule for the mandate.
-
#transaction_type ⇒ Object
Transaction type of the mandate.
Instance Method Summary collapse
-
#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
2011 2012 2013 2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2011 def initialize( custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil ) @custom_mandate_url = custom_mandate_url @default_for = default_for @interval_description = interval_description @payment_schedule = payment_schedule @transaction_type = transaction_type end |
Instance Attribute Details
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.
2001 2002 2003 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2001 def custom_mandate_url @custom_mandate_url end |
#default_for ⇒ Object
List of Stripe products where this mandate can be selected automatically.
2003 2004 2005 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2003 def default_for @default_for end |
#interval_description ⇒ Object
Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.
2005 2006 2007 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2005 def interval_description @interval_description end |
#payment_schedule ⇒ Object
Payment schedule for the mandate.
2007 2008 2009 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2007 def payment_schedule @payment_schedule end |
#transaction_type ⇒ Object
Transaction type of the mandate.
2009 2010 2011 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2009 def transaction_type @transaction_type end |