Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::AcssDebit::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
# File 'lib/stripe/services/setup_intent_service.rb', line 1915

def initialize(
  custom_mandate_url: nil,
  default_for: nil,
  interval_description: nil,
  payment_schedule: nil,
  transaction_type: nil
)
  @custom_mandate_url = custom_mandate_url
  @default_for = default_for
  @interval_description = interval_description
  @payment_schedule = payment_schedule
  @transaction_type = transaction_type
end

Instance Attribute Details

#custom_mandate_urlObject

A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.



1905
1906
1907
# File 'lib/stripe/services/setup_intent_service.rb', line 1905

def custom_mandate_url
  @custom_mandate_url
end

#default_forObject

List of Stripe products where this mandate can be selected automatically.



1907
1908
1909
# File 'lib/stripe/services/setup_intent_service.rb', line 1907

def default_for
  @default_for
end

#interval_descriptionObject

Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.



1909
1910
1911
# File 'lib/stripe/services/setup_intent_service.rb', line 1909

def interval_description
  @interval_description
end

#payment_scheduleObject

Payment schedule for the mandate.



1911
1912
1913
# File 'lib/stripe/services/setup_intent_service.rb', line 1911

def payment_schedule
  @payment_schedule
end

#transaction_typeObject

Transaction type of the mandate.



1913
1914
1915
# File 'lib/stripe/services/setup_intent_service.rb', line 1913

def transaction_type
  @transaction_type
end