Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::AcssDebit::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1637
1638
1639
1640
1641
1642
1643
1644
1645
1646
1647
1648
1649
# File 'lib/stripe/services/setup_intent_service.rb', line 1637

def initialize(
  custom_mandate_url: nil,
  default_for: nil,
  interval_description: nil,
  payment_schedule: nil,
  transaction_type: nil
)
  @custom_mandate_url = custom_mandate_url
  @default_for = default_for
  @interval_description = interval_description
  @payment_schedule = payment_schedule
  @transaction_type = transaction_type
end

Instance Attribute Details

#custom_mandate_urlObject

A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.



1627
1628
1629
# File 'lib/stripe/services/setup_intent_service.rb', line 1627

def custom_mandate_url
  @custom_mandate_url
end

#default_forObject

List of Stripe products where this mandate can be selected automatically.



1629
1630
1631
# File 'lib/stripe/services/setup_intent_service.rb', line 1629

def default_for
  @default_for
end

#interval_descriptionObject

Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.



1631
1632
1633
# File 'lib/stripe/services/setup_intent_service.rb', line 1631

def interval_description
  @interval_description
end

#payment_scheduleObject

Payment schedule for the mandate.



1633
1634
1635
# File 'lib/stripe/services/setup_intent_service.rb', line 1633

def payment_schedule
  @payment_schedule
end

#transaction_typeObject

Transaction type of the mandate.



1635
1636
1637
# File 'lib/stripe/services/setup_intent_service.rb', line 1635

def transaction_type
  @transaction_type
end