Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::AcssDebit::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
2050
# File 'lib/stripe/services/setup_intent_service.rb', line 2038

def initialize(
  custom_mandate_url: nil,
  default_for: nil,
  interval_description: nil,
  payment_schedule: nil,
  transaction_type: nil
)
  @custom_mandate_url = custom_mandate_url
  @default_for = default_for
  @interval_description = interval_description
  @payment_schedule = payment_schedule
  @transaction_type = transaction_type
end

Instance Attribute Details

#custom_mandate_urlObject

A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.



2028
2029
2030
# File 'lib/stripe/services/setup_intent_service.rb', line 2028

def custom_mandate_url
  @custom_mandate_url
end

#default_forObject

List of Stripe products where this mandate can be selected automatically.



2030
2031
2032
# File 'lib/stripe/services/setup_intent_service.rb', line 2030

def default_for
  @default_for
end

#interval_descriptionObject

Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.



2032
2033
2034
# File 'lib/stripe/services/setup_intent_service.rb', line 2032

def interval_description
  @interval_description
end

#payment_scheduleObject

Payment schedule for the mandate.



2034
2035
2036
# File 'lib/stripe/services/setup_intent_service.rb', line 2034

def payment_schedule
  @payment_schedule
end

#transaction_typeObject

Transaction type of the mandate.



2036
2037
2038
# File 'lib/stripe/services/setup_intent_service.rb', line 2036

def transaction_type
  @transaction_type
end