Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::AcssDebit::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
# File 'lib/stripe/services/setup_intent_service.rb', line 1890

def initialize(
  custom_mandate_url: nil,
  default_for: nil,
  interval_description: nil,
  payment_schedule: nil,
  transaction_type: nil
)
  @custom_mandate_url = custom_mandate_url
  @default_for = default_for
  @interval_description = interval_description
  @payment_schedule = payment_schedule
  @transaction_type = transaction_type
end

Instance Attribute Details

#custom_mandate_urlObject

A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.



1880
1881
1882
# File 'lib/stripe/services/setup_intent_service.rb', line 1880

def custom_mandate_url
  @custom_mandate_url
end

#default_forObject

List of Stripe products where this mandate can be selected automatically.



1882
1883
1884
# File 'lib/stripe/services/setup_intent_service.rb', line 1882

def default_for
  @default_for
end

#interval_descriptionObject

Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.



1884
1885
1886
# File 'lib/stripe/services/setup_intent_service.rb', line 1884

def interval_description
  @interval_description
end

#payment_scheduleObject

Payment schedule for the mandate.



1886
1887
1888
# File 'lib/stripe/services/setup_intent_service.rb', line 1886

def payment_schedule
  @payment_schedule
end

#transaction_typeObject

Transaction type of the mandate.



1888
1889
1890
# File 'lib/stripe/services/setup_intent_service.rb', line 1888

def transaction_type
  @transaction_type
end