Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, currency: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
# File 'lib/stripe/services/setup_intent_service.rb', line 2204

def initialize(
  amount: nil,
  amount_type: nil,
  currency: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @currency = currency
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



2175
2176
2177
# File 'lib/stripe/services/setup_intent_service.rb', line 2175

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



2178
2179
2180
# File 'lib/stripe/services/setup_intent_service.rb', line 2178

def amount_type
  @amount_type
end

#currencyObject

Currency in which future payments will be charged. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



2181
2182
2183
# File 'lib/stripe/services/setup_intent_service.rb', line 2181

def currency
  @currency
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



2184
2185
2186
# File 'lib/stripe/services/setup_intent_service.rb', line 2184

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



2187
2188
2189
# File 'lib/stripe/services/setup_intent_service.rb', line 2187

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



2190
2191
2192
# File 'lib/stripe/services/setup_intent_service.rb', line 2190

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



2193
2194
2195
# File 'lib/stripe/services/setup_intent_service.rb', line 2193

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



2196
2197
2198
# File 'lib/stripe/services/setup_intent_service.rb', line 2196

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



2199
2200
2201
# File 'lib/stripe/services/setup_intent_service.rb', line 2199

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are ‘india`.



2202
2203
2204
# File 'lib/stripe/services/setup_intent_service.rb', line 2202

def supported_types
  @supported_types
end