Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::Klarna::OnDemand
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::Klarna::OnDemand
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#average_amount ⇒ Object
Your average amount value.
-
#maximum_amount ⇒ Object
The maximum value you may charge a customer per purchase.
-
#minimum_amount ⇒ Object
The lowest or minimum value you may charge a customer per purchase.
-
#purchase_interval ⇒ Object
Interval at which the customer is making purchases.
-
#purchase_interval_count ⇒ Object
The number of ‘purchase_interval` between charges.
Instance Method Summary collapse
-
#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand
constructor
A new instance of OnDemand.
Methods inherited from RequestParams
Constructor Details
#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand
Returns a new instance of OnDemand.
1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1942 def initialize( average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil ) @average_amount = average_amount @maximum_amount = maximum_amount @minimum_amount = minimum_amount @purchase_interval = purchase_interval @purchase_interval_count = purchase_interval_count end |
Instance Attribute Details
#average_amount ⇒ Object
Your average amount value. You can use a value across your customer base, or segment based on customer type, country, etc.
1932 1933 1934 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1932 def average_amount @average_amount end |
#maximum_amount ⇒ Object
The maximum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.
1934 1935 1936 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1934 def maximum_amount @maximum_amount end |
#minimum_amount ⇒ Object
The lowest or minimum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.
1936 1937 1938 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1936 def minimum_amount @minimum_amount end |
#purchase_interval ⇒ Object
Interval at which the customer is making purchases
1938 1939 1940 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1938 def purchase_interval @purchase_interval end |
#purchase_interval_count ⇒ Object
The number of ‘purchase_interval` between charges
1940 1941 1942 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1940 def purchase_interval_count @purchase_interval_count end |