Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::Klarna::OnDemand
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::Klarna::OnDemand
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#average_amount ⇒ Object
Your average amount value.
-
#maximum_amount ⇒ Object
The maximum value you may charge a customer per purchase.
-
#minimum_amount ⇒ Object
The lowest or minimum value you may charge a customer per purchase.
-
#purchase_interval ⇒ Object
Interval at which the customer is making purchases.
-
#purchase_interval_count ⇒ Object
The number of ‘purchase_interval` between charges.
Instance Method Summary collapse
-
#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand
constructor
A new instance of OnDemand.
Methods inherited from RequestParams
Constructor Details
#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand
Returns a new instance of OnDemand.
2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2220 def initialize( average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil ) @average_amount = average_amount @maximum_amount = maximum_amount @minimum_amount = minimum_amount @purchase_interval = purchase_interval @purchase_interval_count = purchase_interval_count end |
Instance Attribute Details
#average_amount ⇒ Object
Your average amount value. You can use a value across your customer base, or segment based on customer type, country, etc.
2210 2211 2212 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2210 def average_amount @average_amount end |
#maximum_amount ⇒ Object
The maximum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.
2212 2213 2214 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2212 def maximum_amount @maximum_amount end |
#minimum_amount ⇒ Object
The lowest or minimum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.
2214 2215 2216 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2214 def minimum_amount @minimum_amount end |
#purchase_interval ⇒ Object
Interval at which the customer is making purchases
2216 2217 2218 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2216 def purchase_interval @purchase_interval end |
#purchase_interval_count ⇒ Object
The number of ‘purchase_interval` between charges
2218 2219 2220 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2218 def purchase_interval_count @purchase_interval_count end |