Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1980 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
1970 1971 1972 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1970 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
1972 1973 1974 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1972 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
1974 1975 1976 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1974 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
1976 1977 1978 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1976 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
1978 1979 1980 |
# File 'lib/stripe/services/setup_intent_service.rb', line 1978 def reference @reference end |