Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::Paypal

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_agreement_id: nil, currency: nil, subsellers: nil) ⇒ Paypal

Returns a new instance of Paypal.



2128
2129
2130
2131
2132
# File 'lib/stripe/services/setup_intent_service.rb', line 2128

def initialize(billing_agreement_id: nil, currency: nil, subsellers: nil)
  @billing_agreement_id = billing_agreement_id
  @currency = currency
  @subsellers = subsellers
end

Instance Attribute Details

#billing_agreement_idObject

The PayPal Billing Agreement ID (BAID). This is an ID generated by PayPal which represents the mandate between the merchant and the customer.



2122
2123
2124
# File 'lib/stripe/services/setup_intent_service.rb', line 2122

def billing_agreement_id
  @billing_agreement_id
end

#currencyObject

Attribute for param field currency



2124
2125
2126
# File 'lib/stripe/services/setup_intent_service.rb', line 2124

def currency
  @currency
end

#subsellersObject

The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when [separate charges and transfers](stripe.com/docs/connect/separate-charges-and-transfers) are used.



2126
2127
2128
# File 'lib/stripe/services/setup_intent_service.rb', line 2126

def subsellers
  @subsellers
end