Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::Paypal

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_agreement_id: nil, currency: nil, subsellers: nil) ⇒ Paypal

Returns a new instance of Paypal.



2247
2248
2249
2250
2251
# File 'lib/stripe/services/setup_intent_service.rb', line 2247

def initialize(billing_agreement_id: nil, currency: nil, subsellers: nil)
  @billing_agreement_id = billing_agreement_id
  @currency = currency
  @subsellers = subsellers
end

Instance Attribute Details

#billing_agreement_idObject

The PayPal Billing Agreement ID (BAID). This is an ID generated by PayPal which represents the mandate between the merchant and the customer.



2241
2242
2243
# File 'lib/stripe/services/setup_intent_service.rb', line 2241

def billing_agreement_id
  @billing_agreement_id
end

#currencyObject

Attribute for param field currency



2243
2244
2245
# File 'lib/stripe/services/setup_intent_service.rb', line 2243

def currency
  @currency
end

#subsellersObject

The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when [separate charges and transfers](stripe.com/docs/connect/separate-charges-and-transfers) are used.



2245
2246
2247
# File 'lib/stripe/services/setup_intent_service.rb', line 2245

def subsellers
  @subsellers
end