Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::Payto::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::Payto::MandateOptions
- Defined in:
- lib/stripe/services/setup_intent_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount that will be collected.
-
#amount_type ⇒ Object
The type of amount that will be collected.
-
#end_date ⇒ Object
Date, in YYYY-MM-DD format, after which payments will not be collected.
-
#payment_schedule ⇒ Object
The periodicity at which payments will be collected.
-
#payments_per_period ⇒ Object
The number of payments that will be made during a payment period.
-
#purpose ⇒ Object
The purpose for which payments are made.
-
#start_date ⇒ Object
Date, in YYYY-MM-DD format, from which payments will be collected.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2271 def initialize( amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil ) @amount = amount @amount_type = amount_type @end_date = end_date @payment_schedule = payment_schedule @payments_per_period = payments_per_period @purpose = purpose @start_date = start_date end |
Instance Attribute Details
#amount ⇒ Object
Amount that will be collected. It is required when ‘amount_type` is `fixed`.
2257 2258 2259 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2257 def amount @amount end |
#amount_type ⇒ Object
The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.
2259 2260 2261 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2259 def amount_type @amount_type end |
#end_date ⇒ Object
Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.
2261 2262 2263 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2261 def end_date @end_date end |
#payment_schedule ⇒ Object
The periodicity at which payments will be collected.
2263 2264 2265 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2263 def payment_schedule @payment_schedule end |
#payments_per_period ⇒ Object
The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.
2265 2266 2267 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2265 def payments_per_period @payments_per_period end |
#purpose ⇒ Object
The purpose for which payments are made. Defaults to retail.
2267 2268 2269 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2267 def purpose @purpose end |
#start_date ⇒ Object
Date, in YYYY-MM-DD format, from which payments will be collected. Defaults to confirmation time.
2269 2270 2271 |
# File 'lib/stripe/services/setup_intent_service.rb', line 2269 def start_date @start_date end |