Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
# File 'lib/stripe/services/setup_intent_service.rb', line 2115

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil,
  start_date: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
  @start_date = start_date
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when ‘amount_type` is `fixed`.



2101
2102
2103
# File 'lib/stripe/services/setup_intent_service.rb', line 2101

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.



2103
2104
2105
# File 'lib/stripe/services/setup_intent_service.rb', line 2103

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



2105
2106
2107
# File 'lib/stripe/services/setup_intent_service.rb', line 2105

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected.



2107
2108
2109
# File 'lib/stripe/services/setup_intent_service.rb', line 2107

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.



2109
2110
2111
# File 'lib/stripe/services/setup_intent_service.rb', line 2109

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Defaults to retail.



2111
2112
2113
# File 'lib/stripe/services/setup_intent_service.rb', line 2111

def purpose
  @purpose
end

#start_dateObject

Date, in YYYY-MM-DD format, from which payments will be collected. Defaults to confirmation time.



2113
2114
2115
# File 'lib/stripe/services/setup_intent_service.rb', line 2113

def start_date
  @start_date
end