Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
# File 'lib/stripe/services/setup_intent_service.rb', line 2406

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



2396
2397
2398
# File 'lib/stripe/services/setup_intent_service.rb', line 2396

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



2398
2399
2400
# File 'lib/stripe/services/setup_intent_service.rb', line 2398

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



2400
2401
2402
# File 'lib/stripe/services/setup_intent_service.rb', line 2400

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



2402
2403
2404
# File 'lib/stripe/services/setup_intent_service.rb', line 2402

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



2404
2405
2406
# File 'lib/stripe/services/setup_intent_service.rb', line 2404

def return_url
  @return_url
end