Class: Stripe::SetupIntentService::UpdateParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
# File 'lib/stripe/services/setup_intent_service.rb', line 2353

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



2343
2344
2345
# File 'lib/stripe/services/setup_intent_service.rb', line 2343

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



2345
2346
2347
# File 'lib/stripe/services/setup_intent_service.rb', line 2345

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



2347
2348
2349
# File 'lib/stripe/services/setup_intent_service.rb', line 2347

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



2349
2350
2351
# File 'lib/stripe/services/setup_intent_service.rb', line 2349

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



2351
2352
2353
# File 'lib/stripe/services/setup_intent_service.rb', line 2351

def return_url
  @return_url
end