Class: Stripe::SetupIntentService::VerifyMicrodepositsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams

Returns a new instance of VerifyMicrodepositsParams.



3001
3002
3003
3004
3005
# File 'lib/stripe/services/setup_intent_service.rb', line 3001

def initialize(amounts: nil, descriptor_code: nil, expand: nil)
  @amounts = amounts
  @descriptor_code = descriptor_code
  @expand = expand
end

Instance Attribute Details

#amountsObject

Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.



2995
2996
2997
# File 'lib/stripe/services/setup_intent_service.rb', line 2995

def amounts
  @amounts
end

#descriptor_codeObject

A six-character code starting with SM present in the microdeposit sent to the bank account.



2997
2998
2999
# File 'lib/stripe/services/setup_intent_service.rb', line 2997

def descriptor_code
  @descriptor_code
end

#expandObject

Specifies which fields in the response should be expanded.



2999
3000
3001
# File 'lib/stripe/services/setup_intent_service.rb', line 2999

def expand
  @expand
end