Class: Stripe::SetupIntentService::VerifyMicrodepositsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amounts: nil, descriptor_code: nil, expand: nil) ⇒ VerifyMicrodepositsParams

Returns a new instance of VerifyMicrodepositsParams.



3162
3163
3164
3165
3166
# File 'lib/stripe/services/setup_intent_service.rb', line 3162

def initialize(amounts: nil, descriptor_code: nil, expand: nil)
  @amounts = amounts
  @descriptor_code = descriptor_code
  @expand = expand
end

Instance Attribute Details

#amountsObject

Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.



3156
3157
3158
# File 'lib/stripe/services/setup_intent_service.rb', line 3156

def amounts
  @amounts
end

#descriptor_codeObject

A six-character code starting with SM present in the microdeposit sent to the bank account.



3158
3159
3160
# File 'lib/stripe/services/setup_intent_service.rb', line 3158

def descriptor_code
  @descriptor_code
end

#expandObject

Specifies which fields in the response should be expanded.



3160
3161
3162
# File 'lib/stripe/services/setup_intent_service.rb', line 3160

def expand
  @expand
end