Class: Stripe::SetupIntentUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/setup_intent_update_params.rb

Defined Under Namespace

Classes: PaymentMethodData, PaymentMethodOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(allowed_payment_method_types: nil, attach_to_self: nil, customer: nil, customer_account: nil, description: nil, excluded_payment_method_types: nil, expand: nil, flow_directions: nil, metadata: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil) ⇒ SetupIntentUpdateParams

Returns a new instance of SetupIntentUpdateParams.



1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1314

def initialize(
  allowed_payment_method_types: nil,
  attach_to_self: nil,
  customer: nil,
  customer_account: nil,
  description: nil,
  excluded_payment_method_types: nil,
  expand: nil,
  flow_directions: nil,
  metadata: nil,
  payment_method: nil,
  payment_method_configuration: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil
)
  @allowed_payment_method_types = allowed_payment_method_types
  @attach_to_self = attach_to_self
  @customer = customer
  @customer_account = 
  @description = description
  @excluded_payment_method_types = excluded_payment_method_types
  @expand = expand
  @flow_directions = flow_directions
  @metadata = 
  @payment_method = payment_method
  @payment_method_configuration = payment_method_configuration
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
end

Instance Attribute Details

#allowed_payment_method_typesObject

The list of payment method types to allow for this SetupIntent. Stripe will only use methods in this list when determining the payment methods to offer. A list of valid payment method types can be found here.



1277
1278
1279
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1277

def allowed_payment_method_types
  @allowed_payment_method_types
end

#attach_to_selfObject

If present, the SetupIntent's payment method will be attached to the in-context Stripe Account.

It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.



1281
1282
1283
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1281

def attach_to_self
  @attach_to_self
end

#customerObject

ID of the Customer this SetupIntent belongs to, if one exists.

If present, the SetupIntent's payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.



1285
1286
1287
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1285

def customer
  @customer
end

#customer_accountObject

ID of the Account this SetupIntent belongs to, if one exists.

If present, the SetupIntent's payment method will be attached to the Account on successful setup. Payment methods attached to other Accounts cannot be used with this SetupIntent.



1289
1290
1291
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1289

def 
  @customer_account
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1291
1292
1293
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1291

def description
  @description
end

#excluded_payment_method_typesObject

The list of payment method types to exclude from use with this SetupIntent.



1293
1294
1295
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1293

def excluded_payment_method_types
  @excluded_payment_method_types
end

#expandObject

Specifies which fields in the response should be expanded.



1295
1296
1297
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1295

def expand
  @expand
end

#flow_directionsObject

Indicates the directions of money movement for which this payment method is intended to be used.

Include inbound if you intend to use the payment method as the origin to pull funds from. Include outbound if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.



1299
1300
1301
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1299

def flow_directions
  @flow_directions
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



1301
1302
1303
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1301

def 
  @metadata
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent. To unset this field to null, pass in an empty string.



1303
1304
1305
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1303

def payment_method
  @payment_method
end

#payment_method_configurationObject

The ID of the payment method configuration to use with this SetupIntent.



1305
1306
1307
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1305

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_dataObject

When included, this hash creates a PaymentMethod that is set as the payment_method value in the SetupIntent.



1308
1309
1310
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1308

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this SetupIntent.



1310
1311
1312
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1310

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, card) that this SetupIntent can set up. If you don't provide this, Stripe will dynamically show relevant payment methods from your payment method settings. A list of valid payment method types can be found here.



1312
1313
1314
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1312

def payment_method_types
  @payment_method_types
end