Class: Stripe::SetupIntentUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/setup_intent_update_params.rb

Defined Under Namespace

Classes: PaymentMethodData, PaymentMethodOptions, SetupDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(attach_to_self: nil, customer: nil, customer_account: nil, description: nil, excluded_payment_method_types: nil, expand: nil, flow_directions: nil, metadata: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, setup_details: nil) ⇒ SetupIntentUpdateParams

Returns a new instance of SetupIntentUpdateParams.



1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1379

def initialize(
  attach_to_self: nil,
  customer: nil,
  customer_account: nil,
  description: nil,
  excluded_payment_method_types: nil,
  expand: nil,
  flow_directions: nil,
  metadata: nil,
  payment_method: nil,
  payment_method_configuration: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  setup_details: nil
)
  @attach_to_self = attach_to_self
  @customer = customer
  @customer_account = 
  @description = description
  @excluded_payment_method_types = excluded_payment_method_types
  @expand = expand
  @flow_directions = flow_directions
  @metadata = 
  @payment_method = payment_method
  @payment_method_configuration = payment_method_configuration
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @setup_details = setup_details
end

Instance Attribute Details

#attach_to_selfObject

If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.

It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.



1344
1345
1346
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1344

def attach_to_self
  @attach_to_self
end

#customerObject

ID of the Customer this SetupIntent belongs to, if one exists.

If present, the SetupIntent’s payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.



1348
1349
1350
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1348

def customer
  @customer
end

#customer_accountObject

ID of the Account this SetupIntent belongs to, if one exists.

If present, the SetupIntent’s payment method will be attached to the Account on successful setup. Payment methods attached to other Accounts cannot be used with this SetupIntent.



1352
1353
1354
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1352

def 
  @customer_account
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1354
1355
1356
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1354

def description
  @description
end

#excluded_payment_method_typesObject

The list of payment method types to exclude from use with this SetupIntent.



1356
1357
1358
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1356

def excluded_payment_method_types
  @excluded_payment_method_types
end

#expandObject

Specifies which fields in the response should be expanded.



1358
1359
1360
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1358

def expand
  @expand
end

#flow_directionsObject

Indicates the directions of money movement for which this payment method is intended to be used.

Include ‘inbound` if you intend to use the payment method as the origin to pull funds from. Include `outbound` if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.



1362
1363
1364
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1362

def flow_directions
  @flow_directions
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1364
1365
1366
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1364

def 
  @metadata
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent. To unset this field to null, pass in an empty string.



1366
1367
1368
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1366

def payment_method
  @payment_method
end

#payment_method_configurationObject

The ID of the [payment method configuration](docs.stripe.com/api/payment_method_configurations) to use with this SetupIntent.



1368
1369
1370
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1368

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_dataObject

When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](docs.stripe.com/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.



1371
1372
1373
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1371

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this SetupIntent.



1373
1374
1375
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1373

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, card) that this SetupIntent can set up. If you don’t provide this, Stripe will dynamically show relevant payment methods from your [payment method settings](dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).



1375
1376
1377
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1375

def payment_method_types
  @payment_method_types
end

#setup_detailsObject

Provides industry-specific information about the SetupIntent.



1377
1378
1379
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1377

def setup_details
  @setup_details
end