Class: Stripe::SetupIntentUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentUpdateParams
- Defined in:
- lib/stripe/params/setup_intent_update_params.rb
Defined Under Namespace
Classes: PaymentMethodData, PaymentMethodOptions
Instance Attribute Summary collapse
-
#attach_to_self ⇒ Object
If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.
-
#customer ⇒ Object
ID of the Customer this SetupIntent belongs to, if one exists.
-
#customer_account ⇒ Object
ID of the Account this SetupIntent belongs to, if one exists.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#excluded_payment_method_types ⇒ Object
The list of payment method types to exclude from use with this SetupIntent.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#flow_directions ⇒ Object
Indicates the directions of money movement for which this payment method is intended to be used.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.
-
#payment_method_configuration ⇒ Object
The ID of the [payment method configuration](docs.stripe.com/api/payment_method_configurations) to use with this SetupIntent.
-
#payment_method_data ⇒ Object
When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](docs.stripe.com/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.
-
#payment_method_options ⇒ Object
Payment method-specific configuration for this SetupIntent.
-
#payment_method_types ⇒ Object
The list of payment method types (for example, card) that this SetupIntent can set up.
Instance Method Summary collapse
-
#initialize(attach_to_self: nil, customer: nil, customer_account: nil, description: nil, excluded_payment_method_types: nil, expand: nil, flow_directions: nil, metadata: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil) ⇒ SetupIntentUpdateParams
constructor
A new instance of SetupIntentUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(attach_to_self: nil, customer: nil, customer_account: nil, description: nil, excluded_payment_method_types: nil, expand: nil, flow_directions: nil, metadata: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil) ⇒ SetupIntentUpdateParams
Returns a new instance of SetupIntentUpdateParams.
1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1207 def initialize( attach_to_self: nil, customer: nil, customer_account: nil, description: nil, excluded_payment_method_types: nil, expand: nil, flow_directions: nil, metadata: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil ) @attach_to_self = attach_to_self @customer = customer @customer_account = customer_account @description = description @excluded_payment_method_types = excluded_payment_method_types @expand = @flow_directions = flow_directions @metadata = @payment_method = payment_method @payment_method_configuration = payment_method_configuration @payment_method_data = payment_method_data @payment_method_options = @payment_method_types = payment_method_types end |
Instance Attribute Details
#attach_to_self ⇒ Object
If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.
It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.
1174 1175 1176 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1174 def attach_to_self @attach_to_self end |
#customer ⇒ Object
ID of the Customer this SetupIntent belongs to, if one exists.
If present, the SetupIntent’s payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.
1178 1179 1180 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1178 def customer @customer end |
#customer_account ⇒ Object
ID of the Account this SetupIntent belongs to, if one exists.
If present, the SetupIntent’s payment method will be attached to the Account on successful setup. Payment methods attached to other Accounts cannot be used with this SetupIntent.
1182 1183 1184 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1182 def customer_account @customer_account end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
1184 1185 1186 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1184 def description @description end |
#excluded_payment_method_types ⇒ Object
The list of payment method types to exclude from use with this SetupIntent.
1186 1187 1188 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1186 def excluded_payment_method_types @excluded_payment_method_types end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1188 1189 1190 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1188 def @expand end |
#flow_directions ⇒ Object
Indicates the directions of money movement for which this payment method is intended to be used.
Include ‘inbound` if you intend to use the payment method as the origin to pull funds from. Include `outbound` if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.
1192 1193 1194 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1192 def flow_directions @flow_directions end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1194 1195 1196 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1194 def @metadata end |
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent. To unset this field to null, pass in an empty string.
1196 1197 1198 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1196 def payment_method @payment_method end |
#payment_method_configuration ⇒ Object
The ID of the [payment method configuration](docs.stripe.com/api/payment_method_configurations) to use with this SetupIntent.
1198 1199 1200 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1198 def payment_method_configuration @payment_method_configuration end |
#payment_method_data ⇒ Object
When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](docs.stripe.com/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.
1201 1202 1203 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1201 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment method-specific configuration for this SetupIntent.
1203 1204 1205 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1203 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types (for example, card) that this SetupIntent can set up. If you don’t provide this, Stripe will dynamically show relevant payment methods from your [payment method settings](dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).
1205 1206 1207 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1205 def payment_method_types @payment_method_types end |