Class: Stripe::SetupIntentUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentUpdateParams
- Defined in:
- lib/stripe/params/setup_intent_update_params.rb
Defined Under Namespace
Classes: PaymentMethodData, PaymentMethodOptions, SetupDetails
Instance Attribute Summary collapse
-
#attach_to_self ⇒ Object
If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.
-
#customer ⇒ Object
ID of the Customer this SetupIntent belongs to, if one exists.
-
#customer_account ⇒ Object
ID of the Account this SetupIntent belongs to, if one exists.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#excluded_payment_method_types ⇒ Object
The list of payment method types to exclude from use with this SetupIntent.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#flow_directions ⇒ Object
Indicates the directions of money movement for which this payment method is intended to be used.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent.
-
#payment_method_configuration ⇒ Object
The ID of the [payment method configuration](docs.stripe.com/api/payment_method_configurations) to use with this SetupIntent.
-
#payment_method_data ⇒ Object
When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](docs.stripe.com/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.
-
#payment_method_options ⇒ Object
Payment method-specific configuration for this SetupIntent.
-
#payment_method_types ⇒ Object
The list of payment method types (for example, card) that this SetupIntent can set up.
-
#setup_details ⇒ Object
Provides industry-specific information about the SetupIntent.
Instance Method Summary collapse
-
#initialize(attach_to_self: nil, customer: nil, customer_account: nil, description: nil, excluded_payment_method_types: nil, expand: nil, flow_directions: nil, metadata: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, setup_details: nil) ⇒ SetupIntentUpdateParams
constructor
A new instance of SetupIntentUpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(attach_to_self: nil, customer: nil, customer_account: nil, description: nil, excluded_payment_method_types: nil, expand: nil, flow_directions: nil, metadata: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, setup_details: nil) ⇒ SetupIntentUpdateParams
Returns a new instance of SetupIntentUpdateParams.
1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1254 def initialize( attach_to_self: nil, customer: nil, customer_account: nil, description: nil, excluded_payment_method_types: nil, expand: nil, flow_directions: nil, metadata: nil, payment_method: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, setup_details: nil ) @attach_to_self = attach_to_self @customer = customer @customer_account = customer_account @description = description @excluded_payment_method_types = excluded_payment_method_types @expand = @flow_directions = flow_directions @metadata = @payment_method = payment_method @payment_method_configuration = payment_method_configuration @payment_method_data = payment_method_data @payment_method_options = @payment_method_types = payment_method_types @setup_details = setup_details end |
Instance Attribute Details
#attach_to_self ⇒ Object
If present, the SetupIntent’s payment method will be attached to the in-context Stripe Account.
It can only be used for this Stripe Account’s own money movement flows like InboundTransfer and OutboundTransfers. It cannot be set to true when setting up a PaymentMethod for a Customer, and defaults to false when attaching a PaymentMethod to a Customer.
1219 1220 1221 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1219 def attach_to_self @attach_to_self end |
#customer ⇒ Object
ID of the Customer this SetupIntent belongs to, if one exists.
If present, the SetupIntent’s payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.
1223 1224 1225 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1223 def customer @customer end |
#customer_account ⇒ Object
ID of the Account this SetupIntent belongs to, if one exists.
If present, the SetupIntent’s payment method will be attached to the Account on successful setup. Payment methods attached to other Accounts cannot be used with this SetupIntent.
1227 1228 1229 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1227 def customer_account @customer_account end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
1229 1230 1231 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1229 def description @description end |
#excluded_payment_method_types ⇒ Object
The list of payment method types to exclude from use with this SetupIntent.
1231 1232 1233 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1231 def excluded_payment_method_types @excluded_payment_method_types end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1233 1234 1235 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1233 def @expand end |
#flow_directions ⇒ Object
Indicates the directions of money movement for which this payment method is intended to be used.
Include ‘inbound` if you intend to use the payment method as the origin to pull funds from. Include `outbound` if you intend to use the payment method as the destination to send funds to. You can include both if you intend to use the payment method for both purposes.
1237 1238 1239 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1237 def flow_directions @flow_directions end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1239 1240 1241 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1239 def @metadata end |
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent. To unset this field to null, pass in an empty string.
1241 1242 1243 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1241 def payment_method @payment_method end |
#payment_method_configuration ⇒ Object
The ID of the [payment method configuration](docs.stripe.com/api/payment_method_configurations) to use with this SetupIntent.
1243 1244 1245 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1243 def payment_method_configuration @payment_method_configuration end |
#payment_method_data ⇒ Object
When included, this hash creates a PaymentMethod that is set as the [‘payment_method`](docs.stripe.com/api/setup_intents/object#setup_intent_object-payment_method) value in the SetupIntent.
1246 1247 1248 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1246 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment method-specific configuration for this SetupIntent.
1248 1249 1250 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1248 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types (for example, card) that this SetupIntent can set up. If you don’t provide this, Stripe will dynamically show relevant payment methods from your [payment method settings](dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).
1250 1251 1252 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1250 def payment_method_types @payment_method_types end |
#setup_details ⇒ Object
Provides industry-specific information about the SetupIntent.
1252 1253 1254 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1252 def setup_details @setup_details end |