Class: Stripe::SetupIntentUpdateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentUpdateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/params/setup_intent_update_params.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
379 380 381 382 383 384 385 386 387 388 389 390 391 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 379 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
369 370 371 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 369 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
371 372 373 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 371 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
373 374 375 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 373 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
375 376 377 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 375 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
377 378 379 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 377 def routing_number @routing_number end |