Class: Stripe::SetupIntentUpdateParams::PaymentMethodOptions::Card

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_update_params.rb

Defined Under Namespace

Classes: MandateOptions, ThreeDSecure

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(mandate_options: nil, moto: nil, network: nil, request_three_d_secure: nil, three_d_secure: nil) ⇒ Card

Returns a new instance of Card.



870
871
872
873
874
875
876
877
878
879
880
881
882
# File 'lib/stripe/params/setup_intent_update_params.rb', line 870

def initialize(
  mandate_options: nil,
  moto: nil,
  network: nil,
  request_three_d_secure: nil,
  three_d_secure: nil
)
  @mandate_options = mandate_options
  @moto = moto
  @network = network
  @request_three_d_secure = request_three_d_secure
  @three_d_secure = three_d_secure
end

Instance Attribute Details

#mandate_optionsObject

Configuration options for setting up an eMandate for cards issued in India.



857
858
859
# File 'lib/stripe/params/setup_intent_update_params.rb', line 857

def mandate_options
  @mandate_options
end

#motoObject

When specified, this parameter signals that a card has been collected as MOTO (Mail Order Telephone Order) and thus out of scope for SCA. This parameter can only be provided during confirmation.



861
862
863
# File 'lib/stripe/params/setup_intent_update_params.rb', line 861

def moto
  @moto
end

#networkObject

Selected network to process this SetupIntent on. Depends on the available networks of the card attached to the SetupIntent. Can be only set confirm-time.



863
864
865
# File 'lib/stripe/params/setup_intent_update_params.rb', line 863

def network
  @network
end

#request_three_d_secureObject

We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements. However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to automatic. Read our guide on manually requesting 3D Secure for more information on how this configuration interacts with Radar and our SCA Engine.



865
866
867
# File 'lib/stripe/params/setup_intent_update_params.rb', line 865

def request_three_d_secure
  @request_three_d_secure
end

#three_d_secureObject

If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this setup.



868
869
870
# File 'lib/stripe/params/setup_intent_update_params.rb', line 868

def three_d_secure
  @three_d_secure
end