Class: Stripe::SetupIntentUpdateParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, currency: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
# File 'lib/stripe/params/setup_intent_update_params.rb', line 683

def initialize(
  amount: nil,
  amount_type: nil,
  currency: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @currency = currency
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments, specified in the presentment currency.



663
664
665
# File 'lib/stripe/params/setup_intent_update_params.rb', line 663

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



665
666
667
# File 'lib/stripe/params/setup_intent_update_params.rb', line 665

def amount_type
  @amount_type
end

#currencyObject

Currency in which future payments will be charged. Three-letter ISO currency code, in lowercase. Must be a supported currency.



667
668
669
# File 'lib/stripe/params/setup_intent_update_params.rb', line 667

def currency
  @currency
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



669
670
671
# File 'lib/stripe/params/setup_intent_update_params.rb', line 669

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



671
672
673
# File 'lib/stripe/params/setup_intent_update_params.rb', line 671

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of day, week, month, year, or sporadic.



673
674
675
# File 'lib/stripe/params/setup_intent_update_params.rb', line 673

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, interval=month and interval_count=3 indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when interval=sporadic.



675
676
677
# File 'lib/stripe/params/setup_intent_update_params.rb', line 675

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



677
678
679
# File 'lib/stripe/params/setup_intent_update_params.rb', line 677

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



679
680
681
# File 'lib/stripe/params/setup_intent_update_params.rb', line 679

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are india.



681
682
683
# File 'lib/stripe/params/setup_intent_update_params.rb', line 681

def supported_types
  @supported_types
end