Class: Stripe::SetupIntentUpdateParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, currency: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
# File 'lib/stripe/params/setup_intent_update_params.rb', line 761

def initialize(
  amount: nil,
  amount_type: nil,
  currency: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @currency = currency
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments, specified in the presentment currency.



741
742
743
# File 'lib/stripe/params/setup_intent_update_params.rb', line 741

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



743
744
745
# File 'lib/stripe/params/setup_intent_update_params.rb', line 743

def amount_type
  @amount_type
end

#currencyObject

Currency in which future payments will be charged. Three-letter ISO currency code, in lowercase. Must be a supported currency.



745
746
747
# File 'lib/stripe/params/setup_intent_update_params.rb', line 745

def currency
  @currency
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



747
748
749
# File 'lib/stripe/params/setup_intent_update_params.rb', line 747

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



749
750
751
# File 'lib/stripe/params/setup_intent_update_params.rb', line 749

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of day, week, month, year, or sporadic.



751
752
753
# File 'lib/stripe/params/setup_intent_update_params.rb', line 751

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, interval=month and interval_count=3 indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when interval=sporadic.



753
754
755
# File 'lib/stripe/params/setup_intent_update_params.rb', line 753

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



755
756
757
# File 'lib/stripe/params/setup_intent_update_params.rb', line 755

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



757
758
759
# File 'lib/stripe/params/setup_intent_update_params.rb', line 757

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are india.



759
760
761
# File 'lib/stripe/params/setup_intent_update_params.rb', line 759

def supported_types
  @supported_types
end