Class: Stripe::SetupIntentUpdateParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, currency: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
# File 'lib/stripe/params/setup_intent_update_params.rb', line 713

def initialize(
  amount: nil,
  amount_type: nil,
  currency: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @currency = currency
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



693
694
695
# File 'lib/stripe/params/setup_intent_update_params.rb', line 693

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



695
696
697
# File 'lib/stripe/params/setup_intent_update_params.rb', line 695

def amount_type
  @amount_type
end

#currencyObject

Currency in which future payments will be charged. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



697
698
699
# File 'lib/stripe/params/setup_intent_update_params.rb', line 697

def currency
  @currency
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



699
700
701
# File 'lib/stripe/params/setup_intent_update_params.rb', line 699

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



701
702
703
# File 'lib/stripe/params/setup_intent_update_params.rb', line 701

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



703
704
705
# File 'lib/stripe/params/setup_intent_update_params.rb', line 703

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



705
706
707
# File 'lib/stripe/params/setup_intent_update_params.rb', line 705

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



707
708
709
# File 'lib/stripe/params/setup_intent_update_params.rb', line 707

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



709
710
711
# File 'lib/stripe/params/setup_intent_update_params.rb', line 709

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are ‘india`.



711
712
713
# File 'lib/stripe/params/setup_intent_update_params.rb', line 711

def supported_types
  @supported_types
end