Class: Stripe::SetupIntentUpdateParams::PaymentMethodOptions::Klarna

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_update_params.rb

Defined Under Namespace

Classes: OnDemand, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil) ⇒ Klarna

Returns a new instance of Klarna.



913
914
915
916
917
918
# File 'lib/stripe/params/setup_intent_update_params.rb', line 913

def initialize(currency: nil, on_demand: nil, preferred_locale: nil, subscriptions: nil)
  @currency = currency
  @on_demand = on_demand
  @preferred_locale = preferred_locale
  @subscriptions = subscriptions
end

Instance Attribute Details

#currencyObject

The currency of the SetupIntent. Three letter ISO currency code.



905
906
907
# File 'lib/stripe/params/setup_intent_update_params.rb', line 905

def currency
  @currency
end

#on_demandObject

On-demand details if setting up a payment method for on-demand payments.



907
908
909
# File 'lib/stripe/params/setup_intent_update_params.rb', line 907

def on_demand
  @on_demand
end

#preferred_localeObject

Preferred language of the Klarna authorization page that the customer is redirected to



909
910
911
# File 'lib/stripe/params/setup_intent_update_params.rb', line 909

def preferred_locale
  @preferred_locale
end

#subscriptionsObject

Subscription details if setting up or charging a subscription



911
912
913
# File 'lib/stripe/params/setup_intent_update_params.rb', line 911

def subscriptions
  @subscriptions
end