Class: Stripe::SetupIntentUpdateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



844
845
846
847
# File 'lib/stripe/params/setup_intent_update_params.rb', line 844

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



840
841
842
# File 'lib/stripe/params/setup_intent_update_params.rb', line 840

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



842
843
844
# File 'lib/stripe/params/setup_intent_update_params.rb', line 842

def date
  @date
end