Class: Stripe::SetupIntentUpdateParams::PaymentMethodOptions::Paypal

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(billing_agreement_id: nil, currency: nil, subsellers: nil) ⇒ Paypal

Returns a new instance of Paypal.



965
966
967
968
969
# File 'lib/stripe/params/setup_intent_update_params.rb', line 965

def initialize(billing_agreement_id: nil, currency: nil, subsellers: nil)
  @billing_agreement_id = billing_agreement_id
  @currency = currency
  @subsellers = subsellers
end

Instance Attribute Details

#billing_agreement_idObject

The PayPal Billing Agreement ID (BAID). This is an ID generated by PayPal which represents the mandate between the merchant and the customer.



959
960
961
# File 'lib/stripe/params/setup_intent_update_params.rb', line 959

def billing_agreement_id
  @billing_agreement_id
end

#currencyObject

Attribute for param field currency



961
962
963
# File 'lib/stripe/params/setup_intent_update_params.rb', line 961

def currency
  @currency
end

#subsellersObject

The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when [separate charges and transfers](stripe.com/docs/connect/separate-charges-and-transfers) are used.



963
964
965
# File 'lib/stripe/params/setup_intent_update_params.rb', line 963

def subsellers
  @subsellers
end