Class: Stripe::SetupIntentUpdateParams::PaymentMethodOptions::Payto::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SetupIntentUpdateParams::PaymentMethodOptions::Payto::MandateOptions
- Defined in:
- lib/stripe/params/setup_intent_update_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount that will be collected.
-
#amount_type ⇒ Object
The type of amount that will be collected.
-
#end_date ⇒ Object
Date, in YYYY-MM-DD format, after which payments will not be collected.
-
#payment_schedule ⇒ Object
The periodicity at which payments will be collected.
-
#payments_per_period ⇒ Object
The number of payments that will be made during a payment period.
-
#purpose ⇒ Object
The purpose for which payments are made.
-
#start_date ⇒ Object
Date, in YYYY-MM-DD format, from which payments will be collected.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 926 def initialize( amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil ) @amount = amount @amount_type = amount_type @end_date = end_date @payment_schedule = payment_schedule @payments_per_period = payments_per_period @purpose = purpose @start_date = start_date end |
Instance Attribute Details
#amount ⇒ Object
Amount that will be collected. It is required when amount_type is fixed.
912 913 914 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 912 def amount @amount end |
#amount_type ⇒ Object
The type of amount that will be collected. The amount charged must be exact or up to the value of amount param for fixed or maximum type respectively. Defaults to maximum.
914 915 916 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 914 def amount_type @amount_type end |
#end_date ⇒ Object
Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.
916 917 918 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 916 def end_date @end_date end |
#payment_schedule ⇒ Object
The periodicity at which payments will be collected. Defaults to adhoc.
918 919 920 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 918 def payment_schedule @payment_schedule end |
#payments_per_period ⇒ Object
The number of payments that will be made during a payment period. Defaults to 1 except for when payment_schedule is adhoc. In that case, it defaults to no limit.
920 921 922 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 920 def payments_per_period @payments_per_period end |
#purpose ⇒ Object
The purpose for which payments are made. Has a default value based on your merchant category code.
922 923 924 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 922 def purpose @purpose end |
#start_date ⇒ Object
Date, in YYYY-MM-DD format, from which payments will be collected. Defaults to confirmation time.
924 925 926 |
# File 'lib/stripe/params/setup_intent_update_params.rb', line 924 def start_date @start_date end |