Class: Stripe::SetupIntentUpdateParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/setup_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1111
1112
1113
1114
1115
1116
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1111

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



1103
1104
1105
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1103

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



1105
1106
1107
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1105

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



1107
1108
1109
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1107

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



1109
1110
1111
# File 'lib/stripe/params/setup_intent_update_params.rb', line 1109

def end_date
  @end_date
end