Class: Stripe::SharedPayment::GrantedToken
- Inherits:
-
APIResource
- Object
- Stripe::StripeObject
- APIResource
- Stripe::SharedPayment::GrantedToken
- Defined in:
- lib/stripe/resources/shared_payment/granted_token.rb
Overview
SharedPaymentGrantedToken is the view-only resource of a SharedPaymentIssuedToken, which is a limited-use reference to a PaymentMethod. When another Stripe merchant shares a SharedPaymentIssuedToken with you, you can view attributes of the shared token using the SharedPaymentGrantedToken API, and use it with a PaymentIntent.
Defined Under Namespace
Classes: AgentDetails, PaymentMethodDetails, RiskDetails, TestHelpers, UsageDetails, UsageLimits
Constant Summary collapse
- OBJECT_NAME =
"shared_payment.granted_token"
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#agent_details ⇒ Object
readonly
Details about the agent that issued this SharedPaymentGrantedToken.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#deactivated_at ⇒ Object
readonly
Time at which this SharedPaymentGrantedToken expires and can no longer be used to confirm a PaymentIntent.
-
#deactivated_reason ⇒ Object
readonly
The reason why the SharedPaymentGrantedToken has been deactivated.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#payment_method_details ⇒ Object
readonly
Details of the PaymentMethod that was shared via this token.
-
#risk_details ⇒ Object
readonly
Risk details of the SharedPaymentGrantedToken.
-
#shared_metadata ⇒ Object
readonly
Metadata about the SharedPaymentGrantedToken.
-
#usage_details ⇒ Object
readonly
Some details about how the SharedPaymentGrantedToken has been used already.
-
#usage_limits ⇒ Object
readonly
Limits on how this SharedPaymentGrantedToken can be used.
Attributes inherited from APIResource
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#agent_details ⇒ Object (readonly)
Details about the agent that issued this SharedPaymentGrantedToken.
1742 1743 1744 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1742 def agent_details @agent_details end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
1744 1745 1746 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1744 def created @created end |
#deactivated_at ⇒ Object (readonly)
Time at which this SharedPaymentGrantedToken expires and can no longer be used to confirm a PaymentIntent.
1746 1747 1748 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1746 def deactivated_at @deactivated_at end |
#deactivated_reason ⇒ Object (readonly)
The reason why the SharedPaymentGrantedToken has been deactivated.
1748 1749 1750 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1748 def deactivated_reason @deactivated_reason end |
#id ⇒ Object (readonly)
Unique identifier for the object.
1750 1751 1752 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1750 def id @id end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
1752 1753 1754 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1752 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
1754 1755 1756 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1754 def object @object end |
#payment_method_details ⇒ Object (readonly)
Details of the PaymentMethod that was shared via this token.
1756 1757 1758 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1756 def payment_method_details @payment_method_details end |
#risk_details ⇒ Object (readonly)
Risk details of the SharedPaymentGrantedToken.
1758 1759 1760 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1758 def risk_details @risk_details end |
#shared_metadata ⇒ Object (readonly)
Metadata about the SharedPaymentGrantedToken.
1760 1761 1762 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1760 def @shared_metadata end |
#usage_details ⇒ Object (readonly)
Some details about how the SharedPaymentGrantedToken has been used already.
1762 1763 1764 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1762 def usage_details @usage_details end |
#usage_limits ⇒ Object (readonly)
Limits on how this SharedPaymentGrantedToken can be used.
1764 1765 1766 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1764 def usage_limits @usage_limits end |
Class Method Details
.field_remappings ⇒ Object
1817 1818 1819 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1817 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1807 1808 1809 1810 1811 1812 1813 1814 1815 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1807 def self.inner_class_types @inner_class_types = { agent_details: AgentDetails, payment_method_details: PaymentMethodDetails, risk_details: RiskDetails, usage_details: UsageDetails, usage_limits: UsageLimits, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 10 def self.object_name "shared_payment.granted_token" end |
Instance Method Details
#test_helpers ⇒ Object
1766 1767 1768 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1766 def test_helpers TestHelpers.new(self) end |