Class: Stripe::SharedPayment::GrantedToken
- Inherits:
-
APIResource
- Object
- Stripe::StripeObject
- APIResource
- Stripe::SharedPayment::GrantedToken
- Defined in:
- lib/stripe/resources/shared_payment/granted_token.rb
Overview
SharedPaymentGrantedToken is the view-only resource of a SharedPaymentIssuedToken, which is a limited-use reference to a PaymentMethod. When another Stripe merchant shares a SharedPaymentIssuedToken with you, you can view attributes of the shared token using the SharedPaymentGrantedToken API, and use it with a PaymentIntent.
Defined Under Namespace
Classes: TestHelpers, UsageDetails, UsageLimits
Constant Summary collapse
- OBJECT_NAME =
"shared_payment.granted_token"
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#deactivated_at ⇒ Object
readonly
Time at which this SharedPaymentGrantedToken expires and can no longer be used to confirm a PaymentIntent.
-
#deactivated_reason ⇒ Object
readonly
The reason why the SharedPaymentGrantedToken has been deactivated.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#shared_metadata ⇒ Object
readonly
Metadata about the SharedPaymentGrantedToken.
-
#usage_details ⇒ Object
readonly
Some details about how the SharedPaymentGrantedToken has been used already.
-
#usage_limits ⇒ Object
readonly
Limits on how this SharedPaymentGrantedToken can be used.
Attributes inherited from APIResource
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
58 59 60 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 58 def created @created end |
#deactivated_at ⇒ Object (readonly)
Time at which this SharedPaymentGrantedToken expires and can no longer be used to confirm a PaymentIntent.
60 61 62 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 60 def deactivated_at @deactivated_at end |
#deactivated_reason ⇒ Object (readonly)
The reason why the SharedPaymentGrantedToken has been deactivated.
62 63 64 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 62 def deactivated_reason @deactivated_reason end |
#id ⇒ Object (readonly)
Unique identifier for the object.
64 65 66 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 64 def id @id end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
66 67 68 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 66 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
68 69 70 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 68 def object @object end |
#shared_metadata ⇒ Object (readonly)
Metadata about the SharedPaymentGrantedToken.
70 71 72 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 70 def @shared_metadata end |
#usage_details ⇒ Object (readonly)
Some details about how the SharedPaymentGrantedToken has been used already.
72 73 74 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 72 def usage_details @usage_details end |
#usage_limits ⇒ Object (readonly)
Limits on how this SharedPaymentGrantedToken can be used.
74 75 76 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 74 def usage_limits @usage_limits end |
Class Method Details
.field_remappings ⇒ Object
121 122 123 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 121 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
117 118 119 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 117 def self.inner_class_types @inner_class_types = { usage_details: UsageDetails, usage_limits: UsageLimits } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 10 def self.object_name "shared_payment.granted_token" end |
Instance Method Details
#test_helpers ⇒ Object
76 77 78 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 76 def test_helpers TestHelpers.new(self) end |