Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SharedPayment::GrantedToken::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/shared_payment/granted_token.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Bizum, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, Scalapay, SepaDebit, Shopeepay, Sofort, StripeBalance, Sunbit, Swish, Twint, Upi, UsBankAccount, WechatPay, Zip
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billie ⇒ Object
readonly
Attribute for field billie.
-
#billing_details ⇒ Object
readonly
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
-
#bizum ⇒ Object
readonly
Attribute for field bizum.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#crypto ⇒ Object
readonly
Attribute for field crypto.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#interac_present ⇒ Object
readonly
Attribute for field interac_present.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#paypay ⇒ Object
readonly
Attribute for field paypay.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#rechnung ⇒ Object
readonly
Attribute for field rechnung.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#scalapay ⇒ Object
readonly
Attribute for field scalapay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#stripe_balance ⇒ Object
readonly
Attribute for field stripe_balance.
-
#sunbit ⇒ Object
readonly
Attribute for field sunbit.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of the PaymentMethod.
-
#upi ⇒ Object
readonly
Attribute for field upi.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
1351 1352 1353 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1351 def acss_debit @acss_debit end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
1353 1354 1355 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1353 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
1355 1356 1357 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1355 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
1357 1358 1359 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1357 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
1359 1360 1361 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1359 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
1361 1362 1363 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1361 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
1363 1364 1365 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1363 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
1365 1366 1367 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1365 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
1367 1368 1369 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1367 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
Attribute for field billie
1369 1370 1371 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1369 def billie @billie end |
#billing_details ⇒ Object (readonly)
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
1371 1372 1373 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1371 def billing_details @billing_details end |
#bizum ⇒ Object (readonly)
Attribute for field bizum
1373 1374 1375 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1373 def bizum @bizum end |
#blik ⇒ Object (readonly)
Attribute for field blik
1375 1376 1377 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1375 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
1377 1378 1379 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1377 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
1379 1380 1381 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1379 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
1381 1382 1383 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1381 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
1383 1384 1385 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1383 def cashapp @cashapp end |
#crypto ⇒ Object (readonly)
Attribute for field crypto
1385 1386 1387 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1385 def crypto @crypto end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
1387 1388 1389 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1387 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
1389 1390 1391 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1389 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
1391 1392 1393 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1391 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
1393 1394 1395 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1393 def giropay @giropay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
1395 1396 1397 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1395 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
1397 1398 1399 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1397 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
1399 1400 1401 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1399 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
1401 1402 1403 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1401 def ideal @ideal end |
#interac_present ⇒ Object (readonly)
Attribute for field interac_present
1403 1404 1405 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1403 def interac_present @interac_present end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
1405 1406 1407 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1405 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
1407 1408 1409 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1407 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
1409 1410 1411 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1409 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
1411 1412 1413 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1411 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
1413 1414 1415 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1413 def link @link end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
1415 1416 1417 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1415 def mb_way @mb_way end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
1417 1418 1419 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1417 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
1419 1420 1421 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1419 def multibanco @multibanco end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
1421 1422 1423 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1421 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
1423 1424 1425 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1423 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
1425 1426 1427 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1425 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
1427 1428 1429 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1427 def p24 @p24 end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
1429 1430 1431 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1429 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
1431 1432 1433 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1431 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
1433 1434 1435 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1433 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
1435 1436 1437 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1435 def paypal @paypal end |
#paypay ⇒ Object (readonly)
Attribute for field paypay
1437 1438 1439 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1437 def paypay @paypay end |
#payto ⇒ Object (readonly)
Attribute for field payto
1439 1440 1441 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1439 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
1441 1442 1443 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1441 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
1443 1444 1445 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1443 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
1445 1446 1447 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1445 def qris @qris end |
#rechnung ⇒ Object (readonly)
Attribute for field rechnung
1447 1448 1449 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1447 def rechnung @rechnung end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
1449 1450 1451 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1449 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
1451 1452 1453 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1451 def samsung_pay @samsung_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
1453 1454 1455 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1453 def satispay @satispay end |
#scalapay ⇒ Object (readonly)
Attribute for field scalapay
1455 1456 1457 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1455 def scalapay @scalapay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
1457 1458 1459 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1457 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
1459 1460 1461 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1459 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
1461 1462 1463 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1461 def sofort @sofort end |
#stripe_balance ⇒ Object (readonly)
Attribute for field stripe_balance
1463 1464 1465 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1463 def stripe_balance @stripe_balance end |
#sunbit ⇒ Object (readonly)
Attribute for field sunbit
1465 1466 1467 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1465 def sunbit @sunbit end |
#swish ⇒ Object (readonly)
Attribute for field swish
1467 1468 1469 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1467 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
1469 1470 1471 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1469 def twint @twint end |
#type ⇒ Object (readonly)
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
1471 1472 1473 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1471 def type @type end |
#upi ⇒ Object (readonly)
Attribute for field upi
1473 1474 1475 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1473 def upi @upi end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
1475 1476 1477 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1475 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
1477 1478 1479 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1477 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
1479 1480 1481 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1479 def zip @zip end |
Class Method Details
.field_remappings ⇒ Object
1550 1551 1552 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1550 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1481 def self.inner_class_types @inner_class_types = { acss_debit: AcssDebit, affirm: Affirm, afterpay_clearpay: AfterpayClearpay, alipay: Alipay, alma: Alma, amazon_pay: AmazonPay, au_becs_debit: AuBecsDebit, bacs_debit: BacsDebit, bancontact: Bancontact, billie: Billie, billing_details: BillingDetails, bizum: Bizum, blik: Blik, boleto: Boleto, card: Card, card_present: CardPresent, cashapp: Cashapp, crypto: Crypto, customer_balance: CustomerBalance, eps: Eps, fpx: Fpx, giropay: Giropay, gopay: Gopay, grabpay: Grabpay, id_bank_transfer: IdBankTransfer, ideal: Ideal, interac_present: InteracPresent, kakao_pay: KakaoPay, klarna: Klarna, konbini: Konbini, kr_card: KrCard, link: Link, mb_way: MbWay, mobilepay: Mobilepay, multibanco: Multibanco, naver_pay: NaverPay, nz_bank_account: NzBankAccount, oxxo: Oxxo, p24: P24, pay_by_bank: PayByBank, payco: Payco, paynow: Paynow, paypal: Paypal, paypay: Paypay, payto: Payto, pix: Pix, promptpay: Promptpay, qris: Qris, rechnung: Rechnung, revolut_pay: RevolutPay, samsung_pay: SamsungPay, satispay: Satispay, scalapay: Scalapay, sepa_debit: SepaDebit, shopeepay: Shopeepay, sofort: Sofort, stripe_balance: StripeBalance, sunbit: Sunbit, swish: Swish, twint: Twint, upi: Upi, us_bank_account: UsBankAccount, wechat_pay: WechatPay, zip: Zip, } end |