Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SharedPayment::GrantedToken::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/shared_payment/granted_token.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, GiftCard, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, StripeBalance, Sunbit, Swish, Twint, Upi, UsBankAccount, WechatPay, Zip
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billie ⇒ Object
readonly
Attribute for field billie.
-
#billing_details ⇒ Object
readonly
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#crypto ⇒ Object
readonly
Attribute for field crypto.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#gift_card ⇒ Object
readonly
Attribute for field gift_card.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#interac_present ⇒ Object
readonly
Attribute for field interac_present.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#paypay ⇒ Object
readonly
Attribute for field paypay.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#rechnung ⇒ Object
readonly
Attribute for field rechnung.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#stripe_balance ⇒ Object
readonly
Attribute for field stripe_balance.
-
#sunbit ⇒ Object
readonly
Attribute for field sunbit.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of the PaymentMethod.
-
#upi ⇒ Object
readonly
Attribute for field upi.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
1356 1357 1358 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1356 def acss_debit @acss_debit end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
1358 1359 1360 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1358 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
1360 1361 1362 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1360 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
1362 1363 1364 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1362 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
1364 1365 1366 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1364 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
1366 1367 1368 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1366 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
1368 1369 1370 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1368 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
1370 1371 1372 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1370 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
1372 1373 1374 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1372 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
Attribute for field billie
1374 1375 1376 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1374 def billie @billie end |
#billing_details ⇒ Object (readonly)
Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
1376 1377 1378 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1376 def billing_details @billing_details end |
#blik ⇒ Object (readonly)
Attribute for field blik
1378 1379 1380 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1378 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
1380 1381 1382 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1380 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
1382 1383 1384 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1382 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
1384 1385 1386 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1384 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
1386 1387 1388 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1386 def cashapp @cashapp end |
#crypto ⇒ Object (readonly)
Attribute for field crypto
1388 1389 1390 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1388 def crypto @crypto end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
1390 1391 1392 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1390 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
1392 1393 1394 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1392 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
1394 1395 1396 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1394 def fpx @fpx end |
#gift_card ⇒ Object (readonly)
Attribute for field gift_card
1396 1397 1398 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1396 def gift_card @gift_card end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
1398 1399 1400 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1398 def giropay @giropay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
1400 1401 1402 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1400 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
1402 1403 1404 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1402 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
1404 1405 1406 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1404 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
1406 1407 1408 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1406 def ideal @ideal end |
#interac_present ⇒ Object (readonly)
Attribute for field interac_present
1408 1409 1410 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1408 def interac_present @interac_present end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
1410 1411 1412 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1410 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
1412 1413 1414 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1412 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
1414 1415 1416 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1414 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
1416 1417 1418 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1416 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
1418 1419 1420 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1418 def link @link end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
1420 1421 1422 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1420 def mb_way @mb_way end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
1422 1423 1424 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1422 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
1424 1425 1426 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1424 def multibanco @multibanco end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
1426 1427 1428 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1426 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
1428 1429 1430 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1428 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
1430 1431 1432 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1430 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
1432 1433 1434 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1432 def p24 @p24 end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
1434 1435 1436 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1434 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
1436 1437 1438 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1436 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
1438 1439 1440 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1438 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
1440 1441 1442 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1440 def paypal @paypal end |
#paypay ⇒ Object (readonly)
Attribute for field paypay
1442 1443 1444 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1442 def paypay @paypay end |
#payto ⇒ Object (readonly)
Attribute for field payto
1444 1445 1446 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1444 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
1446 1447 1448 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1446 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
1448 1449 1450 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1448 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
1450 1451 1452 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1450 def qris @qris end |
#rechnung ⇒ Object (readonly)
Attribute for field rechnung
1452 1453 1454 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1452 def rechnung @rechnung end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
1454 1455 1456 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1454 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
1456 1457 1458 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1456 def samsung_pay @samsung_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
1458 1459 1460 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1458 def satispay @satispay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
1460 1461 1462 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1460 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
1462 1463 1464 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1462 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
1464 1465 1466 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1464 def sofort @sofort end |
#stripe_balance ⇒ Object (readonly)
Attribute for field stripe_balance
1466 1467 1468 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1466 def stripe_balance @stripe_balance end |
#sunbit ⇒ Object (readonly)
Attribute for field sunbit
1468 1469 1470 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1468 def sunbit @sunbit end |
#swish ⇒ Object (readonly)
Attribute for field swish
1470 1471 1472 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1470 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
1472 1473 1474 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1472 def twint @twint end |
#type ⇒ Object (readonly)
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
1474 1475 1476 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1474 def type @type end |
#upi ⇒ Object (readonly)
Attribute for field upi
1476 1477 1478 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1476 def upi @upi end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
1478 1479 1480 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1478 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
1480 1481 1482 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1480 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
1482 1483 1484 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1482 def zip @zip end |
Class Method Details
.field_remappings ⇒ Object
1552 1553 1554 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1552 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1484 def self.inner_class_types @inner_class_types = { acss_debit: AcssDebit, affirm: Affirm, afterpay_clearpay: AfterpayClearpay, alipay: Alipay, alma: Alma, amazon_pay: AmazonPay, au_becs_debit: AuBecsDebit, bacs_debit: BacsDebit, bancontact: Bancontact, billie: Billie, billing_details: BillingDetails, blik: Blik, boleto: Boleto, card: Card, card_present: CardPresent, cashapp: Cashapp, crypto: Crypto, customer_balance: CustomerBalance, eps: Eps, fpx: Fpx, gift_card: GiftCard, giropay: Giropay, gopay: Gopay, grabpay: Grabpay, id_bank_transfer: IdBankTransfer, ideal: Ideal, interac_present: InteracPresent, kakao_pay: KakaoPay, klarna: Klarna, konbini: Konbini, kr_card: KrCard, link: Link, mb_way: MbWay, mobilepay: Mobilepay, multibanco: Multibanco, naver_pay: NaverPay, nz_bank_account: NzBankAccount, oxxo: Oxxo, p24: P24, pay_by_bank: PayByBank, payco: Payco, paynow: Paynow, paypal: Paypal, paypay: Paypay, payto: Payto, pix: Pix, promptpay: Promptpay, qris: Qris, rechnung: Rechnung, revolut_pay: RevolutPay, samsung_pay: SamsungPay, satispay: Satispay, sepa_debit: SepaDebit, shopeepay: Shopeepay, sofort: Sofort, stripe_balance: StripeBalance, sunbit: Sunbit, swish: Swish, twint: Twint, upi: Upi, us_bank_account: UsBankAccount, wechat_pay: WechatPay, zip: Zip, } end |