Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/shared_payment/granted_token.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, StripeBalance, Sunbit, Swish, Twint, Upi, UsBankAccount, WechatPay, Zip

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

Attribute for field acss_debit



1331
1332
1333
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1331

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



1333
1334
1335
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1333

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



1335
1336
1337
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1335

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



1337
1338
1339
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1337

def alipay
  @alipay
end

#almaObject (readonly)

Attribute for field alma



1339
1340
1341
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1339

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



1341
1342
1343
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1341

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



1343
1344
1345
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1343

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



1345
1346
1347
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1345

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



1347
1348
1349
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1347

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



1349
1350
1351
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1349

def billie
  @billie
end

#billing_detailsObject (readonly)

Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.



1351
1352
1353
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1351

def billing_details
  @billing_details
end

#blikObject (readonly)

Attribute for field blik



1353
1354
1355
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1353

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



1355
1356
1357
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1355

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



1357
1358
1359
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1357

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



1359
1360
1361
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1359

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



1361
1362
1363
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1361

def cashapp
  @cashapp
end

#cryptoObject (readonly)

Attribute for field crypto



1363
1364
1365
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1363

def crypto
  @crypto
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



1365
1366
1367
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1365

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



1367
1368
1369
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1367

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



1369
1370
1371
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1369

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



1371
1372
1373
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1371

def giropay
  @giropay
end

#gopayObject (readonly)

Attribute for field gopay



1373
1374
1375
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1373

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



1375
1376
1377
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1375

def grabpay
  @grabpay
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



1377
1378
1379
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1377

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



1379
1380
1381
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1379

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



1381
1382
1383
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1381

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



1383
1384
1385
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1383

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



1385
1386
1387
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1385

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



1387
1388
1389
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1387

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



1389
1390
1391
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1389

def kr_card
  @kr_card
end

Attribute for field link



1391
1392
1393
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1391

def link
  @link
end

#mb_wayObject (readonly)

Attribute for field mb_way



1393
1394
1395
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1393

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



1395
1396
1397
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1395

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



1397
1398
1399
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1397

def multibanco
  @multibanco
end

Attribute for field naver_pay



1399
1400
1401
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1399

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



1401
1402
1403
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1401

def 
  @nz_bank_account
end

#oxxoObject (readonly)

Attribute for field oxxo



1403
1404
1405
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1403

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



1405
1406
1407
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1405

def p24
  @p24
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



1407
1408
1409
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1407

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



1409
1410
1411
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1409

def payco
  @payco
end

#paynowObject (readonly)

Attribute for field paynow



1411
1412
1413
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1411

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



1413
1414
1415
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1413

def paypal
  @paypal
end

#paypayObject (readonly)

Attribute for field paypay



1415
1416
1417
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1415

def paypay
  @paypay
end

#paytoObject (readonly)

Attribute for field payto



1417
1418
1419
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1417

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



1419
1420
1421
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1419

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



1421
1422
1423
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1421

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



1423
1424
1425
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1423

def qris
  @qris
end

#rechnungObject (readonly)

Attribute for field rechnung



1425
1426
1427
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1425

def rechnung
  @rechnung
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



1427
1428
1429
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1427

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



1429
1430
1431
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1429

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



1431
1432
1433
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1431

def satispay
  @satispay
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



1433
1434
1435
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1433

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



1435
1436
1437
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1435

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



1437
1438
1439
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1437

def sofort
  @sofort
end

#stripe_balanceObject (readonly)

Attribute for field stripe_balance



1439
1440
1441
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1439

def stripe_balance
  @stripe_balance
end

#sunbitObject (readonly)

Attribute for field sunbit



1441
1442
1443
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1441

def sunbit
  @sunbit
end

#swishObject (readonly)

Attribute for field swish



1443
1444
1445
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1443

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



1445
1446
1447
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1445

def twint
  @twint
end

#typeObject (readonly)

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



1447
1448
1449
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1447

def type
  @type
end

#upiObject (readonly)

Attribute for field upi



1449
1450
1451
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1449

def upi
  @upi
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



1451
1452
1453
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1451

def 
  @us_bank_account
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



1453
1454
1455
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1453

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



1455
1456
1457
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1455

def zip
  @zip
end

Class Method Details

.field_remappingsObject



1524
1525
1526
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1524

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1457

def self.inner_class_types
  @inner_class_types = {
    acss_debit: AcssDebit,
    affirm: Affirm,
    afterpay_clearpay: AfterpayClearpay,
    alipay: Alipay,
    alma: Alma,
    amazon_pay: AmazonPay,
    au_becs_debit: AuBecsDebit,
    bacs_debit: BacsDebit,
    bancontact: Bancontact,
    billie: Billie,
    billing_details: BillingDetails,
    blik: Blik,
    boleto: Boleto,
    card: Card,
    card_present: CardPresent,
    cashapp: Cashapp,
    crypto: Crypto,
    customer_balance: CustomerBalance,
    eps: Eps,
    fpx: Fpx,
    giropay: Giropay,
    gopay: Gopay,
    grabpay: Grabpay,
    id_bank_transfer: IdBankTransfer,
    ideal: Ideal,
    interac_present: InteracPresent,
    kakao_pay: KakaoPay,
    klarna: Klarna,
    konbini: Konbini,
    kr_card: KrCard,
    link: Link,
    mb_way: MbWay,
    mobilepay: Mobilepay,
    multibanco: Multibanco,
    naver_pay: NaverPay,
    nz_bank_account: NzBankAccount,
    oxxo: Oxxo,
    p24: P24,
    pay_by_bank: PayByBank,
    payco: Payco,
    paynow: Paynow,
    paypal: Paypal,
    paypay: Paypay,
    payto: Payto,
    pix: Pix,
    promptpay: Promptpay,
    qris: Qris,
    rechnung: Rechnung,
    revolut_pay: RevolutPay,
    samsung_pay: SamsungPay,
    satispay: Satispay,
    sepa_debit: SepaDebit,
    shopeepay: Shopeepay,
    sofort: Sofort,
    stripe_balance: StripeBalance,
    sunbit: Sunbit,
    swish: Swish,
    twint: Twint,
    upi: Upi,
    us_bank_account: UsBankAccount,
    wechat_pay: WechatPay,
    zip: Zip,
  }
end