Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::AcssDebit
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::AcssDebit
- Defined in:
- lib/stripe/resources/shared_payment/granted_token.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_number ⇒ Object
readonly
Account number of the bank account.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular bank account.
-
#institution_number ⇒ Object
readonly
Institution number of the bank account.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#transit_number ⇒ Object
readonly
Transit number of the bank account.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_number ⇒ Object (readonly)
Account number of the bank account.
76 77 78 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 76 def account_number @account_number end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
78 79 80 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 78 def bank_name @bank_name end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
80 81 82 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 80 def fingerprint @fingerprint end |
#institution_number ⇒ Object (readonly)
Institution number of the bank account.
82 83 84 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 82 def institution_number @institution_number end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
84 85 86 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 84 def last4 @last4 end |
#transit_number ⇒ Object (readonly)
Transit number of the bank account.
86 87 88 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 86 def transit_number @transit_number end |
Class Method Details
.field_remappings ⇒ Object
92 93 94 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 92 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
88 89 90 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 88 def self.inner_class_types @inner_class_types = {} end |