Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::Card

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/shared_payment/granted_token.rb

Defined Under Namespace

Classes: Checks, Networks, Wallet

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

Card brand. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa` or `unknown`.



484
485
486
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 484

def brand
  @brand
end

#checksObject (readonly)

Checks on Card address and CVC if provided.



486
487
488
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 486

def checks
  @checks
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



488
489
490
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 488

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



490
491
492
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 490

def description
  @description
end

#display_brandObject (readonly)

The brand to use when displaying the card, this accounts for customer’s brand choice on dual-branded cards. Can be ‘american_express`, `cartes_bancaires`, `diners_club`, `discover`, `eftpos_australia`, `interac`, `jcb`, `mastercard`, `union_pay`, `visa`, or `other` and may contain more values in the future.



492
493
494
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 492

def display_brand
  @display_brand
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



494
495
496
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 494

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



496
497
498
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 496

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*



500
501
502
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 500

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



502
503
504
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 502

def funding
  @funding
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



504
505
506
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 504

def iin
  @iin
end

#issuerObject (readonly)

The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)



506
507
508
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 506

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



508
509
510
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 508

def last4
  @last4
end

#networksObject (readonly)

Contains information about card networks that can be used to process the payment.



510
511
512
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 510

def networks
  @networks
end

#walletObject (readonly)

If this Card is part of a card wallet, this contains the details of the card wallet.



512
513
514
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 512

def wallet
  @wallet
end

Class Method Details

.field_remappingsObject



518
519
520
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 518

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



514
515
516
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 514

def self.inner_class_types
  @inner_class_types = { checks: Checks, networks: Networks, wallet: Wallet }
end