Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::Card
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::Card
- Defined in:
- lib/stripe/resources/shared_payment/granted_token.rb
Defined Under Namespace
Classes: Checks, Networks, Wallet
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#brand ⇒ Object
readonly
Card brand.
-
#checks ⇒ Object
readonly
Checks on Card address and CVC if provided.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country of the card.
-
#description ⇒ Object
readonly
A high-level description of the type of cards issued in this range.
-
#display_brand ⇒ Object
readonly
The brand to use when displaying the card, this accounts for customer’s brand choice on dual-branded cards.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card’s expiration year.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular card number.
-
#funding ⇒ Object
readonly
Card funding type.
-
#iin ⇒ Object
readonly
Issuer identification number of the card.
-
#issuer ⇒ Object
readonly
The name of the card’s issuing bank.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#networks ⇒ Object
readonly
Contains information about card networks that can be used to process the payment.
-
#wallet ⇒ Object
readonly
If this Card is part of a card wallet, this contains the details of the card wallet.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#brand ⇒ Object (readonly)
Card brand. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa` or `unknown`.
520 521 522 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 520 def brand @brand end |
#checks ⇒ Object (readonly)
Checks on Card address and CVC if provided.
522 523 524 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 522 def checks @checks end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.
524 525 526 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 524 def country @country end |
#description ⇒ Object (readonly)
A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)
526 527 528 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 526 def description @description end |
#display_brand ⇒ Object (readonly)
The brand to use when displaying the card, this accounts for customer’s brand choice on dual-branded cards. Can be ‘american_express`, `cartes_bancaires`, `diners_club`, `discover`, `eftpos_australia`, `interac`, `jcb`, `mastercard`, `union_pay`, `visa`, or `other` and may contain more values in the future.
528 529 530 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 528 def display_brand @display_brand end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card’s expiration month.
530 531 532 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 530 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card’s expiration year.
532 533 534 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 532 def exp_year @exp_year end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.
*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*
536 537 538 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 536 def fingerprint @fingerprint end |
#funding ⇒ Object (readonly)
Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.
538 539 540 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 538 def funding @funding end |
#iin ⇒ Object (readonly)
Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)
540 541 542 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 540 def iin @iin end |
#issuer ⇒ Object (readonly)
The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)
542 543 544 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 542 def issuer @issuer end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
544 545 546 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 544 def last4 @last4 end |
#networks ⇒ Object (readonly)
Contains information about card networks that can be used to process the payment.
546 547 548 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 546 def networks @networks end |
#wallet ⇒ Object (readonly)
If this Card is part of a card wallet, this contains the details of the card wallet.
548 549 550 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 548 def wallet @wallet end |
Class Method Details
.field_remappings ⇒ Object
554 555 556 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 554 def self.field_remappings @field_remappings = {} end |