Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::Card::Wallet
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::Card::Wallet
- Defined in:
- lib/stripe/resources/shared_payment/granted_token.rb
Defined Under Namespace
Classes: AmexExpressCheckout, ApplePay, GooglePay, Link, Masterpass, SamsungPay, VisaCheckout
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amex_express_checkout ⇒ Object
readonly
Attribute for field amex_express_checkout.
-
#apple_pay ⇒ Object
readonly
Attribute for field apple_pay.
-
#dynamic_last4 ⇒ Object
readonly
(For tokenized numbers only.) The last four digits of the device account number.
-
#google_pay ⇒ Object
readonly
Attribute for field google_pay.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#masterpass ⇒ Object
readonly
Attribute for field masterpass.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#type ⇒ Object
readonly
The type of the card wallet, one of
amex_express_checkout,apple_pay,google_pay,masterpass,samsung_pay,visa_checkout, orlink. -
#visa_checkout ⇒ Object
readonly
Attribute for field visa_checkout.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amex_express_checkout ⇒ Object (readonly)
Attribute for field amex_express_checkout
299 300 301 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 299 def amex_express_checkout @amex_express_checkout end |
#apple_pay ⇒ Object (readonly)
Attribute for field apple_pay
301 302 303 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 301 def apple_pay @apple_pay end |
#dynamic_last4 ⇒ Object (readonly)
(For tokenized numbers only.) The last four digits of the device account number.
303 304 305 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 303 def dynamic_last4 @dynamic_last4 end |
#google_pay ⇒ Object (readonly)
Attribute for field google_pay
305 306 307 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 305 def google_pay @google_pay end |
#link ⇒ Object (readonly)
Attribute for field link
307 308 309 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 307 def link @link end |
#masterpass ⇒ Object (readonly)
Attribute for field masterpass
309 310 311 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 309 def masterpass @masterpass end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
311 312 313 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 311 def samsung_pay @samsung_pay end |
#type ⇒ Object (readonly)
The type of the card wallet, one of amex_express_checkout, apple_pay, google_pay, masterpass, samsung_pay, visa_checkout, or link. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type.
313 314 315 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 313 def type @type end |
#visa_checkout ⇒ Object (readonly)
Attribute for field visa_checkout
315 316 317 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 315 def visa_checkout @visa_checkout end |
Class Method Details
.field_remappings ⇒ Object
329 330 331 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 329 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 317 def self.inner_class_types @inner_class_types = { amex_express_checkout: AmexExpressCheckout, apple_pay: ApplePay, google_pay: GooglePay, link: Link, masterpass: Masterpass, samsung_pay: SamsungPay, visa_checkout: VisaCheckout, } end |