Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::Card::Wallet::Masterpass

Inherits:
Stripe::StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/shared_payment/granted_token.rb

Defined Under Namespace

Classes: BillingAddress, ShippingAddress

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_addressObject (readonly)

Owner’s verified billing address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



358
359
360
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 358

def billing_address
  @billing_address
end

#emailObject (readonly)

Owner’s verified email. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



360
361
362
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 360

def email
  @email
end

#nameObject (readonly)

Owner’s verified full name. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



362
363
364
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 362

def name
  @name
end

#shipping_addressObject (readonly)

Owner’s verified shipping address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



364
365
366
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 364

def shipping_address
  @shipping_address
end

Class Method Details

.field_remappingsObject



373
374
375
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 373

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



366
367
368
369
370
371
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 366

def self.inner_class_types
  @inner_class_types = {
    billing_address: BillingAddress,
    shipping_address: ShippingAddress,
  }
end