Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::Card::Wallet::Masterpass
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::Card::Wallet::Masterpass
- Defined in:
- lib/stripe/resources/shared_payment/granted_token.rb
Defined Under Namespace
Classes: BillingAddress, ShippingAddress
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_address ⇒ Object
readonly
Owner’s verified billing address.
-
#email ⇒ Object
readonly
Owner’s verified email.
-
#name ⇒ Object
readonly
Owner’s verified full name.
-
#shipping_address ⇒ Object
readonly
Owner’s verified shipping address.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_address ⇒ Object (readonly)
Owner’s verified billing address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
352 353 354 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 352 def billing_address @billing_address end |
#email ⇒ Object (readonly)
Owner’s verified email. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
354 355 356 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 354 def email @email end |
#name ⇒ Object (readonly)
Owner’s verified full name. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
356 357 358 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 356 def name @name end |
#shipping_address ⇒ Object (readonly)
Owner’s verified shipping address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
358 359 360 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 358 def shipping_address @shipping_address end |
Class Method Details
.field_remappings ⇒ Object
367 368 369 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 367 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
360 361 362 363 364 365 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 360 def self.inner_class_types @inner_class_types = { billing_address: BillingAddress, shipping_address: ShippingAddress, } end |