Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::Card::Wallet::Masterpass

Inherits:
Stripe::StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/shared_payment/granted_token.rb

Defined Under Namespace

Classes: BillingAddress, ShippingAddress

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_addressObject (readonly)

Owner’s verified billing address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



388
389
390
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 388

def billing_address
  @billing_address
end

#emailObject (readonly)

Owner’s verified email. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



390
391
392
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 390

def email
  @email
end

#nameObject (readonly)

Owner’s verified full name. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



392
393
394
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 392

def name
  @name
end

#shipping_addressObject (readonly)

Owner’s verified shipping address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



394
395
396
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 394

def shipping_address
  @shipping_address
end

Class Method Details

.field_remappingsObject



403
404
405
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 403

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



396
397
398
399
400
401
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 396

def self.inner_class_types
  @inner_class_types = {
    billing_address: BillingAddress,
    shipping_address: ShippingAddress,
  }
end