Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::Card::Wallet::VisaCheckout

Inherits:
Stripe::StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/shared_payment/granted_token.rb

Defined Under Namespace

Classes: BillingAddress, ShippingAddress

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_addressObject (readonly)

Owner’s verified billing address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



435
436
437
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 435

def billing_address
  @billing_address
end

#emailObject (readonly)

Owner’s verified email. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



437
438
439
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 437

def email
  @email
end

#nameObject (readonly)

Owner’s verified full name. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



439
440
441
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 439

def name
  @name
end

#shipping_addressObject (readonly)

Owner’s verified shipping address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



441
442
443
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 441

def shipping_address
  @shipping_address
end

Class Method Details

.field_remappingsObject



450
451
452
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 450

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



443
444
445
446
447
448
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 443

def self.inner_class_types
  @inner_class_types = {
    billing_address: BillingAddress,
    shipping_address: ShippingAddress,
  }
end