Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::CardPresent::Offline
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::CardPresent::Offline
- Defined in:
- lib/stripe/resources/shared_payment/granted_token.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#stored_at ⇒ Object
readonly
Time at which the payment was collected while offline.
-
#type ⇒ Object
readonly
The method used to process this payment method offline.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#stored_at ⇒ Object (readonly)
Time at which the payment was collected while offline
531 532 533 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 531 def stored_at @stored_at end |
#type ⇒ Object (readonly)
The method used to process this payment method offline. Only deferred is allowed.
533 534 535 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 533 def type @type end |
Class Method Details
.field_remappings ⇒ Object
539 540 541 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 539 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
535 536 537 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 535 def self.inner_class_types @inner_class_types = {} end |