Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::GiftCard
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::GiftCard
- Defined in:
- lib/stripe/resources/shared_payment/granted_token.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#brand ⇒ Object
readonly
The brand of the gift card.
-
#exp_month ⇒ Object
readonly
The expiration month of the gift card.
-
#exp_year ⇒ Object
readonly
The expiration year of the gift card.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies the gift card.
-
#first6 ⇒ Object
readonly
The first six digits of the gift card number.
-
#last4 ⇒ Object
readonly
The last four digits of the gift card number.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#brand ⇒ Object (readonly)
The brand of the gift card.
667 668 669 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 667 def brand @brand end |
#exp_month ⇒ Object (readonly)
The expiration month of the gift card.
669 670 671 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 669 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
The expiration year of the gift card.
671 672 673 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 671 def exp_year @exp_year end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies the gift card.
673 674 675 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 673 def fingerprint @fingerprint end |
#first6 ⇒ Object (readonly)
The first six digits of the gift card number.
675 676 677 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 675 def first6 @first6 end |
#last4 ⇒ Object (readonly)
The last four digits of the gift card number.
677 678 679 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 677 def last4 @last4 end |
Class Method Details
.field_remappings ⇒ Object
683 684 685 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 683 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
679 680 681 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 679 def self.inner_class_types @inner_class_types = {} end |