Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::InteracPresent
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::InteracPresent
- Defined in:
- lib/stripe/resources/shared_payment/granted_token.rb
Defined Under Namespace
Classes: Networks
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#brand ⇒ Object
readonly
Card brand.
-
#cardholder_name ⇒ Object
readonly
The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country of the card.
-
#description ⇒ Object
readonly
A high-level description of the type of cards issued in this range.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card’s expiration year.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular card number.
-
#funding ⇒ Object
readonly
Card funding type.
-
#iin ⇒ Object
readonly
Issuer identification number of the card.
-
#issuer ⇒ Object
readonly
The name of the card’s issuing bank.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#networks ⇒ Object
readonly
Contains information about card networks that can be used to process the payment.
-
#preferred_locales ⇒ Object
readonly
The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card.
-
#read_method ⇒ Object
readonly
How card details were read in this transaction.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#brand ⇒ Object (readonly)
Card brand. Can be ‘interac`, `mastercard` or `visa`.
745 746 747 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 745 def brand @brand end |
#cardholder_name ⇒ Object (readonly)
The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format. May include alphanumeric characters, special characters and first/last name separator (‘/`). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.
747 748 749 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 747 def cardholder_name @cardholder_name end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.
749 750 751 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 749 def country @country end |
#description ⇒ Object (readonly)
A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)
751 752 753 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 751 def description @description end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card’s expiration month.
753 754 755 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 753 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card’s expiration year.
755 756 757 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 755 def exp_year @exp_year end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.
*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*
759 760 761 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 759 def fingerprint @fingerprint end |
#funding ⇒ Object (readonly)
Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.
761 762 763 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 761 def funding @funding end |
#iin ⇒ Object (readonly)
Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)
763 764 765 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 763 def iin @iin end |
#issuer ⇒ Object (readonly)
The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)
765 766 767 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 765 def issuer @issuer end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
767 768 769 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 767 def last4 @last4 end |
#networks ⇒ Object (readonly)
Contains information about card networks that can be used to process the payment.
769 770 771 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 769 def networks @networks end |
#preferred_locales ⇒ Object (readonly)
The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card. Referenced from EMV tag 5F2D, data encoded on the card’s chip.
771 772 773 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 771 def preferred_locales @preferred_locales end |
#read_method ⇒ Object (readonly)
How card details were read in this transaction.
773 774 775 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 773 def read_method @read_method end |
Class Method Details
.field_remappings ⇒ Object
779 780 781 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 779 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
775 776 777 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 775 def self.inner_class_types @inner_class_types = { networks: Networks } end |