Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::NzBankAccount
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::NzBankAccount
- Defined in:
- lib/stripe/resources/shared_payment/granted_token.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
readonly
The name on the bank account.
-
#bank_code ⇒ Object
readonly
The numeric code for the bank account’s bank.
-
#bank_name ⇒ Object
readonly
The name of the bank.
-
#branch_code ⇒ Object
readonly
The numeric code for the bank account’s bank branch.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#suffix ⇒ Object
readonly
The suffix of the bank account number.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_name ⇒ Object (readonly)
The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
943 944 945 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 943 def account_holder_name @account_holder_name end |
#bank_code ⇒ Object (readonly)
The numeric code for the bank account’s bank.
945 946 947 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 945 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
The name of the bank.
947 948 949 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 947 def bank_name @bank_name end |
#branch_code ⇒ Object (readonly)
The numeric code for the bank account’s bank branch.
949 950 951 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 949 def branch_code @branch_code end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
951 952 953 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 951 def last4 @last4 end |
#suffix ⇒ Object (readonly)
The suffix of the bank account number.
953 954 955 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 953 def suffix @suffix end |
Class Method Details
.field_remappings ⇒ Object
959 960 961 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 959 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
955 956 957 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 955 def self.inner_class_types @inner_class_types = {} end |