Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::SepaDebit

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/shared_payment/granted_token.rb

Defined Under Namespace

Classes: GeneratedFrom

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1159
1160
1161
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1159

def bank_code
  @bank_code
end

#branch_codeObject (readonly)

Branch code of bank associated with the bank account.



1161
1162
1163
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1161

def branch_code
  @branch_code
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1163
1164
1165
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1163

def country
  @country
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1165
1166
1167
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1165

def fingerprint
  @fingerprint
end

#generated_fromObject (readonly)

Information about the object that generated this PaymentMethod.



1167
1168
1169
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1167

def generated_from
  @generated_from
end

#last4Object (readonly)

Last four characters of the IBAN.



1169
1170
1171
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1169

def last4
  @last4
end

Class Method Details

.field_remappingsObject



1175
1176
1177
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1175

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1171
1172
1173
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1171

def self.inner_class_types
  @inner_class_types = { generated_from: GeneratedFrom }
end