Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::SepaDebit

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/shared_payment/granted_token.rb

Defined Under Namespace

Classes: GeneratedFrom

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1164
1165
1166
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1164

def bank_code
  @bank_code
end

#branch_codeObject (readonly)

Branch code of bank associated with the bank account.



1166
1167
1168
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1166

def branch_code
  @branch_code
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1168
1169
1170
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1168

def country
  @country
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1170
1171
1172
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1170

def fingerprint
  @fingerprint
end

#generated_fromObject (readonly)

Information about the object that generated this PaymentMethod.



1172
1173
1174
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1172

def generated_from
  @generated_from
end

#last4Object (readonly)

Last four characters of the IBAN.



1174
1175
1176
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1174

def last4
  @last4
end

Class Method Details

.field_remappingsObject



1180
1181
1182
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1180

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1176
1177
1178
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1176

def self.inner_class_types
  @inner_class_types = { generated_from: GeneratedFrom }
end