Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::SepaDebit

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/shared_payment/granted_token.rb

Defined Under Namespace

Classes: GeneratedFrom

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1139
1140
1141
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1139

def bank_code
  @bank_code
end

#branch_codeObject (readonly)

Branch code of bank associated with the bank account.



1141
1142
1143
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1141

def branch_code
  @branch_code
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1143
1144
1145
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1143

def country
  @country
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1145
1146
1147
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1145

def fingerprint
  @fingerprint
end

#generated_fromObject (readonly)

Information about the object that generated this PaymentMethod.



1147
1148
1149
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1147

def generated_from
  @generated_from
end

#last4Object (readonly)

Last four characters of the IBAN.



1149
1150
1151
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1149

def last4
  @last4
end

Class Method Details

.field_remappingsObject



1155
1156
1157
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1155

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1151
1152
1153
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1151

def self.inner_class_types
  @inner_class_types = { generated_from: GeneratedFrom }
end