Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::SepaDebit
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::SepaDebit
- Defined in:
- lib/stripe/resources/shared_payment/granted_token.rb
Defined Under Namespace
Classes: GeneratedFrom
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_code ⇒ Object
readonly
Bank code of bank associated with the bank account.
-
#branch_code ⇒ Object
readonly
Branch code of bank associated with the bank account.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country the bank account is located in.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular bank account.
-
#generated_from ⇒ Object
readonly
Information about the object that generated this PaymentMethod.
-
#last4 ⇒ Object
readonly
Last four characters of the IBAN.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_code ⇒ Object (readonly)
Bank code of bank associated with the bank account.
1139 1140 1141 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1139 def bank_code @bank_code end |
#branch_code ⇒ Object (readonly)
Branch code of bank associated with the bank account.
1141 1142 1143 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1141 def branch_code @branch_code end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country the bank account is located in.
1143 1144 1145 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1143 def country @country end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
1145 1146 1147 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1145 def fingerprint @fingerprint end |
#generated_from ⇒ Object (readonly)
Information about the object that generated this PaymentMethod.
1147 1148 1149 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1147 def generated_from @generated_from end |
#last4 ⇒ Object (readonly)
Last four characters of the IBAN.
1149 1150 1151 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1149 def last4 @last4 end |
Class Method Details
.field_remappings ⇒ Object
1155 1156 1157 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1155 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1151 1152 1153 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1151 def self.inner_class_types @inner_class_types = { generated_from: GeneratedFrom } end |