Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::UsBankAccount
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::UsBankAccount
- Defined in:
- lib/stripe/resources/shared_payment/granted_token.rb
Defined Under Namespace
Classes: Networks, StatusDetails
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
readonly
Account holder type: individual or company.
-
#account_number ⇒ Object
readonly
Account number of the bank account.
-
#account_type ⇒ Object
readonly
Account type: checkings or savings.
-
#bank_name ⇒ Object
readonly
The name of the bank.
-
#financial_connections_account ⇒ Object
readonly
The ID of the Financial Connections Account used to create the payment method.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular bank account.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#networks ⇒ Object
readonly
Contains information about US bank account networks that can be used.
-
#routing_number ⇒ Object
readonly
Routing number of the bank account.
-
#status_details ⇒ Object
readonly
Contains information about the future reusability of this PaymentMethod.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_type ⇒ Object (readonly)
Account holder type: individual or company.
1327 1328 1329 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1327 def account_holder_type @account_holder_type end |
#account_number ⇒ Object (readonly)
Account number of the bank account.
1329 1330 1331 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1329 def account_number @account_number end |
#account_type ⇒ Object (readonly)
Account type: checkings or savings. Defaults to checking if omitted.
1331 1332 1333 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1331 def account_type @account_type end |
#bank_name ⇒ Object (readonly)
The name of the bank.
1333 1334 1335 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1333 def bank_name @bank_name end |
#financial_connections_account ⇒ Object (readonly)
The ID of the Financial Connections Account used to create the payment method.
1335 1336 1337 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1335 def financial_connections_account @financial_connections_account end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
1337 1338 1339 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1337 def fingerprint @fingerprint end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
1339 1340 1341 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1339 def last4 @last4 end |
#networks ⇒ Object (readonly)
Contains information about US bank account networks that can be used.
1341 1342 1343 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1341 def networks @networks end |
#routing_number ⇒ Object (readonly)
Routing number of the bank account.
1343 1344 1345 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1343 def routing_number @routing_number end |
#status_details ⇒ Object (readonly)
Contains information about the future reusability of this PaymentMethod.
1345 1346 1347 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1345 def status_details @status_details end |
Class Method Details
.field_remappings ⇒ Object
1351 1352 1353 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1351 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1347 1348 1349 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1347 def self.inner_class_types @inner_class_types = { networks: Networks, status_details: StatusDetails } end |