Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::UsBankAccount

Inherits:
Stripe::StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/shared_payment/granted_token.rb

Defined Under Namespace

Classes: Networks, StatusDetails

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Account holder type: individual or company.



1307
1308
1309
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1307

def 
  @account_holder_type
end

#account_numberObject (readonly)

Account number of the bank account.



1309
1310
1311
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1309

def 
  @account_number
end

#account_typeObject (readonly)

Account type: checkings or savings. Defaults to checking if omitted.



1311
1312
1313
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1311

def 
  @account_type
end

#bank_nameObject (readonly)

The name of the bank.



1313
1314
1315
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1313

def bank_name
  @bank_name
end

#financial_connections_accountObject (readonly)

The ID of the Financial Connections Account used to create the payment method.



1315
1316
1317
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1315

def 
  @financial_connections_account
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1317
1318
1319
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1317

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



1319
1320
1321
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1319

def last4
  @last4
end

#networksObject (readonly)

Contains information about US bank account networks that can be used.



1321
1322
1323
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1321

def networks
  @networks
end

#routing_numberObject (readonly)

Routing number of the bank account.



1323
1324
1325
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1323

def routing_number
  @routing_number
end

#status_detailsObject (readonly)

Contains information about the future reusability of this PaymentMethod.



1325
1326
1327
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1325

def status_details
  @status_details
end

Class Method Details

.field_remappingsObject



1331
1332
1333
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1331

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1327
1328
1329
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1327

def self.inner_class_types
  @inner_class_types = { networks: Networks, status_details: StatusDetails }
end