Class: Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::UsBankAccount
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SharedPayment::GrantedToken::PaymentMethodDetails::UsBankAccount
- Defined in:
- lib/stripe/resources/shared_payment/granted_token.rb
Defined Under Namespace
Classes: Networks, StatusDetails
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
readonly
Account holder type: individual or company.
-
#account_number ⇒ Object
readonly
Account number of the bank account.
-
#account_type ⇒ Object
readonly
Account type: checkings or savings.
-
#bank_name ⇒ Object
readonly
The name of the bank.
-
#financial_connections_account ⇒ Object
readonly
The ID of the Financial Connections Account used to create the payment method.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular bank account.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#networks ⇒ Object
readonly
Contains information about US bank account networks that can be used.
-
#routing_number ⇒ Object
readonly
Routing number of the bank account.
-
#status_details ⇒ Object
readonly
Contains information about the future reusability of this PaymentMethod.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_type ⇒ Object (readonly)
Account holder type: individual or company.
1282 1283 1284 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1282 def account_holder_type @account_holder_type end |
#account_number ⇒ Object (readonly)
Account number of the bank account.
1284 1285 1286 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1284 def account_number @account_number end |
#account_type ⇒ Object (readonly)
Account type: checkings or savings. Defaults to checking if omitted.
1286 1287 1288 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1286 def account_type @account_type end |
#bank_name ⇒ Object (readonly)
The name of the bank.
1288 1289 1290 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1288 def bank_name @bank_name end |
#financial_connections_account ⇒ Object (readonly)
The ID of the Financial Connections Account used to create the payment method.
1290 1291 1292 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1290 def financial_connections_account @financial_connections_account end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
1292 1293 1294 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1292 def fingerprint @fingerprint end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
1294 1295 1296 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1294 def last4 @last4 end |
#networks ⇒ Object (readonly)
Contains information about US bank account networks that can be used.
1296 1297 1298 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1296 def networks @networks end |
#routing_number ⇒ Object (readonly)
Routing number of the bank account.
1298 1299 1300 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1298 def routing_number @routing_number end |
#status_details ⇒ Object (readonly)
Contains information about the future reusability of this PaymentMethod.
1300 1301 1302 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1300 def status_details @status_details end |
Class Method Details
.field_remappings ⇒ Object
1306 1307 1308 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1306 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1302 1303 1304 |
# File 'lib/stripe/resources/shared_payment/granted_token.rb', line 1302 def self.inner_class_types @inner_class_types = { networks: Networks, status_details: StatusDetails } end |