Class: Stripe::SharedPayment::GrantedTokenCreateParams::UsageLimits
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SharedPayment::GrantedTokenCreateParams::UsageLimits
- Defined in:
- lib/stripe/params/shared_payment/granted_token_create_params.rb
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#expires_at ⇒ Object
Time at which this SharedPaymentToken expires and can no longer be used to confirm a PaymentIntent.
-
#max_amount ⇒ Object
Max amount that can be captured using this SharedPaymentToken.
-
#recurring_interval ⇒ Object
The recurring interval at which the shared payment token’s amount usage restrictions reset.
Instance Method Summary collapse
-
#initialize(currency: nil, expires_at: nil, max_amount: nil, recurring_interval: nil) ⇒ UsageLimits
constructor
A new instance of UsageLimits.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, expires_at: nil, max_amount: nil, recurring_interval: nil) ⇒ UsageLimits
Returns a new instance of UsageLimits.
17 18 19 20 21 22 |
# File 'lib/stripe/params/shared_payment/granted_token_create_params.rb', line 17 def initialize(currency: nil, expires_at: nil, max_amount: nil, recurring_interval: nil) @currency = currency @expires_at = expires_at @max_amount = max_amount @recurring_interval = recurring_interval end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
9 10 11 |
# File 'lib/stripe/params/shared_payment/granted_token_create_params.rb', line 9 def currency @currency end |
#expires_at ⇒ Object
Time at which this SharedPaymentToken expires and can no longer be used to confirm a PaymentIntent.
11 12 13 |
# File 'lib/stripe/params/shared_payment/granted_token_create_params.rb', line 11 def expires_at @expires_at end |
#max_amount ⇒ Object
Max amount that can be captured using this SharedPaymentToken
13 14 15 |
# File 'lib/stripe/params/shared_payment/granted_token_create_params.rb', line 13 def max_amount @max_amount end |
#recurring_interval ⇒ Object
The recurring interval at which the shared payment token’s amount usage restrictions reset.
15 16 17 |
# File 'lib/stripe/params/shared_payment/granted_token_create_params.rb', line 15 def recurring_interval @recurring_interval end |