Class: Stripe::SharedPayment::IssuedToken
- Inherits:
-
APIResource
- Object
- Stripe::StripeObject
- APIResource
- Stripe::SharedPayment::IssuedToken
- Defined in:
- lib/stripe/resources/shared_payment/issued_token.rb
Overview
A SharedPaymentIssuedToken is a limited-use reference to a PaymentMethod that can be created with a secret key. When shared with another Stripe account (Seller), it enables that account to either process a payment on Stripe against a PaymentMethod that your Stripe account owns, or to forward a usable credential created against the originalPaymentMethod to then process the payment off-Stripe.
Defined Under Namespace
Classes: NextAction, RiskDetails, SellerDetails, UsageDetails, UsageLimits
Constant Summary collapse
- OBJECT_NAME =
"shared_payment.issued_token"
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#customer ⇒ Object
readonly
ID of an existing Customer.
-
#deactivated_at ⇒ Object
readonly
Time at which this SharedPaymentIssuedToken was deactivated.
-
#deactivated_reason ⇒ Object
readonly
The reason why the SharedPaymentIssuedToken has been deactivated.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#next_action ⇒ Object
readonly
If present, describes the action required to make this ‘SharedPaymentIssuedToken` usable for payments.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#payment_method ⇒ Object
readonly
ID of an existing PaymentMethod.
-
#return_url ⇒ Object
readonly
If the customer does not exit their browser while authenticating, they will be redirected to this specified URL after completion.
-
#risk_details ⇒ Object
readonly
Risk details of the SharedPaymentIssuedToken.
-
#seller_details ⇒ Object
readonly
Seller details of the SharedPaymentIssuedToken, including network_id and external_id.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to save the PaymentMethod of this SharedPaymentToken to a customer later.
-
#shared_metadata ⇒ Object
readonly
Metadata about the SharedPaymentIssuedToken.
-
#status ⇒ Object
readonly
Status of this SharedPaymentIssuedToken, one of ‘active`, `requires_action`, or `deactivated`.
-
#usage_details ⇒ Object
readonly
Usage details of the SharedPaymentIssuedToken.
-
#usage_limits ⇒ Object
readonly
Usage limits of the SharedPaymentIssuedToken.
Attributes inherited from APIResource
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
214 215 216 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 214 def created @created end |
#customer ⇒ Object (readonly)
ID of an existing Customer.
216 217 218 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 216 def customer @customer end |
#deactivated_at ⇒ Object (readonly)
Time at which this SharedPaymentIssuedToken was deactivated.
218 219 220 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 218 def deactivated_at @deactivated_at end |
#deactivated_reason ⇒ Object (readonly)
The reason why the SharedPaymentIssuedToken has been deactivated.
220 221 222 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 220 def deactivated_reason @deactivated_reason end |
#id ⇒ Object (readonly)
Unique identifier for the object.
222 223 224 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 222 def id @id end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
224 225 226 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 224 def livemode @livemode end |
#next_action ⇒ Object (readonly)
If present, describes the action required to make this ‘SharedPaymentIssuedToken` usable for payments. Present when the token is in `requires_action` state.
226 227 228 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 226 def next_action @next_action end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
228 229 230 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 228 def object @object end |
#payment_method ⇒ Object (readonly)
ID of an existing PaymentMethod.
230 231 232 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 230 def payment_method @payment_method end |
#return_url ⇒ Object (readonly)
If the customer does not exit their browser while authenticating, they will be redirected to this specified URL after completion.
232 233 234 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 232 def return_url @return_url end |
#risk_details ⇒ Object (readonly)
Risk details of the SharedPaymentIssuedToken.
234 235 236 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 234 def risk_details @risk_details end |
#seller_details ⇒ Object (readonly)
Seller details of the SharedPaymentIssuedToken, including network_id and external_id.
236 237 238 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 236 def seller_details @seller_details end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to save the PaymentMethod of this SharedPaymentToken to a customer later.
238 239 240 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 238 def setup_future_usage @setup_future_usage end |
#shared_metadata ⇒ Object (readonly)
Metadata about the SharedPaymentIssuedToken.
240 241 242 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 240 def @shared_metadata end |
#status ⇒ Object (readonly)
Status of this SharedPaymentIssuedToken, one of ‘active`, `requires_action`, or `deactivated`.
242 243 244 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 242 def status @status end |
#usage_details ⇒ Object (readonly)
Usage details of the SharedPaymentIssuedToken
244 245 246 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 244 def usage_details @usage_details end |
#usage_limits ⇒ Object (readonly)
Usage limits of the SharedPaymentIssuedToken.
246 247 248 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 246 def usage_limits @usage_limits end |
Class Method Details
.field_remappings ⇒ Object
258 259 260 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 258 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
248 249 250 251 252 253 254 255 256 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 248 def self.inner_class_types @inner_class_types = { next_action: NextAction, risk_details: RiskDetails, seller_details: SellerDetails, usage_details: UsageDetails, usage_limits: UsageLimits, } end |
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 9 def self.object_name "shared_payment.issued_token" end |