Class: Stripe::SharedPayment::IssuedToken
- Inherits:
-
APIResource
- Object
- Stripe::StripeObject
- APIResource
- Stripe::SharedPayment::IssuedToken
- Defined in:
- lib/stripe/resources/shared_payment/issued_token.rb
Overview
A SharedPaymentIssuedToken is a limited-use reference to a PaymentMethod that can be created with a secret key. When shared with another Stripe account (Seller), it enables that account to either process a payment on Stripe against a PaymentMethod that your Stripe account owns, or to forward a usable credential created against the originalPaymentMethod to then process the payment off-Stripe.
Defined Under Namespace
Classes: RiskDetails, SellerDetails, UsageDetails, UsageLimits
Constant Summary collapse
- OBJECT_NAME =
"shared_payment.issued_token"
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#customer ⇒ Object
readonly
ID of an existing Customer.
-
#deactivated_at ⇒ Object
readonly
Time at which this SharedPaymentIssuedToken was deactivated.
-
#deactivated_reason ⇒ Object
readonly
The reason why the SharedPaymentIssuedToken has been deactivated.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#payment_method ⇒ Object
readonly
ID of an existing PaymentMethod.
-
#return_url ⇒ Object
readonly
If the customer does not exit their browser while authenticating, they will be redirected to this specified URL after completion.
-
#risk_details ⇒ Object
readonly
Risk details of the SharedPaymentIssuedToken.
-
#seller_details ⇒ Object
readonly
Seller details of the SharedPaymentIssuedToken, including network_id and external_id.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to save the PaymentMethod of this SharedPaymentToken to a customer later.
-
#shared_metadata ⇒ Object
readonly
Metadata about the SharedPaymentIssuedToken.
-
#usage_details ⇒ Object
readonly
Usage details of the SharedPaymentIssuedToken.
-
#usage_limits ⇒ Object
readonly
Usage limits of the SharedPaymentIssuedToken.
Attributes inherited from APIResource
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
189 190 191 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 189 def created @created end |
#customer ⇒ Object (readonly)
ID of an existing Customer.
191 192 193 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 191 def customer @customer end |
#deactivated_at ⇒ Object (readonly)
Time at which this SharedPaymentIssuedToken was deactivated.
193 194 195 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 193 def deactivated_at @deactivated_at end |
#deactivated_reason ⇒ Object (readonly)
The reason why the SharedPaymentIssuedToken has been deactivated.
195 196 197 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 195 def deactivated_reason @deactivated_reason end |
#id ⇒ Object (readonly)
Unique identifier for the object.
197 198 199 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 197 def id @id end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
199 200 201 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 199 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
201 202 203 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 201 def object @object end |
#payment_method ⇒ Object (readonly)
ID of an existing PaymentMethod.
203 204 205 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 203 def payment_method @payment_method end |
#return_url ⇒ Object (readonly)
If the customer does not exit their browser while authenticating, they will be redirected to this specified URL after completion.
205 206 207 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 205 def return_url @return_url end |
#risk_details ⇒ Object (readonly)
Risk details of the SharedPaymentIssuedToken.
207 208 209 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 207 def risk_details @risk_details end |
#seller_details ⇒ Object (readonly)
Seller details of the SharedPaymentIssuedToken, including network_id and external_id.
209 210 211 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 209 def seller_details @seller_details end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to save the PaymentMethod of this SharedPaymentToken to a customer later.
211 212 213 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 211 def setup_future_usage @setup_future_usage end |
#shared_metadata ⇒ Object (readonly)
Metadata about the SharedPaymentIssuedToken.
213 214 215 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 213 def @shared_metadata end |
#usage_details ⇒ Object (readonly)
Usage details of the SharedPaymentIssuedToken
215 216 217 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 215 def usage_details @usage_details end |
#usage_limits ⇒ Object (readonly)
Usage limits of the SharedPaymentIssuedToken.
217 218 219 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 217 def usage_limits @usage_limits end |
Class Method Details
.field_remappings ⇒ Object
228 229 230 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 228 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
219 220 221 222 223 224 225 226 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 219 def self.inner_class_types @inner_class_types = { risk_details: RiskDetails, seller_details: SellerDetails, usage_details: UsageDetails, usage_limits: UsageLimits, } end |
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/shared_payment/issued_token.rb', line 9 def self.object_name "shared_payment.issued_token" end |