Class: Stripe::SharedPayment::IssuedTokenCreateParams::SellerDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SharedPayment::IssuedTokenCreateParams::SellerDetails
- Defined in:
- lib/stripe/params/shared_payment/issued_token_create_params.rb
Instance Attribute Summary collapse
-
#external_id ⇒ Object
A unique id within a network that identifies a logical seller, usually this would be the unique merchant id.
-
#network_business_profile ⇒ Object
A string that identifies the network that this SharedToken is being created for.
Instance Method Summary collapse
-
#initialize(external_id: nil, network_business_profile: nil) ⇒ SellerDetails
constructor
A new instance of SellerDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(external_id: nil, network_business_profile: nil) ⇒ SellerDetails
Returns a new instance of SellerDetails.
13 14 15 16 |
# File 'lib/stripe/params/shared_payment/issued_token_create_params.rb', line 13 def initialize(external_id: nil, network_business_profile: nil) @external_id = external_id @network_business_profile = network_business_profile end |
Instance Attribute Details
#external_id ⇒ Object
A unique id within a network that identifies a logical seller, usually this would be the unique merchant id.
9 10 11 |
# File 'lib/stripe/params/shared_payment/issued_token_create_params.rb', line 9 def external_id @external_id end |
#network_business_profile ⇒ Object
A string that identifies the network that this SharedToken is being created for.
11 12 13 |
# File 'lib/stripe/params/shared_payment/issued_token_create_params.rb', line 11 def network_business_profile @network_business_profile end |