Class: Stripe::ShippingRate::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/shipping_rate.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, created: nil, currency: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/stripe/resources/shipping_rate.rb', line 100

def initialize(
  active: nil,
  created: nil,
  currency: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil
)
  @active = active
  @created = created
  @currency = currency
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#activeObject

Only return shipping rates that are active or inactive.



80
81
82
# File 'lib/stripe/resources/shipping_rate.rb', line 80

def active
  @active
end

#createdObject

A filter on the list, based on the object ‘created` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.



83
84
85
# File 'lib/stripe/resources/shipping_rate.rb', line 83

def created
  @created
end

#currencyObject

Only return shipping rates for the given currency.



86
87
88
# File 'lib/stripe/resources/shipping_rate.rb', line 86

def currency
  @currency
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



89
90
91
# File 'lib/stripe/resources/shipping_rate.rb', line 89

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



92
93
94
# File 'lib/stripe/resources/shipping_rate.rb', line 92

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



95
96
97
# File 'lib/stripe/resources/shipping_rate.rb', line 95

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



98
99
100
# File 'lib/stripe/resources/shipping_rate.rb', line 98

def starting_after
  @starting_after
end