Class: Stripe::ShippingRate::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/shipping_rate.rb

Defined Under Namespace

Classes: FixedAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, expand: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



234
235
236
237
238
239
240
# File 'lib/stripe/resources/shipping_rate.rb', line 234

def initialize(active: nil, expand: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil)
  @active = active
  @expand = expand
  @fixed_amount = fixed_amount
  @metadata = 
  @tax_behavior = tax_behavior
end

Instance Attribute Details

#activeObject

Whether the shipping rate can be used for new purchases. Defaults to ‘true`.



224
225
226
# File 'lib/stripe/resources/shipping_rate.rb', line 224

def active
  @active
end

#expandObject

Specifies which fields in the response should be expanded.



226
227
228
# File 'lib/stripe/resources/shipping_rate.rb', line 226

def expand
  @expand
end

#fixed_amountObject

Describes a fixed amount to charge for shipping. Must be present if type is ‘fixed_amount`.



228
229
230
# File 'lib/stripe/resources/shipping_rate.rb', line 228

def fixed_amount
  @fixed_amount
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



230
231
232
# File 'lib/stripe/resources/shipping_rate.rb', line 230

def 
  @metadata
end

#tax_behaviorObject

Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.



232
233
234
# File 'lib/stripe/resources/shipping_rate.rb', line 232

def tax_behavior
  @tax_behavior
end