Class: Stripe::ShippingRate::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ShippingRate::UpdateParams
- Defined in:
- lib/stripe/resources/shipping_rate.rb
Defined Under Namespace
Classes: FixedAmount
Instance Attribute Summary collapse
-
#active ⇒ Object
Whether the shipping rate can be used for new purchases.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fixed_amount ⇒ Object
Describes a fixed amount to charge for shipping.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes.
Instance Method Summary collapse
-
#initialize(active: nil, expand: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, expand: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
243 244 245 246 247 248 249 |
# File 'lib/stripe/resources/shipping_rate.rb', line 243 def initialize(active: nil, expand: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil) @active = active @expand = @fixed_amount = fixed_amount @metadata = @tax_behavior = tax_behavior end |
Instance Attribute Details
#active ⇒ Object
Whether the shipping rate can be used for new purchases. Defaults to ‘true`.
233 234 235 |
# File 'lib/stripe/resources/shipping_rate.rb', line 233 def active @active end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
235 236 237 |
# File 'lib/stripe/resources/shipping_rate.rb', line 235 def @expand end |
#fixed_amount ⇒ Object
Describes a fixed amount to charge for shipping. Must be present if type is ‘fixed_amount`.
237 238 239 |
# File 'lib/stripe/resources/shipping_rate.rb', line 237 def fixed_amount @fixed_amount end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
239 240 241 |
# File 'lib/stripe/resources/shipping_rate.rb', line 239 def @metadata end |
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.
241 242 243 |
# File 'lib/stripe/resources/shipping_rate.rb', line 241 def tax_behavior @tax_behavior end |