Class: Stripe::ShippingRate::UpdateParams::FixedAmount::CurrencyOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ShippingRate::UpdateParams::FixedAmount::CurrencyOptions
- Defined in:
- lib/stripe/resources/shipping_rate.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
-
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes.
Instance Method Summary collapse
-
#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions
constructor
A new instance of CurrencyOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions
Returns a new instance of CurrencyOptions.
249 250 251 252 |
# File 'lib/stripe/resources/shipping_rate.rb', line 249 def initialize(amount: nil, tax_behavior: nil) @amount = amount @tax_behavior = tax_behavior end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
244 245 246 |
# File 'lib/stripe/resources/shipping_rate.rb', line 244 def amount @amount end |
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.
247 248 249 |
# File 'lib/stripe/resources/shipping_rate.rb', line 247 def tax_behavior @tax_behavior end |