Class: Stripe::ShippingRateService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::ShippingRateService
- Defined in:
- lib/stripe/services/shipping_rate_service.rb
Defined Under Namespace
Classes: CreateParams, ListParams, RetrieveParams, UpdateParams
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Creates a new shipping rate object.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of your shipping rates.
-
#retrieve(shipping_rate_token, params = {}, opts = {}) ⇒ Object
Returns the shipping rate object with the given ID.
-
#update(shipping_rate_token, params = {}, opts = {}) ⇒ Object
Updates an existing shipping rate object.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Creates a new shipping rate object.
207 208 209 210 211 212 213 214 215 |
# File 'lib/stripe/services/shipping_rate_service.rb', line 207 def create(params = {}, opts = {}) request( method: :post, path: "/v1/shipping_rates", params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of your shipping rates.
218 219 220 221 222 223 224 225 226 |
# File 'lib/stripe/services/shipping_rate_service.rb', line 218 def list(params = {}, opts = {}) request( method: :get, path: "/v1/shipping_rates", params: params, opts: opts, base_address: :api ) end |
#retrieve(shipping_rate_token, params = {}, opts = {}) ⇒ Object
Returns the shipping rate object with the given ID.
229 230 231 232 233 234 235 236 237 |
# File 'lib/stripe/services/shipping_rate_service.rb', line 229 def retrieve(shipping_rate_token, params = {}, opts = {}) request( method: :get, path: format("/v1/shipping_rates/%<shipping_rate_token>s", { shipping_rate_token: CGI.escape(shipping_rate_token) }), params: params, opts: opts, base_address: :api ) end |
#update(shipping_rate_token, params = {}, opts = {}) ⇒ Object
Updates an existing shipping rate object.
240 241 242 243 244 245 246 247 248 |
# File 'lib/stripe/services/shipping_rate_service.rb', line 240 def update(shipping_rate_token, params = {}, opts = {}) request( method: :post, path: format("/v1/shipping_rates/%<shipping_rate_token>s", { shipping_rate_token: CGI.escape(shipping_rate_token) }), params: params, opts: opts, base_address: :api ) end |