Class: Stripe::ShippingRateService::CreateParams::FixedAmount::CurrencyOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ShippingRateService::CreateParams::FixedAmount::CurrencyOptions
- Defined in:
- lib/stripe/services/shipping_rate_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
-
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes.
Instance Method Summary collapse
-
#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions
constructor
A new instance of CurrencyOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions
Returns a new instance of CurrencyOptions.
114 115 116 117 |
# File 'lib/stripe/services/shipping_rate_service.rb', line 114 def initialize(amount: nil, tax_behavior: nil) @amount = amount @tax_behavior = tax_behavior end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
109 110 111 |
# File 'lib/stripe/services/shipping_rate_service.rb', line 109 def amount @amount end |
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.
112 113 114 |
# File 'lib/stripe/services/shipping_rate_service.rb', line 112 def tax_behavior @tax_behavior end |