Class: Stripe::Source::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/source.rb

Defined Under Namespace

Classes: Mandate, Owner, Receiver, Redirect, SourceOrder

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, customer: nil, expand: nil, flow: nil, mandate: nil, metadata: nil, original_source: nil, owner: nil, receiver: nil, redirect: nil, source_order: nil, statement_descriptor: nil, token: nil, type: nil, usage: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
# File 'lib/stripe/resources/source.rb', line 1137

def initialize(
  amount: nil,
  currency: nil,
  customer: nil,
  expand: nil,
  flow: nil,
  mandate: nil,
  metadata: nil,
  original_source: nil,
  owner: nil,
  receiver: nil,
  redirect: nil,
  source_order: nil,
  statement_descriptor: nil,
  token: nil,
  type: nil,
  usage: nil
)
  @amount = amount
  @currency = currency
  @customer = customer
  @expand = expand
  @flow = flow
  @mandate = mandate
  @metadata = 
  @original_source = original_source
  @owner = owner
  @receiver = receiver
  @redirect = redirect
  @source_order = source_order
  @statement_descriptor = statement_descriptor
  @token = token
  @type = type
  @usage = usage
end

Instance Attribute Details

#amountObject

Amount associated with the source. This is the amount for which the source will be chargeable once ready. Required for ‘single_use` sources. Not supported for `receiver` type sources, where charge amount may not be specified until funds land.



1105
1106
1107
# File 'lib/stripe/resources/source.rb', line 1105

def amount
  @amount
end

#currencyObject

Three-letter [ISO code for the currency](stripe.com/docs/currencies) associated with the source. This is the currency for which the source will be chargeable once ready.



1107
1108
1109
# File 'lib/stripe/resources/source.rb', line 1107

def currency
  @currency
end

#customerObject

The ‘Customer` to whom the original source is attached to. Must be set when the original source is not a `Source` (e.g., `Card`).



1109
1110
1111
# File 'lib/stripe/resources/source.rb', line 1109

def customer
  @customer
end

#expandObject

Specifies which fields in the response should be expanded.



1111
1112
1113
# File 'lib/stripe/resources/source.rb', line 1111

def expand
  @expand
end

#flowObject

The authentication ‘flow` of the source to create. `flow` is one of `redirect`, `receiver`, `code_verification`, `none`. It is generally inferred unless a type supports multiple flows.



1113
1114
1115
# File 'lib/stripe/resources/source.rb', line 1113

def flow
  @flow
end

#mandateObject

Information about a mandate possibility attached to a source object (generally for bank debits) as well as its acceptance status.



1115
1116
1117
# File 'lib/stripe/resources/source.rb', line 1115

def mandate
  @mandate
end

#metadataObject

Attribute for param field metadata



1117
1118
1119
# File 'lib/stripe/resources/source.rb', line 1117

def 
  @metadata
end

#original_sourceObject

The source to share.



1119
1120
1121
# File 'lib/stripe/resources/source.rb', line 1119

def original_source
  @original_source
end

#ownerObject

Information about the owner of the payment instrument that may be used or required by particular source types.



1121
1122
1123
# File 'lib/stripe/resources/source.rb', line 1121

def owner
  @owner
end

#receiverObject

Optional parameters for the receiver flow. Can be set only if the source is a receiver (‘flow` is `receiver`).



1123
1124
1125
# File 'lib/stripe/resources/source.rb', line 1123

def receiver
  @receiver
end

#redirectObject

Parameters required for the redirect flow. Required if the source is authenticated by a redirect (‘flow` is `redirect`).



1125
1126
1127
# File 'lib/stripe/resources/source.rb', line 1125

def redirect
  @redirect
end

#source_orderObject

Information about the items and shipping associated with the source. Required for transactional credit (for example Klarna) sources before you can charge it.



1127
1128
1129
# File 'lib/stripe/resources/source.rb', line 1127

def source_order
  @source_order
end

#statement_descriptorObject

An arbitrary string to be displayed on your customer’s statement. As an example, if your website is ‘RunClub` and the item you’re charging for is a race ticket, you may want to specify a ‘statement_descriptor` of `RunClub 5K race ticket.` While many payment types will display this information, some may not display it at all.



1129
1130
1131
# File 'lib/stripe/resources/source.rb', line 1129

def statement_descriptor
  @statement_descriptor
end

#tokenObject

An optional token used to create the source. When passed, token properties will override source parameters.



1131
1132
1133
# File 'lib/stripe/resources/source.rb', line 1131

def token
  @token
end

#typeObject

The ‘type` of the source to create. Required unless `customer` and `original_source` are specified (see the [Cloning card Sources](stripe.com/docs/sources/connect#cloning-card-sources) guide)



1133
1134
1135
# File 'lib/stripe/resources/source.rb', line 1133

def type
  @type
end

#usageObject

Attribute for param field usage



1135
1136
1137
# File 'lib/stripe/resources/source.rb', line 1135

def usage
  @usage
end