Class: Stripe::Source::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/source.rb

Defined Under Namespace

Classes: Mandate, Owner, Receiver, Redirect, SourceOrder

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, customer: nil, expand: nil, flow: nil, mandate: nil, metadata: nil, original_source: nil, owner: nil, receiver: nil, redirect: nil, source_order: nil, statement_descriptor: nil, token: nil, type: nil, usage: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
# File 'lib/stripe/resources/source.rb', line 1429

def initialize(
  amount: nil,
  currency: nil,
  customer: nil,
  expand: nil,
  flow: nil,
  mandate: nil,
  metadata: nil,
  original_source: nil,
  owner: nil,
  receiver: nil,
  redirect: nil,
  source_order: nil,
  statement_descriptor: nil,
  token: nil,
  type: nil,
  usage: nil
)
  @amount = amount
  @currency = currency
  @customer = customer
  @expand = expand
  @flow = flow
  @mandate = mandate
  @metadata = 
  @original_source = original_source
  @owner = owner
  @receiver = receiver
  @redirect = redirect
  @source_order = source_order
  @statement_descriptor = statement_descriptor
  @token = token
  @type = type
  @usage = usage
end

Instance Attribute Details

#amountObject

Amount associated with the source. This is the amount for which the source will be chargeable once ready. Required for ‘single_use` sources. Not supported for `receiver` type sources, where charge amount may not be specified until funds land.



1382
1383
1384
# File 'lib/stripe/resources/source.rb', line 1382

def amount
  @amount
end

#currencyObject

Three-letter [ISO code for the currency](stripe.com/docs/currencies) associated with the source. This is the currency for which the source will be chargeable once ready.



1385
1386
1387
# File 'lib/stripe/resources/source.rb', line 1385

def currency
  @currency
end

#customerObject

The ‘Customer` to whom the original source is attached to. Must be set when the original source is not a `Source` (e.g., `Card`).



1388
1389
1390
# File 'lib/stripe/resources/source.rb', line 1388

def customer
  @customer
end

#expandObject

Specifies which fields in the response should be expanded.



1391
1392
1393
# File 'lib/stripe/resources/source.rb', line 1391

def expand
  @expand
end

#flowObject

The authentication ‘flow` of the source to create. `flow` is one of `redirect`, `receiver`, `code_verification`, `none`. It is generally inferred unless a type supports multiple flows.



1394
1395
1396
# File 'lib/stripe/resources/source.rb', line 1394

def flow
  @flow
end

#mandateObject

Information about a mandate possibility attached to a source object (generally for bank debits) as well as its acceptance status.



1397
1398
1399
# File 'lib/stripe/resources/source.rb', line 1397

def mandate
  @mandate
end

#metadataObject

Attribute for param field metadata



1400
1401
1402
# File 'lib/stripe/resources/source.rb', line 1400

def 
  @metadata
end

#original_sourceObject

The source to share.



1403
1404
1405
# File 'lib/stripe/resources/source.rb', line 1403

def original_source
  @original_source
end

#ownerObject

Information about the owner of the payment instrument that may be used or required by particular source types.



1406
1407
1408
# File 'lib/stripe/resources/source.rb', line 1406

def owner
  @owner
end

#receiverObject

Optional parameters for the receiver flow. Can be set only if the source is a receiver (‘flow` is `receiver`).



1409
1410
1411
# File 'lib/stripe/resources/source.rb', line 1409

def receiver
  @receiver
end

#redirectObject

Parameters required for the redirect flow. Required if the source is authenticated by a redirect (‘flow` is `redirect`).



1412
1413
1414
# File 'lib/stripe/resources/source.rb', line 1412

def redirect
  @redirect
end

#source_orderObject

Information about the items and shipping associated with the source. Required for transactional credit (for example Klarna) sources before you can charge it.



1415
1416
1417
# File 'lib/stripe/resources/source.rb', line 1415

def source_order
  @source_order
end

#statement_descriptorObject

An arbitrary string to be displayed on your customer’s statement. As an example, if your website is ‘RunClub` and the item you’re charging for is a race ticket, you may want to specify a ‘statement_descriptor` of `RunClub 5K race ticket.` While many payment types will display this information, some may not display it at all.



1418
1419
1420
# File 'lib/stripe/resources/source.rb', line 1418

def statement_descriptor
  @statement_descriptor
end

#tokenObject

An optional token used to create the source. When passed, token properties will override source parameters.



1421
1422
1423
# File 'lib/stripe/resources/source.rb', line 1421

def token
  @token
end

#typeObject

The ‘type` of the source to create. Required unless `customer` and `original_source` are specified (see the [Cloning card Sources](stripe.com/docs/sources/connect#cloning-card-sources) guide)



1424
1425
1426
# File 'lib/stripe/resources/source.rb', line 1424

def type
  @type
end

#usageObject

Attribute for param field usage



1427
1428
1429
# File 'lib/stripe/resources/source.rb', line 1427

def usage
  @usage
end