Class: Stripe::Source::CreateParams::Mandate::Acceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/source.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, offline: nil, online: nil, status: nil, type: nil, user_agent: nil) ⇒ Acceptance

Returns a new instance of Acceptance.



1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
# File 'lib/stripe/resources/source.rb', line 1152

def initialize(
  date: nil,
  ip: nil,
  offline: nil,
  online: nil,
  status: nil,
  type: nil,
  user_agent: nil
)
  @date = date
  @ip = ip
  @offline = offline
  @online = online
  @status = status
  @type = type
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp (in seconds) when the mandate was accepted or refused by the customer.



1132
1133
1134
# File 'lib/stripe/resources/source.rb', line 1132

def date
  @date
end

#ipObject

The IP address from which the mandate was accepted or refused by the customer.



1135
1136
1137
# File 'lib/stripe/resources/source.rb', line 1135

def ip
  @ip
end

#offlineObject

The parameters required to store a mandate accepted offline. Should only be set if ‘mandate` is `offline`



1138
1139
1140
# File 'lib/stripe/resources/source.rb', line 1138

def offline
  @offline
end

#onlineObject

The parameters required to store a mandate accepted online. Should only be set if ‘mandate` is `online`



1141
1142
1143
# File 'lib/stripe/resources/source.rb', line 1141

def online
  @online
end

#statusObject

The status of the mandate acceptance. Either ‘accepted` (the mandate was accepted) or `refused` (the mandate was refused).



1144
1145
1146
# File 'lib/stripe/resources/source.rb', line 1144

def status
  @status
end

#typeObject

The type of acceptance information included with the mandate. Either ‘online` or `offline`



1147
1148
1149
# File 'lib/stripe/resources/source.rb', line 1147

def type
  @type
end

#user_agentObject

The user agent of the browser from which the mandate was accepted or refused by the customer.



1150
1151
1152
# File 'lib/stripe/resources/source.rb', line 1150

def user_agent
  @user_agent
end