Class: Stripe::Source::CreateParams::Mandate::Acceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Source::CreateParams::Mandate::Acceptance
- Defined in:
- lib/stripe/resources/source.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp (in seconds) when the mandate was accepted or refused by the customer.
-
#ip ⇒ Object
The IP address from which the mandate was accepted or refused by the customer.
-
#offline ⇒ Object
The parameters required to store a mandate accepted offline.
-
#online ⇒ Object
The parameters required to store a mandate accepted online.
-
#status ⇒ Object
The status of the mandate acceptance.
-
#type ⇒ Object
The type of acceptance information included with the mandate.
-
#user_agent ⇒ Object
The user agent of the browser from which the mandate was accepted or refused by the customer.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, offline: nil, online: nil, status: nil, type: nil, user_agent: nil) ⇒ Acceptance
constructor
A new instance of Acceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, offline: nil, online: nil, status: nil, type: nil, user_agent: nil) ⇒ Acceptance
Returns a new instance of Acceptance.
902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 |
# File 'lib/stripe/resources/source.rb', line 902 def initialize( date: nil, ip: nil, offline: nil, online: nil, status: nil, type: nil, user_agent: nil ) @date = date @ip = ip @offline = offline @online = online @status = status @type = type @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp (in seconds) when the mandate was accepted or refused by the customer.
888 889 890 |
# File 'lib/stripe/resources/source.rb', line 888 def date @date end |
#ip ⇒ Object
The IP address from which the mandate was accepted or refused by the customer.
890 891 892 |
# File 'lib/stripe/resources/source.rb', line 890 def ip @ip end |
#offline ⇒ Object
The parameters required to store a mandate accepted offline. Should only be set if ‘mandate` is `offline`
892 893 894 |
# File 'lib/stripe/resources/source.rb', line 892 def offline @offline end |
#online ⇒ Object
The parameters required to store a mandate accepted online. Should only be set if ‘mandate` is `online`
894 895 896 |
# File 'lib/stripe/resources/source.rb', line 894 def online @online end |
#status ⇒ Object
The status of the mandate acceptance. Either ‘accepted` (the mandate was accepted) or `refused` (the mandate was refused).
896 897 898 |
# File 'lib/stripe/resources/source.rb', line 896 def status @status end |
#type ⇒ Object
The type of acceptance information included with the mandate. Either ‘online` or `offline`
898 899 900 |
# File 'lib/stripe/resources/source.rb', line 898 def type @type end |
#user_agent ⇒ Object
The user agent of the browser from which the mandate was accepted or refused by the customer.
900 901 902 |
# File 'lib/stripe/resources/source.rb', line 900 def user_agent @user_agent end |