Class: Stripe::Source::CreateParams::Mandate::Acceptance::Online

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/source.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Online

Returns a new instance of Online.



881
882
883
884
885
# File 'lib/stripe/resources/source.rb', line 881

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp (in seconds) when the mandate was accepted or refused by the customer.



875
876
877
# File 'lib/stripe/resources/source.rb', line 875

def date
  @date
end

#ipObject

The IP address from which the mandate was accepted or refused by the customer.



877
878
879
# File 'lib/stripe/resources/source.rb', line 877

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the mandate was accepted or refused by the customer.



879
880
881
# File 'lib/stripe/resources/source.rb', line 879

def user_agent
  @user_agent
end