Class: Stripe::Source::CreateParams::Redirect

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/source.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(return_url: nil) ⇒ Redirect

Returns a new instance of Redirect.



1269
1270
1271
# File 'lib/stripe/resources/source.rb', line 1269

def initialize(return_url: nil)
  @return_url = return_url
end

Instance Attribute Details

#return_urlObject

The URL you provide to redirect the customer back to you after they authenticated their payment. It can use your application URI scheme in the context of a mobile application.



1267
1268
1269
# File 'lib/stripe/resources/source.rb', line 1267

def return_url
  @return_url
end