Class: Stripe::Source::Owner
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::Source::Owner
- Defined in:
- lib/stripe/resources/source.rb
Defined Under Namespace
Classes: Address, VerifiedAddress
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
Owner’s address.
-
#email ⇒ Object
readonly
Owner’s email address.
-
#name ⇒ Object
readonly
Owner’s full name.
-
#phone ⇒ Object
readonly
Owner’s phone number (including extension).
-
#verified_address ⇒ Object
readonly
Verified owner’s address.
-
#verified_email ⇒ Object
readonly
Verified owner’s email address.
-
#verified_name ⇒ Object
readonly
Verified owner’s full name.
-
#verified_phone ⇒ Object
readonly
Verified owner’s phone number (including extension).
Attributes inherited from Stripe::StripeObject
Method Summary
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
Owner’s address.
477 478 479 |
# File 'lib/stripe/resources/source.rb', line 477 def address @address end |
#email ⇒ Object (readonly)
Owner’s email address.
480 481 482 |
# File 'lib/stripe/resources/source.rb', line 480 def email @email end |
#name ⇒ Object (readonly)
Owner’s full name.
483 484 485 |
# File 'lib/stripe/resources/source.rb', line 483 def name @name end |
#phone ⇒ Object (readonly)
Owner’s phone number (including extension).
486 487 488 |
# File 'lib/stripe/resources/source.rb', line 486 def phone @phone end |
#verified_address ⇒ Object (readonly)
Verified owner’s address. Verified values are verified or provided by the payment method directly (and if supported) at the time of authorization or settlement. They cannot be set or mutated.
489 490 491 |
# File 'lib/stripe/resources/source.rb', line 489 def verified_address @verified_address end |
#verified_email ⇒ Object (readonly)
Verified owner’s email address. Verified values are verified or provided by the payment method directly (and if supported) at the time of authorization or settlement. They cannot be set or mutated.
492 493 494 |
# File 'lib/stripe/resources/source.rb', line 492 def verified_email @verified_email end |
#verified_name ⇒ Object (readonly)
Verified owner’s full name. Verified values are verified or provided by the payment method directly (and if supported) at the time of authorization or settlement. They cannot be set or mutated.
495 496 497 |
# File 'lib/stripe/resources/source.rb', line 495 def verified_name @verified_name end |
#verified_phone ⇒ Object (readonly)
Verified owner’s phone number (including extension). Verified values are verified or provided by the payment method directly (and if supported) at the time of authorization or settlement. They cannot be set or mutated.
498 499 500 |
# File 'lib/stripe/resources/source.rb', line 498 def verified_phone @verified_phone end |