Class: Stripe::Source::Receiver
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::Source::Receiver
- Defined in:
- lib/stripe/resources/source.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
The address of the receiver source.
-
#amount_charged ⇒ Object
readonly
The total amount that was moved to your balance.
-
#amount_received ⇒ Object
readonly
The total amount received by the receiver source.
-
#amount_returned ⇒ Object
readonly
The total amount that was returned to the customer.
-
#refund_attributes_method ⇒ Object
readonly
Type of refund attribute method, one of ‘email`, `manual`, or `none`.
-
#refund_attributes_status ⇒ Object
readonly
Type of refund attribute status, one of ‘missing`, `requested`, or `available`.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
The address of the receiver source. This is the value that should be communicated to the customer to send their funds to.
555 556 557 |
# File 'lib/stripe/resources/source.rb', line 555 def address @address end |
#amount_charged ⇒ Object (readonly)
The total amount that was moved to your balance. This is almost always equal to the amount charged. In rare cases when customers deposit excess funds and we are unable to refund those, those funds get moved to your balance and show up in amount_charged as well. The amount charged is expressed in the source’s currency.
557 558 559 |
# File 'lib/stripe/resources/source.rb', line 557 def amount_charged @amount_charged end |
#amount_received ⇒ Object (readonly)
The total amount received by the receiver source. ‘amount_received = amount_returned + amount_charged` should be true for consumed sources unless customers deposit excess funds. The amount received is expressed in the source’s currency.
559 560 561 |
# File 'lib/stripe/resources/source.rb', line 559 def amount_received @amount_received end |
#amount_returned ⇒ Object (readonly)
The total amount that was returned to the customer. The amount returned is expressed in the source’s currency.
561 562 563 |
# File 'lib/stripe/resources/source.rb', line 561 def amount_returned @amount_returned end |
#refund_attributes_method ⇒ Object (readonly)
Type of refund attribute method, one of ‘email`, `manual`, or `none`.
563 564 565 |
# File 'lib/stripe/resources/source.rb', line 563 def refund_attributes_method @refund_attributes_method end |
#refund_attributes_status ⇒ Object (readonly)
Type of refund attribute status, one of ‘missing`, `requested`, or `available`.
565 566 567 |
# File 'lib/stripe/resources/source.rb', line 565 def refund_attributes_status @refund_attributes_status end |
Class Method Details
.field_remappings ⇒ Object
571 572 573 |
# File 'lib/stripe/resources/source.rb', line 571 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
567 568 569 |
# File 'lib/stripe/resources/source.rb', line 567 def self.inner_class_types @inner_class_types = {} end |