Class: Stripe::Source::Receiver

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/source.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Method Summary

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

The address of the receiver source. This is the value that should be communicated to the customer to send their funds to.



403
404
405
# File 'lib/stripe/resources/source.rb', line 403

def address
  @address
end

#amount_chargedObject (readonly)

The total amount that was moved to your balance. This is almost always equal to the amount charged. In rare cases when customers deposit excess funds and we are unable to refund those, those funds get moved to your balance and show up in amount_charged as well. The amount charged is expressed in the source’s currency.



405
406
407
# File 'lib/stripe/resources/source.rb', line 405

def amount_charged
  @amount_charged
end

#amount_receivedObject (readonly)

The total amount received by the receiver source. ‘amount_received = amount_returned + amount_charged` should be true for consumed sources unless customers deposit excess funds. The amount received is expressed in the source’s currency.



407
408
409
# File 'lib/stripe/resources/source.rb', line 407

def amount_received
  @amount_received
end

#amount_returnedObject (readonly)

The total amount that was returned to the customer. The amount returned is expressed in the source’s currency.



409
410
411
# File 'lib/stripe/resources/source.rb', line 409

def amount_returned
  @amount_returned
end

#refund_attributes_methodObject (readonly)

Type of refund attribute method, one of ‘email`, `manual`, or `none`.



411
412
413
# File 'lib/stripe/resources/source.rb', line 411

def refund_attributes_method
  @refund_attributes_method
end

#refund_attributes_statusObject (readonly)

Type of refund attribute status, one of ‘missing`, `requested`, or `available`.



413
414
415
# File 'lib/stripe/resources/source.rb', line 413

def refund_attributes_status
  @refund_attributes_status
end