Class: Stripe::Source::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Source::RetrieveParams
- Defined in:
- lib/stripe/resources/source.rb
Instance Attribute Summary collapse
-
#client_secret ⇒ Object
The client secret of the source.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
600 601 602 603 |
# File 'lib/stripe/resources/source.rb', line 600 def initialize(client_secret: nil, expand: nil) @client_secret = client_secret @expand = end |
Instance Attribute Details
#client_secret ⇒ Object
The client secret of the source. Required if a publishable key is used to retrieve the source.
596 597 598 |
# File 'lib/stripe/resources/source.rb', line 596 def client_secret @client_secret end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
598 599 600 |
# File 'lib/stripe/resources/source.rb', line 598 def @expand end |