Class: Stripe::Source::SourceOrder
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::Source::SourceOrder
- Defined in:
- lib/stripe/resources/source.rb
Defined Under Namespace
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
A positive integer in the smallest currency unit (that is, 100 cents for $1.00, or 1 for ¥1, Japanese Yen being a zero-decimal currency) representing the total amount for the order.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#email ⇒ Object
readonly
The email address of the customer placing the order.
-
#items ⇒ Object
readonly
List of items constituting the order.
-
#shipping ⇒ Object
readonly
Attribute for field shipping.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
A positive integer in the smallest currency unit (that is, 100 cents for $1.00, or 1 for ¥1, Japanese Yen being a zero-decimal currency) representing the total amount for the order.
745 746 747 |
# File 'lib/stripe/resources/source.rb', line 745 def amount @amount end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
747 748 749 |
# File 'lib/stripe/resources/source.rb', line 747 def currency @currency end |
#email ⇒ Object (readonly)
The email address of the customer placing the order.
749 750 751 |
# File 'lib/stripe/resources/source.rb', line 749 def email @email end |
#items ⇒ Object (readonly)
List of items constituting the order.
751 752 753 |
# File 'lib/stripe/resources/source.rb', line 751 def items @items end |
#shipping ⇒ Object (readonly)
Attribute for field shipping
753 754 755 |
# File 'lib/stripe/resources/source.rb', line 753 def shipping @shipping end |
Class Method Details
.field_remappings ⇒ Object
759 760 761 |
# File 'lib/stripe/resources/source.rb', line 759 def self.field_remappings @field_remappings = {} end |