Class: Stripe::Source::SourceOrder::Item

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/source.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Method Summary

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount (price) for this order item.



653
654
655
# File 'lib/stripe/resources/source.rb', line 653

def amount
  @amount
end

#currencyObject (readonly)

This currency of this order item. Required when ‘amount` is present.



656
657
658
# File 'lib/stripe/resources/source.rb', line 656

def currency
  @currency
end

#descriptionObject (readonly)

Human-readable description for this order item.



659
660
661
# File 'lib/stripe/resources/source.rb', line 659

def description
  @description
end

#parentObject (readonly)

The ID of the associated object for this line item. Expandable if not null (e.g., expandable to a SKU).



662
663
664
# File 'lib/stripe/resources/source.rb', line 662

def parent
  @parent
end

#quantityObject (readonly)

The quantity of this order item. When type is ‘sku`, this is the number of instances of the SKU to be ordered.



665
666
667
# File 'lib/stripe/resources/source.rb', line 665

def quantity
  @quantity
end

#typeObject (readonly)

The type of this order item. Must be ‘sku`, `tax`, or `shipping`.



668
669
670
# File 'lib/stripe/resources/source.rb', line 668

def type
  @type
end