Class: Stripe::Source::SourceOrder::Shipping

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/source.rb

Defined Under Namespace

Classes: Address

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

Attribute for field address



726
727
728
# File 'lib/stripe/resources/source.rb', line 726

def address
  @address
end

#carrierObject (readonly)

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



728
729
730
# File 'lib/stripe/resources/source.rb', line 728

def carrier
  @carrier
end

#nameObject (readonly)

Recipient name.



730
731
732
# File 'lib/stripe/resources/source.rb', line 730

def name
  @name
end

#phoneObject (readonly)

Recipient phone (including extension).



732
733
734
# File 'lib/stripe/resources/source.rb', line 732

def phone
  @phone
end

#tracking_numberObject (readonly)

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



734
735
736
# File 'lib/stripe/resources/source.rb', line 734

def tracking_number
  @tracking_number
end

Class Method Details

.field_remappingsObject



740
741
742
# File 'lib/stripe/resources/source.rb', line 740

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



736
737
738
# File 'lib/stripe/resources/source.rb', line 736

def self.inner_class_types
  @inner_class_types = { address: Address }
end