Class: Stripe::Source::SourceOrder::Shipping

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/source.rb

Defined Under Namespace

Classes: Address

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Method Summary

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

Attribute for field address



692
693
694
# File 'lib/stripe/resources/source.rb', line 692

def address
  @address
end

#carrierObject (readonly)

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



695
696
697
# File 'lib/stripe/resources/source.rb', line 695

def carrier
  @carrier
end

#nameObject (readonly)

Recipient name.



698
699
700
# File 'lib/stripe/resources/source.rb', line 698

def name
  @name
end

#phoneObject (readonly)

Recipient phone (including extension).



701
702
703
# File 'lib/stripe/resources/source.rb', line 701

def phone
  @phone
end

#tracking_numberObject (readonly)

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



704
705
706
# File 'lib/stripe/resources/source.rb', line 704

def tracking_number
  @tracking_number
end