Class: Stripe::Source::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/source.rb

Defined Under Namespace

Classes: Mandate, Owner, SourceOrder

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, expand: nil, mandate: nil, metadata: nil, owner: nil, source_order: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
# File 'lib/stripe/resources/source.rb', line 832

def initialize(
  amount: nil,
  expand: nil,
  mandate: nil,
  metadata: nil,
  owner: nil,
  source_order: nil
)
  @amount = amount
  @expand = expand
  @mandate = mandate
  @metadata = 
  @owner = owner
  @source_order = source_order
end

Instance Attribute Details

#amountObject

Amount associated with the source.



820
821
822
# File 'lib/stripe/resources/source.rb', line 820

def amount
  @amount
end

#expandObject

Specifies which fields in the response should be expanded.



822
823
824
# File 'lib/stripe/resources/source.rb', line 822

def expand
  @expand
end

#mandateObject

Information about a mandate possibility attached to a source object (generally for bank debits) as well as its acceptance status.



824
825
826
# File 'lib/stripe/resources/source.rb', line 824

def mandate
  @mandate
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



826
827
828
# File 'lib/stripe/resources/source.rb', line 826

def 
  @metadata
end

#ownerObject

Information about the owner of the payment instrument that may be used or required by particular source types.



828
829
830
# File 'lib/stripe/resources/source.rb', line 828

def owner
  @owner
end

#source_orderObject

Information about the items and shipping associated with the source. Required for transactional credit (for example Klarna) sources before you can charge it.



830
831
832
# File 'lib/stripe/resources/source.rb', line 830

def source_order
  @source_order
end