Class: Stripe::Source::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/source.rb

Defined Under Namespace

Classes: Mandate, Owner, SourceOrder

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, expand: nil, mandate: nil, metadata: nil, owner: nil, source_order: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
# File 'lib/stripe/resources/source.rb', line 844

def initialize(
  amount: nil,
  expand: nil,
  mandate: nil,
  metadata: nil,
  owner: nil,
  source_order: nil
)
  @amount = amount
  @expand = expand
  @mandate = mandate
  @metadata = 
  @owner = owner
  @source_order = source_order
end

Instance Attribute Details

#amountObject

Amount associated with the source.



832
833
834
# File 'lib/stripe/resources/source.rb', line 832

def amount
  @amount
end

#expandObject

Specifies which fields in the response should be expanded.



834
835
836
# File 'lib/stripe/resources/source.rb', line 834

def expand
  @expand
end

#mandateObject

Information about a mandate possibility attached to a source object (generally for bank debits) as well as its acceptance status.



836
837
838
# File 'lib/stripe/resources/source.rb', line 836

def mandate
  @mandate
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



838
839
840
# File 'lib/stripe/resources/source.rb', line 838

def 
  @metadata
end

#ownerObject

Information about the owner of the payment instrument that may be used or required by particular source types.



840
841
842
# File 'lib/stripe/resources/source.rb', line 840

def owner
  @owner
end

#source_orderObject

Information about the items and shipping associated with the source. Required for transactional credit (for example Klarna) sources before you can charge it.



842
843
844
# File 'lib/stripe/resources/source.rb', line 842

def source_order
  @source_order
end