Class: Stripe::Source::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/source.rb

Defined Under Namespace

Classes: Mandate, Owner, SourceOrder

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, expand: nil, mandate: nil, metadata: nil, owner: nil, source_order: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
# File 'lib/stripe/resources/source.rb', line 1086

def initialize(
  amount: nil,
  expand: nil,
  mandate: nil,
  metadata: nil,
  owner: nil,
  source_order: nil
)
  @amount = amount
  @expand = expand
  @mandate = mandate
  @metadata = 
  @owner = owner
  @source_order = source_order
end

Instance Attribute Details

#amountObject

Amount associated with the source.



1069
1070
1071
# File 'lib/stripe/resources/source.rb', line 1069

def amount
  @amount
end

#expandObject

Specifies which fields in the response should be expanded.



1072
1073
1074
# File 'lib/stripe/resources/source.rb', line 1072

def expand
  @expand
end

#mandateObject

Information about a mandate possibility attached to a source object (generally for bank debits) as well as its acceptance status.



1075
1076
1077
# File 'lib/stripe/resources/source.rb', line 1075

def mandate
  @mandate
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1078
1079
1080
# File 'lib/stripe/resources/source.rb', line 1078

def 
  @metadata
end

#ownerObject

Information about the owner of the payment instrument that may be used or required by particular source types.



1081
1082
1083
# File 'lib/stripe/resources/source.rb', line 1081

def owner
  @owner
end

#source_orderObject

Information about the items and shipping associated with the source. Required for transactional credit (for example Klarna) sources before you can charge it.



1084
1085
1086
# File 'lib/stripe/resources/source.rb', line 1084

def source_order
  @source_order
end