Class: Stripe::Source::UpdateParams::Mandate::Acceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/source.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, offline: nil, online: nil, status: nil, type: nil, user_agent: nil) ⇒ Acceptance

Returns a new instance of Acceptance.



635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
# File 'lib/stripe/resources/source.rb', line 635

def initialize(
  date: nil,
  ip: nil,
  offline: nil,
  online: nil,
  status: nil,
  type: nil,
  user_agent: nil
)
  @date = date
  @ip = ip
  @offline = offline
  @online = online
  @status = status
  @type = type
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp (in seconds) when the mandate was accepted or refused by the customer.



621
622
623
# File 'lib/stripe/resources/source.rb', line 621

def date
  @date
end

#ipObject

The IP address from which the mandate was accepted or refused by the customer.



623
624
625
# File 'lib/stripe/resources/source.rb', line 623

def ip
  @ip
end

#offlineObject

The parameters required to store a mandate accepted offline. Should only be set if ‘mandate` is `offline`



625
626
627
# File 'lib/stripe/resources/source.rb', line 625

def offline
  @offline
end

#onlineObject

The parameters required to store a mandate accepted online. Should only be set if ‘mandate` is `online`



627
628
629
# File 'lib/stripe/resources/source.rb', line 627

def online
  @online
end

#statusObject

The status of the mandate acceptance. Either ‘accepted` (the mandate was accepted) or `refused` (the mandate was refused).



629
630
631
# File 'lib/stripe/resources/source.rb', line 629

def status
  @status
end

#typeObject

The type of acceptance information included with the mandate. Either ‘online` or `offline`



631
632
633
# File 'lib/stripe/resources/source.rb', line 631

def type
  @type
end

#user_agentObject

The user agent of the browser from which the mandate was accepted or refused by the customer.



633
634
635
# File 'lib/stripe/resources/source.rb', line 633

def user_agent
  @user_agent
end