Class: Stripe::Source::UpdateParams::Mandate::Acceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/source.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, offline: nil, online: nil, status: nil, type: nil, user_agent: nil) ⇒ Acceptance

Returns a new instance of Acceptance.



857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
# File 'lib/stripe/resources/source.rb', line 857

def initialize(
  date: nil,
  ip: nil,
  offline: nil,
  online: nil,
  status: nil,
  type: nil,
  user_agent: nil
)
  @date = date
  @ip = ip
  @offline = offline
  @online = online
  @status = status
  @type = type
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp (in seconds) when the mandate was accepted or refused by the customer.



837
838
839
# File 'lib/stripe/resources/source.rb', line 837

def date
  @date
end

#ipObject

The IP address from which the mandate was accepted or refused by the customer.



840
841
842
# File 'lib/stripe/resources/source.rb', line 840

def ip
  @ip
end

#offlineObject

The parameters required to store a mandate accepted offline. Should only be set if ‘mandate` is `offline`



843
844
845
# File 'lib/stripe/resources/source.rb', line 843

def offline
  @offline
end

#onlineObject

The parameters required to store a mandate accepted online. Should only be set if ‘mandate` is `online`



846
847
848
# File 'lib/stripe/resources/source.rb', line 846

def online
  @online
end

#statusObject

The status of the mandate acceptance. Either ‘accepted` (the mandate was accepted) or `refused` (the mandate was refused).



849
850
851
# File 'lib/stripe/resources/source.rb', line 849

def status
  @status
end

#typeObject

The type of acceptance information included with the mandate. Either ‘online` or `offline`



852
853
854
# File 'lib/stripe/resources/source.rb', line 852

def type
  @type
end

#user_agentObject

The user agent of the browser from which the mandate was accepted or refused by the customer.



855
856
857
# File 'lib/stripe/resources/source.rb', line 855

def user_agent
  @user_agent
end