Class: Stripe::Source::UpdateParams::Mandate::Acceptance::Online
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Source::UpdateParams::Mandate::Acceptance::Online
- Defined in:
- lib/stripe/resources/source.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp (in seconds) when the mandate was accepted or refused by the customer.
-
#ip ⇒ Object
The IP address from which the mandate was accepted or refused by the customer.
-
#user_agent ⇒ Object
The user agent of the browser from which the mandate was accepted or refused by the customer.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Online
constructor
A new instance of Online.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Online
Returns a new instance of Online.
854 855 856 857 858 |
# File 'lib/stripe/resources/source.rb', line 854 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp (in seconds) when the mandate was accepted or refused by the customer.
848 849 850 |
# File 'lib/stripe/resources/source.rb', line 848 def date @date end |
#ip ⇒ Object
The IP address from which the mandate was accepted or refused by the customer.
850 851 852 |
# File 'lib/stripe/resources/source.rb', line 850 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the mandate was accepted or refused by the customer.
852 853 854 |
# File 'lib/stripe/resources/source.rb', line 852 def user_agent @user_agent end |