Class: Stripe::Source::UpdateParams::Mandate::Acceptance::Online

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/source.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Online

Returns a new instance of Online.



587
588
589
590
591
# File 'lib/stripe/resources/source.rb', line 587

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp (in seconds) when the mandate was accepted or refused by the customer.



581
582
583
# File 'lib/stripe/resources/source.rb', line 581

def date
  @date
end

#ipObject

The IP address from which the mandate was accepted or refused by the customer.



583
584
585
# File 'lib/stripe/resources/source.rb', line 583

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the mandate was accepted or refused by the customer.



585
586
587
# File 'lib/stripe/resources/source.rb', line 585

def user_agent
  @user_agent
end