Class: Stripe::Source::UpdateParams::Mandate::Acceptance::Online

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/source.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Online

Returns a new instance of Online.



626
627
628
629
630
# File 'lib/stripe/resources/source.rb', line 626

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp (in seconds) when the mandate was accepted or refused by the customer.



620
621
622
# File 'lib/stripe/resources/source.rb', line 620

def date
  @date
end

#ipObject

The IP address from which the mandate was accepted or refused by the customer.



622
623
624
# File 'lib/stripe/resources/source.rb', line 622

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the mandate was accepted or refused by the customer.



624
625
626
# File 'lib/stripe/resources/source.rb', line 624

def user_agent
  @user_agent
end