Class: Stripe::SourceService::CreateParams::Receiver

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/source_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(refund_attributes_method: nil) ⇒ Receiver

Returns a new instance of Receiver.



487
488
489
# File 'lib/stripe/services/source_service.rb', line 487

def initialize(refund_attributes_method: nil)
  @refund_attributes_method = refund_attributes_method
end

Instance Attribute Details

#refund_attributes_methodObject

The method Stripe should use to request information needed to process a refund or mispayment. Either ‘email` (an email is sent directly to the customer) or `manual` (a `source.refund_attributes_required` event is sent to your webhooks endpoint). Refer to each payment method’s documentation to learn which refund attributes may be required.



485
486
487
# File 'lib/stripe/services/source_service.rb', line 485

def refund_attributes_method
  @refund_attributes_method
end