Class: Stripe::SourceService::RetrieveParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/source_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(client_secret: nil, expand: nil) ⇒ RetrieveParams

Returns a new instance of RetrieveParams.



29
30
31
32
# File 'lib/stripe/services/source_service.rb', line 29

def initialize(client_secret: nil, expand: nil)
  @client_secret = client_secret
  @expand = expand
end

Instance Attribute Details

#client_secretObject

The client secret of the source. Required if a publishable key is used to retrieve the source.



24
25
26
# File 'lib/stripe/services/source_service.rb', line 24

def client_secret
  @client_secret
end

#expandObject

Specifies which fields in the response should be expanded.



27
28
29
# File 'lib/stripe/services/source_service.rb', line 27

def expand
  @expand
end