Class: Stripe::SourceTransaction
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::SourceTransaction
- Defined in:
- lib/stripe/resources/source_transaction.rb
Overview
Some payment methods have no required amount that a customer must send. Customers can be instructed to send any amount, and it can be made up of multiple transactions. As such, sources can have multiple associated transactions.
Defined Under Namespace
Classes: AchCreditTransfer, ChfCreditTransfer, GbpCreditTransfer, PaperCheck, SepaCreditTransfer
Constant Summary collapse
- OBJECT_NAME =
"source_transaction"
Constants inherited from StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ach_credit_transfer ⇒ Object
readonly
Attribute for field ach_credit_transfer.
-
#amount ⇒ Object
readonly
A positive integer in the smallest currency unit (that is, 100 cents for $1.00, or 1 for ¥1, Japanese Yen being a zero-decimal currency) representing the amount your customer has pushed to the receiver.
-
#chf_credit_transfer ⇒ Object
readonly
Attribute for field chf_credit_transfer.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#gbp_credit_transfer ⇒ Object
readonly
Attribute for field gbp_credit_transfer.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#paper_check ⇒ Object
readonly
Attribute for field paper_check.
-
#sepa_credit_transfer ⇒ Object
readonly
Attribute for field sepa_credit_transfer.
-
#source ⇒ Object
readonly
The ID of the source this transaction is attached to.
-
#status ⇒ Object
readonly
The status of the transaction, one of ‘succeeded`, `pending`, or `failed`.
-
#type ⇒ Object
readonly
The type of source this transaction is attached to.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ach_credit_transfer ⇒ Object (readonly)
Attribute for field ach_credit_transfer
35 36 37 |
# File 'lib/stripe/resources/source_transaction.rb', line 35 def ach_credit_transfer @ach_credit_transfer end |
#amount ⇒ Object (readonly)
A positive integer in the smallest currency unit (that is, 100 cents for $1.00, or 1 for ¥1, Japanese Yen being a zero-decimal currency) representing the amount your customer has pushed to the receiver.
37 38 39 |
# File 'lib/stripe/resources/source_transaction.rb', line 37 def amount @amount end |
#chf_credit_transfer ⇒ Object (readonly)
Attribute for field chf_credit_transfer
39 40 41 |
# File 'lib/stripe/resources/source_transaction.rb', line 39 def chf_credit_transfer @chf_credit_transfer end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
41 42 43 |
# File 'lib/stripe/resources/source_transaction.rb', line 41 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
43 44 45 |
# File 'lib/stripe/resources/source_transaction.rb', line 43 def currency @currency end |
#gbp_credit_transfer ⇒ Object (readonly)
Attribute for field gbp_credit_transfer
45 46 47 |
# File 'lib/stripe/resources/source_transaction.rb', line 45 def gbp_credit_transfer @gbp_credit_transfer end |
#id ⇒ Object (readonly)
Unique identifier for the object.
47 48 49 |
# File 'lib/stripe/resources/source_transaction.rb', line 47 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
49 50 51 |
# File 'lib/stripe/resources/source_transaction.rb', line 49 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
51 52 53 |
# File 'lib/stripe/resources/source_transaction.rb', line 51 def object @object end |
#paper_check ⇒ Object (readonly)
Attribute for field paper_check
53 54 55 |
# File 'lib/stripe/resources/source_transaction.rb', line 53 def paper_check @paper_check end |
#sepa_credit_transfer ⇒ Object (readonly)
Attribute for field sepa_credit_transfer
55 56 57 |
# File 'lib/stripe/resources/source_transaction.rb', line 55 def sepa_credit_transfer @sepa_credit_transfer end |
#source ⇒ Object (readonly)
The ID of the source this transaction is attached to.
57 58 59 |
# File 'lib/stripe/resources/source_transaction.rb', line 57 def source @source end |
#status ⇒ Object (readonly)
The status of the transaction, one of ‘succeeded`, `pending`, or `failed`.
59 60 61 |
# File 'lib/stripe/resources/source_transaction.rb', line 59 def status @status end |
#type ⇒ Object (readonly)
The type of source this transaction is attached to.
61 62 63 |
# File 'lib/stripe/resources/source_transaction.rb', line 61 def type @type end |
Class Method Details
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/source_transaction.rb', line 11 def self.object_name "source_transaction" end |