Class: Stripe::Subscription
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Subscription
- Extended by:
- APIOperations::Create, APIOperations::List, APIOperations::Search
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/subscription.rb
Overview
Subscriptions allow you to charge a customer on a recurring basis.
Related guide: [Creating subscriptions](docs.stripe.com/billing/subscriptions/creating)
Defined Under Namespace
Classes: AutomaticTax, BillingCycleAnchorConfig, BillingMode, BillingThresholds, CancellationDetails, InvoiceSettings, PauseCollection, PaymentSettings, PendingInvoiceItemInterval, PendingUpdate, PresentmentDetails, TransferData, TrialSettings
Constant Summary collapse
- OBJECT_NAME =
"subscription"
Constants inherited from StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#application ⇒ Object
readonly
ID of the Connect Application that created the subscription.
-
#application_fee_percent ⇒ Object
readonly
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#automatic_tax ⇒ Object
readonly
Attribute for field automatic_tax.
-
#billing_cycle_anchor ⇒ Object
readonly
The reference point that aligns future [billing cycle](docs.stripe.com/subscriptions/billing-cycle) dates.
-
#billing_cycle_anchor_config ⇒ Object
readonly
The fixed values used to calculate the ‘billing_cycle_anchor`.
-
#billing_mode ⇒ Object
readonly
The billing mode of the subscription.
-
#billing_thresholds ⇒ Object
readonly
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#cancel_at ⇒ Object
readonly
A date in the future at which the subscription will automatically get canceled.
-
#cancel_at_period_end ⇒ Object
readonly
Whether this subscription will (if ‘status=active`) or did (if `status=canceled`) cancel at the end of the current billing period.
-
#canceled_at ⇒ Object
readonly
If the subscription has been canceled, the date of that cancellation.
-
#cancellation_details ⇒ Object
readonly
Details about why this subscription was cancelled.
-
#collection_method ⇒ Object
readonly
Either ‘charge_automatically`, or `send_invoice`.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
readonly
ID of the customer who owns the subscription.
-
#customer_account ⇒ Object
readonly
ID of the account representing the customer who owns the subscription.
-
#days_until_due ⇒ Object
readonly
Number of days a customer has to pay invoices generated by this subscription.
-
#default_payment_method ⇒ Object
readonly
ID of the default payment method for the subscription.
-
#default_source ⇒ Object
readonly
ID of the default payment source for the subscription.
-
#default_tax_rates ⇒ Object
readonly
The tax rates that will apply to any subscription item that does not have ‘tax_rates` set.
-
#description ⇒ Object
readonly
The subscription’s description, meant to be displayable to the customer.
-
#discounts ⇒ Object
readonly
The discounts applied to the subscription.
-
#ended_at ⇒ Object
readonly
If the subscription has ended, the date the subscription ended.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#invoice_settings ⇒ Object
readonly
Attribute for field invoice_settings.
-
#items ⇒ Object
readonly
List of subscription items, each with an attached price.
-
#latest_invoice ⇒ Object
readonly
The most recent invoice this subscription has generated over its lifecycle (for example, when it cycles or is updated).
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#next_pending_invoice_item_invoice ⇒ Object
readonly
Specifies the approximate timestamp on which any pending invoice items will be billed according to the schedule provided at ‘pending_invoice_item_interval`.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#on_behalf_of ⇒ Object
readonly
The account (if any) the charge was made on behalf of for charges associated with this subscription.
-
#pause_collection ⇒ Object
readonly
If specified, payment collection for this subscription will be paused.
-
#payment_settings ⇒ Object
readonly
Payment settings passed on to invoices created by the subscription.
-
#pending_invoice_item_interval ⇒ Object
readonly
Specifies an interval for how often to bill for any pending invoice items.
-
#pending_setup_intent ⇒ Object
readonly
You can use this [SetupIntent](docs.stripe.com/api/setup_intents) to collect user authentication when creating a subscription without immediate payment or updating a subscription’s payment method, allowing you to optimize for off-session payments.
-
#pending_update ⇒ Object
readonly
If specified, [pending updates](docs.stripe.com/billing/subscriptions/pending-updates) that will be applied to the subscription once the ‘latest_invoice` has been paid.
-
#presentment_details ⇒ Object
readonly
Attribute for field presentment_details.
-
#schedule ⇒ Object
readonly
The schedule attached to the subscription.
-
#start_date ⇒ Object
readonly
Date when the subscription was first created.
-
#status ⇒ Object
readonly
Possible values are ‘incomplete`, `incomplete_expired`, `trialing`, `active`, `past_due`, `canceled`, `unpaid`, or `paused`.
-
#test_clock ⇒ Object
readonly
ID of the test clock this subscription belongs to.
-
#transfer_data ⇒ Object
readonly
The account (if any) the subscription’s payments will be attributed to for tax reporting, and where funds from each payment will be transferred to for each of the subscription’s invoices.
-
#trial_end ⇒ Object
readonly
If the subscription has a trial, the end of that trial.
-
#trial_settings ⇒ Object
readonly
Settings related to subscription trials.
-
#trial_start ⇒ Object
readonly
If the subscription has a trial, the beginning of that trial.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.cancel(subscription_exposed_id, params = {}, opts = {}) ⇒ Object
Cancels a customer’s subscription immediately.
-
.create(params = {}, opts = {}) ⇒ Object
Creates a new subscription on an existing customer.
-
.delete_discount(subscription_exposed_id, params = {}, opts = {}) ⇒ Object
Removes the currently applied discount on a subscription.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
By default, returns a list of subscriptions that have not been canceled.
-
.migrate(subscription, params = {}, opts = {}) ⇒ Object
Upgrade the billing_mode of an existing subscription.
- .object_name ⇒ Object
-
.resume(subscription, params = {}, opts = {}) ⇒ Object
Initiates resumption of a paused subscription, optionally resetting the billing cycle anchor and creating prorations.
- .search(params = {}, opts = {}) ⇒ Object
- .search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object
-
.update(subscription_exposed_id, params = {}, opts = {}) ⇒ Object
Updates an existing subscription to match the specified parameters.
Instance Method Summary collapse
-
#cancel(params = {}, opts = {}) ⇒ Object
Cancels a customer’s subscription immediately.
-
#delete_discount(params = {}, opts = {}) ⇒ Object
Removes the currently applied discount on a subscription.
-
#migrate(params = {}, opts = {}) ⇒ Object
Upgrade the billing_mode of an existing subscription.
-
#resume(params = {}, opts = {}) ⇒ Object
Initiates resumption of a paused subscription, optionally resetting the billing cycle anchor and creating prorations.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Search
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#application ⇒ Object (readonly)
ID of the Connect Application that created the subscription.
522 523 524 |
# File 'lib/stripe/resources/subscription.rb', line 522 def application @application end |
#application_fee_percent ⇒ Object (readonly)
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account.
524 525 526 |
# File 'lib/stripe/resources/subscription.rb', line 524 def application_fee_percent @application_fee_percent end |
#automatic_tax ⇒ Object (readonly)
Attribute for field automatic_tax
526 527 528 |
# File 'lib/stripe/resources/subscription.rb', line 526 def automatic_tax @automatic_tax end |
#billing_cycle_anchor ⇒ Object (readonly)
The reference point that aligns future [billing cycle](docs.stripe.com/subscriptions/billing-cycle) dates. It sets the day of week for ‘week` intervals, the day of month for `month` and `year` intervals, and the month of year for `year` intervals. The timestamp is in UTC format.
528 529 530 |
# File 'lib/stripe/resources/subscription.rb', line 528 def billing_cycle_anchor @billing_cycle_anchor end |
#billing_cycle_anchor_config ⇒ Object (readonly)
The fixed values used to calculate the ‘billing_cycle_anchor`.
530 531 532 |
# File 'lib/stripe/resources/subscription.rb', line 530 def billing_cycle_anchor_config @billing_cycle_anchor_config end |
#billing_mode ⇒ Object (readonly)
The billing mode of the subscription.
532 533 534 |
# File 'lib/stripe/resources/subscription.rb', line 532 def billing_mode @billing_mode end |
#billing_thresholds ⇒ Object (readonly)
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period
534 535 536 |
# File 'lib/stripe/resources/subscription.rb', line 534 def billing_thresholds @billing_thresholds end |
#cancel_at ⇒ Object (readonly)
A date in the future at which the subscription will automatically get canceled
536 537 538 |
# File 'lib/stripe/resources/subscription.rb', line 536 def cancel_at @cancel_at end |
#cancel_at_period_end ⇒ Object (readonly)
Whether this subscription will (if ‘status=active`) or did (if `status=canceled`) cancel at the end of the current billing period.
538 539 540 |
# File 'lib/stripe/resources/subscription.rb', line 538 def cancel_at_period_end @cancel_at_period_end end |
#canceled_at ⇒ Object (readonly)
If the subscription has been canceled, the date of that cancellation. If the subscription was canceled with ‘cancel_at_period_end`, `canceled_at` will reflect the time of the most recent update request, not the end of the subscription period when the subscription is automatically moved to a canceled state.
540 541 542 |
# File 'lib/stripe/resources/subscription.rb', line 540 def canceled_at @canceled_at end |
#cancellation_details ⇒ Object (readonly)
Details about why this subscription was cancelled
542 543 544 |
# File 'lib/stripe/resources/subscription.rb', line 542 def cancellation_details @cancellation_details end |
#collection_method ⇒ Object (readonly)
Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay this subscription at the end of the cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`.
544 545 546 |
# File 'lib/stripe/resources/subscription.rb', line 544 def collection_method @collection_method end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
546 547 548 |
# File 'lib/stripe/resources/subscription.rb', line 546 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
548 549 550 |
# File 'lib/stripe/resources/subscription.rb', line 548 def currency @currency end |
#customer ⇒ Object (readonly)
ID of the customer who owns the subscription.
550 551 552 |
# File 'lib/stripe/resources/subscription.rb', line 550 def customer @customer end |
#customer_account ⇒ Object (readonly)
ID of the account representing the customer who owns the subscription.
552 553 554 |
# File 'lib/stripe/resources/subscription.rb', line 552 def customer_account @customer_account end |
#days_until_due ⇒ Object (readonly)
Number of days a customer has to pay invoices generated by this subscription. This value will be ‘null` for subscriptions where `collection_method=charge_automatically`.
554 555 556 |
# File 'lib/stripe/resources/subscription.rb', line 554 def days_until_due @days_until_due end |
#default_payment_method ⇒ Object (readonly)
ID of the default payment method for the subscription. It must belong to the customer associated with the subscription. This takes precedence over ‘default_source`. If neither are set, invoices will use the customer’s [invoice_settings.default_payment_method](docs.stripe.com/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](docs.stripe.com/api/customers/object#customer_object-default_source).
556 557 558 |
# File 'lib/stripe/resources/subscription.rb', line 556 def default_payment_method @default_payment_method end |
#default_source ⇒ Object (readonly)
ID of the default payment source for the subscription. It must belong to the customer associated with the subscription and be in a chargeable state. If ‘default_payment_method` is also set, `default_payment_method` will take precedence. If neither are set, invoices will use the customer’s [invoice_settings.default_payment_method](docs.stripe.com/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](docs.stripe.com/api/customers/object#customer_object-default_source).
558 559 560 |
# File 'lib/stripe/resources/subscription.rb', line 558 def default_source @default_source end |
#default_tax_rates ⇒ Object (readonly)
The tax rates that will apply to any subscription item that does not have ‘tax_rates` set. Invoices created will have their `default_tax_rates` populated from the subscription.
560 561 562 |
# File 'lib/stripe/resources/subscription.rb', line 560 def default_tax_rates @default_tax_rates end |
#description ⇒ Object (readonly)
The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
562 563 564 |
# File 'lib/stripe/resources/subscription.rb', line 562 def description @description end |
#discounts ⇒ Object (readonly)
The discounts applied to the subscription. Subscription item discounts are applied before subscription discounts. Use ‘expand[]=discounts` to expand each discount.
564 565 566 |
# File 'lib/stripe/resources/subscription.rb', line 564 def discounts @discounts end |
#ended_at ⇒ Object (readonly)
If the subscription has ended, the date the subscription ended.
566 567 568 |
# File 'lib/stripe/resources/subscription.rb', line 566 def ended_at @ended_at end |
#id ⇒ Object (readonly)
Unique identifier for the object.
568 569 570 |
# File 'lib/stripe/resources/subscription.rb', line 568 def id @id end |
#invoice_settings ⇒ Object (readonly)
Attribute for field invoice_settings
570 571 572 |
# File 'lib/stripe/resources/subscription.rb', line 570 def invoice_settings @invoice_settings end |
#items ⇒ Object (readonly)
List of subscription items, each with an attached price.
572 573 574 |
# File 'lib/stripe/resources/subscription.rb', line 572 def items @items end |
#latest_invoice ⇒ Object (readonly)
The most recent invoice this subscription has generated over its lifecycle (for example, when it cycles or is updated).
574 575 576 |
# File 'lib/stripe/resources/subscription.rb', line 574 def latest_invoice @latest_invoice end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
576 577 578 |
# File 'lib/stripe/resources/subscription.rb', line 576 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
578 579 580 |
# File 'lib/stripe/resources/subscription.rb', line 578 def @metadata end |
#next_pending_invoice_item_invoice ⇒ Object (readonly)
Specifies the approximate timestamp on which any pending invoice items will be billed according to the schedule provided at ‘pending_invoice_item_interval`.
580 581 582 |
# File 'lib/stripe/resources/subscription.rb', line 580 def next_pending_invoice_item_invoice @next_pending_invoice_item_invoice end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
582 583 584 |
# File 'lib/stripe/resources/subscription.rb', line 582 def object @object end |
#on_behalf_of ⇒ Object (readonly)
The account (if any) the charge was made on behalf of for charges associated with this subscription. See the [Connect documentation](docs.stripe.com/connect/subscriptions#on-behalf-of) for details.
584 585 586 |
# File 'lib/stripe/resources/subscription.rb', line 584 def on_behalf_of @on_behalf_of end |
#pause_collection ⇒ Object (readonly)
If specified, payment collection for this subscription will be paused. Note that the subscription status will be unchanged and will not be updated to ‘paused`. Learn more about [pausing collection](docs.stripe.com/billing/subscriptions/pause-payment).
586 587 588 |
# File 'lib/stripe/resources/subscription.rb', line 586 def pause_collection @pause_collection end |
#payment_settings ⇒ Object (readonly)
Payment settings passed on to invoices created by the subscription.
588 589 590 |
# File 'lib/stripe/resources/subscription.rb', line 588 def payment_settings @payment_settings end |
#pending_invoice_item_interval ⇒ Object (readonly)
Specifies an interval for how often to bill for any pending invoice items. It is analogous to calling [Create an invoice](/api/invoices/create) for the given subscription at the specified interval.
590 591 592 |
# File 'lib/stripe/resources/subscription.rb', line 590 def pending_invoice_item_interval @pending_invoice_item_interval end |
#pending_setup_intent ⇒ Object (readonly)
You can use this [SetupIntent](docs.stripe.com/api/setup_intents) to collect user authentication when creating a subscription without immediate payment or updating a subscription’s payment method, allowing you to optimize for off-session payments. Learn more in the [SCA Migration Guide](docs.stripe.com/billing/migration/strong-customer-authentication#scenario-2).
592 593 594 |
# File 'lib/stripe/resources/subscription.rb', line 592 def pending_setup_intent @pending_setup_intent end |
#pending_update ⇒ Object (readonly)
If specified, [pending updates](docs.stripe.com/billing/subscriptions/pending-updates) that will be applied to the subscription once the ‘latest_invoice` has been paid.
594 595 596 |
# File 'lib/stripe/resources/subscription.rb', line 594 def pending_update @pending_update end |
#presentment_details ⇒ Object (readonly)
Attribute for field presentment_details
596 597 598 |
# File 'lib/stripe/resources/subscription.rb', line 596 def presentment_details @presentment_details end |
#schedule ⇒ Object (readonly)
The schedule attached to the subscription
598 599 600 |
# File 'lib/stripe/resources/subscription.rb', line 598 def schedule @schedule end |
#start_date ⇒ Object (readonly)
Date when the subscription was first created. The date might differ from the ‘created` date due to backdating.
600 601 602 |
# File 'lib/stripe/resources/subscription.rb', line 600 def start_date @start_date end |
#status ⇒ Object (readonly)
Possible values are ‘incomplete`, `incomplete_expired`, `trialing`, `active`, `past_due`, `canceled`, `unpaid`, or `paused`.
For ‘collection_method=charge_automatically` a subscription moves into `incomplete` if the initial payment attempt fails. A subscription in this status can only have metadata and default_source updated. Once the first invoice is paid, the subscription moves into an `active` status. If the first invoice is not paid within 23 hours, the subscription transitions to `incomplete_expired`. This is a terminal status, the open invoice will be voided and no further invoices will be generated.
A subscription that is currently in a trial period is ‘trialing` and moves to `active` when the trial period is over.
A subscription can only enter a ‘paused` status [when a trial ends without a payment method](docs.stripe.com/billing/subscriptions/trials#create-free-trials-without-payment). A `paused` subscription doesn’t generate invoices and can be resumed after your customer adds their payment method. The ‘paused` status is different from [pausing collection](docs.stripe.com/billing/subscriptions/pause-payment), which still generates invoices and leaves the subscription’s status unchanged.
If subscription ‘collection_method=charge_automatically`, it becomes `past_due` when payment is required but cannot be paid (due to failed payment or awaiting additional user actions). Once Stripe has exhausted all payment retry attempts, the subscription will become `canceled` or `unpaid` (depending on your subscriptions settings).
If subscription ‘collection_method=send_invoice` it becomes `past_due` when its invoice is not paid by the due date, and `canceled` or `unpaid` if it is still not paid by an additional deadline after that. Note that when a subscription has a status of `unpaid`, no subsequent invoices will be attempted (invoices will be created, but then immediately automatically closed). After receiving updated payment information from a customer, you may choose to reopen and pay their closed invoices.
612 613 614 |
# File 'lib/stripe/resources/subscription.rb', line 612 def status @status end |
#test_clock ⇒ Object (readonly)
ID of the test clock this subscription belongs to.
614 615 616 |
# File 'lib/stripe/resources/subscription.rb', line 614 def test_clock @test_clock end |
#transfer_data ⇒ Object (readonly)
The account (if any) the subscription’s payments will be attributed to for tax reporting, and where funds from each payment will be transferred to for each of the subscription’s invoices.
616 617 618 |
# File 'lib/stripe/resources/subscription.rb', line 616 def transfer_data @transfer_data end |
#trial_end ⇒ Object (readonly)
If the subscription has a trial, the end of that trial.
618 619 620 |
# File 'lib/stripe/resources/subscription.rb', line 618 def trial_end @trial_end end |
#trial_settings ⇒ Object (readonly)
Settings related to subscription trials.
620 621 622 |
# File 'lib/stripe/resources/subscription.rb', line 620 def trial_settings @trial_settings end |
#trial_start ⇒ Object (readonly)
If the subscription has a trial, the beginning of that trial.
622 623 624 |
# File 'lib/stripe/resources/subscription.rb', line 622 def trial_start @trial_start end |
Class Method Details
.cancel(subscription_exposed_id, params = {}, opts = {}) ⇒ Object
Cancels a customer’s subscription immediately. The customer won’t be charged again for the subscription. After it’s canceled, you can no longer update the subscription or its [metadata](docs.stripe.com/metadata).
Any pending invoice items that you’ve created are still charged at the end of the period, unless manually [deleted](docs.stripe.com/api/invoiceitems/delete). If you’ve set the subscription to cancel at the end of the period, any pending prorations are also left in place and collected at the end of the period. But if the subscription is set to cancel immediately, pending prorations are removed if invoice_now and prorate are both set to true.
By default, upon subscription cancellation, Stripe stops automatic collection of all finalized invoices for the customer. This is intended to prevent unexpected payment attempts after the customer has canceled a subscription. However, you can resume automatic collection of the invoices manually after subscription cancellation to have us proceed. Or, you could check for unpaid invoices before allowing the customer to cancel the subscription at all.
643 644 645 646 647 648 649 650 |
# File 'lib/stripe/resources/subscription.rb', line 643 def self.cancel(subscription_exposed_id, params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/subscriptions/%<subscription_exposed_id>s", { subscription_exposed_id: CGI.escape(subscription_exposed_id) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
Creates a new subscription on an existing customer. Each customer can have up to 500 active or scheduled subscriptions.
When you create a subscription with collection_method=charge_automatically, the first invoice is finalized as part of the request. The payment_behavior parameter determines the exact behavior of the initial payment.
To start subscriptions where the first invoice always begins in a draft status, use [subscription schedules](docs.stripe.com/docs/billing/subscriptions/subscription-schedules#managing) instead. Schedules provide the flexibility to model more complex billing configurations that change over time.
659 660 661 |
# File 'lib/stripe/resources/subscription.rb', line 659 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/subscriptions", params: params, opts: opts) end |
.delete_discount(subscription_exposed_id, params = {}, opts = {}) ⇒ Object
Removes the currently applied discount on a subscription.
674 675 676 677 678 679 680 681 |
# File 'lib/stripe/resources/subscription.rb', line 674 def self.delete_discount(subscription_exposed_id, params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/subscriptions/%<subscription_exposed_id>s/discount", { subscription_exposed_id: CGI.escape(subscription_exposed_id) }), params: params, opts: opts ) end |
.field_remappings ⇒ Object
791 792 793 |
# File 'lib/stripe/resources/subscription.rb', line 791 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 |
# File 'lib/stripe/resources/subscription.rb', line 773 def self.inner_class_types @inner_class_types = { automatic_tax: AutomaticTax, billing_cycle_anchor_config: BillingCycleAnchorConfig, billing_mode: BillingMode, billing_thresholds: BillingThresholds, cancellation_details: CancellationDetails, invoice_settings: InvoiceSettings, pause_collection: PauseCollection, payment_settings: PaymentSettings, pending_invoice_item_interval: PendingInvoiceItemInterval, pending_update: PendingUpdate, presentment_details: PresentmentDetails, transfer_data: TransferData, trial_settings: TrialSettings, } end |
.list(params = {}, opts = {}) ⇒ Object
By default, returns a list of subscriptions that have not been canceled. In order to list canceled subscriptions, specify status=canceled.
684 685 686 |
# File 'lib/stripe/resources/subscription.rb', line 684 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/subscriptions", params: params, opts: opts) end |
.migrate(subscription, params = {}, opts = {}) ⇒ Object
Upgrade the billing_mode of an existing subscription.
699 700 701 702 703 704 705 706 |
# File 'lib/stripe/resources/subscription.rb', line 699 def self.migrate(subscription, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/subscriptions/%<subscription>s/migrate", { subscription: CGI.escape(subscription) }), params: params, opts: opts ) end |
.object_name ⇒ Object
15 16 17 |
# File 'lib/stripe/resources/subscription.rb', line 15 def self.object_name "subscription" end |
.resume(subscription, params = {}, opts = {}) ⇒ Object
Initiates resumption of a paused subscription, optionally resetting the billing cycle anchor and creating prorations. If no resumption invoice is generated, the subscription becomes active immediately. If a resumption invoice is generated, the subscription remains paused until the invoice is paid or marked uncollectible. If the invoice is not paid by the expiration date, it is voided and the subscription remains paused.
719 720 721 722 723 724 725 726 |
# File 'lib/stripe/resources/subscription.rb', line 719 def self.resume(subscription, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/subscriptions/%<subscription>s/resume", { subscription: CGI.escape(subscription) }), params: params, opts: opts ) end |
.search(params = {}, opts = {}) ⇒ Object
728 729 730 731 732 733 734 735 |
# File 'lib/stripe/resources/subscription.rb', line 728 def self.search(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/subscriptions/search", params: params, opts: opts ) end |
.search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object
737 738 739 |
# File 'lib/stripe/resources/subscription.rb', line 737 def self.search_auto_paging_each(params = {}, opts = {}, &blk) search(params, opts).auto_paging_each(&blk) end |
.update(subscription_exposed_id, params = {}, opts = {}) ⇒ Object
Updates an existing subscription to match the specified parameters. When changing prices or quantities, we optionally prorate the price we charge next month to make up for any price changes. To preview how the proration is calculated, use the [create preview](docs.stripe.com/docs/api/invoices/create_preview) endpoint.
By default, we prorate subscription changes. For example, if a customer signs up on May 1 for a 100 price, they’ll be billed 100 immediately. If on May 15 they switch to a 200 price, then on June 1 they’ll be billed 250 (200 for a renewal of her subscription, plus a 50 prorating adjustment for half of the previous month’s 100 difference). Similarly, a downgrade generates a credit that is applied to the next invoice. We also prorate when you make quantity changes.
Switching prices does not normally change the billing date or generate an immediate charge unless:
The billing interval is changed (for example, from monthly to yearly). The subscription moves from free to paid. A trial starts or ends.
In these cases, we apply a credit for the unused time on the previous price, immediately charge the customer using the new price, and reset the billing date. Learn about how [Stripe immediately attempts payment for subscription changes](docs.stripe.com/docs/billing/subscriptions/upgrade-downgrade#immediate-payment).
If you want to charge for an upgrade immediately, pass proration_behavior as always_invoice to create prorations, automatically invoice the customer for those proration adjustments, and attempt to collect payment. If you pass create_prorations, the prorations are created but not automatically invoiced. If you want to bill the customer for the prorations before the subscription’s renewal date, you need to manually [invoice the customer](docs.stripe.com/docs/api/invoices/create).
If you don’t want to prorate, set the proration_behavior option to none. With this option, the customer is billed 100 on May 1 and 200 on June 1. Similarly, if you set proration_behavior to none when switching between different billing intervals (for example, from monthly to yearly), we don’t generate any credits for the old subscription’s unused time. We still reset the billing date and bill immediately for the new subscription.
Updating the quantity on a subscription many times in an hour may result in [rate limiting. If you need to bill for a frequently changing quantity, consider integrating <a href=“/docs/billing/subscriptions/usage-based”>usage-based billing](docs.stripe.com/docs/rate-limits) instead.
762 763 764 765 766 767 768 769 |
# File 'lib/stripe/resources/subscription.rb', line 762 def self.update(subscription_exposed_id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/subscriptions/%<subscription_exposed_id>s", { subscription_exposed_id: CGI.escape(subscription_exposed_id) }), params: params, opts: opts ) end |
Instance Method Details
#cancel(params = {}, opts = {}) ⇒ Object
Cancels a customer’s subscription immediately. The customer won’t be charged again for the subscription. After it’s canceled, you can no longer update the subscription or its [metadata](docs.stripe.com/metadata).
Any pending invoice items that you’ve created are still charged at the end of the period, unless manually [deleted](docs.stripe.com/api/invoiceitems/delete). If you’ve set the subscription to cancel at the end of the period, any pending prorations are also left in place and collected at the end of the period. But if the subscription is set to cancel immediately, pending prorations are removed if invoice_now and prorate are both set to true.
By default, upon subscription cancellation, Stripe stops automatic collection of all finalized invoices for the customer. This is intended to prevent unexpected payment attempts after the customer has canceled a subscription. However, you can resume automatic collection of the invoices manually after subscription cancellation to have us proceed. Or, you could check for unpaid invoices before allowing the customer to cancel the subscription at all.
629 630 631 632 633 634 635 636 |
# File 'lib/stripe/resources/subscription.rb', line 629 def cancel(params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/subscriptions/%<subscription_exposed_id>s", { subscription_exposed_id: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#delete_discount(params = {}, opts = {}) ⇒ Object
Removes the currently applied discount on a subscription.
664 665 666 667 668 669 670 671 |
# File 'lib/stripe/resources/subscription.rb', line 664 def delete_discount(params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/subscriptions/%<subscription_exposed_id>s/discount", { subscription_exposed_id: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#migrate(params = {}, opts = {}) ⇒ Object
Upgrade the billing_mode of an existing subscription.
689 690 691 692 693 694 695 696 |
# File 'lib/stripe/resources/subscription.rb', line 689 def migrate(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/subscriptions/%<subscription>s/migrate", { subscription: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#resume(params = {}, opts = {}) ⇒ Object
Initiates resumption of a paused subscription, optionally resetting the billing cycle anchor and creating prorations. If no resumption invoice is generated, the subscription becomes active immediately. If a resumption invoice is generated, the subscription remains paused until the invoice is paid or marked uncollectible. If the invoice is not paid by the expiration date, it is voided and the subscription remains paused.
709 710 711 712 713 714 715 716 |
# File 'lib/stripe/resources/subscription.rb', line 709 def resume(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/subscriptions/%<subscription>s/resume", { subscription: CGI.escape(self["id"]) }), params: params, opts: opts ) end |