Class: Stripe::Subscription

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List, APIOperations::Search
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/subscription.rb

Overview

Subscriptions allow you to charge a customer on a recurring basis.

Related guide: [Creating subscriptions](stripe.com/docs/billing/subscriptions/creating)

Defined Under Namespace

Classes: AutomaticTax, BillingCycleAnchorConfig, BillingMode, BillingThresholds, CancelParams, CancellationDetails, CreateParams, DeleteDiscountParams, InvoiceSettings, LastPriceMigrationError, ListParams, MigrateParams, PauseCollection, PaymentSettings, PendingInvoiceItemInterval, PendingUpdate, Prebilling, ResumeParams, SearchParams, TransferData, TrialSettings, UpdateParams

Constant Summary collapse

OBJECT_NAME =
"subscription"

Constants inherited from StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Search

_search

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applicationObject (readonly)

ID of the Connect Application that created the subscription.



2059
2060
2061
# File 'lib/stripe/resources/subscription.rb', line 2059

def application
  @application
end

#application_fee_percentObject (readonly)

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account.



2061
2062
2063
# File 'lib/stripe/resources/subscription.rb', line 2061

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject (readonly)

Attribute for field automatic_tax



2063
2064
2065
# File 'lib/stripe/resources/subscription.rb', line 2063

def automatic_tax
  @automatic_tax
end

#billing_cycle_anchorObject (readonly)

The reference point that aligns future [billing cycle](stripe.com/docs/subscriptions/billing-cycle) dates. It sets the day of week for ‘week` intervals, the day of month for `month` and `year` intervals, and the month of year for `year` intervals. The timestamp is in UTC format.



2065
2066
2067
# File 'lib/stripe/resources/subscription.rb', line 2065

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_cycle_anchor_configObject (readonly)

The fixed values used to calculate the ‘billing_cycle_anchor`.



2067
2068
2069
# File 'lib/stripe/resources/subscription.rb', line 2067

def billing_cycle_anchor_config
  @billing_cycle_anchor_config
end

#billing_modeObject (readonly)

The billing mode of the subscription.



2069
2070
2071
# File 'lib/stripe/resources/subscription.rb', line 2069

def billing_mode
  @billing_mode
end

#billing_thresholdsObject (readonly)

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period



2071
2072
2073
# File 'lib/stripe/resources/subscription.rb', line 2071

def billing_thresholds
  @billing_thresholds
end

#cancel_atObject (readonly)

A date in the future at which the subscription will automatically get canceled



2073
2074
2075
# File 'lib/stripe/resources/subscription.rb', line 2073

def cancel_at
  @cancel_at
end

#cancel_at_period_endObject (readonly)

Whether this subscription will (if ‘status=active`) or did (if `status=canceled`) cancel at the end of the current billing period.



2075
2076
2077
# File 'lib/stripe/resources/subscription.rb', line 2075

def cancel_at_period_end
  @cancel_at_period_end
end

#canceled_atObject (readonly)

If the subscription has been canceled, the date of that cancellation. If the subscription was canceled with ‘cancel_at_period_end`, `canceled_at` will reflect the time of the most recent update request, not the end of the subscription period when the subscription is automatically moved to a canceled state.



2077
2078
2079
# File 'lib/stripe/resources/subscription.rb', line 2077

def canceled_at
  @canceled_at
end

#cancellation_detailsObject (readonly)

Details about why this subscription was cancelled



2079
2080
2081
# File 'lib/stripe/resources/subscription.rb', line 2079

def cancellation_details
  @cancellation_details
end

#collection_methodObject (readonly)

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay this subscription at the end of the cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`.



2081
2082
2083
# File 'lib/stripe/resources/subscription.rb', line 2081

def collection_method
  @collection_method
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



2083
2084
2085
# File 'lib/stripe/resources/subscription.rb', line 2083

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



2085
2086
2087
# File 'lib/stripe/resources/subscription.rb', line 2085

def currency
  @currency
end

#customerObject (readonly)

ID of the customer who owns the subscription.



2087
2088
2089
# File 'lib/stripe/resources/subscription.rb', line 2087

def customer
  @customer
end

#customer_accountObject (readonly)

ID of the account who owns the subscription.



2089
2090
2091
# File 'lib/stripe/resources/subscription.rb', line 2089

def 
  @customer_account
end

#days_until_dueObject (readonly)

Number of days a customer has to pay invoices generated by this subscription. This value will be ‘null` for subscriptions where `collection_method=charge_automatically`.



2091
2092
2093
# File 'lib/stripe/resources/subscription.rb', line 2091

def days_until_due
  @days_until_due
end

#default_payment_methodObject (readonly)

ID of the default payment method for the subscription. It must belong to the customer associated with the subscription. This takes precedence over ‘default_source`. If neither are set, invoices will use the customer’s [invoice_settings.default_payment_method](stripe.com/docs/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](stripe.com/docs/api/customers/object#customer_object-default_source).



2093
2094
2095
# File 'lib/stripe/resources/subscription.rb', line 2093

def default_payment_method
  @default_payment_method
end

#default_sourceObject (readonly)

ID of the default payment source for the subscription. It must belong to the customer associated with the subscription and be in a chargeable state. If ‘default_payment_method` is also set, `default_payment_method` will take precedence. If neither are set, invoices will use the customer’s [invoice_settings.default_payment_method](stripe.com/docs/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](stripe.com/docs/api/customers/object#customer_object-default_source).



2095
2096
2097
# File 'lib/stripe/resources/subscription.rb', line 2095

def default_source
  @default_source
end

#default_tax_ratesObject (readonly)

The tax rates that will apply to any subscription item that does not have ‘tax_rates` set. Invoices created will have their `default_tax_rates` populated from the subscription.



2097
2098
2099
# File 'lib/stripe/resources/subscription.rb', line 2097

def default_tax_rates
  @default_tax_rates
end

#descriptionObject (readonly)

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



2099
2100
2101
# File 'lib/stripe/resources/subscription.rb', line 2099

def description
  @description
end

#discountsObject (readonly)

The discounts applied to the subscription. Subscription item discounts are applied before subscription discounts. Use ‘expand[]=discounts` to expand each discount.



2101
2102
2103
# File 'lib/stripe/resources/subscription.rb', line 2101

def discounts
  @discounts
end

#ended_atObject (readonly)

If the subscription has ended, the date the subscription ended.



2103
2104
2105
# File 'lib/stripe/resources/subscription.rb', line 2103

def ended_at
  @ended_at
end

#idObject (readonly)

Unique identifier for the object.



2105
2106
2107
# File 'lib/stripe/resources/subscription.rb', line 2105

def id
  @id
end

#invoice_settingsObject (readonly)

Attribute for field invoice_settings



2107
2108
2109
# File 'lib/stripe/resources/subscription.rb', line 2107

def invoice_settings
  @invoice_settings
end

#itemsObject (readonly)

List of subscription items, each with an attached price.



2109
2110
2111
# File 'lib/stripe/resources/subscription.rb', line 2109

def items
  @items
end

#last_price_migration_errorObject (readonly)

Details of the most recent price migration that failed for the subscription.



2111
2112
2113
# File 'lib/stripe/resources/subscription.rb', line 2111

def last_price_migration_error
  @last_price_migration_error
end

#latest_invoiceObject (readonly)

The most recent invoice this subscription has generated.



2113
2114
2115
# File 'lib/stripe/resources/subscription.rb', line 2113

def latest_invoice
  @latest_invoice
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



2115
2116
2117
# File 'lib/stripe/resources/subscription.rb', line 2115

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



2117
2118
2119
# File 'lib/stripe/resources/subscription.rb', line 2117

def 
  @metadata
end

#next_pending_invoice_item_invoiceObject (readonly)

Specifies the approximate timestamp on which any pending invoice items will be billed according to the schedule provided at ‘pending_invoice_item_interval`.



2119
2120
2121
# File 'lib/stripe/resources/subscription.rb', line 2119

def next_pending_invoice_item_invoice
  @next_pending_invoice_item_invoice
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



2121
2122
2123
# File 'lib/stripe/resources/subscription.rb', line 2121

def object
  @object
end

#on_behalf_ofObject (readonly)

The account (if any) the charge was made on behalf of for charges associated with this subscription. See the [Connect documentation](stripe.com/docs/connect/subscriptions#on-behalf-of) for details.



2123
2124
2125
# File 'lib/stripe/resources/subscription.rb', line 2123

def on_behalf_of
  @on_behalf_of
end

#pause_collectionObject (readonly)

If specified, payment collection for this subscription will be paused. Note that the subscription status will be unchanged and will not be updated to ‘paused`. Learn more about [pausing collection](stripe.com/docs/billing/subscriptions/pause-payment).



2125
2126
2127
# File 'lib/stripe/resources/subscription.rb', line 2125

def pause_collection
  @pause_collection
end

#payment_settingsObject (readonly)

Payment settings passed on to invoices created by the subscription.



2127
2128
2129
# File 'lib/stripe/resources/subscription.rb', line 2127

def payment_settings
  @payment_settings
end

#pending_invoice_item_intervalObject (readonly)

Specifies an interval for how often to bill for any pending invoice items. It is analogous to calling [Create an invoice](stripe.com/docs/api#create_invoice) for the given subscription at the specified interval.



2129
2130
2131
# File 'lib/stripe/resources/subscription.rb', line 2129

def pending_invoice_item_interval
  @pending_invoice_item_interval
end

#pending_setup_intentObject (readonly)

You can use this [SetupIntent](stripe.com/docs/api/setup_intents) to collect user authentication when creating a subscription without immediate payment or updating a subscription’s payment method, allowing you to optimize for off-session payments. Learn more in the [SCA Migration Guide](stripe.com/docs/billing/migration/strong-customer-authentication#scenario-2).



2131
2132
2133
# File 'lib/stripe/resources/subscription.rb', line 2131

def pending_setup_intent
  @pending_setup_intent
end

#pending_updateObject (readonly)

If specified, [pending updates](stripe.com/docs/billing/subscriptions/pending-updates) that will be applied to the subscription once the ‘latest_invoice` has been paid.



2133
2134
2135
# File 'lib/stripe/resources/subscription.rb', line 2133

def pending_update
  @pending_update
end

#prebillingObject (readonly)

Time period and invoice for a Subscription billed in advance.



2135
2136
2137
# File 'lib/stripe/resources/subscription.rb', line 2135

def prebilling
  @prebilling
end

#scheduleObject (readonly)

The schedule attached to the subscription



2137
2138
2139
# File 'lib/stripe/resources/subscription.rb', line 2137

def schedule
  @schedule
end

#start_dateObject (readonly)

Date when the subscription was first created. The date might differ from the ‘created` date due to backdating.



2139
2140
2141
# File 'lib/stripe/resources/subscription.rb', line 2139

def start_date
  @start_date
end

#statusObject (readonly)

Possible values are ‘incomplete`, `incomplete_expired`, `trialing`, `active`, `past_due`, `canceled`, `unpaid`, or `paused`.

For ‘collection_method=charge_automatically` a subscription moves into `incomplete` if the initial payment attempt fails. A subscription in this status can only have metadata and default_source updated. Once the first invoice is paid, the subscription moves into an `active` status. If the first invoice is not paid within 23 hours, the subscription transitions to `incomplete_expired`. This is a terminal status, the open invoice will be voided and no further invoices will be generated.

A subscription that is currently in a trial period is ‘trialing` and moves to `active` when the trial period is over.

A subscription can only enter a ‘paused` status [when a trial ends without a payment method](stripe.com/docs/billing/subscriptions/trials#create-free-trials-without-payment). A `paused` subscription doesn’t generate invoices and can be resumed after your customer adds their payment method. The ‘paused` status is different from [pausing collection](stripe.com/docs/billing/subscriptions/pause-payment), which still generates invoices and leaves the subscription’s status unchanged.

If subscription ‘collection_method=charge_automatically`, it becomes `past_due` when payment is required but cannot be paid (due to failed payment or awaiting additional user actions). Once Stripe has exhausted all payment retry attempts, the subscription will become `canceled` or `unpaid` (depending on your subscriptions settings).

If subscription ‘collection_method=send_invoice` it becomes `past_due` when its invoice is not paid by the due date, and `canceled` or `unpaid` if it is still not paid by an additional deadline after that. Note that when a subscription has a status of `unpaid`, no subsequent invoices will be attempted (invoices will be created, but then immediately automatically closed). After receiving updated payment information from a customer, you may choose to reopen and pay their closed invoices.



2151
2152
2153
# File 'lib/stripe/resources/subscription.rb', line 2151

def status
  @status
end

#test_clockObject (readonly)

ID of the test clock this subscription belongs to.



2153
2154
2155
# File 'lib/stripe/resources/subscription.rb', line 2153

def test_clock
  @test_clock
end

#transfer_dataObject (readonly)

The account (if any) the subscription’s payments will be attributed to for tax reporting, and where funds from each payment will be transferred to for each of the subscription’s invoices.



2155
2156
2157
# File 'lib/stripe/resources/subscription.rb', line 2155

def transfer_data
  @transfer_data
end

#trial_endObject (readonly)

If the subscription has a trial, the end of that trial.



2157
2158
2159
# File 'lib/stripe/resources/subscription.rb', line 2157

def trial_end
  @trial_end
end

#trial_settingsObject (readonly)

Settings related to subscription trials.



2159
2160
2161
# File 'lib/stripe/resources/subscription.rb', line 2159

def trial_settings
  @trial_settings
end

#trial_startObject (readonly)

If the subscription has a trial, the beginning of that trial.



2161
2162
2163
# File 'lib/stripe/resources/subscription.rb', line 2161

def trial_start
  @trial_start
end

Class Method Details

.cancel(subscription_exposed_id, params = {}, opts = {}) ⇒ Object

Cancels a customer’s subscription immediately. The customer won’t be charged again for the subscription. After it’s canceled, you can no longer update the subscription or its [metadata](docs.stripe.com/metadata).

Any pending invoice items that you’ve created are still charged at the end of the period, unless manually [deleted](docs.stripe.com/api#delete_invoiceitem). If you’ve set the subscription to cancel at the end of the period, any pending prorations are also left in place and collected at the end of the period. But if the subscription is set to cancel immediately, pending prorations are removed if invoice_now and prorate are both set to true.

By default, upon subscription cancellation, Stripe stops automatic collection of all finalized invoices for the customer. This is intended to prevent unexpected payment attempts after the customer has canceled a subscription. However, you can resume automatic collection of the invoices manually after subscription cancellation to have us proceed. Or, you could check for unpaid invoices before allowing the customer to cancel the subscription at all.



2182
2183
2184
2185
2186
2187
2188
2189
# File 'lib/stripe/resources/subscription.rb', line 2182

def self.cancel(subscription_exposed_id, params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/subscriptions/%<subscription_exposed_id>s", { subscription_exposed_id: CGI.escape(subscription_exposed_id) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

Creates a new subscription on an existing customer. Each customer can have up to 500 active or scheduled subscriptions.

When you create a subscription with collection_method=charge_automatically, the first invoice is finalized as part of the request. The payment_behavior parameter determines the exact behavior of the initial payment.

To start subscriptions where the first invoice always begins in a draft status, use [subscription schedules](docs.stripe.com/docs/billing/subscriptions/subscription-schedules#managing) instead. Schedules provide the flexibility to model more complex billing configurations that change over time.



2198
2199
2200
# File 'lib/stripe/resources/subscription.rb', line 2198

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/subscriptions", params: params, opts: opts)
end

.delete_discount(subscription_exposed_id, params = {}, opts = {}) ⇒ Object

Removes the currently applied discount on a subscription.



2213
2214
2215
2216
2217
2218
2219
2220
# File 'lib/stripe/resources/subscription.rb', line 2213

def self.delete_discount(subscription_exposed_id, params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/subscriptions/%<subscription_exposed_id>s/discount", { subscription_exposed_id: CGI.escape(subscription_exposed_id) }),
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

By default, returns a list of subscriptions that have not been canceled. In order to list canceled subscriptions, specify status=canceled.



2223
2224
2225
# File 'lib/stripe/resources/subscription.rb', line 2223

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/subscriptions", params: params, opts: opts)
end

.migrate(subscription, params = {}, opts = {}) ⇒ Object

Upgrade the billing_mode of an existing subscription.



2238
2239
2240
2241
2242
2243
2244
2245
# File 'lib/stripe/resources/subscription.rb', line 2238

def self.migrate(subscription, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscriptions/%<subscription>s/migrate", { subscription: CGI.escape(subscription) }),
    params: params,
    opts: opts
  )
end

.object_nameObject



15
16
17
# File 'lib/stripe/resources/subscription.rb', line 15

def self.object_name
  "subscription"
end

.resume(subscription, params = {}, opts = {}) ⇒ Object

Initiates resumption of a paused subscription, optionally resetting the billing cycle anchor and creating prorations. If a resumption invoice is generated, it must be paid or marked uncollectible before the subscription will be unpaused. If payment succeeds the subscription will become active, and if payment fails the subscription will be past_due. The resumption invoice will void automatically if not paid by the expiration date.



2258
2259
2260
2261
2262
2263
2264
2265
# File 'lib/stripe/resources/subscription.rb', line 2258

def self.resume(subscription, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscriptions/%<subscription>s/resume", { subscription: CGI.escape(subscription) }),
    params: params,
    opts: opts
  )
end

.search(params = {}, opts = {}) ⇒ Object



2267
2268
2269
2270
2271
2272
2273
2274
# File 'lib/stripe/resources/subscription.rb', line 2267

def self.search(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/subscriptions/search",
    params: params,
    opts: opts
  )
end

.search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object



2276
2277
2278
# File 'lib/stripe/resources/subscription.rb', line 2276

def self.search_auto_paging_each(params = {}, opts = {}, &blk)
  search(params, opts).auto_paging_each(&blk)
end

.update(subscription_exposed_id, params = {}, opts = {}) ⇒ Object

Updates an existing subscription to match the specified parameters. When changing prices or quantities, we optionally prorate the price we charge next month to make up for any price changes. To preview how the proration is calculated, use the [create preview](docs.stripe.com/docs/api/invoices/create_preview) endpoint.

By default, we prorate subscription changes. For example, if a customer signs up on May 1 for a 100 price, they’ll be billed 100 immediately. If on May 15 they switch to a 200 price, then on June 1 they’ll be billed 250 (200 for a renewal of her subscription, plus a 50 prorating adjustment for half of the previous month’s 100 difference). Similarly, a downgrade generates a credit that is applied to the next invoice. We also prorate when you make quantity changes.

Switching prices does not normally change the billing date or generate an immediate charge unless:

The billing interval is changed (for example, from monthly to yearly). The subscription moves from free to paid. A trial starts or ends.

In these cases, we apply a credit for the unused time on the previous price, immediately charge the customer using the new price, and reset the billing date. Learn about how [Stripe immediately attempts payment for subscription changes](docs.stripe.com/docs/billing/subscriptions/upgrade-downgrade#immediate-payment).

If you want to charge for an upgrade immediately, pass proration_behavior as always_invoice to create prorations, automatically invoice the customer for those proration adjustments, and attempt to collect payment. If you pass create_prorations, the prorations are created but not automatically invoiced. If you want to bill the customer for the prorations before the subscription’s renewal date, you need to manually [invoice the customer](docs.stripe.com/docs/api/invoices/create).

If you don’t want to prorate, set the proration_behavior option to none. With this option, the customer is billed 100 on May 1 and 200 on June 1. Similarly, if you set proration_behavior to none when switching between different billing intervals (for example, from monthly to yearly), we don’t generate any credits for the old subscription’s unused time. We still reset the billing date and bill immediately for the new subscription.

Updating the quantity on a subscription many times in an hour may result in [rate limiting. If you need to bill for a frequently changing quantity, consider integrating <a href=“/docs/billing/subscriptions/usage-based”>usage-based billing](docs.stripe.com/docs/rate-limits) instead.



2301
2302
2303
2304
2305
2306
2307
2308
# File 'lib/stripe/resources/subscription.rb', line 2301

def self.update(subscription_exposed_id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscriptions/%<subscription_exposed_id>s", { subscription_exposed_id: CGI.escape(subscription_exposed_id) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#cancel(params = {}, opts = {}) ⇒ Object

Cancels a customer’s subscription immediately. The customer won’t be charged again for the subscription. After it’s canceled, you can no longer update the subscription or its [metadata](docs.stripe.com/metadata).

Any pending invoice items that you’ve created are still charged at the end of the period, unless manually [deleted](docs.stripe.com/api#delete_invoiceitem). If you’ve set the subscription to cancel at the end of the period, any pending prorations are also left in place and collected at the end of the period. But if the subscription is set to cancel immediately, pending prorations are removed if invoice_now and prorate are both set to true.

By default, upon subscription cancellation, Stripe stops automatic collection of all finalized invoices for the customer. This is intended to prevent unexpected payment attempts after the customer has canceled a subscription. However, you can resume automatic collection of the invoices manually after subscription cancellation to have us proceed. Or, you could check for unpaid invoices before allowing the customer to cancel the subscription at all.



2168
2169
2170
2171
2172
2173
2174
2175
# File 'lib/stripe/resources/subscription.rb', line 2168

def cancel(params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/subscriptions/%<subscription_exposed_id>s", { subscription_exposed_id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#delete_discount(params = {}, opts = {}) ⇒ Object

Removes the currently applied discount on a subscription.



2203
2204
2205
2206
2207
2208
2209
2210
# File 'lib/stripe/resources/subscription.rb', line 2203

def delete_discount(params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/subscriptions/%<subscription_exposed_id>s/discount", { subscription_exposed_id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#migrate(params = {}, opts = {}) ⇒ Object

Upgrade the billing_mode of an existing subscription.



2228
2229
2230
2231
2232
2233
2234
2235
# File 'lib/stripe/resources/subscription.rb', line 2228

def migrate(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscriptions/%<subscription>s/migrate", { subscription: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#resume(params = {}, opts = {}) ⇒ Object

Initiates resumption of a paused subscription, optionally resetting the billing cycle anchor and creating prorations. If a resumption invoice is generated, it must be paid or marked uncollectible before the subscription will be unpaused. If payment succeeds the subscription will become active, and if payment fails the subscription will be past_due. The resumption invoice will void automatically if not paid by the expiration date.



2248
2249
2250
2251
2252
2253
2254
2255
# File 'lib/stripe/resources/subscription.rb', line 2248

def resume(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscriptions/%<subscription>s/resume", { subscription: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end