Class: Stripe::Subscription::AttachCadenceParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_cadence: nil, expand: nil) ⇒ AttachCadenceParams

Returns a new instance of AttachCadenceParams.



2416
2417
2418
2419
# File 'lib/stripe/resources/subscription.rb', line 2416

def initialize(billing_cadence: nil, expand: nil)
  @billing_cadence = billing_cadence
  @expand = expand
end

Instance Attribute Details

#billing_cadenceObject

The Billing Cadence which controls the timing of recurring invoice generation for this subscription. If unset, the subscription will bill according to its own configured schedule and create its own invoices. If set, this subscription will be billed by the cadence instead, potentially sharing invoices with the other subscriptions linked to that Cadence.



2412
2413
2414
# File 'lib/stripe/resources/subscription.rb', line 2412

def billing_cadence
  @billing_cadence
end

#expandObject

Specifies which fields in the response should be expanded.



2414
2415
2416
# File 'lib/stripe/resources/subscription.rb', line 2414

def expand
  @expand
end