Class: Stripe::Subscription::AttachCadenceParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::AttachCadenceParams
- Defined in:
- lib/stripe/resources/subscription.rb
Instance Attribute Summary collapse
-
#billing_cadence ⇒ Object
The Billing Cadence which controls the timing of recurring invoice generation for this subscription.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(billing_cadence: nil, expand: nil) ⇒ AttachCadenceParams
constructor
A new instance of AttachCadenceParams.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_cadence: nil, expand: nil) ⇒ AttachCadenceParams
Returns a new instance of AttachCadenceParams.
2124 2125 2126 2127 |
# File 'lib/stripe/resources/subscription.rb', line 2124 def initialize(billing_cadence: nil, expand: nil) @billing_cadence = billing_cadence @expand = end |
Instance Attribute Details
#billing_cadence ⇒ Object
The Billing Cadence which controls the timing of recurring invoice generation for this subscription. If unset, the subscription will bill according to its own configured schedule and create its own invoices. If set, this subscription will be billed by the cadence instead, potentially sharing invoices with the other subscriptions linked to that Cadence.
2120 2121 2122 |
# File 'lib/stripe/resources/subscription.rb', line 2120 def billing_cadence @billing_cadence end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2122 2123 2124 |
# File 'lib/stripe/resources/subscription.rb', line 2122 def @expand end |