Class: Stripe::Subscription::BillingSchedule::BillUntil

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration, LineEndsAt

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amendment_endObject (readonly)

Use an index to specify the position of an amendment to end prebilling with.



225
226
227
# File 'lib/stripe/resources/subscription.rb', line 225

def amendment_end
  @amendment_end
end

#computed_timestampObject (readonly)

The timestamp the billing schedule will apply until.



227
228
229
# File 'lib/stripe/resources/subscription.rb', line 227

def computed_timestamp
  @computed_timestamp
end

#durationObject (readonly)

Specifies the billing period.



229
230
231
# File 'lib/stripe/resources/subscription.rb', line 229

def duration
  @duration
end

#line_ends_atObject (readonly)

Lets you bill the period ending at a particular Quote line.



231
232
233
# File 'lib/stripe/resources/subscription.rb', line 231

def line_ends_at
  @line_ends_at
end

#timestampObject (readonly)

If specified, the billing schedule will apply until the specified timestamp.



233
234
235
# File 'lib/stripe/resources/subscription.rb', line 233

def timestamp
  @timestamp
end

#typeObject (readonly)

Describes how the billing schedule will determine the end date. Either ‘duration` or `timestamp`.



235
236
237
# File 'lib/stripe/resources/subscription.rb', line 235

def type
  @type
end

Class Method Details

.field_remappingsObject



245
246
247
# File 'lib/stripe/resources/subscription.rb', line 245

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



237
238
239
240
241
242
243
# File 'lib/stripe/resources/subscription.rb', line 237

def self.inner_class_types
  @inner_class_types = {
    amendment_end: AmendmentEnd,
    duration: Duration,
    line_ends_at: LineEndsAt,
  }
end