Class: Stripe::Subscription::CancelParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CancelParams
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: CancellationDetails
Instance Attribute Summary collapse
-
#cancellation_details ⇒ Object
Details about why this subscription was cancelled.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_now ⇒ Object
Will generate a final invoice that invoices for any un-invoiced metered usage and new/pending proration invoice items.
-
#prorate ⇒ Object
Will generate a proration invoice item that credits remaining unused time until the subscription period end.
Instance Method Summary collapse
-
#initialize(cancellation_details: nil, expand: nil, invoice_now: nil, prorate: nil) ⇒ CancelParams
constructor
A new instance of CancelParams.
Methods inherited from RequestParams
Constructor Details
#initialize(cancellation_details: nil, expand: nil, invoice_now: nil, prorate: nil) ⇒ CancelParams
Returns a new instance of CancelParams.
236 237 238 239 240 241 |
# File 'lib/stripe/resources/subscription.rb', line 236 def initialize(cancellation_details: nil, expand: nil, invoice_now: nil, prorate: nil) @cancellation_details = cancellation_details @expand = @invoice_now = invoice_now @prorate = prorate end |
Instance Attribute Details
#cancellation_details ⇒ Object
Details about why this subscription was cancelled
228 229 230 |
# File 'lib/stripe/resources/subscription.rb', line 228 def cancellation_details @cancellation_details end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
230 231 232 |
# File 'lib/stripe/resources/subscription.rb', line 230 def @expand end |
#invoice_now ⇒ Object
Will generate a final invoice that invoices for any un-invoiced metered usage and new/pending proration invoice items. Defaults to ‘false`.
232 233 234 |
# File 'lib/stripe/resources/subscription.rb', line 232 def invoice_now @invoice_now end |
#prorate ⇒ Object
Will generate a proration invoice item that credits remaining unused time until the subscription period end. Defaults to ‘false`.
234 235 236 |
# File 'lib/stripe/resources/subscription.rb', line 234 def prorate @prorate end |