Class: Stripe::Subscription::CancelParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: CancellationDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(cancellation_details: nil, expand: nil, invoice_now: nil, prorate: nil) ⇒ CancelParams

Returns a new instance of CancelParams.



229
230
231
232
233
234
# File 'lib/stripe/resources/subscription.rb', line 229

def initialize(cancellation_details: nil, expand: nil, invoice_now: nil, prorate: nil)
  @cancellation_details = cancellation_details
  @expand = expand
  @invoice_now = invoice_now
  @prorate = prorate
end

Instance Attribute Details

#cancellation_detailsObject

Details about why this subscription was cancelled



221
222
223
# File 'lib/stripe/resources/subscription.rb', line 221

def cancellation_details
  @cancellation_details
end

#expandObject

Specifies which fields in the response should be expanded.



223
224
225
# File 'lib/stripe/resources/subscription.rb', line 223

def expand
  @expand
end

#invoice_nowObject

Will generate a final invoice that invoices for any un-invoiced metered usage and new/pending proration invoice items. Defaults to ‘false`.



225
226
227
# File 'lib/stripe/resources/subscription.rb', line 225

def invoice_now
  @invoice_now
end

#prorateObject

Will generate a proration invoice item that credits remaining unused time until the subscription period end. Defaults to ‘false`.



227
228
229
# File 'lib/stripe/resources/subscription.rb', line 227

def prorate
  @prorate
end