Class: Stripe::Subscription::CancelParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: CancellationDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(cancellation_details: nil, expand: nil, invoice_now: nil, prorate: nil) ⇒ CancelParams

Returns a new instance of CancelParams.



269
270
271
272
273
274
# File 'lib/stripe/resources/subscription.rb', line 269

def initialize(cancellation_details: nil, expand: nil, invoice_now: nil, prorate: nil)
  @cancellation_details = cancellation_details
  @expand = expand
  @invoice_now = invoice_now
  @prorate = prorate
end

Instance Attribute Details

#cancellation_detailsObject

Details about why this subscription was cancelled



261
262
263
# File 'lib/stripe/resources/subscription.rb', line 261

def cancellation_details
  @cancellation_details
end

#expandObject

Specifies which fields in the response should be expanded.



263
264
265
# File 'lib/stripe/resources/subscription.rb', line 263

def expand
  @expand
end

#invoice_nowObject

Will generate a final invoice that invoices for any un-invoiced metered usage and new/pending proration invoice items. Defaults to ‘false`.



265
266
267
# File 'lib/stripe/resources/subscription.rb', line 265

def invoice_now
  @invoice_now
end

#prorateObject

Will generate a proration invoice item that credits remaining unused time until the subscription period end. Defaults to ‘false`.



267
268
269
# File 'lib/stripe/resources/subscription.rb', line 267

def prorate
  @prorate
end