Class: Stripe::Subscription::CancelParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: CancellationDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(cancellation_details: nil, expand: nil, invoice_now: nil, prorate: nil) ⇒ CancelParams

Returns a new instance of CancelParams.



319
320
321
322
323
324
# File 'lib/stripe/resources/subscription.rb', line 319

def initialize(cancellation_details: nil, expand: nil, invoice_now: nil, prorate: nil)
  @cancellation_details = cancellation_details
  @expand = expand
  @invoice_now = invoice_now
  @prorate = prorate
end

Instance Attribute Details

#cancellation_detailsObject

Details about why this subscription was cancelled



308
309
310
# File 'lib/stripe/resources/subscription.rb', line 308

def cancellation_details
  @cancellation_details
end

#expandObject

Specifies which fields in the response should be expanded.



311
312
313
# File 'lib/stripe/resources/subscription.rb', line 311

def expand
  @expand
end

#invoice_nowObject

Will generate a final invoice that invoices for any un-invoiced metered usage and new/pending proration invoice items. Defaults to ‘false`.



314
315
316
# File 'lib/stripe/resources/subscription.rb', line 314

def invoice_now
  @invoice_now
end

#prorateObject

Will generate a proration invoice item that credits remaining unused time until the subscription period end. Defaults to ‘false`.



317
318
319
# File 'lib/stripe/resources/subscription.rb', line 317

def prorate
  @prorate
end