Class: Stripe::Subscription::CancelParams::CancellationDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CancelParams::CancellationDetails
- Defined in:
- lib/stripe/resources/subscription.rb
Instance Attribute Summary collapse
-
#comment ⇒ Object
Additional comments about why the user canceled the subscription, if the subscription was canceled explicitly by the user.
-
#feedback ⇒ Object
The customer submitted reason for why they canceled, if the subscription was canceled explicitly by the user.
Instance Method Summary collapse
-
#initialize(comment: nil, feedback: nil) ⇒ CancellationDetails
constructor
A new instance of CancellationDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(comment: nil, feedback: nil) ⇒ CancellationDetails
Returns a new instance of CancellationDetails.
255 256 257 258 |
# File 'lib/stripe/resources/subscription.rb', line 255 def initialize(comment: nil, feedback: nil) @comment = comment @feedback = feedback end |
Instance Attribute Details
#comment ⇒ Object
Additional comments about why the user canceled the subscription, if the subscription was canceled explicitly by the user.
251 252 253 |
# File 'lib/stripe/resources/subscription.rb', line 251 def comment @comment end |
#feedback ⇒ Object
The customer submitted reason for why they canceled, if the subscription was canceled explicitly by the user.
253 254 255 |
# File 'lib/stripe/resources/subscription.rb', line 253 def feedback @feedback end |