Class: Stripe::Subscription::CancellationDetails

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#commentObject (readonly)

Additional comments about why the user canceled the subscription, if the subscription was canceled explicitly by the user.



103
104
105
# File 'lib/stripe/resources/subscription.rb', line 103

def comment
  @comment
end

#feedbackObject (readonly)

The customer submitted reason for why they canceled, if the subscription was canceled explicitly by the user.



105
106
107
# File 'lib/stripe/resources/subscription.rb', line 105

def feedback
  @feedback
end

#reasonObject (readonly)

Why this subscription was canceled.



107
108
109
# File 'lib/stripe/resources/subscription.rb', line 107

def reason
  @reason
end

Class Method Details

.field_remappingsObject



113
114
115
# File 'lib/stripe/resources/subscription.rb', line 113

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



109
110
111
# File 'lib/stripe/resources/subscription.rb', line 109

def self.inner_class_types
  @inner_class_types = {}
end