Class: Stripe::Subscription::CancellationDetails

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Method Summary

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#commentObject (readonly)

Additional comments about why the user canceled the subscription, if the subscription was canceled explicitly by the user.



61
62
63
# File 'lib/stripe/resources/subscription.rb', line 61

def comment
  @comment
end

#feedbackObject (readonly)

The customer submitted reason for why they canceled, if the subscription was canceled explicitly by the user.



63
64
65
# File 'lib/stripe/resources/subscription.rb', line 63

def feedback
  @feedback
end

#reasonObject (readonly)

Why this subscription was canceled.



65
66
67
# File 'lib/stripe/resources/subscription.rb', line 65

def reason
  @reason
end