Class: Stripe::Subscription::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: AddInvoiceItem, AutomaticTax, BillingCycleAnchorConfig, BillingThresholds, Discount, InvoiceSettings, Item, PaymentSettings, PendingInvoiceItemInterval, Prebilling, TransferData, TrialSettings
Instance Attribute Summary collapse
-
#add_invoice_items ⇒ Object
A list of prices and quantities that will generate invoice items appended to the next invoice for this subscription.
-
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#automatic_tax ⇒ Object
Automatic tax settings for this subscription.
-
#backdate_start_date ⇒ Object
For new subscriptions, a past timestamp to backdate the subscription’s start date to.
-
#billing_cycle_anchor ⇒ Object
A future timestamp in UTC format to anchor the subscription’s [billing cycle](stripe.com/docs/subscriptions/billing-cycle).
-
#billing_cycle_anchor_config ⇒ Object
Mutually exclusive with billing_cycle_anchor and only valid with monthly and yearly price intervals.
-
#billing_mode ⇒ Object
Controls how prorations and invoices for subscriptions are calculated and orchestrated.
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#cancel_at ⇒ Object
A timestamp at which the subscription should cancel.
-
#cancel_at_period_end ⇒ Object
Indicate whether this subscription should cancel at the end of the current period (‘current_period_end`).
-
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
The identifier of the customer to subscribe.
-
#customer_account ⇒ Object
The identifier of the account to subscribe.
-
#days_until_due ⇒ Object
Number of days a customer has to pay invoices generated by this subscription.
-
#default_payment_method ⇒ Object
ID of the default payment method for the subscription.
-
#default_source ⇒ Object
ID of the default payment source for the subscription.
-
#default_tax_rates ⇒ Object
The tax rates that will apply to any subscription item that does not have ‘tax_rates` set.
-
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
-
#items ⇒ Object
A list of up to 20 subscription items, each with an attached price.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#off_session ⇒ Object
Indicates if a customer is on or off-session while an invoice payment is attempted.
-
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the subscription’s invoices.
-
#payment_behavior ⇒ Object
Only applies to subscriptions with ‘collection_method=charge_automatically`.
-
#payment_settings ⇒ Object
Payment settings to pass to invoices created by the subscription.
-
#pending_invoice_item_interval ⇒ Object
Specifies an interval for how often to bill for any pending invoice items.
-
#prebilling ⇒ Object
If specified, the invoicing for the given billing cycle iterations will be processed now.
-
#proration_behavior ⇒ Object
Determines how to handle [prorations](stripe.com/docs/billing/subscriptions/prorations) resulting from the ‘billing_cycle_anchor`.
-
#transfer_data ⇒ Object
If specified, the funds from the subscription’s invoices will be transferred to the destination and the ID of the resulting transfers will be found on the resulting charges.
-
#trial_end ⇒ Object
Unix timestamp representing the end of the trial period the customer will get before being charged for the first time.
-
#trial_from_plan ⇒ Object
Indicates if a plan’s ‘trial_period_days` should be applied to the subscription.
-
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time.
-
#trial_settings ⇒ Object
Settings related to subscription trials.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, backdate_start_date: nil, billing_cycle_anchor: nil, billing_cycle_anchor_config: nil, billing_mode: nil, billing_thresholds: nil, cancel_at: nil, cancel_at_period_end: nil, collection_method: nil, currency: nil, customer: nil, customer_account: nil, days_until_due: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, invoice_settings: nil, items: nil, metadata: nil, off_session: nil, on_behalf_of: nil, payment_behavior: nil, payment_settings: nil, pending_invoice_item_interval: nil, prebilling: nil, proration_behavior: nil, transfer_data: nil, trial_end: nil, trial_from_plan: nil, trial_period_days: nil, trial_settings: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 1903 1904 1905 1906 1907 |
# File 'lib/stripe/resources/subscription.rb', line 1833 def initialize( add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, backdate_start_date: nil, billing_cycle_anchor: nil, billing_cycle_anchor_config: nil, billing_mode: nil, billing_thresholds: nil, cancel_at: nil, cancel_at_period_end: nil, collection_method: nil, currency: nil, customer: nil, customer_account: nil, days_until_due: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, invoice_settings: nil, items: nil, metadata: nil, off_session: nil, on_behalf_of: nil, payment_behavior: nil, payment_settings: nil, pending_invoice_item_interval: nil, prebilling: nil, proration_behavior: nil, transfer_data: nil, trial_end: nil, trial_from_plan: nil, trial_period_days: nil, trial_settings: nil ) @add_invoice_items = add_invoice_items @application_fee_percent = application_fee_percent @automatic_tax = automatic_tax @backdate_start_date = backdate_start_date @billing_cycle_anchor = billing_cycle_anchor @billing_cycle_anchor_config = billing_cycle_anchor_config @billing_mode = billing_mode @billing_thresholds = billing_thresholds @cancel_at = cancel_at @cancel_at_period_end = cancel_at_period_end @collection_method = collection_method @currency = currency @customer = customer @customer_account = customer_account @days_until_due = days_until_due @default_payment_method = default_payment_method @default_source = default_source @default_tax_rates = default_tax_rates @description = description @discounts = discounts @expand = @invoice_settings = invoice_settings @items = items @metadata = @off_session = off_session @on_behalf_of = on_behalf_of @payment_behavior = payment_behavior @payment_settings = payment_settings @pending_invoice_item_interval = pending_invoice_item_interval @prebilling = prebilling @proration_behavior = proration_behavior @transfer_data = transfer_data @trial_end = trial_end @trial_from_plan = trial_from_plan @trial_period_days = trial_period_days @trial_settings = trial_settings end |
Instance Attribute Details
#add_invoice_items ⇒ Object
A list of prices and quantities that will generate invoice items appended to the next invoice for this subscription. You may pass up to 20 items.
1751 1752 1753 |
# File 'lib/stripe/resources/subscription.rb', line 1751 def add_invoice_items @add_invoice_items end |
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees [documentation](stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).
1753 1754 1755 |
# File 'lib/stripe/resources/subscription.rb', line 1753 def application_fee_percent @application_fee_percent end |
#automatic_tax ⇒ Object
Automatic tax settings for this subscription. We recommend you only include this parameter when the existing value is being changed.
1755 1756 1757 |
# File 'lib/stripe/resources/subscription.rb', line 1755 def automatic_tax @automatic_tax end |
#backdate_start_date ⇒ Object
For new subscriptions, a past timestamp to backdate the subscription’s start date to. If set, the first invoice will contain a proration for the timespan between the start date and the current time. Can be combined with trials and the billing cycle anchor.
1757 1758 1759 |
# File 'lib/stripe/resources/subscription.rb', line 1757 def backdate_start_date @backdate_start_date end |
#billing_cycle_anchor ⇒ Object
A future timestamp in UTC format to anchor the subscription’s [billing cycle](stripe.com/docs/subscriptions/billing-cycle). The anchor is the reference point that aligns future billing cycle dates. It sets the day of week for ‘week` intervals, the day of month for `month` and `year` intervals, and the month of year for `year` intervals.
1759 1760 1761 |
# File 'lib/stripe/resources/subscription.rb', line 1759 def billing_cycle_anchor @billing_cycle_anchor end |
#billing_cycle_anchor_config ⇒ Object
Mutually exclusive with billing_cycle_anchor and only valid with monthly and yearly price intervals. When provided, the billing_cycle_anchor is set to the next occurence of the day_of_month at the hour, minute, and second UTC.
1761 1762 1763 |
# File 'lib/stripe/resources/subscription.rb', line 1761 def billing_cycle_anchor_config @billing_cycle_anchor_config end |
#billing_mode ⇒ Object
Controls how prorations and invoices for subscriptions are calculated and orchestrated.
1763 1764 1765 |
# File 'lib/stripe/resources/subscription.rb', line 1763 def billing_mode @billing_mode end |
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.
1765 1766 1767 |
# File 'lib/stripe/resources/subscription.rb', line 1765 def billing_thresholds @billing_thresholds end |
#cancel_at ⇒ Object
A timestamp at which the subscription should cancel. If set to a date before the current period ends, this will cause a proration if prorations have been enabled using ‘proration_behavior`. If set during a future period, this will always cause a proration for that period.
1767 1768 1769 |
# File 'lib/stripe/resources/subscription.rb', line 1767 def cancel_at @cancel_at end |
#cancel_at_period_end ⇒ Object
Indicate whether this subscription should cancel at the end of the current period (‘current_period_end`). Defaults to `false`. This param will be removed in a future API version. Please use `cancel_at` instead.
1769 1770 1771 |
# File 'lib/stripe/resources/subscription.rb', line 1769 def cancel_at_period_end @cancel_at_period_end end |
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay this subscription at the end of the cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically`.
1771 1772 1773 |
# File 'lib/stripe/resources/subscription.rb', line 1771 def collection_method @collection_method end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
1773 1774 1775 |
# File 'lib/stripe/resources/subscription.rb', line 1773 def currency @currency end |
#customer ⇒ Object
The identifier of the customer to subscribe.
1775 1776 1777 |
# File 'lib/stripe/resources/subscription.rb', line 1775 def customer @customer end |
#customer_account ⇒ Object
The identifier of the account to subscribe.
1777 1778 1779 |
# File 'lib/stripe/resources/subscription.rb', line 1777 def customer_account @customer_account end |
#days_until_due ⇒ Object
Number of days a customer has to pay invoices generated by this subscription. Valid only for subscriptions where ‘collection_method` is set to `send_invoice`.
1779 1780 1781 |
# File 'lib/stripe/resources/subscription.rb', line 1779 def days_until_due @days_until_due end |
#default_payment_method ⇒ Object
ID of the default payment method for the subscription. It must belong to the customer associated with the subscription. This takes precedence over ‘default_source`. If neither are set, invoices will use the customer’s [invoice_settings.default_payment_method](stripe.com/docs/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](stripe.com/docs/api/customers/object#customer_object-default_source).
1781 1782 1783 |
# File 'lib/stripe/resources/subscription.rb', line 1781 def default_payment_method @default_payment_method end |
#default_source ⇒ Object
ID of the default payment source for the subscription. It must belong to the customer associated with the subscription and be in a chargeable state. If ‘default_payment_method` is also set, `default_payment_method` will take precedence. If neither are set, invoices will use the customer’s [invoice_settings.default_payment_method](stripe.com/docs/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](stripe.com/docs/api/customers/object#customer_object-default_source).
1783 1784 1785 |
# File 'lib/stripe/resources/subscription.rb', line 1783 def default_source @default_source end |
#default_tax_rates ⇒ Object
The tax rates that will apply to any subscription item that does not have ‘tax_rates` set. Invoices created will have their `default_tax_rates` populated from the subscription.
1785 1786 1787 |
# File 'lib/stripe/resources/subscription.rb', line 1785 def default_tax_rates @default_tax_rates end |
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
1787 1788 1789 |
# File 'lib/stripe/resources/subscription.rb', line 1787 def description @description end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription. If not specified or empty, inherits the discount from the subscription’s customer.
1789 1790 1791 |
# File 'lib/stripe/resources/subscription.rb', line 1789 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1791 1792 1793 |
# File 'lib/stripe/resources/subscription.rb', line 1791 def @expand end |
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
1793 1794 1795 |
# File 'lib/stripe/resources/subscription.rb', line 1793 def invoice_settings @invoice_settings end |
#items ⇒ Object
A list of up to 20 subscription items, each with an attached price.
1795 1796 1797 |
# File 'lib/stripe/resources/subscription.rb', line 1795 def items @items end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1797 1798 1799 |
# File 'lib/stripe/resources/subscription.rb', line 1797 def @metadata end |
#off_session ⇒ Object
Indicates if a customer is on or off-session while an invoice payment is attempted. Defaults to ‘false` (on-session).
1799 1800 1801 |
# File 'lib/stripe/resources/subscription.rb', line 1799 def off_session @off_session end |
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the subscription’s invoices.
1801 1802 1803 |
# File 'lib/stripe/resources/subscription.rb', line 1801 def on_behalf_of @on_behalf_of end |
#payment_behavior ⇒ Object
Only applies to subscriptions with ‘collection_method=charge_automatically`.
Use ‘allow_incomplete` to create Subscriptions with `status=incomplete` if the first invoice can’t be paid. Creating Subscriptions with this status allows you to manage scenarios where additional customer actions are needed to pay a subscription’s invoice. For example, SCA regulation may require 3DS authentication to complete payment. See the [SCA Migration Guide](stripe.com/docs/billing/migration/strong-customer-authentication) for Billing to learn more. This is the default behavior.
Use ‘default_incomplete` to create Subscriptions with `status=incomplete` when the first invoice requires payment, otherwise start as active. Subscriptions transition to `status=active` when successfully confirming the PaymentIntent on the first invoice. This allows simpler management of scenarios where additional customer actions are needed to pay a subscription’s invoice, such as failed payments, [SCA regulation](stripe.com/docs/billing/migration/strong-customer-authentication), or collecting a mandate for a bank debit payment method. If the PaymentIntent is not confirmed within 23 hours Subscriptions transition to `status=incomplete_expired`, which is a terminal state.
Use ‘error_if_incomplete` if you want Stripe to return an HTTP 402 status code if a subscription’s first invoice can’t be paid. For example, if a payment method requires 3DS authentication due to SCA regulation and further customer action is needed, this parameter doesn’t create a Subscription and returns an error instead. This was the default behavior for API versions prior to 2019-03-14. See the [changelog](stripe.com/docs/upgrades#2019-03-14) to learn more.
‘pending_if_incomplete` is only used with updates and cannot be passed when creating a Subscription.
Subscriptions with ‘collection_method=send_invoice` are automatically activated regardless of the first Invoice status.
1813 1814 1815 |
# File 'lib/stripe/resources/subscription.rb', line 1813 def payment_behavior @payment_behavior end |
#payment_settings ⇒ Object
Payment settings to pass to invoices created by the subscription.
1815 1816 1817 |
# File 'lib/stripe/resources/subscription.rb', line 1815 def payment_settings @payment_settings end |
#pending_invoice_item_interval ⇒ Object
Specifies an interval for how often to bill for any pending invoice items. It is analogous to calling [Create an invoice](stripe.com/docs/api#create_invoice) for the given subscription at the specified interval.
1817 1818 1819 |
# File 'lib/stripe/resources/subscription.rb', line 1817 def pending_invoice_item_interval @pending_invoice_item_interval end |
#prebilling ⇒ Object
If specified, the invoicing for the given billing cycle iterations will be processed now.
1819 1820 1821 |
# File 'lib/stripe/resources/subscription.rb', line 1819 def prebilling @prebilling end |
#proration_behavior ⇒ Object
Determines how to handle [prorations](stripe.com/docs/billing/subscriptions/prorations) resulting from the ‘billing_cycle_anchor`. If no value is passed, the default is `create_prorations`.
1821 1822 1823 |
# File 'lib/stripe/resources/subscription.rb', line 1821 def proration_behavior @proration_behavior end |
#transfer_data ⇒ Object
If specified, the funds from the subscription’s invoices will be transferred to the destination and the ID of the resulting transfers will be found on the resulting charges.
1823 1824 1825 |
# File 'lib/stripe/resources/subscription.rb', line 1823 def transfer_data @transfer_data end |
#trial_end ⇒ Object
Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. If set, trial_end will override the default trial period of the plan the customer is being subscribed to. The special value ‘now` can be provided to end the customer’s trial immediately. Can be at most two years from ‘billing_cycle_anchor`. See [Using trial periods on subscriptions](stripe.com/docs/billing/subscriptions/trials) to learn more.
1825 1826 1827 |
# File 'lib/stripe/resources/subscription.rb', line 1825 def trial_end @trial_end end |
#trial_from_plan ⇒ Object
Indicates if a plan’s ‘trial_period_days` should be applied to the subscription. Setting `trial_end` per subscription is preferred, and this defaults to `false`. Setting this flag to `true` together with `trial_end` is not allowed. See [Using trial periods on subscriptions](stripe.com/docs/billing/subscriptions/trials) to learn more.
1827 1828 1829 |
# File 'lib/stripe/resources/subscription.rb', line 1827 def trial_from_plan @trial_from_plan end |
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time. This will always overwrite any trials that might apply via a subscribed plan. See [Using trial periods on subscriptions](stripe.com/docs/billing/subscriptions/trials) to learn more.
1829 1830 1831 |
# File 'lib/stripe/resources/subscription.rb', line 1829 def trial_period_days @trial_period_days end |
#trial_settings ⇒ Object
Settings related to subscription trials.
1831 1832 1833 |
# File 'lib/stripe/resources/subscription.rb', line 1831 def trial_settings @trial_settings end |