Class: Stripe::Subscription::CreateParams::AddInvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::AddInvoiceItem
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: Discount, Period, PriceData
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#period ⇒ Object
The period associated with this invoice item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates which apply to the item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
constructor
A new instance of AddInvoiceItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
Returns a new instance of AddInvoiceItem.
1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 |
# File 'lib/stripe/resources/subscription.rb', line 1370 def initialize( discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @discounts = discounts @metadata = @period = period @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
1356 1357 1358 |
# File 'lib/stripe/resources/subscription.rb', line 1356 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1358 1359 1360 |
# File 'lib/stripe/resources/subscription.rb', line 1358 def @metadata end |
#period ⇒ Object
The period associated with this invoice item. Defaults to the current period of the subscription.
1360 1361 1362 |
# File 'lib/stripe/resources/subscription.rb', line 1360 def period @period end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
1362 1363 1364 |
# File 'lib/stripe/resources/subscription.rb', line 1362 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
1364 1365 1366 |
# File 'lib/stripe/resources/subscription.rb', line 1364 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item. Defaults to 1.
1366 1367 1368 |
# File 'lib/stripe/resources/subscription.rb', line 1366 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.
1368 1369 1370 |
# File 'lib/stripe/resources/subscription.rb', line 1368 def tax_rates @tax_rates end |