Class: Stripe::Subscription::CreateParams::AddInvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::AddInvoiceItem
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: Discount, Period, PriceData
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#period ⇒ Object
The period associated with this invoice item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates which apply to the item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
constructor
A new instance of AddInvoiceItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
Returns a new instance of AddInvoiceItem.
1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 |
# File 'lib/stripe/resources/subscription.rb', line 1150 def initialize( discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @discounts = discounts @metadata = @period = period @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
1136 1137 1138 |
# File 'lib/stripe/resources/subscription.rb', line 1136 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1138 1139 1140 |
# File 'lib/stripe/resources/subscription.rb', line 1138 def @metadata end |
#period ⇒ Object
The period associated with this invoice item. Defaults to the current period of the subscription.
1140 1141 1142 |
# File 'lib/stripe/resources/subscription.rb', line 1140 def period @period end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
1142 1143 1144 |
# File 'lib/stripe/resources/subscription.rb', line 1142 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
1144 1145 1146 |
# File 'lib/stripe/resources/subscription.rb', line 1144 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item. Defaults to 1.
1146 1147 1148 |
# File 'lib/stripe/resources/subscription.rb', line 1146 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.
1148 1149 1150 |
# File 'lib/stripe/resources/subscription.rb', line 1148 def tax_rates @tax_rates end |