Class: Stripe::Subscription::CreateParams::AddInvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::AddInvoiceItem
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates which apply to the item.
Instance Method Summary collapse
-
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
constructor
A new instance of AddInvoiceItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
Returns a new instance of AddInvoiceItem.
1062 1063 1064 1065 1066 1067 1068 |
# File 'lib/stripe/resources/subscription.rb', line 1062 def initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) @discounts = discounts @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
1052 1053 1054 |
# File 'lib/stripe/resources/subscription.rb', line 1052 def discounts @discounts end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
1054 1055 1056 |
# File 'lib/stripe/resources/subscription.rb', line 1054 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
1056 1057 1058 |
# File 'lib/stripe/resources/subscription.rb', line 1056 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item. Defaults to 1.
1058 1059 1060 |
# File 'lib/stripe/resources/subscription.rb', line 1058 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.
1060 1061 1062 |
# File 'lib/stripe/resources/subscription.rb', line 1060 def tax_rates @tax_rates end |