Class: Stripe::Subscription::CreateParams::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1067
1068
1069
1070
1071
# File 'lib/stripe/resources/subscription.rb', line 1067

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1061
1062
1063
# File 'lib/stripe/resources/subscription.rb', line 1061

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1063
1064
1065
# File 'lib/stripe/resources/subscription.rb', line 1063

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1065
1066
1067
# File 'lib/stripe/resources/subscription.rb', line 1065

def promotion_code
  @promotion_code
end