Class: Stripe::Subscription::CreateParams::AddInvoiceItem::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::AddInvoiceItem::Discount
- Defined in:
- lib/stripe/resources/subscription.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1067 1068 1069 1070 1071 |
# File 'lib/stripe/resources/subscription.rb', line 1067 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1061 1062 1063 |
# File 'lib/stripe/resources/subscription.rb', line 1061 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1063 1064 1065 |
# File 'lib/stripe/resources/subscription.rb', line 1063 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1065 1066 1067 |
# File 'lib/stripe/resources/subscription.rb', line 1065 def promotion_code @promotion_code end |