Class: Stripe::Subscription::CreateParams::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1188
1189
1190
1191
1192
1193
# File 'lib/stripe/resources/subscription.rb', line 1188

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1180
1181
1182
# File 'lib/stripe/resources/subscription.rb', line 1180

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1182
1183
1184
# File 'lib/stripe/resources/subscription.rb', line 1182

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1184
1185
1186
# File 'lib/stripe/resources/subscription.rb', line 1184

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1186
1187
1188
# File 'lib/stripe/resources/subscription.rb', line 1186

def promotion_code
  @promotion_code
end