Class: Stripe::Subscription::CreateParams::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1153
1154
1155
1156
1157
1158
# File 'lib/stripe/resources/subscription.rb', line 1153

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1145
1146
1147
# File 'lib/stripe/resources/subscription.rb', line 1145

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1147
1148
1149
# File 'lib/stripe/resources/subscription.rb', line 1147

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1149
1150
1151
# File 'lib/stripe/resources/subscription.rb', line 1149

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1151
1152
1153
# File 'lib/stripe/resources/subscription.rb', line 1151

def promotion_code
  @promotion_code
end