Class: Stripe::Subscription::CreateParams::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1385
1386
1387
1388
1389
1390
# File 'lib/stripe/resources/subscription.rb', line 1385

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1374
1375
1376
# File 'lib/stripe/resources/subscription.rb', line 1374

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1377
1378
1379
# File 'lib/stripe/resources/subscription.rb', line 1377

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1380
1381
1382
# File 'lib/stripe/resources/subscription.rb', line 1380

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1383
1384
1385
# File 'lib/stripe/resources/subscription.rb', line 1383

def promotion_code
  @promotion_code
end