Class: Stripe::Subscription::CreateParams::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1138
1139
1140
1141
1142
# File 'lib/stripe/resources/subscription.rb', line 1138

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1132
1133
1134
# File 'lib/stripe/resources/subscription.rb', line 1132

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1134
1135
1136
# File 'lib/stripe/resources/subscription.rb', line 1134

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1136
1137
1138
# File 'lib/stripe/resources/subscription.rb', line 1136

def type
  @type
end