Class: Stripe::Subscription::CreateParams::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1187
1188
1189
1190
1191
# File 'lib/stripe/resources/subscription.rb', line 1187

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1181
1182
1183
# File 'lib/stripe/resources/subscription.rb', line 1181

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1183
1184
1185
# File 'lib/stripe/resources/subscription.rb', line 1183

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1185
1186
1187
# File 'lib/stripe/resources/subscription.rb', line 1185

def type
  @type
end