Class: Stripe::Subscription::CreateParams::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1367
1368
1369
1370
1371
# File 'lib/stripe/resources/subscription.rb', line 1367

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1359
1360
1361
# File 'lib/stripe/resources/subscription.rb', line 1359

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1362
1363
1364
# File 'lib/stripe/resources/subscription.rb', line 1362

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1365
1366
1367
# File 'lib/stripe/resources/subscription.rb', line 1365

def type
  @type
end