Class: Stripe::Subscription::CreateParams::AddInvoiceItem::Period::End
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::AddInvoiceItem::Period::End
- Defined in:
- lib/stripe/resources/subscription.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period.
-
#type ⇒ Object
Select how to calculate the end of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ End
constructor
A new instance of End.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ End
Returns a new instance of End.
1081 1082 1083 1084 |
# File 'lib/stripe/resources/subscription.rb', line 1081 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.
1077 1078 1079 |
# File 'lib/stripe/resources/subscription.rb', line 1077 def @timestamp end |
#type ⇒ Object
Select how to calculate the end of the invoice item period.
1079 1080 1081 |
# File 'lib/stripe/resources/subscription.rb', line 1079 def type @type end |