Class: Stripe::Subscription::CreateParams::AddInvoiceItem::Period::Start
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::AddInvoiceItem::Period::Start
- Defined in:
- lib/stripe/resources/subscription.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period.
-
#type ⇒ Object
Select how to calculate the start of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ Start
constructor
A new instance of Start.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ Start
Returns a new instance of Start.
1605 1606 1607 1608 |
# File 'lib/stripe/resources/subscription.rb', line 1605 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.
1601 1602 1603 |
# File 'lib/stripe/resources/subscription.rb', line 1601 def @timestamp end |
#type ⇒ Object
Select how to calculate the start of the invoice item period.
1603 1604 1605 |
# File 'lib/stripe/resources/subscription.rb', line 1603 def type @type end |