Class: Stripe::Subscription::CreateParams::AddInvoiceItem::Period::Start

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ Start

Returns a new instance of Start.



1093
1094
1095
1096
# File 'lib/stripe/resources/subscription.rb', line 1093

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.



1089
1090
1091
# File 'lib/stripe/resources/subscription.rb', line 1089

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the start of the invoice item period.



1091
1092
1093
# File 'lib/stripe/resources/subscription.rb', line 1091

def type
  @type
end