Class: Stripe::Subscription::CreateParams::AutomaticTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::AutomaticTax
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: Liability
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Enabled automatic tax calculation which will automatically compute tax rates on all invoices generated by the subscription.
-
#liability ⇒ Object
The account that’s liable for tax.
Instance Method Summary collapse
-
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
constructor
A new instance of AutomaticTax.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
Returns a new instance of AutomaticTax.
1186 1187 1188 1189 |
# File 'lib/stripe/resources/subscription.rb', line 1186 def initialize(enabled: nil, liability: nil) @enabled = enabled @liability = liability end |
Instance Attribute Details
#enabled ⇒ Object
Enabled automatic tax calculation which will automatically compute tax rates on all invoices generated by the subscription.
1182 1183 1184 |
# File 'lib/stripe/resources/subscription.rb', line 1182 def enabled @enabled end |
#liability ⇒ Object
The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
1184 1185 1186 |
# File 'lib/stripe/resources/subscription.rb', line 1184 def liability @liability end |