Class: Stripe::Subscription::CreateParams::BillingCycleAnchorConfig
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::BillingCycleAnchorConfig
- Defined in:
- lib/stripe/resources/subscription.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig
constructor
A new instance of BillingCycleAnchorConfig.
Methods inherited from RequestParams
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig
Returns a new instance of BillingCycleAnchorConfig.
1424 1425 1426 1427 1428 1429 1430 |
# File 'lib/stripe/resources/subscription.rb', line 1424 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
1414 1415 1416 |
# File 'lib/stripe/resources/subscription.rb', line 1414 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
1416 1417 1418 |
# File 'lib/stripe/resources/subscription.rb', line 1416 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
1418 1419 1420 |
# File 'lib/stripe/resources/subscription.rb', line 1418 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
1420 1421 1422 |
# File 'lib/stripe/resources/subscription.rb', line 1420 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
1422 1423 1424 |
# File 'lib/stripe/resources/subscription.rb', line 1422 def second @second end |