Class: Stripe::Subscription::CreateParams::BillingCycleAnchorConfig

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig

Returns a new instance of BillingCycleAnchorConfig.



1204
1205
1206
1207
1208
1209
1210
# File 'lib/stripe/resources/subscription.rb', line 1204

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



1194
1195
1196
# File 'lib/stripe/resources/subscription.rb', line 1194

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



1196
1197
1198
# File 'lib/stripe/resources/subscription.rb', line 1196

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



1198
1199
1200
# File 'lib/stripe/resources/subscription.rb', line 1198

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



1200
1201
1202
# File 'lib/stripe/resources/subscription.rb', line 1200

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



1202
1203
1204
# File 'lib/stripe/resources/subscription.rb', line 1202

def second
  @second
end