Class: Stripe::Subscription::CreateParams::BillingCycleAnchorConfig
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::BillingCycleAnchorConfig
- Defined in:
- lib/stripe/resources/subscription.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig
constructor
A new instance of BillingCycleAnchorConfig.
Methods inherited from RequestParams
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig
Returns a new instance of BillingCycleAnchorConfig.
1204 1205 1206 1207 1208 1209 1210 |
# File 'lib/stripe/resources/subscription.rb', line 1204 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
1194 1195 1196 |
# File 'lib/stripe/resources/subscription.rb', line 1194 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
1196 1197 1198 |
# File 'lib/stripe/resources/subscription.rb', line 1196 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
1198 1199 1200 |
# File 'lib/stripe/resources/subscription.rb', line 1198 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
1200 1201 1202 |
# File 'lib/stripe/resources/subscription.rb', line 1200 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
1202 1203 1204 |
# File 'lib/stripe/resources/subscription.rb', line 1202 def second @second end |