Class: Stripe::Subscription::CreateParams::BillingMode
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::BillingMode
- Defined in:
- lib/stripe/resources/subscription.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
Controls the calculation and orchestration of prorations and invoices for subscriptions.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ BillingMode
constructor
A new instance of BillingMode.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil) ⇒ BillingMode
Returns a new instance of BillingMode.
1339 1340 1341 |
# File 'lib/stripe/resources/subscription.rb', line 1339 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
Controls the calculation and orchestration of prorations and invoices for subscriptions.
1337 1338 1339 |
# File 'lib/stripe/resources/subscription.rb', line 1337 def type @type end |