Class: Stripe::Subscription::CreateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1344
1345
1346
1347
1348
1349
# File 'lib/stripe/resources/subscription.rb', line 1344

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1336
1337
1338
# File 'lib/stripe/resources/subscription.rb', line 1336

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1338
1339
1340
# File 'lib/stripe/resources/subscription.rb', line 1338

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1340
1341
1342
# File 'lib/stripe/resources/subscription.rb', line 1340

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1342
1343
1344
# File 'lib/stripe/resources/subscription.rb', line 1342

def promotion_code
  @promotion_code
end