Class: Stripe::Subscription::CreateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1333
1334
1335
1336
1337
1338
# File 'lib/stripe/resources/subscription.rb', line 1333

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1325
1326
1327
# File 'lib/stripe/resources/subscription.rb', line 1325

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1327
1328
1329
# File 'lib/stripe/resources/subscription.rb', line 1327

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1329
1330
1331
# File 'lib/stripe/resources/subscription.rb', line 1329

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1331
1332
1333
# File 'lib/stripe/resources/subscription.rb', line 1331

def promotion_code
  @promotion_code
end