Class: Stripe::Subscription::CreateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1128
1129
1130
1131
1132
# File 'lib/stripe/resources/subscription.rb', line 1128

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1122
1123
1124
# File 'lib/stripe/resources/subscription.rb', line 1122

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1124
1125
1126
# File 'lib/stripe/resources/subscription.rb', line 1124

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1126
1127
1128
# File 'lib/stripe/resources/subscription.rb', line 1126

def promotion_code
  @promotion_code
end