Class: Stripe::Subscription::CreateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1376
1377
1378
1379
1380
# File 'lib/stripe/resources/subscription.rb', line 1376

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1370
1371
1372
# File 'lib/stripe/resources/subscription.rb', line 1370

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1372
1373
1374
# File 'lib/stripe/resources/subscription.rb', line 1372

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1374
1375
1376
# File 'lib/stripe/resources/subscription.rb', line 1374

def type
  @type
end