Class: Stripe::Subscription::CreateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1329
1330
1331
1332
1333
# File 'lib/stripe/resources/subscription.rb', line 1329

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1323
1324
1325
# File 'lib/stripe/resources/subscription.rb', line 1323

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1325
1326
1327
# File 'lib/stripe/resources/subscription.rb', line 1325

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1327
1328
1329
# File 'lib/stripe/resources/subscription.rb', line 1327

def type
  @type
end