Class: Stripe::Subscription::CreateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1318
1319
1320
1321
1322
# File 'lib/stripe/resources/subscription.rb', line 1318

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1312
1313
1314
# File 'lib/stripe/resources/subscription.rb', line 1312

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1314
1315
1316
# File 'lib/stripe/resources/subscription.rb', line 1314

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1316
1317
1318
# File 'lib/stripe/resources/subscription.rb', line 1316

def type
  @type
end