Class: Stripe::Subscription::CreateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1533
1534
1535
1536
1537
# File 'lib/stripe/resources/subscription.rb', line 1533

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1525
1526
1527
# File 'lib/stripe/resources/subscription.rb', line 1525

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1528
1529
1530
# File 'lib/stripe/resources/subscription.rb', line 1528

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1531
1532
1533
# File 'lib/stripe/resources/subscription.rb', line 1531

def type
  @type
end