Class: Stripe::Subscription::CreateParams::Item

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
# File 'lib/stripe/resources/subscription.rb', line 1355

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



1339
1340
1341
# File 'lib/stripe/resources/subscription.rb', line 1339

def billing_thresholds
  @billing_thresholds
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



1341
1342
1343
# File 'lib/stripe/resources/subscription.rb', line 1341

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1343
1344
1345
# File 'lib/stripe/resources/subscription.rb', line 1343

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



1345
1346
1347
# File 'lib/stripe/resources/subscription.rb', line 1345

def plan
  @plan
end

#priceObject

The ID of the price object.



1347
1348
1349
# File 'lib/stripe/resources/subscription.rb', line 1347

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



1349
1350
1351
# File 'lib/stripe/resources/subscription.rb', line 1349

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



1351
1352
1353
# File 'lib/stripe/resources/subscription.rb', line 1351

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



1353
1354
1355
# File 'lib/stripe/resources/subscription.rb', line 1353

def tax_rates
  @tax_rates
end