Class: Stripe::Subscription::CreateParams::Item

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
1259
# File 'lib/stripe/resources/subscription.rb', line 1241

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



1225
1226
1227
# File 'lib/stripe/resources/subscription.rb', line 1225

def billing_thresholds
  @billing_thresholds
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



1227
1228
1229
# File 'lib/stripe/resources/subscription.rb', line 1227

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1229
1230
1231
# File 'lib/stripe/resources/subscription.rb', line 1229

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



1231
1232
1233
# File 'lib/stripe/resources/subscription.rb', line 1231

def plan
  @plan
end

#priceObject

The ID of the price object.



1233
1234
1235
# File 'lib/stripe/resources/subscription.rb', line 1233

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



1235
1236
1237
# File 'lib/stripe/resources/subscription.rb', line 1235

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



1237
1238
1239
# File 'lib/stripe/resources/subscription.rb', line 1237

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



1239
1240
1241
# File 'lib/stripe/resources/subscription.rb', line 1239

def tax_rates
  @tax_rates
end