Class: Stripe::Subscription::CreateParams::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::Item
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: Discount, PriceData, Trial
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#plan ⇒ Object
Plan ID for this item, as a string.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids.
-
#trial ⇒ Object
Define options to configure the trial on the subscription item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Item
Returns a new instance of Item.
1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 |
# File 'lib/stripe/resources/subscription.rb', line 1431 def initialize( discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil ) @discounts = discounts @metadata = @plan = plan @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
1415 1416 1417 |
# File 'lib/stripe/resources/subscription.rb', line 1415 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1417 1418 1419 |
# File 'lib/stripe/resources/subscription.rb', line 1417 def @metadata end |
#plan ⇒ Object
Plan ID for this item, as a string.
1419 1420 1421 |
# File 'lib/stripe/resources/subscription.rb', line 1419 def plan @plan end |
#price ⇒ Object
The ID of the price object.
1421 1422 1423 |
# File 'lib/stripe/resources/subscription.rb', line 1421 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
1423 1424 1425 |
# File 'lib/stripe/resources/subscription.rb', line 1423 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item.
1425 1426 1427 |
# File 'lib/stripe/resources/subscription.rb', line 1425 def quantity @quantity end |
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
1427 1428 1429 |
# File 'lib/stripe/resources/subscription.rb', line 1427 def tax_rates @tax_rates end |
#trial ⇒ Object
Define options to configure the trial on the subscription item.
1429 1430 1431 |
# File 'lib/stripe/resources/subscription.rb', line 1429 def trial @trial end |