Class: Stripe::Subscription::CreateParams::Item

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Item

Returns a new instance of Item.



1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
# File 'lib/stripe/resources/subscription.rb', line 1730

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.



1704
1705
1706
# File 'lib/stripe/resources/subscription.rb', line 1704

def billing_thresholds
  @billing_thresholds
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



1707
1708
1709
# File 'lib/stripe/resources/subscription.rb', line 1707

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1710
1711
1712
# File 'lib/stripe/resources/subscription.rb', line 1710

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



1713
1714
1715
# File 'lib/stripe/resources/subscription.rb', line 1713

def plan
  @plan
end

#priceObject

The ID of the price object.



1716
1717
1718
# File 'lib/stripe/resources/subscription.rb', line 1716

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



1719
1720
1721
# File 'lib/stripe/resources/subscription.rb', line 1719

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



1722
1723
1724
# File 'lib/stripe/resources/subscription.rb', line 1722

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



1725
1726
1727
# File 'lib/stripe/resources/subscription.rb', line 1725

def tax_rates
  @tax_rates
end

#trialObject

Define options to configure the trial on the subscription item.



1728
1729
1730
# File 'lib/stripe/resources/subscription.rb', line 1728

def trial
  @trial
end