Class: Stripe::Subscription::CreateParams::Item

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Item

Returns a new instance of Item.



1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
# File 'lib/stripe/resources/subscription.rb', line 1503

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.



1485
1486
1487
# File 'lib/stripe/resources/subscription.rb', line 1485

def billing_thresholds
  @billing_thresholds
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



1487
1488
1489
# File 'lib/stripe/resources/subscription.rb', line 1487

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1489
1490
1491
# File 'lib/stripe/resources/subscription.rb', line 1489

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



1491
1492
1493
# File 'lib/stripe/resources/subscription.rb', line 1491

def plan
  @plan
end

#priceObject

The ID of the price object.



1493
1494
1495
# File 'lib/stripe/resources/subscription.rb', line 1493

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



1495
1496
1497
# File 'lib/stripe/resources/subscription.rb', line 1495

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



1497
1498
1499
# File 'lib/stripe/resources/subscription.rb', line 1497

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



1499
1500
1501
# File 'lib/stripe/resources/subscription.rb', line 1499

def tax_rates
  @tax_rates
end

#trialObject

Define options to configure the trial on the subscription item.



1501
1502
1503
# File 'lib/stripe/resources/subscription.rb', line 1501

def trial
  @trial
end