Class: Stripe::Subscription::CreateParams::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1290
1291
1292
1293
1294
# File 'lib/stripe/resources/subscription.rb', line 1290

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1284
1285
1286
# File 'lib/stripe/resources/subscription.rb', line 1284

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1286
1287
1288
# File 'lib/stripe/resources/subscription.rb', line 1286

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1288
1289
1290
# File 'lib/stripe/resources/subscription.rb', line 1288

def promotion_code
  @promotion_code
end