Class: Stripe::Subscription::CreateParams::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::Item::Discount
- Defined in:
- lib/stripe/resources/subscription.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1290 1291 1292 1293 1294 |
# File 'lib/stripe/resources/subscription.rb', line 1290 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1284 1285 1286 |
# File 'lib/stripe/resources/subscription.rb', line 1284 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1286 1287 1288 |
# File 'lib/stripe/resources/subscription.rb', line 1286 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1288 1289 1290 |
# File 'lib/stripe/resources/subscription.rb', line 1288 def promotion_code @promotion_code end |