Class: Stripe::Subscription::CreateParams::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::Item::Discount
- Defined in:
- lib/stripe/resources/subscription.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1192 1193 1194 1195 1196 |
# File 'lib/stripe/resources/subscription.rb', line 1192 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1186 1187 1188 |
# File 'lib/stripe/resources/subscription.rb', line 1186 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1188 1189 1190 |
# File 'lib/stripe/resources/subscription.rb', line 1188 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1190 1191 1192 |
# File 'lib/stripe/resources/subscription.rb', line 1190 def promotion_code @promotion_code end |