Class: Stripe::Subscription::CreateParams::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1423
1424
1425
1426
1427
1428
# File 'lib/stripe/resources/subscription.rb', line 1423

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1415
1416
1417
# File 'lib/stripe/resources/subscription.rb', line 1415

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1417
1418
1419
# File 'lib/stripe/resources/subscription.rb', line 1417

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1419
1420
1421
# File 'lib/stripe/resources/subscription.rb', line 1419

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1421
1422
1423
# File 'lib/stripe/resources/subscription.rb', line 1421

def promotion_code
  @promotion_code
end