Class: Stripe::Subscription::CreateParams::Item::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::Item::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1405 1406 1407 1408 1409 |
# File 'lib/stripe/resources/subscription.rb', line 1405 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1399 1400 1401 |
# File 'lib/stripe/resources/subscription.rb', line 1399 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1401 1402 1403 |
# File 'lib/stripe/resources/subscription.rb', line 1401 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1403 1404 1405 |
# File 'lib/stripe/resources/subscription.rb', line 1403 def type @type end |