Class: Stripe::Subscription::CreateParams::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1394
1395
1396
1397
1398
# File 'lib/stripe/resources/subscription.rb', line 1394

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1388
1389
1390
# File 'lib/stripe/resources/subscription.rb', line 1388

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1390
1391
1392
# File 'lib/stripe/resources/subscription.rb', line 1390

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1392
1393
1394
# File 'lib/stripe/resources/subscription.rb', line 1392

def type
  @type
end