Class: Stripe::Subscription::CreateParams::Item::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::Item::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1338 1339 1340 1341 1342 |
# File 'lib/stripe/resources/subscription.rb', line 1338 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1332 1333 1334 |
# File 'lib/stripe/resources/subscription.rb', line 1332 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1334 1335 1336 |
# File 'lib/stripe/resources/subscription.rb', line 1334 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1336 1337 1338 |
# File 'lib/stripe/resources/subscription.rb', line 1336 def type @type end |