Class: Stripe::Subscription::CreateParams::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1408
1409
1410
1411
1412
# File 'lib/stripe/resources/subscription.rb', line 1408

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1402
1403
1404
# File 'lib/stripe/resources/subscription.rb', line 1402

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1404
1405
1406
# File 'lib/stripe/resources/subscription.rb', line 1404

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1406
1407
1408
# File 'lib/stripe/resources/subscription.rb', line 1406

def type
  @type
end