Class: Stripe::Subscription::CreateParams::Item::PriceData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::Item::PriceData
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: Recurring
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#product ⇒ Object
The ID of the [Product](docs.stripe.com/api/products) that this [Price](docs.stripe.com/api/prices) will belong to.
-
#recurring ⇒ Object
The recurring components of a price such as ‘interval` and `interval_count`.
-
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings.
-
#unit_amount ⇒ Object
A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.
-
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places.
Instance Method Summary collapse
-
#initialize(currency: nil, product: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData
constructor
A new instance of PriceData.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, product: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData
Returns a new instance of PriceData.
1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 |
# File 'lib/stripe/resources/subscription.rb', line 1453 def initialize( currency: nil, product: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil ) @currency = currency @product = product @recurring = recurring @tax_behavior = tax_behavior @unit_amount = unit_amount @unit_amount_decimal = unit_amount_decimal end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
1441 1442 1443 |
# File 'lib/stripe/resources/subscription.rb', line 1441 def currency @currency end |
#product ⇒ Object
The ID of the [Product](docs.stripe.com/api/products) that this [Price](docs.stripe.com/api/prices) will belong to.
1443 1444 1445 |
# File 'lib/stripe/resources/subscription.rb', line 1443 def product @product end |
#recurring ⇒ Object
The recurring components of a price such as ‘interval` and `interval_count`.
1445 1446 1447 |
# File 'lib/stripe/resources/subscription.rb', line 1445 def recurring @recurring end |
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.
1447 1448 1449 |
# File 'lib/stripe/resources/subscription.rb', line 1447 def tax_behavior @tax_behavior end |
#unit_amount ⇒ Object
A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.
1449 1450 1451 |
# File 'lib/stripe/resources/subscription.rb', line 1449 def unit_amount @unit_amount end |
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.
1451 1452 1453 |
# File 'lib/stripe/resources/subscription.rb', line 1451 def unit_amount_decimal @unit_amount_decimal end |