Class: Stripe::Subscription::CreateParams::PaymentSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::PaymentSettings
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: PaymentMethodOptions
Instance Attribute Summary collapse
-
#payment_method_options ⇒ Object
Payment-method-specific configuration to provide to invoices created by the subscription.
-
#payment_method_types ⇒ Object
The list of payment method types (e.g. card) to provide to the invoice’s PaymentIntent.
-
#save_default_payment_method ⇒ Object
Configure whether Stripe updates ‘subscription.default_payment_method` when payment succeeds.
Instance Method Summary collapse
-
#initialize(payment_method_options: nil, payment_method_types: nil, save_default_payment_method: nil) ⇒ PaymentSettings
constructor
A new instance of PaymentSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(payment_method_options: nil, payment_method_types: nil, save_default_payment_method: nil) ⇒ PaymentSettings
Returns a new instance of PaymentSettings.
1687 1688 1689 1690 1691 1692 1693 1694 1695 |
# File 'lib/stripe/resources/subscription.rb', line 1687 def initialize( payment_method_options: nil, payment_method_types: nil, save_default_payment_method: nil ) @payment_method_options = @payment_method_types = payment_method_types @save_default_payment_method = save_default_payment_method end |
Instance Attribute Details
#payment_method_options ⇒ Object
Payment-method-specific configuration to provide to invoices created by the subscription.
1681 1682 1683 |
# File 'lib/stripe/resources/subscription.rb', line 1681 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types (e.g. card) to provide to the invoice’s PaymentIntent. If not set, Stripe attempts to automatically determine the types to use by looking at the invoice’s default payment method, the subscription’s default payment method, the customer’s default payment method, and your [invoice template settings](dashboard.stripe.com/settings/billing/invoice). Should not be specified with payment_method_configuration
1683 1684 1685 |
# File 'lib/stripe/resources/subscription.rb', line 1683 def payment_method_types @payment_method_types end |
#save_default_payment_method ⇒ Object
Configure whether Stripe updates ‘subscription.default_payment_method` when payment succeeds. Defaults to `off` if unspecified.
1685 1686 1687 |
# File 'lib/stripe/resources/subscription.rb', line 1685 def save_default_payment_method @save_default_payment_method end |