Class: Stripe::Subscription::CreateParams::PaymentSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: PaymentMethodOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(payment_method_options: nil, payment_method_types: nil, save_default_payment_method: nil) ⇒ PaymentSettings

Returns a new instance of PaymentSettings.



1706
1707
1708
1709
1710
1711
1712
1713
1714
# File 'lib/stripe/resources/subscription.rb', line 1706

def initialize(
  payment_method_options: nil,
  payment_method_types: nil,
  save_default_payment_method: nil
)
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @save_default_payment_method = save_default_payment_method
end

Instance Attribute Details

#payment_method_optionsObject

Payment-method-specific configuration to provide to invoices created by the subscription.



1700
1701
1702
# File 'lib/stripe/resources/subscription.rb', line 1700

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (e.g. card) to provide to the invoice’s PaymentIntent. If not set, Stripe attempts to automatically determine the types to use by looking at the invoice’s default payment method, the subscription’s default payment method, the customer’s default payment method, and your [invoice template settings](dashboard.stripe.com/settings/billing/invoice). Should not be specified with payment_method_configuration



1702
1703
1704
# File 'lib/stripe/resources/subscription.rb', line 1702

def payment_method_types
  @payment_method_types
end

#save_default_payment_methodObject

Configure whether Stripe updates ‘subscription.default_payment_method` when payment succeeds. Defaults to `off` if unspecified.



1704
1705
1706
# File 'lib/stripe/resources/subscription.rb', line 1704

def save_default_payment_method
  @save_default_payment_method
end