Class: Stripe::Subscription::CreateParams::PaymentSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::PaymentSettings
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: PaymentMethodOptions
Instance Attribute Summary collapse
-
#payment_method_options ⇒ Object
Payment-method-specific configuration to provide to invoices created by the subscription.
-
#payment_method_types ⇒ Object
The list of payment method types (e.g. card) to provide to the invoice’s PaymentIntent.
-
#save_default_payment_method ⇒ Object
Configure whether Stripe updates ‘subscription.default_payment_method` when payment succeeds.
Instance Method Summary collapse
-
#initialize(payment_method_options: nil, payment_method_types: nil, save_default_payment_method: nil) ⇒ PaymentSettings
constructor
A new instance of PaymentSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(payment_method_options: nil, payment_method_types: nil, save_default_payment_method: nil) ⇒ PaymentSettings
Returns a new instance of PaymentSettings.
1953 1954 1955 1956 1957 1958 1959 1960 1961 |
# File 'lib/stripe/resources/subscription.rb', line 1953 def initialize( payment_method_options: nil, payment_method_types: nil, save_default_payment_method: nil ) @payment_method_options = @payment_method_types = payment_method_types @save_default_payment_method = save_default_payment_method end |
Instance Attribute Details
#payment_method_options ⇒ Object
Payment-method-specific configuration to provide to invoices created by the subscription.
1945 1946 1947 |
# File 'lib/stripe/resources/subscription.rb', line 1945 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types (e.g. card) to provide to the invoice’s PaymentIntent. If not set, Stripe attempts to automatically determine the types to use by looking at the invoice’s default payment method, the subscription’s default payment method, the customer’s default payment method, and your [invoice template settings](dashboard.stripe.com/settings/billing/invoice). Should not be specified with payment_method_configuration
1948 1949 1950 |
# File 'lib/stripe/resources/subscription.rb', line 1948 def payment_method_types @payment_method_types end |
#save_default_payment_method ⇒ Object
Configure whether Stripe updates ‘subscription.default_payment_method` when payment succeeds. Defaults to `off` if unspecified.
1951 1952 1953 |
# File 'lib/stripe/resources/subscription.rb', line 1951 def save_default_payment_method @save_default_payment_method end |