Class: Stripe::Subscription::CreateParams::PaymentSettings::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::PaymentSettings::PaymentMethodOptions
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: AcssDebit, Bancontact, Card, CustomerBalance, IdBankTransfer, Konbini, SepaDebit, UsBankAccount
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
-
#bancontact ⇒ Object
This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
-
#card ⇒ Object
This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
-
#customer_balance ⇒ Object
This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
-
#id_bank_transfer ⇒ Object
This sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.
-
#konbini ⇒ Object
This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
-
#sepa_debit ⇒ Object
This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
-
#us_bank_account ⇒ Object
This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, sepa_debit: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, sepa_debit: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 1696 1697 |
# File 'lib/stripe/resources/subscription.rb', line 1679 def initialize( acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, sepa_debit: nil, us_bank_account: nil ) @acss_debit = acss_debit @bancontact = bancontact @card = card @customer_balance = customer_balance @id_bank_transfer = id_bank_transfer @konbini = konbini @sepa_debit = sepa_debit @us_bank_account = us_bank_account end |
Instance Attribute Details
#acss_debit ⇒ Object
This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
1663 1664 1665 |
# File 'lib/stripe/resources/subscription.rb', line 1663 def acss_debit @acss_debit end |
#bancontact ⇒ Object
This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
1665 1666 1667 |
# File 'lib/stripe/resources/subscription.rb', line 1665 def bancontact @bancontact end |
#card ⇒ Object
This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
1667 1668 1669 |
# File 'lib/stripe/resources/subscription.rb', line 1667 def card @card end |
#customer_balance ⇒ Object
This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
1669 1670 1671 |
# File 'lib/stripe/resources/subscription.rb', line 1669 def customer_balance @customer_balance end |
#id_bank_transfer ⇒ Object
This sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.
1671 1672 1673 |
# File 'lib/stripe/resources/subscription.rb', line 1671 def id_bank_transfer @id_bank_transfer end |
#konbini ⇒ Object
This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
1673 1674 1675 |
# File 'lib/stripe/resources/subscription.rb', line 1673 def konbini @konbini end |
#sepa_debit ⇒ Object
This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
1675 1676 1677 |
# File 'lib/stripe/resources/subscription.rb', line 1675 def sepa_debit @sepa_debit end |
#us_bank_account ⇒ Object
This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
1677 1678 1679 |
# File 'lib/stripe/resources/subscription.rb', line 1677 def us_bank_account @us_bank_account end |