Class: Stripe::Subscription::CreateParams::PaymentSettings::PaymentMethodOptions::CustomerBalance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::PaymentSettings::PaymentMethodOptions::CustomerBalance
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: BankTransfer
Instance Attribute Summary collapse
-
#bank_transfer ⇒ Object
Configuration for the bank transfer funding type, if the ‘funding_type` is set to `bank_transfer`.
-
#funding_type ⇒ Object
The funding method type to be used when there are not enough funds in the customer balance.
Instance Method Summary collapse
-
#initialize(bank_transfer: nil, funding_type: nil) ⇒ CustomerBalance
constructor
A new instance of CustomerBalance.
Methods inherited from RequestParams
Constructor Details
#initialize(bank_transfer: nil, funding_type: nil) ⇒ CustomerBalance
Returns a new instance of CustomerBalance.
1290 1291 1292 1293 |
# File 'lib/stripe/resources/subscription.rb', line 1290 def initialize(bank_transfer: nil, funding_type: nil) @bank_transfer = bank_transfer @funding_type = funding_type end |
Instance Attribute Details
#bank_transfer ⇒ Object
Configuration for the bank transfer funding type, if the ‘funding_type` is set to `bank_transfer`.
1286 1287 1288 |
# File 'lib/stripe/resources/subscription.rb', line 1286 def bank_transfer @bank_transfer end |
#funding_type ⇒ Object
The funding method type to be used when there are not enough funds in the customer balance. Permitted values include: ‘bank_transfer`.
1288 1289 1290 |
# File 'lib/stripe/resources/subscription.rb', line 1288 def funding_type @funding_type end |