Class: Stripe::Subscription::CreateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1572
1573
1574
1575
# File 'lib/stripe/resources/subscription.rb', line 1572

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



1568
1569
1570
# File 'lib/stripe/resources/subscription.rb', line 1568

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



1570
1571
1572
# File 'lib/stripe/resources/subscription.rb', line 1570

def destination
  @destination
end