Class: Stripe::Subscription::CreateParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::CreateParams::TransferData
- Defined in:
- lib/stripe/resources/subscription.rb
Instance Attribute Summary collapse
-
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
1816 1817 1818 1819 |
# File 'lib/stripe/resources/subscription.rb', line 1816 def initialize(amount_percent: nil, destination: nil) @amount_percent = amount_percent @destination = destination end |
Instance Attribute Details
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.
1812 1813 1814 |
# File 'lib/stripe/resources/subscription.rb', line 1812 def amount_percent @amount_percent end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
1814 1815 1816 |
# File 'lib/stripe/resources/subscription.rb', line 1814 def destination @destination end |