Class: Stripe::Subscription::CreateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1474
1475
1476
1477
# File 'lib/stripe/resources/subscription.rb', line 1474

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



1470
1471
1472
# File 'lib/stripe/resources/subscription.rb', line 1470

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



1472
1473
1474
# File 'lib/stripe/resources/subscription.rb', line 1472

def destination
  @destination
end