Class: Stripe::Subscription::CreateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1458
1459
1460
1461
# File 'lib/stripe/resources/subscription.rb', line 1458

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



1454
1455
1456
# File 'lib/stripe/resources/subscription.rb', line 1454

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



1456
1457
1458
# File 'lib/stripe/resources/subscription.rb', line 1456

def destination
  @destination
end