Class: Stripe::Subscription::CreateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1997
1998
1999
2000
# File 'lib/stripe/resources/subscription.rb', line 1997

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



1992
1993
1994
# File 'lib/stripe/resources/subscription.rb', line 1992

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



1995
1996
1997
# File 'lib/stripe/resources/subscription.rb', line 1995

def destination
  @destination
end