Class: Stripe::Subscription::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::ListParams
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: AutomaticTax, Created, CurrentPeriodEnd, CurrentPeriodStart
Instance Attribute Summary collapse
-
#automatic_tax ⇒ Object
Filter subscriptions by their automatic tax settings.
-
#collection_method ⇒ Object
The collection method of the subscriptions to retrieve.
-
#created ⇒ Object
Only return subscriptions that were created during the given date interval.
-
#current_period_end ⇒ Object
Only return subscriptions whose minimum item current_period_end falls within the given date interval.
-
#current_period_start ⇒ Object
Only return subscriptions whose maximum item current_period_start falls within the given date interval.
-
#customer ⇒ Object
The ID of the customer whose subscriptions will be retrieved.
-
#customer_account ⇒ Object
The ID of the account whose subscriptions will be retrieved.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#plan ⇒ Object
The ID of the plan whose subscriptions will be retrieved.
-
#price ⇒ Object
Filter for subscriptions that contain this recurring price ID.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
The status of the subscriptions to retrieve.
-
#test_clock ⇒ Object
Filter for subscriptions that are associated with the specified test clock.
Instance Method Summary collapse
-
#initialize(automatic_tax: nil, collection_method: nil, created: nil, current_period_end: nil, current_period_start: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, plan: nil, price: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(automatic_tax: nil, collection_method: nil, created: nil, current_period_end: nil, current_period_start: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, plan: nil, price: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams
Returns a new instance of ListParams.
1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 |
# File 'lib/stripe/resources/subscription.rb', line 1214 def initialize( automatic_tax: nil, collection_method: nil, created: nil, current_period_end: nil, current_period_start: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, plan: nil, price: nil, starting_after: nil, status: nil, test_clock: nil ) @automatic_tax = automatic_tax @collection_method = collection_method @created = created @current_period_end = current_period_end @current_period_start = current_period_start @customer = customer @customer_account = customer_account @ending_before = ending_before @expand = @limit = limit @plan = plan @price = price @starting_after = starting_after @status = status @test_clock = test_clock end |
Instance Attribute Details
#automatic_tax ⇒ Object
Filter subscriptions by their automatic tax settings.
1184 1185 1186 |
# File 'lib/stripe/resources/subscription.rb', line 1184 def automatic_tax @automatic_tax end |
#collection_method ⇒ Object
The collection method of the subscriptions to retrieve. Either ‘charge_automatically` or `send_invoice`.
1186 1187 1188 |
# File 'lib/stripe/resources/subscription.rb', line 1186 def collection_method @collection_method end |
#created ⇒ Object
Only return subscriptions that were created during the given date interval.
1188 1189 1190 |
# File 'lib/stripe/resources/subscription.rb', line 1188 def created @created end |
#current_period_end ⇒ Object
Only return subscriptions whose minimum item current_period_end falls within the given date interval.
1190 1191 1192 |
# File 'lib/stripe/resources/subscription.rb', line 1190 def current_period_end @current_period_end end |
#current_period_start ⇒ Object
Only return subscriptions whose maximum item current_period_start falls within the given date interval.
1192 1193 1194 |
# File 'lib/stripe/resources/subscription.rb', line 1192 def current_period_start @current_period_start end |
#customer ⇒ Object
The ID of the customer whose subscriptions will be retrieved.
1194 1195 1196 |
# File 'lib/stripe/resources/subscription.rb', line 1194 def customer @customer end |
#customer_account ⇒ Object
The ID of the account whose subscriptions will be retrieved.
1196 1197 1198 |
# File 'lib/stripe/resources/subscription.rb', line 1196 def customer_account @customer_account end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
1198 1199 1200 |
# File 'lib/stripe/resources/subscription.rb', line 1198 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1200 1201 1202 |
# File 'lib/stripe/resources/subscription.rb', line 1200 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1202 1203 1204 |
# File 'lib/stripe/resources/subscription.rb', line 1202 def limit @limit end |
#plan ⇒ Object
The ID of the plan whose subscriptions will be retrieved.
1204 1205 1206 |
# File 'lib/stripe/resources/subscription.rb', line 1204 def plan @plan end |
#price ⇒ Object
Filter for subscriptions that contain this recurring price ID.
1206 1207 1208 |
# File 'lib/stripe/resources/subscription.rb', line 1206 def price @price end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
1208 1209 1210 |
# File 'lib/stripe/resources/subscription.rb', line 1208 def starting_after @starting_after end |
#status ⇒ Object
The status of the subscriptions to retrieve. Passing in a value of ‘canceled` will return all canceled subscriptions, including those belonging to deleted customers. Pass `ended` to find subscriptions that are canceled and subscriptions that are expired due to [incomplete payment](stripe.com/docs/billing/subscriptions/overview#subscription-statuses). Passing in a value of `all` will return subscriptions of all statuses. If no value is supplied, all subscriptions that have not been canceled are returned.
1210 1211 1212 |
# File 'lib/stripe/resources/subscription.rb', line 1210 def status @status end |
#test_clock ⇒ Object
Filter for subscriptions that are associated with the specified test clock. The response will not include subscriptions with test clocks if this and the customer parameter is not set.
1212 1213 1214 |
# File 'lib/stripe/resources/subscription.rb', line 1212 def test_clock @test_clock end |