Class: Stripe::Subscription::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: AutomaticTax, Created, CurrentPeriodEnd, CurrentPeriodStart

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_tax: nil, collection_method: nil, created: nil, current_period_end: nil, current_period_start: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, plan: nil, price: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams

Returns a new instance of ListParams.



1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
# File 'lib/stripe/resources/subscription.rb', line 1024

def initialize(
  automatic_tax: nil,
  collection_method: nil,
  created: nil,
  current_period_end: nil,
  current_period_start: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  plan: nil,
  price: nil,
  starting_after: nil,
  status: nil,
  test_clock: nil
)
  @automatic_tax = automatic_tax
  @collection_method = collection_method
  @created = created
  @current_period_end = current_period_end
  @current_period_start = current_period_start
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @plan = plan
  @price = price
  @starting_after = starting_after
  @status = status
  @test_clock = test_clock
end

Instance Attribute Details

#automatic_taxObject

Filter subscriptions by their automatic tax settings.



996
997
998
# File 'lib/stripe/resources/subscription.rb', line 996

def automatic_tax
  @automatic_tax
end

#collection_methodObject

The collection method of the subscriptions to retrieve. Either ‘charge_automatically` or `send_invoice`.



998
999
1000
# File 'lib/stripe/resources/subscription.rb', line 998

def collection_method
  @collection_method
end

#createdObject

Only return subscriptions that were created during the given date interval.



1000
1001
1002
# File 'lib/stripe/resources/subscription.rb', line 1000

def created
  @created
end

#current_period_endObject

Only return subscriptions whose minimum item current_period_end falls within the given date interval.



1002
1003
1004
# File 'lib/stripe/resources/subscription.rb', line 1002

def current_period_end
  @current_period_end
end

#current_period_startObject

Only return subscriptions whose maximum item current_period_start falls within the given date interval.



1004
1005
1006
# File 'lib/stripe/resources/subscription.rb', line 1004

def current_period_start
  @current_period_start
end

#customerObject

The ID of the customer whose subscriptions will be retrieved.



1006
1007
1008
# File 'lib/stripe/resources/subscription.rb', line 1006

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



1008
1009
1010
# File 'lib/stripe/resources/subscription.rb', line 1008

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



1010
1011
1012
# File 'lib/stripe/resources/subscription.rb', line 1010

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1012
1013
1014
# File 'lib/stripe/resources/subscription.rb', line 1012

def limit
  @limit
end

#planObject

The ID of the plan whose subscriptions will be retrieved.



1014
1015
1016
# File 'lib/stripe/resources/subscription.rb', line 1014

def plan
  @plan
end

#priceObject

Filter for subscriptions that contain this recurring price ID.



1016
1017
1018
# File 'lib/stripe/resources/subscription.rb', line 1016

def price
  @price
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



1018
1019
1020
# File 'lib/stripe/resources/subscription.rb', line 1018

def starting_after
  @starting_after
end

#statusObject

The status of the subscriptions to retrieve. Passing in a value of ‘canceled` will return all canceled subscriptions, including those belonging to deleted customers. Pass `ended` to find subscriptions that are canceled and subscriptions that are expired due to [incomplete payment](stripe.com/docs/billing/subscriptions/overview#subscription-statuses). Passing in a value of `all` will return subscriptions of all statuses. If no value is supplied, all subscriptions that have not been canceled are returned.



1020
1021
1022
# File 'lib/stripe/resources/subscription.rb', line 1020

def status
  @status
end

#test_clockObject

Filter for subscriptions that are associated with the specified test clock. The response will not include subscriptions with test clocks if this and the customer parameter is not set.



1022
1023
1024
# File 'lib/stripe/resources/subscription.rb', line 1022

def test_clock
  @test_clock
end