Class: Stripe::Subscription::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: AutomaticTax, Created, CurrentPeriodEnd, CurrentPeriodStart

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_tax: nil, collection_method: nil, created: nil, current_period_end: nil, current_period_start: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, plan: nil, price: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams

Returns a new instance of ListParams.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
# File 'lib/stripe/resources/subscription.rb', line 1165

def initialize(
  automatic_tax: nil,
  collection_method: nil,
  created: nil,
  current_period_end: nil,
  current_period_start: nil,
  customer: nil,
  customer_account: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  plan: nil,
  price: nil,
  starting_after: nil,
  status: nil,
  test_clock: nil
)
  @automatic_tax = automatic_tax
  @collection_method = collection_method
  @created = created
  @current_period_end = current_period_end
  @current_period_start = current_period_start
  @customer = customer
  @customer_account = 
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @plan = plan
  @price = price
  @starting_after = starting_after
  @status = status
  @test_clock = test_clock
end

Instance Attribute Details

#automatic_taxObject

Filter subscriptions by their automatic tax settings.



1135
1136
1137
# File 'lib/stripe/resources/subscription.rb', line 1135

def automatic_tax
  @automatic_tax
end

#collection_methodObject

The collection method of the subscriptions to retrieve. Either ‘charge_automatically` or `send_invoice`.



1137
1138
1139
# File 'lib/stripe/resources/subscription.rb', line 1137

def collection_method
  @collection_method
end

#createdObject

Only return subscriptions that were created during the given date interval.



1139
1140
1141
# File 'lib/stripe/resources/subscription.rb', line 1139

def created
  @created
end

#current_period_endObject

Only return subscriptions whose current_period_end falls within the given date interval.



1141
1142
1143
# File 'lib/stripe/resources/subscription.rb', line 1141

def current_period_end
  @current_period_end
end

#current_period_startObject

Only return subscriptions whose current_period_start falls within the given date interval.



1143
1144
1145
# File 'lib/stripe/resources/subscription.rb', line 1143

def current_period_start
  @current_period_start
end

#customerObject

The ID of the customer whose subscriptions will be retrieved.



1145
1146
1147
# File 'lib/stripe/resources/subscription.rb', line 1145

def customer
  @customer
end

#customer_accountObject

The ID of the account whose subscriptions will be retrieved.



1147
1148
1149
# File 'lib/stripe/resources/subscription.rb', line 1147

def 
  @customer_account
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



1149
1150
1151
# File 'lib/stripe/resources/subscription.rb', line 1149

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



1151
1152
1153
# File 'lib/stripe/resources/subscription.rb', line 1151

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1153
1154
1155
# File 'lib/stripe/resources/subscription.rb', line 1153

def limit
  @limit
end

#planObject

The ID of the plan whose subscriptions will be retrieved.



1155
1156
1157
# File 'lib/stripe/resources/subscription.rb', line 1155

def plan
  @plan
end

#priceObject

Filter for subscriptions that contain this recurring price ID.



1157
1158
1159
# File 'lib/stripe/resources/subscription.rb', line 1157

def price
  @price
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



1159
1160
1161
# File 'lib/stripe/resources/subscription.rb', line 1159

def starting_after
  @starting_after
end

#statusObject

The status of the subscriptions to retrieve. Passing in a value of ‘canceled` will return all canceled subscriptions, including those belonging to deleted customers. Pass `ended` to find subscriptions that are canceled and subscriptions that are expired due to [incomplete payment](stripe.com/docs/billing/subscriptions/overview#subscription-statuses). Passing in a value of `all` will return subscriptions of all statuses. If no value is supplied, all subscriptions that have not been canceled are returned.



1161
1162
1163
# File 'lib/stripe/resources/subscription.rb', line 1161

def status
  @status
end

#test_clockObject

Filter for subscriptions that are associated with the specified test clock. The response will not include subscriptions with test clocks if this and the customer parameter is not set.



1163
1164
1165
# File 'lib/stripe/resources/subscription.rb', line 1163

def test_clock
  @test_clock
end