Class: Stripe::Subscription::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::ListParams
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: AutomaticTax, Created, CurrentPeriodEnd, CurrentPeriodStart
Instance Attribute Summary collapse
-
#automatic_tax ⇒ Object
Filter subscriptions by their automatic tax settings.
-
#collection_method ⇒ Object
The collection method of the subscriptions to retrieve.
-
#created ⇒ Object
Only return subscriptions that were created during the given date interval.
-
#current_period_end ⇒ Object
Only return subscriptions whose current_period_end falls within the given date interval.
-
#current_period_start ⇒ Object
Only return subscriptions whose current_period_start falls within the given date interval.
-
#customer ⇒ Object
The ID of the customer whose subscriptions will be retrieved.
-
#customer_account ⇒ Object
The ID of the account whose subscriptions will be retrieved.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#plan ⇒ Object
The ID of the plan whose subscriptions will be retrieved.
-
#price ⇒ Object
Filter for subscriptions that contain this recurring price ID.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
The status of the subscriptions to retrieve.
-
#test_clock ⇒ Object
Filter for subscriptions that are associated with the specified test clock.
Instance Method Summary collapse
-
#initialize(automatic_tax: nil, collection_method: nil, created: nil, current_period_end: nil, current_period_start: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, plan: nil, price: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(automatic_tax: nil, collection_method: nil, created: nil, current_period_end: nil, current_period_start: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, plan: nil, price: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams
Returns a new instance of ListParams.
1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 |
# File 'lib/stripe/resources/subscription.rb', line 1118 def initialize( automatic_tax: nil, collection_method: nil, created: nil, current_period_end: nil, current_period_start: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, plan: nil, price: nil, starting_after: nil, status: nil, test_clock: nil ) @automatic_tax = automatic_tax @collection_method = collection_method @created = created @current_period_end = current_period_end @current_period_start = current_period_start @customer = customer @customer_account = customer_account @ending_before = ending_before @expand = @limit = limit @plan = plan @price = price @starting_after = starting_after @status = status @test_clock = test_clock end |
Instance Attribute Details
#automatic_tax ⇒ Object
Filter subscriptions by their automatic tax settings.
1088 1089 1090 |
# File 'lib/stripe/resources/subscription.rb', line 1088 def automatic_tax @automatic_tax end |
#collection_method ⇒ Object
The collection method of the subscriptions to retrieve. Either ‘charge_automatically` or `send_invoice`.
1090 1091 1092 |
# File 'lib/stripe/resources/subscription.rb', line 1090 def collection_method @collection_method end |
#created ⇒ Object
Only return subscriptions that were created during the given date interval.
1092 1093 1094 |
# File 'lib/stripe/resources/subscription.rb', line 1092 def created @created end |
#current_period_end ⇒ Object
Only return subscriptions whose current_period_end falls within the given date interval.
1094 1095 1096 |
# File 'lib/stripe/resources/subscription.rb', line 1094 def current_period_end @current_period_end end |
#current_period_start ⇒ Object
Only return subscriptions whose current_period_start falls within the given date interval.
1096 1097 1098 |
# File 'lib/stripe/resources/subscription.rb', line 1096 def current_period_start @current_period_start end |
#customer ⇒ Object
The ID of the customer whose subscriptions will be retrieved.
1098 1099 1100 |
# File 'lib/stripe/resources/subscription.rb', line 1098 def customer @customer end |
#customer_account ⇒ Object
The ID of the account whose subscriptions will be retrieved.
1100 1101 1102 |
# File 'lib/stripe/resources/subscription.rb', line 1100 def customer_account @customer_account end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
1102 1103 1104 |
# File 'lib/stripe/resources/subscription.rb', line 1102 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1104 1105 1106 |
# File 'lib/stripe/resources/subscription.rb', line 1104 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1106 1107 1108 |
# File 'lib/stripe/resources/subscription.rb', line 1106 def limit @limit end |
#plan ⇒ Object
The ID of the plan whose subscriptions will be retrieved.
1108 1109 1110 |
# File 'lib/stripe/resources/subscription.rb', line 1108 def plan @plan end |
#price ⇒ Object
Filter for subscriptions that contain this recurring price ID.
1110 1111 1112 |
# File 'lib/stripe/resources/subscription.rb', line 1110 def price @price end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
1112 1113 1114 |
# File 'lib/stripe/resources/subscription.rb', line 1112 def starting_after @starting_after end |
#status ⇒ Object
The status of the subscriptions to retrieve. Passing in a value of ‘canceled` will return all canceled subscriptions, including those belonging to deleted customers. Pass `ended` to find subscriptions that are canceled and subscriptions that are expired due to [incomplete payment](stripe.com/docs/billing/subscriptions/overview#subscription-statuses). Passing in a value of `all` will return subscriptions of all statuses. If no value is supplied, all subscriptions that have not been canceled are returned.
1114 1115 1116 |
# File 'lib/stripe/resources/subscription.rb', line 1114 def status @status end |
#test_clock ⇒ Object
Filter for subscriptions that are associated with the specified test clock. The response will not include subscriptions with test clocks if this and the customer parameter is not set.
1116 1117 1118 |
# File 'lib/stripe/resources/subscription.rb', line 1116 def test_clock @test_clock end |