Class: Stripe::Subscription::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: AutomaticTax, Created, CurrentPeriodEnd, CurrentPeriodStart

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_tax: nil, collection_method: nil, created: nil, current_period_end: nil, current_period_start: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, plan: nil, price: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams

Returns a new instance of ListParams.



1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
# File 'lib/stripe/resources/subscription.rb', line 1081

def initialize(
  automatic_tax: nil,
  collection_method: nil,
  created: nil,
  current_period_end: nil,
  current_period_start: nil,
  customer: nil,
  customer_account: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  plan: nil,
  price: nil,
  starting_after: nil,
  status: nil,
  test_clock: nil
)
  @automatic_tax = automatic_tax
  @collection_method = collection_method
  @created = created
  @current_period_end = current_period_end
  @current_period_start = current_period_start
  @customer = customer
  @customer_account = 
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @plan = plan
  @price = price
  @starting_after = starting_after
  @status = status
  @test_clock = test_clock
end

Instance Attribute Details

#automatic_taxObject

Filter subscriptions by their automatic tax settings.



1051
1052
1053
# File 'lib/stripe/resources/subscription.rb', line 1051

def automatic_tax
  @automatic_tax
end

#collection_methodObject

The collection method of the subscriptions to retrieve. Either ‘charge_automatically` or `send_invoice`.



1053
1054
1055
# File 'lib/stripe/resources/subscription.rb', line 1053

def collection_method
  @collection_method
end

#createdObject

Only return subscriptions that were created during the given date interval.



1055
1056
1057
# File 'lib/stripe/resources/subscription.rb', line 1055

def created
  @created
end

#current_period_endObject

Only return subscriptions whose current_period_end falls within the given date interval.



1057
1058
1059
# File 'lib/stripe/resources/subscription.rb', line 1057

def current_period_end
  @current_period_end
end

#current_period_startObject

Only return subscriptions whose current_period_start falls within the given date interval.



1059
1060
1061
# File 'lib/stripe/resources/subscription.rb', line 1059

def current_period_start
  @current_period_start
end

#customerObject

The ID of the customer whose subscriptions will be retrieved.



1061
1062
1063
# File 'lib/stripe/resources/subscription.rb', line 1061

def customer
  @customer
end

#customer_accountObject

The ID of the account whose subscriptions will be retrieved.



1063
1064
1065
# File 'lib/stripe/resources/subscription.rb', line 1063

def 
  @customer_account
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



1065
1066
1067
# File 'lib/stripe/resources/subscription.rb', line 1065

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



1067
1068
1069
# File 'lib/stripe/resources/subscription.rb', line 1067

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1069
1070
1071
# File 'lib/stripe/resources/subscription.rb', line 1069

def limit
  @limit
end

#planObject

The ID of the plan whose subscriptions will be retrieved.



1071
1072
1073
# File 'lib/stripe/resources/subscription.rb', line 1071

def plan
  @plan
end

#priceObject

Filter for subscriptions that contain this recurring price ID.



1073
1074
1075
# File 'lib/stripe/resources/subscription.rb', line 1073

def price
  @price
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



1075
1076
1077
# File 'lib/stripe/resources/subscription.rb', line 1075

def starting_after
  @starting_after
end

#statusObject

The status of the subscriptions to retrieve. Passing in a value of ‘canceled` will return all canceled subscriptions, including those belonging to deleted customers. Pass `ended` to find subscriptions that are canceled and subscriptions that are expired due to [incomplete payment](stripe.com/docs/billing/subscriptions/overview#subscription-statuses). Passing in a value of `all` will return subscriptions of all statuses. If no value is supplied, all subscriptions that have not been canceled are returned.



1077
1078
1079
# File 'lib/stripe/resources/subscription.rb', line 1077

def status
  @status
end

#test_clockObject

Filter for subscriptions that are associated with the specified test clock. The response will not include subscriptions with test clocks if this and the customer parameter is not set.



1079
1080
1081
# File 'lib/stripe/resources/subscription.rb', line 1079

def test_clock
  @test_clock
end