Class: Stripe::Subscription::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: AutomaticTax, Created, CurrentPeriodEnd, CurrentPeriodStart

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_tax: nil, collection_method: nil, created: nil, current_period_end: nil, current_period_start: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, plan: nil, price: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams

Returns a new instance of ListParams.



936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
# File 'lib/stripe/resources/subscription.rb', line 936

def initialize(
  automatic_tax: nil,
  collection_method: nil,
  created: nil,
  current_period_end: nil,
  current_period_start: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  plan: nil,
  price: nil,
  starting_after: nil,
  status: nil,
  test_clock: nil
)
  @automatic_tax = automatic_tax
  @collection_method = collection_method
  @created = created
  @current_period_end = current_period_end
  @current_period_start = current_period_start
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @plan = plan
  @price = price
  @starting_after = starting_after
  @status = status
  @test_clock = test_clock
end

Instance Attribute Details

#automatic_taxObject

Filter subscriptions by their automatic tax settings.



908
909
910
# File 'lib/stripe/resources/subscription.rb', line 908

def automatic_tax
  @automatic_tax
end

#collection_methodObject

The collection method of the subscriptions to retrieve. Either ‘charge_automatically` or `send_invoice`.



910
911
912
# File 'lib/stripe/resources/subscription.rb', line 910

def collection_method
  @collection_method
end

#createdObject

Only return subscriptions that were created during the given date interval.



912
913
914
# File 'lib/stripe/resources/subscription.rb', line 912

def created
  @created
end

#current_period_endObject

Only return subscriptions whose current_period_end falls within the given date interval.



914
915
916
# File 'lib/stripe/resources/subscription.rb', line 914

def current_period_end
  @current_period_end
end

#current_period_startObject

Only return subscriptions whose current_period_start falls within the given date interval.



916
917
918
# File 'lib/stripe/resources/subscription.rb', line 916

def current_period_start
  @current_period_start
end

#customerObject

The ID of the customer whose subscriptions will be retrieved.



918
919
920
# File 'lib/stripe/resources/subscription.rb', line 918

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



920
921
922
# File 'lib/stripe/resources/subscription.rb', line 920

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



922
923
924
# File 'lib/stripe/resources/subscription.rb', line 922

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



924
925
926
# File 'lib/stripe/resources/subscription.rb', line 924

def limit
  @limit
end

#planObject

The ID of the plan whose subscriptions will be retrieved.



926
927
928
# File 'lib/stripe/resources/subscription.rb', line 926

def plan
  @plan
end

#priceObject

Filter for subscriptions that contain this recurring price ID.



928
929
930
# File 'lib/stripe/resources/subscription.rb', line 928

def price
  @price
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



930
931
932
# File 'lib/stripe/resources/subscription.rb', line 930

def starting_after
  @starting_after
end

#statusObject

The status of the subscriptions to retrieve. Passing in a value of ‘canceled` will return all canceled subscriptions, including those belonging to deleted customers. Pass `ended` to find subscriptions that are canceled and subscriptions that are expired due to [incomplete payment](stripe.com/docs/billing/subscriptions/overview#subscription-statuses). Passing in a value of `all` will return subscriptions of all statuses. If no value is supplied, all subscriptions that have not been canceled are returned.



932
933
934
# File 'lib/stripe/resources/subscription.rb', line 932

def status
  @status
end

#test_clockObject

Filter for subscriptions that are associated with the specified test clock. The response will not include subscriptions with test clocks if this and the customer parameter is not set.



934
935
936
# File 'lib/stripe/resources/subscription.rb', line 934

def test_clock
  @test_clock
end