Class: Stripe::Subscription::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: AutomaticTax, Created, CurrentPeriodEnd, CurrentPeriodStart

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_tax: nil, collection_method: nil, created: nil, current_period_end: nil, current_period_start: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, plan: nil, price: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams

Returns a new instance of ListParams.



1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
# File 'lib/stripe/resources/subscription.rb', line 1309

def initialize(
  automatic_tax: nil,
  collection_method: nil,
  created: nil,
  current_period_end: nil,
  current_period_start: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  plan: nil,
  price: nil,
  starting_after: nil,
  status: nil,
  test_clock: nil
)
  @automatic_tax = automatic_tax
  @collection_method = collection_method
  @created = created
  @current_period_end = current_period_end
  @current_period_start = current_period_start
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @plan = plan
  @price = price
  @starting_after = starting_after
  @status = status
  @test_clock = test_clock
end

Instance Attribute Details

#automatic_taxObject

Filter subscriptions by their automatic tax settings.



1268
1269
1270
# File 'lib/stripe/resources/subscription.rb', line 1268

def automatic_tax
  @automatic_tax
end

#collection_methodObject

The collection method of the subscriptions to retrieve. Either ‘charge_automatically` or `send_invoice`.



1271
1272
1273
# File 'lib/stripe/resources/subscription.rb', line 1271

def collection_method
  @collection_method
end

#createdObject

Only return subscriptions that were created during the given date interval.



1274
1275
1276
# File 'lib/stripe/resources/subscription.rb', line 1274

def created
  @created
end

#current_period_endObject

Only return subscriptions whose current_period_end falls within the given date interval.



1277
1278
1279
# File 'lib/stripe/resources/subscription.rb', line 1277

def current_period_end
  @current_period_end
end

#current_period_startObject

Only return subscriptions whose current_period_start falls within the given date interval.



1280
1281
1282
# File 'lib/stripe/resources/subscription.rb', line 1280

def current_period_start
  @current_period_start
end

#customerObject

The ID of the customer whose subscriptions will be retrieved.



1283
1284
1285
# File 'lib/stripe/resources/subscription.rb', line 1283

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



1286
1287
1288
# File 'lib/stripe/resources/subscription.rb', line 1286

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



1289
1290
1291
# File 'lib/stripe/resources/subscription.rb', line 1289

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1292
1293
1294
# File 'lib/stripe/resources/subscription.rb', line 1292

def limit
  @limit
end

#planObject

The ID of the plan whose subscriptions will be retrieved.



1295
1296
1297
# File 'lib/stripe/resources/subscription.rb', line 1295

def plan
  @plan
end

#priceObject

Filter for subscriptions that contain this recurring price ID.



1298
1299
1300
# File 'lib/stripe/resources/subscription.rb', line 1298

def price
  @price
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



1301
1302
1303
# File 'lib/stripe/resources/subscription.rb', line 1301

def starting_after
  @starting_after
end

#statusObject

The status of the subscriptions to retrieve. Passing in a value of ‘canceled` will return all canceled subscriptions, including those belonging to deleted customers. Pass `ended` to find subscriptions that are canceled and subscriptions that are expired due to [incomplete payment](stripe.com/docs/billing/subscriptions/overview#subscription-statuses). Passing in a value of `all` will return subscriptions of all statuses. If no value is supplied, all subscriptions that have not been canceled are returned.



1304
1305
1306
# File 'lib/stripe/resources/subscription.rb', line 1304

def status
  @status
end

#test_clockObject

Filter for subscriptions that are associated with the specified test clock. The response will not include subscriptions with test clocks if this and the customer parameter is not set.



1307
1308
1309
# File 'lib/stripe/resources/subscription.rb', line 1307

def test_clock
  @test_clock
end