Class: Stripe::Subscription::MigrateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: BillingMode

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_mode: nil, expand: nil) ⇒ MigrateParams

Returns a new instance of MigrateParams.



2436
2437
2438
2439
# File 'lib/stripe/resources/subscription.rb', line 2436

def initialize(billing_mode: nil, expand: nil)
  @billing_mode = billing_mode
  @expand = expand
end

Instance Attribute Details

#billing_modeObject

Controls how prorations and invoices for subscriptions are calculated and orchestrated.



2432
2433
2434
# File 'lib/stripe/resources/subscription.rb', line 2432

def billing_mode
  @billing_mode
end

#expandObject

Specifies which fields in the response should be expanded.



2434
2435
2436
# File 'lib/stripe/resources/subscription.rb', line 2434

def expand
  @expand
end