Class: Stripe::Subscription::MigrateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: BillingMode

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_mode: nil, expand: nil) ⇒ MigrateParams

Returns a new instance of MigrateParams.



1778
1779
1780
1781
# File 'lib/stripe/resources/subscription.rb', line 1778

def initialize(billing_mode: nil, expand: nil)
  @billing_mode = billing_mode
  @expand = expand
end

Instance Attribute Details

#billing_modeObject

Controls how prorations and invoices for subscriptions are calculated and orchestrated.



1774
1775
1776
# File 'lib/stripe/resources/subscription.rb', line 1774

def billing_mode
  @billing_mode
end

#expandObject

Specifies which fields in the response should be expanded.



1776
1777
1778
# File 'lib/stripe/resources/subscription.rb', line 1776

def expand
  @expand
end