Class: Stripe::Subscription::MigrateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::MigrateParams
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: BillingMode
Instance Attribute Summary collapse
-
#billing_mode ⇒ Object
Controls how prorations and invoices for subscriptions are calculated and orchestrated.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(billing_mode: nil, expand: nil) ⇒ MigrateParams
constructor
A new instance of MigrateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_mode: nil, expand: nil) ⇒ MigrateParams
Returns a new instance of MigrateParams.
1778 1779 1780 1781 |
# File 'lib/stripe/resources/subscription.rb', line 1778 def initialize(billing_mode: nil, expand: nil) @billing_mode = billing_mode @expand = end |
Instance Attribute Details
#billing_mode ⇒ Object
Controls how prorations and invoices for subscriptions are calculated and orchestrated.
1774 1775 1776 |
# File 'lib/stripe/resources/subscription.rb', line 1774 def billing_mode @billing_mode end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1776 1777 1778 |
# File 'lib/stripe/resources/subscription.rb', line 1776 def @expand end |