Class: Stripe::Subscription::MigrateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: BillingMode

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_mode: nil, expand: nil) ⇒ MigrateParams

Returns a new instance of MigrateParams.



2030
2031
2032
2033
# File 'lib/stripe/resources/subscription.rb', line 2030

def initialize(billing_mode: nil, expand: nil)
  @billing_mode = billing_mode
  @expand = expand
end

Instance Attribute Details

#billing_modeObject

Controls how prorations and invoices for subscriptions are calculated and orchestrated.



2026
2027
2028
# File 'lib/stripe/resources/subscription.rb', line 2026

def billing_mode
  @billing_mode
end

#expandObject

Specifies which fields in the response should be expanded.



2028
2029
2030
# File 'lib/stripe/resources/subscription.rb', line 2028

def expand
  @expand
end