Class: Stripe::Subscription::MigrateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: BillingMode

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_mode: nil, expand: nil) ⇒ MigrateParams

Returns a new instance of MigrateParams.



1953
1954
1955
1956
# File 'lib/stripe/resources/subscription.rb', line 1953

def initialize(billing_mode: nil, expand: nil)
  @billing_mode = billing_mode
  @expand = expand
end

Instance Attribute Details

#billing_modeObject

Controls how prorations and invoices for subscriptions are calculated and orchestrated.



1949
1950
1951
# File 'lib/stripe/resources/subscription.rb', line 1949

def billing_mode
  @billing_mode
end

#expandObject

Specifies which fields in the response should be expanded.



1951
1952
1953
# File 'lib/stripe/resources/subscription.rb', line 1951

def expand
  @expand
end