Class: Stripe::Subscription::MigrateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: BillingMode

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_mode: nil, expand: nil) ⇒ MigrateParams

Returns a new instance of MigrateParams.



1680
1681
1682
1683
# File 'lib/stripe/resources/subscription.rb', line 1680

def initialize(billing_mode: nil, expand: nil)
  @billing_mode = billing_mode
  @expand = expand
end

Instance Attribute Details

#billing_modeObject

Controls how prorations and invoices for subscriptions are calculated and orchestrated.



1676
1677
1678
# File 'lib/stripe/resources/subscription.rb', line 1676

def billing_mode
  @billing_mode
end

#expandObject

Specifies which fields in the response should be expanded.



1678
1679
1680
# File 'lib/stripe/resources/subscription.rb', line 1678

def expand
  @expand
end