Class: Stripe::Subscription::MigrateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_mode: nil, expand: nil) ⇒ MigrateParams

Returns a new instance of MigrateParams.



1934
1935
1936
1937
# File 'lib/stripe/resources/subscription.rb', line 1934

def initialize(billing_mode: nil, expand: nil)
  @billing_mode = billing_mode
  @expand = expand
end

Instance Attribute Details

#billing_modeObject

Controls how prorations and invoices for subscriptions are calculated and orchestrated.



1930
1931
1932
# File 'lib/stripe/resources/subscription.rb', line 1930

def billing_mode
  @billing_mode
end

#expandObject

Specifies which fields in the response should be expanded.



1932
1933
1934
# File 'lib/stripe/resources/subscription.rb', line 1932

def expand
  @expand
end