Class: Stripe::Subscription::PaymentSettings

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: PaymentMethodOptions

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#payment_method_optionsObject (readonly)

Payment-method-specific configuration to provide to invoices created by the subscription.



596
597
598
# File 'lib/stripe/resources/subscription.rb', line 596

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject (readonly)

The list of payment method types to provide to every invoice created by the subscription. If not set, Stripe attempts to automatically determine the types to use by looking at the invoice’s default payment method, the subscription’s default payment method, the customer’s default payment method, and your [invoice template settings](dashboard.stripe.com/settings/billing/invoice).



598
599
600
# File 'lib/stripe/resources/subscription.rb', line 598

def payment_method_types
  @payment_method_types
end

#save_default_payment_methodObject (readonly)

Configure whether Stripe updates ‘subscription.default_payment_method` when payment succeeds. Defaults to `off`.



600
601
602
# File 'lib/stripe/resources/subscription.rb', line 600

def save_default_payment_method
  @save_default_payment_method
end

Class Method Details

.field_remappingsObject



606
607
608
# File 'lib/stripe/resources/subscription.rb', line 606

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



602
603
604
# File 'lib/stripe/resources/subscription.rb', line 602

def self.inner_class_types
  @inner_class_types = { payment_method_options: PaymentMethodOptions }
end