Class: Stripe::Subscription::PaymentSettings
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::Subscription::PaymentSettings
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: PaymentMethodOptions
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#payment_method_options ⇒ Object
readonly
Payment-method-specific configuration to provide to invoices created by the subscription.
-
#payment_method_types ⇒ Object
readonly
The list of payment method types to provide to every invoice created by the subscription.
-
#save_default_payment_method ⇒ Object
readonly
Configure whether Stripe updates ‘subscription.default_payment_method` when payment succeeds.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#payment_method_options ⇒ Object (readonly)
Payment-method-specific configuration to provide to invoices created by the subscription.
583 584 585 |
# File 'lib/stripe/resources/subscription.rb', line 583 def @payment_method_options end |
#payment_method_types ⇒ Object (readonly)
The list of payment method types to provide to every invoice created by the subscription. If not set, Stripe attempts to automatically determine the types to use by looking at the invoice’s default payment method, the subscription’s default payment method, the customer’s default payment method, and your [invoice template settings](dashboard.stripe.com/settings/billing/invoice).
585 586 587 |
# File 'lib/stripe/resources/subscription.rb', line 585 def payment_method_types @payment_method_types end |
#save_default_payment_method ⇒ Object (readonly)
Configure whether Stripe updates ‘subscription.default_payment_method` when payment succeeds. Defaults to `off`.
587 588 589 |
# File 'lib/stripe/resources/subscription.rb', line 587 def save_default_payment_method @save_default_payment_method end |
Class Method Details
.field_remappings ⇒ Object
593 594 595 |
# File 'lib/stripe/resources/subscription.rb', line 593 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
589 590 591 |
# File 'lib/stripe/resources/subscription.rb', line 589 def self.inner_class_types @inner_class_types = { payment_method_options: PaymentMethodOptions } end |