Class: Stripe::Subscription::PaymentSettings

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: PaymentMethodOptions

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Method Summary

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#payment_method_optionsObject (readonly)

Payment-method-specific configuration to provide to invoices created by the subscription.



197
198
199
# File 'lib/stripe/resources/subscription.rb', line 197

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject (readonly)

The list of payment method types to provide to every invoice created by the subscription. If not set, Stripe attempts to automatically determine the types to use by looking at the invoice’s default payment method, the subscription’s default payment method, the customer’s default payment method, and your [invoice template settings](dashboard.stripe.com/settings/billing/invoice).



199
200
201
# File 'lib/stripe/resources/subscription.rb', line 199

def payment_method_types
  @payment_method_types
end

#save_default_payment_methodObject (readonly)

Configure whether Stripe updates ‘subscription.default_payment_method` when payment succeeds. Defaults to `off`.



201
202
203
# File 'lib/stripe/resources/subscription.rb', line 201

def save_default_payment_method
  @save_default_payment_method
end