Class: Stripe::Subscription::PaymentSettings::PaymentMethodOptions::Card
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::Subscription::PaymentSettings::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: MandateOptions
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#mandate_options ⇒ Object
readonly
Attribute for field mandate_options.
-
#network ⇒ Object
readonly
Selected network to process this Subscription on.
-
#request_three_d_secure ⇒ Object
readonly
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#mandate_options ⇒ Object (readonly)
Attribute for field mandate_options
390 391 392 |
# File 'lib/stripe/resources/subscription.rb', line 390 def @mandate_options end |
#network ⇒ Object (readonly)
Selected network to process this Subscription on. Depends on the available networks of the card attached to the Subscription. Can be only set confirm-time.
392 393 394 |
# File 'lib/stripe/resources/subscription.rb', line 392 def network @network end |
#request_three_d_secure ⇒ Object (readonly)
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements. However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. Read our guide on manually requesting 3D Secure for more information on how this configuration interacts with Radar and our SCA Engine.
394 395 396 |
# File 'lib/stripe/resources/subscription.rb', line 394 def request_three_d_secure @request_three_d_secure end |
Class Method Details
.field_remappings ⇒ Object
400 401 402 |
# File 'lib/stripe/resources/subscription.rb', line 400 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
396 397 398 |
# File 'lib/stripe/resources/subscription.rb', line 396 def self.inner_class_types @inner_class_types = { mandate_options: MandateOptions } end |