Class: Stripe::Subscription::PaymentSettings::PaymentMethodOptions::Card::MandateOptions

Inherits:
Stripe::StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments, specified in the presentment currency.



354
355
356
# File 'lib/stripe/resources/subscription.rb', line 354

def amount
  @amount
end

#amount_typeObject (readonly)

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



356
357
358
# File 'lib/stripe/resources/subscription.rb', line 356

def amount_type
  @amount_type
end

#descriptionObject (readonly)

A description of the mandate or subscription that is meant to be displayed to the customer.



358
359
360
# File 'lib/stripe/resources/subscription.rb', line 358

def description
  @description
end

Class Method Details

.field_remappingsObject



364
365
366
# File 'lib/stripe/resources/subscription.rb', line 364

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



360
361
362
# File 'lib/stripe/resources/subscription.rb', line 360

def self.inner_class_types
  @inner_class_types = {}
end