Class: Stripe::Subscription::PaymentSettings::PaymentMethodOptions::Pix::MandateOptions
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::Subscription::PaymentSettings::PaymentMethodOptions::Pix::MandateOptions
- Defined in:
- lib/stripe/resources/subscription.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount to be charged for future payments.
-
#amount_includes_iof ⇒ Object
readonly
Determines if the amount includes the IOF tax.
-
#end_date ⇒ Object
readonly
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.
-
#payment_schedule ⇒ Object
readonly
Schedule at which the future payments will be charged.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount to be charged for future payments.
458 459 460 |
# File 'lib/stripe/resources/subscription.rb', line 458 def amount @amount end |
#amount_includes_iof ⇒ Object (readonly)
Determines if the amount includes the IOF tax.
460 461 462 |
# File 'lib/stripe/resources/subscription.rb', line 460 def amount_includes_iof @amount_includes_iof end |
#end_date ⇒ Object (readonly)
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.
462 463 464 |
# File 'lib/stripe/resources/subscription.rb', line 462 def end_date @end_date end |
#payment_schedule ⇒ Object (readonly)
Schedule at which the future payments will be charged.
464 465 466 |
# File 'lib/stripe/resources/subscription.rb', line 464 def payment_schedule @payment_schedule end |
Class Method Details
.field_remappings ⇒ Object
470 471 472 |
# File 'lib/stripe/resources/subscription.rb', line 470 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
466 467 468 |
# File 'lib/stripe/resources/subscription.rb', line 466 def self.inner_class_types @inner_class_types = {} end |