Class: Stripe::Subscription::PendingUpdate

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_cycle_anchorObject (readonly)

If the update is applied, determines the date of the first full invoice, and, for plans with month or year intervals, the day of the month for subsequent invoices. The timestamp is in UTC format.



707
708
709
# File 'lib/stripe/resources/subscription.rb', line 707

def billing_cycle_anchor
  @billing_cycle_anchor
end

#discountObject (readonly)

The pending subscription-level discount that will be applied when the pending update is applied.



709
710
711
# File 'lib/stripe/resources/subscription.rb', line 709

def discount
  @discount
end

#discountsObject (readonly)

The discounts that will be applied to the subscription when the pending update is applied. Use expand[]=discounts to expand each discount.



711
712
713
# File 'lib/stripe/resources/subscription.rb', line 711

def discounts
  @discounts
end

#expires_atObject (readonly)

The point after which the changes reflected by this update will be discarded and no longer applied.



713
714
715
# File 'lib/stripe/resources/subscription.rb', line 713

def expires_at
  @expires_at
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



715
716
717
# File 'lib/stripe/resources/subscription.rb', line 715

def 
  @metadata
end

#prebilling_iterationsObject (readonly)

The number of iterations of prebilling to apply.



717
718
719
# File 'lib/stripe/resources/subscription.rb', line 717

def prebilling_iterations
  @prebilling_iterations
end

#subscription_itemsObject (readonly)

List of subscription items, each with an attached plan, that will be set if the update is applied.



719
720
721
# File 'lib/stripe/resources/subscription.rb', line 719

def subscription_items
  @subscription_items
end

#trial_endObject (readonly)

Unix timestamp representing the end of the trial period the customer will get before being charged for the first time, if the update is applied.



721
722
723
# File 'lib/stripe/resources/subscription.rb', line 721

def trial_end
  @trial_end
end

#trial_from_planObject (readonly)

Indicates if a plan's trial_period_days should be applied to the subscription. Setting trial_end per subscription is preferred, and this defaults to false. Setting this flag to true together with trial_end is not allowed. See Using trial periods on subscriptions to learn more.



723
724
725
# File 'lib/stripe/resources/subscription.rb', line 723

def trial_from_plan
  @trial_from_plan
end

Class Method Details

.field_remappingsObject



729
730
731
# File 'lib/stripe/resources/subscription.rb', line 729

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



725
726
727
# File 'lib/stripe/resources/subscription.rb', line 725

def self.inner_class_types
  @inner_class_types = {}
end