Class: Stripe::Subscription::PendingUpdate

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_cycle_anchorObject (readonly)

If the update is applied, determines the date of the first full invoice, and, for plans with month or year intervals, the day of the month for subsequent invoices. The timestamp is in UTC format.



618
619
620
# File 'lib/stripe/resources/subscription.rb', line 618

def billing_cycle_anchor
  @billing_cycle_anchor
end

#discountObject (readonly)

The pending subscription-level discount that will be applied when the pending update is applied.



620
621
622
# File 'lib/stripe/resources/subscription.rb', line 620

def discount
  @discount
end

#discountsObject (readonly)

The discounts that will be applied to the subscription when the pending update is applied. Use expand[]=discounts to expand each discount.



622
623
624
# File 'lib/stripe/resources/subscription.rb', line 622

def discounts
  @discounts
end

#expires_atObject (readonly)

The point after which the changes reflected by this update will be discarded and no longer applied.



624
625
626
# File 'lib/stripe/resources/subscription.rb', line 624

def expires_at
  @expires_at
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



626
627
628
# File 'lib/stripe/resources/subscription.rb', line 626

def 
  @metadata
end

#subscription_itemsObject (readonly)

List of subscription items, each with an attached plan, that will be set if the update is applied.



628
629
630
# File 'lib/stripe/resources/subscription.rb', line 628

def subscription_items
  @subscription_items
end

#trial_endObject (readonly)

Unix timestamp representing the end of the trial period the customer will get before being charged for the first time, if the update is applied.



630
631
632
# File 'lib/stripe/resources/subscription.rb', line 630

def trial_end
  @trial_end
end

#trial_from_planObject (readonly)

Indicates if a plan's trial_period_days should be applied to the subscription. Setting trial_end per subscription is preferred, and this defaults to false. Setting this flag to true together with trial_end is not allowed. See Using trial periods on subscriptions to learn more.



632
633
634
# File 'lib/stripe/resources/subscription.rb', line 632

def trial_from_plan
  @trial_from_plan
end

Class Method Details

.field_remappingsObject



638
639
640
# File 'lib/stripe/resources/subscription.rb', line 638

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



634
635
636
# File 'lib/stripe/resources/subscription.rb', line 634

def self.inner_class_types
  @inner_class_types = {}
end