Class: Stripe::Subscription::PendingUpdate
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::Subscription::PendingUpdate
- Defined in:
- lib/stripe/resources/subscription.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_cycle_anchor ⇒ Object
readonly
If the update is applied, determines the date of the first full invoice, and, for plans with
monthoryearintervals, the day of the month for subsequent invoices. -
#discount ⇒ Object
readonly
The pending subscription-level discount that will be applied when the pending update is applied.
-
#discounts ⇒ Object
readonly
The discounts that will be applied to the subscription when the pending update is applied.
-
#expires_at ⇒ Object
readonly
The point after which the changes reflected by this update will be discarded and no longer applied.
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#prebilling_iterations ⇒ Object
readonly
The number of iterations of prebilling to apply.
-
#subscription_items ⇒ Object
readonly
List of subscription items, each with an attached plan, that will be set if the update is applied.
-
#trial_end ⇒ Object
readonly
Unix timestamp representing the end of the trial period the customer will get before being charged for the first time, if the update is applied.
-
#trial_from_plan ⇒ Object
readonly
Indicates if a plan's
trial_period_daysshould be applied to the subscription.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_cycle_anchor ⇒ Object (readonly)
If the update is applied, determines the date of the first full invoice, and, for plans with month or year intervals, the day of the month for subsequent invoices. The timestamp is in UTC format.
692 693 694 |
# File 'lib/stripe/resources/subscription.rb', line 692 def billing_cycle_anchor @billing_cycle_anchor end |
#discount ⇒ Object (readonly)
The pending subscription-level discount that will be applied when the pending update is applied.
694 695 696 |
# File 'lib/stripe/resources/subscription.rb', line 694 def discount @discount end |
#discounts ⇒ Object (readonly)
The discounts that will be applied to the subscription when the pending update is applied. Use expand[]=discounts to expand each discount.
696 697 698 |
# File 'lib/stripe/resources/subscription.rb', line 696 def discounts @discounts end |
#expires_at ⇒ Object (readonly)
The point after which the changes reflected by this update will be discarded and no longer applied.
698 699 700 |
# File 'lib/stripe/resources/subscription.rb', line 698 def expires_at @expires_at end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
700 701 702 |
# File 'lib/stripe/resources/subscription.rb', line 700 def @metadata end |
#prebilling_iterations ⇒ Object (readonly)
The number of iterations of prebilling to apply.
702 703 704 |
# File 'lib/stripe/resources/subscription.rb', line 702 def prebilling_iterations @prebilling_iterations end |
#subscription_items ⇒ Object (readonly)
List of subscription items, each with an attached plan, that will be set if the update is applied.
704 705 706 |
# File 'lib/stripe/resources/subscription.rb', line 704 def subscription_items @subscription_items end |
#trial_end ⇒ Object (readonly)
Unix timestamp representing the end of the trial period the customer will get before being charged for the first time, if the update is applied.
706 707 708 |
# File 'lib/stripe/resources/subscription.rb', line 706 def trial_end @trial_end end |
#trial_from_plan ⇒ Object (readonly)
Indicates if a plan's trial_period_days should be applied to the subscription. Setting trial_end per subscription is preferred, and this defaults to false. Setting this flag to true together with trial_end is not allowed. See Using trial periods on subscriptions to learn more.
708 709 710 |
# File 'lib/stripe/resources/subscription.rb', line 708 def trial_from_plan @trial_from_plan end |
Class Method Details
.field_remappings ⇒ Object
714 715 716 |
# File 'lib/stripe/resources/subscription.rb', line 714 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
710 711 712 |
# File 'lib/stripe/resources/subscription.rb', line 710 def self.inner_class_types @inner_class_types = {} end |