Class: Stripe::Subscription::PendingUpdate

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Method Summary

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_cycle_anchorObject (readonly)

If the update is applied, determines the date of the first full invoice, and, for plans with ‘month` or `year` intervals, the day of the month for subsequent invoices. The timestamp is in UTC format.



213
214
215
# File 'lib/stripe/resources/subscription.rb', line 213

def billing_cycle_anchor
  @billing_cycle_anchor
end

#expires_atObject (readonly)

The point after which the changes reflected by this update will be discarded and no longer applied.



215
216
217
# File 'lib/stripe/resources/subscription.rb', line 215

def expires_at
  @expires_at
end

#prebilling_iterationsObject (readonly)

The number of iterations of prebilling to apply.



217
218
219
# File 'lib/stripe/resources/subscription.rb', line 217

def prebilling_iterations
  @prebilling_iterations
end

#subscription_itemsObject (readonly)

List of subscription items, each with an attached plan, that will be set if the update is applied.



219
220
221
# File 'lib/stripe/resources/subscription.rb', line 219

def subscription_items
  @subscription_items
end

#trial_endObject (readonly)

Unix timestamp representing the end of the trial period the customer will get before being charged for the first time, if the update is applied.



221
222
223
# File 'lib/stripe/resources/subscription.rb', line 221

def trial_end
  @trial_end
end

#trial_from_planObject (readonly)

Indicates if a plan’s ‘trial_period_days` should be applied to the subscription. Setting `trial_end` per subscription is preferred, and this defaults to `false`. Setting this flag to `true` together with `trial_end` is not allowed. See [Using trial periods on subscriptions](stripe.com/docs/billing/subscriptions/trials) to learn more.



223
224
225
# File 'lib/stripe/resources/subscription.rb', line 223

def trial_from_plan
  @trial_from_plan
end