Class: Stripe::Subscription::PendingUpdate
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::Subscription::PendingUpdate
- Defined in:
- lib/stripe/resources/subscription.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_cycle_anchor ⇒ Object
readonly
If the update is applied, determines the date of the first full invoice, and, for plans with ‘month` or `year` intervals, the day of the month for subsequent invoices.
-
#expires_at ⇒ Object
readonly
The point after which the changes reflected by this update will be discarded and no longer applied.
-
#subscription_items ⇒ Object
readonly
List of subscription items, each with an attached plan, that will be set if the update is applied.
-
#trial_end ⇒ Object
readonly
Unix timestamp representing the end of the trial period the customer will get before being charged for the first time, if the update is applied.
-
#trial_from_plan ⇒ Object
readonly
Indicates if a plan’s ‘trial_period_days` should be applied to the subscription.
Attributes inherited from Stripe::StripeObject
Method Summary
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_cycle_anchor ⇒ Object (readonly)
If the update is applied, determines the date of the first full invoice, and, for plans with ‘month` or `year` intervals, the day of the month for subsequent invoices. The timestamp is in UTC format.
188 189 190 |
# File 'lib/stripe/resources/subscription.rb', line 188 def billing_cycle_anchor @billing_cycle_anchor end |
#expires_at ⇒ Object (readonly)
The point after which the changes reflected by this update will be discarded and no longer applied.
190 191 192 |
# File 'lib/stripe/resources/subscription.rb', line 190 def expires_at @expires_at end |
#subscription_items ⇒ Object (readonly)
List of subscription items, each with an attached plan, that will be set if the update is applied.
192 193 194 |
# File 'lib/stripe/resources/subscription.rb', line 192 def subscription_items @subscription_items end |
#trial_end ⇒ Object (readonly)
Unix timestamp representing the end of the trial period the customer will get before being charged for the first time, if the update is applied.
194 195 196 |
# File 'lib/stripe/resources/subscription.rb', line 194 def trial_end @trial_end end |
#trial_from_plan ⇒ Object (readonly)
Indicates if a plan’s ‘trial_period_days` should be applied to the subscription. Setting `trial_end` per subscription is preferred, and this defaults to `false`. Setting this flag to `true` together with `trial_end` is not allowed. See [Using trial periods on subscriptions](stripe.com/docs/billing/subscriptions/trials) to learn more.
196 197 198 |
# File 'lib/stripe/resources/subscription.rb', line 196 def trial_from_plan @trial_from_plan end |