Class: Stripe::Subscription::Prebilling
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::Subscription::Prebilling
- Defined in:
- lib/stripe/resources/subscription.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#invoice ⇒ Object
readonly
ID of the prebilling invoice.
-
#period_end ⇒ Object
readonly
The end of the last period for which the invoice pre-bills.
-
#period_start ⇒ Object
readonly
The start of the first period for which the invoice pre-bills.
-
#update_behavior ⇒ Object
readonly
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#invoice ⇒ Object (readonly)
ID of the prebilling invoice.
694 695 696 |
# File 'lib/stripe/resources/subscription.rb', line 694 def invoice @invoice end |
#period_end ⇒ Object (readonly)
The end of the last period for which the invoice pre-bills.
696 697 698 |
# File 'lib/stripe/resources/subscription.rb', line 696 def period_end @period_end end |
#period_start ⇒ Object (readonly)
The start of the first period for which the invoice pre-bills.
698 699 700 |
# File 'lib/stripe/resources/subscription.rb', line 698 def period_start @period_start end |
#update_behavior ⇒ Object (readonly)
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period.
700 701 702 |
# File 'lib/stripe/resources/subscription.rb', line 700 def update_behavior @update_behavior end |
Class Method Details
.field_remappings ⇒ Object
706 707 708 |
# File 'lib/stripe/resources/subscription.rb', line 706 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
702 703 704 |
# File 'lib/stripe/resources/subscription.rb', line 702 def self.inner_class_types @inner_class_types = {} end |