Class: Stripe::Subscription::Prebilling

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Method Summary

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#invoiceObject (readonly)

ID of the prebilling invoice.



230
231
232
# File 'lib/stripe/resources/subscription.rb', line 230

def invoice
  @invoice
end

#period_endObject (readonly)

The end of the last period for which the invoice pre-bills.



232
233
234
# File 'lib/stripe/resources/subscription.rb', line 232

def period_end
  @period_end
end

#period_startObject (readonly)

The start of the first period for which the invoice pre-bills.



234
235
236
# File 'lib/stripe/resources/subscription.rb', line 234

def period_start
  @period_start
end

#update_behaviorObject (readonly)

Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period.



236
237
238
# File 'lib/stripe/resources/subscription.rb', line 236

def update_behavior
  @update_behavior
end