Class: Stripe::Subscription::ResumeParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::ResumeParams
- Defined in:
- lib/stripe/resources/subscription.rb
Instance Attribute Summary collapse
-
#billing_cycle_anchor ⇒ Object
The billing cycle anchor that applies when the subscription is resumed.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#proration_behavior ⇒ Object
Determines how to handle [prorations](stripe.com/docs/billing/subscriptions/prorations) resulting from the ‘billing_cycle_anchor` being `unchanged`.
-
#proration_date ⇒ Object
If set, prorations will be calculated as though the subscription was resumed at the given time.
Instance Method Summary collapse
-
#initialize(billing_cycle_anchor: nil, expand: nil, proration_behavior: nil, proration_date: nil) ⇒ ResumeParams
constructor
A new instance of ResumeParams.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_cycle_anchor: nil, expand: nil, proration_behavior: nil, proration_date: nil) ⇒ ResumeParams
Returns a new instance of ResumeParams.
1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 |
# File 'lib/stripe/resources/subscription.rb', line 1969 def initialize( billing_cycle_anchor: nil, expand: nil, proration_behavior: nil, proration_date: nil ) @billing_cycle_anchor = billing_cycle_anchor @expand = @proration_behavior = proration_behavior @proration_date = proration_date end |
Instance Attribute Details
#billing_cycle_anchor ⇒ Object
The billing cycle anchor that applies when the subscription is resumed. Either ‘now` or `unchanged`. The default is `now`. For more information, see the billing cycle [documentation](stripe.com/docs/billing/subscriptions/billing-cycle).
1961 1962 1963 |
# File 'lib/stripe/resources/subscription.rb', line 1961 def billing_cycle_anchor @billing_cycle_anchor end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1963 1964 1965 |
# File 'lib/stripe/resources/subscription.rb', line 1963 def @expand end |
#proration_behavior ⇒ Object
Determines how to handle [prorations](stripe.com/docs/billing/subscriptions/prorations) resulting from the ‘billing_cycle_anchor` being `unchanged`. When the `billing_cycle_anchor` is set to `now` (default value), no prorations are generated. If no value is passed, the default is `create_prorations`.
1965 1966 1967 |
# File 'lib/stripe/resources/subscription.rb', line 1965 def proration_behavior @proration_behavior end |
#proration_date ⇒ Object
If set, prorations will be calculated as though the subscription was resumed at the given time. This can be used to apply exactly the same prorations that were previewed with the [create preview](stripe.com/docs/api/invoices/create_preview) endpoint.
1967 1968 1969 |
# File 'lib/stripe/resources/subscription.rb', line 1967 def proration_date @proration_date end |