Class: Stripe::Subscription::SearchParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams

Returns a new instance of SearchParams.



2008
2009
2010
2011
2012
2013
# File 'lib/stripe/resources/subscription.rb', line 2008

def initialize(expand: nil, limit: nil, page: nil, query: nil)
  @expand = expand
  @limit = limit
  @page = page
  @query = query
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



2000
2001
2002
# File 'lib/stripe/resources/subscription.rb', line 2000

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



2002
2003
2004
# File 'lib/stripe/resources/subscription.rb', line 2002

def limit
  @limit
end

#pageObject

A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.



2004
2005
2006
# File 'lib/stripe/resources/subscription.rb', line 2004

def page
  @page
end

#queryObject

The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for subscriptions](stripe.com/docs/search#query-fields-for-subscriptions).



2006
2007
2008
# File 'lib/stripe/resources/subscription.rb', line 2006

def query
  @query
end