Class: Stripe::Subscription::SearchParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams

Returns a new instance of SearchParams.



1931
1932
1933
1934
1935
1936
# File 'lib/stripe/resources/subscription.rb', line 1931

def initialize(expand: nil, limit: nil, page: nil, query: nil)
  @expand = expand
  @limit = limit
  @page = page
  @query = query
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



1923
1924
1925
# File 'lib/stripe/resources/subscription.rb', line 1923

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1925
1926
1927
# File 'lib/stripe/resources/subscription.rb', line 1925

def limit
  @limit
end

#pageObject

A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.



1927
1928
1929
# File 'lib/stripe/resources/subscription.rb', line 1927

def page
  @page
end

#queryObject

The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for subscriptions](stripe.com/docs/search#query-fields-for-subscriptions).



1929
1930
1931
# File 'lib/stripe/resources/subscription.rb', line 1929

def query
  @query
end