Class: Stripe::Subscription::SearchParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::SearchParams
- Defined in:
- lib/stripe/resources/subscription.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#page ⇒ Object
A cursor for pagination across multiple pages of results.
-
#query ⇒ Object
The search query string.
Instance Method Summary collapse
-
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
constructor
A new instance of SearchParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
Returns a new instance of SearchParams.
1920 1921 1922 1923 1924 1925 |
# File 'lib/stripe/resources/subscription.rb', line 1920 def initialize(expand: nil, limit: nil, page: nil, query: nil) @expand = @limit = limit @page = page @query = query end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1912 1913 1914 |
# File 'lib/stripe/resources/subscription.rb', line 1912 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1914 1915 1916 |
# File 'lib/stripe/resources/subscription.rb', line 1914 def limit @limit end |
#page ⇒ Object
A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.
1916 1917 1918 |
# File 'lib/stripe/resources/subscription.rb', line 1916 def page @page end |
#query ⇒ Object
The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for subscriptions](stripe.com/docs/search#query-fields-for-subscriptions).
1918 1919 1920 |
# File 'lib/stripe/resources/subscription.rb', line 1918 def query @query end |