Class: Stripe::Subscription::TransferData

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_percentObject (readonly)

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



484
485
486
# File 'lib/stripe/resources/subscription.rb', line 484

def amount_percent
  @amount_percent
end

#destinationObject (readonly)

The account where funds from the payment will be transferred to upon payment success.



486
487
488
# File 'lib/stripe/resources/subscription.rb', line 486

def destination
  @destination
end

Class Method Details

.field_remappingsObject



492
493
494
# File 'lib/stripe/resources/subscription.rb', line 492

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



488
489
490
# File 'lib/stripe/resources/subscription.rb', line 488

def self.inner_class_types
  @inner_class_types = {}
end