Class: Stripe::Subscription::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: AddInvoiceItem, AutomaticTax, BillingThresholds, CancellationDetails, Discount, InvoiceSettings, Item, PauseCollection, PaymentSettings, PendingInvoiceItemInterval, Prebilling, TransferData, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_thresholds: nil, cancel_at: nil, cancel_at_period_end: nil, cancellation_details: nil, collection_method: nil, days_until_due: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, invoice_settings: nil, items: nil, metadata: nil, off_session: nil, on_behalf_of: nil, pause_collection: nil, payment_behavior: nil, payment_settings: nil, pending_invoice_item_interval: nil, prebilling: nil, proration_behavior: nil, proration_date: nil, transfer_data: nil, trial_end: nil, trial_from_plan: nil, trial_settings: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
# File 'lib/stripe/resources/subscription.rb', line 953

def initialize(
  add_invoice_items: nil,
  application_fee_percent: nil,
  automatic_tax: nil,
  billing_cycle_anchor: nil,
  billing_thresholds: nil,
  cancel_at: nil,
  cancel_at_period_end: nil,
  cancellation_details: nil,
  collection_method: nil,
  days_until_due: nil,
  default_payment_method: nil,
  default_source: nil,
  default_tax_rates: nil,
  description: nil,
  discounts: nil,
  expand: nil,
  invoice_settings: nil,
  items: nil,
  metadata: nil,
  off_session: nil,
  on_behalf_of: nil,
  pause_collection: nil,
  payment_behavior: nil,
  payment_settings: nil,
  pending_invoice_item_interval: nil,
  prebilling: nil,
  proration_behavior: nil,
  proration_date: nil,
  transfer_data: nil,
  trial_end: nil,
  trial_from_plan: nil,
  trial_settings: nil
)
  @add_invoice_items = add_invoice_items
  @application_fee_percent = application_fee_percent
  @automatic_tax = automatic_tax
  @billing_cycle_anchor = billing_cycle_anchor
  @billing_thresholds = billing_thresholds
  @cancel_at = cancel_at
  @cancel_at_period_end = cancel_at_period_end
  @cancellation_details = cancellation_details
  @collection_method = collection_method
  @days_until_due = days_until_due
  @default_payment_method = default_payment_method
  @default_source = default_source
  @default_tax_rates = default_tax_rates
  @description = description
  @discounts = discounts
  @expand = expand
  @invoice_settings = invoice_settings
  @items = items
  @metadata = 
  @off_session = off_session
  @on_behalf_of = on_behalf_of
  @pause_collection = pause_collection
  @payment_behavior = payment_behavior
  @payment_settings = payment_settings
  @pending_invoice_item_interval = pending_invoice_item_interval
  @prebilling = prebilling
  @proration_behavior = proration_behavior
  @proration_date = proration_date
  @transfer_data = transfer_data
  @trial_end = trial_end
  @trial_from_plan = trial_from_plan
  @trial_settings = trial_settings
end

Instance Attribute Details

#add_invoice_itemsObject

A list of prices and quantities that will generate invoice items appended to the next invoice for this subscription. You may pass up to 20 items.



883
884
885
# File 'lib/stripe/resources/subscription.rb', line 883

def add_invoice_items
  @add_invoice_items
end

#application_fee_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees [documentation](stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).



885
886
887
# File 'lib/stripe/resources/subscription.rb', line 885

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject

Automatic tax settings for this subscription. We recommend you only include this parameter when the existing value is being changed.



887
888
889
# File 'lib/stripe/resources/subscription.rb', line 887

def automatic_tax
  @automatic_tax
end

#billing_cycle_anchorObject

Either ‘now` or `unchanged`. Setting the value to `now` resets the subscription’s billing cycle anchor to the current time (in UTC). For more information, see the billing cycle [documentation](stripe.com/docs/billing/subscriptions/billing-cycle).



889
890
891
# File 'lib/stripe/resources/subscription.rb', line 889

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.



891
892
893
# File 'lib/stripe/resources/subscription.rb', line 891

def billing_thresholds
  @billing_thresholds
end

#cancel_atObject

A timestamp at which the subscription should cancel. If set to a date before the current period ends, this will cause a proration if prorations have been enabled using ‘proration_behavior`. If set during a future period, this will always cause a proration for that period.



893
894
895
# File 'lib/stripe/resources/subscription.rb', line 893

def cancel_at
  @cancel_at
end

#cancel_at_period_endObject

Indicate whether this subscription should cancel at the end of the current period (‘current_period_end`). Defaults to `false`.



895
896
897
# File 'lib/stripe/resources/subscription.rb', line 895

def cancel_at_period_end
  @cancel_at_period_end
end

#cancellation_detailsObject

Details about why this subscription was cancelled



897
898
899
# File 'lib/stripe/resources/subscription.rb', line 897

def cancellation_details
  @cancellation_details
end

#collection_methodObject

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay this subscription at the end of the cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically`.



899
900
901
# File 'lib/stripe/resources/subscription.rb', line 899

def collection_method
  @collection_method
end

#days_until_dueObject

Number of days a customer has to pay invoices generated by this subscription. Valid only for subscriptions where ‘collection_method` is set to `send_invoice`.



901
902
903
# File 'lib/stripe/resources/subscription.rb', line 901

def days_until_due
  @days_until_due
end

#default_payment_methodObject

ID of the default payment method for the subscription. It must belong to the customer associated with the subscription. This takes precedence over ‘default_source`. If neither are set, invoices will use the customer’s [invoice_settings.default_payment_method](stripe.com/docs/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](stripe.com/docs/api/customers/object#customer_object-default_source).



903
904
905
# File 'lib/stripe/resources/subscription.rb', line 903

def default_payment_method
  @default_payment_method
end

#default_sourceObject

ID of the default payment source for the subscription. It must belong to the customer associated with the subscription and be in a chargeable state. If ‘default_payment_method` is also set, `default_payment_method` will take precedence. If neither are set, invoices will use the customer’s [invoice_settings.default_payment_method](stripe.com/docs/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](stripe.com/docs/api/customers/object#customer_object-default_source).



905
906
907
# File 'lib/stripe/resources/subscription.rb', line 905

def default_source
  @default_source
end

#default_tax_ratesObject

The tax rates that will apply to any subscription item that does not have ‘tax_rates` set. Invoices created will have their `default_tax_rates` populated from the subscription. Pass an empty string to remove previously-defined tax rates.



907
908
909
# File 'lib/stripe/resources/subscription.rb', line 907

def default_tax_rates
  @default_tax_rates
end

#descriptionObject

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



909
910
911
# File 'lib/stripe/resources/subscription.rb', line 909

def description
  @description
end

#discountsObject

The coupons to redeem into discounts for the subscription. If not specified or empty, inherits the discount from the subscription’s customer.



911
912
913
# File 'lib/stripe/resources/subscription.rb', line 911

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



913
914
915
# File 'lib/stripe/resources/subscription.rb', line 913

def expand
  @expand
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



915
916
917
# File 'lib/stripe/resources/subscription.rb', line 915

def invoice_settings
  @invoice_settings
end

#itemsObject

A list of up to 20 subscription items, each with an attached price.



917
918
919
# File 'lib/stripe/resources/subscription.rb', line 917

def items
  @items
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



919
920
921
# File 'lib/stripe/resources/subscription.rb', line 919

def 
  @metadata
end

#off_sessionObject

Indicates if a customer is on or off-session while an invoice payment is attempted. Defaults to ‘false` (on-session).



921
922
923
# File 'lib/stripe/resources/subscription.rb', line 921

def off_session
  @off_session
end

#on_behalf_ofObject

The account on behalf of which to charge, for each of the subscription’s invoices.



923
924
925
# File 'lib/stripe/resources/subscription.rb', line 923

def on_behalf_of
  @on_behalf_of
end

#pause_collectionObject

If specified, payment collection for this subscription will be paused. Note that the subscription status will be unchanged and will not be updated to ‘paused`. Learn more about [pausing collection](stripe.com/docs/billing/subscriptions/pause-payment).



925
926
927
# File 'lib/stripe/resources/subscription.rb', line 925

def pause_collection
  @pause_collection
end

#payment_behaviorObject

Use ‘allow_incomplete` to transition the subscription to `status=past_due` if a payment is required but cannot be paid. This allows you to manage scenarios where additional user actions are needed to pay a subscription’s invoice. For example, SCA regulation may require 3DS authentication to complete payment. See the [SCA Migration Guide](stripe.com/docs/billing/migration/strong-customer-authentication) for Billing to learn more. This is the default behavior.

Use ‘default_incomplete` to transition the subscription to `status=past_due` when payment is required and await explicit confirmation of the invoice’s payment intent. This allows simpler management of scenarios where additional user actions are needed to pay a subscription’s invoice. Such as failed payments, [SCA regulation](stripe.com/docs/billing/migration/strong-customer-authentication), or collecting a mandate for a bank debit payment method.

Use ‘pending_if_incomplete` to update the subscription using [pending updates](stripe.com/docs/billing/subscriptions/pending-updates). When you use `pending_if_incomplete` you can only pass the parameters [supported by pending updates](stripe.com/docs/billing/pending-updates-reference#supported-attributes).

Use ‘error_if_incomplete` if you want Stripe to return an HTTP 402 status code if a subscription’s invoice cannot be paid. For example, if a payment method requires 3DS authentication due to SCA regulation and further user action is needed, this parameter does not update the subscription and returns an error instead. This was the default behavior for API versions prior to 2019-03-14. See the [changelog](stripe.com/docs/upgrades#2019-03-14) to learn more.



933
934
935
# File 'lib/stripe/resources/subscription.rb', line 933

def payment_behavior
  @payment_behavior
end

#payment_settingsObject

Payment settings to pass to invoices created by the subscription.



935
936
937
# File 'lib/stripe/resources/subscription.rb', line 935

def payment_settings
  @payment_settings
end

#pending_invoice_item_intervalObject

Specifies an interval for how often to bill for any pending invoice items. It is analogous to calling [Create an invoice](stripe.com/docs/api#create_invoice) for the given subscription at the specified interval.



937
938
939
# File 'lib/stripe/resources/subscription.rb', line 937

def pending_invoice_item_interval
  @pending_invoice_item_interval
end

#prebillingObject

If specified, the invoicing for the given billing cycle iterations will be processed now.



939
940
941
# File 'lib/stripe/resources/subscription.rb', line 939

def prebilling
  @prebilling
end

#proration_behaviorObject

Determines how to handle [prorations](stripe.com/docs/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes. The default value is `create_prorations`.



941
942
943
# File 'lib/stripe/resources/subscription.rb', line 941

def proration_behavior
  @proration_behavior
end

#proration_dateObject

If set, prorations will be calculated as though the subscription was updated at the given time. This can be used to apply exactly the same prorations that were previewed with the [create preview](stripe.com/docs/api/invoices/create_preview) endpoint. ‘proration_date` can also be used to implement custom proration logic, such as prorating by day instead of by second, by providing the time that you wish to use for proration calculations.



943
944
945
# File 'lib/stripe/resources/subscription.rb', line 943

def proration_date
  @proration_date
end

#transfer_dataObject

If specified, the funds from the subscription’s invoices will be transferred to the destination and the ID of the resulting transfers will be found on the resulting charges. This will be unset if you POST an empty value.



945
946
947
# File 'lib/stripe/resources/subscription.rb', line 945

def transfer_data
  @transfer_data
end

#trial_endObject

Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. This will always overwrite any trials that might apply via a subscribed plan. If set, ‘trial_end` will override the default trial period of the plan the customer is being subscribed to. The `billing_cycle_anchor` will be updated to the `trial_end` value. The special value `now` can be provided to end the customer’s trial immediately. Can be at most two years from ‘billing_cycle_anchor`.



947
948
949
# File 'lib/stripe/resources/subscription.rb', line 947

def trial_end
  @trial_end
end

#trial_from_planObject

Indicates if a plan’s ‘trial_period_days` should be applied to the subscription. Setting `trial_end` per subscription is preferred, and this defaults to `false`. Setting this flag to `true` together with `trial_end` is not allowed. See [Using trial periods on subscriptions](stripe.com/docs/billing/subscriptions/trials) to learn more.



949
950
951
# File 'lib/stripe/resources/subscription.rb', line 949

def trial_from_plan
  @trial_from_plan
end

#trial_settingsObject

Settings related to subscription trials.



951
952
953
# File 'lib/stripe/resources/subscription.rb', line 951

def trial_settings
  @trial_settings
end