Class: Stripe::Subscription::UpdateParams::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



323
324
325
326
327
328
# File 'lib/stripe/resources/subscription.rb', line 323

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



315
316
317
# File 'lib/stripe/resources/subscription.rb', line 315

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



317
318
319
# File 'lib/stripe/resources/subscription.rb', line 317

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



319
320
321
# File 'lib/stripe/resources/subscription.rb', line 319

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



321
322
323
# File 'lib/stripe/resources/subscription.rb', line 321

def promotion_code
  @promotion_code
end