Class: Stripe::Subscription::UpdateParams::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



304
305
306
307
308
# File 'lib/stripe/resources/subscription.rb', line 304

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



298
299
300
# File 'lib/stripe/resources/subscription.rb', line 298

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



300
301
302
# File 'lib/stripe/resources/subscription.rb', line 300

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



302
303
304
# File 'lib/stripe/resources/subscription.rb', line 302

def type
  @type
end