Class: Stripe::Subscription::UpdateParams::AddInvoiceItem::Period::Start
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::UpdateParams::AddInvoiceItem::Period::Start
- Defined in:
- lib/stripe/resources/subscription.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period.
-
#type ⇒ Object
Select how to calculate the start of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ Start
constructor
A new instance of Start.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ Start
Returns a new instance of Start.
365 366 367 368 |
# File 'lib/stripe/resources/subscription.rb', line 365 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.
361 362 363 |
# File 'lib/stripe/resources/subscription.rb', line 361 def @timestamp end |
#type ⇒ Object
Select how to calculate the start of the invoice item period.
363 364 365 |
# File 'lib/stripe/resources/subscription.rb', line 363 def type @type end |