Class: Stripe::Subscription::UpdateParams::AddInvoiceItem::Period::Start
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::UpdateParams::AddInvoiceItem::Period::Start
- Defined in:
- lib/stripe/resources/subscription.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period.
-
#type ⇒ Object
Select how to calculate the start of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ Start
constructor
A new instance of Start.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ Start
Returns a new instance of Start.
287 288 289 290 |
# File 'lib/stripe/resources/subscription.rb', line 287 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.
283 284 285 |
# File 'lib/stripe/resources/subscription.rb', line 283 def @timestamp end |
#type ⇒ Object
Select how to calculate the start of the invoice item period.
285 286 287 |
# File 'lib/stripe/resources/subscription.rb', line 285 def type @type end |