Class: Stripe::Subscription::UpdateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::UpdateParams::Discount
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
474 475 476 477 478 479 |
# File 'lib/stripe/resources/subscription.rb', line 474 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
466 467 468 |
# File 'lib/stripe/resources/subscription.rb', line 466 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
468 469 470 |
# File 'lib/stripe/resources/subscription.rb', line 468 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
470 471 472 |
# File 'lib/stripe/resources/subscription.rb', line 470 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
472 473 474 |
# File 'lib/stripe/resources/subscription.rb', line 472 def promotion_code @promotion_code end |