Class: Stripe::Subscription::UpdateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



369
370
371
372
373
# File 'lib/stripe/resources/subscription.rb', line 369

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



363
364
365
# File 'lib/stripe/resources/subscription.rb', line 363

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



365
366
367
# File 'lib/stripe/resources/subscription.rb', line 365

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



367
368
369
# File 'lib/stripe/resources/subscription.rb', line 367

def promotion_code
  @promotion_code
end