Class: Stripe::Subscription::UpdateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



431
432
433
434
435
436
# File 'lib/stripe/resources/subscription.rb', line 431

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



423
424
425
# File 'lib/stripe/resources/subscription.rb', line 423

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



425
426
427
# File 'lib/stripe/resources/subscription.rb', line 425

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



427
428
429
# File 'lib/stripe/resources/subscription.rb', line 427

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



429
430
431
# File 'lib/stripe/resources/subscription.rb', line 429

def promotion_code
  @promotion_code
end