Class: Stripe::Subscription::UpdateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



533
534
535
536
537
538
# File 'lib/stripe/resources/subscription.rb', line 533

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



522
523
524
# File 'lib/stripe/resources/subscription.rb', line 522

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



525
526
527
# File 'lib/stripe/resources/subscription.rb', line 525

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



528
529
530
# File 'lib/stripe/resources/subscription.rb', line 528

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



531
532
533
# File 'lib/stripe/resources/subscription.rb', line 531

def promotion_code
  @promotion_code
end