Class: Stripe::Subscription::UpdateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



416
417
418
419
420
# File 'lib/stripe/resources/subscription.rb', line 416

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



410
411
412
# File 'lib/stripe/resources/subscription.rb', line 410

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



412
413
414
# File 'lib/stripe/resources/subscription.rb', line 412

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



414
415
416
# File 'lib/stripe/resources/subscription.rb', line 414

def type
  @type
end