Class: Stripe::Subscription::UpdateParams::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::UpdateParams::Item
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: BillingThresholds, Discount, PriceData
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#clear_usage ⇒ Object
Delete all usage for a given subscription item.
-
#deleted ⇒ Object
A flag that, if set to ‘true`, will delete the specified item.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#id ⇒ Object
Subscription item to update.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#plan ⇒ Object
Plan ID for this item, as a string.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids.
Instance Method Summary collapse
-
#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item
Returns a new instance of Item.
671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 |
# File 'lib/stripe/resources/subscription.rb', line 671 def initialize( billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @billing_thresholds = billing_thresholds @clear_usage = clear_usage @deleted = deleted @discounts = discounts @id = id @metadata = @plan = plan @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
649 650 651 |
# File 'lib/stripe/resources/subscription.rb', line 649 def billing_thresholds @billing_thresholds end |
#clear_usage ⇒ Object
Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.
651 652 653 |
# File 'lib/stripe/resources/subscription.rb', line 651 def clear_usage @clear_usage end |
#deleted ⇒ Object
A flag that, if set to ‘true`, will delete the specified item.
653 654 655 |
# File 'lib/stripe/resources/subscription.rb', line 653 def deleted @deleted end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
655 656 657 |
# File 'lib/stripe/resources/subscription.rb', line 655 def discounts @discounts end |
#id ⇒ Object
Subscription item to update.
657 658 659 |
# File 'lib/stripe/resources/subscription.rb', line 657 def id @id end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
659 660 661 |
# File 'lib/stripe/resources/subscription.rb', line 659 def @metadata end |
#plan ⇒ Object
Plan ID for this item, as a string.
661 662 663 |
# File 'lib/stripe/resources/subscription.rb', line 661 def plan @plan end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.
663 664 665 |
# File 'lib/stripe/resources/subscription.rb', line 663 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
665 666 667 |
# File 'lib/stripe/resources/subscription.rb', line 665 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item.
667 668 669 |
# File 'lib/stripe/resources/subscription.rb', line 667 def quantity @quantity end |
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
669 670 671 |
# File 'lib/stripe/resources/subscription.rb', line 669 def tax_rates @tax_rates end |