Class: Stripe::Subscription::UpdateParams::Item

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
# File 'lib/stripe/resources/subscription.rb', line 622

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



600
601
602
# File 'lib/stripe/resources/subscription.rb', line 600

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



602
603
604
# File 'lib/stripe/resources/subscription.rb', line 602

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



604
605
606
# File 'lib/stripe/resources/subscription.rb', line 604

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



606
607
608
# File 'lib/stripe/resources/subscription.rb', line 606

def discounts
  @discounts
end

#idObject

Subscription item to update.



608
609
610
# File 'lib/stripe/resources/subscription.rb', line 608

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



610
611
612
# File 'lib/stripe/resources/subscription.rb', line 610

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



612
613
614
# File 'lib/stripe/resources/subscription.rb', line 612

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



614
615
616
# File 'lib/stripe/resources/subscription.rb', line 614

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



616
617
618
# File 'lib/stripe/resources/subscription.rb', line 616

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



618
619
620
# File 'lib/stripe/resources/subscription.rb', line 618

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



620
621
622
# File 'lib/stripe/resources/subscription.rb', line 620

def tax_rates
  @tax_rates
end