Class: Stripe::Subscription::UpdateParams::Item

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/stripe/resources/subscription.rb', line 481

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



459
460
461
# File 'lib/stripe/resources/subscription.rb', line 459

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



461
462
463
# File 'lib/stripe/resources/subscription.rb', line 461

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



463
464
465
# File 'lib/stripe/resources/subscription.rb', line 463

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



465
466
467
# File 'lib/stripe/resources/subscription.rb', line 465

def discounts
  @discounts
end

#idObject

Subscription item to update.



467
468
469
# File 'lib/stripe/resources/subscription.rb', line 467

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



469
470
471
# File 'lib/stripe/resources/subscription.rb', line 469

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



471
472
473
# File 'lib/stripe/resources/subscription.rb', line 471

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



473
474
475
# File 'lib/stripe/resources/subscription.rb', line 473

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



475
476
477
# File 'lib/stripe/resources/subscription.rb', line 475

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



477
478
479
# File 'lib/stripe/resources/subscription.rb', line 477

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



479
480
481
# File 'lib/stripe/resources/subscription.rb', line 479

def tax_rates
  @tax_rates
end