Class: Stripe::Subscription::UpdateParams::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::UpdateParams::Item::Discount
- Defined in:
- lib/stripe/resources/subscription.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
417 418 419 420 421 |
# File 'lib/stripe/resources/subscription.rb', line 417 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
411 412 413 |
# File 'lib/stripe/resources/subscription.rb', line 411 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
413 414 415 |
# File 'lib/stripe/resources/subscription.rb', line 413 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
415 416 417 |
# File 'lib/stripe/resources/subscription.rb', line 415 def promotion_code @promotion_code end |