Class: Stripe::Subscription::UpdateParams::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



410
411
412
413
414
# File 'lib/stripe/resources/subscription.rb', line 410

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



404
405
406
# File 'lib/stripe/resources/subscription.rb', line 404

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



406
407
408
# File 'lib/stripe/resources/subscription.rb', line 406

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



408
409
410
# File 'lib/stripe/resources/subscription.rb', line 408

def promotion_code
  @promotion_code
end