Class: Stripe::Subscription::UpdateParams::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



876
877
878
879
880
# File 'lib/stripe/resources/subscription.rb', line 876

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



870
871
872
# File 'lib/stripe/resources/subscription.rb', line 870

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



872
873
874
# File 'lib/stripe/resources/subscription.rb', line 872

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



874
875
876
# File 'lib/stripe/resources/subscription.rb', line 874

def type
  @type
end