Class: Stripe::Subscription::UpdateParams::Item::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::UpdateParams::Item::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
483 484 485 486 487 |
# File 'lib/stripe/resources/subscription.rb', line 483 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
477 478 479 |
# File 'lib/stripe/resources/subscription.rb', line 477 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
479 480 481 |
# File 'lib/stripe/resources/subscription.rb', line 479 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
481 482 483 |
# File 'lib/stripe/resources/subscription.rb', line 481 def type @type end |