Class: Stripe::Subscription::UpdateParams::PaymentSettings::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Subscription::UpdateParams::PaymentSettings::PaymentMethodOptions
- Defined in:
- lib/stripe/resources/subscription.rb
Defined Under Namespace
Classes: AcssDebit, Bancontact, Card, CustomerBalance, IdBankTransfer, Konbini, SepaDebit, UsBankAccount
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
-
#bancontact ⇒ Object
This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
-
#card ⇒ Object
This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
-
#customer_balance ⇒ Object
This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
-
#id_bank_transfer ⇒ Object
This sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.
-
#konbini ⇒ Object
This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
-
#sepa_debit ⇒ Object
This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
-
#us_bank_account ⇒ Object
This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, sepa_debit: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, sepa_debit: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 |
# File 'lib/stripe/resources/subscription.rb', line 758 def initialize( acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, sepa_debit: nil, us_bank_account: nil ) @acss_debit = acss_debit @bancontact = bancontact @card = card @customer_balance = customer_balance @id_bank_transfer = id_bank_transfer @konbini = konbini @sepa_debit = sepa_debit @us_bank_account = us_bank_account end |
Instance Attribute Details
#acss_debit ⇒ Object
This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
742 743 744 |
# File 'lib/stripe/resources/subscription.rb', line 742 def acss_debit @acss_debit end |
#bancontact ⇒ Object
This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
744 745 746 |
# File 'lib/stripe/resources/subscription.rb', line 744 def bancontact @bancontact end |
#card ⇒ Object
This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
746 747 748 |
# File 'lib/stripe/resources/subscription.rb', line 746 def card @card end |
#customer_balance ⇒ Object
This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
748 749 750 |
# File 'lib/stripe/resources/subscription.rb', line 748 def customer_balance @customer_balance end |
#id_bank_transfer ⇒ Object
This sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.
750 751 752 |
# File 'lib/stripe/resources/subscription.rb', line 750 def id_bank_transfer @id_bank_transfer end |
#konbini ⇒ Object
This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
752 753 754 |
# File 'lib/stripe/resources/subscription.rb', line 752 def konbini @konbini end |
#sepa_debit ⇒ Object
This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
754 755 756 |
# File 'lib/stripe/resources/subscription.rb', line 754 def sepa_debit @sepa_debit end |
#us_bank_account ⇒ Object
This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
756 757 758 |
# File 'lib/stripe/resources/subscription.rb', line 756 def us_bank_account @us_bank_account end |