Class: Stripe::Subscription::UpdateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



723
724
725
726
# File 'lib/stripe/resources/subscription.rb', line 723

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



719
720
721
# File 'lib/stripe/resources/subscription.rb', line 719

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



721
722
723
# File 'lib/stripe/resources/subscription.rb', line 721

def destination
  @destination
end