Class: Stripe::SubscriptionAttachCadenceParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_attach_cadence_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(billing_cadence: nil, expand: nil) ⇒ SubscriptionAttachCadenceParams

Returns a new instance of SubscriptionAttachCadenceParams.



11
12
13
14
# File 'lib/stripe/params/subscription_attach_cadence_params.rb', line 11

def initialize(billing_cadence: nil, expand: nil)
  @billing_cadence = billing_cadence
  @expand = expand
end

Instance Attribute Details

#billing_cadenceObject

The Billing Cadence which controls the timing of recurring invoice generation for this subscription. If unset, the subscription will bill according to its own configured schedule and create its own invoices. If set, this subscription will be billed by the cadence instead, potentially sharing invoices with the other subscriptions linked to that Cadence.



7
8
9
# File 'lib/stripe/params/subscription_attach_cadence_params.rb', line 7

def billing_cadence
  @billing_cadence
end

#expandObject

Specifies which fields in the response should be expanded.



9
10
11
# File 'lib/stripe/params/subscription_attach_cadence_params.rb', line 9

def expand
  @expand
end