Class: Stripe::SubscriptionCancelParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCancelParams
- Defined in:
- lib/stripe/params/subscription_cancel_params.rb
Defined Under Namespace
Classes: CancellationDetails
Instance Attribute Summary collapse
-
#cancellation_details ⇒ Object
Details about why this subscription was cancelled.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_now ⇒ Object
Will generate a final invoice that invoices for any un-invoiced metered usage and new/pending proration invoice items.
-
#prorate ⇒ Object
Will generate a proration invoice item that credits remaining unused time until the subscription period end.
Instance Method Summary collapse
-
#initialize(cancellation_details: nil, expand: nil, invoice_now: nil, prorate: nil) ⇒ SubscriptionCancelParams
constructor
A new instance of SubscriptionCancelParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(cancellation_details: nil, expand: nil, invoice_now: nil, prorate: nil) ⇒ SubscriptionCancelParams
Returns a new instance of SubscriptionCancelParams.
29 30 31 32 33 34 |
# File 'lib/stripe/params/subscription_cancel_params.rb', line 29 def initialize(cancellation_details: nil, expand: nil, invoice_now: nil, prorate: nil) @cancellation_details = cancellation_details @expand = @invoice_now = invoice_now @prorate = prorate end |
Instance Attribute Details
#cancellation_details ⇒ Object
Details about why this subscription was cancelled
21 22 23 |
# File 'lib/stripe/params/subscription_cancel_params.rb', line 21 def cancellation_details @cancellation_details end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
23 24 25 |
# File 'lib/stripe/params/subscription_cancel_params.rb', line 23 def @expand end |
#invoice_now ⇒ Object
Will generate a final invoice that invoices for any un-invoiced metered usage and new/pending proration invoice items. Defaults to false.
25 26 27 |
# File 'lib/stripe/params/subscription_cancel_params.rb', line 25 def invoice_now @invoice_now end |
#prorate ⇒ Object
Will generate a proration invoice item that credits remaining unused time until the subscription period end. Defaults to false.
27 28 29 |
# File 'lib/stripe/params/subscription_cancel_params.rb', line 27 def prorate @prorate end |