Class: Stripe::SubscriptionCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Defined Under Namespace
Classes: AddInvoiceItem, AutomaticTax, BillingCycleAnchorConfig, BillingMode, BillingSchedule, BillingThresholds, Discount, InvoiceSettings, Item, PaymentSettings, PendingInvoiceItemInterval, Prebilling, TransferData, TrialSettings
Instance Attribute Summary collapse
-
#add_invoice_items ⇒ Object
A list of prices and quantities that will generate invoice items appended to the next invoice for this subscription.
-
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#automatic_tax ⇒ Object
Automatic tax settings for this subscription.
-
#backdate_start_date ⇒ Object
A past timestamp to backdate the subscription’s start date to.
-
#billing_cycle_anchor ⇒ Object
A future timestamp in UTC format to anchor the subscription’s [billing cycle](docs.stripe.com/subscriptions/billing-cycle).
-
#billing_cycle_anchor_config ⇒ Object
Mutually exclusive with billing_cycle_anchor and only valid with monthly and yearly price intervals.
-
#billing_mode ⇒ Object
Controls how prorations and invoices for subscriptions are calculated and orchestrated.
-
#billing_schedules ⇒ Object
Sets the billing schedules for the subscription.
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#cancel_at ⇒ Object
A timestamp at which the subscription should cancel.
-
#cancel_at_period_end ⇒ Object
Indicate whether this subscription should cancel at the end of the current period (‘current_period_end`).
-
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
The identifier of the customer to subscribe.
-
#customer_account ⇒ Object
The identifier of the account representing the customer to subscribe.
-
#days_until_due ⇒ Object
Number of days a customer has to pay invoices generated by this subscription.
-
#default_payment_method ⇒ Object
ID of the default payment method for the subscription.
-
#default_source ⇒ Object
ID of the default payment source for the subscription.
-
#default_tax_rates ⇒ Object
The tax rates that will apply to any subscription item that does not have ‘tax_rates` set.
-
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
-
#items ⇒ Object
A list of up to 20 subscription items, each with an attached price.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#off_session ⇒ Object
Indicates if a customer is on or off-session while an invoice payment is attempted.
-
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the subscription’s invoices.
-
#payment_behavior ⇒ Object
Controls how Stripe handles the first invoice when payment is required and ‘collection_method=charge_automatically`.
-
#payment_settings ⇒ Object
Payment settings to pass to invoices created by the subscription.
-
#pending_invoice_item_interval ⇒ Object
Specifies an interval for how often to bill for any pending invoice items.
-
#prebilling ⇒ Object
If specified, the invoicing for the given billing cycle iterations will be processed now.
-
#proration_behavior ⇒ Object
Determines how to handle [prorations](docs.stripe.com/billing/subscriptions/prorations) resulting from the ‘billing_cycle_anchor`.
-
#transfer_data ⇒ Object
If specified, the funds from the subscription’s invoices will be transferred to the destination and the ID of the resulting transfers will be found on the resulting charges.
-
#trial_end ⇒ Object
Unix timestamp representing the end of the trial period the customer will get before being charged for the first time.
-
#trial_from_plan ⇒ Object
Indicates if a plan’s ‘trial_period_days` should be applied to the subscription.
-
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time.
-
#trial_settings ⇒ Object
Settings related to subscription trials.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, backdate_start_date: nil, billing_cycle_anchor: nil, billing_cycle_anchor_config: nil, billing_mode: nil, billing_schedules: nil, billing_thresholds: nil, cancel_at: nil, cancel_at_period_end: nil, collection_method: nil, currency: nil, customer: nil, customer_account: nil, days_until_due: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, invoice_settings: nil, items: nil, metadata: nil, off_session: nil, on_behalf_of: nil, payment_behavior: nil, payment_settings: nil, pending_invoice_item_interval: nil, prebilling: nil, proration_behavior: nil, transfer_data: nil, trial_end: nil, trial_from_plan: nil, trial_period_days: nil, trial_settings: nil) ⇒ SubscriptionCreateParams
Returns a new instance of SubscriptionCreateParams.
957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/stripe/params/subscription_create_params.rb', line 957 def initialize( add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, backdate_start_date: nil, billing_cycle_anchor: nil, billing_cycle_anchor_config: nil, billing_mode: nil, billing_schedules: nil, billing_thresholds: nil, cancel_at: nil, cancel_at_period_end: nil, collection_method: nil, currency: nil, customer: nil, customer_account: nil, days_until_due: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, invoice_settings: nil, items: nil, metadata: nil, off_session: nil, on_behalf_of: nil, payment_behavior: nil, payment_settings: nil, pending_invoice_item_interval: nil, prebilling: nil, proration_behavior: nil, transfer_data: nil, trial_end: nil, trial_from_plan: nil, trial_period_days: nil, trial_settings: nil ) @add_invoice_items = add_invoice_items @application_fee_percent = application_fee_percent @automatic_tax = automatic_tax @backdate_start_date = backdate_start_date @billing_cycle_anchor = billing_cycle_anchor @billing_cycle_anchor_config = billing_cycle_anchor_config @billing_mode = billing_mode @billing_schedules = billing_schedules @billing_thresholds = billing_thresholds @cancel_at = cancel_at @cancel_at_period_end = cancel_at_period_end @collection_method = collection_method @currency = currency @customer = customer @customer_account = customer_account @days_until_due = days_until_due @default_payment_method = default_payment_method @default_source = default_source @default_tax_rates = default_tax_rates @description = description @discounts = discounts @expand = @invoice_settings = invoice_settings @items = items @metadata = @off_session = off_session @on_behalf_of = on_behalf_of @payment_behavior = payment_behavior @payment_settings = payment_settings @pending_invoice_item_interval = pending_invoice_item_interval @prebilling = prebilling @proration_behavior = proration_behavior @transfer_data = transfer_data @trial_end = trial_end @trial_from_plan = trial_from_plan @trial_period_days = trial_period_days @trial_settings = trial_settings end |
Instance Attribute Details
#add_invoice_items ⇒ Object
A list of prices and quantities that will generate invoice items appended to the next invoice for this subscription. You may pass up to 20 items.
883 884 885 |
# File 'lib/stripe/params/subscription_create_params.rb', line 883 def add_invoice_items @add_invoice_items end |
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees [documentation](stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).
885 886 887 |
# File 'lib/stripe/params/subscription_create_params.rb', line 885 def application_fee_percent @application_fee_percent end |
#automatic_tax ⇒ Object
Automatic tax settings for this subscription.
887 888 889 |
# File 'lib/stripe/params/subscription_create_params.rb', line 887 def automatic_tax @automatic_tax end |
#backdate_start_date ⇒ Object
A past timestamp to backdate the subscription’s start date to. If set, the first invoice will contain line items for the timespan between the start date and the current time. Can be combined with trials and the billing cycle anchor.
889 890 891 |
# File 'lib/stripe/params/subscription_create_params.rb', line 889 def backdate_start_date @backdate_start_date end |
#billing_cycle_anchor ⇒ Object
A future timestamp in UTC format to anchor the subscription’s [billing cycle](docs.stripe.com/subscriptions/billing-cycle). The anchor is the reference point that aligns future billing cycle dates. It sets the day of week for ‘week` intervals, the day of month for `month` and `year` intervals, and the month of year for `year` intervals.
891 892 893 |
# File 'lib/stripe/params/subscription_create_params.rb', line 891 def billing_cycle_anchor @billing_cycle_anchor end |
#billing_cycle_anchor_config ⇒ Object
Mutually exclusive with billing_cycle_anchor and only valid with monthly and yearly price intervals. When provided, the billing_cycle_anchor is set to the next occurrence of the day_of_month at the hour, minute, and second UTC.
893 894 895 |
# File 'lib/stripe/params/subscription_create_params.rb', line 893 def billing_cycle_anchor_config @billing_cycle_anchor_config end |
#billing_mode ⇒ Object
Controls how prorations and invoices for subscriptions are calculated and orchestrated.
895 896 897 |
# File 'lib/stripe/params/subscription_create_params.rb', line 895 def billing_mode @billing_mode end |
#billing_schedules ⇒ Object
Sets the billing schedules for the subscription.
897 898 899 |
# File 'lib/stripe/params/subscription_create_params.rb', line 897 def billing_schedules @billing_schedules end |
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.
899 900 901 |
# File 'lib/stripe/params/subscription_create_params.rb', line 899 def billing_thresholds @billing_thresholds end |
#cancel_at ⇒ Object
A timestamp at which the subscription should cancel. If set to a date before the current period ends, this will cause a proration if prorations have been enabled using ‘proration_behavior`. If set during a future period, this will always cause a proration for that period.
901 902 903 |
# File 'lib/stripe/params/subscription_create_params.rb', line 901 def cancel_at @cancel_at end |
#cancel_at_period_end ⇒ Object
Indicate whether this subscription should cancel at the end of the current period (‘current_period_end`). Defaults to `false`.
903 904 905 |
# File 'lib/stripe/params/subscription_create_params.rb', line 903 def cancel_at_period_end @cancel_at_period_end end |
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay this subscription at the end of the cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically`.
905 906 907 |
# File 'lib/stripe/params/subscription_create_params.rb', line 905 def collection_method @collection_method end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
907 908 909 |
# File 'lib/stripe/params/subscription_create_params.rb', line 907 def currency @currency end |
#customer ⇒ Object
The identifier of the customer to subscribe.
909 910 911 |
# File 'lib/stripe/params/subscription_create_params.rb', line 909 def customer @customer end |
#customer_account ⇒ Object
The identifier of the account representing the customer to subscribe.
911 912 913 |
# File 'lib/stripe/params/subscription_create_params.rb', line 911 def customer_account @customer_account end |
#days_until_due ⇒ Object
Number of days a customer has to pay invoices generated by this subscription. Valid only for subscriptions where ‘collection_method` is set to `send_invoice`.
913 914 915 |
# File 'lib/stripe/params/subscription_create_params.rb', line 913 def days_until_due @days_until_due end |
#default_payment_method ⇒ Object
ID of the default payment method for the subscription. It must belong to the customer associated with the subscription. This takes precedence over ‘default_source`. If neither are set, invoices will use the customer’s [invoice_settings.default_payment_method](docs.stripe.com/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](docs.stripe.com/api/customers/object#customer_object-default_source).
915 916 917 |
# File 'lib/stripe/params/subscription_create_params.rb', line 915 def default_payment_method @default_payment_method end |
#default_source ⇒ Object
ID of the default payment source for the subscription. It must belong to the customer associated with the subscription and be in a chargeable state. If ‘default_payment_method` is also set, `default_payment_method` will take precedence. If neither are set, invoices will use the customer’s [invoice_settings.default_payment_method](docs.stripe.com/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](docs.stripe.com/api/customers/object#customer_object-default_source).
917 918 919 |
# File 'lib/stripe/params/subscription_create_params.rb', line 917 def default_source @default_source end |
#default_tax_rates ⇒ Object
The tax rates that will apply to any subscription item that does not have ‘tax_rates` set. Invoices created will have their `default_tax_rates` populated from the subscription.
919 920 921 |
# File 'lib/stripe/params/subscription_create_params.rb', line 919 def default_tax_rates @default_tax_rates end |
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
921 922 923 |
# File 'lib/stripe/params/subscription_create_params.rb', line 921 def description @description end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription. If not specified or empty, inherits the discount from the subscription’s customer.
923 924 925 |
# File 'lib/stripe/params/subscription_create_params.rb', line 923 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
925 926 927 |
# File 'lib/stripe/params/subscription_create_params.rb', line 925 def @expand end |
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
927 928 929 |
# File 'lib/stripe/params/subscription_create_params.rb', line 927 def invoice_settings @invoice_settings end |
#items ⇒ Object
A list of up to 20 subscription items, each with an attached price.
929 930 931 |
# File 'lib/stripe/params/subscription_create_params.rb', line 929 def items @items end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
931 932 933 |
# File 'lib/stripe/params/subscription_create_params.rb', line 931 def @metadata end |
#off_session ⇒ Object
Indicates if a customer is on or off-session while an invoice payment is attempted. Defaults to ‘false` (on-session).
933 934 935 |
# File 'lib/stripe/params/subscription_create_params.rb', line 933 def off_session @off_session end |
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the subscription’s invoices.
935 936 937 |
# File 'lib/stripe/params/subscription_create_params.rb', line 935 def on_behalf_of @on_behalf_of end |
#payment_behavior ⇒ Object
Controls how Stripe handles the first invoice when payment is required and ‘collection_method=charge_automatically`. Subscriptions with `collection_method=send_invoice` are automatically activated regardless of the first Invoice status.
937 938 939 |
# File 'lib/stripe/params/subscription_create_params.rb', line 937 def payment_behavior @payment_behavior end |
#payment_settings ⇒ Object
Payment settings to pass to invoices created by the subscription.
939 940 941 |
# File 'lib/stripe/params/subscription_create_params.rb', line 939 def payment_settings @payment_settings end |
#pending_invoice_item_interval ⇒ Object
Specifies an interval for how often to bill for any pending invoice items. It is analogous to calling [Create an invoice](/api/invoices/create) for the given subscription at the specified interval.
941 942 943 |
# File 'lib/stripe/params/subscription_create_params.rb', line 941 def pending_invoice_item_interval @pending_invoice_item_interval end |
#prebilling ⇒ Object
If specified, the invoicing for the given billing cycle iterations will be processed now.
943 944 945 |
# File 'lib/stripe/params/subscription_create_params.rb', line 943 def prebilling @prebilling end |
#proration_behavior ⇒ Object
Determines how to handle [prorations](docs.stripe.com/billing/subscriptions/prorations) resulting from the ‘billing_cycle_anchor`. If no value is passed, the default is `create_prorations`.
945 946 947 |
# File 'lib/stripe/params/subscription_create_params.rb', line 945 def proration_behavior @proration_behavior end |
#transfer_data ⇒ Object
If specified, the funds from the subscription’s invoices will be transferred to the destination and the ID of the resulting transfers will be found on the resulting charges.
947 948 949 |
# File 'lib/stripe/params/subscription_create_params.rb', line 947 def transfer_data @transfer_data end |
#trial_end ⇒ Object
Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. If set, trial_end will override the default trial period of the plan the customer is being subscribed to. The special value ‘now` can be provided to end the customer’s trial immediately. Can be at most two years from ‘billing_cycle_anchor`. See [Using trial periods on subscriptions](docs.stripe.com/billing/subscriptions/trials) to learn more.
949 950 951 |
# File 'lib/stripe/params/subscription_create_params.rb', line 949 def trial_end @trial_end end |
#trial_from_plan ⇒ Object
Indicates if a plan’s ‘trial_period_days` should be applied to the subscription. Setting `trial_end` per subscription is preferred, and this defaults to `false`. Setting this flag to `true` together with `trial_end` is not allowed. See [Using trial periods on subscriptions](docs.stripe.com/billing/subscriptions/trials) to learn more.
951 952 953 |
# File 'lib/stripe/params/subscription_create_params.rb', line 951 def trial_from_plan @trial_from_plan end |
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time. This will always overwrite any trials that might apply via a subscribed plan. See [Using trial periods on subscriptions](docs.stripe.com/billing/subscriptions/trials) to learn more.
953 954 955 |
# File 'lib/stripe/params/subscription_create_params.rb', line 953 def trial_period_days @trial_period_days end |
#trial_settings ⇒ Object
Settings related to subscription trials.
955 956 957 |
# File 'lib/stripe/params/subscription_create_params.rb', line 955 def trial_settings @trial_settings end |
Class Method Details
.field_encodings ⇒ Object
1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 |
# File 'lib/stripe/params/subscription_create_params.rb', line 1035 def self.field_encodings @field_encodings = { add_invoice_items: { kind: :array, element: { kind: :object, fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } }, }, }, items: { kind: :array, element: { kind: :object, fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } }, }, }, } end |