Class: Stripe::SubscriptionCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Defined Under Namespace

Classes: AddInvoiceItem, AutomaticTax, BillingCycleAnchorConfig, BillingMode, BillingSchedule, BillingThresholds, Discount, InvoiceSettings, Item, PaymentSettings, PendingInvoiceItemInterval, Prebilling, TransferData, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, backdate_start_date: nil, billing_cadence: nil, billing_cycle_anchor: nil, billing_cycle_anchor_config: nil, billing_mode: nil, billing_schedules: nil, billing_thresholds: nil, cancel_at: nil, cancel_at_period_end: nil, collection_method: nil, currency: nil, customer: nil, customer_account: nil, days_until_due: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, invoice_settings: nil, items: nil, metadata: nil, off_session: nil, on_behalf_of: nil, payment_behavior: nil, payment_settings: nil, pending_invoice_item_interval: nil, prebilling: nil, proration_behavior: nil, transfer_data: nil, trial_end: nil, trial_from_plan: nil, trial_period_days: nil, trial_settings: nil) ⇒ SubscriptionCreateParams

Returns a new instance of SubscriptionCreateParams.



878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
# File 'lib/stripe/params/subscription_create_params.rb', line 878

def initialize(
  add_invoice_items: nil,
  application_fee_percent: nil,
  automatic_tax: nil,
  backdate_start_date: nil,
  billing_cadence: nil,
  billing_cycle_anchor: nil,
  billing_cycle_anchor_config: nil,
  billing_mode: nil,
  billing_schedules: nil,
  billing_thresholds: nil,
  cancel_at: nil,
  cancel_at_period_end: nil,
  collection_method: nil,
  currency: nil,
  customer: nil,
  customer_account: nil,
  days_until_due: nil,
  default_payment_method: nil,
  default_source: nil,
  default_tax_rates: nil,
  description: nil,
  discounts: nil,
  expand: nil,
  invoice_settings: nil,
  items: nil,
  metadata: nil,
  off_session: nil,
  on_behalf_of: nil,
  payment_behavior: nil,
  payment_settings: nil,
  pending_invoice_item_interval: nil,
  prebilling: nil,
  proration_behavior: nil,
  transfer_data: nil,
  trial_end: nil,
  trial_from_plan: nil,
  trial_period_days: nil,
  trial_settings: nil
)
  @add_invoice_items = add_invoice_items
  @application_fee_percent = application_fee_percent
  @automatic_tax = automatic_tax
  @backdate_start_date = backdate_start_date
  @billing_cadence = billing_cadence
  @billing_cycle_anchor = billing_cycle_anchor
  @billing_cycle_anchor_config = billing_cycle_anchor_config
  @billing_mode = billing_mode
  @billing_schedules = billing_schedules
  @billing_thresholds = billing_thresholds
  @cancel_at = cancel_at
  @cancel_at_period_end = cancel_at_period_end
  @collection_method = collection_method
  @currency = currency
  @customer = customer
  @customer_account = 
  @days_until_due = days_until_due
  @default_payment_method = default_payment_method
  @default_source = default_source
  @default_tax_rates = default_tax_rates
  @description = description
  @discounts = discounts
  @expand = expand
  @invoice_settings = invoice_settings
  @items = items
  @metadata = 
  @off_session = off_session
  @on_behalf_of = on_behalf_of
  @payment_behavior = payment_behavior
  @payment_settings = payment_settings
  @pending_invoice_item_interval = pending_invoice_item_interval
  @prebilling = prebilling
  @proration_behavior = proration_behavior
  @transfer_data = transfer_data
  @trial_end = trial_end
  @trial_from_plan = trial_from_plan
  @trial_period_days = trial_period_days
  @trial_settings = trial_settings
end

Instance Attribute Details

#add_invoice_itemsObject

A list of prices and quantities that will generate invoice items appended to the next invoice for this subscription. You may pass up to 20 items.



792
793
794
# File 'lib/stripe/params/subscription_create_params.rb', line 792

def add_invoice_items
  @add_invoice_items
end

#application_fee_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees [documentation](stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).



794
795
796
# File 'lib/stripe/params/subscription_create_params.rb', line 794

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject

Automatic tax settings for this subscription.



796
797
798
# File 'lib/stripe/params/subscription_create_params.rb', line 796

def automatic_tax
  @automatic_tax
end

#backdate_start_dateObject

A past timestamp to backdate the subscription’s start date to. If set, the first invoice will contain line items for the timespan between the start date and the current time. Can be combined with trials and the billing cycle anchor.



798
799
800
# File 'lib/stripe/params/subscription_create_params.rb', line 798

def backdate_start_date
  @backdate_start_date
end

#billing_cadenceObject

The Billing Cadence which controls the timing of recurring invoice generation for this subscription. If unset, the subscription will bill according to its own configured schedule and create its own invoices. If set, this subscription will be billed by the cadence instead, potentially sharing invoices with the other subscriptions linked to that Cadence.



800
801
802
# File 'lib/stripe/params/subscription_create_params.rb', line 800

def billing_cadence
  @billing_cadence
end

#billing_cycle_anchorObject

A future timestamp in UTC format to anchor the subscription’s [billing cycle](stripe.com/docs/subscriptions/billing-cycle). The anchor is the reference point that aligns future billing cycle dates. It sets the day of week for ‘week` intervals, the day of month for `month` and `year` intervals, and the month of year for `year` intervals.



802
803
804
# File 'lib/stripe/params/subscription_create_params.rb', line 802

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_cycle_anchor_configObject

Mutually exclusive with billing_cycle_anchor and only valid with monthly and yearly price intervals. When provided, the billing_cycle_anchor is set to the next occurrence of the day_of_month at the hour, minute, and second UTC.



804
805
806
# File 'lib/stripe/params/subscription_create_params.rb', line 804

def billing_cycle_anchor_config
  @billing_cycle_anchor_config
end

#billing_modeObject

Controls how prorations and invoices for subscriptions are calculated and orchestrated.



806
807
808
# File 'lib/stripe/params/subscription_create_params.rb', line 806

def billing_mode
  @billing_mode
end

#billing_schedulesObject

Sets the billing schedules for the subscription.



808
809
810
# File 'lib/stripe/params/subscription_create_params.rb', line 808

def billing_schedules
  @billing_schedules
end

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.



810
811
812
# File 'lib/stripe/params/subscription_create_params.rb', line 810

def billing_thresholds
  @billing_thresholds
end

#cancel_atObject

A timestamp at which the subscription should cancel. If set to a date before the current period ends, this will cause a proration if prorations have been enabled using ‘proration_behavior`. If set during a future period, this will always cause a proration for that period.



812
813
814
# File 'lib/stripe/params/subscription_create_params.rb', line 812

def cancel_at
  @cancel_at
end

#cancel_at_period_endObject

Indicate whether this subscription should cancel at the end of the current period (‘current_period_end`). Defaults to `false`.



814
815
816
# File 'lib/stripe/params/subscription_create_params.rb', line 814

def cancel_at_period_end
  @cancel_at_period_end
end

#collection_methodObject

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay this subscription at the end of the cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically`.



816
817
818
# File 'lib/stripe/params/subscription_create_params.rb', line 816

def collection_method
  @collection_method
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



818
819
820
# File 'lib/stripe/params/subscription_create_params.rb', line 818

def currency
  @currency
end

#customerObject

The identifier of the customer to subscribe.



820
821
822
# File 'lib/stripe/params/subscription_create_params.rb', line 820

def customer
  @customer
end

#customer_accountObject

The identifier of the account to subscribe.



822
823
824
# File 'lib/stripe/params/subscription_create_params.rb', line 822

def 
  @customer_account
end

#days_until_dueObject

Number of days a customer has to pay invoices generated by this subscription. Valid only for subscriptions where ‘collection_method` is set to `send_invoice`.



824
825
826
# File 'lib/stripe/params/subscription_create_params.rb', line 824

def days_until_due
  @days_until_due
end

#default_payment_methodObject

ID of the default payment method for the subscription. It must belong to the customer associated with the subscription. This takes precedence over ‘default_source`. If neither are set, invoices will use the customer’s [invoice_settings.default_payment_method](stripe.com/docs/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](stripe.com/docs/api/customers/object#customer_object-default_source).



826
827
828
# File 'lib/stripe/params/subscription_create_params.rb', line 826

def default_payment_method
  @default_payment_method
end

#default_sourceObject

ID of the default payment source for the subscription. It must belong to the customer associated with the subscription and be in a chargeable state. If ‘default_payment_method` is also set, `default_payment_method` will take precedence. If neither are set, invoices will use the customer’s [invoice_settings.default_payment_method](stripe.com/docs/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](stripe.com/docs/api/customers/object#customer_object-default_source).



828
829
830
# File 'lib/stripe/params/subscription_create_params.rb', line 828

def default_source
  @default_source
end

#default_tax_ratesObject

The tax rates that will apply to any subscription item that does not have ‘tax_rates` set. Invoices created will have their `default_tax_rates` populated from the subscription.



830
831
832
# File 'lib/stripe/params/subscription_create_params.rb', line 830

def default_tax_rates
  @default_tax_rates
end

#descriptionObject

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



832
833
834
# File 'lib/stripe/params/subscription_create_params.rb', line 832

def description
  @description
end

#discountsObject

The coupons to redeem into discounts for the subscription. If not specified or empty, inherits the discount from the subscription’s customer.



834
835
836
# File 'lib/stripe/params/subscription_create_params.rb', line 834

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



836
837
838
# File 'lib/stripe/params/subscription_create_params.rb', line 836

def expand
  @expand
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



838
839
840
# File 'lib/stripe/params/subscription_create_params.rb', line 838

def invoice_settings
  @invoice_settings
end

#itemsObject

A list of up to 20 subscription items, each with an attached price.



840
841
842
# File 'lib/stripe/params/subscription_create_params.rb', line 840

def items
  @items
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



842
843
844
# File 'lib/stripe/params/subscription_create_params.rb', line 842

def 
  @metadata
end

#off_sessionObject

Indicates if a customer is on or off-session while an invoice payment is attempted. Defaults to ‘false` (on-session).



844
845
846
# File 'lib/stripe/params/subscription_create_params.rb', line 844

def off_session
  @off_session
end

#on_behalf_ofObject

The account on behalf of which to charge, for each of the subscription’s invoices.



846
847
848
# File 'lib/stripe/params/subscription_create_params.rb', line 846

def on_behalf_of
  @on_behalf_of
end

#payment_behaviorObject

Only applies to subscriptions with ‘collection_method=charge_automatically`.

Use ‘allow_incomplete` to create Subscriptions with `status=incomplete` if the first invoice can’t be paid. Creating Subscriptions with this status allows you to manage scenarios where additional customer actions are needed to pay a subscription’s invoice. For example, SCA regulation may require 3DS authentication to complete payment. See the [SCA Migration Guide](stripe.com/docs/billing/migration/strong-customer-authentication) for Billing to learn more. This is the default behavior.

Use ‘default_incomplete` to create Subscriptions with `status=incomplete` when the first invoice requires payment, otherwise start as active. Subscriptions transition to `status=active` when successfully confirming the PaymentIntent on the first invoice. This allows simpler management of scenarios where additional customer actions are needed to pay a subscription’s invoice, such as failed payments, [SCA regulation](stripe.com/docs/billing/migration/strong-customer-authentication), or collecting a mandate for a bank debit payment method. If the PaymentIntent is not confirmed within 23 hours Subscriptions transition to `status=incomplete_expired`, which is a terminal state.

Use ‘error_if_incomplete` if you want Stripe to return an HTTP 402 status code if a subscription’s first invoice can’t be paid. For example, if a payment method requires 3DS authentication due to SCA regulation and further customer action is needed, this parameter doesn’t create a Subscription and returns an error instead. This was the default behavior for API versions prior to 2019-03-14. See the [changelog](stripe.com/docs/upgrades#2019-03-14) to learn more.

‘pending_if_incomplete` is only used with updates and cannot be passed when creating a Subscription.

Subscriptions with ‘collection_method=send_invoice` are automatically activated regardless of the first Invoice status.



858
859
860
# File 'lib/stripe/params/subscription_create_params.rb', line 858

def payment_behavior
  @payment_behavior
end

#payment_settingsObject

Payment settings to pass to invoices created by the subscription.



860
861
862
# File 'lib/stripe/params/subscription_create_params.rb', line 860

def payment_settings
  @payment_settings
end

#pending_invoice_item_intervalObject

Specifies an interval for how often to bill for any pending invoice items. It is analogous to calling [Create an invoice](stripe.com/docs/api#create_invoice) for the given subscription at the specified interval.



862
863
864
# File 'lib/stripe/params/subscription_create_params.rb', line 862

def pending_invoice_item_interval
  @pending_invoice_item_interval
end

#prebillingObject

If specified, the invoicing for the given billing cycle iterations will be processed now.



864
865
866
# File 'lib/stripe/params/subscription_create_params.rb', line 864

def prebilling
  @prebilling
end

#proration_behaviorObject

Determines how to handle [prorations](stripe.com/docs/billing/subscriptions/prorations) resulting from the ‘billing_cycle_anchor`. If no value is passed, the default is `create_prorations`.



866
867
868
# File 'lib/stripe/params/subscription_create_params.rb', line 866

def proration_behavior
  @proration_behavior
end

#transfer_dataObject

If specified, the funds from the subscription’s invoices will be transferred to the destination and the ID of the resulting transfers will be found on the resulting charges.



868
869
870
# File 'lib/stripe/params/subscription_create_params.rb', line 868

def transfer_data
  @transfer_data
end

#trial_endObject

Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. If set, trial_end will override the default trial period of the plan the customer is being subscribed to. The special value ‘now` can be provided to end the customer’s trial immediately. Can be at most two years from ‘billing_cycle_anchor`. See [Using trial periods on subscriptions](stripe.com/docs/billing/subscriptions/trials) to learn more.



870
871
872
# File 'lib/stripe/params/subscription_create_params.rb', line 870

def trial_end
  @trial_end
end

#trial_from_planObject

Indicates if a plan’s ‘trial_period_days` should be applied to the subscription. Setting `trial_end` per subscription is preferred, and this defaults to `false`. Setting this flag to `true` together with `trial_end` is not allowed. See [Using trial periods on subscriptions](stripe.com/docs/billing/subscriptions/trials) to learn more.



872
873
874
# File 'lib/stripe/params/subscription_create_params.rb', line 872

def trial_from_plan
  @trial_from_plan
end

#trial_period_daysObject

Integer representing the number of trial period days before the customer is charged for the first time. This will always overwrite any trials that might apply via a subscribed plan. See [Using trial periods on subscriptions](stripe.com/docs/billing/subscriptions/trials) to learn more.



874
875
876
# File 'lib/stripe/params/subscription_create_params.rb', line 874

def trial_period_days
  @trial_period_days
end

#trial_settingsObject

Settings related to subscription trials.



876
877
878
# File 'lib/stripe/params/subscription_create_params.rb', line 876

def trial_settings
  @trial_settings
end