Class: Stripe::SubscriptionCreateParams::BillingCycleAnchorConfig

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig

Returns a new instance of BillingCycleAnchorConfig.



190
191
192
193
194
195
196
# File 'lib/stripe/params/subscription_create_params.rb', line 190

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



180
181
182
# File 'lib/stripe/params/subscription_create_params.rb', line 180

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



182
183
184
# File 'lib/stripe/params/subscription_create_params.rb', line 182

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



184
185
186
# File 'lib/stripe/params/subscription_create_params.rb', line 184

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



186
187
188
# File 'lib/stripe/params/subscription_create_params.rb', line 186

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



188
189
190
# File 'lib/stripe/params/subscription_create_params.rb', line 188

def second
  @second
end