Class: Stripe::SubscriptionCreateParams::BillingCycleAnchorConfig

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig

Returns a new instance of BillingCycleAnchorConfig.



180
181
182
183
184
185
186
# File 'lib/stripe/params/subscription_create_params.rb', line 180

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



170
171
172
# File 'lib/stripe/params/subscription_create_params.rb', line 170

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



172
173
174
# File 'lib/stripe/params/subscription_create_params.rb', line 172

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



174
175
176
# File 'lib/stripe/params/subscription_create_params.rb', line 174

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



176
177
178
# File 'lib/stripe/params/subscription_create_params.rb', line 176

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



178
179
180
# File 'lib/stripe/params/subscription_create_params.rb', line 178

def second
  @second
end