Class: Stripe::SubscriptionCreateParams::BillingCycleAnchorConfig
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::BillingCycleAnchorConfig
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig
constructor
A new instance of BillingCycleAnchorConfig.
Methods inherited from RequestParams
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig
Returns a new instance of BillingCycleAnchorConfig.
180 181 182 183 184 185 186 |
# File 'lib/stripe/params/subscription_create_params.rb', line 180 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
170 171 172 |
# File 'lib/stripe/params/subscription_create_params.rb', line 170 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
172 173 174 |
# File 'lib/stripe/params/subscription_create_params.rb', line 172 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
174 175 176 |
# File 'lib/stripe/params/subscription_create_params.rb', line 174 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
176 177 178 |
# File 'lib/stripe/params/subscription_create_params.rb', line 176 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
178 179 180 |
# File 'lib/stripe/params/subscription_create_params.rb', line 178 def second @second end |