Class: Stripe::SubscriptionCreateParams::BillingSchedule::AppliesTo
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::BillingSchedule::AppliesTo
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Instance Attribute Summary collapse
-
#price ⇒ Object
The ID of the price object.
-
#type ⇒ Object
Controls which subscription items the billing schedule applies to.
Instance Method Summary collapse
-
#initialize(price: nil, type: nil) ⇒ AppliesTo
constructor
A new instance of AppliesTo.
Methods inherited from RequestParams
Constructor Details
#initialize(price: nil, type: nil) ⇒ AppliesTo
Returns a new instance of AppliesTo.
216 217 218 219 |
# File 'lib/stripe/params/subscription_create_params.rb', line 216 def initialize(price: nil, type: nil) @price = price @type = type end |
Instance Attribute Details
#price ⇒ Object
The ID of the price object.
212 213 214 |
# File 'lib/stripe/params/subscription_create_params.rb', line 212 def price @price end |
#type ⇒ Object
Controls which subscription items the billing schedule applies to.
214 215 216 |
# File 'lib/stripe/params/subscription_create_params.rb', line 214 def type @type end |