Class: Stripe::SubscriptionCreateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::Discount
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
318 319 320 321 322 323 |
# File 'lib/stripe/params/subscription_create_params.rb', line 318 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
310 311 312 |
# File 'lib/stripe/params/subscription_create_params.rb', line 310 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
312 313 314 |
# File 'lib/stripe/params/subscription_create_params.rb', line 312 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
314 315 316 |
# File 'lib/stripe/params/subscription_create_params.rb', line 314 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
316 317 318 |
# File 'lib/stripe/params/subscription_create_params.rb', line 316 def promotion_code @promotion_code end |