Class: Stripe::SubscriptionCreateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Defined Under Namespace

Classes: DiscountEnd, Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount

Returns a new instance of Discount.



353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/stripe/params/subscription_create_params.rb', line 353

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  promotion_code: nil,
  settings: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
  @settings = settings
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



343
344
345
# File 'lib/stripe/params/subscription_create_params.rb', line 343

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



345
346
347
# File 'lib/stripe/params/subscription_create_params.rb', line 345

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



347
348
349
# File 'lib/stripe/params/subscription_create_params.rb', line 347

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



349
350
351
# File 'lib/stripe/params/subscription_create_params.rb', line 349

def promotion_code
  @promotion_code
end

#settingsObject

Settings for discount application including service period anchoring.



351
352
353
# File 'lib/stripe/params/subscription_create_params.rb', line 351

def settings
  @settings
end