Class: Stripe::SubscriptionCreateParams::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



314
315
316
317
318
319
320
# File 'lib/stripe/params/subscription_create_params.rb', line 314

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



304
305
306
# File 'lib/stripe/params/subscription_create_params.rb', line 304

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



306
307
308
# File 'lib/stripe/params/subscription_create_params.rb', line 306

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



308
309
310
# File 'lib/stripe/params/subscription_create_params.rb', line 308

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



310
311
312
# File 'lib/stripe/params/subscription_create_params.rb', line 310

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



312
313
314
# File 'lib/stripe/params/subscription_create_params.rb', line 312

def second
  @second
end