Class: Stripe::SubscriptionCreateParams::InvoiceSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Defined Under Namespace

Classes: CustomField, Issuer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil) ⇒ InvoiceSettings

Returns a new instance of InvoiceSettings.



365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/stripe/params/subscription_create_params.rb', line 365

def initialize(
  account_tax_ids: nil,
  custom_fields: nil,
  description: nil,
  footer: nil,
  issuer: nil
)
  @account_tax_ids = 
  @custom_fields = custom_fields
  @description = description
  @footer = footer
  @issuer = issuer
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the subscription. Will be set on invoices generated by the subscription.



355
356
357
# File 'lib/stripe/params/subscription_create_params.rb', line 355

def 
  @account_tax_ids
end

#custom_fieldsObject

A list of up to 4 custom fields to be displayed on the invoice.



357
358
359
# File 'lib/stripe/params/subscription_create_params.rb', line 357

def custom_fields
  @custom_fields
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



359
360
361
# File 'lib/stripe/params/subscription_create_params.rb', line 359

def description
  @description
end

Footer to be displayed on the invoice.



361
362
363
# File 'lib/stripe/params/subscription_create_params.rb', line 361

def footer
  @footer
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



363
364
365
# File 'lib/stripe/params/subscription_create_params.rb', line 363

def issuer
  @issuer
end