Class: Stripe::SubscriptionCreateParams::Item

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Defined Under Namespace

Classes: BillingThresholds, CurrentTrial, Discount, PriceData, Trial

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(billing_thresholds: nil, current_trial: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Item

Returns a new instance of Item.



627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
# File 'lib/stripe/params/subscription_create_params.rb', line 627

def initialize(
  billing_thresholds: nil,
  current_trial: nil,
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @billing_thresholds = billing_thresholds
  @current_trial = current_trial
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



607
608
609
# File 'lib/stripe/params/subscription_create_params.rb', line 607

def billing_thresholds
  @billing_thresholds
end

#current_trialObject

The trial offer to apply to this subscription item.



609
610
611
# File 'lib/stripe/params/subscription_create_params.rb', line 609

def current_trial
  @current_trial
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



611
612
613
# File 'lib/stripe/params/subscription_create_params.rb', line 611

def discounts
  @discounts
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



613
614
615
# File 'lib/stripe/params/subscription_create_params.rb', line 613

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



615
616
617
# File 'lib/stripe/params/subscription_create_params.rb', line 615

def plan
  @plan
end

#priceObject

The ID of the price object.



617
618
619
# File 'lib/stripe/params/subscription_create_params.rb', line 617

def price
  @price
end

#price_dataObject

Data used to generate a new Price object inline.



619
620
621
# File 'lib/stripe/params/subscription_create_params.rb', line 619

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



621
622
623
# File 'lib/stripe/params/subscription_create_params.rb', line 621

def quantity
  @quantity
end

#tax_ratesObject

A list of Tax Rate ids. These Tax Rates will override the default_tax_rates on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



623
624
625
# File 'lib/stripe/params/subscription_create_params.rb', line 623

def tax_rates
  @tax_rates
end

#trialObject

Define options to configure the trial on the subscription item.



625
626
627
# File 'lib/stripe/params/subscription_create_params.rb', line 625

def trial
  @trial
end

Class Method Details

.field_encodingsObject



651
652
653
654
655
# File 'lib/stripe/params/subscription_create_params.rb', line 651

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end