Class: Stripe::SubscriptionCreateParams::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::Item
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Defined Under Namespace
Classes: BillingThresholds, Discount, PriceData
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#plan ⇒ Object
Plan ID for this item, as a string.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new Price object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
A list of Tax Rate ids.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item
Returns a new instance of Item.
411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'lib/stripe/params/subscription_create_params.rb', line 411 def initialize( billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @billing_thresholds = billing_thresholds @discounts = discounts @metadata = @plan = plan @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
395 396 397 |
# File 'lib/stripe/params/subscription_create_params.rb', line 395 def billing_thresholds @billing_thresholds end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
397 398 399 |
# File 'lib/stripe/params/subscription_create_params.rb', line 397 def discounts @discounts end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
399 400 401 |
# File 'lib/stripe/params/subscription_create_params.rb', line 399 def @metadata end |
#plan ⇒ Object
Plan ID for this item, as a string.
401 402 403 |
# File 'lib/stripe/params/subscription_create_params.rb', line 401 def plan @plan end |
#price ⇒ Object
The ID of the price object.
403 404 405 |
# File 'lib/stripe/params/subscription_create_params.rb', line 403 def price @price end |
#price_data ⇒ Object
Data used to generate a new Price object inline.
405 406 407 |
# File 'lib/stripe/params/subscription_create_params.rb', line 405 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item.
407 408 409 |
# File 'lib/stripe/params/subscription_create_params.rb', line 407 def quantity @quantity end |
#tax_rates ⇒ Object
A list of Tax Rate ids. These Tax Rates will override the default_tax_rates on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
409 410 411 |
# File 'lib/stripe/params/subscription_create_params.rb', line 409 def tax_rates @tax_rates end |
Class Method Details
.field_encodings ⇒ Object
431 432 433 434 435 |
# File 'lib/stripe/params/subscription_create_params.rb', line 431 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |