Class: Stripe::SubscriptionCreateParams::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::Item
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Defined Under Namespace
Classes: BillingThresholds, Discount, PriceData
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#plan ⇒ Object
Plan ID for this item, as a string.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item
Returns a new instance of Item.
384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/stripe/params/subscription_create_params.rb', line 384 def initialize( billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @billing_thresholds = billing_thresholds @discounts = discounts @metadata = @plan = plan @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
368 369 370 |
# File 'lib/stripe/params/subscription_create_params.rb', line 368 def billing_thresholds @billing_thresholds end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
370 371 372 |
# File 'lib/stripe/params/subscription_create_params.rb', line 370 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
372 373 374 |
# File 'lib/stripe/params/subscription_create_params.rb', line 372 def @metadata end |
#plan ⇒ Object
Plan ID for this item, as a string.
374 375 376 |
# File 'lib/stripe/params/subscription_create_params.rb', line 374 def plan @plan end |
#price ⇒ Object
The ID of the price object.
376 377 378 |
# File 'lib/stripe/params/subscription_create_params.rb', line 376 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
378 379 380 |
# File 'lib/stripe/params/subscription_create_params.rb', line 378 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item.
380 381 382 |
# File 'lib/stripe/params/subscription_create_params.rb', line 380 def quantity @quantity end |
#tax_rates ⇒ Object
A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
382 383 384 |
# File 'lib/stripe/params/subscription_create_params.rb', line 382 def tax_rates @tax_rates end |
Class Method Details
.field_encodings ⇒ Object
404 405 406 407 408 |
# File 'lib/stripe/params/subscription_create_params.rb', line 404 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |