Class: Stripe::SubscriptionCreateParams::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::Item
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Defined Under Namespace
Classes: BillingThresholds, CurrentTrial, Discount, PriceData, Trial
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#current_trial ⇒ Object
The trial offer to apply to this subscription item.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#plan ⇒ Object
Plan ID for this item, as a string.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids.
-
#trial ⇒ Object
Define options to configure the trial on the subscription item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_thresholds: nil, current_trial: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(billing_thresholds: nil, current_trial: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Item
Returns a new instance of Item.
492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 |
# File 'lib/stripe/params/subscription_create_params.rb', line 492 def initialize( billing_thresholds: nil, current_trial: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil ) @billing_thresholds = billing_thresholds @current_trial = current_trial @discounts = discounts @metadata = @plan = plan @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
472 473 474 |
# File 'lib/stripe/params/subscription_create_params.rb', line 472 def billing_thresholds @billing_thresholds end |
#current_trial ⇒ Object
The trial offer to apply to this subscription item.
474 475 476 |
# File 'lib/stripe/params/subscription_create_params.rb', line 474 def current_trial @current_trial end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
476 477 478 |
# File 'lib/stripe/params/subscription_create_params.rb', line 476 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
478 479 480 |
# File 'lib/stripe/params/subscription_create_params.rb', line 478 def @metadata end |
#plan ⇒ Object
Plan ID for this item, as a string.
480 481 482 |
# File 'lib/stripe/params/subscription_create_params.rb', line 480 def plan @plan end |
#price ⇒ Object
The ID of the price object.
482 483 484 |
# File 'lib/stripe/params/subscription_create_params.rb', line 482 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
484 485 486 |
# File 'lib/stripe/params/subscription_create_params.rb', line 484 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item.
486 487 488 |
# File 'lib/stripe/params/subscription_create_params.rb', line 486 def quantity @quantity end |
#tax_rates ⇒ Object
A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
488 489 490 |
# File 'lib/stripe/params/subscription_create_params.rb', line 488 def tax_rates @tax_rates end |
#trial ⇒ Object
Define options to configure the trial on the subscription item.
490 491 492 |
# File 'lib/stripe/params/subscription_create_params.rb', line 490 def trial @trial end |
Class Method Details
.field_encodings ⇒ Object
516 517 518 519 520 |
# File 'lib/stripe/params/subscription_create_params.rb', line 516 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |