Class: Stripe::SubscriptionCreateParams::Item

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Defined Under Namespace

Classes: BillingThresholds, CurrentTrial, Discount, PriceData, Trial

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(billing_thresholds: nil, current_trial: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Item

Returns a new instance of Item.



596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
# File 'lib/stripe/params/subscription_create_params.rb', line 596

def initialize(
  billing_thresholds: nil,
  current_trial: nil,
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @billing_thresholds = billing_thresholds
  @current_trial = current_trial
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



576
577
578
# File 'lib/stripe/params/subscription_create_params.rb', line 576

def billing_thresholds
  @billing_thresholds
end

#current_trialObject

The trial offer to apply to this subscription item.



578
579
580
# File 'lib/stripe/params/subscription_create_params.rb', line 578

def current_trial
  @current_trial
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



580
581
582
# File 'lib/stripe/params/subscription_create_params.rb', line 580

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



582
583
584
# File 'lib/stripe/params/subscription_create_params.rb', line 582

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



584
585
586
# File 'lib/stripe/params/subscription_create_params.rb', line 584

def plan
  @plan
end

#priceObject

The ID of the price object.



586
587
588
# File 'lib/stripe/params/subscription_create_params.rb', line 586

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.



588
589
590
# File 'lib/stripe/params/subscription_create_params.rb', line 588

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



590
591
592
# File 'lib/stripe/params/subscription_create_params.rb', line 590

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



592
593
594
# File 'lib/stripe/params/subscription_create_params.rb', line 592

def tax_rates
  @tax_rates
end

#trialObject

Define options to configure the trial on the subscription item.



594
595
596
# File 'lib/stripe/params/subscription_create_params.rb', line 594

def trial
  @trial
end

Class Method Details

.field_encodingsObject



620
621
622
623
624
# File 'lib/stripe/params/subscription_create_params.rb', line 620

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end