Class: Stripe::SubscriptionCreateParams::Item

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Defined Under Namespace

Classes: BillingThresholds, CurrentTrial, Discount, PriceData, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, current_trial: nil) ⇒ Item

Returns a new instance of Item.



478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
# File 'lib/stripe/params/subscription_create_params.rb', line 478

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil,
  current_trial: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
  @current_trial = current_trial
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



458
459
460
# File 'lib/stripe/params/subscription_create_params.rb', line 458

def billing_thresholds
  @billing_thresholds
end

#current_trialObject

The trial offer to apply to this subscription item.



476
477
478
# File 'lib/stripe/params/subscription_create_params.rb', line 476

def current_trial
  @current_trial
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



460
461
462
# File 'lib/stripe/params/subscription_create_params.rb', line 460

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



462
463
464
# File 'lib/stripe/params/subscription_create_params.rb', line 462

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



464
465
466
# File 'lib/stripe/params/subscription_create_params.rb', line 464

def plan
  @plan
end

#priceObject

The ID of the price object.



466
467
468
# File 'lib/stripe/params/subscription_create_params.rb', line 466

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



468
469
470
# File 'lib/stripe/params/subscription_create_params.rb', line 468

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



470
471
472
# File 'lib/stripe/params/subscription_create_params.rb', line 470

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



472
473
474
# File 'lib/stripe/params/subscription_create_params.rb', line 472

def tax_rates
  @tax_rates
end

#trialObject

Define options to configure the trial on the subscription item.



474
475
476
# File 'lib/stripe/params/subscription_create_params.rb', line 474

def trial
  @trial
end