Class: Stripe::SubscriptionCreateParams::Item::CurrentTrial

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(trial_end: nil, trial_offer: nil) ⇒ CurrentTrial

Returns a new instance of CurrentTrial.



365
366
367
368
# File 'lib/stripe/params/subscription_create_params.rb', line 365

def initialize(trial_end: nil, trial_offer: nil)
  @trial_end = trial_end
  @trial_offer = trial_offer
end

Instance Attribute Details

#trial_endObject

Unix timestamp representing the end of the trial offer period. Required when the trial offer has ‘duration.type=timestamp`. Cannot be specified when `duration.type=relative`.



361
362
363
# File 'lib/stripe/params/subscription_create_params.rb', line 361

def trial_end
  @trial_end
end

#trial_offerObject

The ID of the trial offer to apply to the subscription item.



363
364
365
# File 'lib/stripe/params/subscription_create_params.rb', line 363

def trial_offer
  @trial_offer
end