Class: Stripe::SubscriptionCreateParams::Item::CurrentTrial
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::Item::CurrentTrial
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Instance Attribute Summary collapse
-
#trial_end ⇒ Object
Unix timestamp representing the end of the trial offer period.
-
#trial_offer ⇒ Object
The ID of the trial offer to apply to the subscription item.
Instance Method Summary collapse
-
#initialize(trial_end: nil, trial_offer: nil) ⇒ CurrentTrial
constructor
A new instance of CurrentTrial.
Methods inherited from RequestParams
Constructor Details
#initialize(trial_end: nil, trial_offer: nil) ⇒ CurrentTrial
Returns a new instance of CurrentTrial.
407 408 409 410 |
# File 'lib/stripe/params/subscription_create_params.rb', line 407 def initialize(trial_end: nil, trial_offer: nil) @trial_end = trial_end @trial_offer = trial_offer end |
Instance Attribute Details
#trial_end ⇒ Object
Unix timestamp representing the end of the trial offer period. Required when the trial offer has ‘duration.type=timestamp`. Cannot be specified when `duration.type=relative`.
403 404 405 |
# File 'lib/stripe/params/subscription_create_params.rb', line 403 def trial_end @trial_end end |
#trial_offer ⇒ Object
The ID of the trial offer to apply to the subscription item.
405 406 407 |
# File 'lib/stripe/params/subscription_create_params.rb', line 405 def trial_offer @trial_offer end |