Class: Stripe::SubscriptionCreateParams::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



410
411
412
413
414
415
# File 'lib/stripe/params/subscription_create_params.rb', line 410

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



402
403
404
# File 'lib/stripe/params/subscription_create_params.rb', line 402

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



404
405
406
# File 'lib/stripe/params/subscription_create_params.rb', line 404

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



406
407
408
# File 'lib/stripe/params/subscription_create_params.rb', line 406

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



408
409
410
# File 'lib/stripe/params/subscription_create_params.rb', line 408

def promotion_code
  @promotion_code
end