Class: Stripe::SubscriptionCreateParams::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



384
385
386
387
388
389
# File 'lib/stripe/params/subscription_create_params.rb', line 384

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



376
377
378
# File 'lib/stripe/params/subscription_create_params.rb', line 376

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



378
379
380
# File 'lib/stripe/params/subscription_create_params.rb', line 378

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



380
381
382
# File 'lib/stripe/params/subscription_create_params.rb', line 380

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



382
383
384
# File 'lib/stripe/params/subscription_create_params.rb', line 382

def promotion_code
  @promotion_code
end