Class: Stripe::SubscriptionCreateParams::Item::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::Item::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
Returns a new instance of Custom.
468 469 470 471 472 473 474 |
# File 'lib/stripe/params/subscription_create_params.rb', line 468 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
458 459 460 |
# File 'lib/stripe/params/subscription_create_params.rb', line 458 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
460 461 462 |
# File 'lib/stripe/params/subscription_create_params.rb', line 460 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
462 463 464 |
# File 'lib/stripe/params/subscription_create_params.rb', line 462 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
464 465 466 |
# File 'lib/stripe/params/subscription_create_params.rb', line 464 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
466 467 468 |
# File 'lib/stripe/params/subscription_create_params.rb', line 466 def second @second end |