Class: Stripe::SubscriptionCreateParams::Item::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



464
465
466
467
468
469
470
# File 'lib/stripe/params/subscription_create_params.rb', line 464

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



454
455
456
# File 'lib/stripe/params/subscription_create_params.rb', line 454

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



456
457
458
# File 'lib/stripe/params/subscription_create_params.rb', line 456

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



458
459
460
# File 'lib/stripe/params/subscription_create_params.rb', line 458

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



460
461
462
# File 'lib/stripe/params/subscription_create_params.rb', line 460

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



462
463
464
# File 'lib/stripe/params/subscription_create_params.rb', line 462

def second
  @second
end