Class: Stripe::SubscriptionCreateParams::PaymentSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Defined Under Namespace

Classes: PaymentMethodOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(payment_method_options: nil, payment_method_types: nil, save_default_payment_method: nil) ⇒ PaymentSettings

Returns a new instance of PaymentSettings.



698
699
700
701
702
703
704
705
706
# File 'lib/stripe/params/subscription_create_params.rb', line 698

def initialize(
  payment_method_options: nil,
  payment_method_types: nil,
  save_default_payment_method: nil
)
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @save_default_payment_method = save_default_payment_method
end

Instance Attribute Details

#payment_method_optionsObject

Payment-method-specific configuration to provide to invoices created by the subscription.



692
693
694
# File 'lib/stripe/params/subscription_create_params.rb', line 692

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (e.g. card) to provide to the invoice’s PaymentIntent. If not set, Stripe attempts to automatically determine the types to use by looking at the invoice’s default payment method, the subscription’s default payment method, the customer’s default payment method, and your invoice template settings. Should not be specified with payment_method_configuration



694
695
696
# File 'lib/stripe/params/subscription_create_params.rb', line 694

def payment_method_types
  @payment_method_types
end

#save_default_payment_methodObject

Configure whether Stripe updates subscription.default_payment_method when payment succeeds. Defaults to off if unspecified.



696
697
698
# File 'lib/stripe/params/subscription_create_params.rb', line 696

def save_default_payment_method
  @save_default_payment_method
end