Class: Stripe::SubscriptionCreateParams::PaymentSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::PaymentSettings
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Defined Under Namespace
Classes: PaymentMethodOptions
Instance Attribute Summary collapse
-
#payment_method_options ⇒ Object
Payment-method-specific configuration to provide to invoices created by the subscription.
-
#payment_method_types ⇒ Object
The list of payment method types (e.g. card) to provide to the invoice’s PaymentIntent.
-
#save_default_payment_method ⇒ Object
Configure whether Stripe updates ‘subscription.default_payment_method` when payment succeeds.
Instance Method Summary collapse
-
#initialize(payment_method_options: nil, payment_method_types: nil, save_default_payment_method: nil) ⇒ PaymentSettings
constructor
A new instance of PaymentSettings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(payment_method_options: nil, payment_method_types: nil, save_default_payment_method: nil) ⇒ PaymentSettings
Returns a new instance of PaymentSettings.
983 984 985 986 987 988 989 990 991 |
# File 'lib/stripe/params/subscription_create_params.rb', line 983 def initialize( payment_method_options: nil, payment_method_types: nil, save_default_payment_method: nil ) @payment_method_options = @payment_method_types = payment_method_types @save_default_payment_method = save_default_payment_method end |
Instance Attribute Details
#payment_method_options ⇒ Object
Payment-method-specific configuration to provide to invoices created by the subscription.
977 978 979 |
# File 'lib/stripe/params/subscription_create_params.rb', line 977 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types (e.g. card) to provide to the invoice’s PaymentIntent. If not set, Stripe attempts to automatically determine the types to use by looking at the invoice’s default payment method, the subscription’s default payment method, the customer’s default payment method, and your [invoice template settings](dashboard.stripe.com/settings/billing/invoice). Should not be specified with payment_method_configuration
979 980 981 |
# File 'lib/stripe/params/subscription_create_params.rb', line 979 def payment_method_types @payment_method_types end |
#save_default_payment_method ⇒ Object
Configure whether Stripe updates ‘subscription.default_payment_method` when payment succeeds. Defaults to `off` if unspecified.
981 982 983 |
# File 'lib/stripe/params/subscription_create_params.rb', line 981 def save_default_payment_method @save_default_payment_method end |