Class: Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Defined Under Namespace
Classes: AcssDebit, Bancontact, Blik, Card, CustomerBalance, IdBankTransfer, Konbini, Payto, Pix, SepaDebit, Upi, UsBankAccount
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
-
#bancontact ⇒ Object
This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
-
#blik ⇒ Object
This sub-hash contains details about the Blik payment method options to pass to the invoice’s PaymentIntent.
-
#card ⇒ Object
This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
-
#customer_balance ⇒ Object
This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
-
#id_bank_transfer ⇒ Object
This sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.
-
#konbini ⇒ Object
This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
-
#payto ⇒ Object
This sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.
-
#pix ⇒ Object
This sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.
-
#sepa_debit ⇒ Object
This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
-
#upi ⇒ Object
This sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.
-
#us_bank_account ⇒ Object
This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, bancontact: nil, blik: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(acss_debit: nil, bancontact: nil, blik: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 |
# File 'lib/stripe/params/subscription_create_params.rb', line 808 def initialize( acss_debit: nil, bancontact: nil, blik: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil ) @acss_debit = acss_debit @bancontact = bancontact @blik = blik @card = card @customer_balance = customer_balance @id_bank_transfer = id_bank_transfer @konbini = konbini @payto = payto @pix = pix @sepa_debit = sepa_debit @upi = upi @us_bank_account = us_bank_account end |
Instance Attribute Details
#acss_debit ⇒ Object
This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
784 785 786 |
# File 'lib/stripe/params/subscription_create_params.rb', line 784 def acss_debit @acss_debit end |
#bancontact ⇒ Object
This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
786 787 788 |
# File 'lib/stripe/params/subscription_create_params.rb', line 786 def bancontact @bancontact end |
#blik ⇒ Object
This sub-hash contains details about the Blik payment method options to pass to the invoice’s PaymentIntent.
788 789 790 |
# File 'lib/stripe/params/subscription_create_params.rb', line 788 def blik @blik end |
#card ⇒ Object
This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
790 791 792 |
# File 'lib/stripe/params/subscription_create_params.rb', line 790 def card @card end |
#customer_balance ⇒ Object
This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
792 793 794 |
# File 'lib/stripe/params/subscription_create_params.rb', line 792 def customer_balance @customer_balance end |
#id_bank_transfer ⇒ Object
This sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.
794 795 796 |
# File 'lib/stripe/params/subscription_create_params.rb', line 794 def id_bank_transfer @id_bank_transfer end |
#konbini ⇒ Object
This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
796 797 798 |
# File 'lib/stripe/params/subscription_create_params.rb', line 796 def konbini @konbini end |
#payto ⇒ Object
This sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.
798 799 800 |
# File 'lib/stripe/params/subscription_create_params.rb', line 798 def payto @payto end |
#pix ⇒ Object
This sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.
800 801 802 |
# File 'lib/stripe/params/subscription_create_params.rb', line 800 def pix @pix end |
#sepa_debit ⇒ Object
This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
802 803 804 |
# File 'lib/stripe/params/subscription_create_params.rb', line 802 def sepa_debit @sepa_debit end |
#upi ⇒ Object
This sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.
804 805 806 |
# File 'lib/stripe/params/subscription_create_params.rb', line 804 def upi @upi end |
#us_bank_account ⇒ Object
This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
806 807 808 |
# File 'lib/stripe/params/subscription_create_params.rb', line 806 def us_bank_account @us_bank_account end |