Class: Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Defined Under Namespace
Classes: AcssDebit, Bancontact, Bizum, Blik, Card, CheckScan, CustomerBalance, IdBankTransfer, Konbini, Payto, Pix, SepaDebit, Upi, UsBankAccount, WechatPay
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
-
#bancontact ⇒ Object
This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
-
#bizum ⇒ Object
This sub-hash contains details about the Bizum payment method options to pass to the invoice’s PaymentIntent.
-
#blik ⇒ Object
This sub-hash contains details about the Blik payment method options to pass to the invoice’s PaymentIntent.
-
#card ⇒ Object
This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
-
#check_scan ⇒ Object
This sub-hash contains details about the Check Scan payment method options to pass to the invoice’s PaymentIntent.
-
#customer_balance ⇒ Object
This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
-
#id_bank_transfer ⇒ Object
This sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.
-
#konbini ⇒ Object
This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
-
#payto ⇒ Object
This sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.
-
#pix ⇒ Object
This sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.
-
#sepa_debit ⇒ Object
This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
-
#upi ⇒ Object
This sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.
-
#us_bank_account ⇒ Object
This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
-
#wechat_pay ⇒ Object
This sub-hash contains details about the WeChat Pay payment method options to pass to the invoice’s PaymentIntent.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, bancontact: nil, bizum: nil, blik: nil, card: nil, check_scan: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(acss_debit: nil, bancontact: nil, bizum: nil, blik: nil, card: nil, check_scan: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 |
# File 'lib/stripe/params/subscription_create_params.rb', line 925 def initialize( acss_debit: nil, bancontact: nil, bizum: nil, blik: nil, card: nil, check_scan: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil, wechat_pay: nil ) @acss_debit = acss_debit @bancontact = bancontact @bizum = bizum @blik = blik @card = card @check_scan = check_scan @customer_balance = customer_balance @id_bank_transfer = id_bank_transfer @konbini = konbini @payto = payto @pix = pix @sepa_debit = sepa_debit @upi = upi @us_bank_account = us_bank_account @wechat_pay = wechat_pay end |
Instance Attribute Details
#acss_debit ⇒ Object
This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
895 896 897 |
# File 'lib/stripe/params/subscription_create_params.rb', line 895 def acss_debit @acss_debit end |
#bancontact ⇒ Object
This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
897 898 899 |
# File 'lib/stripe/params/subscription_create_params.rb', line 897 def bancontact @bancontact end |
#bizum ⇒ Object
This sub-hash contains details about the Bizum payment method options to pass to the invoice’s PaymentIntent.
899 900 901 |
# File 'lib/stripe/params/subscription_create_params.rb', line 899 def bizum @bizum end |
#blik ⇒ Object
This sub-hash contains details about the Blik payment method options to pass to the invoice’s PaymentIntent.
901 902 903 |
# File 'lib/stripe/params/subscription_create_params.rb', line 901 def blik @blik end |
#card ⇒ Object
This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
903 904 905 |
# File 'lib/stripe/params/subscription_create_params.rb', line 903 def card @card end |
#check_scan ⇒ Object
This sub-hash contains details about the Check Scan payment method options to pass to the invoice’s PaymentIntent.
905 906 907 |
# File 'lib/stripe/params/subscription_create_params.rb', line 905 def check_scan @check_scan end |
#customer_balance ⇒ Object
This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
907 908 909 |
# File 'lib/stripe/params/subscription_create_params.rb', line 907 def customer_balance @customer_balance end |
#id_bank_transfer ⇒ Object
This sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.
909 910 911 |
# File 'lib/stripe/params/subscription_create_params.rb', line 909 def id_bank_transfer @id_bank_transfer end |
#konbini ⇒ Object
This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
911 912 913 |
# File 'lib/stripe/params/subscription_create_params.rb', line 911 def konbini @konbini end |
#payto ⇒ Object
This sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.
913 914 915 |
# File 'lib/stripe/params/subscription_create_params.rb', line 913 def payto @payto end |
#pix ⇒ Object
This sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.
915 916 917 |
# File 'lib/stripe/params/subscription_create_params.rb', line 915 def pix @pix end |
#sepa_debit ⇒ Object
This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
917 918 919 |
# File 'lib/stripe/params/subscription_create_params.rb', line 917 def sepa_debit @sepa_debit end |
#upi ⇒ Object
This sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.
919 920 921 |
# File 'lib/stripe/params/subscription_create_params.rb', line 919 def upi @upi end |
#us_bank_account ⇒ Object
This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
921 922 923 |
# File 'lib/stripe/params/subscription_create_params.rb', line 921 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
This sub-hash contains details about the WeChat Pay payment method options to pass to the invoice’s PaymentIntent.
923 924 925 |
# File 'lib/stripe/params/subscription_create_params.rb', line 923 def wechat_pay @wechat_pay end |