Class: Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Bizum, Blik, Card, CheckScan, CustomerBalance, IdBankTransfer, Konbini, Payto, Pix, SepaDebit, Upi, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(acss_debit: nil, bancontact: nil, bizum: nil, blik: nil, card: nil, check_scan: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
# File 'lib/stripe/params/subscription_create_params.rb', line 944

def initialize(
  acss_debit: nil,
  bancontact: nil,
  bizum: nil,
  blik: nil,
  card: nil,
  check_scan: nil,
  customer_balance: nil,
  id_bank_transfer: nil,
  konbini: nil,
  payto: nil,
  pix: nil,
  sepa_debit: nil,
  upi: nil,
  us_bank_account: nil
)
  @acss_debit = acss_debit
  @bancontact = bancontact
  @bizum = bizum
  @blik = blik
  @card = card
  @check_scan = check_scan
  @customer_balance = customer_balance
  @id_bank_transfer = id_bank_transfer
  @konbini = konbini
  @payto = payto
  @pix = pix
  @sepa_debit = sepa_debit
  @upi = upi
  @us_bank_account = 
end

Instance Attribute Details

#acss_debitObject

This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.



916
917
918
# File 'lib/stripe/params/subscription_create_params.rb', line 916

def acss_debit
  @acss_debit
end

#bancontactObject

This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.



918
919
920
# File 'lib/stripe/params/subscription_create_params.rb', line 918

def bancontact
  @bancontact
end

#bizumObject

This sub-hash contains details about the Bizum payment method options to pass to the invoice’s PaymentIntent.



920
921
922
# File 'lib/stripe/params/subscription_create_params.rb', line 920

def bizum
  @bizum
end

#blikObject

This sub-hash contains details about the Blik payment method options to pass to the invoice’s PaymentIntent.



922
923
924
# File 'lib/stripe/params/subscription_create_params.rb', line 922

def blik
  @blik
end

#cardObject

This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.



924
925
926
# File 'lib/stripe/params/subscription_create_params.rb', line 924

def card
  @card
end

#check_scanObject

This sub-hash contains details about the Check Scan payment method options to pass to the invoice’s PaymentIntent.



926
927
928
# File 'lib/stripe/params/subscription_create_params.rb', line 926

def check_scan
  @check_scan
end

#customer_balanceObject

This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.



928
929
930
# File 'lib/stripe/params/subscription_create_params.rb', line 928

def customer_balance
  @customer_balance
end

#id_bank_transferObject

This sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.



930
931
932
# File 'lib/stripe/params/subscription_create_params.rb', line 930

def id_bank_transfer
  @id_bank_transfer
end

#konbiniObject

This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.



932
933
934
# File 'lib/stripe/params/subscription_create_params.rb', line 932

def konbini
  @konbini
end

#paytoObject

This sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.



934
935
936
# File 'lib/stripe/params/subscription_create_params.rb', line 934

def payto
  @payto
end

#pixObject

This sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.



936
937
938
# File 'lib/stripe/params/subscription_create_params.rb', line 936

def pix
  @pix
end

#sepa_debitObject

This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.



938
939
940
# File 'lib/stripe/params/subscription_create_params.rb', line 938

def sepa_debit
  @sepa_debit
end

#upiObject

This sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.



940
941
942
# File 'lib/stripe/params/subscription_create_params.rb', line 940

def upi
  @upi
end

#us_bank_accountObject

This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.



942
943
944
# File 'lib/stripe/params/subscription_create_params.rb', line 942

def 
  @us_bank_account
end