Class: Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Blik, Card, CustomerBalance, IdBankTransfer, Konbini, Payto, Pix, SepaDebit, Upi, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(acss_debit: nil, bancontact: nil, blik: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
# File 'lib/stripe/params/subscription_create_params.rb', line 777

def initialize(
  acss_debit: nil,
  bancontact: nil,
  blik: nil,
  card: nil,
  customer_balance: nil,
  id_bank_transfer: nil,
  konbini: nil,
  payto: nil,
  pix: nil,
  sepa_debit: nil,
  upi: nil,
  us_bank_account: nil
)
  @acss_debit = acss_debit
  @bancontact = bancontact
  @blik = blik
  @card = card
  @customer_balance = customer_balance
  @id_bank_transfer = id_bank_transfer
  @konbini = konbini
  @payto = payto
  @pix = pix
  @sepa_debit = sepa_debit
  @upi = upi
  @us_bank_account = 
end

Instance Attribute Details

#acss_debitObject

This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.



753
754
755
# File 'lib/stripe/params/subscription_create_params.rb', line 753

def acss_debit
  @acss_debit
end

#bancontactObject

This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.



755
756
757
# File 'lib/stripe/params/subscription_create_params.rb', line 755

def bancontact
  @bancontact
end

#blikObject

This sub-hash contains details about the Blik payment method options to pass to the invoice’s PaymentIntent.



757
758
759
# File 'lib/stripe/params/subscription_create_params.rb', line 757

def blik
  @blik
end

#cardObject

This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.



759
760
761
# File 'lib/stripe/params/subscription_create_params.rb', line 759

def card
  @card
end

#customer_balanceObject

This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.



761
762
763
# File 'lib/stripe/params/subscription_create_params.rb', line 761

def customer_balance
  @customer_balance
end

#id_bank_transferObject

This sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.



763
764
765
# File 'lib/stripe/params/subscription_create_params.rb', line 763

def id_bank_transfer
  @id_bank_transfer
end

#konbiniObject

This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.



765
766
767
# File 'lib/stripe/params/subscription_create_params.rb', line 765

def konbini
  @konbini
end

#paytoObject

This sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.



767
768
769
# File 'lib/stripe/params/subscription_create_params.rb', line 767

def payto
  @payto
end

#pixObject

This sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.



769
770
771
# File 'lib/stripe/params/subscription_create_params.rb', line 769

def pix
  @pix
end

#sepa_debitObject

This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.



771
772
773
# File 'lib/stripe/params/subscription_create_params.rb', line 771

def sepa_debit
  @sepa_debit
end

#upiObject

This sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.



773
774
775
# File 'lib/stripe/params/subscription_create_params.rb', line 773

def upi
  @upi
end

#us_bank_accountObject

This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.



775
776
777
# File 'lib/stripe/params/subscription_create_params.rb', line 775

def 
  @us_bank_account
end