Class: Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Card, CheckScan, CustomerBalance, IdBankTransfer, Konbini, Payto, Pix, SepaDebit, Upi, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil, check_scan: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
# File 'lib/stripe/params/subscription_create_params.rb', line 903

def initialize(
  acss_debit: nil,
  bancontact: nil,
  card: nil,
  customer_balance: nil,
  id_bank_transfer: nil,
  konbini: nil,
  payto: nil,
  pix: nil,
  sepa_debit: nil,
  upi: nil,
  us_bank_account: nil,
  check_scan: nil
)
  @acss_debit = acss_debit
  @bancontact = bancontact
  @card = card
  @customer_balance = customer_balance
  @id_bank_transfer = id_bank_transfer
  @konbini = konbini
  @payto = payto
  @pix = pix
  @sepa_debit = sepa_debit
  @upi = upi
  @us_bank_account = 
  @check_scan = check_scan
end

Instance Attribute Details

#acss_debitObject

This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.



879
880
881
# File 'lib/stripe/params/subscription_create_params.rb', line 879

def acss_debit
  @acss_debit
end

#bancontactObject

This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.



881
882
883
# File 'lib/stripe/params/subscription_create_params.rb', line 881

def bancontact
  @bancontact
end

#cardObject

This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.



883
884
885
# File 'lib/stripe/params/subscription_create_params.rb', line 883

def card
  @card
end

#check_scanObject

This sub-hash contains details about the Check Scan payment method options to pass to the invoice’s PaymentIntent.



901
902
903
# File 'lib/stripe/params/subscription_create_params.rb', line 901

def check_scan
  @check_scan
end

#customer_balanceObject

This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.



885
886
887
# File 'lib/stripe/params/subscription_create_params.rb', line 885

def customer_balance
  @customer_balance
end

#id_bank_transferObject

This sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.



887
888
889
# File 'lib/stripe/params/subscription_create_params.rb', line 887

def id_bank_transfer
  @id_bank_transfer
end

#konbiniObject

This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.



889
890
891
# File 'lib/stripe/params/subscription_create_params.rb', line 889

def konbini
  @konbini
end

#paytoObject

This sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.



891
892
893
# File 'lib/stripe/params/subscription_create_params.rb', line 891

def payto
  @payto
end

#pixObject

This sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.



893
894
895
# File 'lib/stripe/params/subscription_create_params.rb', line 893

def pix
  @pix
end

#sepa_debitObject

This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.



895
896
897
# File 'lib/stripe/params/subscription_create_params.rb', line 895

def sepa_debit
  @sepa_debit
end

#upiObject

This sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.



897
898
899
# File 'lib/stripe/params/subscription_create_params.rb', line 897

def upi
  @upi
end

#us_bank_accountObject

This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.



899
900
901
# File 'lib/stripe/params/subscription_create_params.rb', line 899

def 
  @us_bank_account
end