Class: Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Bizum, Card, CheckScan, CustomerBalance, IdBankTransfer, Konbini, Payto, Pix, SepaDebit, Upi, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(acss_debit: nil, bancontact: nil, bizum: nil, card: nil, check_scan: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
# File 'lib/stripe/params/subscription_create_params.rb', line 925

def initialize(
  acss_debit: nil,
  bancontact: nil,
  bizum: nil,
  card: nil,
  check_scan: nil,
  customer_balance: nil,
  id_bank_transfer: nil,
  konbini: nil,
  payto: nil,
  pix: nil,
  sepa_debit: nil,
  upi: nil,
  us_bank_account: nil
)
  @acss_debit = acss_debit
  @bancontact = bancontact
  @bizum = bizum
  @card = card
  @check_scan = check_scan
  @customer_balance = customer_balance
  @id_bank_transfer = id_bank_transfer
  @konbini = konbini
  @payto = payto
  @pix = pix
  @sepa_debit = sepa_debit
  @upi = upi
  @us_bank_account = 
end

Instance Attribute Details

#acss_debitObject

This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.



899
900
901
# File 'lib/stripe/params/subscription_create_params.rb', line 899

def acss_debit
  @acss_debit
end

#bancontactObject

This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.



901
902
903
# File 'lib/stripe/params/subscription_create_params.rb', line 901

def bancontact
  @bancontact
end

#bizumObject

This sub-hash contains details about the Bizum payment method options to pass to the invoice’s PaymentIntent.



903
904
905
# File 'lib/stripe/params/subscription_create_params.rb', line 903

def bizum
  @bizum
end

#cardObject

This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.



905
906
907
# File 'lib/stripe/params/subscription_create_params.rb', line 905

def card
  @card
end

#check_scanObject

This sub-hash contains details about the Check Scan payment method options to pass to the invoice’s PaymentIntent.



907
908
909
# File 'lib/stripe/params/subscription_create_params.rb', line 907

def check_scan
  @check_scan
end

#customer_balanceObject

This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.



909
910
911
# File 'lib/stripe/params/subscription_create_params.rb', line 909

def customer_balance
  @customer_balance
end

#id_bank_transferObject

This sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.



911
912
913
# File 'lib/stripe/params/subscription_create_params.rb', line 911

def id_bank_transfer
  @id_bank_transfer
end

#konbiniObject

This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.



913
914
915
# File 'lib/stripe/params/subscription_create_params.rb', line 913

def konbini
  @konbini
end

#paytoObject

This sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.



915
916
917
# File 'lib/stripe/params/subscription_create_params.rb', line 915

def payto
  @payto
end

#pixObject

This sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.



917
918
919
# File 'lib/stripe/params/subscription_create_params.rb', line 917

def pix
  @pix
end

#sepa_debitObject

This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.



919
920
921
# File 'lib/stripe/params/subscription_create_params.rb', line 919

def sepa_debit
  @sepa_debit
end

#upiObject

This sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.



921
922
923
# File 'lib/stripe/params/subscription_create_params.rb', line 921

def upi
  @upi
end

#us_bank_accountObject

This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.



923
924
925
# File 'lib/stripe/params/subscription_create_params.rb', line 923

def 
  @us_bank_account
end