Class: Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Defined Under Namespace
Classes: AcssDebit, Bancontact, Card, CustomerBalance, IdBankTransfer, Konbini, Payto, Pix, SepaDebit, Upi, UsBankAccount
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
-
#bancontact ⇒ Object
This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
-
#card ⇒ Object
This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
-
#customer_balance ⇒ Object
This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
-
#id_bank_transfer ⇒ Object
This sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.
-
#konbini ⇒ Object
This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
-
#payto ⇒ Object
This sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.
-
#pix ⇒ Object
This sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.
-
#sepa_debit ⇒ Object
This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
-
#upi ⇒ Object
This sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.
-
#us_bank_account ⇒ Object
This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 |
# File 'lib/stripe/params/subscription_create_params.rb', line 719 def initialize( acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil ) @acss_debit = acss_debit @bancontact = bancontact @card = card @customer_balance = customer_balance @id_bank_transfer = id_bank_transfer @konbini = konbini @payto = payto @pix = pix @sepa_debit = sepa_debit @upi = upi @us_bank_account = us_bank_account end |
Instance Attribute Details
#acss_debit ⇒ Object
This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
697 698 699 |
# File 'lib/stripe/params/subscription_create_params.rb', line 697 def acss_debit @acss_debit end |
#bancontact ⇒ Object
This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
699 700 701 |
# File 'lib/stripe/params/subscription_create_params.rb', line 699 def bancontact @bancontact end |
#card ⇒ Object
This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
701 702 703 |
# File 'lib/stripe/params/subscription_create_params.rb', line 701 def card @card end |
#customer_balance ⇒ Object
This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
703 704 705 |
# File 'lib/stripe/params/subscription_create_params.rb', line 703 def customer_balance @customer_balance end |
#id_bank_transfer ⇒ Object
This sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.
705 706 707 |
# File 'lib/stripe/params/subscription_create_params.rb', line 705 def id_bank_transfer @id_bank_transfer end |
#konbini ⇒ Object
This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
707 708 709 |
# File 'lib/stripe/params/subscription_create_params.rb', line 707 def konbini @konbini end |
#payto ⇒ Object
This sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.
709 710 711 |
# File 'lib/stripe/params/subscription_create_params.rb', line 709 def payto @payto end |
#pix ⇒ Object
This sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.
711 712 713 |
# File 'lib/stripe/params/subscription_create_params.rb', line 711 def pix @pix end |
#sepa_debit ⇒ Object
This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
713 714 715 |
# File 'lib/stripe/params/subscription_create_params.rb', line 713 def sepa_debit @sepa_debit end |
#upi ⇒ Object
This sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.
715 716 717 |
# File 'lib/stripe/params/subscription_create_params.rb', line 715 def upi @upi end |
#us_bank_account ⇒ Object
This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
717 718 719 |
# File 'lib/stripe/params/subscription_create_params.rb', line 717 def us_bank_account @us_bank_account end |