Class: Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions::Blik::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(expires_after: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



559
560
561
# File 'lib/stripe/params/subscription_create_params.rb', line 559

def initialize(expires_after: nil)
  @expires_after = expires_after
end

Instance Attribute Details

#expires_afterObject

Date when the mandate expires and no further payments will be charged. If not provided, the mandate will be set to be indefinite.



557
558
559
# File 'lib/stripe/params/subscription_create_params.rb', line 557

def expires_after
  @expires_after
end