Class: Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions::Card::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions::Card::MandateOptions
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments, specified in the presentment currency.
-
#amount_type ⇒ Object
One of
fixedormaximum. -
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, description: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_type: nil, description: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
613 614 615 616 617 |
# File 'lib/stripe/params/subscription_create_params.rb', line 613 def initialize(amount: nil, amount_type: nil, description: nil) @amount = amount @amount_type = amount_type @description = description end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments, specified in the presentment currency.
607 608 609 |
# File 'lib/stripe/params/subscription_create_params.rb', line 607 def amount @amount end |
#amount_type ⇒ Object
One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.
609 610 611 |
# File 'lib/stripe/params/subscription_create_params.rb', line 609 def amount_type @amount_type end |
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
611 612 613 |
# File 'lib/stripe/params/subscription_create_params.rb', line 611 def description @description end |