Class: Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



735
736
737
738
739
# File 'lib/stripe/params/subscription_create_params.rb', line 735

def initialize(amount: nil, amount_type: nil, description: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments, specified in the presentment currency.



729
730
731
# File 'lib/stripe/params/subscription_create_params.rb', line 729

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



731
732
733
# File 'lib/stripe/params/subscription_create_params.rb', line 731

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



733
734
735
# File 'lib/stripe/params/subscription_create_params.rb', line 733

def description
  @description
end