Class: Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



478
479
480
481
482
# File 'lib/stripe/params/subscription_create_params.rb', line 478

def initialize(amount: nil, amount_type: nil, description: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments, specified in the presentment currency.



472
473
474
# File 'lib/stripe/params/subscription_create_params.rb', line 472

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



474
475
476
# File 'lib/stripe/params/subscription_create_params.rb', line 474

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



476
477
478
# File 'lib/stripe/params/subscription_create_params.rb', line 476

def description
  @description
end