Class: Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



611
612
613
614
615
# File 'lib/stripe/params/subscription_create_params.rb', line 611

def initialize(amount: nil, amount_type: nil, description: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments, specified in the presentment currency.



605
606
607
# File 'lib/stripe/params/subscription_create_params.rb', line 605

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



607
608
609
# File 'lib/stripe/params/subscription_create_params.rb', line 607

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



609
610
611
# File 'lib/stripe/params/subscription_create_params.rb', line 609

def description
  @description
end