Class: Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions::Payto::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions::Payto::MandateOptions
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The maximum amount that can be collected in a single invoice.
-
#purpose ⇒ Object
The purpose for which payments are made.
Instance Method Summary collapse
-
#initialize(amount: nil, purpose: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, purpose: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
708 709 710 711 |
# File 'lib/stripe/params/subscription_create_params.rb', line 708 def initialize(amount: nil, purpose: nil) @amount = amount @purpose = purpose end |
Instance Attribute Details
#amount ⇒ Object
The maximum amount that can be collected in a single invoice. If you don’t specify a maximum, then there is no limit.
704 705 706 |
# File 'lib/stripe/params/subscription_create_params.rb', line 704 def amount @amount end |
#purpose ⇒ Object
The purpose for which payments are made. Has a default value based on your merchant category code.
706 707 708 |
# File 'lib/stripe/params/subscription_create_params.rb', line 706 def purpose @purpose end |