Class: Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions::Payto::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions::Payto::MandateOptions
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The maximum amount that can be collected in a single invoice.
-
#purpose ⇒ Object
The purpose for which payments are made.
Instance Method Summary collapse
-
#initialize(amount: nil, purpose: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, purpose: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
604 605 606 607 |
# File 'lib/stripe/params/subscription_create_params.rb', line 604 def initialize(amount: nil, purpose: nil) @amount = amount @purpose = purpose end |
Instance Attribute Details
#amount ⇒ Object
The maximum amount that can be collected in a single invoice. If you don’t specify a maximum, then there is no limit.
600 601 602 |
# File 'lib/stripe/params/subscription_create_params.rb', line 600 def amount @amount end |
#purpose ⇒ Object
The purpose for which payments are made. Has a default value based on your merchant category code.
602 603 604 |
# File 'lib/stripe/params/subscription_create_params.rb', line 602 def purpose @purpose end |