Class: Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions::Pix::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(amount: nil, amount_includes_iof: nil, end_date: nil, payment_schedule: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



732
733
734
735
736
737
738
739
740
741
742
# File 'lib/stripe/params/subscription_create_params.rb', line 732

def initialize(
  amount: nil,
  amount_includes_iof: nil,
  end_date: nil,
  payment_schedule: nil
)
  @amount = amount
  @amount_includes_iof = amount_includes_iof
  @end_date = end_date
  @payment_schedule = payment_schedule
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments. If not provided, defaults to 40000.



724
725
726
# File 'lib/stripe/params/subscription_create_params.rb', line 724

def amount
  @amount
end

#amount_includes_iofObject

Determines if the amount includes the IOF tax. Defaults to ‘never`.



726
727
728
# File 'lib/stripe/params/subscription_create_params.rb', line 726

def amount_includes_iof
  @amount_includes_iof
end

#end_dateObject

Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`. If not provided, the mandate will be active until canceled.



728
729
730
# File 'lib/stripe/params/subscription_create_params.rb', line 728

def end_date
  @end_date
end

#payment_scheduleObject

Schedule at which the future payments will be charged. Defaults to ‘weekly`.



730
731
732
# File 'lib/stripe/params/subscription_create_params.rb', line 730

def payment_schedule
  @payment_schedule
end