Class: Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions::Pix::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions::Pix::MandateOptions
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments.
-
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax.
-
#end_date ⇒ Object
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.
-
#payment_schedule ⇒ Object
Schedule at which the future payments will be charged.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_includes_iof: nil, end_date: nil, payment_schedule: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_includes_iof: nil, end_date: nil, payment_schedule: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
628 629 630 631 632 633 634 635 636 637 638 |
# File 'lib/stripe/params/subscription_create_params.rb', line 628 def initialize( amount: nil, amount_includes_iof: nil, end_date: nil, payment_schedule: nil ) @amount = amount @amount_includes_iof = amount_includes_iof @end_date = end_date @payment_schedule = payment_schedule end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments. If not provided, defaults to 40000.
620 621 622 |
# File 'lib/stripe/params/subscription_create_params.rb', line 620 def amount @amount end |
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax. Defaults to ‘never`.
622 623 624 |
# File 'lib/stripe/params/subscription_create_params.rb', line 622 def amount_includes_iof @amount_includes_iof end |
#end_date ⇒ Object
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`. If not provided, the mandate will be active until canceled.
624 625 626 |
# File 'lib/stripe/params/subscription_create_params.rb', line 624 def end_date @end_date end |
#payment_schedule ⇒ Object
Schedule at which the future payments will be charged. Defaults to ‘weekly`.
626 627 628 |
# File 'lib/stripe/params/subscription_create_params.rb', line 626 def payment_schedule @payment_schedule end |