Class: Stripe::SubscriptionCreateParams::PaymentSettings::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



831
832
833
834
835
836
# File 'lib/stripe/params/subscription_create_params.rb', line 831

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



823
824
825
# File 'lib/stripe/params/subscription_create_params.rb', line 823

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



825
826
827
# File 'lib/stripe/params/subscription_create_params.rb', line 825

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



827
828
829
# File 'lib/stripe/params/subscription_create_params.rb', line 827

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



829
830
831
# File 'lib/stripe/params/subscription_create_params.rb', line 829

def end_date
  @end_date
end