Class: Stripe::SubscriptionCreateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1024
1025
1026
1027
# File 'lib/stripe/params/subscription_create_params.rb', line 1024

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



1020
1021
1022
# File 'lib/stripe/params/subscription_create_params.rb', line 1020

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



1022
1023
1024
# File 'lib/stripe/params/subscription_create_params.rb', line 1022

def destination
  @destination
end