Class: Stripe::SubscriptionCreateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



793
794
795
796
# File 'lib/stripe/params/subscription_create_params.rb', line 793

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



789
790
791
# File 'lib/stripe/params/subscription_create_params.rb', line 789

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



791
792
793
# File 'lib/stripe/params/subscription_create_params.rb', line 791

def destination
  @destination
end