Class: Stripe::SubscriptionCreateParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::TransferData
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Instance Attribute Summary collapse
-
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
809 810 811 812 |
# File 'lib/stripe/params/subscription_create_params.rb', line 809 def initialize(amount_percent: nil, destination: nil) @amount_percent = amount_percent @destination = destination end |
Instance Attribute Details
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.
805 806 807 |
# File 'lib/stripe/params/subscription_create_params.rb', line 805 def amount_percent @amount_percent end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
807 808 809 |
# File 'lib/stripe/params/subscription_create_params.rb', line 807 def destination @destination end |