Class: Stripe::SubscriptionCreateParams::TrialSettings::EndBehavior

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(billing_cycle_anchor: nil, missing_payment_method: nil) ⇒ EndBehavior

Returns a new instance of EndBehavior.



1037
1038
1039
1040
# File 'lib/stripe/params/subscription_create_params.rb', line 1037

def initialize(billing_cycle_anchor: nil, missing_payment_method: nil)
  @billing_cycle_anchor = billing_cycle_anchor
  @missing_payment_method = missing_payment_method
end

Instance Attribute Details

#billing_cycle_anchorObject

Indicates how the subscription’s billing cycle anchor is reset when a trial ends. Defaults to ‘now`.



1033
1034
1035
# File 'lib/stripe/params/subscription_create_params.rb', line 1033

def billing_cycle_anchor
  @billing_cycle_anchor
end

#missing_payment_methodObject

Indicates how the subscription should change when the trial ends if the user did not provide a payment method.



1035
1036
1037
# File 'lib/stripe/params/subscription_create_params.rb', line 1035

def missing_payment_method
  @missing_payment_method
end