Class: Stripe::SubscriptionCreateParams::TrialSettings::EndBehavior
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionCreateParams::TrialSettings::EndBehavior
- Defined in:
- lib/stripe/params/subscription_create_params.rb
Instance Attribute Summary collapse
-
#missing_payment_method ⇒ Object
Indicates how the subscription should change when the trial ends if the user did not provide a payment method.
Instance Method Summary collapse
-
#initialize(missing_payment_method: nil) ⇒ EndBehavior
constructor
A new instance of EndBehavior.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(missing_payment_method: nil) ⇒ EndBehavior
Returns a new instance of EndBehavior.
587 588 589 |
# File 'lib/stripe/params/subscription_create_params.rb', line 587 def initialize(missing_payment_method: nil) @missing_payment_method = missing_payment_method end |
Instance Attribute Details
#missing_payment_method ⇒ Object
Indicates how the subscription should change when the trial ends if the user did not provide a payment method.
585 586 587 |
# File 'lib/stripe/params/subscription_create_params.rb', line 585 def missing_payment_method @missing_payment_method end |