Class: Stripe::SubscriptionItem::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription_item.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, expand: nil, metadata: nil, payment_behavior: nil, plan: nil, price: nil, price_data: nil, proration_behavior: nil, proration_date: nil, quantity: nil, subscription: nil, tax_rates: nil, trial: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
# File 'lib/stripe/resources/subscription_item.rb', line 371

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  expand: nil,
  metadata: nil,
  payment_behavior: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  proration_behavior: nil,
  proration_date: nil,
  quantity: nil,
  subscription: nil,
  tax_rates: nil,
  trial: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @expand = expand
  @metadata = 
  @payment_behavior = payment_behavior
  @plan = plan
  @price = price
  @price_data = price_data
  @proration_behavior = proration_behavior
  @proration_date = proration_date
  @quantity = quantity
  @subscription = subscription
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



337
338
339
# File 'lib/stripe/resources/subscription_item.rb', line 337

def billing_thresholds
  @billing_thresholds
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



339
340
341
# File 'lib/stripe/resources/subscription_item.rb', line 339

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



341
342
343
# File 'lib/stripe/resources/subscription_item.rb', line 341

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



343
344
345
# File 'lib/stripe/resources/subscription_item.rb', line 343

def 
  @metadata
end

#payment_behaviorObject

Use ‘allow_incomplete` to transition the subscription to `status=past_due` if a payment is required but cannot be paid. This allows you to manage scenarios where additional user actions are needed to pay a subscription’s invoice. For example, SCA regulation may require 3DS authentication to complete payment. See the [SCA Migration Guide](stripe.com/docs/billing/migration/strong-customer-authentication) for Billing to learn more. This is the default behavior.

Use ‘default_incomplete` to transition the subscription to `status=past_due` when payment is required and await explicit confirmation of the invoice’s payment intent. This allows simpler management of scenarios where additional user actions are needed to pay a subscription’s invoice. Such as failed payments, [SCA regulation](stripe.com/docs/billing/migration/strong-customer-authentication), or collecting a mandate for a bank debit payment method.

Use ‘pending_if_incomplete` to update the subscription using [pending updates](stripe.com/docs/billing/subscriptions/pending-updates). When you use `pending_if_incomplete` you can only pass the parameters [supported by pending updates](stripe.com/docs/billing/pending-updates-reference#supported-attributes).

Use ‘error_if_incomplete` if you want Stripe to return an HTTP 402 status code if a subscription’s invoice cannot be paid. For example, if a payment method requires 3DS authentication due to SCA regulation and further user action is needed, this parameter does not update the subscription and returns an error instead. This was the default behavior for API versions prior to 2019-03-14. See the [changelog](docs.stripe.com/changelog/2019-03-14) to learn more.



351
352
353
# File 'lib/stripe/resources/subscription_item.rb', line 351

def payment_behavior
  @payment_behavior
end

#planObject

The identifier of the plan to add to the subscription.



353
354
355
# File 'lib/stripe/resources/subscription_item.rb', line 353

def plan
  @plan
end

#priceObject

The ID of the price object.



355
356
357
# File 'lib/stripe/resources/subscription_item.rb', line 355

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



357
358
359
# File 'lib/stripe/resources/subscription_item.rb', line 357

def price_data
  @price_data
end

#proration_behaviorObject

Determines how to handle [prorations](stripe.com/docs/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes. The default value is `create_prorations`.



359
360
361
# File 'lib/stripe/resources/subscription_item.rb', line 359

def proration_behavior
  @proration_behavior
end

#proration_dateObject

If set, the proration will be calculated as though the subscription was updated at the given time. This can be used to apply the same proration that was previewed with the [upcoming invoice](stripe.com/docs/api#retrieve_customer_invoice) endpoint.



361
362
363
# File 'lib/stripe/resources/subscription_item.rb', line 361

def proration_date
  @proration_date
end

#quantityObject

The quantity you’d like to apply to the subscription item you’re creating.



363
364
365
# File 'lib/stripe/resources/subscription_item.rb', line 363

def quantity
  @quantity
end

#subscriptionObject

The identifier of the subscription to modify.



365
366
367
# File 'lib/stripe/resources/subscription_item.rb', line 365

def subscription
  @subscription
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



367
368
369
# File 'lib/stripe/resources/subscription_item.rb', line 367

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



369
370
371
# File 'lib/stripe/resources/subscription_item.rb', line 369

def trial
  @trial
end