Class: Stripe::SubscriptionItem::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionItem::CreateParams
- Defined in:
- lib/stripe/resources/subscription_item.rb
Defined Under Namespace
Classes: Discount, PriceData, Trial
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment_behavior ⇒ Object
Use ‘allow_incomplete` to transition the subscription to `status=past_due` if a payment is required but cannot be paid.
-
#plan ⇒ Object
The identifier of the plan to add to the subscription.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#proration_behavior ⇒ Object
Determines how to handle [prorations](stripe.com/docs/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes.
-
#proration_date ⇒ Object
If set, the proration will be calculated as though the subscription was updated at the given time.
-
#quantity ⇒ Object
The quantity you’d like to apply to the subscription item you’re creating.
-
#subscription ⇒ Object
The identifier of the subscription to modify.
-
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
Instance Method Summary collapse
-
#initialize(discounts: nil, expand: nil, metadata: nil, payment_behavior: nil, plan: nil, price: nil, price_data: nil, proration_behavior: nil, proration_date: nil, quantity: nil, subscription: nil, tax_rates: nil, trial: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, expand: nil, metadata: nil, payment_behavior: nil, plan: nil, price: nil, price_data: nil, proration_behavior: nil, proration_date: nil, quantity: nil, subscription: nil, tax_rates: nil, trial: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/stripe/resources/subscription_item.rb', line 342 def initialize( discounts: nil, expand: nil, metadata: nil, payment_behavior: nil, plan: nil, price: nil, price_data: nil, proration_behavior: nil, proration_date: nil, quantity: nil, subscription: nil, tax_rates: nil, trial: nil ) @discounts = discounts @expand = @metadata = @payment_behavior = payment_behavior @plan = plan @price = price @price_data = price_data @proration_behavior = proration_behavior @proration_date = proration_date @quantity = quantity @subscription = subscription @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
310 311 312 |
# File 'lib/stripe/resources/subscription_item.rb', line 310 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
312 313 314 |
# File 'lib/stripe/resources/subscription_item.rb', line 312 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
314 315 316 |
# File 'lib/stripe/resources/subscription_item.rb', line 314 def @metadata end |
#payment_behavior ⇒ Object
Use ‘allow_incomplete` to transition the subscription to `status=past_due` if a payment is required but cannot be paid. This allows you to manage scenarios where additional user actions are needed to pay a subscription’s invoice. For example, SCA regulation may require 3DS authentication to complete payment. See the [SCA Migration Guide](stripe.com/docs/billing/migration/strong-customer-authentication) for Billing to learn more. This is the default behavior.
Use ‘default_incomplete` to transition the subscription to `status=past_due` when payment is required and await explicit confirmation of the invoice’s payment intent. This allows simpler management of scenarios where additional user actions are needed to pay a subscription’s invoice. Such as failed payments, [SCA regulation](stripe.com/docs/billing/migration/strong-customer-authentication), or collecting a mandate for a bank debit payment method.
Use ‘pending_if_incomplete` to update the subscription using [pending updates](stripe.com/docs/billing/subscriptions/pending-updates). When you use `pending_if_incomplete` you can only pass the parameters [supported by pending updates](stripe.com/docs/billing/pending-updates-reference#supported-attributes).
Use ‘error_if_incomplete` if you want Stripe to return an HTTP 402 status code if a subscription’s invoice cannot be paid. For example, if a payment method requires 3DS authentication due to SCA regulation and further user action is needed, this parameter does not update the subscription and returns an error instead. This was the default behavior for API versions prior to 2019-03-14. See the [changelog](stripe.com/docs/upgrades#2019-03-14) to learn more.
322 323 324 |
# File 'lib/stripe/resources/subscription_item.rb', line 322 def payment_behavior @payment_behavior end |
#plan ⇒ Object
The identifier of the plan to add to the subscription.
324 325 326 |
# File 'lib/stripe/resources/subscription_item.rb', line 324 def plan @plan end |
#price ⇒ Object
The ID of the price object.
326 327 328 |
# File 'lib/stripe/resources/subscription_item.rb', line 326 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
328 329 330 |
# File 'lib/stripe/resources/subscription_item.rb', line 328 def price_data @price_data end |
#proration_behavior ⇒ Object
Determines how to handle [prorations](stripe.com/docs/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes. The default value is `create_prorations`.
330 331 332 |
# File 'lib/stripe/resources/subscription_item.rb', line 330 def proration_behavior @proration_behavior end |
#proration_date ⇒ Object
If set, the proration will be calculated as though the subscription was updated at the given time. This can be used to apply the same proration that was previewed with the [upcoming invoice](stripe.com/docs/api#retrieve_customer_invoice) endpoint.
332 333 334 |
# File 'lib/stripe/resources/subscription_item.rb', line 332 def proration_date @proration_date end |
#quantity ⇒ Object
The quantity you’d like to apply to the subscription item you’re creating.
334 335 336 |
# File 'lib/stripe/resources/subscription_item.rb', line 334 def quantity @quantity end |
#subscription ⇒ Object
The identifier of the subscription to modify.
336 337 338 |
# File 'lib/stripe/resources/subscription_item.rb', line 336 def subscription @subscription end |
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
338 339 340 |
# File 'lib/stripe/resources/subscription_item.rb', line 338 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
340 341 342 |
# File 'lib/stripe/resources/subscription_item.rb', line 340 def trial @trial end |