Class: Stripe::SubscriptionItem::CreateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionItem::CreateParams::Discount
- Defined in:
- lib/stripe/resources/subscription_item.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
275 276 277 278 279 280 |
# File 'lib/stripe/resources/subscription_item.rb', line 275 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
267 268 269 |
# File 'lib/stripe/resources/subscription_item.rb', line 267 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
269 270 271 |
# File 'lib/stripe/resources/subscription_item.rb', line 269 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
271 272 273 |
# File 'lib/stripe/resources/subscription_item.rb', line 271 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
273 274 275 |
# File 'lib/stripe/resources/subscription_item.rb', line 273 def promotion_code @promotion_code end |