Class: Stripe::SubscriptionItem::CreateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_item.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



290
291
292
293
294
295
# File 'lib/stripe/resources/subscription_item.rb', line 290

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



282
283
284
# File 'lib/stripe/resources/subscription_item.rb', line 282

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



284
285
286
# File 'lib/stripe/resources/subscription_item.rb', line 284

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



286
287
288
# File 'lib/stripe/resources/subscription_item.rb', line 286

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



288
289
290
# File 'lib/stripe/resources/subscription_item.rb', line 288

def promotion_code
  @promotion_code
end