Class: Stripe::SubscriptionItemCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionItemCreateParams
- Defined in:
- lib/stripe/params/subscription_item_create_params.rb
Defined Under Namespace
Classes: BillingThresholds, CurrentTrial, Discount, PriceData, Trial
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#current_trial ⇒ Object
The trial offer to apply to this subscription item.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#payment_behavior ⇒ Object
Controls how Stripe handles payment when a subscription update requires payment and ‘collection_method=charge_automatically`.
-
#plan ⇒ Object
The identifier of the plan to add to the subscription.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
-
#proration_behavior ⇒ Object
Determines how to handle [prorations](docs.stripe.com/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes.
-
#proration_date ⇒ Object
If set, the proration will be calculated as though the subscription was updated at the given time.
-
#quantity ⇒ Object
The quantity you’d like to apply to the subscription item you’re creating.
-
#subscription ⇒ Object
The identifier of the subscription to modify.
-
#tax_rates ⇒ Object
A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_thresholds: nil, current_trial: nil, discounts: nil, expand: nil, metadata: nil, payment_behavior: nil, plan: nil, price: nil, price_data: nil, proration_behavior: nil, proration_date: nil, quantity: nil, subscription: nil, tax_rates: nil, trial: nil) ⇒ SubscriptionItemCreateParams
constructor
A new instance of SubscriptionItemCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(billing_thresholds: nil, current_trial: nil, discounts: nil, expand: nil, metadata: nil, payment_behavior: nil, plan: nil, price: nil, price_data: nil, proration_behavior: nil, proration_date: nil, quantity: nil, subscription: nil, tax_rates: nil, trial: nil) ⇒ SubscriptionItemCreateParams
Returns a new instance of SubscriptionItemCreateParams.
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 210 def initialize( billing_thresholds: nil, current_trial: nil, discounts: nil, expand: nil, metadata: nil, payment_behavior: nil, plan: nil, price: nil, price_data: nil, proration_behavior: nil, proration_date: nil, quantity: nil, subscription: nil, tax_rates: nil, trial: nil ) @billing_thresholds = billing_thresholds @current_trial = current_trial @discounts = discounts @expand = @metadata = @payment_behavior = payment_behavior @plan = plan @price = price @price_data = price_data @proration_behavior = proration_behavior @proration_date = proration_date @quantity = quantity @subscription = subscription @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
180 181 182 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 180 def billing_thresholds @billing_thresholds end |
#current_trial ⇒ Object
The trial offer to apply to this subscription item.
182 183 184 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 182 def current_trial @current_trial end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
184 185 186 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 184 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
186 187 188 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 186 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
188 189 190 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 188 def @metadata end |
#payment_behavior ⇒ Object
Controls how Stripe handles payment when a subscription update requires payment and ‘collection_method=charge_automatically`.
190 191 192 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 190 def payment_behavior @payment_behavior end |
#plan ⇒ Object
The identifier of the plan to add to the subscription.
192 193 194 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 192 def plan @plan end |
#price ⇒ Object
The ID of the price object.
194 195 196 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 194 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
196 197 198 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 196 def price_data @price_data end |
#proration_behavior ⇒ Object
Determines how to handle [prorations](docs.stripe.com/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes. The default value is `create_prorations`.
198 199 200 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 198 def proration_behavior @proration_behavior end |
#proration_date ⇒ Object
If set, the proration will be calculated as though the subscription was updated at the given time. This can be used to apply the same proration that was previewed with the [upcoming invoice](/api/invoices/create_preview) endpoint.
200 201 202 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 200 def proration_date @proration_date end |
#quantity ⇒ Object
The quantity you’d like to apply to the subscription item you’re creating.
202 203 204 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 202 def quantity @quantity end |
#subscription ⇒ Object
The identifier of the subscription to modify.
204 205 206 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 204 def subscription @subscription end |
#tax_rates ⇒ Object
A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
206 207 208 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 206 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
208 209 210 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 208 def trial @trial end |
Class Method Details
.field_encodings ⇒ Object
244 245 246 247 248 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 244 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |