Class: Stripe::SubscriptionItemCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_item_create_params.rb

Defined Under Namespace

Classes: BillingThresholds, CurrentTrial, Discount, PriceData, Trial

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(billing_thresholds: nil, current_trial: nil, discounts: nil, expand: nil, metadata: nil, payment_behavior: nil, plan: nil, price: nil, price_data: nil, proration_behavior: nil, proration_date: nil, quantity: nil, subscription: nil, tax_rates: nil, trial: nil) ⇒ SubscriptionItemCreateParams

Returns a new instance of SubscriptionItemCreateParams.



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/stripe/params/subscription_item_create_params.rb', line 158

def initialize(
  billing_thresholds: nil,
  current_trial: nil,
  discounts: nil,
  expand: nil,
  metadata: nil,
  payment_behavior: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  proration_behavior: nil,
  proration_date: nil,
  quantity: nil,
  subscription: nil,
  tax_rates: nil,
  trial: nil
)
  @billing_thresholds = billing_thresholds
  @current_trial = current_trial
  @discounts = discounts
  @expand = expand
  @metadata = 
  @payment_behavior = payment_behavior
  @plan = plan
  @price = price
  @price_data = price_data
  @proration_behavior = proration_behavior
  @proration_date = proration_date
  @quantity = quantity
  @subscription = subscription
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



128
129
130
# File 'lib/stripe/params/subscription_item_create_params.rb', line 128

def billing_thresholds
  @billing_thresholds
end

#current_trialObject

The trial offer to apply to this subscription item.



130
131
132
# File 'lib/stripe/params/subscription_item_create_params.rb', line 130

def current_trial
  @current_trial
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



132
133
134
# File 'lib/stripe/params/subscription_item_create_params.rb', line 132

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



134
135
136
# File 'lib/stripe/params/subscription_item_create_params.rb', line 134

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



136
137
138
# File 'lib/stripe/params/subscription_item_create_params.rb', line 136

def 
  @metadata
end

#payment_behaviorObject

Controls how Stripe handles payment when a subscription update requires payment and ‘collection_method=charge_automatically`.



138
139
140
# File 'lib/stripe/params/subscription_item_create_params.rb', line 138

def payment_behavior
  @payment_behavior
end

#planObject

The identifier of the plan to add to the subscription.



140
141
142
# File 'lib/stripe/params/subscription_item_create_params.rb', line 140

def plan
  @plan
end

#priceObject

The ID of the price object.



142
143
144
# File 'lib/stripe/params/subscription_item_create_params.rb', line 142

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.



144
145
146
# File 'lib/stripe/params/subscription_item_create_params.rb', line 144

def price_data
  @price_data
end

#proration_behaviorObject

Determines how to handle [prorations](docs.stripe.com/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes. The default value is `create_prorations`.



146
147
148
# File 'lib/stripe/params/subscription_item_create_params.rb', line 146

def proration_behavior
  @proration_behavior
end

#proration_dateObject

If set, the proration will be calculated as though the subscription was updated at the given time. This can be used to apply the same proration that was previewed with the [upcoming invoice](/api/invoices/create_preview) endpoint.



148
149
150
# File 'lib/stripe/params/subscription_item_create_params.rb', line 148

def proration_date
  @proration_date
end

#quantityObject

The quantity you’d like to apply to the subscription item you’re creating.



150
151
152
# File 'lib/stripe/params/subscription_item_create_params.rb', line 150

def quantity
  @quantity
end

#subscriptionObject

The identifier of the subscription to modify.



152
153
154
# File 'lib/stripe/params/subscription_item_create_params.rb', line 152

def subscription
  @subscription
end

#tax_ratesObject

A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



154
155
156
# File 'lib/stripe/params/subscription_item_create_params.rb', line 154

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



156
157
158
# File 'lib/stripe/params/subscription_item_create_params.rb', line 156

def trial
  @trial
end

Class Method Details

.field_encodingsObject



192
193
194
195
196
# File 'lib/stripe/params/subscription_item_create_params.rb', line 192

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end