Class: Stripe::SubscriptionItemCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionItemCreateParams
- Defined in:
- lib/stripe/params/subscription_item_create_params.rb
Defined Under Namespace
Classes: BillingThresholds, CurrentTrial, Discount, PriceData, Trial
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#current_trial ⇒ Object
The trial offer to apply to this subscription item.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#payment_behavior ⇒ Object
Use ‘allow_incomplete` to transition the subscription to `status=past_due` if a payment is required but cannot be paid.
-
#plan ⇒ Object
The identifier of the plan to add to the subscription.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
-
#proration_behavior ⇒ Object
Determines how to handle [prorations](docs.stripe.com/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes.
-
#proration_date ⇒ Object
If set, the proration will be calculated as though the subscription was updated at the given time.
-
#quantity ⇒ Object
The quantity you’d like to apply to the subscription item you’re creating.
-
#subscription ⇒ Object
The identifier of the subscription to modify.
-
#tax_rates ⇒ Object
A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_thresholds: nil, current_trial: nil, discounts: nil, expand: nil, metadata: nil, payment_behavior: nil, plan: nil, price: nil, price_data: nil, proration_behavior: nil, proration_date: nil, quantity: nil, subscription: nil, tax_rates: nil, trial: nil) ⇒ SubscriptionItemCreateParams
constructor
A new instance of SubscriptionItemCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(billing_thresholds: nil, current_trial: nil, discounts: nil, expand: nil, metadata: nil, payment_behavior: nil, plan: nil, price: nil, price_data: nil, proration_behavior: nil, proration_date: nil, quantity: nil, subscription: nil, tax_rates: nil, trial: nil) ⇒ SubscriptionItemCreateParams
Returns a new instance of SubscriptionItemCreateParams.
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 164 def initialize( billing_thresholds: nil, current_trial: nil, discounts: nil, expand: nil, metadata: nil, payment_behavior: nil, plan: nil, price: nil, price_data: nil, proration_behavior: nil, proration_date: nil, quantity: nil, subscription: nil, tax_rates: nil, trial: nil ) @billing_thresholds = billing_thresholds @current_trial = current_trial @discounts = discounts @expand = @metadata = @payment_behavior = payment_behavior @plan = plan @price = price @price_data = price_data @proration_behavior = proration_behavior @proration_date = proration_date @quantity = quantity @subscription = subscription @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
128 129 130 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 128 def billing_thresholds @billing_thresholds end |
#current_trial ⇒ Object
The trial offer to apply to this subscription item.
130 131 132 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 130 def current_trial @current_trial end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
132 133 134 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 132 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
134 135 136 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 134 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
136 137 138 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 136 def @metadata end |
#payment_behavior ⇒ Object
Use ‘allow_incomplete` to transition the subscription to `status=past_due` if a payment is required but cannot be paid. This allows you to manage scenarios where additional user actions are needed to pay a subscription’s invoice. For example, SCA regulation may require 3DS authentication to complete payment. See the [SCA Migration Guide](docs.stripe.com/billing/migration/strong-customer-authentication) for Billing to learn more. This is the default behavior.
Use ‘default_incomplete` to transition the subscription to `status=past_due` when payment is required and await explicit confirmation of the invoice’s payment intent. This allows simpler management of scenarios where additional user actions are needed to pay a subscription’s invoice. Such as failed payments, [SCA regulation](docs.stripe.com/billing/migration/strong-customer-authentication), or collecting a mandate for a bank debit payment method.
Use ‘pending_if_incomplete` to update the subscription using [pending updates](docs.stripe.com/billing/subscriptions/pending-updates). When you use `pending_if_incomplete` you can only pass the parameters [supported by pending updates](docs.stripe.com/billing/pending-updates-reference#supported-attributes).
Use ‘error_if_incomplete` if you want Stripe to return an HTTP 402 status code if a subscription’s invoice cannot be paid. For example, if a payment method requires 3DS authentication due to SCA regulation and further user action is needed, this parameter does not update the subscription and returns an error instead. This was the default behavior for API versions prior to 2019-03-14. See the [changelog](docs.stripe.com/changelog/2019-03-14) to learn more.
144 145 146 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 144 def payment_behavior @payment_behavior end |
#plan ⇒ Object
The identifier of the plan to add to the subscription.
146 147 148 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 146 def plan @plan end |
#price ⇒ Object
The ID of the price object.
148 149 150 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 148 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
150 151 152 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 150 def price_data @price_data end |
#proration_behavior ⇒ Object
Determines how to handle [prorations](docs.stripe.com/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes. The default value is `create_prorations`.
152 153 154 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 152 def proration_behavior @proration_behavior end |
#proration_date ⇒ Object
If set, the proration will be calculated as though the subscription was updated at the given time. This can be used to apply the same proration that was previewed with the [upcoming invoice](/api/invoices/create_preview) endpoint.
154 155 156 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 154 def proration_date @proration_date end |
#quantity ⇒ Object
The quantity you’d like to apply to the subscription item you’re creating.
156 157 158 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 156 def quantity @quantity end |
#subscription ⇒ Object
The identifier of the subscription to modify.
158 159 160 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 158 def subscription @subscription end |
#tax_rates ⇒ Object
A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
160 161 162 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 160 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
162 163 164 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 162 def trial @trial end |
Class Method Details
.field_encodings ⇒ Object
198 199 200 201 202 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 198 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |