Class: Stripe::SubscriptionItemCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_item_create_params.rb

Defined Under Namespace

Classes: BillingThresholds, CurrentTrial, Discount, PriceData, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, current_trial: nil, discounts: nil, expand: nil, metadata: nil, payment_behavior: nil, plan: nil, price: nil, price_data: nil, proration_behavior: nil, proration_date: nil, quantity: nil, subscription: nil, tax_rates: nil, trial: nil) ⇒ SubscriptionItemCreateParams

Returns a new instance of SubscriptionItemCreateParams.



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/stripe/params/subscription_item_create_params.rb', line 212

def initialize(
  billing_thresholds: nil,
  current_trial: nil,
  discounts: nil,
  expand: nil,
  metadata: nil,
  payment_behavior: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  proration_behavior: nil,
  proration_date: nil,
  quantity: nil,
  subscription: nil,
  tax_rates: nil,
  trial: nil
)
  @billing_thresholds = billing_thresholds
  @current_trial = current_trial
  @discounts = discounts
  @expand = expand
  @metadata = 
  @payment_behavior = payment_behavior
  @plan = plan
  @price = price
  @price_data = price_data
  @proration_behavior = proration_behavior
  @proration_date = proration_date
  @quantity = quantity
  @subscription = subscription
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



176
177
178
# File 'lib/stripe/params/subscription_item_create_params.rb', line 176

def billing_thresholds
  @billing_thresholds
end

#current_trialObject

The trial offer to apply to this subscription item.



178
179
180
# File 'lib/stripe/params/subscription_item_create_params.rb', line 178

def current_trial
  @current_trial
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



180
181
182
# File 'lib/stripe/params/subscription_item_create_params.rb', line 180

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



182
183
184
# File 'lib/stripe/params/subscription_item_create_params.rb', line 182

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



184
185
186
# File 'lib/stripe/params/subscription_item_create_params.rb', line 184

def 
  @metadata
end

#payment_behaviorObject

Use ‘allow_incomplete` to transition the subscription to `status=past_due` if a payment is required but cannot be paid. This allows you to manage scenarios where additional user actions are needed to pay a subscription’s invoice. For example, SCA regulation may require 3DS authentication to complete payment. See the [SCA Migration Guide](docs.stripe.com/billing/migration/strong-customer-authentication) for Billing to learn more. This is the default behavior.

Use ‘default_incomplete` to transition the subscription to `status=past_due` when payment is required and await explicit confirmation of the invoice’s payment intent. This allows simpler management of scenarios where additional user actions are needed to pay a subscription’s invoice. Such as failed payments, [SCA regulation](docs.stripe.com/billing/migration/strong-customer-authentication), or collecting a mandate for a bank debit payment method.

Use ‘pending_if_incomplete` to update the subscription using [pending updates](docs.stripe.com/billing/subscriptions/pending-updates). When you use `pending_if_incomplete` you can only pass the parameters [supported by pending updates](docs.stripe.com/billing/pending-updates-reference#supported-attributes).

Use ‘error_if_incomplete` if you want Stripe to return an HTTP 402 status code if a subscription’s invoice cannot be paid. For example, if a payment method requires 3DS authentication due to SCA regulation and further user action is needed, this parameter does not update the subscription and returns an error instead. This was the default behavior for API versions prior to 2019-03-14. See the [changelog](docs.stripe.com/changelog/2019-03-14) to learn more.



192
193
194
# File 'lib/stripe/params/subscription_item_create_params.rb', line 192

def payment_behavior
  @payment_behavior
end

#planObject

The identifier of the plan to add to the subscription.



194
195
196
# File 'lib/stripe/params/subscription_item_create_params.rb', line 194

def plan
  @plan
end

#priceObject

The ID of the price object.



196
197
198
# File 'lib/stripe/params/subscription_item_create_params.rb', line 196

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.



198
199
200
# File 'lib/stripe/params/subscription_item_create_params.rb', line 198

def price_data
  @price_data
end

#proration_behaviorObject

Determines how to handle [prorations](docs.stripe.com/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes. The default value is `create_prorations`.



200
201
202
# File 'lib/stripe/params/subscription_item_create_params.rb', line 200

def proration_behavior
  @proration_behavior
end

#proration_dateObject

If set, the proration will be calculated as though the subscription was updated at the given time. This can be used to apply the same proration that was previewed with the [upcoming invoice](api.stripe.com#retrieve_customer_invoice) endpoint.



202
203
204
# File 'lib/stripe/params/subscription_item_create_params.rb', line 202

def proration_date
  @proration_date
end

#quantityObject

The quantity you’d like to apply to the subscription item you’re creating.



204
205
206
# File 'lib/stripe/params/subscription_item_create_params.rb', line 204

def quantity
  @quantity
end

#subscriptionObject

The identifier of the subscription to modify.



206
207
208
# File 'lib/stripe/params/subscription_item_create_params.rb', line 206

def subscription
  @subscription
end

#tax_ratesObject

A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



208
209
210
# File 'lib/stripe/params/subscription_item_create_params.rb', line 208

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



210
211
212
# File 'lib/stripe/params/subscription_item_create_params.rb', line 210

def trial
  @trial
end