Class: Stripe::SubscriptionItemCreateParams::Trial
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionItemCreateParams::Trial
- Defined in:
- lib/stripe/params/subscription_item_create_params.rb
Instance Attribute Summary collapse
-
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial.
-
#type ⇒ Object
Determines the type of trial for this item.
Instance Method Summary collapse
-
#initialize(converts_to: nil, type: nil) ⇒ Trial
constructor
A new instance of Trial.
Methods inherited from RequestParams
Constructor Details
#initialize(converts_to: nil, type: nil) ⇒ Trial
Returns a new instance of Trial.
170 171 172 173 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 170 def initialize(converts_to: nil, type: nil) @converts_to = converts_to @type = type end |
Instance Attribute Details
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial. Currently only supports at most 1 price ID.
166 167 168 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 166 def converts_to @converts_to end |
#type ⇒ Object
Determines the type of trial for this item.
168 169 170 |
# File 'lib/stripe/params/subscription_item_create_params.rb', line 168 def type @type end |