Class: Stripe::SubscriptionItemService

Inherits:
StripeService show all
Defined in:
lib/stripe/services/subscription_item_service.rb

Defined Under Namespace

Classes: CreateParams, DeleteParams, ListParams, RetrieveParams, UpdateParams

Instance Method Summary collapse

Methods inherited from StripeService

#initialize, #request, #request_stream

Constructor Details

This class inherits a constructor from Stripe::StripeService

Instance Method Details

#create(params = {}, opts = {}) ⇒ Object

Adds a new item to an existing subscription. No existing items will be changed or replaced.



318
319
320
321
322
323
324
325
326
# File 'lib/stripe/services/subscription_item_service.rb', line 318

def create(params = {}, opts = {})
  request(
    method: :post,
    path: "/v1/subscription_items",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#delete(item, params = {}, opts = {}) ⇒ Object

Deletes an item from the subscription. Removing a subscription item from a subscription will not cancel the subscription.



329
330
331
332
333
334
335
336
337
# File 'lib/stripe/services/subscription_item_service.rb', line 329

def delete(item, params = {}, opts = {})
  request(
    method: :delete,
    path: format("/v1/subscription_items/%<item>s", { item: CGI.escape(item) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#list(params = {}, opts = {}) ⇒ Object

Returns a list of your subscription items for a given subscription.



340
341
342
343
344
345
346
347
348
# File 'lib/stripe/services/subscription_item_service.rb', line 340

def list(params = {}, opts = {})
  request(
    method: :get,
    path: "/v1/subscription_items",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#retrieve(item, params = {}, opts = {}) ⇒ Object

Retrieves the subscription item with the given ID.



351
352
353
354
355
356
357
358
359
# File 'lib/stripe/services/subscription_item_service.rb', line 351

def retrieve(item, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v1/subscription_items/%<item>s", { item: CGI.escape(item) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#update(item, params = {}, opts = {}) ⇒ Object

Updates the plan or quantity of an item on a current subscription.



362
363
364
365
366
367
368
369
370
# File 'lib/stripe/services/subscription_item_service.rb', line 362

def update(item, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/subscription_items/%<item>s", { item: CGI.escape(item) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end