Class: Stripe::SubscriptionItemService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::SubscriptionItemService
- Defined in:
- lib/stripe/services/subscription_item_service.rb
Defined Under Namespace
Classes: CreateParams, DeleteParams, ListParams, RetrieveParams, UpdateParams
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Adds a new item to an existing subscription.
-
#delete(item, params = {}, opts = {}) ⇒ Object
Deletes an item from the subscription.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of your subscription items for a given subscription.
-
#retrieve(item, params = {}, opts = {}) ⇒ Object
Retrieves the subscription item with the given ID.
-
#update(item, params = {}, opts = {}) ⇒ Object
Updates the plan or quantity of an item on a current subscription.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Adds a new item to an existing subscription. No existing items will be changed or replaced.
292 293 294 295 296 297 298 299 300 |
# File 'lib/stripe/services/subscription_item_service.rb', line 292 def create(params = {}, opts = {}) request( method: :post, path: "/v1/subscription_items", params: params, opts: opts, base_address: :api ) end |
#delete(item, params = {}, opts = {}) ⇒ Object
Deletes an item from the subscription. Removing a subscription item from a subscription will not cancel the subscription.
303 304 305 306 307 308 309 310 311 |
# File 'lib/stripe/services/subscription_item_service.rb', line 303 def delete(item, params = {}, opts = {}) request( method: :delete, path: format("/v1/subscription_items/%<item>s", { item: CGI.escape(item) }), params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of your subscription items for a given subscription.
314 315 316 317 318 319 320 321 322 |
# File 'lib/stripe/services/subscription_item_service.rb', line 314 def list(params = {}, opts = {}) request( method: :get, path: "/v1/subscription_items", params: params, opts: opts, base_address: :api ) end |
#retrieve(item, params = {}, opts = {}) ⇒ Object
Retrieves the subscription item with the given ID.
325 326 327 328 329 330 331 332 333 |
# File 'lib/stripe/services/subscription_item_service.rb', line 325 def retrieve(item, params = {}, opts = {}) request( method: :get, path: format("/v1/subscription_items/%<item>s", { item: CGI.escape(item) }), params: params, opts: opts, base_address: :api ) end |
#update(item, params = {}, opts = {}) ⇒ Object
Updates the plan or quantity of an item on a current subscription.
336 337 338 339 340 341 342 343 344 |
# File 'lib/stripe/services/subscription_item_service.rb', line 336 def update(item, params = {}, opts = {}) request( method: :post, path: format("/v1/subscription_items/%<item>s", { item: CGI.escape(item) }), params: params, opts: opts, base_address: :api ) end |