Class: Stripe::SubscriptionItemService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_item_service.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, expand: nil, metadata: nil, payment_behavior: nil, plan: nil, price: nil, price_data: nil, proration_behavior: nil, proration_date: nil, quantity: nil, subscription: nil, tax_rates: nil, trial: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
# File 'lib/stripe/services/subscription_item_service.rb', line 420

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  expand: nil,
  metadata: nil,
  payment_behavior: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  proration_behavior: nil,
  proration_date: nil,
  quantity: nil,
  subscription: nil,
  tax_rates: nil,
  trial: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @expand = expand
  @metadata = 
  @payment_behavior = payment_behavior
  @plan = plan
  @price = price
  @price_data = price_data
  @proration_behavior = proration_behavior
  @proration_date = proration_date
  @quantity = quantity
  @subscription = subscription
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.



373
374
375
# File 'lib/stripe/services/subscription_item_service.rb', line 373

def billing_thresholds
  @billing_thresholds
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



376
377
378
# File 'lib/stripe/services/subscription_item_service.rb', line 376

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



379
380
381
# File 'lib/stripe/services/subscription_item_service.rb', line 379

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



382
383
384
# File 'lib/stripe/services/subscription_item_service.rb', line 382

def 
  @metadata
end

#payment_behaviorObject

Use ‘allow_incomplete` to transition the subscription to `status=past_due` if a payment is required but cannot be paid. This allows you to manage scenarios where additional user actions are needed to pay a subscription’s invoice. For example, SCA regulation may require 3DS authentication to complete payment. See the [SCA Migration Guide](stripe.com/docs/billing/migration/strong-customer-authentication) for Billing to learn more. This is the default behavior.

Use ‘default_incomplete` to transition the subscription to `status=past_due` when payment is required and await explicit confirmation of the invoice’s payment intent. This allows simpler management of scenarios where additional user actions are needed to pay a subscription’s invoice. Such as failed payments, [SCA regulation](stripe.com/docs/billing/migration/strong-customer-authentication), or collecting a mandate for a bank debit payment method.

Use ‘pending_if_incomplete` to update the subscription using [pending updates](stripe.com/docs/billing/subscriptions/pending-updates). When you use `pending_if_incomplete` you can only pass the parameters [supported by pending updates](stripe.com/docs/billing/pending-updates-reference#supported-attributes).

Use ‘error_if_incomplete` if you want Stripe to return an HTTP 402 status code if a subscription’s invoice cannot be paid. For example, if a payment method requires 3DS authentication due to SCA regulation and further user action is needed, this parameter does not update the subscription and returns an error instead. This was the default behavior for API versions prior to 2019-03-14. See the [changelog](stripe.com/docs/upgrades#2019-03-14) to learn more.



391
392
393
# File 'lib/stripe/services/subscription_item_service.rb', line 391

def payment_behavior
  @payment_behavior
end

#planObject

The identifier of the plan to add to the subscription.



394
395
396
# File 'lib/stripe/services/subscription_item_service.rb', line 394

def plan
  @plan
end

#priceObject

The ID of the price object.



397
398
399
# File 'lib/stripe/services/subscription_item_service.rb', line 397

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



400
401
402
# File 'lib/stripe/services/subscription_item_service.rb', line 400

def price_data
  @price_data
end

#proration_behaviorObject

Determines how to handle [prorations](stripe.com/docs/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes. The default value is `create_prorations`.



403
404
405
# File 'lib/stripe/services/subscription_item_service.rb', line 403

def proration_behavior
  @proration_behavior
end

#proration_dateObject

If set, the proration will be calculated as though the subscription was updated at the given time. This can be used to apply the same proration that was previewed with the [upcoming invoice](stripe.com/docs/api#retrieve_customer_invoice) endpoint.



406
407
408
# File 'lib/stripe/services/subscription_item_service.rb', line 406

def proration_date
  @proration_date
end

#quantityObject

The quantity you’d like to apply to the subscription item you’re creating.



409
410
411
# File 'lib/stripe/services/subscription_item_service.rb', line 409

def quantity
  @quantity
end

#subscriptionObject

The identifier of the subscription to modify.



412
413
414
# File 'lib/stripe/services/subscription_item_service.rb', line 412

def subscription
  @subscription
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



415
416
417
# File 'lib/stripe/services/subscription_item_service.rb', line 415

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



418
419
420
# File 'lib/stripe/services/subscription_item_service.rb', line 418

def trial
  @trial
end