Class: Stripe::SubscriptionItemUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_item_update_params.rb

Defined Under Namespace

Classes: BillingThresholds, CurrentTrial, Discount, PriceData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(billing_thresholds: nil, current_trial: nil, discounts: nil, expand: nil, metadata: nil, off_session: nil, payment_behavior: nil, plan: nil, price: nil, price_data: nil, proration_behavior: nil, proration_date: nil, quantity: nil, tax_rates: nil) ⇒ SubscriptionItemUpdateParams

Returns a new instance of SubscriptionItemUpdateParams.



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/stripe/params/subscription_item_update_params.rb', line 196

def initialize(
  billing_thresholds: nil,
  current_trial: nil,
  discounts: nil,
  expand: nil,
  metadata: nil,
  off_session: nil,
  payment_behavior: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  proration_behavior: nil,
  proration_date: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @current_trial = current_trial
  @discounts = discounts
  @expand = expand
  @metadata = 
  @off_session = off_session
  @payment_behavior = payment_behavior
  @plan = plan
  @price = price
  @price_data = price_data
  @proration_behavior = proration_behavior
  @proration_date = proration_date
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



168
169
170
# File 'lib/stripe/params/subscription_item_update_params.rb', line 168

def billing_thresholds
  @billing_thresholds
end

#current_trialObject

The trial offer to apply to this subscription item.



170
171
172
# File 'lib/stripe/params/subscription_item_update_params.rb', line 170

def current_trial
  @current_trial
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



172
173
174
# File 'lib/stripe/params/subscription_item_update_params.rb', line 172

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



174
175
176
# File 'lib/stripe/params/subscription_item_update_params.rb', line 174

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



176
177
178
# File 'lib/stripe/params/subscription_item_update_params.rb', line 176

def 
  @metadata
end

#off_sessionObject

Indicates if a customer is on or off-session while an invoice payment is attempted. Defaults to ‘false` (on-session).



178
179
180
# File 'lib/stripe/params/subscription_item_update_params.rb', line 178

def off_session
  @off_session
end

#payment_behaviorObject

Controls how Stripe handles payment when a subscription update requires payment and ‘collection_method=charge_automatically`.



180
181
182
# File 'lib/stripe/params/subscription_item_update_params.rb', line 180

def payment_behavior
  @payment_behavior
end

#planObject

The identifier of the new plan for this subscription item.



182
183
184
# File 'lib/stripe/params/subscription_item_update_params.rb', line 182

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



184
185
186
# File 'lib/stripe/params/subscription_item_update_params.rb', line 184

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.



186
187
188
# File 'lib/stripe/params/subscription_item_update_params.rb', line 186

def price_data
  @price_data
end

#proration_behaviorObject

Determines how to handle [prorations](docs.stripe.com/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes. The default value is `create_prorations`.



188
189
190
# File 'lib/stripe/params/subscription_item_update_params.rb', line 188

def proration_behavior
  @proration_behavior
end

#proration_dateObject

If set, the proration will be calculated as though the subscription was updated at the given time. This can be used to apply the same proration that was previewed with the [upcoming invoice](/api/invoices/create_preview) endpoint.



190
191
192
# File 'lib/stripe/params/subscription_item_update_params.rb', line 190

def proration_date
  @proration_date
end

#quantityObject

The quantity you’d like to apply to the subscription item you’re creating.



192
193
194
# File 'lib/stripe/params/subscription_item_update_params.rb', line 192

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



194
195
196
# File 'lib/stripe/params/subscription_item_update_params.rb', line 194

def tax_rates
  @tax_rates
end

Class Method Details

.field_encodingsObject



228
229
230
231
232
# File 'lib/stripe/params/subscription_item_update_params.rb', line 228

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end