Class: Stripe::SubscriptionItemUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionItemUpdateParams
- Defined in:
- lib/stripe/params/subscription_item_update_params.rb
Defined Under Namespace
Classes: BillingThresholds, CurrentTrial, Discount, PriceData
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#current_trial ⇒ Object
The trial offer to apply to this subscription item.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#off_session ⇒ Object
Indicates if a customer is on or off-session while an invoice payment is attempted.
-
#payment_behavior ⇒ Object
Use ‘allow_incomplete` to transition the subscription to `status=past_due` if a payment is required but cannot be paid.
-
#plan ⇒ Object
The identifier of the new plan for this subscription item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
-
#proration_behavior ⇒ Object
Determines how to handle [prorations](docs.stripe.com/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes.
-
#proration_date ⇒ Object
If set, the proration will be calculated as though the subscription was updated at the given time.
-
#quantity ⇒ Object
The quantity you’d like to apply to the subscription item you’re creating.
-
#tax_rates ⇒ Object
A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_thresholds: nil, current_trial: nil, discounts: nil, expand: nil, metadata: nil, off_session: nil, payment_behavior: nil, plan: nil, price: nil, price_data: nil, proration_behavior: nil, proration_date: nil, quantity: nil, tax_rates: nil) ⇒ SubscriptionItemUpdateParams
constructor
A new instance of SubscriptionItemUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(billing_thresholds: nil, current_trial: nil, discounts: nil, expand: nil, metadata: nil, off_session: nil, payment_behavior: nil, plan: nil, price: nil, price_data: nil, proration_behavior: nil, proration_date: nil, quantity: nil, tax_rates: nil) ⇒ SubscriptionItemUpdateParams
Returns a new instance of SubscriptionItemUpdateParams.
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/stripe/params/subscription_item_update_params.rb', line 202 def initialize( billing_thresholds: nil, current_trial: nil, discounts: nil, expand: nil, metadata: nil, off_session: nil, payment_behavior: nil, plan: nil, price: nil, price_data: nil, proration_behavior: nil, proration_date: nil, quantity: nil, tax_rates: nil ) @billing_thresholds = billing_thresholds @current_trial = current_trial @discounts = discounts @expand = @metadata = @off_session = off_session @payment_behavior = payment_behavior @plan = plan @price = price @price_data = price_data @proration_behavior = proration_behavior @proration_date = proration_date @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
168 169 170 |
# File 'lib/stripe/params/subscription_item_update_params.rb', line 168 def billing_thresholds @billing_thresholds end |
#current_trial ⇒ Object
The trial offer to apply to this subscription item.
170 171 172 |
# File 'lib/stripe/params/subscription_item_update_params.rb', line 170 def current_trial @current_trial end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
172 173 174 |
# File 'lib/stripe/params/subscription_item_update_params.rb', line 172 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
174 175 176 |
# File 'lib/stripe/params/subscription_item_update_params.rb', line 174 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
176 177 178 |
# File 'lib/stripe/params/subscription_item_update_params.rb', line 176 def @metadata end |
#off_session ⇒ Object
Indicates if a customer is on or off-session while an invoice payment is attempted. Defaults to ‘false` (on-session).
178 179 180 |
# File 'lib/stripe/params/subscription_item_update_params.rb', line 178 def off_session @off_session end |
#payment_behavior ⇒ Object
Use ‘allow_incomplete` to transition the subscription to `status=past_due` if a payment is required but cannot be paid. This allows you to manage scenarios where additional user actions are needed to pay a subscription’s invoice. For example, SCA regulation may require 3DS authentication to complete payment. See the [SCA Migration Guide](docs.stripe.com/billing/migration/strong-customer-authentication) for Billing to learn more. This is the default behavior.
Use ‘default_incomplete` to transition the subscription to `status=past_due` when payment is required and await explicit confirmation of the invoice’s payment intent. This allows simpler management of scenarios where additional user actions are needed to pay a subscription’s invoice. Such as failed payments, [SCA regulation](docs.stripe.com/billing/migration/strong-customer-authentication), or collecting a mandate for a bank debit payment method.
Use ‘pending_if_incomplete` to update the subscription using [pending updates](docs.stripe.com/billing/subscriptions/pending-updates). When you use `pending_if_incomplete` you can only pass the parameters [supported by pending updates](docs.stripe.com/billing/pending-updates-reference#supported-attributes).
Use ‘error_if_incomplete` if you want Stripe to return an HTTP 402 status code if a subscription’s invoice cannot be paid. For example, if a payment method requires 3DS authentication due to SCA regulation and further user action is needed, this parameter does not update the subscription and returns an error instead. This was the default behavior for API versions prior to 2019-03-14. See the [changelog](docs.stripe.com/changelog/2019-03-14) to learn more.
186 187 188 |
# File 'lib/stripe/params/subscription_item_update_params.rb', line 186 def payment_behavior @payment_behavior end |
#plan ⇒ Object
The identifier of the new plan for this subscription item.
188 189 190 |
# File 'lib/stripe/params/subscription_item_update_params.rb', line 188 def plan @plan end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.
190 191 192 |
# File 'lib/stripe/params/subscription_item_update_params.rb', line 190 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.
192 193 194 |
# File 'lib/stripe/params/subscription_item_update_params.rb', line 192 def price_data @price_data end |
#proration_behavior ⇒ Object
Determines how to handle [prorations](docs.stripe.com/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes. The default value is `create_prorations`.
194 195 196 |
# File 'lib/stripe/params/subscription_item_update_params.rb', line 194 def proration_behavior @proration_behavior end |
#proration_date ⇒ Object
If set, the proration will be calculated as though the subscription was updated at the given time. This can be used to apply the same proration that was previewed with the [upcoming invoice](/api/invoices/create_preview) endpoint.
196 197 198 |
# File 'lib/stripe/params/subscription_item_update_params.rb', line 196 def proration_date @proration_date end |
#quantity ⇒ Object
The quantity you’d like to apply to the subscription item you’re creating.
198 199 200 |
# File 'lib/stripe/params/subscription_item_update_params.rb', line 198 def quantity @quantity end |
#tax_rates ⇒ Object
A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
200 201 202 |
# File 'lib/stripe/params/subscription_item_update_params.rb', line 200 def tax_rates @tax_rates end |
Class Method Details
.field_encodings ⇒ Object
234 235 236 237 238 |
# File 'lib/stripe/params/subscription_item_update_params.rb', line 234 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |