Class: Stripe::SubscriptionPauseParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionPauseParams
- Defined in:
- lib/stripe/params/subscription_pause_params.rb
Defined Under Namespace
Classes: BillFor
Instance Attribute Summary collapse
-
#bill_for ⇒ Object
Controls what to bill for when pausing the subscription.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoicing_behavior ⇒ Object
Determines how to handle debits and credits when pausing.
-
#type ⇒ Object
The type of pause to apply.
Instance Method Summary collapse
-
#initialize(bill_for: nil, expand: nil, invoicing_behavior: nil, type: nil) ⇒ SubscriptionPauseParams
constructor
A new instance of SubscriptionPauseParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bill_for: nil, expand: nil, invoicing_behavior: nil, type: nil) ⇒ SubscriptionPauseParams
Returns a new instance of SubscriptionPauseParams.
43 44 45 46 47 48 |
# File 'lib/stripe/params/subscription_pause_params.rb', line 43 def initialize(bill_for: nil, expand: nil, invoicing_behavior: nil, type: nil) @bill_for = bill_for @expand = @invoicing_behavior = invoicing_behavior @type = type end |
Instance Attribute Details
#bill_for ⇒ Object
Controls what to bill for when pausing the subscription.
35 36 37 |
# File 'lib/stripe/params/subscription_pause_params.rb', line 35 def bill_for @bill_for end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
37 38 39 |
# File 'lib/stripe/params/subscription_pause_params.rb', line 37 def @expand end |
#invoicing_behavior ⇒ Object
Determines how to handle debits and credits when pausing. The default is ‘pending_invoice_item`.
39 40 41 |
# File 'lib/stripe/params/subscription_pause_params.rb', line 39 def invoicing_behavior @invoicing_behavior end |
#type ⇒ Object
The type of pause to apply. Defaults to ‘subscription`.
41 42 43 |
# File 'lib/stripe/params/subscription_pause_params.rb', line 41 def type @type end |