Class: Stripe::SubscriptionPauseParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionPauseParams
- Defined in:
- lib/stripe/params/subscription_pause_params.rb
Defined Under Namespace
Classes: BillFor
Instance Attribute Summary collapse
-
#bill_for ⇒ Object
Controls what to bill for when pausing the subscription.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoicing_behavior ⇒ Object
Determines how to handle debits and credits when pausing.
-
#type ⇒ Object
The type of pause to apply.
Instance Method Summary collapse
-
#initialize(bill_for: nil, expand: nil, invoicing_behavior: nil, type: nil) ⇒ SubscriptionPauseParams
constructor
A new instance of SubscriptionPauseParams.
Methods inherited from RequestParams
Constructor Details
#initialize(bill_for: nil, expand: nil, invoicing_behavior: nil, type: nil) ⇒ SubscriptionPauseParams
Returns a new instance of SubscriptionPauseParams.
26 27 28 29 30 31 |
# File 'lib/stripe/params/subscription_pause_params.rb', line 26 def initialize(bill_for: nil, expand: nil, invoicing_behavior: nil, type: nil) @bill_for = bill_for @expand = @invoicing_behavior = invoicing_behavior @type = type end |
Instance Attribute Details
#bill_for ⇒ Object
Controls what to bill for when pausing the subscription.
18 19 20 |
# File 'lib/stripe/params/subscription_pause_params.rb', line 18 def bill_for @bill_for end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
20 21 22 |
# File 'lib/stripe/params/subscription_pause_params.rb', line 20 def @expand end |
#invoicing_behavior ⇒ Object
Determines how to handle debits and credits when pausing. The default is ‘pending_invoice_item`.
22 23 24 |
# File 'lib/stripe/params/subscription_pause_params.rb', line 22 def invoicing_behavior @invoicing_behavior end |
#type ⇒ Object
The type of pause to apply.
24 25 26 |
# File 'lib/stripe/params/subscription_pause_params.rb', line 24 def type @type end |