Class: Stripe::SubscriptionPauseParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_pause_params.rb

Defined Under Namespace

Classes: BillFor

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bill_for: nil, expand: nil, invoicing_behavior: nil, type: nil) ⇒ SubscriptionPauseParams

Returns a new instance of SubscriptionPauseParams.



26
27
28
29
30
31
# File 'lib/stripe/params/subscription_pause_params.rb', line 26

def initialize(bill_for: nil, expand: nil, invoicing_behavior: nil, type: nil)
  @bill_for = bill_for
  @expand = expand
  @invoicing_behavior = invoicing_behavior
  @type = type
end

Instance Attribute Details

#bill_forObject

Controls what to bill for when pausing the subscription.



18
19
20
# File 'lib/stripe/params/subscription_pause_params.rb', line 18

def bill_for
  @bill_for
end

#expandObject

Specifies which fields in the response should be expanded.



20
21
22
# File 'lib/stripe/params/subscription_pause_params.rb', line 20

def expand
  @expand
end

#invoicing_behaviorObject

Determines how to handle debits and credits when pausing. The default is ‘pending_invoice_item`.



22
23
24
# File 'lib/stripe/params/subscription_pause_params.rb', line 22

def invoicing_behavior
  @invoicing_behavior
end

#typeObject

The type of pause to apply.



24
25
26
# File 'lib/stripe/params/subscription_pause_params.rb', line 24

def type
  @type
end