Class: Stripe::SubscriptionSchedule

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/subscription_schedule.rb

Overview

A subscription schedule allows you to create and manage the lifecycle of a subscription by predefining expected changes.

Related guide: [Subscription schedules](docs.stripe.com/billing/subscriptions/subscription-schedules)

Defined Under Namespace

Classes: BillingMode, CurrentPhase, DefaultSettings, LastPriceMigrationError, Phase, Prebilling

Constant Summary collapse

OBJECT_NAME =
"subscription_schedule"

Constants inherited from StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applicationObject (readonly)

ID of the Connect Application that created the schedule.



660
661
662
# File 'lib/stripe/resources/subscription_schedule.rb', line 660

def application
  @application
end

#billing_behaviorObject (readonly)

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



662
663
664
# File 'lib/stripe/resources/subscription_schedule.rb', line 662

def billing_behavior
  @billing_behavior
end

#billing_modeObject (readonly)

The billing mode of the subscription.



664
665
666
# File 'lib/stripe/resources/subscription_schedule.rb', line 664

def billing_mode
  @billing_mode
end

#canceled_atObject (readonly)

Time at which the subscription schedule was canceled. Measured in seconds since the Unix epoch.



666
667
668
# File 'lib/stripe/resources/subscription_schedule.rb', line 666

def canceled_at
  @canceled_at
end

#completed_atObject (readonly)

Time at which the subscription schedule was completed. Measured in seconds since the Unix epoch.



668
669
670
# File 'lib/stripe/resources/subscription_schedule.rb', line 668

def completed_at
  @completed_at
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



670
671
672
# File 'lib/stripe/resources/subscription_schedule.rb', line 670

def created
  @created
end

#current_phaseObject (readonly)

Object representing the start and end dates for the current phase of the subscription schedule, if it is ‘active`.



672
673
674
# File 'lib/stripe/resources/subscription_schedule.rb', line 672

def current_phase
  @current_phase
end

#customerObject (readonly)

ID of the customer who owns the subscription schedule.



674
675
676
# File 'lib/stripe/resources/subscription_schedule.rb', line 674

def customer
  @customer
end

#customer_accountObject (readonly)

ID of the account who owns the subscription schedule.



676
677
678
# File 'lib/stripe/resources/subscription_schedule.rb', line 676

def 
  @customer_account
end

#default_settingsObject (readonly)

Attribute for field default_settings



678
679
680
# File 'lib/stripe/resources/subscription_schedule.rb', line 678

def default_settings
  @default_settings
end

#end_behaviorObject (readonly)

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



680
681
682
# File 'lib/stripe/resources/subscription_schedule.rb', line 680

def end_behavior
  @end_behavior
end

#idObject (readonly)

Unique identifier for the object.



682
683
684
# File 'lib/stripe/resources/subscription_schedule.rb', line 682

def id
  @id
end

#last_price_migration_errorObject (readonly)

Details of the most recent price migration that failed for the subscription schedule.



684
685
686
# File 'lib/stripe/resources/subscription_schedule.rb', line 684

def last_price_migration_error
  @last_price_migration_error
end

#livemodeObject (readonly)

If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.



686
687
688
# File 'lib/stripe/resources/subscription_schedule.rb', line 686

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



688
689
690
# File 'lib/stripe/resources/subscription_schedule.rb', line 688

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



690
691
692
# File 'lib/stripe/resources/subscription_schedule.rb', line 690

def object
  @object
end

#phasesObject (readonly)

Configuration for the subscription schedule’s phases.



692
693
694
# File 'lib/stripe/resources/subscription_schedule.rb', line 692

def phases
  @phases
end

#prebillingObject (readonly)

Time period and invoice for a Subscription billed in advance.



694
695
696
# File 'lib/stripe/resources/subscription_schedule.rb', line 694

def prebilling
  @prebilling
end

#released_atObject (readonly)

Time at which the subscription schedule was released. Measured in seconds since the Unix epoch.



696
697
698
# File 'lib/stripe/resources/subscription_schedule.rb', line 696

def released_at
  @released_at
end

#released_subscriptionObject (readonly)

ID of the subscription once managed by the subscription schedule (if it is released).



698
699
700
# File 'lib/stripe/resources/subscription_schedule.rb', line 698

def released_subscription
  @released_subscription
end

#statusObject (readonly)

The present status of the subscription schedule. Possible values are ‘not_started`, `active`, `completed`, `released`, and `canceled`. You can read more about the different states in our [behavior guide](docs.stripe.com/billing/subscriptions/subscription-schedules).



700
701
702
# File 'lib/stripe/resources/subscription_schedule.rb', line 700

def status
  @status
end

#subscriptionObject (readonly)

ID of the subscription managed by the subscription schedule.



702
703
704
# File 'lib/stripe/resources/subscription_schedule.rb', line 702

def subscription
  @subscription
end

#test_clockObject (readonly)

ID of the test clock this subscription schedule belongs to.



704
705
706
# File 'lib/stripe/resources/subscription_schedule.rb', line 704

def test_clock
  @test_clock
end

Class Method Details

.amend(schedule, params = {}, opts = {}) ⇒ Object

Amends an existing subscription schedule.



717
718
719
720
721
722
723
724
# File 'lib/stripe/resources/subscription_schedule.rb', line 717

def self.amend(schedule, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/amend", { schedule: CGI.escape(schedule) }),
    params: params,
    opts: opts
  )
end

.cancel(schedule, params = {}, opts = {}) ⇒ Object

Cancels a subscription schedule and its associated subscription immediately (if the subscription schedule has an active subscription). A subscription schedule can only be canceled if its status is not_started or active.



737
738
739
740
741
742
743
744
# File 'lib/stripe/resources/subscription_schedule.rb', line 737

def self.cancel(schedule, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/cancel", { schedule: CGI.escape(schedule) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

Creates a new subscription schedule object. Each customer can have up to 500 active or scheduled subscriptions.



747
748
749
750
751
752
753
754
# File 'lib/stripe/resources/subscription_schedule.rb', line 747

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/subscription_schedules",
    params: params,
    opts: opts
  )
end

.field_remappingsObject



807
808
809
# File 'lib/stripe/resources/subscription_schedule.rb', line 807

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



796
797
798
799
800
801
802
803
804
805
# File 'lib/stripe/resources/subscription_schedule.rb', line 796

def self.inner_class_types
  @inner_class_types = {
    billing_mode: BillingMode,
    current_phase: CurrentPhase,
    default_settings: DefaultSettings,
    last_price_migration_error: LastPriceMigrationError,
    phases: Phase,
    prebilling: Prebilling,
  }
end

.list(params = {}, opts = {}) ⇒ Object

Retrieves the list of your subscription schedules.



757
758
759
760
761
762
763
764
# File 'lib/stripe/resources/subscription_schedule.rb', line 757

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/subscription_schedules",
    params: params,
    opts: opts
  )
end

.object_nameObject



14
15
16
# File 'lib/stripe/resources/subscription_schedule.rb', line 14

def self.object_name
  "subscription_schedule"
end

.release(schedule, params = {}, opts = {}) ⇒ Object

Releases the subscription schedule immediately, which will stop scheduling of its phases, but leave any existing subscription in place. A schedule can only be released if its status is not_started or active. If the subscription schedule is currently associated with a subscription, releasing it will remove its subscription property and set the subscription’s ID to the released_subscription property.



777
778
779
780
781
782
783
784
# File 'lib/stripe/resources/subscription_schedule.rb', line 777

def self.release(schedule, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/release", { schedule: CGI.escape(schedule) }),
    params: params,
    opts: opts
  )
end

.update(schedule, params = {}, opts = {}) ⇒ Object

Updates an existing subscription schedule.



787
788
789
790
791
792
793
794
# File 'lib/stripe/resources/subscription_schedule.rb', line 787

def self.update(schedule, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s", { schedule: CGI.escape(schedule) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#amend(params = {}, opts = {}) ⇒ Object

Amends an existing subscription schedule.



707
708
709
710
711
712
713
714
# File 'lib/stripe/resources/subscription_schedule.rb', line 707

def amend(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/amend", { schedule: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#cancel(params = {}, opts = {}) ⇒ Object

Cancels a subscription schedule and its associated subscription immediately (if the subscription schedule has an active subscription). A subscription schedule can only be canceled if its status is not_started or active.



727
728
729
730
731
732
733
734
# File 'lib/stripe/resources/subscription_schedule.rb', line 727

def cancel(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/cancel", { schedule: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#release(params = {}, opts = {}) ⇒ Object

Releases the subscription schedule immediately, which will stop scheduling of its phases, but leave any existing subscription in place. A schedule can only be released if its status is not_started or active. If the subscription schedule is currently associated with a subscription, releasing it will remove its subscription property and set the subscription’s ID to the released_subscription property.



767
768
769
770
771
772
773
774
# File 'lib/stripe/resources/subscription_schedule.rb', line 767

def release(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/release", { schedule: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end