Class: Stripe::SubscriptionSchedule

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/subscription_schedule.rb

Overview

A subscription schedule allows you to create and manage the lifecycle of a subscription by predefining expected changes.

Related guide: [Subscription schedules](docs.stripe.com/billing/subscriptions/subscription-schedules)

Defined Under Namespace

Classes: BillingMode, BillingSchedule, CurrentPhase, DefaultSettings, LastPriceMigrationError, Phase, Prebilling

Constant Summary collapse

OBJECT_NAME =
"subscription_schedule"

Constants inherited from StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applicationObject (readonly)

ID of the Connect Application that created the schedule.



849
850
851
# File 'lib/stripe/resources/subscription_schedule.rb', line 849

def application
  @application
end

#billing_behaviorObject (readonly)

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



851
852
853
# File 'lib/stripe/resources/subscription_schedule.rb', line 851

def billing_behavior
  @billing_behavior
end

#billing_modeObject (readonly)

The billing mode of the subscription.



853
854
855
# File 'lib/stripe/resources/subscription_schedule.rb', line 853

def billing_mode
  @billing_mode
end

#billing_schedulesObject (readonly)

Billing schedules for this subscription schedule.



855
856
857
# File 'lib/stripe/resources/subscription_schedule.rb', line 855

def billing_schedules
  @billing_schedules
end

#canceled_atObject (readonly)

Time at which the subscription schedule was canceled. Measured in seconds since the Unix epoch.



857
858
859
# File 'lib/stripe/resources/subscription_schedule.rb', line 857

def canceled_at
  @canceled_at
end

#completed_atObject (readonly)

Time at which the subscription schedule was completed. Measured in seconds since the Unix epoch.



859
860
861
# File 'lib/stripe/resources/subscription_schedule.rb', line 859

def completed_at
  @completed_at
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



861
862
863
# File 'lib/stripe/resources/subscription_schedule.rb', line 861

def created
  @created
end

#current_phaseObject (readonly)

Object representing the start and end dates for the current phase of the subscription schedule, if it is ‘active`.



863
864
865
# File 'lib/stripe/resources/subscription_schedule.rb', line 863

def current_phase
  @current_phase
end

#customerObject (readonly)

ID of the customer who owns the subscription schedule.



865
866
867
# File 'lib/stripe/resources/subscription_schedule.rb', line 865

def customer
  @customer
end

#customer_accountObject (readonly)

ID of the account who owns the subscription schedule.



867
868
869
# File 'lib/stripe/resources/subscription_schedule.rb', line 867

def 
  @customer_account
end

#default_settingsObject (readonly)

Attribute for field default_settings



869
870
871
# File 'lib/stripe/resources/subscription_schedule.rb', line 869

def default_settings
  @default_settings
end

#end_behaviorObject (readonly)

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



871
872
873
# File 'lib/stripe/resources/subscription_schedule.rb', line 871

def end_behavior
  @end_behavior
end

#idObject (readonly)

Unique identifier for the object.



873
874
875
# File 'lib/stripe/resources/subscription_schedule.rb', line 873

def id
  @id
end

#last_price_migration_errorObject (readonly)

Details of the most recent price migration that failed for the subscription schedule.



875
876
877
# File 'lib/stripe/resources/subscription_schedule.rb', line 875

def last_price_migration_error
  @last_price_migration_error
end

#latest_invoiceObject (readonly)

The most recent invoice this subscription schedule has generated.



877
878
879
# File 'lib/stripe/resources/subscription_schedule.rb', line 877

def latest_invoice
  @latest_invoice
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



879
880
881
# File 'lib/stripe/resources/subscription_schedule.rb', line 879

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



881
882
883
# File 'lib/stripe/resources/subscription_schedule.rb', line 881

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



883
884
885
# File 'lib/stripe/resources/subscription_schedule.rb', line 883

def object
  @object
end

#phasesObject (readonly)

Configuration for the subscription schedule’s phases.



885
886
887
# File 'lib/stripe/resources/subscription_schedule.rb', line 885

def phases
  @phases
end

#prebillingObject (readonly)

Time period and invoice for a Subscription billed in advance.



887
888
889
# File 'lib/stripe/resources/subscription_schedule.rb', line 887

def prebilling
  @prebilling
end

#released_atObject (readonly)

Time at which the subscription schedule was released. Measured in seconds since the Unix epoch.



889
890
891
# File 'lib/stripe/resources/subscription_schedule.rb', line 889

def released_at
  @released_at
end

#released_subscriptionObject (readonly)

ID of the subscription once managed by the subscription schedule (if it is released).



891
892
893
# File 'lib/stripe/resources/subscription_schedule.rb', line 891

def released_subscription
  @released_subscription
end

#statusObject (readonly)

The present status of the subscription schedule. Possible values are ‘not_started`, `active`, `completed`, `released`, and `canceled`. You can read more about the different states in our [behavior guide](docs.stripe.com/billing/subscriptions/subscription-schedules).



893
894
895
# File 'lib/stripe/resources/subscription_schedule.rb', line 893

def status
  @status
end

#subscriptionObject (readonly)

ID of the subscription managed by the subscription schedule.



895
896
897
# File 'lib/stripe/resources/subscription_schedule.rb', line 895

def subscription
  @subscription
end

#test_clockObject (readonly)

ID of the test clock this subscription schedule belongs to.



897
898
899
# File 'lib/stripe/resources/subscription_schedule.rb', line 897

def test_clock
  @test_clock
end

Class Method Details

.amend(schedule, params = {}, opts = {}) ⇒ Object

Amends an existing subscription schedule.



910
911
912
913
914
915
916
917
# File 'lib/stripe/resources/subscription_schedule.rb', line 910

def self.amend(schedule, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/amend", { schedule: CGI.escape(schedule) }),
    params: params,
    opts: opts
  )
end

.cancel(schedule, params = {}, opts = {}) ⇒ Object

Cancels a subscription schedule and its associated subscription immediately (if the subscription schedule has an active subscription). A subscription schedule can only be canceled if its status is not_started or active.



930
931
932
933
934
935
936
937
# File 'lib/stripe/resources/subscription_schedule.rb', line 930

def self.cancel(schedule, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/cancel", { schedule: CGI.escape(schedule) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

Creates a new subscription schedule object. Each customer can have up to 500 active or scheduled subscriptions.



940
941
942
943
944
945
946
947
# File 'lib/stripe/resources/subscription_schedule.rb', line 940

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/subscription_schedules",
    params: params,
    opts: opts
  )
end

.field_remappingsObject



1001
1002
1003
# File 'lib/stripe/resources/subscription_schedule.rb', line 1001

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



989
990
991
992
993
994
995
996
997
998
999
# File 'lib/stripe/resources/subscription_schedule.rb', line 989

def self.inner_class_types
  @inner_class_types = {
    billing_mode: BillingMode,
    billing_schedules: BillingSchedule,
    current_phase: CurrentPhase,
    default_settings: DefaultSettings,
    last_price_migration_error: LastPriceMigrationError,
    phases: Phase,
    prebilling: Prebilling,
  }
end

.list(params = {}, opts = {}) ⇒ Object

Retrieves the list of your subscription schedules.



950
951
952
953
954
955
956
957
# File 'lib/stripe/resources/subscription_schedule.rb', line 950

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/subscription_schedules",
    params: params,
    opts: opts
  )
end

.object_nameObject



14
15
16
# File 'lib/stripe/resources/subscription_schedule.rb', line 14

def self.object_name
  "subscription_schedule"
end

.release(schedule, params = {}, opts = {}) ⇒ Object

Releases the subscription schedule immediately, which will stop scheduling of its phases, but leave any existing subscription in place. A schedule can only be released if its status is not_started or active. If the subscription schedule is currently associated with a subscription, releasing it will remove its subscription property and set the subscription’s ID to the released_subscription property.



970
971
972
973
974
975
976
977
# File 'lib/stripe/resources/subscription_schedule.rb', line 970

def self.release(schedule, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/release", { schedule: CGI.escape(schedule) }),
    params: params,
    opts: opts
  )
end

.update(schedule, params = {}, opts = {}) ⇒ Object

Updates an existing subscription schedule.



980
981
982
983
984
985
986
987
# File 'lib/stripe/resources/subscription_schedule.rb', line 980

def self.update(schedule, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s", { schedule: CGI.escape(schedule) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#amend(params = {}, opts = {}) ⇒ Object

Amends an existing subscription schedule.



900
901
902
903
904
905
906
907
# File 'lib/stripe/resources/subscription_schedule.rb', line 900

def amend(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/amend", { schedule: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#cancel(params = {}, opts = {}) ⇒ Object

Cancels a subscription schedule and its associated subscription immediately (if the subscription schedule has an active subscription). A subscription schedule can only be canceled if its status is not_started or active.



920
921
922
923
924
925
926
927
# File 'lib/stripe/resources/subscription_schedule.rb', line 920

def cancel(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/cancel", { schedule: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#release(params = {}, opts = {}) ⇒ Object

Releases the subscription schedule immediately, which will stop scheduling of its phases, but leave any existing subscription in place. A schedule can only be released if its status is not_started or active. If the subscription schedule is currently associated with a subscription, releasing it will remove its subscription property and set the subscription’s ID to the released_subscription property.



960
961
962
963
964
965
966
967
# File 'lib/stripe/resources/subscription_schedule.rb', line 960

def release(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/release", { schedule: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end