Class: Stripe::SubscriptionSchedule

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/subscription_schedule.rb

Overview

A subscription schedule allows you to create and manage the lifecycle of a subscription by predefining expected changes.

Related guide: [Subscription schedules](stripe.com/docs/billing/subscriptions/subscription-schedules)

Defined Under Namespace

Classes: AmendParams, BillingMode, CancelParams, CreateParams, CurrentPhase, DefaultSettings, LastPriceMigrationError, ListParams, Phase, Prebilling, ReleaseParams, UpdateParams

Constant Summary collapse

OBJECT_NAME =
"subscription_schedule"

Constants inherited from StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applicationObject (readonly)

ID of the Connect Application that created the schedule.



2521
2522
2523
# File 'lib/stripe/resources/subscription_schedule.rb', line 2521

def application
  @application
end

#billing_behaviorObject (readonly)

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



2523
2524
2525
# File 'lib/stripe/resources/subscription_schedule.rb', line 2523

def billing_behavior
  @billing_behavior
end

#billing_modeObject (readonly)

The billing mode of the subscription.



2525
2526
2527
# File 'lib/stripe/resources/subscription_schedule.rb', line 2525

def billing_mode
  @billing_mode
end

#canceled_atObject (readonly)

Time at which the subscription schedule was canceled. Measured in seconds since the Unix epoch.



2527
2528
2529
# File 'lib/stripe/resources/subscription_schedule.rb', line 2527

def canceled_at
  @canceled_at
end

#completed_atObject (readonly)

Time at which the subscription schedule was completed. Measured in seconds since the Unix epoch.



2529
2530
2531
# File 'lib/stripe/resources/subscription_schedule.rb', line 2529

def completed_at
  @completed_at
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



2531
2532
2533
# File 'lib/stripe/resources/subscription_schedule.rb', line 2531

def created
  @created
end

#current_phaseObject (readonly)

Object representing the start and end dates for the current phase of the subscription schedule, if it is ‘active`.



2533
2534
2535
# File 'lib/stripe/resources/subscription_schedule.rb', line 2533

def current_phase
  @current_phase
end

#customerObject (readonly)

ID of the customer who owns the subscription schedule.



2535
2536
2537
# File 'lib/stripe/resources/subscription_schedule.rb', line 2535

def customer
  @customer
end

#customer_accountObject (readonly)

ID of the account who owns the subscription schedule.



2537
2538
2539
# File 'lib/stripe/resources/subscription_schedule.rb', line 2537

def 
  @customer_account
end

#default_settingsObject (readonly)

Attribute for field default_settings



2539
2540
2541
# File 'lib/stripe/resources/subscription_schedule.rb', line 2539

def default_settings
  @default_settings
end

#end_behaviorObject (readonly)

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



2541
2542
2543
# File 'lib/stripe/resources/subscription_schedule.rb', line 2541

def end_behavior
  @end_behavior
end

#idObject (readonly)

Unique identifier for the object.



2543
2544
2545
# File 'lib/stripe/resources/subscription_schedule.rb', line 2543

def id
  @id
end

#last_price_migration_errorObject (readonly)

Details of the most recent price migration that failed for the subscription schedule.



2545
2546
2547
# File 'lib/stripe/resources/subscription_schedule.rb', line 2545

def last_price_migration_error
  @last_price_migration_error
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



2547
2548
2549
# File 'lib/stripe/resources/subscription_schedule.rb', line 2547

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



2549
2550
2551
# File 'lib/stripe/resources/subscription_schedule.rb', line 2549

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



2551
2552
2553
# File 'lib/stripe/resources/subscription_schedule.rb', line 2551

def object
  @object
end

#phasesObject (readonly)

Configuration for the subscription schedule’s phases.



2553
2554
2555
# File 'lib/stripe/resources/subscription_schedule.rb', line 2553

def phases
  @phases
end

#prebillingObject (readonly)

Time period and invoice for a Subscription billed in advance.



2555
2556
2557
# File 'lib/stripe/resources/subscription_schedule.rb', line 2555

def prebilling
  @prebilling
end

#released_atObject (readonly)

Time at which the subscription schedule was released. Measured in seconds since the Unix epoch.



2557
2558
2559
# File 'lib/stripe/resources/subscription_schedule.rb', line 2557

def released_at
  @released_at
end

#released_subscriptionObject (readonly)

ID of the subscription once managed by the subscription schedule (if it is released).



2559
2560
2561
# File 'lib/stripe/resources/subscription_schedule.rb', line 2559

def released_subscription
  @released_subscription
end

#statusObject (readonly)

The present status of the subscription schedule. Possible values are ‘not_started`, `active`, `completed`, `released`, and `canceled`. You can read more about the different states in our [behavior guide](stripe.com/docs/billing/subscriptions/subscription-schedules).



2561
2562
2563
# File 'lib/stripe/resources/subscription_schedule.rb', line 2561

def status
  @status
end

#subscriptionObject (readonly)

ID of the subscription managed by the subscription schedule.



2563
2564
2565
# File 'lib/stripe/resources/subscription_schedule.rb', line 2563

def subscription
  @subscription
end

#test_clockObject (readonly)

ID of the test clock this subscription schedule belongs to.



2565
2566
2567
# File 'lib/stripe/resources/subscription_schedule.rb', line 2565

def test_clock
  @test_clock
end

Class Method Details

.amend(schedule, params = {}, opts = {}) ⇒ Object

Amends an existing subscription schedule.



2578
2579
2580
2581
2582
2583
2584
2585
# File 'lib/stripe/resources/subscription_schedule.rb', line 2578

def self.amend(schedule, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/amend", { schedule: CGI.escape(schedule) }),
    params: params,
    opts: opts
  )
end

.cancel(schedule, params = {}, opts = {}) ⇒ Object

Cancels a subscription schedule and its associated subscription immediately (if the subscription schedule has an active subscription). A subscription schedule can only be canceled if its status is not_started or active.



2598
2599
2600
2601
2602
2603
2604
2605
# File 'lib/stripe/resources/subscription_schedule.rb', line 2598

def self.cancel(schedule, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/cancel", { schedule: CGI.escape(schedule) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

Creates a new subscription schedule object. Each customer can have up to 500 active or scheduled subscriptions.



2608
2609
2610
2611
2612
2613
2614
2615
# File 'lib/stripe/resources/subscription_schedule.rb', line 2608

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/subscription_schedules",
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

Retrieves the list of your subscription schedules.



2618
2619
2620
2621
2622
2623
2624
2625
# File 'lib/stripe/resources/subscription_schedule.rb', line 2618

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/subscription_schedules",
    params: params,
    opts: opts
  )
end

.object_nameObject



14
15
16
# File 'lib/stripe/resources/subscription_schedule.rb', line 14

def self.object_name
  "subscription_schedule"
end

.release(schedule, params = {}, opts = {}) ⇒ Object

Releases the subscription schedule immediately, which will stop scheduling of its phases, but leave any existing subscription in place. A schedule can only be released if its status is not_started or active. If the subscription schedule is currently associated with a subscription, releasing it will remove its subscription property and set the subscription’s ID to the released_subscription property.



2638
2639
2640
2641
2642
2643
2644
2645
# File 'lib/stripe/resources/subscription_schedule.rb', line 2638

def self.release(schedule, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/release", { schedule: CGI.escape(schedule) }),
    params: params,
    opts: opts
  )
end

.update(schedule, params = {}, opts = {}) ⇒ Object

Updates an existing subscription schedule.



2648
2649
2650
2651
2652
2653
2654
2655
# File 'lib/stripe/resources/subscription_schedule.rb', line 2648

def self.update(schedule, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s", { schedule: CGI.escape(schedule) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#amend(params = {}, opts = {}) ⇒ Object

Amends an existing subscription schedule.



2568
2569
2570
2571
2572
2573
2574
2575
# File 'lib/stripe/resources/subscription_schedule.rb', line 2568

def amend(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/amend", { schedule: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#cancel(params = {}, opts = {}) ⇒ Object

Cancels a subscription schedule and its associated subscription immediately (if the subscription schedule has an active subscription). A subscription schedule can only be canceled if its status is not_started or active.



2588
2589
2590
2591
2592
2593
2594
2595
# File 'lib/stripe/resources/subscription_schedule.rb', line 2588

def cancel(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/cancel", { schedule: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#release(params = {}, opts = {}) ⇒ Object

Releases the subscription schedule immediately, which will stop scheduling of its phases, but leave any existing subscription in place. A schedule can only be released if its status is not_started or active. If the subscription schedule is currently associated with a subscription, releasing it will remove its subscription property and set the subscription’s ID to the released_subscription property.



2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/stripe/resources/subscription_schedule.rb', line 2628

def release(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/release", { schedule: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end