Class: Stripe::SubscriptionSchedule

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/subscription_schedule.rb

Overview

A subscription schedule allows you to create and manage the lifecycle of a subscription by predefining expected changes.

Related guide: [Subscription schedules](stripe.com/docs/billing/subscriptions/subscription-schedules)

Defined Under Namespace

Classes: AmendParams, BillingMode, CancelParams, CreateParams, CurrentPhase, DefaultSettings, LastPriceMigrationError, ListParams, Phase, Prebilling, ReleaseParams, UpdateParams

Constant Summary collapse

OBJECT_NAME =
"subscription_schedule"

Constants inherited from StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applicationObject (readonly)

ID of the Connect Application that created the schedule.



2820
2821
2822
# File 'lib/stripe/resources/subscription_schedule.rb', line 2820

def application
  @application
end

#billing_behaviorObject (readonly)

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



2822
2823
2824
# File 'lib/stripe/resources/subscription_schedule.rb', line 2822

def billing_behavior
  @billing_behavior
end

#billing_modeObject (readonly)

The billing mode of the subscription.



2824
2825
2826
# File 'lib/stripe/resources/subscription_schedule.rb', line 2824

def billing_mode
  @billing_mode
end

#canceled_atObject (readonly)

Time at which the subscription schedule was canceled. Measured in seconds since the Unix epoch.



2826
2827
2828
# File 'lib/stripe/resources/subscription_schedule.rb', line 2826

def canceled_at
  @canceled_at
end

#completed_atObject (readonly)

Time at which the subscription schedule was completed. Measured in seconds since the Unix epoch.



2828
2829
2830
# File 'lib/stripe/resources/subscription_schedule.rb', line 2828

def completed_at
  @completed_at
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



2830
2831
2832
# File 'lib/stripe/resources/subscription_schedule.rb', line 2830

def created
  @created
end

#current_phaseObject (readonly)

Object representing the start and end dates for the current phase of the subscription schedule, if it is ‘active`.



2832
2833
2834
# File 'lib/stripe/resources/subscription_schedule.rb', line 2832

def current_phase
  @current_phase
end

#customerObject (readonly)

ID of the customer who owns the subscription schedule.



2834
2835
2836
# File 'lib/stripe/resources/subscription_schedule.rb', line 2834

def customer
  @customer
end

#customer_accountObject (readonly)

ID of the account who owns the subscription schedule.



2836
2837
2838
# File 'lib/stripe/resources/subscription_schedule.rb', line 2836

def 
  @customer_account
end

#default_settingsObject (readonly)

Attribute for field default_settings



2838
2839
2840
# File 'lib/stripe/resources/subscription_schedule.rb', line 2838

def default_settings
  @default_settings
end

#end_behaviorObject (readonly)

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



2840
2841
2842
# File 'lib/stripe/resources/subscription_schedule.rb', line 2840

def end_behavior
  @end_behavior
end

#idObject (readonly)

Unique identifier for the object.



2842
2843
2844
# File 'lib/stripe/resources/subscription_schedule.rb', line 2842

def id
  @id
end

#last_price_migration_errorObject (readonly)

Details of the most recent price migration that failed for the subscription schedule.



2844
2845
2846
# File 'lib/stripe/resources/subscription_schedule.rb', line 2844

def last_price_migration_error
  @last_price_migration_error
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



2846
2847
2848
# File 'lib/stripe/resources/subscription_schedule.rb', line 2846

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



2848
2849
2850
# File 'lib/stripe/resources/subscription_schedule.rb', line 2848

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



2850
2851
2852
# File 'lib/stripe/resources/subscription_schedule.rb', line 2850

def object
  @object
end

#phasesObject (readonly)

Configuration for the subscription schedule’s phases.



2852
2853
2854
# File 'lib/stripe/resources/subscription_schedule.rb', line 2852

def phases
  @phases
end

#prebillingObject (readonly)

Time period and invoice for a Subscription billed in advance.



2854
2855
2856
# File 'lib/stripe/resources/subscription_schedule.rb', line 2854

def prebilling
  @prebilling
end

#released_atObject (readonly)

Time at which the subscription schedule was released. Measured in seconds since the Unix epoch.



2856
2857
2858
# File 'lib/stripe/resources/subscription_schedule.rb', line 2856

def released_at
  @released_at
end

#released_subscriptionObject (readonly)

ID of the subscription once managed by the subscription schedule (if it is released).



2858
2859
2860
# File 'lib/stripe/resources/subscription_schedule.rb', line 2858

def released_subscription
  @released_subscription
end

#statusObject (readonly)

The present status of the subscription schedule. Possible values are ‘not_started`, `active`, `completed`, `released`, and `canceled`. You can read more about the different states in our [behavior guide](stripe.com/docs/billing/subscriptions/subscription-schedules).



2860
2861
2862
# File 'lib/stripe/resources/subscription_schedule.rb', line 2860

def status
  @status
end

#subscriptionObject (readonly)

ID of the subscription managed by the subscription schedule.



2862
2863
2864
# File 'lib/stripe/resources/subscription_schedule.rb', line 2862

def subscription
  @subscription
end

#test_clockObject (readonly)

ID of the test clock this subscription schedule belongs to.



2864
2865
2866
# File 'lib/stripe/resources/subscription_schedule.rb', line 2864

def test_clock
  @test_clock
end

Class Method Details

.amend(schedule, params = {}, opts = {}) ⇒ Object

Amends an existing subscription schedule.



2877
2878
2879
2880
2881
2882
2883
2884
# File 'lib/stripe/resources/subscription_schedule.rb', line 2877

def self.amend(schedule, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/amend", { schedule: CGI.escape(schedule) }),
    params: params,
    opts: opts
  )
end

.cancel(schedule, params = {}, opts = {}) ⇒ Object

Cancels a subscription schedule and its associated subscription immediately (if the subscription schedule has an active subscription). A subscription schedule can only be canceled if its status is not_started or active.



2897
2898
2899
2900
2901
2902
2903
2904
# File 'lib/stripe/resources/subscription_schedule.rb', line 2897

def self.cancel(schedule, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/cancel", { schedule: CGI.escape(schedule) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

Creates a new subscription schedule object. Each customer can have up to 500 active or scheduled subscriptions.



2907
2908
2909
2910
2911
2912
2913
2914
# File 'lib/stripe/resources/subscription_schedule.rb', line 2907

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/subscription_schedules",
    params: params,
    opts: opts
  )
end

.field_remappingsObject



2967
2968
2969
# File 'lib/stripe/resources/subscription_schedule.rb', line 2967

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
# File 'lib/stripe/resources/subscription_schedule.rb', line 2956

def self.inner_class_types
  @inner_class_types = {
    billing_mode: BillingMode,
    current_phase: CurrentPhase,
    default_settings: DefaultSettings,
    last_price_migration_error: LastPriceMigrationError,
    phases: Phase,
    prebilling: Prebilling,
  }
end

.list(params = {}, opts = {}) ⇒ Object

Retrieves the list of your subscription schedules.



2917
2918
2919
2920
2921
2922
2923
2924
# File 'lib/stripe/resources/subscription_schedule.rb', line 2917

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/subscription_schedules",
    params: params,
    opts: opts
  )
end

.object_nameObject



14
15
16
# File 'lib/stripe/resources/subscription_schedule.rb', line 14

def self.object_name
  "subscription_schedule"
end

.release(schedule, params = {}, opts = {}) ⇒ Object

Releases the subscription schedule immediately, which will stop scheduling of its phases, but leave any existing subscription in place. A schedule can only be released if its status is not_started or active. If the subscription schedule is currently associated with a subscription, releasing it will remove its subscription property and set the subscription’s ID to the released_subscription property.



2937
2938
2939
2940
2941
2942
2943
2944
# File 'lib/stripe/resources/subscription_schedule.rb', line 2937

def self.release(schedule, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/release", { schedule: CGI.escape(schedule) }),
    params: params,
    opts: opts
  )
end

.update(schedule, params = {}, opts = {}) ⇒ Object

Updates an existing subscription schedule.



2947
2948
2949
2950
2951
2952
2953
2954
# File 'lib/stripe/resources/subscription_schedule.rb', line 2947

def self.update(schedule, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s", { schedule: CGI.escape(schedule) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#amend(params = {}, opts = {}) ⇒ Object

Amends an existing subscription schedule.



2867
2868
2869
2870
2871
2872
2873
2874
# File 'lib/stripe/resources/subscription_schedule.rb', line 2867

def amend(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/amend", { schedule: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#cancel(params = {}, opts = {}) ⇒ Object

Cancels a subscription schedule and its associated subscription immediately (if the subscription schedule has an active subscription). A subscription schedule can only be canceled if its status is not_started or active.



2887
2888
2889
2890
2891
2892
2893
2894
# File 'lib/stripe/resources/subscription_schedule.rb', line 2887

def cancel(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/cancel", { schedule: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#release(params = {}, opts = {}) ⇒ Object

Releases the subscription schedule immediately, which will stop scheduling of its phases, but leave any existing subscription in place. A schedule can only be released if its status is not_started or active. If the subscription schedule is currently associated with a subscription, releasing it will remove its subscription property and set the subscription’s ID to the released_subscription property.



2927
2928
2929
2930
2931
2932
2933
2934
# File 'lib/stripe/resources/subscription_schedule.rb', line 2927

def release(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/release", { schedule: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end