Class: Stripe::SubscriptionSchedule

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/subscription_schedule.rb

Overview

A subscription schedule allows you to create and manage the lifecycle of a subscription by predefining expected changes.

Related guide: [Subscription schedules](stripe.com/docs/billing/subscriptions/subscription-schedules)

Defined Under Namespace

Classes: BillingMode, CancelParams, CreateParams, CurrentPhase, DefaultSettings, ListParams, Phase, ReleaseParams, UpdateParams

Constant Summary collapse

OBJECT_NAME =
"subscription_schedule"

Constants inherited from StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applicationObject (readonly)

ID of the Connect Application that created the schedule.



1552
1553
1554
# File 'lib/stripe/resources/subscription_schedule.rb', line 1552

def application
  @application
end

#billing_modeObject (readonly)

The billing mode of the subscription.



1554
1555
1556
# File 'lib/stripe/resources/subscription_schedule.rb', line 1554

def billing_mode
  @billing_mode
end

#canceled_atObject (readonly)

Time at which the subscription schedule was canceled. Measured in seconds since the Unix epoch.



1556
1557
1558
# File 'lib/stripe/resources/subscription_schedule.rb', line 1556

def canceled_at
  @canceled_at
end

#completed_atObject (readonly)

Time at which the subscription schedule was completed. Measured in seconds since the Unix epoch.



1558
1559
1560
# File 'lib/stripe/resources/subscription_schedule.rb', line 1558

def completed_at
  @completed_at
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



1560
1561
1562
# File 'lib/stripe/resources/subscription_schedule.rb', line 1560

def created
  @created
end

#current_phaseObject (readonly)

Object representing the start and end dates for the current phase of the subscription schedule, if it is ‘active`.



1562
1563
1564
# File 'lib/stripe/resources/subscription_schedule.rb', line 1562

def current_phase
  @current_phase
end

#customerObject (readonly)

ID of the customer who owns the subscription schedule.



1564
1565
1566
# File 'lib/stripe/resources/subscription_schedule.rb', line 1564

def customer
  @customer
end

#default_settingsObject (readonly)

Attribute for field default_settings



1566
1567
1568
# File 'lib/stripe/resources/subscription_schedule.rb', line 1566

def default_settings
  @default_settings
end

#end_behaviorObject (readonly)

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



1568
1569
1570
# File 'lib/stripe/resources/subscription_schedule.rb', line 1568

def end_behavior
  @end_behavior
end

#idObject (readonly)

Unique identifier for the object.



1570
1571
1572
# File 'lib/stripe/resources/subscription_schedule.rb', line 1570

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



1572
1573
1574
# File 'lib/stripe/resources/subscription_schedule.rb', line 1572

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



1574
1575
1576
# File 'lib/stripe/resources/subscription_schedule.rb', line 1574

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



1576
1577
1578
# File 'lib/stripe/resources/subscription_schedule.rb', line 1576

def object
  @object
end

#phasesObject (readonly)

Configuration for the subscription schedule’s phases.



1578
1579
1580
# File 'lib/stripe/resources/subscription_schedule.rb', line 1578

def phases
  @phases
end

#released_atObject (readonly)

Time at which the subscription schedule was released. Measured in seconds since the Unix epoch.



1580
1581
1582
# File 'lib/stripe/resources/subscription_schedule.rb', line 1580

def released_at
  @released_at
end

#released_subscriptionObject (readonly)

ID of the subscription once managed by the subscription schedule (if it is released).



1582
1583
1584
# File 'lib/stripe/resources/subscription_schedule.rb', line 1582

def released_subscription
  @released_subscription
end

#statusObject (readonly)

The present status of the subscription schedule. Possible values are ‘not_started`, `active`, `completed`, `released`, and `canceled`. You can read more about the different states in our [behavior guide](stripe.com/docs/billing/subscriptions/subscription-schedules).



1584
1585
1586
# File 'lib/stripe/resources/subscription_schedule.rb', line 1584

def status
  @status
end

#subscriptionObject (readonly)

ID of the subscription managed by the subscription schedule.



1586
1587
1588
# File 'lib/stripe/resources/subscription_schedule.rb', line 1586

def subscription
  @subscription
end

#test_clockObject (readonly)

ID of the test clock this subscription schedule belongs to.



1588
1589
1590
# File 'lib/stripe/resources/subscription_schedule.rb', line 1588

def test_clock
  @test_clock
end

Class Method Details

.cancel(schedule, params = {}, opts = {}) ⇒ Object

Cancels a subscription schedule and its associated subscription immediately (if the subscription schedule has an active subscription). A subscription schedule can only be canceled if its status is not_started or active.



1601
1602
1603
1604
1605
1606
1607
1608
# File 'lib/stripe/resources/subscription_schedule.rb', line 1601

def self.cancel(schedule, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/cancel", { schedule: CGI.escape(schedule) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

Creates a new subscription schedule object. Each customer can have up to 500 active or scheduled subscriptions.



1611
1612
1613
1614
1615
1616
1617
1618
# File 'lib/stripe/resources/subscription_schedule.rb', line 1611

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/subscription_schedules",
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

Retrieves the list of your subscription schedules.



1621
1622
1623
1624
1625
1626
1627
1628
# File 'lib/stripe/resources/subscription_schedule.rb', line 1621

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/subscription_schedules",
    params: params,
    opts: opts
  )
end

.object_nameObject



14
15
16
# File 'lib/stripe/resources/subscription_schedule.rb', line 14

def self.object_name
  "subscription_schedule"
end

.release(schedule, params = {}, opts = {}) ⇒ Object

Releases the subscription schedule immediately, which will stop scheduling of its phases, but leave any existing subscription in place. A schedule can only be released if its status is not_started or active. If the subscription schedule is currently associated with a subscription, releasing it will remove its subscription property and set the subscription’s ID to the released_subscription property.



1641
1642
1643
1644
1645
1646
1647
1648
# File 'lib/stripe/resources/subscription_schedule.rb', line 1641

def self.release(schedule, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/release", { schedule: CGI.escape(schedule) }),
    params: params,
    opts: opts
  )
end

.update(schedule, params = {}, opts = {}) ⇒ Object

Updates an existing subscription schedule.



1651
1652
1653
1654
1655
1656
1657
1658
# File 'lib/stripe/resources/subscription_schedule.rb', line 1651

def self.update(schedule, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s", { schedule: CGI.escape(schedule) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#cancel(params = {}, opts = {}) ⇒ Object

Cancels a subscription schedule and its associated subscription immediately (if the subscription schedule has an active subscription). A subscription schedule can only be canceled if its status is not_started or active.



1591
1592
1593
1594
1595
1596
1597
1598
# File 'lib/stripe/resources/subscription_schedule.rb', line 1591

def cancel(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/cancel", { schedule: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#release(params = {}, opts = {}) ⇒ Object

Releases the subscription schedule immediately, which will stop scheduling of its phases, but leave any existing subscription in place. A schedule can only be released if its status is not_started or active. If the subscription schedule is currently associated with a subscription, releasing it will remove its subscription property and set the subscription’s ID to the released_subscription property.



1631
1632
1633
1634
1635
1636
1637
1638
# File 'lib/stripe/resources/subscription_schedule.rb', line 1631

def release(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/release", { schedule: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end