Class: Stripe::SubscriptionSchedule

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/subscription_schedule.rb

Overview

A subscription schedule allows you to create and manage the lifecycle of a subscription by predefining expected changes.

Related guide: [Subscription schedules](stripe.com/docs/billing/subscriptions/subscription-schedules)

Defined Under Namespace

Classes: AmendParams, BillingMode, CancelParams, CreateParams, CurrentPhase, DefaultSettings, LastPriceMigrationError, ListParams, Phase, Prebilling, ReleaseParams, UpdateParams

Constant Summary collapse

OBJECT_NAME =
"subscription_schedule"

Constants inherited from StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applicationObject (readonly)

ID of the Connect Application that created the schedule.



2399
2400
2401
# File 'lib/stripe/resources/subscription_schedule.rb', line 2399

def application
  @application
end

#billing_behaviorObject (readonly)

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



2401
2402
2403
# File 'lib/stripe/resources/subscription_schedule.rb', line 2401

def billing_behavior
  @billing_behavior
end

#billing_modeObject (readonly)

The billing mode of the subscription.



2403
2404
2405
# File 'lib/stripe/resources/subscription_schedule.rb', line 2403

def billing_mode
  @billing_mode
end

#canceled_atObject (readonly)

Time at which the subscription schedule was canceled. Measured in seconds since the Unix epoch.



2405
2406
2407
# File 'lib/stripe/resources/subscription_schedule.rb', line 2405

def canceled_at
  @canceled_at
end

#completed_atObject (readonly)

Time at which the subscription schedule was completed. Measured in seconds since the Unix epoch.



2407
2408
2409
# File 'lib/stripe/resources/subscription_schedule.rb', line 2407

def completed_at
  @completed_at
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



2409
2410
2411
# File 'lib/stripe/resources/subscription_schedule.rb', line 2409

def created
  @created
end

#current_phaseObject (readonly)

Object representing the start and end dates for the current phase of the subscription schedule, if it is ‘active`.



2411
2412
2413
# File 'lib/stripe/resources/subscription_schedule.rb', line 2411

def current_phase
  @current_phase
end

#customerObject (readonly)

ID of the customer who owns the subscription schedule.



2413
2414
2415
# File 'lib/stripe/resources/subscription_schedule.rb', line 2413

def customer
  @customer
end

#customer_accountObject (readonly)

ID of the account who owns the subscription schedule.



2415
2416
2417
# File 'lib/stripe/resources/subscription_schedule.rb', line 2415

def 
  @customer_account
end

#default_settingsObject (readonly)

Attribute for field default_settings



2417
2418
2419
# File 'lib/stripe/resources/subscription_schedule.rb', line 2417

def default_settings
  @default_settings
end

#end_behaviorObject (readonly)

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



2419
2420
2421
# File 'lib/stripe/resources/subscription_schedule.rb', line 2419

def end_behavior
  @end_behavior
end

#idObject (readonly)

Unique identifier for the object.



2421
2422
2423
# File 'lib/stripe/resources/subscription_schedule.rb', line 2421

def id
  @id
end

#last_price_migration_errorObject (readonly)

Details of the most recent price migration that failed for the subscription schedule.



2423
2424
2425
# File 'lib/stripe/resources/subscription_schedule.rb', line 2423

def last_price_migration_error
  @last_price_migration_error
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



2425
2426
2427
# File 'lib/stripe/resources/subscription_schedule.rb', line 2425

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



2427
2428
2429
# File 'lib/stripe/resources/subscription_schedule.rb', line 2427

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



2429
2430
2431
# File 'lib/stripe/resources/subscription_schedule.rb', line 2429

def object
  @object
end

#phasesObject (readonly)

Configuration for the subscription schedule’s phases.



2431
2432
2433
# File 'lib/stripe/resources/subscription_schedule.rb', line 2431

def phases
  @phases
end

#prebillingObject (readonly)

Time period and invoice for a Subscription billed in advance.



2433
2434
2435
# File 'lib/stripe/resources/subscription_schedule.rb', line 2433

def prebilling
  @prebilling
end

#released_atObject (readonly)

Time at which the subscription schedule was released. Measured in seconds since the Unix epoch.



2435
2436
2437
# File 'lib/stripe/resources/subscription_schedule.rb', line 2435

def released_at
  @released_at
end

#released_subscriptionObject (readonly)

ID of the subscription once managed by the subscription schedule (if it is released).



2437
2438
2439
# File 'lib/stripe/resources/subscription_schedule.rb', line 2437

def released_subscription
  @released_subscription
end

#statusObject (readonly)

The present status of the subscription schedule. Possible values are ‘not_started`, `active`, `completed`, `released`, and `canceled`. You can read more about the different states in our [behavior guide](stripe.com/docs/billing/subscriptions/subscription-schedules).



2439
2440
2441
# File 'lib/stripe/resources/subscription_schedule.rb', line 2439

def status
  @status
end

#subscriptionObject (readonly)

ID of the subscription managed by the subscription schedule.



2441
2442
2443
# File 'lib/stripe/resources/subscription_schedule.rb', line 2441

def subscription
  @subscription
end

#test_clockObject (readonly)

ID of the test clock this subscription schedule belongs to.



2443
2444
2445
# File 'lib/stripe/resources/subscription_schedule.rb', line 2443

def test_clock
  @test_clock
end

Class Method Details

.amend(schedule, params = {}, opts = {}) ⇒ Object

Amends an existing subscription schedule.



2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/stripe/resources/subscription_schedule.rb', line 2456

def self.amend(schedule, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/amend", { schedule: CGI.escape(schedule) }),
    params: params,
    opts: opts
  )
end

.cancel(schedule, params = {}, opts = {}) ⇒ Object

Cancels a subscription schedule and its associated subscription immediately (if the subscription schedule has an active subscription). A subscription schedule can only be canceled if its status is not_started or active.



2476
2477
2478
2479
2480
2481
2482
2483
# File 'lib/stripe/resources/subscription_schedule.rb', line 2476

def self.cancel(schedule, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/cancel", { schedule: CGI.escape(schedule) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

Creates a new subscription schedule object. Each customer can have up to 500 active or scheduled subscriptions.



2486
2487
2488
2489
2490
2491
2492
2493
# File 'lib/stripe/resources/subscription_schedule.rb', line 2486

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/subscription_schedules",
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

Retrieves the list of your subscription schedules.



2496
2497
2498
2499
2500
2501
2502
2503
# File 'lib/stripe/resources/subscription_schedule.rb', line 2496

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/subscription_schedules",
    params: params,
    opts: opts
  )
end

.object_nameObject



14
15
16
# File 'lib/stripe/resources/subscription_schedule.rb', line 14

def self.object_name
  "subscription_schedule"
end

.release(schedule, params = {}, opts = {}) ⇒ Object

Releases the subscription schedule immediately, which will stop scheduling of its phases, but leave any existing subscription in place. A schedule can only be released if its status is not_started or active. If the subscription schedule is currently associated with a subscription, releasing it will remove its subscription property and set the subscription’s ID to the released_subscription property.



2516
2517
2518
2519
2520
2521
2522
2523
# File 'lib/stripe/resources/subscription_schedule.rb', line 2516

def self.release(schedule, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/release", { schedule: CGI.escape(schedule) }),
    params: params,
    opts: opts
  )
end

.update(schedule, params = {}, opts = {}) ⇒ Object

Updates an existing subscription schedule.



2526
2527
2528
2529
2530
2531
2532
2533
# File 'lib/stripe/resources/subscription_schedule.rb', line 2526

def self.update(schedule, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s", { schedule: CGI.escape(schedule) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#amend(params = {}, opts = {}) ⇒ Object

Amends an existing subscription schedule.



2446
2447
2448
2449
2450
2451
2452
2453
# File 'lib/stripe/resources/subscription_schedule.rb', line 2446

def amend(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/amend", { schedule: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#cancel(params = {}, opts = {}) ⇒ Object

Cancels a subscription schedule and its associated subscription immediately (if the subscription schedule has an active subscription). A subscription schedule can only be canceled if its status is not_started or active.



2466
2467
2468
2469
2470
2471
2472
2473
# File 'lib/stripe/resources/subscription_schedule.rb', line 2466

def cancel(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/cancel", { schedule: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#release(params = {}, opts = {}) ⇒ Object

Releases the subscription schedule immediately, which will stop scheduling of its phases, but leave any existing subscription in place. A schedule can only be released if its status is not_started or active. If the subscription schedule is currently associated with a subscription, releasing it will remove its subscription property and set the subscription’s ID to the released_subscription property.



2506
2507
2508
2509
2510
2511
2512
2513
# File 'lib/stripe/resources/subscription_schedule.rb', line 2506

def release(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/subscription_schedules/%<schedule>s/release", { schedule: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end