Class: Stripe::SubscriptionSchedule::AmendParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Amendment, Prebilling, ScheduleSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ AmendParams

Returns a new instance of AmendParams.



2778
2779
2780
2781
2782
2783
2784
2785
2786
2787
2788
2789
2790
# File 'lib/stripe/resources/subscription_schedule.rb', line 2778

def initialize(
  amendments: nil,
  expand: nil,
  prebilling: nil,
  proration_behavior: nil,
  schedule_settings: nil
)
  @amendments = amendments
  @expand = expand
  @prebilling = prebilling
  @proration_behavior = proration_behavior
  @schedule_settings = schedule_settings
end

Instance Attribute Details

#amendmentsObject

Changes to apply to the phases of the subscription schedule, in the order provided.



2767
2768
2769
# File 'lib/stripe/resources/subscription_schedule.rb', line 2767

def amendments
  @amendments
end

#expandObject

Specifies which fields in the response should be expanded.



2769
2770
2771
# File 'lib/stripe/resources/subscription_schedule.rb', line 2769

def expand
  @expand
end

#prebillingObject

Provide any time periods to bill in advance.



2771
2772
2773
# File 'lib/stripe/resources/subscription_schedule.rb', line 2771

def prebilling
  @prebilling
end

#proration_behaviorObject

In cases where the amendment changes the currently active phase,

specifies if and how to prorate at the time of the request.


2774
2775
2776
# File 'lib/stripe/resources/subscription_schedule.rb', line 2774

def proration_behavior
  @proration_behavior
end

#schedule_settingsObject

Changes to apply to the subscription schedule.



2776
2777
2778
# File 'lib/stripe/resources/subscription_schedule.rb', line 2776

def schedule_settings
  @schedule_settings
end