Class: Stripe::SubscriptionSchedule::AmendParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: Amendment, Prebilling, ScheduleSettings
Instance Attribute Summary collapse
-
#amendments ⇒ Object
Changes to apply to the phases of the subscription schedule, in the order provided.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#prebilling ⇒ Object
Provide any time periods to bill in advance.
-
#proration_behavior ⇒ Object
In cases where the amendment changes the currently active phase, specifies if and how to prorate at the time of the request.
-
#schedule_settings ⇒ Object
Changes to apply to the subscription schedule.
Instance Method Summary collapse
-
#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ AmendParams
constructor
A new instance of AmendParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ AmendParams
Returns a new instance of AmendParams.
2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 2369 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2357 def initialize( amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil ) @amendments = amendments @expand = @prebilling = prebilling @proration_behavior = proration_behavior @schedule_settings = schedule_settings end |
Instance Attribute Details
#amendments ⇒ Object
Changes to apply to the phases of the subscription schedule, in the order provided.
2346 2347 2348 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2346 def amendments @amendments end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2348 2349 2350 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2348 def @expand end |
#prebilling ⇒ Object
Provide any time periods to bill in advance.
2350 2351 2352 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2350 def prebilling @prebilling end |
#proration_behavior ⇒ Object
In cases where the amendment changes the currently active phase,
specifies if and how to prorate at the time of the request.
2353 2354 2355 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2353 def proration_behavior @proration_behavior end |
#schedule_settings ⇒ Object
Changes to apply to the subscription schedule.
2355 2356 2357 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2355 def schedule_settings @schedule_settings end |