Class: Stripe::SubscriptionSchedule::AmendParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Amendment, Prebilling, ScheduleSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ AmendParams

Returns a new instance of AmendParams.



2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
# File 'lib/stripe/resources/subscription_schedule.rb', line 2325

def initialize(
  amendments: nil,
  expand: nil,
  prebilling: nil,
  proration_behavior: nil,
  schedule_settings: nil
)
  @amendments = amendments
  @expand = expand
  @prebilling = prebilling
  @proration_behavior = proration_behavior
  @schedule_settings = schedule_settings
end

Instance Attribute Details

#amendmentsObject

Changes to apply to the phases of the subscription schedule, in the order provided.



2314
2315
2316
# File 'lib/stripe/resources/subscription_schedule.rb', line 2314

def amendments
  @amendments
end

#expandObject

Specifies which fields in the response should be expanded.



2316
2317
2318
# File 'lib/stripe/resources/subscription_schedule.rb', line 2316

def expand
  @expand
end

#prebillingObject

Provide any time periods to bill in advance.



2318
2319
2320
# File 'lib/stripe/resources/subscription_schedule.rb', line 2318

def prebilling
  @prebilling
end

#proration_behaviorObject

In cases where the amendment changes the currently active phase,

specifies if and how to prorate at the time of the request.


2321
2322
2323
# File 'lib/stripe/resources/subscription_schedule.rb', line 2321

def proration_behavior
  @proration_behavior
end

#schedule_settingsObject

Changes to apply to the subscription schedule.



2323
2324
2325
# File 'lib/stripe/resources/subscription_schedule.rb', line 2323

def schedule_settings
  @schedule_settings
end