Class: Stripe::SubscriptionSchedule::AmendParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Amendment, Prebilling, ScheduleSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ AmendParams

Returns a new instance of AmendParams.



2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
# File 'lib/stripe/resources/subscription_schedule.rb', line 2309

def initialize(
  amendments: nil,
  expand: nil,
  prebilling: nil,
  proration_behavior: nil,
  schedule_settings: nil
)
  @amendments = amendments
  @expand = expand
  @prebilling = prebilling
  @proration_behavior = proration_behavior
  @schedule_settings = schedule_settings
end

Instance Attribute Details

#amendmentsObject

Changes to apply to the phases of the subscription schedule, in the order provided.



2298
2299
2300
# File 'lib/stripe/resources/subscription_schedule.rb', line 2298

def amendments
  @amendments
end

#expandObject

Specifies which fields in the response should be expanded.



2300
2301
2302
# File 'lib/stripe/resources/subscription_schedule.rb', line 2300

def expand
  @expand
end

#prebillingObject

Provide any time periods to bill in advance.



2302
2303
2304
# File 'lib/stripe/resources/subscription_schedule.rb', line 2302

def prebilling
  @prebilling
end

#proration_behaviorObject

In cases where the amendment changes the currently active phase,

specifies if and how to prorate at the time of the request.


2305
2306
2307
# File 'lib/stripe/resources/subscription_schedule.rb', line 2305

def proration_behavior
  @proration_behavior
end

#schedule_settingsObject

Changes to apply to the subscription schedule.



2307
2308
2309
# File 'lib/stripe/resources/subscription_schedule.rb', line 2307

def schedule_settings
  @schedule_settings
end