Class: Stripe::SubscriptionSchedule::AmendParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: Amendment, Prebilling, ScheduleSettings
Instance Attribute Summary collapse
-
#amendments ⇒ Object
Changes to apply to the phases of the subscription schedule, in the order provided.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#prebilling ⇒ Object
Provide any time periods to bill in advance.
-
#proration_behavior ⇒ Object
In cases where the amendment changes the currently active phase, specifies if and how to prorate at the time of the request.
-
#schedule_settings ⇒ Object
Changes to apply to the subscription schedule.
Instance Method Summary collapse
-
#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ AmendParams
constructor
A new instance of AmendParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ AmendParams
Returns a new instance of AmendParams.
2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2309 def initialize( amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil ) @amendments = amendments @expand = @prebilling = prebilling @proration_behavior = proration_behavior @schedule_settings = schedule_settings end |
Instance Attribute Details
#amendments ⇒ Object
Changes to apply to the phases of the subscription schedule, in the order provided.
2298 2299 2300 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2298 def amendments @amendments end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2300 2301 2302 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2300 def @expand end |
#prebilling ⇒ Object
Provide any time periods to bill in advance.
2302 2303 2304 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2302 def prebilling @prebilling end |
#proration_behavior ⇒ Object
In cases where the amendment changes the currently active phase,
specifies if and how to prorate at the time of the request.
2305 2306 2307 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2305 def proration_behavior @proration_behavior end |
#schedule_settings ⇒ Object
Changes to apply to the subscription schedule.
2307 2308 2309 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2307 def schedule_settings @schedule_settings end |