Class: Stripe::SubscriptionSchedule::AmendParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Amendment, Prebilling, ScheduleSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ AmendParams

Returns a new instance of AmendParams.



2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
# File 'lib/stripe/resources/subscription_schedule.rb', line 2194

def initialize(
  amendments: nil,
  expand: nil,
  prebilling: nil,
  proration_behavior: nil,
  schedule_settings: nil
)
  @amendments = amendments
  @expand = expand
  @prebilling = prebilling
  @proration_behavior = proration_behavior
  @schedule_settings = schedule_settings
end

Instance Attribute Details

#amendmentsObject

Changes to apply to the phases of the subscription schedule, in the order provided.



2183
2184
2185
# File 'lib/stripe/resources/subscription_schedule.rb', line 2183

def amendments
  @amendments
end

#expandObject

Specifies which fields in the response should be expanded.



2185
2186
2187
# File 'lib/stripe/resources/subscription_schedule.rb', line 2185

def expand
  @expand
end

#prebillingObject

Provide any time periods to bill in advance.



2187
2188
2189
# File 'lib/stripe/resources/subscription_schedule.rb', line 2187

def prebilling
  @prebilling
end

#proration_behaviorObject

In cases where the amendment changes the currently active phase,

specifies if and how to prorate at the time of the request.


2190
2191
2192
# File 'lib/stripe/resources/subscription_schedule.rb', line 2190

def proration_behavior
  @proration_behavior
end

#schedule_settingsObject

Changes to apply to the subscription schedule.



2192
2193
2194
# File 'lib/stripe/resources/subscription_schedule.rb', line 2192

def schedule_settings
  @schedule_settings
end