Class: Stripe::SubscriptionSchedule::AmendParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: Amendment, Prebilling, ScheduleSettings
Instance Attribute Summary collapse
-
#amendments ⇒ Object
Changes to apply to the phases of the subscription schedule, in the order provided.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#prebilling ⇒ Object
Provide any time periods to bill in advance.
-
#proration_behavior ⇒ Object
In cases where the amendment changes the currently active phase, specifies if and how to prorate at the time of the request.
-
#schedule_settings ⇒ Object
Changes to apply to the subscription schedule.
Instance Method Summary collapse
-
#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ AmendParams
constructor
A new instance of AmendParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ AmendParams
Returns a new instance of AmendParams.
2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2681 def initialize( amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil ) @amendments = amendments @expand = @prebilling = prebilling @proration_behavior = proration_behavior @schedule_settings = schedule_settings end |
Instance Attribute Details
#amendments ⇒ Object
Changes to apply to the phases of the subscription schedule, in the order provided.
2666 2667 2668 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2666 def amendments @amendments end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2669 2670 2671 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2669 def @expand end |
#prebilling ⇒ Object
Provide any time periods to bill in advance.
2672 2673 2674 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2672 def prebilling @prebilling end |
#proration_behavior ⇒ Object
In cases where the amendment changes the currently active phase,
specifies if and how to prorate at the time of the request.
2676 2677 2678 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2676 def proration_behavior @proration_behavior end |
#schedule_settings ⇒ Object
Changes to apply to the subscription schedule.
2679 2680 2681 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2679 def schedule_settings @schedule_settings end |