Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::AmendmentEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Amendment::AmendmentEnd
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: DiscountEnd, Duration
Instance Attribute Summary collapse
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#duration ⇒ Object
Time span for the amendment starting from the ‘amendment_start`.
-
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to end.
-
#type ⇒ Object
Select one of three ways to pass the ‘amendment_end`.
Instance Method Summary collapse
-
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd
constructor
A new instance of AmendmentEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd
Returns a new instance of AmendmentEnd.
2259 2260 2261 2262 2263 2264 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2259 def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) @discount_end = discount_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
2251 2252 2253 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2251 def discount_end @discount_end end |
#duration ⇒ Object
Time span for the amendment starting from the ‘amendment_start`.
2253 2254 2255 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2253 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.
2255 2256 2257 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2255 def @timestamp end |
#type ⇒ Object
Select one of three ways to pass the ‘amendment_end`.
2257 2258 2259 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2257 def type @type end |