Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::AmendmentEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd

Returns a new instance of AmendmentEnd.



1838
1839
1840
1841
1842
1843
# File 'lib/stripe/resources/subscription_schedule.rb', line 1838

def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil)
  @discount_end = discount_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#discount_endObject

Use the ‘end` time of a given discount.



1830
1831
1832
# File 'lib/stripe/resources/subscription_schedule.rb', line 1830

def discount_end
  @discount_end
end

#durationObject

Time span for the amendment starting from the ‘amendment_start`.



1832
1833
1834
# File 'lib/stripe/resources/subscription_schedule.rb', line 1832

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.



1834
1835
1836
# File 'lib/stripe/resources/subscription_schedule.rb', line 1834

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_end`.



1836
1837
1838
# File 'lib/stripe/resources/subscription_schedule.rb', line 1836

def type
  @type
end