Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::AmendmentEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd

Returns a new instance of AmendmentEnd.



1806
1807
1808
1809
1810
1811
# File 'lib/stripe/resources/subscription_schedule.rb', line 1806

def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil)
  @discount_end = discount_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#discount_endObject

Use the ‘end` time of a given discount.



1798
1799
1800
# File 'lib/stripe/resources/subscription_schedule.rb', line 1798

def discount_end
  @discount_end
end

#durationObject

Time span for the amendment starting from the ‘amendment_start`.



1800
1801
1802
# File 'lib/stripe/resources/subscription_schedule.rb', line 1800

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.



1802
1803
1804
# File 'lib/stripe/resources/subscription_schedule.rb', line 1802

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_end`.



1804
1805
1806
# File 'lib/stripe/resources/subscription_schedule.rb', line 1804

def type
  @type
end