Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::AmendmentEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd

Returns a new instance of AmendmentEnd.



1790
1791
1792
1793
1794
1795
# File 'lib/stripe/resources/subscription_schedule.rb', line 1790

def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil)
  @discount_end = discount_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#discount_endObject

Use the ‘end` time of a given discount.



1782
1783
1784
# File 'lib/stripe/resources/subscription_schedule.rb', line 1782

def discount_end
  @discount_end
end

#durationObject

Time span for the amendment starting from the ‘amendment_start`.



1784
1785
1786
# File 'lib/stripe/resources/subscription_schedule.rb', line 1784

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.



1786
1787
1788
# File 'lib/stripe/resources/subscription_schedule.rb', line 1786

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_end`.



1788
1789
1790
# File 'lib/stripe/resources/subscription_schedule.rb', line 1788

def type
  @type
end