Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::AmendmentStart
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Amendment::AmendmentStart
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: AmendmentEnd, DiscountEnd
Instance Attribute Summary collapse
-
#amendment_end ⇒ Object
Details of another amendment in the same array, immediately after which this amendment should begin.
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to start.
-
#type ⇒ Object
Select one of three ways to pass the ‘amendment_start`.
Instance Method Summary collapse
-
#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart
constructor
A new instance of AmendmentStart.
Methods inherited from RequestParams
Constructor Details
#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart
Returns a new instance of AmendmentStart.
1995 1996 1997 1998 1999 2000 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1995 def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) @amendment_end = amendment_end @discount_end = discount_end @timestamp = @type = type end |
Instance Attribute Details
#amendment_end ⇒ Object
Details of another amendment in the same array, immediately after which this amendment should begin.
1987 1988 1989 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1987 def amendment_end @amendment_end end |
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
1989 1990 1991 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1989 def discount_end @discount_end end |
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to start.
1991 1992 1993 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1991 def @timestamp end |
#type ⇒ Object
Select one of three ways to pass the ‘amendment_start`.
1993 1994 1995 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1993 def type @type end |