Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::AmendmentStart
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Amendment::AmendmentStart
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: AmendmentEnd, DiscountEnd
Instance Attribute Summary collapse
-
#amendment_end ⇒ Object
Details of another amendment in the same array, immediately after which this amendment should begin.
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to start.
-
#type ⇒ Object
Select one of three ways to pass the ‘amendment_start`.
Instance Method Summary collapse
-
#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart
constructor
A new instance of AmendmentStart.
Methods inherited from RequestParams
Constructor Details
#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart
Returns a new instance of AmendmentStart.
1841 1842 1843 1844 1845 1846 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1841 def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) @amendment_end = amendment_end @discount_end = discount_end @timestamp = @type = type end |
Instance Attribute Details
#amendment_end ⇒ Object
Details of another amendment in the same array, immediately after which this amendment should begin.
1833 1834 1835 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1833 def amendment_end @amendment_end end |
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
1835 1836 1837 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1835 def discount_end @discount_end end |
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to start.
1837 1838 1839 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1837 def @timestamp end |
#type ⇒ Object
Select one of three ways to pass the ‘amendment_start`.
1839 1840 1841 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1839 def type @type end |