Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::AmendmentStart

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: AmendmentEnd, DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart

Returns a new instance of AmendmentStart.



2133
2134
2135
2136
2137
2138
# File 'lib/stripe/resources/subscription_schedule.rb', line 2133

def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @discount_end = discount_end
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

Details of another amendment in the same array, immediately after which this amendment should begin.



2122
2123
2124
# File 'lib/stripe/resources/subscription_schedule.rb', line 2122

def amendment_end
  @amendment_end
end

#discount_endObject

Use the ‘end` time of a given discount.



2125
2126
2127
# File 'lib/stripe/resources/subscription_schedule.rb', line 2125

def discount_end
  @discount_end
end

#timestampObject

A precise Unix timestamp for the amendment to start.



2128
2129
2130
# File 'lib/stripe/resources/subscription_schedule.rb', line 2128

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_start`.



2131
2132
2133
# File 'lib/stripe/resources/subscription_schedule.rb', line 2131

def type
  @type
end