Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the discount to add.
-
#remove ⇒ Object
Details of the discount to remove.
-
#set ⇒ Object
Details of the discount to replace the existing discounts with.
-
#type ⇒ Object
Determines the type of discount action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
constructor
A new instance of DiscountAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
Returns a new instance of DiscountAction.
1788 1789 1790 1791 1792 1793 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1788 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the discount to add.
1780 1781 1782 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1780 def add @add end |
#remove ⇒ Object
Details of the discount to remove.
1782 1783 1784 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1782 def remove @remove end |
#set ⇒ Object
Details of the discount to replace the existing discounts with.
1784 1785 1786 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1784 def set @set end |
#type ⇒ Object
Determines the type of discount action.
1786 1787 1788 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1786 def type @type end |