Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the discount to add.
-
#remove ⇒ Object
Details of the discount to remove.
-
#set ⇒ Object
Details of the discount to replace the existing discounts with.
-
#type ⇒ Object
Determines the type of discount action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
constructor
A new instance of DiscountAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
Returns a new instance of DiscountAction.
1914 1915 1916 1917 1918 1919 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1914 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the discount to add.
1906 1907 1908 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1906 def add @add end |
#remove ⇒ Object
Details of the discount to remove.
1908 1909 1910 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1908 def remove @remove end |
#set ⇒ Object
Details of the discount to replace the existing discounts with.
1910 1911 1912 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1910 def set @set end |
#type ⇒ Object
Determines the type of discount action.
1912 1913 1914 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1912 def type @type end |