Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add

Returns a new instance of Add.



2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
# File 'lib/stripe/resources/subscription_schedule.rb', line 2323

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



2313
2314
2315
# File 'lib/stripe/resources/subscription_schedule.rb', line 2313

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



2315
2316
2317
# File 'lib/stripe/resources/subscription_schedule.rb', line 2315

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2317
2318
2319
# File 'lib/stripe/resources/subscription_schedule.rb', line 2317

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



2319
2320
2321
# File 'lib/stripe/resources/subscription_schedule.rb', line 2319

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



2321
2322
2323
# File 'lib/stripe/resources/subscription_schedule.rb', line 2321

def promotion_code
  @promotion_code
end