Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Add
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
Returns a new instance of Add.
2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2323 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
2313 2314 2315 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2313 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
2315 2316 2317 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2315 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
2317 2318 2319 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2317 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
2319 2320 2321 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2319 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
2321 2322 2323 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2321 def promotion_code @promotion_code end |