Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Add
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
Returns a new instance of Add.
2024 2025 2026 2027 2028 2029 2030 2031 2032 2033 2034 2035 2036 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2024 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
2014 2015 2016 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2014 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
2016 2017 2018 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2016 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
2018 2019 2020 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2018 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
2020 2021 2022 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2020 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
2022 2023 2024 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2022 def promotion_code @promotion_code end |