Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Add
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
Returns a new instance of Add.
1902 1903 1904 1905 1906 1907 1908 1909 1910 1911 1912 1913 1914 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1902 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
1892 1893 1894 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1892 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
1894 1895 1896 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1894 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1896 1897 1898 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1896 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
1898 1899 1900 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1898 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
1900 1901 1902 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1900 def promotion_code @promotion_code end |