Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add

Returns a new instance of Add.



1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
# File 'lib/stripe/resources/subscription_schedule.rb', line 1870

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



1860
1861
1862
# File 'lib/stripe/resources/subscription_schedule.rb', line 1860

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



1862
1863
1864
# File 'lib/stripe/resources/subscription_schedule.rb', line 1862

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1864
1865
1866
# File 'lib/stripe/resources/subscription_schedule.rb', line 1864

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



1866
1867
1868
# File 'lib/stripe/resources/subscription_schedule.rb', line 1866

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



1868
1869
1870
# File 'lib/stripe/resources/subscription_schedule.rb', line 1868

def promotion_code
  @promotion_code
end