Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add

Returns a new instance of Add.



1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
# File 'lib/stripe/resources/subscription_schedule.rb', line 1854

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



1844
1845
1846
# File 'lib/stripe/resources/subscription_schedule.rb', line 1844

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



1846
1847
1848
# File 'lib/stripe/resources/subscription_schedule.rb', line 1846

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1848
1849
1850
# File 'lib/stripe/resources/subscription_schedule.rb', line 1848

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



1850
1851
1852
# File 'lib/stripe/resources/subscription_schedule.rb', line 1850

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



1852
1853
1854
# File 'lib/stripe/resources/subscription_schedule.rb', line 1852

def promotion_code
  @promotion_code
end