Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Add
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
Returns a new instance of Add.
1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1739 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
1729 1730 1731 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1729 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
1731 1732 1733 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1731 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1733 1734 1735 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1733 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
1735 1736 1737 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1735 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
1737 1738 1739 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1737 def promotion_code @promotion_code end |