Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add

Returns a new instance of Add.



2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
# File 'lib/stripe/resources/subscription_schedule.rb', line 2166

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



2152
2153
2154
# File 'lib/stripe/resources/subscription_schedule.rb', line 2152

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



2155
2156
2157
# File 'lib/stripe/resources/subscription_schedule.rb', line 2155

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2158
2159
2160
# File 'lib/stripe/resources/subscription_schedule.rb', line 2158

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



2161
2162
2163
# File 'lib/stripe/resources/subscription_schedule.rb', line 2161

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



2164
2165
2166
# File 'lib/stripe/resources/subscription_schedule.rb', line 2164

def promotion_code
  @promotion_code
end