Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add

Returns a new instance of Add.



1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
# File 'lib/stripe/resources/subscription_schedule.rb', line 1861

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



1851
1852
1853
# File 'lib/stripe/resources/subscription_schedule.rb', line 1851

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



1853
1854
1855
# File 'lib/stripe/resources/subscription_schedule.rb', line 1853

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1855
1856
1857
# File 'lib/stripe/resources/subscription_schedule.rb', line 1855

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



1857
1858
1859
# File 'lib/stripe/resources/subscription_schedule.rb', line 1857

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



1859
1860
1861
# File 'lib/stripe/resources/subscription_schedule.rb', line 1859

def promotion_code
  @promotion_code
end