Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



1925
1926
1927
1928
1929
# File 'lib/stripe/resources/subscription_schedule.rb', line 1925

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



1919
1920
1921
# File 'lib/stripe/resources/subscription_schedule.rb', line 1919

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



1921
1922
1923
# File 'lib/stripe/resources/subscription_schedule.rb', line 1921

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



1923
1924
1925
# File 'lib/stripe/resources/subscription_schedule.rb', line 1923

def promotion_code
  @promotion_code
end