Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



1877
1878
1879
1880
1881
# File 'lib/stripe/resources/subscription_schedule.rb', line 1877

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



1871
1872
1873
# File 'lib/stripe/resources/subscription_schedule.rb', line 1871

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



1873
1874
1875
# File 'lib/stripe/resources/subscription_schedule.rb', line 1873

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



1875
1876
1877
# File 'lib/stripe/resources/subscription_schedule.rb', line 1875

def promotion_code
  @promotion_code
end