Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



1762
1763
1764
1765
1766
# File 'lib/stripe/resources/subscription_schedule.rb', line 1762

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



1756
1757
1758
# File 'lib/stripe/resources/subscription_schedule.rb', line 1756

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



1758
1759
1760
# File 'lib/stripe/resources/subscription_schedule.rb', line 1758

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



1760
1761
1762
# File 'lib/stripe/resources/subscription_schedule.rb', line 1760

def promotion_code
  @promotion_code
end