Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Remove
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Remove
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to remove from the ‘discounts` array.
-
#discount ⇒ Object
The ID of a discount to remove from the ‘discounts` array.
-
#promotion_code ⇒ Object
The ID of a promotion code to remove from the ‘discounts` array.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove
constructor
A new instance of Remove.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove
Returns a new instance of Remove.
2191 2192 2193 2194 2195 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2191 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to remove from the ‘discounts` array.
2183 2184 2185 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2183 def coupon @coupon end |
#discount ⇒ Object
The ID of a discount to remove from the ‘discounts` array.
2186 2187 2188 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2186 def discount @discount end |
#promotion_code ⇒ Object
The ID of a promotion code to remove from the ‘discounts` array.
2189 2190 2191 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2189 def promotion_code @promotion_code end |