Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set

Returns a new instance of Set.



1940
1941
1942
1943
1944
# File 'lib/stripe/resources/subscription_schedule.rb', line 1940

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



1934
1935
1936
# File 'lib/stripe/resources/subscription_schedule.rb', line 1934

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



1936
1937
1938
# File 'lib/stripe/resources/subscription_schedule.rb', line 1936

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



1938
1939
1940
# File 'lib/stripe/resources/subscription_schedule.rb', line 1938

def promotion_code
  @promotion_code
end