Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set

Returns a new instance of Set.



1908
1909
1910
1911
1912
# File 'lib/stripe/resources/subscription_schedule.rb', line 1908

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



1902
1903
1904
# File 'lib/stripe/resources/subscription_schedule.rb', line 1902

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



1904
1905
1906
# File 'lib/stripe/resources/subscription_schedule.rb', line 1904

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



1906
1907
1908
# File 'lib/stripe/resources/subscription_schedule.rb', line 1906

def promotion_code
  @promotion_code
end